# School data downloaded from https://data-nces.opendata.arcgis.com/search
# NCES Open Data - National Center for Education Statistics
# Using Public School Characteristics - Current
# Published Date May 2, 2022, 12:18 PM


school_list = [
    {
        "school": "John Shaw Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000480",
    },
    {
        "school": "Kiita Learning Community",
        "district": "North Slope Borough School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20061000470",
    },
    {
        "school": "Soldotna Montessori Charter School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000448",
    },
    {
        "school": "Kaleidoscope School of Arts & Science",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000463",
    },
    {
        "school": "Marathon School",
        "district": "Kenai Peninsula Borough School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20039000513",
    },
    {
        "school": "Whale Pass School",
        "district": "Southeast Island School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20070000526",
    },
    {
        "school": "Chatham Correspondence",
        "district": "Chatham School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20073000477",
    },
    {
        "school": "Denali PEAK",
        "district": "Denali Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20077000447",
    },
    {
        "school": "Akutan School",
        "district": "Aleutians East Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000700004",
    },
    {
        "school": "False Pass School",
        "district": "Aleutians East Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000700007",
    },
    {
        "school": "King Cove School",
        "district": "Aleutians East Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000700177",
    },
    {
        "school": "Sand Point School",
        "district": "Aleutians East Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000700461",
    },
    {
        "school": "St Paul School",
        "district": "Pribilof School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20067000308",
    },
    {
        "school": "Eagle's View Elementary School",
        "district": "Unalaska City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20072000340",
    },
    {
        "school": "Unalaska Jr/Sr High School",
        "district": "Unalaska City School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20072000661",
    },
    {
        "school": "Joann A. Alexie Memorial School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100206",
    },
    {
        "school": "Gladys Jung Elementary",
        "district": "Lower Kuskokwim School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100207",
    },
    {
        "school": "Bethel Regional High School",
        "district": "Lower Kuskokwim School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100208",
    },
    {
        "school": "Chaputnguak School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100209",
    },
    {
        "school": "Chief Paul Memorial School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100210",
    },
    {
        "school": "Ayagina'ar Elitnaurvik",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100211",
    },
    {
        "school": "Kwigillingok School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100212",
    },
    {
        "school": "Nelson Island Area School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100213",
    },
    {
        "school": "Anna Tobeluk Memorial School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100214",
    },
    {
        "school": "Arviq School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100215",
    },
    {
        "school": "Kuskokwim Learning Academy",
        "district": "Lower Kuskokwim School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20000100318",
    },
    {
        "school": "Ayaprun Elitnaurvik",
        "district": "Lower Kuskokwim School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100329",
    },
    {
        "school": "Paul T. Albert Memorial School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100389",
    },
    {
        "school": "Akula Elitnaurvik School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100391",
    },
    {
        "school": "Eek School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100392",
    },
    {
        "school": "Lewis Angapak Memorial School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100406",
    },
    {
        "school": "Nuniwarmiut School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100408",
    },
    {
        "school": "William Miller Memorial School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100409",
    },
    {
        "school": "Mikelnguut Elitnaurviat",
        "district": "Lower Kuskokwim School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100436",
    },
    {
        "school": "Ket'acik/Aapalluk Memorial School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100438",
    },
    {
        "school": "Z. John Williams Memorial School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100439",
    },
    {
        "school": "Ayaprun School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100440",
    },
    {
        "school": "Kuinerrarmiut Elitnaurviat",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100441",
    },
    {
        "school": "Negtemiut Elitnaurviat School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100474",
    },
    {
        "school": "Qugcuun Memorial School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100475",
    },
    {
        "school": "Rocky Mountain School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100476",
    },
    {
        "school": "Akiuk Memorial School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100619",
    },
    {
        "school": "Bethel Youth Facility",
        "district": "Lower Kuskokwim School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20000100620",
    },
    {
        "school": "Akiachak School",
        "district": "Yupiit School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000400579",
    },
    {
        "school": "Tuluksak School",
        "district": "Yupiit School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000400623",
    },
    {
        "school": "Akiak School",
        "district": "Yupiit School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000400624",
    },
    {
        "school": "Auntie Mary Nicoli Elementary",
        "district": "Kuspuk School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20076000346",
    },
    {
        "school": "Crow Village Sam School",
        "district": "Kuspuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20076000347",
    },
    {
        "school": "Johnnie John Sr. School",
        "district": "Kuspuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20076000348",
    },
    {
        "school": "Zackar Levi Elementary",
        "district": "Kuspuk School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20076000350",
    },
    {
        "school": "Jack Egnaty Sr. School",
        "district": "Kuspuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20076000352",
    },
    {
        "school": "Gusty Michael School",
        "district": "Kuspuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20076000353",
    },
    {
        "school": "Joseph S. & Olinga Gregory Elementary",
        "district": "Kuspuk School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20076000491",
    },
    {
        "school": "Aniak Jr/Sr High School",
        "district": "Kuspuk School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20076000663",
    },
    {
        "school": "George Morgan Sr. H.S.",
        "district": "Kuspuk School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20076000665",
    },
    {
        "school": "Bristol Bay Middle/High School",
        "district": "Bristol Bay Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20003000020",
    },
    {
        "school": "Naknek Elementary",
        "district": "Bristol Bay Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20003000626",
    },
    {
        "school": "Lakeview Home School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500473",
    },
    {
        "school": "Dillingham Elementary",
        "district": "Dillingham City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20012000042",
    },
    {
        "school": "Dillingham Middle/High School",
        "district": "Dillingham City School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20012000634",
    },
    {
        "school": "Aleknagik School",
        "district": "Southwest Region School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20071000330",
    },
    {
        "school": "Clarks Point School",
        "district": "Southwest Region School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20071000331",
    },
    {
        "school": "Koliganek School",
        "district": "Southwest Region School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20071000333",
    },
    {
        "school": "Manokotak School",
        "district": "Southwest Region School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20071000335",
    },
    {
        "school": "Chief Ivan Blunka School",
        "district": "Southwest Region School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20071000336",
    },
    {
        "school": "Togiak School",
        "district": "Southwest Region School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20071000338",
    },
    {
        "school": "William Sonny Nelson School",
        "district": "Southwest Region School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20071000465",
    },
    {
        "school": "Twin Hills School",
        "district": "Southwest Region School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20071000573",
    },
    {
        "school": "Interior Distance Education of Alaska (IDEA)",
        "district": "Galena City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20013000253",
    },
    {
        "school": "Haines Elementary",
        "district": "Haines Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20027000144",
    },
    {
        "school": "Haines High School",
        "district": "Haines Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20027000639",
    },
    {
        "school": "Haines Home School",
        "district": "Haines Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20027000670",
    },
    {
        "school": "Klukwan School",
        "district": "Chatham School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20073000490",
    },
    {
        "school": "Kenai Alternative High School",
        "district": "Kenai Peninsula Borough School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20039000079",
    },
    {
        "school": "Homer Flex School",
        "district": "Kenai Peninsula Borough School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20039000081",
    },
    {
        "school": "Chapman School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000152",
    },
    {
        "school": "Tebughna School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000153",
    },
    {
        "school": "Cooper Landing School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000155",
    },
    {
        "school": "Paul Banks Elementary",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000156",
    },
    {
        "school": "Nanwalek School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000157",
    },
    {
        "school": "Homer High School",
        "district": "Kenai Peninsula Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000158",
    },
    {
        "school": "Hope School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000159",
    },
    {
        "school": "Moose Pass School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000163",
    },
    {
        "school": "Nikolaevsk School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000164",
    },
    {
        "school": "Ninilchik School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000165",
    },
    {
        "school": "Port Graham School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000168",
    },
    {
        "school": "William H. Seward Elementary School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000169",
    },
    {
        "school": "Soldotna Elementary",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000171",
    },
    {
        "school": "Sterling Elementary",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000173",
    },
    {
        "school": "Susan B English School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000175",
    },
    {
        "school": "Tustumena Elementary",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000176",
    },
    {
        "school": "Aurora Borealis Charter School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000274",
    },
    {
        "school": "Fireweed Academy",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000296",
    },
    {
        "school": "West Homer Elementary",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000299",
    },
    {
        "school": "Connections",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000397",
    },
    {
        "school": "Redoubt Elementary",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000403",
    },
    {
        "school": "Seward Middle School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000437",
    },
    {
        "school": "McNeil Canyon Elementary",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000512",
    },
    {
        "school": "Razdolna School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000536",
    },
    {
        "school": "Kenai Central High School",
        "district": "Kenai Peninsula Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000537",
    },
    {
        "school": "Kenai Middle School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000538",
    },
    {
        "school": "Kalifornsky Beach Elementary",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000539",
    },
    {
        "school": "Seward High School",
        "district": "Kenai Peninsula Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000540",
    },
    {
        "school": "Skyview Middle School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000541",
    },
    {
        "school": "Soldotna High School",
        "district": "Kenai Peninsula Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000542",
    },
    {
        "school": "Homer Middle School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000543",
    },
    {
        "school": "Mt. View Elementary",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000601",
    },
    {
        "school": "Nikiski North Star Elementary",
        "district": "Kenai Peninsula Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000602",
    },
    {
        "school": "Voznesenka School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000612",
    },
    {
        "school": "Nikiski Middle/Senior High School",
        "district": "Kenai Peninsula Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000645",
    },
    {
        "school": "Kachemak Selo School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000718",
    },
    {
        "school": "Barry Craig Stewart Kasaan School",
        "district": "Southeast Island School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20070000319",
    },
    {
        "school": "Naukati School",
        "district": "Southeast Island School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20070000589",
    },
    {
        "school": "Chignik Bay School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500193",
    },
    {
        "school": "Chignik Lagoon School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500194",
    },
    {
        "school": "Chignik Lake School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500195",
    },
    {
        "school": "Igiugig School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500197",
    },
    {
        "school": "Kokhanok School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500198",
    },
    {
        "school": "Newhalen School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500199",
    },
    {
        "school": "Nondalton School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500200",
    },
    {
        "school": "Perryville School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500202",
    },
    {
        "school": "Pilot Point School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500203",
    },
    {
        "school": "Tanalian School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500204",
    },
    {
        "school": "Meshik School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500205",
    },
    {
        "school": "Levelock School",
        "district": "Lake and Peninsula Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048500334",
    },
    {
        "school": "Gambell School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000012",
    },
    {
        "school": "Koyuk-Malimiut School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000013",
    },
    {
        "school": "Hogarth Kingeekuk Sr. Memorial School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000014",
    },
    {
        "school": "Shishmaref School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000015",
    },
    {
        "school": "James C. Isabell School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000016",
    },
    {
        "school": "Unalakleet School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000017",
    },
    {
        "school": "Wales School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000018",
    },
    {
        "school": "White Mountain School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000019",
    },
    {
        "school": "Aniguiin School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000421",
    },
    {
        "school": "Martin L. Olson School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000422",
    },
    {
        "school": "Brevig Mission School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000423",
    },
    {
        "school": "Shaktoolik School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000466",
    },
    {
        "school": "Anthony A. Andrews School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000467",
    },
    {
        "school": "Tukurngailnguq School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000468",
    },
    {
        "school": "Diomede School",
        "district": "Bering Strait School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20002000499",
    },
    {
        "school": "Nome Elementary",
        "district": "Nome Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20057000254",
    },
    {
        "school": "Anvil City Science Academy",
        "district": "Nome Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20057000323",
    },
    {
        "school": "Extensions Correspondence",
        "district": "Nome Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20057000426",
    },
    {
        "school": "Nome-Beltz Jr/Sr High",
        "district": "Nome Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20057000568",
    },
    {
        "school": "Eben Hopson Middle School",
        "district": "North Slope Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20061000139",
    },
    {
        "school": "Nunamiut School",
        "district": "North Slope Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20061000283",
    },
    {
        "school": "Meade River School",
        "district": "North Slope Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20061000284",
    },
    {
        "school": "Fred Ipalook Elementary",
        "district": "North Slope Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20061000285",
    },
    {
        "school": "Barrow High School",
        "district": "North Slope Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20061000286",
    },
    {
        "school": "Harold Kaveolook School",
        "district": "North Slope Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20061000287",
    },
    {
        "school": "Nuiqsut Trapper School",
        "district": "North Slope Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20061000288",
    },
    {
        "school": "Tikigaq School",
        "district": "North Slope Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20061000289",
    },
    {
        "school": "Kali School",
        "district": "North Slope Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20061000290",
    },
    {
        "school": "Alak School",
        "district": "North Slope Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20061000291",
    },
    {
        "school": "Ambler School",
        "district": "Northwest Arctic Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500292",
    },
    {
        "school": "Buckland School",
        "district": "Northwest Arctic Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500293",
    },
    {
        "school": "Deering School",
        "district": "Northwest Arctic Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500294",
    },
    {
        "school": "Kiana School",
        "district": "Northwest Arctic Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500295",
    },
    {
        "school": "Kobuk School",
        "district": "Northwest Arctic Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500297",
    },
    {
        "school": "June Nelson Elementary",
        "district": "Northwest Arctic Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500298",
    },
    {
        "school": "McQueen School",
        "district": "Northwest Arctic Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500300",
    },
    {
        "school": "Napaaqtugmiut School",
        "district": "Northwest Arctic Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500301",
    },
    {
        "school": "Aqqaluk High/Noorvik Elementary",
        "district": "Northwest Arctic Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500302",
    },
    {
        "school": "Shungnak School",
        "district": "Northwest Arctic Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500303",
    },
    {
        "school": "Davis-Ramoth School",
        "district": "Northwest Arctic Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500394",
    },
    {
        "school": "Kotzebue Middle/High School",
        "district": "Northwest Arctic Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500569",
    },
    {
        "school": "Craig High School",
        "district": "Craig City School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20009000038",
    },
    {
        "school": "PACE Correspondence",
        "district": "Craig City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20009000160",
    },
    {
        "school": "Craig Middle School",
        "district": "Craig City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20009000433",
    },
    {
        "school": "Craig Elementary",
        "district": "Craig City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20009000629",
    },
    {
        "school": "Hydaburg School",
        "district": "Hydaburg City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20033000148",
    },
    {
        "school": "Klawock City School",
        "district": "Klawock City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20045000179",
    },
    {
        "school": "Charles R. Leask Sr. Middle School",
        "district": "Annette Island School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20052500111",
    },
    {
        "school": "Richard Johnson Elementary",
        "district": "Annette Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20052500250",
    },
    {
        "school": "Metlakatla High School",
        "district": "Annette Island School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20052500648",
    },
    {
        "school": "Howard Valentine Coffman Cove School",
        "district": "Southeast Island School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20070000314",
    },
    {
        "school": "Thorne Bay School",
        "district": "Southeast Island School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20070000326",
    },
    {
        "school": "Hyder School",
        "district": "Southeast Island School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20070000428",
    },
    {
        "school": "Hollis School",
        "district": "Southeast Island School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20070000484",
    },
    {
        "school": "SE Island Correspondence",
        "district": "Southeast Island School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20070000486",
    },
    {
        "school": "Mt. Edgecumbe High School",
        "district": "Mount Edgecumbe High School Agency",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000600558",
    },
    {
        "school": "Pacific High School",
        "district": "Sitka School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20024000035",
    },
    {
        "school": "Blatchley Middle School",
        "district": "Sitka School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20024000136",
    },
    {
        "school": "Sitka High School",
        "district": "Sitka School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20024000143",
    },
    {
        "school": "Keet Gooshi Heen Elementary",
        "district": "Sitka School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20024000638",
    },
    {
        "school": "Hoonah City School",
        "district": "Hoonah City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20030000146",
    },
    {
        "school": "Pelican School",
        "district": "Pelican City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20063000304",
    },
    {
        "school": "Skagway School",
        "district": "Skagway School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20069000310",
    },
    {
        "school": "Angoon School",
        "district": "Chatham School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20073000342",
    },
    {
        "school": "Gustavus School",
        "district": "Chatham School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20073000344",
    },
    {
        "school": "Alaska REACH Academy",
        "district": "Alaska Gateway School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20005000023",
    },
    {
        "school": "Dot Lake School",
        "district": "Alaska Gateway School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20005000024",
    },
    {
        "school": "Eagle Community School",
        "district": "Alaska Gateway School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20005000025",
    },
    {
        "school": "Walter Northway School",
        "district": "Alaska Gateway School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20005000027",
    },
    {
        "school": "Tok School",
        "district": "Alaska Gateway School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20005000028",
    },
    {
        "school": "Tanacross School",
        "district": "Alaska Gateway School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20005000424",
    },
    {
        "school": "Tetlin School",
        "district": "Alaska Gateway School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20005000528",
    },
    {
        "school": "Mentasta Lake School",
        "district": "Alaska Gateway School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20005000026",
    },
    {
        "school": "Cordova Jr/Sr High School",
        "district": "Cordova City School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20006000029",
    },
    {
        "school": "Mt. Eccles Elementary",
        "district": "Cordova City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20006000627",
    },
    {
        "school": "Glennallen Elementary",
        "district": "Copper River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20007000034",
    },
    {
        "school": "Kenny Lake School",
        "district": "Copper River School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20007000036",
    },
    {
        "school": "Glennallen Jr/Sr High School",
        "district": "Copper River School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20007000039",
    },
    {
        "school": "Upstream Learning Correspondence",
        "district": "Copper River School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20007000398",
    },
    {
        "school": "Slana School",
        "district": "Copper River School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20007000583",
    },
    {
        "school": "George H. Gilson Middle School",
        "district": "Valdez City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20078000367",
    },
    {
        "school": "Valdez High School",
        "district": "Valdez City School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20078000370",
    },
    {
        "school": "Hermon Hutchens Elementary",
        "district": "Valdez City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20078000495",
    },
    {
        "school": "Alakanuk School",
        "district": "Lower Yukon School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000300216",
    },
    {
        "school": "Emmonak School",
        "district": "Lower Yukon School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000300217",
    },
    {
        "school": "Marshall School",
        "district": "Lower Yukon School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000300218",
    },
    {
        "school": "Hooper Bay School",
        "district": "Lower Yukon School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000300219",
    },
    {
        "school": "Mountain Village School",
        "district": "Lower Yukon School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000300220",
    },
    {
        "school": "Russian Mission School",
        "district": "Lower Yukon School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000300222",
    },
    {
        "school": "Pilot Station School",
        "district": "Lower Yukon School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000300410",
    },
    {
        "school": "Kotlik School",
        "district": "Lower Yukon School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000300411",
    },
    {
        "school": "Scammon Bay School",
        "district": "Lower Yukon School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000300412",
    },
    {
        "school": "Nunam Iqua School",
        "district": "Lower Yukon School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000300413",
    },
    {
        "school": "Chevak School",
        "district": "Kashunamiut School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000500582",
    },
    {
        "school": "Saint Mary's School",
        "district": "Saint Mary's School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20068000659",
    },
    {
        "school": "Baranof Elementary",
        "district": "Sitka School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20024000135",
    },
    {
        "school": "Sitka REACH",
        "district": "Sitka School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20024000142",
    },
    {
        "school": "Kake Elementary & High School",
        "district": "Kake City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20036000150",
    },
    {
        "school": "Rae C. Stedman Elementary",
        "district": "Petersburg Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20066000305",
    },
    {
        "school": "Petersburg High School",
        "district": "Petersburg Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20066000570",
    },
    {
        "school": "Mitkof Middle School",
        "district": "Petersburg Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20066000604",
    },
    {
        "school": "Port Alexander School",
        "district": "Southeast Island School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20070000322",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Wrangell Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20081000373",
    },
    {
        "school": "Wrangell High School",
        "district": "Wrangell Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20081000576",
    },
    {
        "school": "Stikine Middle School",
        "district": "Wrangell Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20081000728",
    },
    {
        "school": "Yakutat School",
        "district": "Yakutat School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20084000667",
    },
    {
        "school": "Sidney C. Huntington Elementary",
        "district": "Galena City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20013000044",
    },
    {
        "school": "Galena Interior Learning Academy (GILA)",
        "district": "Galena City School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20013000252",
    },
    {
        "school": "Sidney C. Huntington Jr/Sr High School",
        "district": "Galena City School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20013000635",
    },
    {
        "school": "Nenana City School",
        "district": "Nenana City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20054000251",
    },
    {
        "school": "CyberLynx Correspondence Program",
        "district": "Nenana City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20054000321",
    },
    {
        "school": "Maudrey J. Sommer School",
        "district": "Tanana City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20071500488",
    },
    {
        "school": "Anderson School",
        "district": "Denali Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20077000354",
    },
    {
        "school": "Cantwell School",
        "district": "Denali Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20077000356",
    },
    {
        "school": "Tri-Valley School",
        "district": "Denali Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20077000357",
    },
    {
        "school": "Arctic Village School",
        "district": "Yukon Flats School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20077500358",
    },
    {
        "school": "Tsuk Taih School",
        "district": "Yukon Flats School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20077500360",
    },
    {
        "school": "Circle School",
        "district": "Yukon Flats School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20077500361",
    },
    {
        "school": "Fort Yukon School",
        "district": "Yukon Flats School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20077500362",
    },
    {
        "school": "John Fredson School",
        "district": "Yukon Flats School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20077500366",
    },
    {
        "school": "Yukon Flats Distance Education Program",
        "district": "Yukon Flats School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20077500446",
    },
    {
        "school": "Cruikshank School",
        "district": "Yukon Flats School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20077500552",
    },
    {
        "school": "Distance Learning/Corresp. Ctr.",
        "district": "Iditarod Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20052000327",
    },
    {
        "school": "Blackwell School",
        "district": "Iditarod Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20052000240",
    },
    {
        "school": "David Louis Memorial School",
        "district": "Iditarod Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20052000241",
    },
    {
        "school": "Jeffery A. Bader Memorial School",
        "district": "Iditarod Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20052000242",
    },
    {
        "school": "McGrath School",
        "district": "Iditarod Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20052000244",
    },
    {
        "school": "Top of the Kuskokwim School",
        "district": "Iditarod Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20052000245",
    },
    {
        "school": "Innoko River School",
        "district": "Iditarod Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20052000246",
    },
    {
        "school": "Takotna Community School",
        "district": "Iditarod Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20052000247",
    },
    {
        "school": "South Anchorage High School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000454",
    },
    {
        "school": "Eagle River High School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000458",
    },
    {
        "school": "Winterberry School",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000459",
    },
    {
        "school": "Eagle Academy Charter School",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000460",
    },
    {
        "school": "Crossroads",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20018000509",
    },
    {
        "school": "Frontier Charter School",
        "district": "Anchorage School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000530",
    },
    {
        "school": "Highland Academy Charter",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000555",
    },
    {
        "school": "Houston Middle School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000450",
    },
    {
        "school": "American Charter Academy",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000452",
    },
    {
        "school": "Twindly Bridge Charter School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000469",
    },
    {
        "school": "Yakov E. Netsvetov School",
        "district": "Aleutian Region School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20001000005",
    },
    {
        "school": "Adak School",
        "district": "Aleutian Region School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20001000080",
    },
    {
        "school": "Goose Bay Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000011",
    },
    {
        "school": "Mat-Su Central School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000224",
    },
    {
        "school": "Glacier View School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000225",
    },
    {
        "school": "Iditarod Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000226",
    },
    {
        "school": "Palmer High School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000227",
    },
    {
        "school": "Sherrod Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000230",
    },
    {
        "school": "Susitna Valley High",
        "district": "Matanuska-Susitna Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000232",
    },
    {
        "school": "Swanson Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000233",
    },
    {
        "school": "Wasilla High School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000237",
    },
    {
        "school": "Academy Charter School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000311",
    },
    {
        "school": "Midnight Sun Family Learning Center",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000312",
    },
    {
        "school": "Mat-Su Youth Facility",
        "district": "Matanuska-Susitna Borough School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20051000407",
    },
    {
        "school": "Snowshoe Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000414",
    },
    {
        "school": "Meadow Lakes Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000416",
    },
    {
        "school": "Valley Pathways",
        "district": "Matanuska-Susitna Borough School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20051000425",
    },
    {
        "school": "Larson Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000443",
    },
    {
        "school": "Teeland Middle School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000444",
    },
    {
        "school": "Cottonwood Creek Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000514",
    },
    {
        "school": "Palmer Middle School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000544",
    },
    {
        "school": "Wasilla Middle School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000545",
    },
    {
        "school": "Tanaina Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000547",
    },
    {
        "school": "Pioneer Peak Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000565",
    },
    {
        "school": "Finger Lake Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000585",
    },
    {
        "school": "Houston Jr./Sr. High School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000586",
    },
    {
        "school": "Colony High School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000711",
    },
    {
        "school": "Colony Middle School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000719",
    },
    {
        "school": "Burchell High School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20051000720",
    },
    {
        "school": "Willow Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000721",
    },
    {
        "school": "Trapper Creek Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000722",
    },
    {
        "school": "Talkeetna Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000723",
    },
    {
        "school": "Butte Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000724",
    },
    {
        "school": "Sutton Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000725",
    },
    {
        "school": "Beryozova School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000726",
    },
    {
        "school": "Big Lake Elementary",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000727",
    },
    {
        "school": "Tatitlek Community School",
        "district": "Chugach School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20080000371",
    },
    {
        "school": "Whittier Community School",
        "district": "Chugach School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20080000372",
    },
    {
        "school": "FOCUS Homeschool",
        "district": "Chugach School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20080000496",
    },
    {
        "school": "Chenega School",
        "district": "Chugach School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20080000553",
    },
    {
        "school": "Abbott Loop Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000053",
    },
    {
        "school": "Airport Heights Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000054",
    },
    {
        "school": "Aurora Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000056",
    },
    {
        "school": "Bartlett High School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000057",
    },
    {
        "school": "Baxter Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000058",
    },
    {
        "school": "Bayshore Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000059",
    },
    {
        "school": "Birchwood ABC Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000060",
    },
    {
        "school": "Campbell STEM Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000062",
    },
    {
        "school": "Central Middle School of Science",
        "district": "Anchorage School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000063",
    },
    {
        "school": "Clark Middle School",
        "district": "Anchorage School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000064",
    },
    {
        "school": "Chester Valley Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000065",
    },
    {
        "school": "Chinook Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000066",
    },
    {
        "school": "Chugach Optional Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000067",
    },
    {
        "school": "Chugiak Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000068",
    },
    {
        "school": "Chugiak High School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000069",
    },
    {
        "school": "College Gate Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000070",
    },
    {
        "school": "Creekside Park Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000071",
    },
    {
        "school": "Denali Montessori Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000072",
    },
    {
        "school": "Dimond High School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000073",
    },
    {
        "school": "Eagle River Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000074",
    },
    {
        "school": "East High School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000075",
    },
    {
        "school": "Fairview Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000076",
    },
    {
        "school": "Girdwood School",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000077",
    },
    {
        "school": "Gladys Wood Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000078",
    },
    {
        "school": "Huffman Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000082",
    },
    {
        "school": "Inlet View Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000083",
    },
    {
        "school": "Lake Otis Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000086",
    },
    {
        "school": "Tudor Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000087",
    },
    {
        "school": "Turnagain Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000088",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000089",
    },
    {
        "school": "Muldoon Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000092",
    },
    {
        "school": "North Star Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000093",
    },
    {
        "school": "Northern Lights ABC K-8 School",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000094",
    },
    {
        "school": "Northwood ABC",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000095",
    },
    {
        "school": "Nunaka Valley Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000096",
    },
    {
        "school": "O'Malley Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000097",
    },
    {
        "school": "Ocean View Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000098",
    },
    {
        "school": "Orion Elementary School",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000099",
    },
    {
        "school": "Polaris K-12 School",
        "district": "Anchorage School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000101",
    },
    {
        "school": "Ptarmigan Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000102",
    },
    {
        "school": "Rabbit Creek Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000103",
    },
    {
        "school": "Alpenglow Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000104",
    },
    {
        "school": "Rogers Park Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000105",
    },
    {
        "school": "Romig Middle School",
        "district": "Anchorage School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000106",
    },
    {
        "school": "Russian Jack Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000107",
    },
    {
        "school": "Sand Lake Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000108",
    },
    {
        "school": "S.A.V.E. High School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20018000109",
    },
    {
        "school": "Benson Secondary/S.E.A.R.C.H.",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20018000110",
    },
    {
        "school": "Scenic Park Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000112",
    },
    {
        "school": "Steller Secondary School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000115",
    },
    {
        "school": "Susitna Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000116",
    },
    {
        "school": "Taku Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000117",
    },
    {
        "school": "Ursa Minor Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000118",
    },
    {
        "school": "Wendler Middle School",
        "district": "Anchorage School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000119",
    },
    {
        "school": "West High School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000120",
    },
    {
        "school": "Whaley School",
        "district": "Anchorage School District",
        "level": "Other",
        "type": "Special education school",
        "state": "AK",
        "nces_id": "20018000121",
    },
    {
        "school": "Williwaw Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000122",
    },
    {
        "school": "Willow Crest Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000123",
    },
    {
        "school": "Wonder Park Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000124",
    },
    {
        "school": "Kasuun Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000147",
    },
    {
        "school": "Kincaid Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000149",
    },
    {
        "school": "Lake Hood Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000151",
    },
    {
        "school": "William Tyson Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000154",
    },
    {
        "school": "Aquarian Charter School",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000172",
    },
    {
        "school": "Family Partnership Charter School",
        "district": "Anchorage School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000178",
    },
    {
        "school": "Mirror Lake Middle School",
        "district": "Anchorage School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000229",
    },
    {
        "school": "Alaska State School for Deaf and Hard of Hearing",
        "district": "Anchorage School District",
        "level": "Other",
        "type": "Special education school",
        "state": "AK",
        "nces_id": "20018000341",
    },
    {
        "school": "Trailside Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000390",
    },
    {
        "school": "Ursa Major Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000400",
    },
    {
        "school": "Martin Luther King Jr. Technical High School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AK",
        "nces_id": "20018000401",
    },
    {
        "school": "McLaughlin Secondary School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20018000432",
    },
    {
        "school": "Government Hill Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000504",
    },
    {
        "school": "Gruening Middle School",
        "district": "Anchorage School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000505",
    },
    {
        "school": "Klatt Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000506",
    },
    {
        "school": "Service High School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000531",
    },
    {
        "school": "Ravenwood Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000532",
    },
    {
        "school": "Bear Valley Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000533",
    },
    {
        "school": "Hanshew Middle School",
        "district": "Anchorage School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000534",
    },
    {
        "school": "Spring Hill Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000561",
    },
    {
        "school": "Mears Middle School",
        "district": "Anchorage School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000562",
    },
    {
        "school": "Fire Lake Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000598",
    },
    {
        "school": "Bowman Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000713",
    },
    {
        "school": "AVAIL School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20018000714",
    },
    {
        "school": "Star of the North Secondary School",
        "district": "Fairbanks North Star Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000462",
    },
    {
        "school": "Effie Kokrine Charter School",
        "district": "Fairbanks North Star Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000464",
    },
    {
        "school": "Raven School",
        "district": "Yukon-Koyukuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20086200453",
    },
    {
        "school": "Gerstle River School",
        "district": "Delta-Greely School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20010000510",
    },
    {
        "school": "Ladd Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000002",
    },
    {
        "school": "University Park Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000045",
    },
    {
        "school": "Golden Heart Academy",
        "district": "Fairbanks North Star Borough School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20060000049",
    },
    {
        "school": "Arctic Light Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000055",
    },
    {
        "school": "Anne Wien Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000114",
    },
    {
        "school": "Chinook Montessori Charter School",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000162",
    },
    {
        "school": "Crawford Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000238",
    },
    {
        "school": "Anderson Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000256",
    },
    {
        "school": "Midnight Sun Elementary School",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000258",
    },
    {
        "school": "Barnette Magnet School",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000259",
    },
    {
        "school": "Ben Eielson Jr/Sr High School",
        "district": "Fairbanks North Star Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000260",
    },
    {
        "school": "Denali Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000262",
    },
    {
        "school": "Hunter Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000267",
    },
    {
        "school": "Joy Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000269",
    },
    {
        "school": "Lathrop High School",
        "district": "Fairbanks North Star Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000270",
    },
    {
        "school": "Nordale Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000271",
    },
    {
        "school": "North Pole High School",
        "district": "Fairbanks North Star Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000273",
    },
    {
        "school": "Ryan Middle School",
        "district": "Fairbanks North Star Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000275",
    },
    {
        "school": "Salcha Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000276",
    },
    {
        "school": "Tanana Middle School",
        "district": "Fairbanks North Star Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000277",
    },
    {
        "school": "Two Rivers School",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000279",
    },
    {
        "school": "Woodriver Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000280",
    },
    {
        "school": "West Valley High School",
        "district": "Fairbanks North Star Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000281",
    },
    {
        "school": "Randy Smith Middle School",
        "district": "Fairbanks North Star Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000324",
    },
    {
        "school": "Alternative Learning Systems",
        "district": "Fairbanks North Star Borough School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20060000325",
    },
    {
        "school": "Pearl Creek Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000516",
    },
    {
        "school": "Weller Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000519",
    },
    {
        "school": "Fairbanks B.E.S.T.",
        "district": "Fairbanks North Star Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000587",
    },
    {
        "school": "Ticasuk Brown Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000600",
    },
    {
        "school": "Hutchison High School",
        "district": "Fairbanks North Star Borough School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AK",
        "nces_id": "20060000650",
    },
    {
        "school": "North Pole Elementary",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000651",
    },
    {
        "school": "North Pole Middle School",
        "district": "Fairbanks North Star Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000652",
    },
    {
        "school": "Delta Junction Elementary",
        "district": "Delta-Greely School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20010000559",
    },
    {
        "school": "Delta/Greely Homeschool",
        "district": "Delta-Greely School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20010000599",
    },
    {
        "school": "Delta Junction Senior High School",
        "district": "Delta-Greely School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20010000630",
    },
    {
        "school": "Allakaket School",
        "district": "Yukon-Koyukuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20086200377",
    },
    {
        "school": "Johnny Oldman School",
        "district": "Yukon-Koyukuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20086200379",
    },
    {
        "school": "Jimmy Huntington School",
        "district": "Yukon-Koyukuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20086200380",
    },
    {
        "school": "Kaltag School",
        "district": "Yukon-Koyukuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20086200381",
    },
    {
        "school": "Ella B. Vernetti School",
        "district": "Yukon-Koyukuk School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20086200382",
    },
    {
        "school": "Gladys Dart School",
        "district": "Yukon-Koyukuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20086200383",
    },
    {
        "school": "Minto School",
        "district": "Yukon-Koyukuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20086200384",
    },
    {
        "school": "Andrew K. Demoski School",
        "district": "Yukon-Koyukuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20086200385",
    },
    {
        "school": "Merreline A Kangas School",
        "district": "Yukon-Koyukuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20086200386",
    },
    {
        "school": "HomeBRIDGE",
        "district": "Juneau Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000125",
    },
    {
        "school": "Auke Bay Elementary",
        "district": "Juneau Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000127",
    },
    {
        "school": "Floyd Dryden Middle School",
        "district": "Juneau Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000129",
    },
    {
        "school": "Say?ik: Gastineau Community School",
        "district": "Juneau Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000130",
    },
    {
        "school": "Glacier Valley Elementary",
        "district": "Juneau Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000131",
    },
    {
        "school": "Harborview Elementary",
        "district": "Juneau Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000132",
    },
    {
        "school": "Juneau-Douglas High School",
        "district": "Juneau Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000133",
    },
    {
        "school": "Dzantik'i Heeni Middle School",
        "district": "Juneau Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000134",
    },
    {
        "school": "Riverbend Elementary",
        "district": "Juneau Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000265",
    },
    {
        "school": "Juneau Community Charter School",
        "district": "Juneau Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000268",
    },
    {
        "school": "Johnson Youth Center",
        "district": "Juneau Borough School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20021000396",
    },
    {
        "school": "Mendenhall River Community School",
        "district": "Juneau Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000508",
    },
    {
        "school": "Tongass School of Arts and Sciences Charter School",
        "district": "Ketchikan Gateway Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20015000523",
    },
    {
        "school": "Houghtaling Elementary",
        "district": "Ketchikan Gateway Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20015000046",
    },
    {
        "school": "Ketchikan High School",
        "district": "Ketchikan Gateway Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20015000047",
    },
    {
        "school": "Revilla Jr/Sr High School",
        "district": "Ketchikan Gateway Borough School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20015000048",
    },
    {
        "school": "Schoenbar Middle School",
        "district": "Ketchikan Gateway Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20015000050",
    },
    {
        "school": "Fawn Mountain Elementary",
        "district": "Ketchikan Gateway Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20015000052",
    },
    {
        "school": "Ketchikan Charter School",
        "district": "Ketchikan Gateway Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20015000306",
    },
    {
        "school": "Fast Track",
        "district": "Ketchikan Gateway Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20015000427",
    },
    {
        "school": "Point Higgins School",
        "district": "Ketchikan Gateway Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20015000584",
    },
    {
        "school": "North Star Elementary",
        "district": "Kodiak Island Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000137",
    },
    {
        "school": "Akhiok School",
        "district": "Kodiak Island Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000180",
    },
    {
        "school": "Chiniak School",
        "district": "Kodiak Island Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000181",
    },
    {
        "school": "East Elementary",
        "district": "Kodiak Island Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000183",
    },
    {
        "school": "Kodiak High School",
        "district": "Kodiak Island Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000185",
    },
    {
        "school": "Kodiak Middle School",
        "district": "Kodiak Island Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000186",
    },
    {
        "school": "Main Elementary",
        "district": "Kodiak Island Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000188",
    },
    {
        "school": "Old Harbor School",
        "district": "Kodiak Island Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000189",
    },
    {
        "school": "Peterson Elementary",
        "district": "Kodiak Island Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000190",
    },
    {
        "school": "Port Lions School",
        "district": "Kodiak Island Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000191",
    },
    {
        "school": "Ouzinkie School",
        "district": "Kodiak Island Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000192",
    },
    {
        "school": "AKTEACH",
        "district": "Kodiak Island Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20048000435",
    },
    {
        "school": "Hope Academy",
        "district": "Eufaula City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10141001874",
    },
    {
        "school": "Cleburne County Middle School",
        "district": "Cleburne County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10078001671",
    },
    {
        "school": "Straughn Middle School",
        "district": "Covington County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10093001672",
    },
    {
        "school": "Harmony School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102001676",
    },
    {
        "school": "West Point Intermediate School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102001679",
    },
    {
        "school": "Gadsden City High School",
        "district": "Gadsden City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162001824",
    },
    {
        "school": "Tharptown High School",
        "district": "Franklin County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10159001869",
    },
    {
        "school": "Ossie Ware Mitchell Middle School",
        "district": "Birmingham City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039001823",
    },
    {
        "school": "Phillips Academy",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039001878",
    },
    {
        "school": "Sparkman Ninth Grade School",
        "district": "Madison County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222001821",
    },
    {
        "school": "Learning Tree Inc Tallassee",
        "district": "The Little Tree Preschool  Auburn",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003502105",
    },
    {
        "school": "Priceville Junior High School",
        "district": "Morgan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001871",
    },
    {
        "school": "Odenville Intermediate School",
        "district": "St Clair County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201877",
    },
    {
        "school": "Chelsea Park Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001822",
    },
    {
        "school": "Calera Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001868",
    },
    {
        "school": "Choctaw County Elementary",
        "district": "Choctaw County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10069001561",
    },
    {
        "school": "Central Elementary School",
        "district": "Coosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10090002074",
    },
    {
        "school": "Crossville High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114001860",
    },
    {
        "school": "Phil Campbell Elementary School",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10159001861",
    },
    {
        "school": "Lamar County HighIntermediate",
        "district": "Lamar County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10195001511",
    },
    {
        "school": "Barbour County High School",
        "district": "Barbour County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10030000074",
    },
    {
        "school": "Barbour County Primary School",
        "district": "Barbour County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10030001478",
    },
    {
        "school": "Barbour County Intermediate School",
        "district": "Barbour County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10030001641",
    },
    {
        "school": "Eufaula High School",
        "district": "Eufaula City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10141000511",
    },
    {
        "school": "Moorer Middle School",
        "district": "Eufaula City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10141000513",
    },
    {
        "school": "Eufaula Primary School",
        "district": "Eufaula City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10141000514",
    },
    {
        "school": "Eufaula Elementary School",
        "district": "Eufaula City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10141001510",
    },
    {
        "school": "Bullock County High School",
        "district": "Bullock County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10048000218",
    },
    {
        "school": "South Highlands Middle School",
        "district": "Bullock County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10048000221",
    },
    {
        "school": "Union Springs Elementary School",
        "district": "Bullock County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10048000222",
    },
    {
        "school": "Bullock County Career Technical Center",
        "district": "Bullock County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10048000688",
    },
    {
        "school": "Greenville High School",
        "district": "Butler County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10051000226",
    },
    {
        "school": "Greenville Middle School",
        "district": "Butler County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10051000228",
    },
    {
        "school": "McKenzie High School",
        "district": "Butler County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10051000229",
    },
    {
        "school": "WO Parmer Elementary School",
        "district": "Butler County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10051000231",
    },
    {
        "school": "Butler County Area Vocational School",
        "district": "Butler County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10051000690",
    },
    {
        "school": "Greenville Elementary School",
        "district": "Butler County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10051001482",
    },
    {
        "school": "Cedar Bluff High School",
        "district": "Cherokee County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10063000274",
    },
    {
        "school": "Centre Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10063000275",
    },
    {
        "school": "Centre Middle School",
        "district": "Cherokee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10063000276",
    },
    {
        "school": "Cherokee County High School",
        "district": "Cherokee County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10063000278",
    },
    {
        "school": "Gaylesville High School",
        "district": "Cherokee County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10063000279",
    },
    {
        "school": "Sand Rock High School",
        "district": "Cherokee County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10063000282",
    },
    {
        "school": "Spring Garden High School",
        "district": "Cherokee County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10063000283",
    },
    {
        "school": "Cherokee County Career  Technology Center",
        "district": "Cherokee County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10063000741",
    },
    {
        "school": "Southern Choctaw Elementary School",
        "district": "Choctaw County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10069000182",
    },
    {
        "school": "Choctaw County High School",
        "district": "Choctaw County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10069000291",
    },
    {
        "school": "Southern Choctaw High School",
        "district": "Choctaw County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10069000297",
    },
    {
        "school": "Clarke County High School",
        "district": "Clarke County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10072000298",
    },
    {
        "school": "Grove Hill Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10072000302",
    },
    {
        "school": "Jackson Middle School",
        "district": "Clarke County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10072000304",
    },
    {
        "school": "Joe M Gillmore Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10072000305",
    },
    {
        "school": "Wilson Hall Middle School",
        "district": "Clarke County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10072000306",
    },
    {
        "school": "Jackson Intermediate School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10072001450",
    },
    {
        "school": "Jackson High School",
        "district": "Clarke County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10072001493",
    },
    {
        "school": "Thomasville Elementary School",
        "district": "Thomasville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10330001247",
    },
    {
        "school": "Thomasville High School",
        "district": "Thomasville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10330001248",
    },
    {
        "school": "Ashland Elementary School",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10075000307",
    },
    {
        "school": "Lineville Elementary School",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10075000312",
    },
    {
        "school": "Cleburne County Elementary School",
        "district": "Cleburne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10078000317",
    },
    {
        "school": "Cleburne County High School",
        "district": "Cleburne County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10078000318",
    },
    {
        "school": "Fruithurst Elementary School",
        "district": "Cleburne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10078000319",
    },
    {
        "school": "Pleasant Grove Elementary School",
        "district": "Cleburne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10078000320",
    },
    {
        "school": "Ranburne High School",
        "district": "Cleburne County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10078000321",
    },
    {
        "school": "Cleburne County Career Technical School",
        "district": "Cleburne County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10078000768",
    },
    {
        "school": "Ranburne Elementary School",
        "district": "Cleburne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10078001726",
    },
    {
        "school": "Conecuh County Junior High School",
        "district": "Conecuh County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10087000344",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Conecuh County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10087000345",
    },
    {
        "school": "Lyeffion Junior High School",
        "district": "Conecuh County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10087000347",
    },
    {
        "school": "Thurgood Marshall Middle School",
        "district": "Conecuh County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10087000348",
    },
    {
        "school": "Repton Junior High School",
        "district": "Conecuh County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10087000350",
    },
    {
        "school": "Hillcrest High School",
        "district": "Conecuh County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10087001766",
    },
    {
        "school": "Coosa County Career Tech Center",
        "district": "Coosa County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10090000798",
    },
    {
        "school": "Central High School",
        "district": "Coosa County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10090001749",
    },
    {
        "school": "Andalusia High School",
        "district": "Andalusia City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10006000007",
    },
    {
        "school": "Andalusia Junior High",
        "district": "Andalusia City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10006000008",
    },
    {
        "school": "Andalusia Elementary School",
        "district": "Andalusia City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10006001467",
    },
    {
        "school": "Straughn Elementary School",
        "district": "Covington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10093000280",
    },
    {
        "school": "Fleeta School",
        "district": "Covington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10093000359",
    },
    {
        "school": "Florala High School",
        "district": "Covington County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10093000360",
    },
    {
        "school": "Pleasant Home School",
        "district": "Covington County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10093000361",
    },
    {
        "school": "Red Level High School",
        "district": "Covington County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10093000362",
    },
    {
        "school": "Straughn High School",
        "district": "Covington County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10093000363",
    },
    {
        "school": "WS Harlan Elementary School",
        "district": "Covington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10093000364",
    },
    {
        "school": "Opp High School",
        "district": "Opp City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10261001073",
    },
    {
        "school": "Opp Middle School",
        "district": "Opp City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10261001074",
    },
    {
        "school": "Opp Elementary School",
        "district": "Opp City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10261001078",
    },
    {
        "school": "Brantley High School",
        "district": "Crenshaw County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10096000365",
    },
    {
        "school": "Highland Home School",
        "district": "Crenshaw County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10096000367",
    },
    {
        "school": "Luverne High School",
        "district": "Crenshaw County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10096000368",
    },
    {
        "school": "Crenshaw County Area Vocational",
        "district": "Crenshaw County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10096000801",
    },
    {
        "school": "Collinsville High School",
        "district": "DeKalb County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114000411",
    },
    {
        "school": "Crossville Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114000412",
    },
    {
        "school": "Fyffe High School",
        "district": "DeKalb County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114000415",
    },
    {
        "school": "Geraldine School",
        "district": "DeKalb County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114000416",
    },
    {
        "school": "Henagar Junior High School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114000418",
    },
    {
        "school": "Ider School",
        "district": "DeKalb County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114000419",
    },
    {
        "school": "Moon Lake School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114000421",
    },
    {
        "school": "Plainview School",
        "district": "DeKalb County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114000422",
    },
    {
        "school": "Ruhuma Junior High School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114000423",
    },
    {
        "school": "Sylvania School",
        "district": "DeKalb County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114000424",
    },
    {
        "school": "Valley Head High School",
        "district": "DeKalb County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114000425",
    },
    {
        "school": "Alternative School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10114000819",
    },
    {
        "school": "Dekalb Annex School",
        "district": "DeKalb County",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10114000830",
    },
    {
        "school": "Dekalb Technical Center",
        "district": "DeKalb County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10114000832",
    },
    {
        "school": "Fort Payne High School",
        "district": "Fort Payne City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10156000538",
    },
    {
        "school": "Williams Avenue Elementary School",
        "district": "Fort Payne City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10156000539",
    },
    {
        "school": "Wills Valley Elementary School",
        "district": "Fort Payne City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10156001365",
    },
    {
        "school": "Fort Payne Middle School",
        "district": "Fort Payne City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10156001750",
    },
    {
        "school": "Brewton Elementary School",
        "district": "Brewton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10045000214",
    },
    {
        "school": "Brewton Middle School",
        "district": "Brewton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10045000215",
    },
    {
        "school": "TR Miller High School",
        "district": "Brewton City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10045000216",
    },
    {
        "school": "Escambia County High School",
        "district": "Escambia County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10135000484",
    },
    {
        "school": "Escambia County Middle School",
        "district": "Escambia County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10135000485",
    },
    {
        "school": "Flomaton High School",
        "district": "Escambia County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10135000487",
    },
    {
        "school": "Huxford Elementary School",
        "district": "Escambia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10135000488",
    },
    {
        "school": "PollardMcCall Junior High School",
        "district": "Escambia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10135000489",
    },
    {
        "school": "W S Neal High School",
        "district": "Escambia County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10135000492",
    },
    {
        "school": "Escambia County Alternative School",
        "district": "Escambia County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10135000840",
    },
    {
        "school": "EscambiaBrewton Career Technical Center",
        "district": "Escambia County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10135000841",
    },
    {
        "school": "Flomaton Elementary School",
        "district": "Escambia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10135001504",
    },
    {
        "school": "W S Neal Elementary School",
        "district": "Escambia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10135001505",
    },
    {
        "school": "W S Neal Middle School",
        "district": "Escambia County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10135001506",
    },
    {
        "school": "Rachel Patterson Elementary School",
        "district": "Escambia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10135001661",
    },
    {
        "school": "Berry High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10147000521",
    },
    {
        "school": "Fayette Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10147000523",
    },
    {
        "school": "Hubbertville School",
        "district": "Fayette County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10147000525",
    },
    {
        "school": "Berry Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10147001512",
    },
    {
        "school": "Fayette Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10147001514",
    },
    {
        "school": "Fayette County High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10147001787",
    },
    {
        "school": "Belgreen High School",
        "district": "Franklin County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10159000541",
    },
    {
        "school": "East Franklin Junior High School",
        "district": "Franklin County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10159000542",
    },
    {
        "school": "Phil Campbell High School",
        "district": "Franklin County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10159000544",
    },
    {
        "school": "Red Bay High School",
        "district": "Franklin County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10159000545",
    },
    {
        "school": "Tharptown Elementary School",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10159000547",
    },
    {
        "school": "Vina High School",
        "district": "Franklin County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10159000548",
    },
    {
        "school": "Franklin County Career Technical Center",
        "district": "Franklin County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10159000860",
    },
    {
        "school": "Phillips High School",
        "district": "Marion County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10231000869",
    },
    {
        "school": "Phillips Elementary School",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10231001455",
    },
    {
        "school": "Russellville Elementary School",
        "district": "Russellville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10291001140",
    },
    {
        "school": "Russellville Middle School",
        "district": "Russellville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10291001141",
    },
    {
        "school": "Russellville High School",
        "district": "Russellville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10291001142",
    },
    {
        "school": "West Elementary School",
        "district": "Russellville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10291001143",
    },
    {
        "school": "Sulligent School",
        "district": "Lamar County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10195000756",
    },
    {
        "school": "Vernon Elementary School",
        "district": "Lamar County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10195000757",
    },
    {
        "school": "Lamar County School Of Technology",
        "district": "Lamar County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10195000941",
    },
    {
        "school": "South Lamar School",
        "district": "Lamar County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10195001720",
    },
    {
        "school": "Demopolis High School",
        "district": "Demopolis City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10120000148",
    },
    {
        "school": "Demopolis Middle School",
        "district": "Demopolis City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10120000439",
    },
    {
        "school": "US Jones Elementary School",
        "district": "Demopolis City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10120000441",
    },
    {
        "school": "Westside Elementary School",
        "district": "Demopolis City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10120000442",
    },
    {
        "school": "George P Austin Junior High School",
        "district": "Linden City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10213000811",
    },
    {
        "school": "Linden Elementary School",
        "district": "Linden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10213000812",
    },
    {
        "school": "Linden High School",
        "district": "Linden City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10213000813",
    },
    {
        "school": "Amelia L Johnson High School",
        "district": "Marengo County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10225000852",
    },
    {
        "school": "Marengo High School",
        "district": "Marengo County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10225000856",
    },
    {
        "school": "Sweet Water High School",
        "district": "Marengo County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10225000857",
    },
    {
        "school": "Brilliant School",
        "district": "Marion County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10231000861",
    },
    {
        "school": "Marion County High School",
        "district": "Marion County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10231000863",
    },
    {
        "school": "Guin Elementary School",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10231000865",
    },
    {
        "school": "Hackleburg High School",
        "district": "Marion County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10231000866",
    },
    {
        "school": "Hamilton Middle School",
        "district": "Marion County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10231000867",
    },
    {
        "school": "Hamilton High School",
        "district": "Marion County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10231000868",
    },
    {
        "school": "Marion County Alternative School",
        "district": "Marion County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10231000985",
    },
    {
        "school": "Hamilton Elementary School",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10231001552",
    },
    {
        "school": "Winfield Middle School",
        "district": "Winfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10354000343",
    },
    {
        "school": "Winfield High School",
        "district": "Winfield City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10354001355",
    },
    {
        "school": "Winfield Elementary School",
        "district": "Winfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10354001613",
    },
    {
        "school": "Monroe County High School",
        "district": "Monroe County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10240000973",
    },
    {
        "school": "Excel High School",
        "district": "Monroe County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10240000975",
    },
    {
        "school": "J F Shields High School",
        "district": "Monroe County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10240000979",
    },
    {
        "school": "J U Blacksher School",
        "district": "Monroe County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10240000980",
    },
    {
        "school": "Monroeville Middle School",
        "district": "Monroe County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10240000983",
    },
    {
        "school": "C P Carmichael Alternative School",
        "district": "Monroe County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10240001087",
    },
    {
        "school": "Monroe County Careertechnical Center",
        "district": "Monroe County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10240001094",
    },
    {
        "school": "Monroeville Elementary School",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10240001562",
    },
    {
        "school": "Robert C Hatch High School",
        "district": "Perry County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10267001577",
    },
    {
        "school": "Francis Marion School",
        "district": "Perry County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10267001734",
    },
    {
        "school": "Aliceville Elementary School",
        "district": "Pickens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10273001097",
    },
    {
        "school": "Aliceville High School",
        "district": "Pickens County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10273001098",
    },
    {
        "school": "Pickens County High School",
        "district": "Pickens County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10273001102",
    },
    {
        "school": "Gordo Elementary School",
        "district": "Pickens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10273001103",
    },
    {
        "school": "Gordo High School",
        "district": "Pickens County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10273001104",
    },
    {
        "school": "Reform Elementary School",
        "district": "Pickens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10273001106",
    },
    {
        "school": "Ladow Technical Center",
        "district": "Pickens County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10273001131",
    },
    {
        "school": "Randolph County High School",
        "district": "Randolph County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10282001119",
    },
    {
        "school": "Rock Mills Junior High School",
        "district": "Randolph County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10282001122",
    },
    {
        "school": "Wadley High School",
        "district": "Randolph County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10282001123",
    },
    {
        "school": "Wedowee Middle School",
        "district": "Randolph County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10282001124",
    },
    {
        "school": "Woodland High School",
        "district": "Randolph County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10282001125",
    },
    {
        "school": "RandolphRoanoke Career Technology Center",
        "district": "Randolph County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10282001139",
    },
    {
        "school": "Handley High School",
        "district": "Roanoke City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10285001126",
    },
    {
        "school": "Handley Middle School",
        "district": "Roanoke City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10285001127",
    },
    {
        "school": "Knight Enloe Elementary School",
        "district": "Roanoke City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10285001128",
    },
    {
        "school": "RandolphRoanoke Career Technology Center",
        "district": "Roanoke City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10285001387",
    },
    {
        "school": "Livingston Junior High School",
        "district": "Sumter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10309001192",
    },
    {
        "school": "BellBrown Career Technical Center",
        "district": "Sumter County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10309001194",
    },
    {
        "school": "York West End Junior High School",
        "district": "Sumter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10309001195",
    },
    {
        "school": "Kinterbish Junior High School",
        "district": "Sumter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10309001592",
    },
    {
        "school": "Alexander City Middle School",
        "district": "Alexander City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10003000001",
    },
    {
        "school": "Benjamin Russell High School",
        "district": "Alexander City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10003000003",
    },
    {
        "school": "Jim Pearson Elementary School",
        "district": "Alexander City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10003000004",
    },
    {
        "school": "Nathaniel H Stephens Elementary School",
        "district": "Alexander City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10003000005",
    },
    {
        "school": "William L Radney Elementary School",
        "district": "Alexander City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10003000006",
    },
    {
        "school": "Horseshoe Bend High School",
        "district": "Tallapoosa County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10321000038",
    },
    {
        "school": "Dadeville Elementary School",
        "district": "Tallapoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10321001228",
    },
    {
        "school": "Dadeville High School",
        "district": "Tallapoosa County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10321001229",
    },
    {
        "school": "Reeltown High School",
        "district": "Tallapoosa County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10321001234",
    },
    {
        "school": "Washington County Career Technical Center",
        "district": "Washington County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10348001242",
    },
    {
        "school": "McIntosh Elementary School",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10348001332",
    },
    {
        "school": "Chatom Elementary School",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10348001333",
    },
    {
        "school": "Washington County High School",
        "district": "Washington County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10348001335",
    },
    {
        "school": "Fruitdale High School",
        "district": "Washington County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10348001336",
    },
    {
        "school": "Leroy High School",
        "district": "Washington County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10348001337",
    },
    {
        "school": "McIntosh High School",
        "district": "Washington County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10348001338",
    },
    {
        "school": "Millry High School",
        "district": "Washington County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10348001339",
    },
    {
        "school": "Monroe Intermediate School",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10240000981",
    },
    {
        "school": "F S Ervin Elementary School",
        "district": "Wilcox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10351000325",
    },
    {
        "school": "ABC Elementary",
        "district": "Wilcox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10351001342",
    },
    {
        "school": "J E Hobbs Elementary School",
        "district": "Wilcox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10351001344",
    },
    {
        "school": "Wilcox County Alternative School",
        "district": "Wilcox County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10351001419",
    },
    {
        "school": "Wilcox Central High School",
        "district": "Wilcox County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10351001780",
    },
    {
        "school": "Camden School Of Arts  Technology",
        "district": "Wilcox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10351001809",
    },
    {
        "school": "Haleyville High School",
        "district": "Haleyville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10172000594",
    },
    {
        "school": "Haleyville Center Of Technology",
        "district": "Haleyville City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10172001370",
    },
    {
        "school": "Haleyville Elementary School",
        "district": "Haleyville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10172001795",
    },
    {
        "school": "Winston County Technical Center",
        "district": "Winston County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10358001243",
    },
    {
        "school": "Addison High School",
        "district": "Winston County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10358001356",
    },
    {
        "school": "Winston County High School",
        "district": "Winston County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10358001357",
    },
    {
        "school": "Double Springs Elementary School",
        "district": "Winston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10358001358",
    },
    {
        "school": "Lynn High School",
        "district": "Winston County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10358001359",
    },
    {
        "school": "Meek High School",
        "district": "Winston County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10358001360",
    },
    {
        "school": "Addison Elementary School",
        "district": "Winston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10358001463",
    },
    {
        "school": "Double Springs Middle School",
        "district": "Winston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10358001464",
    },
    {
        "school": "Lynn Elementary School",
        "district": "Winston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10358001465",
    },
    {
        "school": "Meek Elementary School",
        "district": "Winston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10358001466",
    },
    {
        "school": "Brindlee Mountain High School",
        "district": "Marshall County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000601585",
    },
    {
        "school": "Boaz Middle School",
        "district": "Boaz City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001200123",
    },
    {
        "school": "Boaz High School",
        "district": "Boaz City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001200874",
    },
    {
        "school": "Corley Elementary School",
        "district": "Boaz City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001200884",
    },
    {
        "school": "Boaz Intermediate School",
        "district": "Boaz City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001201630",
    },
    {
        "school": "Boaz Elementary School",
        "district": "Boaz City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001201781",
    },
    {
        "school": "Albertville Middle School",
        "district": "Albertville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000500870",
    },
    {
        "school": "Albertville High School",
        "district": "Albertville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000500871",
    },
    {
        "school": "Evans Elementary School",
        "district": "Albertville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000500879",
    },
    {
        "school": "Albertville Elementary School",
        "district": "Albertville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000500889",
    },
    {
        "school": "Albertville Kindergarten and PreK",
        "district": "Albertville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000501616",
    },
    {
        "school": "Kate Duncan Smith DAR Middle",
        "district": "Marshall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000600193",
    },
    {
        "school": "Asbury High School",
        "district": "Marshall County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000600872",
    },
    {
        "school": "Claysville School",
        "district": "Marshall County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000600876",
    },
    {
        "school": "Douglas Elementary School",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000600877",
    },
    {
        "school": "Douglas High School",
        "district": "Marshall County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000600878",
    },
    {
        "school": "Brindlee Mountain Elementary School",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000600880",
    },
    {
        "school": "Kate D Smith DAR High School",
        "district": "Marshall County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000600883",
    },
    {
        "school": "Brindlee Mountain Primary School",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000600887",
    },
    {
        "school": "Marshall Alternative School",
        "district": "Marshall County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10000600986",
    },
    {
        "school": "Marshall Technical School",
        "district": "Marshall County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10000600987",
    },
    {
        "school": "Robert D Sloman Primary",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000601413",
    },
    {
        "school": "Kate D Smith DAR Elementary School",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000601685",
    },
    {
        "school": "Douglas Middle School",
        "district": "Marshall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000601812",
    },
    {
        "school": "Arab Elementary School",
        "district": "Arab City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10010000022",
    },
    {
        "school": "Arab Primary School",
        "district": "Arab City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10010000025",
    },
    {
        "school": "Arab Junior High School",
        "district": "Arab City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10010000027",
    },
    {
        "school": "Arab High School",
        "district": "Arab City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10010000028",
    },
    {
        "school": "Guntersville Middle School",
        "district": "Guntersville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10169000579",
    },
    {
        "school": "Cherokee Elementary School",
        "district": "Guntersville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10169000580",
    },
    {
        "school": "Guntersville Elementary School",
        "district": "Guntersville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10169000581",
    },
    {
        "school": "Guntersville High School",
        "district": "Guntersville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10169000582",
    },
    {
        "school": "De Armanville Elementary School",
        "district": "Oxford City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10263501865",
    },
    {
        "school": "Coldwater Elementary School",
        "district": "Oxford City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10263502099",
    },
    {
        "school": "Anniston High School",
        "district": "Anniston City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10009000011",
    },
    {
        "school": "Golden Springs Elementary School",
        "district": "Anniston City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10009000017",
    },
    {
        "school": "Randolph Park Elementary School",
        "district": "Anniston City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10009000020",
    },
    {
        "school": "Tenth Street Elementary School",
        "district": "Anniston City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10009000021",
    },
    {
        "school": "Anniston City Boot Camp School",
        "district": "Anniston City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10009001246",
    },
    {
        "school": "Anniston Middle School",
        "district": "Anniston City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10009001725",
    },
    {
        "school": "Cobb Preparatory Academy",
        "district": "Anniston City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10009001782",
    },
    {
        "school": "Alexandria High School",
        "district": "Calhoun County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054000232",
    },
    {
        "school": "Ohatchee High School",
        "district": "Calhoun County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054000240",
    },
    {
        "school": "Saks Elementary School",
        "district": "Calhoun County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054000242",
    },
    {
        "school": "Saks High School",
        "district": "Calhoun County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054000243",
    },
    {
        "school": "Saks Middle School",
        "district": "Calhoun County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054000244",
    },
    {
        "school": "Weaver Elementary School",
        "district": "Calhoun County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054000246",
    },
    {
        "school": "Weaver High School",
        "district": "Calhoun County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054000247",
    },
    {
        "school": "Wellborn Elementary School",
        "district": "Calhoun County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054000249",
    },
    {
        "school": "White Plains High School",
        "district": "Calhoun County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054000250",
    },
    {
        "school": "Calhoun County Alternative School",
        "district": "Calhoun County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10054000700",
    },
    {
        "school": "Calhoun County Career Technical Center",
        "district": "Calhoun County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10054000708",
    },
    {
        "school": "Ohatchee Elementary School",
        "district": "Calhoun County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054001428",
    },
    {
        "school": "Pleasant Valley Elementary School",
        "district": "Calhoun County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054001429",
    },
    {
        "school": "White Plains Elementary School",
        "district": "Calhoun County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054001430",
    },
    {
        "school": "Pleasant Valley High School",
        "district": "Calhoun County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054001488",
    },
    {
        "school": "Wellborn High School",
        "district": "Calhoun County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054001489",
    },
    {
        "school": "Alexandria Elementary School",
        "district": "Calhoun County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054001747",
    },
    {
        "school": "Kitty Stone Elementary School",
        "district": "Jacksonville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10186000672",
    },
    {
        "school": "Jacksonville High School",
        "district": "Jacksonville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10186000673",
    },
    {
        "school": "Oxford High School",
        "district": "Oxford City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10263501075",
    },
    {
        "school": "Oxford Elementary School",
        "district": "Oxford City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10263501076",
    },
    {
        "school": "Oxford Middle School",
        "district": "Oxford City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10263501383",
    },
    {
        "school": "Oxford Area Vocational School",
        "district": "Oxford City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10263501384",
    },
    {
        "school": "CE Hanna School",
        "district": "Oxford City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10263501733",
    },
    {
        "school": "Piedmont High School",
        "district": "Piedmont City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10276001108",
    },
    {
        "school": "Piedmont Elementary School",
        "district": "Piedmont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10276001109",
    },
    {
        "school": "Piedmont Middle School",
        "district": "Piedmont City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10276001818",
    },
    {
        "school": "Opelika Learning Center",
        "district": "Opelika City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10258002098",
    },
    {
        "school": "Auburn High School",
        "district": "Auburn City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021000036",
    },
    {
        "school": "Auburn Junior High School",
        "district": "Auburn City",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021000037",
    },
    {
        "school": "Cary Woods Elementary School",
        "district": "Auburn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021000039",
    },
    {
        "school": "Dean Road Elementary School",
        "district": "Auburn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021000040",
    },
    {
        "school": "Drake Middle School",
        "district": "Auburn City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021000041",
    },
    {
        "school": "Wrights Mill Road Elementary School",
        "district": "Auburn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021000042",
    },
    {
        "school": "Auburn Early Education Center",
        "district": "Auburn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021000053",
    },
    {
        "school": "Ogletree Elementary School",
        "district": "Auburn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021001254",
    },
    {
        "school": "Margaret Yarbrough Elementary School",
        "district": "Auburn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021001259",
    },
    {
        "school": "Beauregard Elementary School",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000284",
    },
    {
        "school": "Beulah Elementary School",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000285",
    },
    {
        "school": "Loachapoka Elementary School",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000290",
    },
    {
        "school": "South Smiths Station Elementary School",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000296",
    },
    {
        "school": "East Smiths Station Elementary School",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000486",
    },
    {
        "school": "Beauregard High School",
        "district": "Lee County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000790",
    },
    {
        "school": "Beulah High School",
        "district": "Lee County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000791",
    },
    {
        "school": "Loachapoka High School",
        "district": "Lee County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000792",
    },
    {
        "school": "Sanford Middle School",
        "district": "Lee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000793",
    },
    {
        "school": "West Smiths Station Elementary School",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000794",
    },
    {
        "school": "Smiths Station High School",
        "district": "Lee County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000795",
    },
    {
        "school": "Smiths Station Junior High School",
        "district": "Lee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207000796",
    },
    {
        "school": "West Forest Intermediate School",
        "district": "Opelika City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10258000093",
    },
    {
        "school": "Northside School",
        "district": "Opelika City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10258000349",
    },
    {
        "school": "Carver Primary School",
        "district": "Opelika City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10258001067",
    },
    {
        "school": "Jeter Primary School",
        "district": "Opelika City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10258001068",
    },
    {
        "school": "Opelika High School",
        "district": "Opelika City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10258001070",
    },
    {
        "school": "Opelika Middle School",
        "district": "Opelika City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10258001071",
    },
    {
        "school": "Morris Avenue Intermediate School",
        "district": "Opelika City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10258001566",
    },
    {
        "school": "Southview Primary School",
        "district": "Opelika City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10258001778",
    },
    {
        "school": "Hayden Middle School",
        "district": "Blount County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042001870",
    },
    {
        "school": "The Boyd School",
        "district": "Boyd School",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10002001831",
    },
    {
        "school": "TriWil Inc",
        "district": "Triwill Portacras",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10002801839",
    },
    {
        "school": "SafetyNet Academy Minter",
        "district": "SafetyNet Academy Minter",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10001501827",
    },
    {
        "school": "Leeds Elementary School",
        "district": "Leeds City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001102094",
    },
    {
        "school": "Leeds Middle School",
        "district": "Leeds City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001102095",
    },
    {
        "school": "Leeds High School",
        "district": "Leeds City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001102096",
    },
    {
        "school": "HewittTrussville Middle School",
        "district": "Trussville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001300714",
    },
    {
        "school": "Paine Elementary School",
        "district": "Trussville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001301498",
    },
    {
        "school": "HewittTrussville High School",
        "district": "Trussville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001301682",
    },
    {
        "school": "United Ability",
        "district": "United Ability",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10001901830",
    },
    {
        "school": "Glenwood Inc",
        "district": "Glenwood Mental Health Service",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003301843",
    },
    {
        "school": "Gateway",
        "district": "Birmingham City",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10039001629",
    },
    {
        "school": "North Jefferson Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192002079",
    },
    {
        "school": "Vestavia Hills Elementary Cahaba Heights",
        "district": "Vestavia Hills City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10343002103",
    },
    {
        "school": "Duran South",
        "district": "Pell City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10265001541",
    },
    {
        "school": "Moody Junior High School",
        "district": "St Clair County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201537",
    },
    {
        "school": "Riverchase Elementary School",
        "district": "Hoover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000702091",
    },
    {
        "school": "Developing Alabama Youth Prog",
        "district": "Developing Alabama Youth Prog",
        "level": "Secondary",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10004101852",
    },
    {
        "school": "Mt Laurel Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303002085",
    },
    {
        "school": "Bibb County High School",
        "district": "Bibb County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10036000092",
    },
    {
        "school": "Centreville Middle School",
        "district": "Bibb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10036000094",
    },
    {
        "school": "Brent Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10036000095",
    },
    {
        "school": "Randolph Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10036000096",
    },
    {
        "school": "West Blocton Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10036000098",
    },
    {
        "school": "West Blocton High School",
        "district": "Bibb County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10036000099",
    },
    {
        "school": "Bibb County Career Academy",
        "district": "Bibb County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10036000669",
    },
    {
        "school": "West Blocton Middle School",
        "district": "Bibb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10036001426",
    },
    {
        "school": "Woodstock Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10036001480",
    },
    {
        "school": "Isabella High School",
        "district": "Chilton County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066000261",
    },
    {
        "school": "Jemison High School",
        "district": "Chilton County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066000262",
    },
    {
        "school": "Maplesville High School",
        "district": "Chilton County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066000265",
    },
    {
        "school": "Thorsby High School",
        "district": "Chilton County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066000270",
    },
    {
        "school": "Clanton Elementary School",
        "district": "Chilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066000286",
    },
    {
        "school": "Clanton Middle School",
        "district": "Chilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066000287",
    },
    {
        "school": "Verbena High School",
        "district": "Chilton County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066000288",
    },
    {
        "school": "Jemison Middle School",
        "district": "Chilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066000745",
    },
    {
        "school": "W A Lecroy Career  Technical Center",
        "district": "Chilton County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10066000748",
    },
    {
        "school": "Clanton Intermediate School",
        "district": "Chilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066001431",
    },
    {
        "school": "Chilton County High School",
        "district": "Chilton County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066001491",
    },
    {
        "school": "Jemison Elementary School",
        "district": "Chilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066001657",
    },
    {
        "school": "Maddox Intermediate School",
        "district": "Jasper City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10189000674",
    },
    {
        "school": "Memorial Park Elementary School",
        "district": "Jasper City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10189000675",
    },
    {
        "school": "T R Simmons Elementary School",
        "district": "Jasper City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10189000677",
    },
    {
        "school": "Jasper High School",
        "district": "Jasper City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10189000678",
    },
    {
        "school": "Carbon Hill ElementaryJunior High School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345000131",
    },
    {
        "school": "Carbon Hill High School",
        "district": "Walker County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345000135",
    },
    {
        "school": "Walker County Schools 180 Program",
        "district": "Walker County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10345001225",
    },
    {
        "school": "Walker County Center Of Technology",
        "district": "Walker County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10345001237",
    },
    {
        "school": "Bankhead Middle School",
        "district": "Walker County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001305",
    },
    {
        "school": "Cordova Elementary School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001307",
    },
    {
        "school": "Cordova High School",
        "district": "Walker County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001308",
    },
    {
        "school": "Curry Elementary School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001309",
    },
    {
        "school": "Curry High School",
        "district": "Walker County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001310",
    },
    {
        "school": "Dora High School",
        "district": "Walker County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001311",
    },
    {
        "school": "Lupton Junior High School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001317",
    },
    {
        "school": "Oakman Middle School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001319",
    },
    {
        "school": "Oakman High School",
        "district": "Walker County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001320",
    },
    {
        "school": "Parrish ElementaryMiddle School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001321",
    },
    {
        "school": "Sumiton Middle School",
        "district": "Walker County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001325",
    },
    {
        "school": "Valley Junior High School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001611",
    },
    {
        "school": "Curry Middle School",
        "district": "Walker County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345001703",
    },
    {
        "school": "Hayden Elementary School",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042000101",
    },
    {
        "school": "Appalachian  School",
        "district": "Blount County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042000203",
    },
    {
        "school": "Blountsville Elementary School",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042000205",
    },
    {
        "school": "Cleveland High School",
        "district": "Blount County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042000206",
    },
    {
        "school": "Hayden Primary School",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042000207",
    },
    {
        "school": "Hayden High School",
        "district": "Blount County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042000208",
    },
    {
        "school": "JB Pennington High School",
        "district": "Blount County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042000209",
    },
    {
        "school": "Locust Fork High School",
        "district": "Blount County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042000210",
    },
    {
        "school": "Southeastern School",
        "district": "Blount County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042000211",
    },
    {
        "school": "Susan Moore High School",
        "district": "Blount County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042000213",
    },
    {
        "school": "Allgood Alternative School",
        "district": "Blount County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10042000670",
    },
    {
        "school": "Blount County Learning Center",
        "district": "Blount County",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10042000676",
    },
    {
        "school": "Blount County Career Technical Center",
        "district": "Blount County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10042000682",
    },
    {
        "school": "Locust Fork Elementary",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042001427",
    },
    {
        "school": "Cleveland Elementary School",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042001476",
    },
    {
        "school": "Susan Moore Elementary School",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10042001481",
    },
    {
        "school": "Oneonta Elementary School",
        "district": "Oneonta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10255000583",
    },
    {
        "school": "Oneonta High School",
        "district": "Oneonta City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10255001064",
    },
    {
        "school": "Trace Crossings Elementary School",
        "district": "Hoover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000700091",
    },
    {
        "school": "Hoover High School",
        "district": "Hoover City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000700251",
    },
    {
        "school": "Berry Middle School",
        "district": "Hoover City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000700337",
    },
    {
        "school": "South Shades Crest Elementary School",
        "district": "Hoover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000700342",
    },
    {
        "school": "Robert F Bumpus Middle School",
        "district": "Hoover City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000701422",
    },
    {
        "school": "Deer Valley Elementary School",
        "district": "Hoover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000701483",
    },
    {
        "school": "Bluff Park Elementary School",
        "district": "Hoover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000701738",
    },
    {
        "school": "Green Valley Elementary School",
        "district": "Hoover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000701739",
    },
    {
        "school": "Gwin Elementary School",
        "district": "Hoover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000701740",
    },
    {
        "school": "Ira F Simmons Middle School",
        "district": "Hoover City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000701741",
    },
    {
        "school": "Rocky Ridge Elementary School",
        "district": "Hoover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000701742",
    },
    {
        "school": "Shades Mountain Elementary School",
        "district": "Hoover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000701743",
    },
    {
        "school": "Greenwood Elementary School",
        "district": "Bessemer City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10033000082",
    },
    {
        "school": "Charles F Hard Elementary School",
        "district": "Bessemer City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10033000084",
    },
    {
        "school": "Bessemer City Middle School",
        "district": "Bessemer City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10033000086",
    },
    {
        "school": "Bessemer City High School",
        "district": "Bessemer City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10033000087",
    },
    {
        "school": "Jonesboro Elementary School",
        "district": "Bessemer City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10033000088",
    },
    {
        "school": "Westhills Elementary School",
        "district": "Bessemer City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10033000090",
    },
    {
        "school": "New Horizon Alternative School",
        "district": "Bessemer City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10033001264",
    },
    {
        "school": "Bessemer Center For Technology",
        "district": "Bessemer City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10033001267",
    },
    {
        "school": "Abrams Elementary School",
        "district": "Bessemer City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10033001479",
    },
    {
        "school": "Engle Day Treatment",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10039000079",
    },
    {
        "school": "Avondale Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000103",
    },
    {
        "school": "Barrett Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000106",
    },
    {
        "school": "Charles A Brown Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000107",
    },
    {
        "school": "Central Park Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000112",
    },
    {
        "school": "Christian School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000113",
    },
    {
        "school": "EPIC Alternative Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000119",
    },
    {
        "school": "Oliver K5 School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000127",
    },
    {
        "school": "Green Acres Middle School",
        "district": "Birmingham City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000133",
    },
    {
        "school": "Hemphill Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000136",
    },
    {
        "school": "Hudson KEight School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000139",
    },
    {
        "school": "Huffman Middle School",
        "district": "Birmingham City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000140",
    },
    {
        "school": "Huffman High SchoolMagnet",
        "district": "Birmingham City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000141",
    },
    {
        "school": "Inglenook School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000142",
    },
    {
        "school": "Minor Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000156",
    },
    {
        "school": "Norwood Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000161",
    },
    {
        "school": "JacksonOlin High School",
        "district": "Birmingham City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000164",
    },
    {
        "school": "Parker High School",
        "district": "Birmingham City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000165",
    },
    {
        "school": "Princeton School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000174",
    },
    {
        "school": "WE Putnam Middle SchoolMagnet",
        "district": "Birmingham City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000175",
    },
    {
        "school": "Ramsay High School",
        "district": "Birmingham City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000176",
    },
    {
        "school": "Robinson Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000179",
    },
    {
        "school": "Smith Middle School",
        "district": "Birmingham City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000184",
    },
    {
        "school": "Tuggle Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000187",
    },
    {
        "school": "Washington K8",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000190",
    },
    {
        "school": "Jones Valley Middle School",
        "district": "Birmingham City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000191",
    },
    {
        "school": "Wenonah High School",
        "district": "Birmingham City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000192",
    },
    {
        "school": "Wilkerson Middle School",
        "district": "Birmingham City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000196",
    },
    {
        "school": "Woodlawn High SchoolMagnet",
        "district": "Birmingham City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000198",
    },
    {
        "school": "Wylam Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039000201",
    },
    {
        "school": "Family Court Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10039000530",
    },
    {
        "school": "City Elementary",
        "district": "Birmingham City",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10039001270",
    },
    {
        "school": "Dupuy Alternative School",
        "district": "Birmingham City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10039001288",
    },
    {
        "school": "Adolescent Day Treatment",
        "district": "Birmingham City",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10039001296",
    },
    {
        "school": "South Hampton K8",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039001421",
    },
    {
        "school": "Martha Gaskins K5",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039001446",
    },
    {
        "school": "George Washington Carver High School",
        "district": "Birmingham City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039001468",
    },
    {
        "school": "Glen Iris Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039001484",
    },
    {
        "school": "Family Court High School",
        "district": "Birmingham City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10039001761",
    },
    {
        "school": "Sun Valley Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039001762",
    },
    {
        "school": "Homebound Elementary School",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10039001764",
    },
    {
        "school": "Homebound High School",
        "district": "Birmingham City",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10039001765",
    },
    {
        "school": "Donald Elementary School",
        "district": "Fairfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10144000515",
    },
    {
        "school": "Fairfield High Preparatory School",
        "district": "Fairfield City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10144000516",
    },
    {
        "school": "Glen Oaks Elementary School",
        "district": "Fairfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10144000518",
    },
    {
        "school": "Robinson Elementary School",
        "district": "Fairfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10144000519",
    },
    {
        "school": "Fairfield Alternative School",
        "district": "Fairfield City",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10144001361",
    },
    {
        "school": "Fairfield Area Vocational School",
        "district": "Fairfield City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10144001363",
    },
    {
        "school": "Edgewood Elementary School",
        "district": "Homewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10176000606",
    },
    {
        "school": "Hall Kent Elementary School",
        "district": "Homewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10176000607",
    },
    {
        "school": "Homewood High School",
        "district": "Homewood City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10176000608",
    },
    {
        "school": "Homewood Middle School",
        "district": "Homewood City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10176000609",
    },
    {
        "school": "Shades Cahaba Elementary School",
        "district": "Homewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10176000610",
    },
    {
        "school": "Jefferson County Counseling Learning CenterEast",
        "district": "Jefferson County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10192000466",
    },
    {
        "school": "ClayChalkville High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000469",
    },
    {
        "school": "ClayChalkville Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000472",
    },
    {
        "school": "McAdory Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000483",
    },
    {
        "school": "Adamsville Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000681",
    },
    {
        "school": "Bagley Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000684",
    },
    {
        "school": "Minor Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000687",
    },
    {
        "school": "Bragg Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000689",
    },
    {
        "school": "Brighton School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000691",
    },
    {
        "school": "Brookville Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000692",
    },
    {
        "school": "Center Point Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000694",
    },
    {
        "school": "Chalkville Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000695",
    },
    {
        "school": "Clay Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000696",
    },
    {
        "school": "Concord Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000697",
    },
    {
        "school": "Corner High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000698",
    },
    {
        "school": "Crumly Chapel Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000699",
    },
    {
        "school": "Erwin Intermediate School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000701",
    },
    {
        "school": "Center Point High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000702",
    },
    {
        "school": "Fultondale Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000703",
    },
    {
        "school": "Fultondale High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000704",
    },
    {
        "school": "Gardendale Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000705",
    },
    {
        "school": "Gardendale High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000706",
    },
    {
        "school": "McCalla Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000710",
    },
    {
        "school": "Hillview Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000715",
    },
    {
        "school": "Hueytown Intermediate School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000716",
    },
    {
        "school": "Hueytown High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000717",
    },
    {
        "school": "Irondale Community School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000718",
    },
    {
        "school": "Bryan Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000720",
    },
    {
        "school": "Lipscomb Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000724",
    },
    {
        "school": "McAdory High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000725",
    },
    {
        "school": "Minor Community School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000727",
    },
    {
        "school": "Mortimer Jordan High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000728",
    },
    {
        "school": "Mount Olive Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000729",
    },
    {
        "school": "Hueytown Primary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000730",
    },
    {
        "school": "Oak Grove High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000732",
    },
    {
        "school": "Pinson Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000733",
    },
    {
        "school": "Pinson Valley High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000734",
    },
    {
        "school": "Hueytown Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000735",
    },
    {
        "school": "Pleasant Grove Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000736",
    },
    {
        "school": "Pleasant Grove High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000737",
    },
    {
        "school": "Snow Rogers Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000740",
    },
    {
        "school": "Shades Valley High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000744",
    },
    {
        "school": "Warrior Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000749",
    },
    {
        "school": "West Jefferson Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192000750",
    },
    {
        "school": "Oak Grove Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192001453",
    },
    {
        "school": "Grantswood Community School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192001539",
    },
    {
        "school": "Kermit Johnson School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192001542",
    },
    {
        "school": "Rudd Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192001543",
    },
    {
        "school": "William E Burkett MultiHandicapped Center",
        "district": "Jefferson County",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10192001680",
    },
    {
        "school": "Minor High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192001752",
    },
    {
        "school": "Midfield Elementary School",
        "district": "Midfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10235000890",
    },
    {
        "school": "Midfield High School",
        "district": "Midfield City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10235000891",
    },
    {
        "school": "Rutledge School",
        "district": "Midfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10235000892",
    },
    {
        "school": "Midfield Area Vocational Department",
        "district": "Midfield City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10235001381",
    },
    {
        "school": "Brookwood Forest Elementary School",
        "district": "Mountain Brook City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10249001053",
    },
    {
        "school": "Cherokee Bend Elementary School",
        "district": "Mountain Brook City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10249001054",
    },
    {
        "school": "Crestline Elementary School",
        "district": "Mountain Brook City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10249001055",
    },
    {
        "school": "Mountain Brook High School",
        "district": "Mountain Brook City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10249001056",
    },
    {
        "school": "Mountain Brook Junior High School",
        "district": "Mountain Brook City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10249001057",
    },
    {
        "school": "Mountain Brook Elementary School",
        "district": "Mountain Brook City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10249001058",
    },
    {
        "school": "Tarrant Elementary School",
        "district": "Tarrant City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10327001239",
    },
    {
        "school": "Tarrant High School",
        "district": "Tarrant City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10327001240",
    },
    {
        "school": "Pizitz Middle School",
        "district": "Vestavia Hills City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10343001301",
    },
    {
        "school": "East Elementary",
        "district": "Vestavia Hills City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10343001302",
    },
    {
        "school": "West Elementary",
        "district": "Vestavia Hills City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10343001303",
    },
    {
        "school": "Vestavia Hills High School",
        "district": "Vestavia Hills City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10343001304",
    },
    {
        "school": "Liberty Park Elementary",
        "district": "Vestavia Hills City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10343001425",
    },
    {
        "school": "Eden Elementary School",
        "district": "Pell City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10265001469",
    },
    {
        "school": "Coosa Valley Elementary School",
        "district": "Pell City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10265001569",
    },
    {
        "school": "Duran Junior High School",
        "district": "Pell City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10265001570",
    },
    {
        "school": "Iola Roberts Elementary School",
        "district": "Pell City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10265001572",
    },
    {
        "school": "Pell City High School",
        "district": "Pell City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10265001573",
    },
    {
        "school": "Walter M Kennedy School",
        "district": "Pell City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10265001722",
    },
    {
        "school": "Springville Elementary School",
        "district": "St Clair County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306200217",
    },
    {
        "school": "Odenville Elementary School",
        "district": "St Clair County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306200219",
    },
    {
        "school": "Ashville Middle School",
        "district": "St Clair County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306200322",
    },
    {
        "school": "Springville Middle School",
        "district": "St Clair County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306200520",
    },
    {
        "school": "Odenville Middle School",
        "district": "St Clair County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201172",
    },
    {
        "school": "Eden Area Technical Center",
        "district": "St Clair County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10306201180",
    },
    {
        "school": "Ashville High School",
        "district": "St Clair County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201362",
    },
    {
        "school": "Saint Clair County High School",
        "district": "St Clair County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201367",
    },
    {
        "school": "Moody Middle School",
        "district": "St Clair County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201372",
    },
    {
        "school": "Ragland High School",
        "district": "St Clair County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201376",
    },
    {
        "school": "Springville High School",
        "district": "St Clair County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201377",
    },
    {
        "school": "Steele Junior High School",
        "district": "St Clair County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201378",
    },
    {
        "school": "Ruben Yancy Alternative School",
        "district": "St Clair County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10306201590",
    },
    {
        "school": "Moody High School",
        "district": "St Clair County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201591",
    },
    {
        "school": "Ashville Elementary School",
        "district": "St Clair County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201622",
    },
    {
        "school": "Moody Elementary School",
        "district": "St Clair County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306201779",
    },
    {
        "school": "Greystone Elementary School",
        "district": "Hoover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000700248",
    },
    {
        "school": "Spain Park High School",
        "district": "Hoover City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000701456",
    },
    {
        "school": "Chelsea Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303000031",
    },
    {
        "school": "Oak Mountain Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303000124",
    },
    {
        "school": "Oak Mountain Intermediate School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303000324",
    },
    {
        "school": "Calera Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001169",
    },
    {
        "school": "Calera High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001170",
    },
    {
        "school": "Chelsea High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001171",
    },
    {
        "school": "Columbiana Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001173",
    },
    {
        "school": "Shelby County High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001174",
    },
    {
        "school": "Helena Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001175",
    },
    {
        "school": "Montevallo Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001176",
    },
    {
        "school": "Montevallo High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001177",
    },
    {
        "school": "Montevallo Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001178",
    },
    {
        "school": "Shelby Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001181",
    },
    {
        "school": "Vincent Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001186",
    },
    {
        "school": "Vincent Middle High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001187",
    },
    {
        "school": "Wilsonville Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001188",
    },
    {
        "school": "Oak Mountain High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001189",
    },
    {
        "school": "Career Technical Education Center",
        "district": "Shelby County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10303001190",
    },
    {
        "school": "New Direction",
        "district": "Shelby County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10303001418",
    },
    {
        "school": "Helena Intermediate School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001442",
    },
    {
        "school": "Elvin Hill Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001588",
    },
    {
        "school": "Inverness Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001621",
    },
    {
        "school": "Linda Nolen Learning Center",
        "district": "Shelby County",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10303001803",
    },
    {
        "school": "Oak Mountain Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303001804",
    },
    {
        "school": "Lakewood Elementary School",
        "district": "Phenix City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10270001547",
    },
    {
        "school": "Phenix City Elementary School",
        "district": "Phenix City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10270001548",
    },
    {
        "school": "Central High School",
        "district": "Phenix City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10270001088",
    },
    {
        "school": "Meadowlane Elementary School",
        "district": "Phenix City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10270001089",
    },
    {
        "school": "Phenix City Intermediate School",
        "district": "Phenix City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10270001090",
    },
    {
        "school": "Ridgecrest Elementary School",
        "district": "Phenix City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10270001091",
    },
    {
        "school": "South Girard School",
        "district": "Phenix City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10270001092",
    },
    {
        "school": "Sherwood Elementary School",
        "district": "Phenix City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10270001093",
    },
    {
        "school": "Westview Elementary School",
        "district": "Phenix City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10270001096",
    },
    {
        "school": "Dixie Elementary School",
        "district": "Russell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10288001132",
    },
    {
        "school": "Ladonia Elementary School",
        "district": "Russell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10288001133",
    },
    {
        "school": "Mount Olive Intermediate School",
        "district": "Russell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10288001134",
    },
    {
        "school": "Oliver Elementary School",
        "district": "Russell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10288001135",
    },
    {
        "school": "Alternative Learning Center",
        "district": "Russell County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10288001155",
    },
    {
        "school": "Russell County Middle School",
        "district": "Russell County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10288001441",
    },
    {
        "school": "Russell County High School",
        "district": "Russell County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10288001802",
    },
    {
        "school": "Cullman Community Comprehensive Learning Center",
        "district": "Cullman City",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10099002089",
    },
    {
        "school": "Good Hope Primary School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102001444",
    },
    {
        "school": "Cullman Area Resource Education",
        "district": "Cullman County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10102001567",
    },
    {
        "school": "Cullman City Primary School",
        "district": "Cullman City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10099000326",
    },
    {
        "school": "Cullman Middle School",
        "district": "Cullman City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10099000369",
    },
    {
        "school": "Cullman High School",
        "district": "Cullman City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10099000370",
    },
    {
        "school": "East Elementary School",
        "district": "Cullman City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10099000371",
    },
    {
        "school": "West Elementary School",
        "district": "Cullman City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10099000372",
    },
    {
        "school": "Cullman City Career Tech",
        "district": "Cullman City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10099001323",
    },
    {
        "school": "Parkside Elementary School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000373",
    },
    {
        "school": "Cold Springs High School",
        "district": "Cullman County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000374",
    },
    {
        "school": "Cold Springs Elementary School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000375",
    },
    {
        "school": "Fairview High School",
        "district": "Cullman County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000377",
    },
    {
        "school": "Good Hope High School",
        "district": "Cullman County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000379",
    },
    {
        "school": "Hanceville High School",
        "district": "Cullman County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000380",
    },
    {
        "school": "Holly Pond High School",
        "district": "Cullman County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000381",
    },
    {
        "school": "Vinemont High School",
        "district": "Cullman County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000385",
    },
    {
        "school": "Welti Elementary School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000386",
    },
    {
        "school": "West Point High School",
        "district": "Cullman County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000387",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000396",
    },
    {
        "school": "Fairview Middle School",
        "district": "Cullman County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000400",
    },
    {
        "school": "Good Hope Elementary School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000403",
    },
    {
        "school": "Good Hope Middle School",
        "district": "Cullman County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000413",
    },
    {
        "school": "Hanceville Elementary School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000414",
    },
    {
        "school": "Hanceville Middle School",
        "district": "Cullman County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000420",
    },
    {
        "school": "Holly Pond Elementary School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000440",
    },
    {
        "school": "Vinemont Elementary School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000446",
    },
    {
        "school": "Vinemont Middle School",
        "district": "Cullman County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000453",
    },
    {
        "school": "West Point Elementary School",
        "district": "Cullman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000458",
    },
    {
        "school": "West Point Middle School",
        "district": "Cullman County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102000459",
    },
    {
        "school": "Cullman Area Technology Academy",
        "district": "Cullman County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10102000803",
    },
    {
        "school": "Cullman Child Development Center",
        "district": "Cullman County",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10102001497",
    },
    {
        "school": "Bay Minette Middle School",
        "district": "Baldwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001859",
    },
    {
        "school": "Daphne East Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027002072",
    },
    {
        "school": "Spanish Fort High School",
        "district": "Baldwin County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027002073",
    },
    {
        "school": "Daphne Middle School",
        "district": "Baldwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000013",
    },
    {
        "school": "Robertsdale High School",
        "district": "Baldwin County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000024",
    },
    {
        "school": "W J Carroll Intermediate School",
        "district": "Baldwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000056",
    },
    {
        "school": "Elberta High School",
        "district": "Baldwin County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000057",
    },
    {
        "school": "Elsanor School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000058",
    },
    {
        "school": "Fairhope Middle School",
        "district": "Baldwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000059",
    },
    {
        "school": "Foley Middle School",
        "district": "Baldwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000060",
    },
    {
        "school": "Perdido Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000062",
    },
    {
        "school": "Rosinton School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000065",
    },
    {
        "school": "Silverhill School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000066",
    },
    {
        "school": "Spanish Fort Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000067",
    },
    {
        "school": "Stapleton School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000068",
    },
    {
        "school": "Summerdale School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000069",
    },
    {
        "school": "Swift Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000070",
    },
    {
        "school": "Fairhope High School",
        "district": "Baldwin County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000100",
    },
    {
        "school": "Central Baldwin Middle School",
        "district": "Baldwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000162",
    },
    {
        "school": "Orange Beach Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000549",
    },
    {
        "school": "Rockwell Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000550",
    },
    {
        "school": "Elberta Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000625",
    },
    {
        "school": "Magnolia School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000648",
    },
    {
        "school": "J Larry Newton School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027000660",
    },
    {
        "school": "North Baldwin Center For Technology",
        "district": "Baldwin County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10027000664",
    },
    {
        "school": "South Baldwin Center For Technology",
        "district": "Baldwin County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10027000665",
    },
    {
        "school": "Bay Minette Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001708",
    },
    {
        "school": "Daphne Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001709",
    },
    {
        "school": "Fairhope East Elementary",
        "district": "Baldwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001710",
    },
    {
        "school": "Fairhope West Elementary",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001711",
    },
    {
        "school": "Foley Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001712",
    },
    {
        "school": "Florence B Mathis Elementary",
        "district": "Baldwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001713",
    },
    {
        "school": "Loxley Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001714",
    },
    {
        "school": "Pine Grove Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001715",
    },
    {
        "school": "Robertsdale Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001716",
    },
    {
        "school": "Daphne High School",
        "district": "Baldwin County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001759",
    },
    {
        "school": "Delta Elementary School",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001783",
    },
    {
        "school": "Foley High School",
        "district": "Baldwin County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001784",
    },
    {
        "school": "Baldwin County High School",
        "district": "Baldwin County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001810",
    },
    {
        "school": "Sequel TSI Courtland LLC",
        "district": "Sequel TSI Courtland LLC",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10002201833",
    },
    {
        "school": "Long Term Case",
        "district": "Decatur City",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10117001631",
    },
    {
        "school": "Morgan County Learning Center",
        "district": "Morgan County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10248001526",
    },
    {
        "school": "West Morgan Middle School",
        "district": "Morgan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001864",
    },
    {
        "school": "R A Hubbard High School",
        "district": "Lawrence County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204000776",
    },
    {
        "school": "The Judy Jester Learning Center",
        "district": "Lawrence County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10204000777",
    },
    {
        "school": "East Lawrence Middle School",
        "district": "Lawrence County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204000778",
    },
    {
        "school": "Hatton Elementary School",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204000779",
    },
    {
        "school": "Hatton High School",
        "district": "Lawrence County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204000780",
    },
    {
        "school": "Hazlewood Elementary School",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204000781",
    },
    {
        "school": "Lawrence County High School",
        "district": "Lawrence County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204000783",
    },
    {
        "school": "Moulton Elementary School",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204000785",
    },
    {
        "school": "Moulton Middle School",
        "district": "Lawrence County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204000786",
    },
    {
        "school": "Mount Hope",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204000787",
    },
    {
        "school": "Speake",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204000788",
    },
    {
        "school": "Lawrence County Career Technical Center",
        "district": "Lawrence County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10204000958",
    },
    {
        "school": "East Lawrence Elementary School",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204001410",
    },
    {
        "school": "East Lawrence High School",
        "district": "Lawrence County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10204001546",
    },
    {
        "school": "Austin Middle School",
        "district": "Decatur City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000081",
    },
    {
        "school": "Austin High School",
        "district": "Decatur City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000426",
    },
    {
        "school": "Austinville Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000427",
    },
    {
        "school": "Decatur High School",
        "district": "Decatur City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000429",
    },
    {
        "school": "Eastwood Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000430",
    },
    {
        "school": "Leon Sheffield Magnet Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000431",
    },
    {
        "school": "BanksCaddell Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000432",
    },
    {
        "school": "Decatur Middle School",
        "district": "Decatur City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000433",
    },
    {
        "school": "Oak Park Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000434",
    },
    {
        "school": "West Decatur Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000435",
    },
    {
        "school": "Walter Jackson Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000436",
    },
    {
        "school": "Benjamin Davis Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000437",
    },
    {
        "school": "Woodmeade Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117000438",
    },
    {
        "school": "Frances Nungester Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117001615",
    },
    {
        "school": "Julian Harris Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117001728",
    },
    {
        "school": "Chestnut Grove Elementary School",
        "district": "Decatur City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117001786",
    },
    {
        "school": "Barkley Bridge Elementary School",
        "district": "Hartselle City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10173000328",
    },
    {
        "school": "Crestline Elementary School",
        "district": "Hartselle City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10173000596",
    },
    {
        "school": "FE Burleson Elementary School",
        "district": "Hartselle City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10173000597",
    },
    {
        "school": "Hartselle Junior High School",
        "district": "Hartselle City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10173000598",
    },
    {
        "school": "Hartselle High School",
        "district": "Hartselle City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10173000599",
    },
    {
        "school": "DanvilleNeel Elementary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248000202",
    },
    {
        "school": "Falkville Elementary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248000204",
    },
    {
        "school": "West Morgan Elementary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248000212",
    },
    {
        "school": "Danville Middle School",
        "district": "Morgan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248000574",
    },
    {
        "school": "Cotaco School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001041",
    },
    {
        "school": "Danville High School",
        "district": "Morgan County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001042",
    },
    {
        "school": "Eva School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001043",
    },
    {
        "school": "Falkville High School",
        "district": "Morgan County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001044",
    },
    {
        "school": "Laceys Spring Elementary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001046",
    },
    {
        "school": "Priceville High School",
        "district": "Morgan County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001048",
    },
    {
        "school": "Sparkman Elementary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001050",
    },
    {
        "school": "Union Hill School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001051",
    },
    {
        "school": "West Morgan High School",
        "district": "Morgan County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001052",
    },
    {
        "school": "Morgan County Schools Technology Park",
        "district": "Morgan County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10248001121",
    },
    {
        "school": "Priceville Elementary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001440",
    },
    {
        "school": "Albert P Brewer High School",
        "district": "Morgan County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10248001696",
    },
    {
        "school": "Laurel Oaks Behavioral Health Center",
        "district": "Laurel Oaks Behavioral Health Center",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10004201853",
    },
    {
        "school": "Rehobeth Middle School",
        "district": "Houston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10177002077",
    },
    {
        "school": "Rehobeth Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10177002078",
    },
    {
        "school": "Geneva High School",
        "district": "Geneva City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10164000567",
    },
    {
        "school": "Mulkey Elementary School",
        "district": "Geneva City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10164000568",
    },
    {
        "school": "Geneva Middle School",
        "district": "Geneva City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10164001788",
    },
    {
        "school": "Geneva County High School",
        "district": "Geneva County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10166000570",
    },
    {
        "school": "Samson High School",
        "district": "Geneva County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10166000571",
    },
    {
        "school": "Slocomb High School",
        "district": "Geneva County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10166001519",
    },
    {
        "school": "Samson Elementary School",
        "district": "Geneva County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10166001771",
    },
    {
        "school": "Samson Middle School",
        "district": "Geneva County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10166001772",
    },
    {
        "school": "Geneva County Elementary School",
        "district": "Geneva County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10166001791",
    },
    {
        "school": "Geneva County Middle School",
        "district": "Geneva County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10166001792",
    },
    {
        "school": "Slocomb Elementary School",
        "district": "Geneva County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10166001793",
    },
    {
        "school": "Slocomb Middle School",
        "district": "Geneva County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10166001794",
    },
    {
        "school": "Abbeville High School",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10174000600",
    },
    {
        "school": "Abbeville Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10174000602",
    },
    {
        "school": "Headland Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10174000603",
    },
    {
        "school": "Headland High School",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10174000604",
    },
    {
        "school": "Headland Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10174000605",
    },
    {
        "school": "Carver School of Mathematics Science and Technology",
        "district": "Dothan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123000443",
    },
    {
        "school": "Girard Intermediate School",
        "district": "Dothan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123000447",
    },
    {
        "school": "Girard Primary School",
        "district": "Dothan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123000448",
    },
    {
        "school": "Heard Elementary School",
        "district": "Dothan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123000450",
    },
    {
        "school": "Selma Street Elementary School",
        "district": "Dothan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123000454",
    },
    {
        "school": "Faine Elementary School",
        "district": "Dothan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123000456",
    },
    {
        "school": "PASS Academy",
        "district": "Dothan City",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10123001331",
    },
    {
        "school": "Dothan Technology Center",
        "district": "Dothan City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10123001349",
    },
    {
        "school": "Hidden Lake Primary School",
        "district": "Dothan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123001447",
    },
    {
        "school": "Highlands Elementary School",
        "district": "Dothan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123001448",
    },
    {
        "school": "Morris Slingluff Elementary School",
        "district": "Dothan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123001449",
    },
    {
        "school": "Beverlye Intermediate School",
        "district": "Dothan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123001499",
    },
    {
        "school": "Dothan High School",
        "district": "Dothan City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123001501",
    },
    {
        "school": "Kelly Springs Elementary School",
        "district": "Dothan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123001817",
    },
    {
        "school": "Ashford High School",
        "district": "Houston County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10177000611",
    },
    {
        "school": "Cottonwood High School",
        "district": "Houston County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10177000612",
    },
    {
        "school": "Houston County High School",
        "district": "Houston County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10177000614",
    },
    {
        "school": "Rehobeth High School",
        "district": "Houston County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10177000615",
    },
    {
        "school": "Webb Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10177000616",
    },
    {
        "school": "Wicksburg High School",
        "district": "Houston County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10177000617",
    },
    {
        "school": "Houston County Alternative School",
        "district": "Houston County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10177000882",
    },
    {
        "school": "Houston County Area Vocational Center",
        "district": "Houston County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10177000885",
    },
    {
        "school": "Ashford Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10177001668",
    },
    {
        "school": "Enterprise Early Education Center",
        "district": "Enterprise City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10132001867",
    },
    {
        "school": "Pathway Inc",
        "district": "Pathway Inc",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003801849",
    },
    {
        "school": "Kinston School",
        "district": "Coffee County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10081000323",
    },
    {
        "school": "Zion Chapel High School",
        "district": "Coffee County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10081000327",
    },
    {
        "school": "New Brockton High School",
        "district": "Coffee County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10081001494",
    },
    {
        "school": "New Brockton Elementary School",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10081001748",
    },
    {
        "school": "Elba Elementary School",
        "district": "Elba City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10126000460",
    },
    {
        "school": "Elba High School",
        "district": "Elba City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10126000461",
    },
    {
        "school": "Elba Area Vocational School",
        "district": "Elba City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10126001354",
    },
    {
        "school": "Coppinville School",
        "district": "Enterprise City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10132000474",
    },
    {
        "school": "Dauphin Junior High School",
        "district": "Enterprise City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10132000475",
    },
    {
        "school": "Enterprise High School",
        "district": "Enterprise City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10132000476",
    },
    {
        "school": "Hillcrest Elementary School",
        "district": "Enterprise City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10132000478",
    },
    {
        "school": "Holly Hill Elementary School",
        "district": "Enterprise City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10132000479",
    },
    {
        "school": "Pinedale Elementary School",
        "district": "Enterprise City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10132000480",
    },
    {
        "school": "Rucker Boulevard Elementary School",
        "district": "Enterprise City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10132000481",
    },
    {
        "school": "Harrand Creek Elementary School",
        "district": "Enterprise City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10132001719",
    },
    {
        "school": "GW Long Elementary School",
        "district": "Dale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10105000281",
    },
    {
        "school": "Ariton School",
        "district": "Dale County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10105000388",
    },
    {
        "school": "Dale County High School",
        "district": "Dale County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10105000389",
    },
    {
        "school": "George W Long High School",
        "district": "Dale County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10105000390",
    },
    {
        "school": "Midland City Elementary School",
        "district": "Dale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10105000391",
    },
    {
        "school": "Newton Elementary School",
        "district": "Dale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10105000392",
    },
    {
        "school": "South Dale Middle School",
        "district": "Dale County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10105000393",
    },
    {
        "school": "Daleville High School",
        "district": "Daleville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10108000394",
    },
    {
        "school": "A M Windham Elementary School",
        "district": "Daleville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10108001767",
    },
    {
        "school": "Carroll High School",
        "district": "Ozark City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10264001080",
    },
    {
        "school": "D A Smith Middle School",
        "district": "Ozark City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10264001081",
    },
    {
        "school": "Harry N Mixon Intermediate School",
        "district": "Ozark City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10264001084",
    },
    {
        "school": "Joseph W Lisenby Primary School",
        "district": "Ozark City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10264001085",
    },
    {
        "school": "Opportunity Academy",
        "district": "Ozark City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10264001385",
    },
    {
        "school": "Carroll High School Career Center",
        "district": "Ozark City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10264001386",
    },
    {
        "school": "Deshler Alternative School",
        "district": "Tuscumbia City",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10342001656",
    },
    {
        "school": "Florence Learning Center",
        "district": "Florence City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10153001644",
    },
    {
        "school": "Cherokee Elementary School",
        "district": "Colbert County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10084000331",
    },
    {
        "school": "Cherokee High School",
        "district": "Colbert County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10084000333",
    },
    {
        "school": "Colbert County High School",
        "district": "Colbert County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10084000334",
    },
    {
        "school": "Colbert Heights High School",
        "district": "Colbert County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10084000335",
    },
    {
        "school": "Hatton Elementary School",
        "district": "Colbert County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10084000336",
    },
    {
        "school": "Leighton Elementary School",
        "district": "Colbert County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10084000338",
    },
    {
        "school": "New Bethel Elementary School",
        "district": "Colbert County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10084000341",
    },
    {
        "school": "Colbert Heights Elementary School",
        "district": "Colbert County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10084001658",
    },
    {
        "school": "Muscle Shoals Middle School",
        "district": "Muscle Shoals City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10252001059",
    },
    {
        "school": "Highland Park Elementary School",
        "district": "Muscle Shoals City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10252001060",
    },
    {
        "school": "Muscle Shoals High School",
        "district": "Muscle Shoals City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10252001062",
    },
    {
        "school": "Webster Elementary School",
        "district": "Muscle Shoals City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10252001063",
    },
    {
        "school": "Muscle Shoals Career Academy",
        "district": "Muscle Shoals City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10252001382",
    },
    {
        "school": "McBride Elementary School",
        "district": "Muscle Shoals City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10252001424",
    },
    {
        "school": "Howell Graves Preschool",
        "district": "Muscle Shoals City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10252001800",
    },
    {
        "school": "Sheffield Junior High School",
        "district": "Sheffield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10300000160",
    },
    {
        "school": "Sheffield High School",
        "district": "Sheffield City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10300001164",
    },
    {
        "school": "WA Threadgill Primary School",
        "district": "Sheffield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10300001167",
    },
    {
        "school": "L E Willson Elementary School",
        "district": "Sheffield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10300001168",
    },
    {
        "school": "Deshler High School",
        "district": "Tuscumbia City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10342001297",
    },
    {
        "school": "Deshler Middle School",
        "district": "Tuscumbia City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10342001298",
    },
    {
        "school": "R E Thompson Intermediate School",
        "district": "Tuscumbia City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10342001299",
    },
    {
        "school": "G W Trenholm Primary School",
        "district": "Tuscumbia City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10342001300",
    },
    {
        "school": "Deshler Career Technical Center",
        "district": "Tuscumbia City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10342001400",
    },
    {
        "school": "Florence High School",
        "district": "Florence City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10153000528",
    },
    {
        "school": "Florence Freshman Center",
        "district": "Florence City",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10153000531",
    },
    {
        "school": "Forest Hills School",
        "district": "Florence City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10153000532",
    },
    {
        "school": "Harlan Elementary School",
        "district": "Florence City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10153000534",
    },
    {
        "school": "Weeden Elementary School",
        "district": "Florence City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10153000535",
    },
    {
        "school": "Florence Middle School",
        "district": "Florence City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10153000536",
    },
    {
        "school": "Hibbett School",
        "district": "Florence City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10153001664",
    },
    {
        "school": "Allen Thornton Career Technical Center",
        "district": "Lauderdale County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10201000762",
    },
    {
        "school": "Brooks High School",
        "district": "Lauderdale County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10201000764",
    },
    {
        "school": "Central High School",
        "district": "Lauderdale County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10201000765",
    },
    {
        "school": "Lauderdale County High School",
        "district": "Lauderdale County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10201000767",
    },
    {
        "school": "Lexington School",
        "district": "Lauderdale County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10201000770",
    },
    {
        "school": "Rogers High School",
        "district": "Lauderdale County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10201000772",
    },
    {
        "school": "Underwood Elementary School",
        "district": "Lauderdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10201000773",
    },
    {
        "school": "Waterloo High School",
        "district": "Lauderdale County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10201000774",
    },
    {
        "school": "Wilson High School",
        "district": "Lauderdale County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10201000775",
    },
    {
        "school": "Brooks Elementary School",
        "district": "Lauderdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10201001545",
    },
    {
        "school": "Southeastern Psychiaric Management Inc",
        "district": "Southeastern Psychiaric Management Inc",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10004301854",
    },
    {
        "school": "Gadsden City Alternative School",
        "district": "Gadsden City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10162001646",
    },
    {
        "school": "Therapeutic Academic Program",
        "district": "Gadsden City",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10162001650",
    },
    {
        "school": "Etowah High School",
        "district": "Attalla City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018000033",
    },
    {
        "school": "Etowah Middle School",
        "district": "Attalla City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018000034",
    },
    {
        "school": "Attalla Elementary School",
        "district": "Attalla City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018000035",
    },
    {
        "school": "Carlisle Elementary School",
        "district": "Etowah County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000493",
    },
    {
        "school": "Duck Springs Elementary School",
        "district": "Etowah County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000494",
    },
    {
        "school": "Gaston High School",
        "district": "Etowah County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000496",
    },
    {
        "school": "Glencoe Elementary School",
        "district": "Etowah County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000497",
    },
    {
        "school": "Glencoe High School",
        "district": "Etowah County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000498",
    },
    {
        "school": "Hokes Bluff Elementary School",
        "district": "Etowah County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000499",
    },
    {
        "school": "Hokes Bluff Middle School",
        "district": "Etowah County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000500",
    },
    {
        "school": "Ivalee Elementary School",
        "district": "Etowah County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000501",
    },
    {
        "school": "John S Jones Elementary School",
        "district": "Etowah County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000502",
    },
    {
        "school": "Highland Elementary School",
        "district": "Etowah County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000503",
    },
    {
        "school": "Sardis High School",
        "district": "Etowah County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000505",
    },
    {
        "school": "Southside High School",
        "district": "Etowah County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000506",
    },
    {
        "school": "West End High School",
        "district": "Etowah County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000507",
    },
    {
        "school": "West End Elementary School",
        "district": "Etowah County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000508",
    },
    {
        "school": "Whitesboro Elementary School",
        "district": "Etowah County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138000509",
    },
    {
        "school": "Etowah County Special Education Learning Center",
        "district": "Etowah County",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10138000845",
    },
    {
        "school": "The Etowah County Refocus Center",
        "district": "Etowah County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10138000849",
    },
    {
        "school": "Career Technical Center",
        "district": "Etowah County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10138000853",
    },
    {
        "school": "Glencoe Middle School",
        "district": "Etowah County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138001507",
    },
    {
        "school": "Rainbow Middle School",
        "district": "Etowah County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138001508",
    },
    {
        "school": "Southside Elementary School",
        "district": "Etowah County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138001509",
    },
    {
        "school": "Hokes Bluff High School",
        "district": "Etowah County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138001662",
    },
    {
        "school": "Donehoo Elementary School",
        "district": "Gadsden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162000551",
    },
    {
        "school": "Litchfield Middle School",
        "district": "Gadsden City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162000552",
    },
    {
        "school": "Gadsden Middle School",
        "district": "Gadsden City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162000553",
    },
    {
        "school": "Eura Brown Elementary School",
        "district": "Gadsden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162000555",
    },
    {
        "school": "Sansom Middle School",
        "district": "Gadsden City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162000559",
    },
    {
        "school": "Mitchell Elementary School",
        "district": "Gadsden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162000563",
    },
    {
        "school": "W E Striplin Elementary School",
        "district": "Gadsden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162000564",
    },
    {
        "school": "Walnut Park Elementary School",
        "district": "Gadsden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162000565",
    },
    {
        "school": "C I T Y Program",
        "district": "Gadsden City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10162001368",
    },
    {
        "school": "Floyd Elementary School",
        "district": "Gadsden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162001517",
    },
    {
        "school": "Adams Elementary School",
        "district": "Gadsden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162001665",
    },
    {
        "school": "Thompson Elementary School",
        "district": "Gadsden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10162001666",
    },
    {
        "school": "Cedar Hill Elementary School",
        "district": "Limestone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210002081",
    },
    {
        "school": "Columbia Elementary School",
        "district": "Madison City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000802097",
    },
    {
        "school": "Sequel TSI Madison LLC",
        "district": "Sequel TSI Madison LLC",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10002301834",
    },
    {
        "school": "Sequel TSI New Beginnings LLC",
        "district": "Sequel TSI New Beginnings LLC",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10002401835",
    },
    {
        "school": "Columbia High School",
        "district": "Huntsville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180001651",
    },
    {
        "school": "Mental Health Center",
        "district": "Huntsville City",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10180001653",
    },
    {
        "school": "Hampton Cove Middle School",
        "district": "Huntsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180002093",
    },
    {
        "school": "Mt Carmel Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222001513",
    },
    {
        "school": "Legacy Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222001820",
    },
    {
        "school": "Riverton Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222002082",
    },
    {
        "school": "Athens Intermediate School",
        "district": "Athens City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10012000522",
    },
    {
        "school": "Athens Elementary School",
        "district": "Athens City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10012001471",
    },
    {
        "school": "Athens High School",
        "district": "Athens City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10012001472",
    },
    {
        "school": "Athens Middle School",
        "district": "Athens City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10012001473",
    },
    {
        "school": "James L Cowart Elementary School",
        "district": "Athens City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10012001474",
    },
    {
        "school": "Julian Newman Elementary School",
        "district": "Athens City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10012001475",
    },
    {
        "school": "Brookhill Elementary School",
        "district": "Athens City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10012001758",
    },
    {
        "school": "Ardmore High School",
        "district": "Limestone County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210000797",
    },
    {
        "school": "Clements High School",
        "district": "Limestone County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210000799",
    },
    {
        "school": "East Limestone High School",
        "district": "Limestone County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210000800",
    },
    {
        "school": "Johnson Elementary School",
        "district": "Limestone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210000802",
    },
    {
        "school": "Sugar Creek Elementary School",
        "district": "Limestone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210000805",
    },
    {
        "school": "Piney Chapel Elementary School",
        "district": "Limestone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210000806",
    },
    {
        "school": "Tanner High School",
        "district": "Limestone County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210000808",
    },
    {
        "school": "West Limestone High School",
        "district": "Limestone County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210000810",
    },
    {
        "school": "Limestone County Area Vocational Technology",
        "district": "Limestone County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10210000959",
    },
    {
        "school": "Creekside Elementary School",
        "district": "Limestone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210001454",
    },
    {
        "school": "Elkmont High School",
        "district": "Limestone County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210001549",
    },
    {
        "school": "Horizon Elementary School",
        "district": "Madison City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000800303",
    },
    {
        "school": "Discovery Middle School",
        "district": "Madison City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000800495",
    },
    {
        "school": "Bob Jones High School",
        "district": "Madison City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000800831",
    },
    {
        "school": "Madison Elementary School",
        "district": "Madison City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000800839",
    },
    {
        "school": "West Madison Elementary School",
        "district": "Madison City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000800851",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Madison City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000801423",
    },
    {
        "school": "Rainbow Elementary School",
        "district": "Madison City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000801485",
    },
    {
        "school": "Liberty Middle School",
        "district": "Madison City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000801798",
    },
    {
        "school": "Hampton Cove Elementary",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000533",
    },
    {
        "school": "Blossomwood Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000618",
    },
    {
        "school": "Academy For Academics  Arts Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000620",
    },
    {
        "school": "Roger B Chaffee Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000621",
    },
    {
        "school": "Chapman Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000622",
    },
    {
        "school": "Martin Luther King Jr Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000623",
    },
    {
        "school": "Academy For Science  Foreign Language",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000624",
    },
    {
        "school": "Farley Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000628",
    },
    {
        "school": "Virgil Grissom High School",
        "district": "Huntsville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000629",
    },
    {
        "school": "Highlands Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000630",
    },
    {
        "school": "Huntsville High School",
        "district": "Huntsville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000631",
    },
    {
        "school": "Huntsville Junior High School",
        "district": "Huntsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000632",
    },
    {
        "school": "Jones Valley Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000634",
    },
    {
        "school": "Lakewood Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000635",
    },
    {
        "school": "Lee High School",
        "district": "Huntsville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000636",
    },
    {
        "school": "McDonnell Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000638",
    },
    {
        "school": "Monte Sano Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000639",
    },
    {
        "school": "Montview Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000640",
    },
    {
        "school": "Mountain Gap Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000642",
    },
    {
        "school": "Ridgecrest Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000643",
    },
    {
        "school": "Rolling Hills Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000644",
    },
    {
        "school": "James Dawson Elementary",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000650",
    },
    {
        "school": "Weatherly Heights Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000651",
    },
    {
        "school": "Whitesburg Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180000653",
    },
    {
        "school": "New Century Technology High School",
        "district": "Huntsville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180001374",
    },
    {
        "school": "NeavesDavis Detention Center for Children",
        "district": "Huntsville City",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10180001375",
    },
    {
        "school": "Huntsville Center For Technology",
        "district": "Huntsville City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10180001379",
    },
    {
        "school": "Chapman Middle School",
        "district": "Huntsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180001527",
    },
    {
        "school": "Morris Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180001529",
    },
    {
        "school": "Mountain Gap Middle School",
        "district": "Huntsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180001530",
    },
    {
        "school": "Whitesburg Middle School",
        "district": "Huntsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180001531",
    },
    {
        "school": "Challenger Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180001773",
    },
    {
        "school": "Challenger Middle School",
        "district": "Huntsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180001774",
    },
    {
        "school": "Williams Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180001796",
    },
    {
        "school": "Hazel Green Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000030",
    },
    {
        "school": "Madison County High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000556",
    },
    {
        "school": "Monrovia Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000560",
    },
    {
        "school": "New Hope Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000566",
    },
    {
        "school": "Harvest School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000835",
    },
    {
        "school": "Hazel Green High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000836",
    },
    {
        "school": "Madison County Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000837",
    },
    {
        "school": "Madison Cross Roads Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000838",
    },
    {
        "school": "Monrovia Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000842",
    },
    {
        "school": "New Hope High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000843",
    },
    {
        "school": "New Market School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000844",
    },
    {
        "school": "Owens Cross Roads School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000846",
    },
    {
        "school": "Sparkman High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000848",
    },
    {
        "school": "Walnut Grove School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222000850",
    },
    {
        "school": "Madison County Alternative School",
        "district": "Madison County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10222000978",
    },
    {
        "school": "Madison County Career Technical Center",
        "district": "Madison County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10222000984",
    },
    {
        "school": "Meridianville Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222001411",
    },
    {
        "school": "Sparkman Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222001412",
    },
    {
        "school": "Endeavor Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222001433",
    },
    {
        "school": "Buckhorn High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222001683",
    },
    {
        "school": "Central School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222001684",
    },
    {
        "school": "Lynn Fanning Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222001731",
    },
    {
        "school": "Learning Tree Inc Webb",
        "district": "The Little Tree Preschool  Auburn",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003501846",
    },
    {
        "school": "Learning Tree Inc Semmes",
        "district": "The Little Tree Preschool  Auburn",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003501845",
    },
    {
        "school": "BayPointe ResidentialAltaPointe Health Systems",
        "district": "BayPointe Residential Services",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003701848",
    },
    {
        "school": "J E Turner Elementary",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001516",
    },
    {
        "school": "Dr Robert W Gilliard Elementary",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001595",
    },
    {
        "school": "Goodwill Easter Seal Center Special Child",
        "district": "Mobile County",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10237001597",
    },
    {
        "school": "Mobile Mental Health Center",
        "district": "Mobile County",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10237001605",
    },
    {
        "school": "Pearl Haskew Elementary",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001620",
    },
    {
        "school": "UCP Of Mobile Inc",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10237001624",
    },
    {
        "school": "Breitling Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237002083",
    },
    {
        "school": "Allentown Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000572",
    },
    {
        "school": "Peter F Alba Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000895",
    },
    {
        "school": "Mary B Austin Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000896",
    },
    {
        "school": "Denton Magnet School of Technology",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000897",
    },
    {
        "school": "Ben C Rain High School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000898",
    },
    {
        "school": "Baker High School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000899",
    },
    {
        "school": "Mattie T Blount High School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000900",
    },
    {
        "school": "Booker T Washington Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000901",
    },
    {
        "school": "Calcedeaver Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000904",
    },
    {
        "school": "Citronelle High School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000906",
    },
    {
        "school": "W H Council Traditional School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000907",
    },
    {
        "school": "Nan Gray Davis Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000910",
    },
    {
        "school": "Dauphin Island Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000911",
    },
    {
        "school": "WP Davidson High School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000912",
    },
    {
        "school": "ER Dickson Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000913",
    },
    {
        "school": "Dixon Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000914",
    },
    {
        "school": "Olive J Dodge Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000915",
    },
    {
        "school": "Dunbar Creative Performing Arts",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000916",
    },
    {
        "school": "CollinsRhodes Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000919",
    },
    {
        "school": "Elizabeth Fonde Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000920",
    },
    {
        "school": "Forest Hill Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000922",
    },
    {
        "school": "Cora Castlen Elementary",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000924",
    },
    {
        "school": "Hollingers Island Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000927",
    },
    {
        "school": "Indian Springs Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000928",
    },
    {
        "school": "John Will Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000930",
    },
    {
        "school": "ClarkShaw Magnet School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000931",
    },
    {
        "school": "Leinkauf Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000932",
    },
    {
        "school": "Mary G Montgomery High School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000934",
    },
    {
        "school": "Mary W Burroughs Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000935",
    },
    {
        "school": "Maryvale Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000936",
    },
    {
        "school": "Grand Bay Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000938",
    },
    {
        "school": "Mobile County Training Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000939",
    },
    {
        "school": "Morningside Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000940",
    },
    {
        "school": "Murphy High School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000942",
    },
    {
        "school": "Old Shell Road Magnet School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000943",
    },
    {
        "school": "Orchard Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000944",
    },
    {
        "school": "Pillans Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000946",
    },
    {
        "school": "Phillips Preparatory Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000947",
    },
    {
        "school": "WD Robbins Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000949",
    },
    {
        "school": "CL Scarborough Model Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000954",
    },
    {
        "school": "Semmes Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000955",
    },
    {
        "school": "Kate Shepard Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000956",
    },
    {
        "school": "Tanner Williams Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000960",
    },
    {
        "school": "Katherine H Hankins Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000961",
    },
    {
        "school": "John L Leflore Magnet School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000962",
    },
    {
        "school": "ChastangFournier Middle School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000963",
    },
    {
        "school": "CF Vigor High School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000964",
    },
    {
        "school": "WC Griggs Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000965",
    },
    {
        "school": "SpencerWestlawn Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000966",
    },
    {
        "school": "Whitley Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000968",
    },
    {
        "school": "Lillie B Williamson High School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000969",
    },
    {
        "school": "Wilmer Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000970",
    },
    {
        "school": "Alma Bryant High School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000989",
    },
    {
        "school": "Burns Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000990",
    },
    {
        "school": "Calloway Smith Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237000992",
    },
    {
        "school": "Grant Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001028",
    },
    {
        "school": "Florence Howard Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001030",
    },
    {
        "school": "The Pathway",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10237001038",
    },
    {
        "school": "TL Faulkner  School",
        "district": "Mobile County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10237001083",
    },
    {
        "school": "George H Bryant VocationalAgricultural Center",
        "district": "Mobile County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10237001086",
    },
    {
        "school": "Hutchens Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001414",
    },
    {
        "school": "Bernice J Causey Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001435",
    },
    {
        "school": "Elsie Collier Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001436",
    },
    {
        "school": "McDavidJones Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001437",
    },
    {
        "school": "Lott Middle School",
        "district": "Mobile County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001438",
    },
    {
        "school": "George Hall Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001556",
    },
    {
        "school": "Anna F Booth Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001559",
    },
    {
        "school": "Semmes Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001560",
    },
    {
        "school": "Holloway Elementary",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001617",
    },
    {
        "school": "Augusta Evans School",
        "district": "Mobile County",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10237001618",
    },
    {
        "school": "Meadowlake Elementary",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001619",
    },
    {
        "school": "Continuous Learning Center",
        "district": "Mobile County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10237001686",
    },
    {
        "school": "Theodore High School",
        "district": "Mobile County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001688",
    },
    {
        "school": "HL Sonny Callahan School for the Deaf and Blind",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10237001689",
    },
    {
        "school": "Saint Elmo Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001732",
    },
    {
        "school": "Erwin Craighead Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001775",
    },
    {
        "school": "Just 4 Development Laboratory",
        "district": "Mobile County",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10237001799",
    },
    {
        "school": "ORourke Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237001813",
    },
    {
        "school": "Louise M Smith Development Center",
        "district": "Autauga County",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10024001550",
    },
    {
        "school": "Project Success Learning Center",
        "district": "Lowndes County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10216001578",
    },
    {
        "school": "Brantwood Childrens Home",
        "district": "Brantwood Childrens Home",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10004001851",
    },
    {
        "school": "McKee Middle School",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001524",
    },
    {
        "school": "Blount Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243002084",
    },
    {
        "school": "Calhoun High School",
        "district": "Lowndes County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10216000815",
    },
    {
        "school": "Central Elementary School",
        "district": "Lowndes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10216000816",
    },
    {
        "school": "Central High School",
        "district": "Lowndes County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10216000817",
    },
    {
        "school": "JacksonSteele Elementary School",
        "district": "Lowndes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10216000821",
    },
    {
        "school": "Fort Deposit Elementary School",
        "district": "Lowndes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10216001635",
    },
    {
        "school": "Hayneville Middle School",
        "district": "Lowndes County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10216001636",
    },
    {
        "school": "Lowndes County Middle School",
        "district": "Lowndes County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10216001637",
    },
    {
        "school": "Billingsley High School",
        "district": "Autauga County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024000045",
    },
    {
        "school": "Prattville Elementary School",
        "district": "Autauga County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024000047",
    },
    {
        "school": "Prattville High School",
        "district": "Autauga County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024000048",
    },
    {
        "school": "Prattville Junior High School",
        "district": "Autauga County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024000049",
    },
    {
        "school": "Prattville Intermediate School",
        "district": "Autauga County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024000050",
    },
    {
        "school": "Prattville Primary School",
        "district": "Autauga County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024000051",
    },
    {
        "school": "Pine Level Elementary School",
        "district": "Autauga County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024000543",
    },
    {
        "school": "Daniel Pratt Elementary School",
        "district": "Autauga County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024000546",
    },
    {
        "school": "Autauga County Alternative School",
        "district": "Autauga County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10024000587",
    },
    {
        "school": "Autauga County Technology Center",
        "district": "Autauga County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10024000590",
    },
    {
        "school": "Autaugaville School",
        "district": "Autauga County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024001408",
    },
    {
        "school": "Prattville Kindergarten School",
        "district": "Autauga County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024001639",
    },
    {
        "school": "Marbury High School",
        "district": "Autauga County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024000046",
    },
    {
        "school": "Wetumpka Middle School",
        "district": "Elmore County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129000102",
    },
    {
        "school": "Elmore County High School",
        "district": "Elmore County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129000463",
    },
    {
        "school": "Holtville High School",
        "district": "Elmore County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129000465",
    },
    {
        "school": "Stanhope Elmore High School",
        "district": "Elmore County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129000468",
    },
    {
        "school": "Wetumpka Elementary School",
        "district": "Elmore County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129000470",
    },
    {
        "school": "Wetumpka High School",
        "district": "Elmore County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129000471",
    },
    {
        "school": "Coosada Elementary School",
        "district": "Elmore County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129000833",
    },
    {
        "school": "Elmore County Technical Center",
        "district": "Elmore County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10129000834",
    },
    {
        "school": "Eclectic Middle School",
        "district": "Elmore County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129001432",
    },
    {
        "school": "Holtville Middle School",
        "district": "Elmore County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129001451",
    },
    {
        "school": "Millbrook Middle School",
        "district": "Elmore County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129001660",
    },
    {
        "school": "Eclectic Elementary School",
        "district": "Elmore County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129001768",
    },
    {
        "school": "Holtville Elementary School",
        "district": "Elmore County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129001769",
    },
    {
        "school": "Southside Middle School",
        "district": "Tallassee City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10324001236",
    },
    {
        "school": "Tallassee High School",
        "district": "Tallassee City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10324001238",
    },
    {
        "school": "Tallassee Elementary School",
        "district": "Tallassee City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10324001601",
    },
    {
        "school": "Booker T Washington Magnet High School",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243000504",
    },
    {
        "school": "Bear Exploration Center",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243000991",
    },
    {
        "school": "Bellingrath Middle School",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243000993",
    },
    {
        "school": "Capitol Heights Middle School",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243000995",
    },
    {
        "school": "Carver Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243000996",
    },
    {
        "school": "Catoma Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243000998",
    },
    {
        "school": "Chisholm Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001001",
    },
    {
        "school": "Crump Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001004",
    },
    {
        "school": "Dalraida Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001006",
    },
    {
        "school": "Dannelly Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001007",
    },
    {
        "school": "Davis Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001008",
    },
    {
        "school": "Dozier Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001009",
    },
    {
        "school": "DunbarRamer School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001010",
    },
    {
        "school": "McIntyre Comprehensive Academy",
        "district": "Montgomery County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10243001011",
    },
    {
        "school": "Flowers Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001012",
    },
    {
        "school": "Floyd Middle School",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001013",
    },
    {
        "school": "Forest Avenue Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001014",
    },
    {
        "school": "Carver Senior High School",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001015",
    },
    {
        "school": "Goodwyn Middle School",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001017",
    },
    {
        "school": "Highland Avenue Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001021",
    },
    {
        "school": "Highland Gardens Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001022",
    },
    {
        "school": "Jefferson Davis High School",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001024",
    },
    {
        "school": "Johnson Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001025",
    },
    {
        "school": "MacMillan International at McKee",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001027",
    },
    {
        "school": "Morningview Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001031",
    },
    {
        "school": "Pintlala Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001034",
    },
    {
        "school": "Lee High School",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001035",
    },
    {
        "school": "Lanier Senior High School",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001036",
    },
    {
        "school": "Southlawn Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001037",
    },
    {
        "school": "Vaughn Road Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001039",
    },
    {
        "school": "King Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001101",
    },
    {
        "school": "Morris Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001105",
    },
    {
        "school": "Southlawn Middle School",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001111",
    },
    {
        "school": "Brewbaker Intermediate School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001392",
    },
    {
        "school": "Loveless Academic Magnet Program High School",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001417",
    },
    {
        "school": "Nixon Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001439",
    },
    {
        "school": "Brewbaker Technology Magnet High School",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001457",
    },
    {
        "school": "Garrett Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001458",
    },
    {
        "school": "Halcyon Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001459",
    },
    {
        "school": "Brewbaker Middle School",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001563",
    },
    {
        "school": "Wares Ferry Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001564",
    },
    {
        "school": "Childrens Center",
        "district": "Montgomery County",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10243001691",
    },
    {
        "school": "Brewbaker Primary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001753",
    },
    {
        "school": "Baldwin Art And Academics Magnet",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001776",
    },
    {
        "school": "Fitzpatrick Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243001777",
    },
    {
        "school": "Bridgeport Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183000654",
    },
    {
        "school": "Bridgeport Middle School",
        "district": "Jackson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183000655",
    },
    {
        "school": "Bryant School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183000656",
    },
    {
        "school": "Dutton Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183000657",
    },
    {
        "school": "Flat Rock School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183000658",
    },
    {
        "school": "Hollywood Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183000659",
    },
    {
        "school": "North Sand Mountain School",
        "district": "Jackson County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183000662",
    },
    {
        "school": "Rosalie Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183000666",
    },
    {
        "school": "Section High School",
        "district": "Jackson County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183000667",
    },
    {
        "school": "Skyline High School",
        "district": "Jackson County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183000668",
    },
    {
        "school": "Woodville High School",
        "district": "Jackson County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183000671",
    },
    {
        "school": "Jackson County Alternative School",
        "district": "Jackson County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10183000888",
    },
    {
        "school": "Epruett Center Of Technology",
        "district": "Jackson County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10183000908",
    },
    {
        "school": "Pisgah High School",
        "district": "Jackson County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183001532",
    },
    {
        "school": "Stevenson Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183001533",
    },
    {
        "school": "Stevenson Middle School",
        "district": "Jackson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183001534",
    },
    {
        "school": "Macedonia School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183001674",
    },
    {
        "school": "North Jackson High School",
        "district": "Jackson County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10183001751",
    },
    {
        "school": "Caldwell Elementary School",
        "district": "Scottsboro City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10294001145",
    },
    {
        "school": "Scottsboro High School",
        "district": "Scottsboro City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10294001147",
    },
    {
        "school": "Scottsboro Junior High School",
        "district": "Scottsboro City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10294001148",
    },
    {
        "school": "Collins Intermediate School",
        "district": "Scottsboro City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10294001486",
    },
    {
        "school": "Thurston T Nelson Elementary School",
        "district": "Scottsboro City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10294001587",
    },
    {
        "school": "Brantley Elementary School",
        "district": "Dallas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10111000395",
    },
    {
        "school": "Dallas County High School",
        "district": "Dallas County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10111000397",
    },
    {
        "school": "JE Terry Elementary School",
        "district": "Dallas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10111000401",
    },
    {
        "school": "Keith MiddleHigh School",
        "district": "Dallas County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10111000402",
    },
    {
        "school": "Salem Elementary School",
        "district": "Dallas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10111000404",
    },
    {
        "school": "Southside High School",
        "district": "Dallas County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10111000406",
    },
    {
        "school": "Southside Primary School",
        "district": "Dallas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10111000407",
    },
    {
        "school": "Tipton Durant Middle School",
        "district": "Dallas County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10111000408",
    },
    {
        "school": "Valley Grande Elementary School",
        "district": "Dallas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10111000409",
    },
    {
        "school": "William R Martin Middle School",
        "district": "Dallas County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10111000814",
    },
    {
        "school": "Dallas County Career Technical Center",
        "district": "Dallas County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10111000818",
    },
    {
        "school": "Bruce K Craig Elementary School",
        "district": "Dallas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10111001785",
    },
    {
        "school": "Sophia P Kingston Elementary School",
        "district": "Selma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10297000152",
    },
    {
        "school": "Phoenix School",
        "district": "Selma City",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10297000540",
    },
    {
        "school": "Byrd First Class Early Learning Center",
        "district": "Selma City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10297001149",
    },
    {
        "school": "Clark Elementary School",
        "district": "Selma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10297001151",
    },
    {
        "school": "School Of Discovery Genesis Center",
        "district": "Selma City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10297001153",
    },
    {
        "school": "Edgewood Elementary School",
        "district": "Selma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10297001154",
    },
    {
        "school": "Knox Elementary School",
        "district": "Selma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10297001156",
    },
    {
        "school": "Meadowview Elementary School",
        "district": "Selma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10297001157",
    },
    {
        "school": "Payne Elementary School",
        "district": "Selma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10297001158",
    },
    {
        "school": "Selma High School",
        "district": "Selma City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10297001160",
    },
    {
        "school": "The RBHudson STEAM Academy",
        "district": "Selma City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10297001161",
    },
    {
        "school": "Presbyterian Home for Children",
        "district": "Presbyterian Home for Children",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003901850",
    },
    {
        "school": "NicholsLawson Middle School",
        "district": "Sylacauga City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10312002100",
    },
    {
        "school": "Munford Middle School",
        "district": "Talladega County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318002086",
    },
    {
        "school": "Alabama School For Deaf",
        "district": "Al Inst Deaf And Blind",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10000901403",
    },
    {
        "school": "Alabama School For Blind",
        "district": "Al Inst Deaf And Blind",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10000901404",
    },
    {
        "school": "Helen Keller School",
        "district": "Al Inst Deaf And Blind",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10000901405",
    },
    {
        "school": "E H Gentry Technical Facility",
        "district": "Al Inst Deaf And Blind",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10000901406",
    },
    {
        "school": "Pinecrest Elementary School",
        "district": "Sylacauga City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10312001199",
    },
    {
        "school": "Sylacauga High School",
        "district": "Sylacauga City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10312001200",
    },
    {
        "school": "Indian Valley Elementary School",
        "district": "Sylacauga City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10312001594",
    },
    {
        "school": "C L Salter Elementary School",
        "district": "Talladega City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10315001201",
    },
    {
        "school": "Graham Elementary School",
        "district": "Talladega City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10315001203",
    },
    {
        "school": "Raymond L Young Elementary School",
        "district": "Talladega City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10315001205",
    },
    {
        "school": "Talladega High School",
        "district": "Talladega City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10315001207",
    },
    {
        "school": "Zora Ellis Junior High School",
        "district": "Talladega City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10315001208",
    },
    {
        "school": "Talladega Career Technical Center",
        "district": "Talladega City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10315001390",
    },
    {
        "school": "Evelyn D Houston Elementary School",
        "district": "Talladega City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10315001724",
    },
    {
        "school": "BB Comer Memorial Elementary School",
        "district": "Talladega County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318000577",
    },
    {
        "school": "Talladega County Genesis School",
        "district": "Talladega County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10318001206",
    },
    {
        "school": "AH Watwood Elementary School",
        "district": "Talladega County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001209",
    },
    {
        "school": "BB Comer Memorial High School",
        "district": "Talladega County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001210",
    },
    {
        "school": "Charles R Drew Middle School",
        "district": "Talladega County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001211",
    },
    {
        "school": "Childersburg Elementary School",
        "district": "Talladega County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001212",
    },
    {
        "school": "Childersburg High School",
        "district": "Talladega County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001213",
    },
    {
        "school": "Lincoln High School",
        "district": "Talladega County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001214",
    },
    {
        "school": "Talladega County Central High",
        "district": "Talladega County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001215",
    },
    {
        "school": "Fayetteville High School",
        "district": "Talladega County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001216",
    },
    {
        "school": "Munford High School",
        "district": "Talladega County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001220",
    },
    {
        "school": "Winterboro High School",
        "district": "Talladega County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001226",
    },
    {
        "school": "Munford Elementary School",
        "district": "Talladega County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001443",
    },
    {
        "school": "Sycamore School",
        "district": "Talladega County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001599",
    },
    {
        "school": "Childersburg Middle School",
        "district": "Talladega County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001756",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Talladega County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001805",
    },
    {
        "school": "Stemley Road Elementary School",
        "district": "Talladega County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10318001806",
    },
    {
        "school": "Banks School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10279001110",
    },
    {
        "school": "Pike County High School",
        "district": "Pike County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10279001112",
    },
    {
        "school": "Goshen Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10279001113",
    },
    {
        "school": "Goshen High School",
        "district": "Pike County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10279001114",
    },
    {
        "school": "Pike County Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10279001115",
    },
    {
        "school": "TroyPike Center For Technology",
        "district": "Pike County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10279001137",
    },
    {
        "school": "Alternative Learning Center",
        "district": "Troy City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10333001395",
    },
    {
        "school": "Charles Henderson High School",
        "district": "Troy City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10333001602",
    },
    {
        "school": "Charles Henderson Middle",
        "district": "Troy City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10333001603",
    },
    {
        "school": "Troy Elementary School",
        "district": "Troy City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10333001807",
    },
    {
        "school": "DMH Adolescent Education Program UAB",
        "district": "Bryce Adolescent School",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10001601828",
    },
    {
        "school": "BrewerPorch Childrens Center",
        "district": "BrewerPorch Childrens Center",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10002101832",
    },
    {
        "school": "Paul W Bryant High School",
        "district": "Tuscaloosa City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336002101",
    },
    {
        "school": "Northridge High School",
        "district": "Tuscaloosa City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336002102",
    },
    {
        "school": "Brookwood Middle School",
        "district": "Tuscaloosa County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001540",
    },
    {
        "school": "Northside Middle School",
        "district": "Tuscaloosa County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339002087",
    },
    {
        "school": "DavisEmerson Middle School",
        "district": "Tuscaloosa County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339002088",
    },
    {
        "school": "Greene County High School",
        "district": "Greene County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10168000576",
    },
    {
        "school": "Peter J Kirksey Career Center",
        "district": "Greene County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10168000864",
    },
    {
        "school": "Eutaw Primary School",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10168001452",
    },
    {
        "school": "Robert Brown Middle School",
        "district": "Greene County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10168001520",
    },
    {
        "school": "Hale County High School",
        "district": "Hale County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10171000588",
    },
    {
        "school": "Moundville Elementary School",
        "district": "Hale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10171000589",
    },
    {
        "school": "College and Career Academy",
        "district": "Hale County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10171000875",
    },
    {
        "school": "Rock Quarry Elementary School",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336000584",
    },
    {
        "school": "The Alberta School of Performing Arts",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001250",
    },
    {
        "school": "Arcadia Elementary School",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001251",
    },
    {
        "school": "Central Elementary School",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001252",
    },
    {
        "school": "Eastwood Middle School",
        "district": "Tuscaloosa City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001255",
    },
    {
        "school": "Oakdale Elementary School",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001257",
    },
    {
        "school": "Skyland Elementary School",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001260",
    },
    {
        "school": "University Place Elementary School",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001266",
    },
    {
        "school": "Westlawn Middle School",
        "district": "Tuscaloosa City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001268",
    },
    {
        "school": "Woodland Forrest Elementary School",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001269",
    },
    {
        "school": "Martin L King Jr Elementary School",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001271",
    },
    {
        "school": "Tuscaloosa Career and Technology Academy",
        "district": "Tuscaloosa City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10336001399",
    },
    {
        "school": "Central High School",
        "district": "Tuscaloosa City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001608",
    },
    {
        "school": "Verner Elementary School",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001632",
    },
    {
        "school": "Hillcrest High School",
        "district": "Tuscaloosa County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339000052",
    },
    {
        "school": "Tuscaloosa County Juvenile Detention Center",
        "district": "Tuscaloosa County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10339000233",
    },
    {
        "school": "Holt Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001272",
    },
    {
        "school": "Brookwood Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001273",
    },
    {
        "school": "Brookwood High School",
        "district": "Tuscaloosa County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001274",
    },
    {
        "school": "Buhl Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001275",
    },
    {
        "school": "Cottondale Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001276",
    },
    {
        "school": "Crestmont Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001277",
    },
    {
        "school": "Englewood Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001278",
    },
    {
        "school": "Flatwoods Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001279",
    },
    {
        "school": "Hillcrest Middle School",
        "district": "Tuscaloosa County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001280",
    },
    {
        "school": "Holt High School",
        "district": "Tuscaloosa County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001282",
    },
    {
        "school": "Matthews Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001283",
    },
    {
        "school": "Maxwell Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001284",
    },
    {
        "school": "Myrtlewood Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001285",
    },
    {
        "school": "Northside High School",
        "district": "Tuscaloosa County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001287",
    },
    {
        "school": "CollinsRiverside Middle School",
        "district": "Tuscaloosa County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001289",
    },
    {
        "school": "Tuscaloosa County High School",
        "district": "Tuscaloosa County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001291",
    },
    {
        "school": "Vance Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001292",
    },
    {
        "school": "FaucettVestavia Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001293",
    },
    {
        "school": "Walker Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001294",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001295",
    },
    {
        "school": "Taylorville Primary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001445",
    },
    {
        "school": "Echols Middle School",
        "district": "Tuscaloosa County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001462",
    },
    {
        "school": "Huntington Place Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001633",
    },
    {
        "school": "Lloyd Wood Education Center",
        "district": "Tuscaloosa County",
        "level": "Other",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10339001702",
    },
    {
        "school": "George Washington Carver Elementary School",
        "district": "Macon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10219001863",
    },
    {
        "school": "Notasulga High School",
        "district": "Macon County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10219000824",
    },
    {
        "school": "Tuskegee Institute Middle School",
        "district": "Macon County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10219000826",
    },
    {
        "school": "Tuskegee Public Elementary",
        "district": "Macon County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10219000827",
    },
    {
        "school": "DC Wolfe School",
        "district": "Macon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10219000829",
    },
    {
        "school": "Booker T Washington High",
        "district": "Macon County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10219001811",
    },
    {
        "school": "Lafayette Eastside Elementary School",
        "district": "Chambers County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10060000256",
    },
    {
        "school": "Fairfax Elementary School",
        "district": "Chambers County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10060000257",
    },
    {
        "school": "Five Points Elementary School",
        "district": "Chambers County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10060000259",
    },
    {
        "school": "Huguley Elementary School",
        "district": "Chambers County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10060000260",
    },
    {
        "school": "Lafayette High School",
        "district": "Chambers County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10060000263",
    },
    {
        "school": "Lafayette Lanier Elementary School",
        "district": "Chambers County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10060000264",
    },
    {
        "school": "Bob HardingShawmut Elementary",
        "district": "Chambers County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10060000268",
    },
    {
        "school": "John P Powell Middle School",
        "district": "Chambers County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10060000269",
    },
    {
        "school": "Valley High School",
        "district": "Chambers County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10060000271",
    },
    {
        "school": "W F Burns Middle School",
        "district": "Chambers County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10060000272",
    },
    {
        "school": "Chambers County Career Technology Center",
        "district": "Chambers County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10060000738",
    },
    {
        "school": "Lanett Senior High School",
        "district": "Lanett City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10198000759",
    },
    {
        "school": "Lanett Junior High School",
        "district": "Lanett City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10198000760",
    },
    {
        "school": "W O Lance Elementary",
        "district": "Lanett City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10198001544",
    },
    {
        "school": "STUTTGART JUNIOR HIGH SCHOOL",
        "district": "STUTTGART SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51296001249",
    },
    {
        "school": "CENTERTON GAMBLE ELEMENTARY",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001199",
    },
    {
        "school": "DELBERT PETE & PAT ALLEN ELE",
        "district": "SILOAM SPRINGS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51245001235",
    },
    {
        "school": "EUDORA ELEMENTARY SCHOOL",
        "district": "LAKESIDE SCHOOL DISTRICT (CHICOT COUNTY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50864001215",
    },
    {
        "school": "MORRILTON ELEMENTARY SCHOOL",
        "district": "SO. CONWAY CO. SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51252001166",
    },
    {
        "school": "RAY/PHYLLIS SIMON INTERMEDIATE",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459001198",
    },
    {
        "school": "OZARK KINDERGARTEN SCHOOL",
        "district": "OZARK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51101001165",
    },
    {
        "school": "IZARD COUNTY CONS MIDDLE SCH",
        "district": "IZARD CO. CONS. SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002101233",
    },
    {
        "school": "WALNUT RIDGE ELEMENTARY SCHOOL",
        "district": "LAWRENCE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50008201186",
    },
    {
        "school": "WALNUT RIDGE HIGH SCHOOL",
        "district": "LAWRENCE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50008201216",
    },
    {
        "school": "POTTSVILLE JUNIOR HIGH SCHOOL",
        "district": "POTTSVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51170001180",
    },
    {
        "school": "RUTH BARKER MIDDLE SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001139",
    },
    {
        "school": "BETHEL MIDDLE SCHOOL",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369001197",
    },
    {
        "school": "OWL CREEK SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612001213",
    },
    {
        "school": "TURNBOW ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001161",
    },
    {
        "school": "RIVERVIEW JUNIOR HIGH SCHOOL",
        "district": "RIVERVIEW SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50840001202",
    },
    {
        "school": "GILLETT ELEMENTARY SCHOOL",
        "district": "DEWITT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50000100391",
    },
    {
        "school": "PHILLIPS COMMUNITY CAREER & TECH",
        "district": "PHILLIPS COMMUNITY COLLEGE CAREER & TECHNICAL CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50006600781",
    },
    {
        "school": "GLEN ROSE MIDDLE SCHOOL",
        "district": "GLEN ROSE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50663000982",
    },
    {
        "school": "SWIFTON MIDDLE SCHOOL",
        "district": "JACKSON CO. SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51323001060",
    },
    {
        "school": "LAMAR MIDDLE SCHOOL",
        "district": "LAMAR SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50870000994",
    },
    {
        "school": "LAFAYETTE COUNTY ELEMENTARY",
        "district": "LAFAYETTE COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006500719",
    },
    {
        "school": "LAFAYETTE COUNTY HIGH SCHOOL",
        "district": "LAFAYETTE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006500727",
    },
    {
        "school": "IMBODEN AREA CHARTER SCHOOL",
        "district": "IMBODEN CHARTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006100658",
    },
    {
        "school": "HILLCREST ELEMENTARY SCHOOL",
        "district": "HILLCREST SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007100647",
    },
    {
        "school": "HILLCREST HIGH SCHOOL",
        "district": "HILLCREST SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007101010",
    },
    {
        "school": "ACORN ELEMENTARY SCHOOL",
        "district": "OUACHITA RIVER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007300001",
    },
    {
        "school": "ACORN HIGH SCHOOL",
        "district": "OUACHITA RIVER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007300002",
    },
    {
        "school": "LESLIE ELEMENTARY SCHOOL",
        "district": "SEARCY COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50948000595",
    },
    {
        "school": "NORTH CENTRAL VOCATIONAL CENTER",
        "district": "SEARCY COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50948000620",
    },
    {
        "school": "RURAL SPECIAL ELEM. SCHOOL",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51020000964",
    },
    {
        "school": "RURAL SPECIAL HIGH SCHOOL",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51020000965",
    },
    {
        "school": "TIMBO ELEMENTARY SCHOOL",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51020001086",
    },
    {
        "school": "TIMBO HIGH SCHOOL",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51020001087",
    },
    {
        "school": "CLINTON JR HIGH SCHOOL",
        "district": "CLINTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50441000765",
    },
    {
        "school": "DEWITT HIGH SCHOOL",
        "district": "DEWITT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50000100216",
    },
    {
        "school": "DEWITT MIDDLE SCHOOL",
        "district": "DEWITT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50000100217",
    },
    {
        "school": "DEWITT ELEMENTARY SCHOOL",
        "district": "DEWITT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50000100218",
    },
    {
        "school": "PARK AVENUE ELEMENTARY SCHOOL",
        "district": "STUTTGART SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51296001052",
    },
    {
        "school": "STUTTGART HIGH SCHOOL",
        "district": "STUTTGART SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51296001055",
    },
    {
        "school": "MEEKINS MIDDLE SCHOOL",
        "district": "STUTTGART SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51296001057",
    },
    {
        "school": "HAMBURG MIDDLE SCHOOL",
        "district": "HAMBURG SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004201280",
    },
    {
        "school": "HAMBURG HIGH SCHOOL",
        "district": "HAMBURG SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004201281",
    },
    {
        "school": "PORTLAND ELEMENTARY SCHOOL",
        "district": "HAMBURG SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004201282",
    },
    {
        "school": "CROSSETT ELEMENTARY SCHOOL",
        "district": "CROSSETT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50480000201",
    },
    {
        "school": "CROSSETT HIGH SCHOOL",
        "district": "CROSSETT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50480000202",
    },
    {
        "school": "CROSSETT MIDDLE SCHOOL",
        "district": "CROSSETT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50480001356",
    },
    {
        "school": "SEACBEC (WARREN)",
        "district": "WARREN SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50000600543",
    },
    {
        "school": "EASTSIDE ELEMENTARY SCHOOL",
        "district": "WARREN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50000601129",
    },
    {
        "school": "WARREN HIGH SCHOOL DISTRICT CONVERSION CHARTER",
        "district": "WARREN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50000601130",
    },
    {
        "school": "WARREN MIDDLE SCHOOL",
        "district": "WARREN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50000601334",
    },
    {
        "school": "HERMITAGE ELEMENTARY SCHOOL",
        "district": "HERMITAGE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50771000484",
    },
    {
        "school": "HERMITAGE HIGH SCHOOL",
        "district": "HERMITAGE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50771000485",
    },
    {
        "school": "BERRYVILLE ELEMENTARY SCHOOL",
        "district": "BERRYVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50315000079",
    },
    {
        "school": "BERRYVILLE HIGH SCHOOL",
        "district": "BERRYVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50315000080",
    },
    {
        "school": "BERRYVILLE MIDDLE SCHOOL",
        "district": "BERRYVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50315000411",
    },
    {
        "school": "EUREKA SPRINGS MIDDLE SCHOOL",
        "district": "EUREKA SPRINGS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50597000250",
    },
    {
        "school": "EUREKA SPRINGS ELEM. SCHOOL",
        "district": "EUREKA SPRINGS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50597000305",
    },
    {
        "school": "EUREKA SPRINGS HIGH SCHOOL",
        "district": "EUREKA SPRINGS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50597000306",
    },
    {
        "school": "GREEN FOREST ELEMENTARY SCHOOL",
        "district": "GREEN FOREST SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50687000415",
    },
    {
        "school": "GREEN FOREST HIGH SCHOOL",
        "district": "GREEN FOREST SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50687000416",
    },
    {
        "school": "GREEN FOREST INTERMED SCHOOL",
        "district": "GREEN FOREST SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50687000546",
    },
    {
        "school": "DERMOTT ELEMENTARY SCHOOL",
        "district": "DERMOTT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50517000238",
    },
    {
        "school": "DERMOTT HIGH SCHOOL",
        "district": "DERMOTT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50517000239",
    },
    {
        "school": "LAKESIDE ELEMENTARY SCHOOL",
        "district": "LAKESIDE SCHOOL DISTRICT (CHICOT COUNTY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50864000576",
    },
    {
        "school": "LAKESIDE MIDDLE SCHOOL",
        "district": "LAKESIDE SCHOOL DISTRICT (CHICOT COUNTY)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50864000577",
    },
    {
        "school": "LAKESIDE HIGH SCHOOL",
        "district": "LAKESIDE SCHOOL DISTRICT (CHICOT COUNTY)",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50864000578",
    },
    {
        "school": "CORNING HIGH SCHOOL",
        "district": "CORNING SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50000900191",
    },
    {
        "school": "PARK ELEMENTARY SCHOOL",
        "district": "CORNING SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50000900192",
    },
    {
        "school": "RECTOR ELEMENTARY SCHOOL",
        "district": "RECTOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50437001273",
    },
    {
        "school": "RECTOR HIGH SCHOOL",
        "district": "RECTOR SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50437001274",
    },
    {
        "school": "PIGGOTT ELEMENTARY SCHOOL",
        "district": "PIGGOTT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51137000851",
    },
    {
        "school": "PIGGOTT HIGH SCHOOL",
        "district": "PIGGOTT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51137000852",
    },
    {
        "school": "CONCORD ELEMENTARY SCHOOL",
        "district": "CONCORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50456000180",
    },
    {
        "school": "CONCORD HIGH SCHOOL",
        "district": "CONCORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50456000181",
    },
    {
        "school": "HEBER SPRINGS ELEM. SCHOOL",
        "district": "HEBER SPRINGS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50756000466",
    },
    {
        "school": "HEBER SPRINGS HIGH SCHOOL",
        "district": "HEBER SPRINGS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50756000467",
    },
    {
        "school": "HEBER SPRINGS MIDDLE SCHOOL",
        "district": "HEBER SPRINGS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50756000468",
    },
    {
        "school": "QUITMAN ELEMENTARY SCHOOL",
        "district": "QUITMAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51188000946",
    },
    {
        "school": "QUITMAN HIGH SCHOOL",
        "district": "QUITMAN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51188000947",
    },
    {
        "school": "WEST SIDE ELEMENTARY SCHOOL",
        "district": "WEST SIDE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51404001146",
    },
    {
        "school": "WEST SIDE HIGH SCHOOL",
        "district": "WEST SIDE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51404001147",
    },
    {
        "school": "NEMO VISTA ELEMENTARY SCHOOL",
        "district": "NEMO VISTA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51041000759",
    },
    {
        "school": "NEMO VISTA HIGH SCHOOL",
        "district": "NEMO VISTA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51041000760",
    },
    {
        "school": "MORRILTON JUNIOR HIGH SCHOOL",
        "district": "SO. CONWAY CO. SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51252000041",
    },
    {
        "school": "RIVER VALLEY VOCATIONAL CENTER",
        "district": "SO. CONWAY CO. SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "51252000567",
    },
    {
        "school": "MORRILTON SR. HIGH SCHOOL",
        "district": "SO. CONWAY CO. SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51252001242",
    },
    {
        "school": "MORRILTON INTERMEDIATE SCHOOL",
        "district": "SO. CONWAY CO. SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51252001243",
    },
    {
        "school": "MORRILTON PRIMARY SCHOOL",
        "district": "SO. CONWAY CO. SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51252001245",
    },
    {
        "school": "WONDERVIEW ELEMENTARY SCHOOL",
        "district": "WONDERVIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51437001169",
    },
    {
        "school": "WONDERVIEW HIGH SCHOOL",
        "district": "WONDERVIEW SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51437001170",
    },
    {
        "school": "WYNNE INTERMEDIATE SCHOOL",
        "district": "WYNNE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51443001173",
    },
    {
        "school": "WYNNE JUNIOR HIGH SCHOOL",
        "district": "WYNNE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51443001174",
    },
    {
        "school": "WYNNE PRIMARY SCHOOL",
        "district": "WYNNE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51443001175",
    },
    {
        "school": "WYNNE HIGH SCHOOL",
        "district": "WYNNE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51443001176",
    },
    {
        "school": "FORDYCE HIGH SCHOOL",
        "district": "FORDYCE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50621000335",
    },
    {
        "school": "FORDYCE ELEMENTARY SCHOOLS",
        "district": "FORDYCE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50621001230",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "DUMAS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50550000260",
    },
    {
        "school": "DUMAS JUNIOR HIGH SCHOOL",
        "district": "DUMAS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50550000261",
    },
    {
        "school": "DUMAS HIGH SCHOOL",
        "district": "DUMAS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50550000262",
    },
    {
        "school": "MCGEHEE ELEMENTARY SCHOOL",
        "district": "MCGEHEE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50963000703",
    },
    {
        "school": "MCGEHEE HIGH SCHOOL",
        "district": "MCGEHEE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50963000705",
    },
    {
        "school": "DREW CENTRAL ELEM. SCHOOL",
        "district": "DREW CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50547000258",
    },
    {
        "school": "DREW CENTRAL HIGH SCHOOL",
        "district": "DREW CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50547000259",
    },
    {
        "school": "MONTICELLO VOCATIONAL CENTER",
        "district": "MONTICELLO SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50984000570",
    },
    {
        "school": "MONTICELLO HIGH SCHOOL",
        "district": "MONTICELLO SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50984000721",
    },
    {
        "school": "MONTICELLO MIDDLE SCHOOL",
        "district": "MONTICELLO SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50984000722",
    },
    {
        "school": "MONTICELLO ELEMENTARY SCHOOL",
        "district": "MONTICELLO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50984000724",
    },
    {
        "school": "MONTICELLO INTERMEDIATE SCHOOL",
        "district": "MONTICELLO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50984001395",
    },
    {
        "school": "MAMMOTH SPRING ELEM. SCHOOL",
        "district": "MAMMOTH SPRING SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50927000665",
    },
    {
        "school": "MAMMOTH SPRING HIGH SCHOOL",
        "district": "MAMMOTH SPRING SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50927000666",
    },
    {
        "school": "SALEM ELEMENTARY SCHOOL",
        "district": "SALEM SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51209000974",
    },
    {
        "school": "SALEM HIGH SCHOOL",
        "district": "SALEM SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51209000975",
    },
    {
        "school": "VIOLA ELEMENTARY SCHOOL",
        "district": "VIOLA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51356001111",
    },
    {
        "school": "VIOLA HIGH SCHOOL",
        "district": "VIOLA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51356001112",
    },
    {
        "school": "OUACHITA VOCATIONAL CENTER",
        "district": "OUACHITA VOCATIONAL CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50005400583",
    },
    {
        "school": "BISMARCK ELEMENTARY SCHOOL",
        "district": "BISMARCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50324000085",
    },
    {
        "school": "BISMARCK HIGH SCHOOL",
        "district": "BISMARCK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50324000086",
    },
    {
        "school": "BISMARCK MIDDLE SCHOOL",
        "district": "BISMARCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50324000336",
    },
    {
        "school": "GLEN ROSE ELEMENTARY SCHOOL",
        "district": "GLEN ROSE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50663000397",
    },
    {
        "school": "GLEN ROSE HIGH SCHOOL",
        "district": "GLEN ROSE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50663000398",
    },
    {
        "school": "MAGNET COVE ELEMENTARY SCHOOL",
        "district": "MAGNET COVE SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50919000651",
    },
    {
        "school": "MAGNET COVE HIGH SCHOOL",
        "district": "MAGNET COVE SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50919000652",
    },
    {
        "school": "WILSON INTERMEDIATE SCHOOL",
        "district": "MALVERN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50924001327",
    },
    {
        "school": "MALVERN ELEMENTARY SCHOOL",
        "district": "MALVERN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50924001366",
    },
    {
        "school": "MALVERN HIGH SCHOOL",
        "district": "MALVERN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50924001372",
    },
    {
        "school": "MALVERN JUNIOR HIGH SCHOOL",
        "district": "MALVERN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50924001373",
    },
    {
        "school": "OUACHITA ELEMENTARY SCHOOL",
        "district": "OUACHITA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51098000827",
    },
    {
        "school": "OUACHITA HIGH SCHOOL",
        "district": "OUACHITA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51098000828",
    },
    {
        "school": "JOANN WALTERS ELEMENTARY SCH",
        "district": "DIERKS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50534000248",
    },
    {
        "school": "DIERKS HIGH SCHOOL",
        "district": "DIERKS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50534000249",
    },
    {
        "school": "MINERAL SPRINGS ELEM. SCHOOL",
        "district": "MINERAL SPRINGS SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50978000716",
    },
    {
        "school": "MINERAL SPRINGS HIGH SCHOOL",
        "district": "MINERAL SPRINGS SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50978000717",
    },
    {
        "school": "NASHVILLE ELEMENTARY SCHOOL",
        "district": "NASHVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51038000756",
    },
    {
        "school": "NASHVILLE HIGH SCHOOL",
        "district": "NASHVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51038000757",
    },
    {
        "school": "NASHVILLE JUNIOR HIGH SCHOOL",
        "district": "NASHVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51038000758",
    },
    {
        "school": "NASHVILLE PRIMARY SCHOOL",
        "district": "NASHVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51038001193",
    },
    {
        "school": "IZARD CO. CONS. ELEM. SCHOOL",
        "district": "IZARD CO. CONS. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002101299",
    },
    {
        "school": "IZARD CO. CONS. HIGH SCHOOL",
        "district": "IZARD CO. CONS. SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002101300",
    },
    {
        "school": "CALICO ROCK ELEMENTARY SCHOOL",
        "district": "CALICO ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50384000131",
    },
    {
        "school": "CALICO ROCK HIGH SCHOOL",
        "district": "CALICO ROCK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50384000132",
    },
    {
        "school": "MELBOURNE ELEMENTARY SCHOOL",
        "district": "MELBOURNE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50972000710",
    },
    {
        "school": "MELBOURNE HIGH SCHOOL",
        "district": "MELBOURNE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50972000711",
    },
    {
        "school": "NEWPORT HIGH SCHOOL",
        "district": "NEWPORT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002300772",
    },
    {
        "school": "MCCRORY ELEMENTARY SCHOOL",
        "district": "MCCRORY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50960000701",
    },
    {
        "school": "MCCRORY HIGH SCHOOL",
        "district": "MCCRORY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50960000702",
    },
    {
        "school": "TUCKERMAN ELEMENTARY SCHOOL",
        "district": "JACKSON CO. SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51323001082",
    },
    {
        "school": "TUCKERMAN HIGH SCHOOL",
        "district": "JACKSON CO. SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51323001083",
    },
    {
        "school": "KRAUS MIDDLE SCHOOL",
        "district": "CLARKSVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50438000154",
    },
    {
        "school": "CLARKSVILLE HIGH SCHOOL",
        "district": "CLARKSVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50438000166",
    },
    {
        "school": "CLARKSVILLE JUNIOR HIGH SCHOOL",
        "district": "CLARKSVILLE SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50438000167",
    },
    {
        "school": "PYRON ELEMENTARY SCHOOL",
        "district": "CLARKSVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50438000168",
    },
    {
        "school": "CLARKSVILLE PRIMARY SCHOOL",
        "district": "CLARKSVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50438000806",
    },
    {
        "school": "LAMAR ELEMENTARY SCHOOL",
        "district": "LAMAR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50870000584",
    },
    {
        "school": "LAMAR HIGH SCHOOL",
        "district": "LAMAR SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50870000585",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "WESTSIDE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51402001266",
    },
    {
        "school": "WESTSIDE HIGH SCHOOL",
        "district": "WESTSIDE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51402001267",
    },
    {
        "school": "HOXIE ELEMENTARY SCHOOL",
        "district": "HOXIE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50799000517",
    },
    {
        "school": "HOXIE HIGH SCHOOL",
        "district": "HOXIE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50799000518",
    },
    {
        "school": "SLOAN-HENDRIX ELEM. SCHOOL",
        "district": "SLOAN-HENDRIX SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51248001006",
    },
    {
        "school": "SLOAN-HENDRIX HIGH SCHOOL",
        "district": "SLOAN-HENDRIX SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51248001007",
    },
    {
        "school": "LEE HIGH SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50936000675",
    },
    {
        "school": "ASHDOWN HIGH SCHOOL",
        "district": "ASHDOWN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50258000028",
    },
    {
        "school": "L.F. HENDERSON INTERM. SCH.",
        "district": "ASHDOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50258000029",
    },
    {
        "school": "ASHDOWN JUNIOR HIGH SCHOOL",
        "district": "ASHDOWN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50258000031",
    },
    {
        "school": "MARGARET DANIELS PRIMARY",
        "district": "ASHDOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50258000807",
    },
    {
        "school": "OSCAR HAMILTON ELEMENTARY SCH",
        "district": "FOREMAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50624000337",
    },
    {
        "school": "FOREMAN HIGH SCHOOL",
        "district": "FOREMAN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50624000338",
    },
    {
        "school": "BOONEVILLE ELEMENTARY SCHOOL",
        "district": "BOONEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50345000104",
    },
    {
        "school": "BOONEVILLE HIGH SCHOOL",
        "district": "BOONEVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50345000105",
    },
    {
        "school": "BOONEVILLE JR HIGH SCHOOL",
        "district": "BOONEVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50345000339",
    },
    {
        "school": "MAGAZINE ELEMENTARY SCHOOL",
        "district": "MAGAZINE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50915000649",
    },
    {
        "school": "J.D. LEFTWICH HIGH SCHOOL",
        "district": "MAGAZINE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50915000650",
    },
    {
        "school": "PARIS ELEMENTARY SCHOOL",
        "district": "PARIS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51113000836",
    },
    {
        "school": "PARIS HIGH SCHOOL",
        "district": "PARIS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51113000837",
    },
    {
        "school": "PARIS MIDDLE SCHOOL",
        "district": "PARIS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51113001412",
    },
    {
        "school": "SCRANTON ELEMENTARY SCHOOL",
        "district": "SCRANTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51218000980",
    },
    {
        "school": "SCRANTON HIGH SCHOOL",
        "district": "SCRANTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51218000981",
    },
    {
        "school": "FLIPPIN MIDDLE SCHOOL",
        "district": "FLIPPIN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50615000277",
    },
    {
        "school": "FLIPPIN ELEMENTARY SCHOOL",
        "district": "FLIPPIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50615000330",
    },
    {
        "school": "FLIPPIN HIGH SCHOOL",
        "district": "FLIPPIN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50615000331",
    },
    {
        "school": "YELLVILLE-SUMMIT ELEM. SCHOOL",
        "district": "YELLVILLE-SUMMIT SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51449001177",
    },
    {
        "school": "YELLVILLE-SUMMIT HIGH SCHOOL",
        "district": "YELLVILLE-SUMMIT SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51449001178",
    },
    {
        "school": "BRINKLEY HIGH SCHOOL",
        "district": "BRINKLEY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50363000112",
    },
    {
        "school": "C.B. PARTEE ELEMENTARY SCHOOL",
        "district": "BRINKLEY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50363000114",
    },
    {
        "school": "CLARENDON ELEMENTARY SCHOOL",
        "district": "CLARENDON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50435000163",
    },
    {
        "school": "CLARENDON HIGH SCHOOL",
        "district": "CLARENDON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50435000164",
    },
    {
        "school": "CADDO HILLS ELEMENTARY SCHOOL",
        "district": "CADDO HILLS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50377000126",
    },
    {
        "school": "CADDO HILLS HIGH SCHOOL",
        "district": "CADDO HILLS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50377000127",
    },
    {
        "school": "MOUNT IDA ELEMENTARY SCHOOL",
        "district": "MOUNT IDA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50999000732",
    },
    {
        "school": "MOUNT IDA HIGH SCHOOL",
        "district": "MOUNT IDA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50999000733",
    },
    {
        "school": "KIRBY ELEMENTARY SCHOOL",
        "district": "KIRBY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50849000565",
    },
    {
        "school": "KIRBY HIGH SCHOOL",
        "district": "KIRBY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50849000566",
    },
    {
        "school": "MURFREESBORO ELEMENTARY SCHOOL",
        "district": "SOUTH PIKE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51032000754",
    },
    {
        "school": "MURFREESBORO HIGH SCHOOL",
        "district": "SOUTH PIKE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51032000755",
    },
    {
        "school": "LOUISE DURHAM ELEM. SCHOOL",
        "district": "MENA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50975000712",
    },
    {
        "school": "MENA HIGH SCHOOL",
        "district": "MENA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50975000713",
    },
    {
        "school": "MENA MIDDLE SCHOOL",
        "district": "MENA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50975000714",
    },
    {
        "school": "HOLLY HARSHMAN ELEM. SCHOOL",
        "district": "MENA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50975000715",
    },
    {
        "school": "DES ARC HIGH SCHOOL",
        "district": "DES ARC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50519000240",
    },
    {
        "school": "DES ARC ELEMENTARY SCHOOL",
        "district": "DES ARC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50519000241",
    },
    {
        "school": "HAZEN ELEMENTARY SCHOOL",
        "district": "HAZEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50753000464",
    },
    {
        "school": "HAZEN HIGH SCHOOL",
        "district": "HAZEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50753000465",
    },
    {
        "school": "MAYNARD ELEMENTARY SCHOOL",
        "district": "MAYNARD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50957000699",
    },
    {
        "school": "MAYNARD HIGH SCHOOL",
        "district": "MAYNARD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50957000700",
    },
    {
        "school": "ALMA SPIKES ELEMENTARY SCHOOL",
        "district": "POCAHONTAS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51161000883",
    },
    {
        "school": "POCAHONTAS HIGH SCHOOL",
        "district": "POCAHONTAS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51161000884",
    },
    {
        "school": "M.D. WILLIAMS INTERMEDIATE SCHOOL",
        "district": "POCAHONTAS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51161000885",
    },
    {
        "school": "POCAHONTAS JUNIOR HIGH SCHOOL",
        "district": "POCAHONTAS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51161001438",
    },
    {
        "school": "WALDRON ELEMENTARY SCHOOL",
        "district": "WALDRON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51368001120",
    },
    {
        "school": "WALDRON MIDDLE SCHOOL",
        "district": "WALDRON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51368001121",
    },
    {
        "school": "WALDRON HIGH SCHOOL",
        "district": "WALDRON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51368001122",
    },
    {
        "school": "MARSHALL ELEMENTARY SCHOOL",
        "district": "SEARCY COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50948000692",
    },
    {
        "school": "MARSHALL HIGH SCHOOL",
        "district": "SEARCY COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50948000693",
    },
    {
        "school": "DEQUEEN ELEMENTARY SCHOOL",
        "district": "DEQUEEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004900234",
    },
    {
        "school": "DEQUEEN HIGH SCHOOL",
        "district": "DEQUEEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004900235",
    },
    {
        "school": "DEQUEEN MIDDLE SCHOOL",
        "district": "DEQUEEN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004900236",
    },
    {
        "school": "DEQUEEN PRIMARY",
        "district": "DEQUEEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004900853",
    },
    {
        "school": "HORATIO ELEMENTARY SCHOOL",
        "district": "HORATIO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50786000501",
    },
    {
        "school": "HORATIO HIGH SCHOOL",
        "district": "HORATIO SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50786000502",
    },
    {
        "school": "CAVE CITY ELEMENTARY SCHOOL",
        "district": "CAVE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50405000147",
    },
    {
        "school": "CAVE CITY HIGH CAREER & COLLEGIATE PREPARATORY SCHOOL",
        "district": "CAVE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50405000148",
    },
    {
        "school": "CHEROKEE ELEMENTARY SCHOOL",
        "district": "HIGHLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50777000490",
    },
    {
        "school": "HIGHLAND HIGH SCHOOL",
        "district": "HIGHLAND SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50777000491",
    },
    {
        "school": "HIGHLAND MIDDLE SCHOOL",
        "district": "HIGHLAND SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50777001232",
    },
    {
        "school": "MOUNTAIN VIEW ELEM. SCHOOL",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51020000747",
    },
    {
        "school": "MOUNTAIN VIEW HIGH SCHOOL",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51020000749",
    },
    {
        "school": "COWSERT ELEMENTARY SCHOOL",
        "district": "CLINTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50441000171",
    },
    {
        "school": "CLINTON HIGH SCHOOL",
        "district": "CLINTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50441000172",
    },
    {
        "school": "SHIRLEY ELEMENTARY SCHOOL",
        "district": "SHIRLEY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51242001000",
    },
    {
        "school": "SHIRLEY HIGH SCHOOL",
        "district": "SHIRLEY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51242001001",
    },
    {
        "school": "SOUTH SIDE ELEMENTARY SCHOOL",
        "district": "SOUTH SIDE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51257001013",
    },
    {
        "school": "SOUTH SIDE HIGH SCHOOL",
        "district": "SOUTH SIDE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51257001014",
    },
    {
        "school": "AUGUSTA HIGH SCHOOL",
        "district": "AUGUSTA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50267000034",
    },
    {
        "school": "AUGUSTA ELEMENTARY SCHOOL",
        "district": "AUGUSTA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50267000036",
    },
    {
        "school": "ARKADELPHIA HIGH SCHOOL",
        "district": "ARKADELPHIA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50243000018",
    },
    {
        "school": "CENTRAL PRIMARY SCHOOL",
        "district": "ARKADELPHIA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50243000019",
    },
    {
        "school": "GOZA MIDDLE SCHOOL",
        "district": "ARKADELPHIA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50243000020",
    },
    {
        "school": "PEAKE ELEMENTARY SCHOOL",
        "district": "ARKADELPHIA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50243000021",
    },
    {
        "school": "LOUISA PERRITT PRIMARY",
        "district": "ARKADELPHIA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50243000022",
    },
    {
        "school": "GURDON HIGH SCHOOL",
        "district": "GURDON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50711000430",
    },
    {
        "school": "CABE MIDDLE SCHOOL",
        "district": "GURDON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50711000431",
    },
    {
        "school": "GURDON PRIMARY SCHOOL",
        "district": "GURDON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50711000432",
    },
    {
        "school": "CENTERPOINT HIGH SCHOOL",
        "district": "CENTERPOINT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50669000341",
    },
    {
        "school": "SULPHUR ROCK MAGNET SCHOOL",
        "district": "BATESVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001901092",
    },
    {
        "school": "NEWARK ELEMENTARY SCHOOL",
        "district": "CEDAR RIDGE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007000767",
    },
    {
        "school": "CEDAR RIDGE HIGH SCHOOL",
        "district": "CEDAR RIDGE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007000768",
    },
    {
        "school": "BATESVILLE JUNIOR HIGH SCHOOL",
        "district": "BATESVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001900042",
    },
    {
        "school": "BATESVILLE HIGH SCHOOL",
        "district": "BATESVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001900043",
    },
    {
        "school": "WEST MAGNET SCHOOL",
        "district": "BATESVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001900046",
    },
    {
        "school": "EAGLE MOUNTAIN MAGNET SCHOOL",
        "district": "BATESVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001900144",
    },
    {
        "school": "MIDLAND ELEMENTARY SCHOOL",
        "district": "MIDLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002001297",
    },
    {
        "school": "MIDLAND HIGH SCHOOL",
        "district": "MIDLAND SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002001298",
    },
    {
        "school": "SOUTHSIDE MIDDLE SCHOOL",
        "district": "SOUTHSIDE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51254000100",
    },
    {
        "school": "SOUTHSIDE ELEMENTARY SCHOOL",
        "district": "SOUTHSIDE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51254001011",
    },
    {
        "school": "SOUTHSIDE CHARTER HIGH SCHOOL",
        "district": "SOUTHSIDE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51254001012",
    },
    {
        "school": "ARKANSAS NORTHEASTERN COLLEGE",
        "district": "ARKANSAS NORTHEASTERN COLLEGE TECHNICAL CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50008001098",
    },
    {
        "school": "GOSNELL ELEMENTARY SCHOOL",
        "district": "GOSNELL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002901275",
    },
    {
        "school": "GOSNELL HIGH SCHOOL",
        "district": "GOSNELL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002901277",
    },
    {
        "school": "RIVERCREST HIGH SCHOOL",
        "district": "RIVERCREST SCHOOL DISTRICT #57",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004501204",
    },
    {
        "school": "MANILA ELEMENTARY SCHOOL",
        "district": "MANILA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004600667",
    },
    {
        "school": "MANILA HIGH SCHOOL",
        "district": "MANILA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004600668",
    },
    {
        "school": "ARMOREL ELEMENTARY SCHOOL",
        "district": "ARMOREL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50255000026",
    },
    {
        "school": "ARMOREL HIGH SCHOOL",
        "district": "ARMOREL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50255000027",
    },
    {
        "school": "BLYTHEVILLE ELEMENTARY SCHOOL",
        "district": "BLYTHEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50332000093",
    },
    {
        "school": "BLYTHEVILLE PRIMARY SCHOOL",
        "district": "BLYTHEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50332000096",
    },
    {
        "school": "BLYTHEVILLE MIDDLE SCHOOL",
        "district": "BLYTHEVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50332000099",
    },
    {
        "school": "OSCEOLA HIGH SCHOOL",
        "district": "OSCEOLA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51095000825",
    },
    {
        "school": "NORTH ELEMENTARY SCHOOL",
        "district": "OSCEOLA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51095001237",
    },
    {
        "school": "SPARKMAN ELEMENTARY SCHOOL",
        "district": "HARMONY GROVE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50729001015",
    },
    {
        "school": "SPARKMAN HIGH SCHOOL",
        "district": "HARMONY GROVE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50729001016",
    },
    {
        "school": "HAMPTON ELEMENTARY SCHOOL",
        "district": "HAMPTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50723000440",
    },
    {
        "school": "HAMPTON HIGH SCHOOL",
        "district": "HAMPTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50723000441",
    },
    {
        "school": "SAU TECH CAREER CENTER",
        "district": "SAU-TECH CAREER CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50000200594",
    },
    {
        "school": "BEARDEN ELEMENTARY SCHOOL",
        "district": "BEARDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50003200052",
    },
    {
        "school": "BEARDEN HIGH SCHOOL",
        "district": "BEARDEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50003200053",
    },
    {
        "school": "FAIRVIEW ELEMENTARY SCHOOL",
        "district": "CAMDEN FAIRVIEW SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50606000311",
    },
    {
        "school": "CAMDEN FAIRVIEW HIGH SCHOOL",
        "district": "CAMDEN FAIRVIEW SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50606000312",
    },
    {
        "school": "IVORY PRIMARY SCHOOL",
        "district": "CAMDEN FAIRVIEW SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50606001432",
    },
    {
        "school": "CAMDEN FAIRVIEW INTERMEDIATE",
        "district": "CAMDEN FAIRVIEW SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50606001433",
    },
    {
        "school": "CAMDEN FAIRVIEW MIDDLE SCHOOL",
        "district": "CAMDEN FAIRVIEW SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50606001435",
    },
    {
        "school": "HARMONY GROVE ELEM. SCHOOL",
        "district": "HARMONY GROVE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50729000442",
    },
    {
        "school": "HARMONY GROVE HIGH SCHOOL",
        "district": "HARMONY GROVE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50729000443",
    },
    {
        "school": "SOUTHARK CAREER CENTER",
        "district": "SOUTH ARK CAREER CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50005200646",
    },
    {
        "school": "BARTON JR. HIGH SCHOOL",
        "district": "EL DORADO SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50568000273",
    },
    {
        "school": "EL DORADO HIGH SCHOOL",
        "district": "EL DORADO SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50568000274",
    },
    {
        "school": "HUGH GOODWIN ELEMENTARY SCHOOL",
        "district": "EL DORADO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50568000276",
    },
    {
        "school": "NORTHWEST ELEMENTARY SCHOOL",
        "district": "EL DORADO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50568000279",
    },
    {
        "school": "RETTA BROWN ELEMENTARY SCHOOL",
        "district": "EL DORADO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50568000280",
    },
    {
        "school": "WASHINGTON MIDDLE SCHOOL",
        "district": "EL DORADO SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50568000281",
    },
    {
        "school": "YOCUM ELEMENTARY SCHOOL",
        "district": "EL DORADO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50568000285",
    },
    {
        "school": "JUNCTION CITY ELEM. SCHOOL",
        "district": "JUNCTION CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50834000557",
    },
    {
        "school": "JUNCTION CITY HIGH SCHOOL",
        "district": "JUNCTION CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50834000558",
    },
    {
        "school": "PARKERS CHAPEL ELEM. SCHOOL",
        "district": "PARKERS CHAPEL SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51122000840",
    },
    {
        "school": "PARKERS CHAPEL HIGH SCHOOL",
        "district": "PARKERS CHAPEL SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51122000841",
    },
    {
        "school": "SMACKOVER ELEMENTARY SCHOOL",
        "district": "SMACKOVER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51251001008",
    },
    {
        "school": "SMACKOVER HIGH SCHOOL",
        "district": "SMACKOVER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51251001009",
    },
    {
        "school": "MARY MAE JONES ELEM. SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306000879",
    },
    {
        "school": "CENTRAL PARK AT MORNING STAR",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001080",
    },
    {
        "school": "ELZA R. TUCKER ELEM. SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000881",
    },
    {
        "school": "OLD WIRE ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197001088",
    },
    {
        "school": "HUNT ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001127",
    },
    {
        "school": "HUNTSVILLE INTERMEDIATE SCH",
        "district": "HUNTSVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50813000662",
    },
    {
        "school": "ST. PAUL ELEMENTARY SCHOOL",
        "district": "HUNTSVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50813001034",
    },
    {
        "school": "ST. PAUL HIGH SCHOOL",
        "district": "HUNTSVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50813001035",
    },
    {
        "school": "HAAS HALL ACADEMY",
        "district": "HAAS HALL ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007801078",
    },
    {
        "school": "NWA COMMUNITY COLLEGE REG CENTER",
        "district": "NORTHWEST ARKANSAS COMMUNITY COLLEGE REGIONAL CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50008100320",
    },
    {
        "school": "ELKINS ELEM. PRIMARY SCHOOL",
        "district": "ELKINS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50576001051",
    },
    {
        "school": "JERRY POP WILLIAMS ELEM SCH",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50609001113",
    },
    {
        "school": "GREENLAND MIDDLE SCHOOL",
        "district": "GREENLAND SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50693000660",
    },
    {
        "school": "HARP ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266000669",
    },
    {
        "school": "BAYYARI ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001053",
    },
    {
        "school": "GEORGE JUNIOR HIGH SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001077",
    },
    {
        "school": "HELLSTERN MIDDLE SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001114",
    },
    {
        "school": "HAR-BER HIGH SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001118",
    },
    {
        "school": "WATSON PRIMARY SCHOOL",
        "district": "HUNTSVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50813000537",
    },
    {
        "school": "HUNTSVILLE HIGH SCHOOL",
        "district": "HUNTSVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50813000538",
    },
    {
        "school": "HUNTSVILLE MIDDLE SCHOOL",
        "district": "HUNTSVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50813000539",
    },
    {
        "school": "ARKANSAS ARTS ACADEMY ELEMENTARY/MIDDLE SCHOOL",
        "district": "BENTON COUNTY SCHOOL OF ARTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50005500513",
    },
    {
        "school": "PEA RIDGE INTERMEDIATE SCHOOL",
        "district": "PEA RIDGE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50303000071",
    },
    {
        "school": "PEA RIDGE HIGH SCHOOL",
        "district": "PEA RIDGE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50303000072",
    },
    {
        "school": "PEA RIDGE MIDDLE SCHOOL",
        "district": "PEA RIDGE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50303000169",
    },
    {
        "school": "BENTONVILLE HIGH SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306000073",
    },
    {
        "school": "WASHINGTON JUNIOR HIGH SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306000074",
    },
    {
        "school": "R.E. BAKER ELEMENTARY SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306000075",
    },
    {
        "school": "THOMAS JEFFERSON ELEM. SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306000076",
    },
    {
        "school": "SPRING HILL MIDDLE SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306000160",
    },
    {
        "school": "ELM TREE ELEMENTARY SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306000165",
    },
    {
        "school": "LINCOLN JUNIOR HIGH SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306000789",
    },
    {
        "school": "OLD HIGH MIDDLE SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001229",
    },
    {
        "school": "SUGAR CREEK ELEMENTARY SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001423",
    },
    {
        "school": "APPLE GLEN ELEMENTARY SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001424",
    },
    {
        "school": "DECATUR NORTHSIDE ELEMENTARY",
        "district": "DECATUR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50498000220",
    },
    {
        "school": "DECATUR HIGH SCHOOL",
        "district": "DECATUR SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50498000221",
    },
    {
        "school": "GENTRY INTERMEDIATE SCHOOL",
        "district": "GENTRY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50654000389",
    },
    {
        "school": "GENTRY HIGH SCHOOL CONVERSION CHARTER",
        "district": "GENTRY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50654000390",
    },
    {
        "school": "GENTRY PRIMARY SCHOOL",
        "district": "GENTRY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50654000791",
    },
    {
        "school": "GENTRY MIDDLE SCHOOL",
        "district": "GENTRY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50654001231",
    },
    {
        "school": "GRAVETTE UPPER ELEMENTARY",
        "district": "GRAVETTE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50684000406",
    },
    {
        "school": "GLENN DUFFY ELEMENTARY SCHOOL",
        "district": "GRAVETTE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50684000413",
    },
    {
        "school": "GRAVETTE HIGH SCHOOL",
        "district": "GRAVETTE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50684000414",
    },
    {
        "school": "GRAVETTE MIDDLE SCHOOL",
        "district": "GRAVETTE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50684001394",
    },
    {
        "school": "FRANK TILLERY ELEM. SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000101",
    },
    {
        "school": "JOE MATHIAS ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000117",
    },
    {
        "school": "FAIRVIEW ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000304",
    },
    {
        "school": "LINGLE MIDDLE SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000328",
    },
    {
        "school": "BELLVIEW ELEMENTARY",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000349",
    },
    {
        "school": "JONES ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000505",
    },
    {
        "school": "EASTSIDE ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000952",
    },
    {
        "school": "ELMWOOD MIDDLE SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000953",
    },
    {
        "school": "GARFIELD ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000954",
    },
    {
        "school": "LOWELL ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000955",
    },
    {
        "school": "NORTHSIDE ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000956",
    },
    {
        "school": "OAKDALE MIDDLE SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000957",
    },
    {
        "school": "ROGERS HIGH SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000958",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197000960",
    },
    {
        "school": "GRACE HILL ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197001221",
    },
    {
        "school": "BONNIE GRIMES ELEM. SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197001370",
    },
    {
        "school": "REAGAN ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197001414",
    },
    {
        "school": "NORTHSIDE ELEMENTARY SCHOOL",
        "district": "SILOAM SPRINGS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51245001002",
    },
    {
        "school": "SILOAM SPRINGS HIGH SCHOOL CONVERSION CHARTER",
        "district": "SILOAM SPRINGS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51245001003",
    },
    {
        "school": "SILOAM SPRINGS MIDDLE SCHOOL",
        "district": "SILOAM SPRINGS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51245001004",
    },
    {
        "school": "SOUTHSIDE ELEMENTARY SCHOOL",
        "district": "SILOAM SPRINGS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51245001005",
    },
    {
        "school": "ELKINS ELEMENTARY SCHOOL",
        "district": "ELKINS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50576000289",
    },
    {
        "school": "ELKINS HIGH SCHOOL",
        "district": "ELKINS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50576000290",
    },
    {
        "school": "ELKINS MIDDLE SCHOOL",
        "district": "ELKINS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50576000303",
    },
    {
        "school": "FARMINGTON CAREER ACADEMIES",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50609000315",
    },
    {
        "school": "RANDALL G. LYNCH MIDDLE SCHOOL",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50609000854",
    },
    {
        "school": "HOLCOMB ELEMENTARY SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000229",
    },
    {
        "school": "VANDERGRIFF ELEMENTARY SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000231",
    },
    {
        "school": "ASBELL ELEMENTARY SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000316",
    },
    {
        "school": "BUTTERFIELD ELEMENTARY SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000318",
    },
    {
        "school": "FAYETTEVILLE HIGH SCHOOL EAST",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000319",
    },
    {
        "school": "HAPPY HOLLOW ELEMENTARY SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000321",
    },
    {
        "school": "LEVERETT ELEMENTARY SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000323",
    },
    {
        "school": "RAMAY JUNIOR HIGH SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000324",
    },
    {
        "school": "ROOT ELEMENTARY SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000325",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000326",
    },
    {
        "school": "WOODLAND JUNIOR HIGH SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000327",
    },
    {
        "school": "MCNAIR MIDDLE SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000856",
    },
    {
        "school": "HOLT MIDDLE SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612000863",
    },
    {
        "school": "GREENLAND ELEMENTARY SCHOOL",
        "district": "GREENLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50693000419",
    },
    {
        "school": "GREENLAND HIGH SCHOOL",
        "district": "GREENLAND SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50693000420",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "LINCOLN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50894000600",
    },
    {
        "school": "LINCOLN MIDDLE SCHOOL",
        "district": "LINCOLN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50894001363",
    },
    {
        "school": "PRAIRIE GROVE ELEM. SCHOOL",
        "district": "PRAIRIE GROVE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51176000894",
    },
    {
        "school": "PRAIRIE GROVE HIGH SCHOOL",
        "district": "PRAIRIE GROVE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51176000895",
    },
    {
        "school": "PRAIRIE GROVE MIDDLE SCHOOL",
        "district": "PRAIRIE GROVE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51176001426",
    },
    {
        "school": "GEORGE ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266000059",
    },
    {
        "school": "J. O. KELLY MIDDLE SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266000233",
    },
    {
        "school": "HELEN TYSON MIDDLE SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266000237",
    },
    {
        "school": "BERNICE YOUNG ELEMENTARY",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266000869",
    },
    {
        "school": "CENTRAL JUNIOR HIGH SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001020",
    },
    {
        "school": "ELMDALE ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001021",
    },
    {
        "school": "JONES ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001022",
    },
    {
        "school": "ROBERT E. LEE ELEM. SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001023",
    },
    {
        "school": "SOUTHWEST JUNIOR HIGH SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001024",
    },
    {
        "school": "SPRINGDALE HIGH SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001025",
    },
    {
        "school": "JOHN TYSON ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001027",
    },
    {
        "school": "WESTWOOD ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001029",
    },
    {
        "school": "PARSON  HILLS ELEM. SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001259",
    },
    {
        "school": "THURMAN G. SMITH ELEM. SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001260",
    },
    {
        "school": "WALKER ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001396",
    },
    {
        "school": "WEST FORK ELEMENTARY SCHOOL",
        "district": "WEST FORK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51401001143",
    },
    {
        "school": "WEST FORK HIGH SCHOOL",
        "district": "WEST FORK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51401001144",
    },
    {
        "school": "WEST FORK MIDDLE SCHOOL",
        "district": "WEST FORK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51401001145",
    },
    {
        "school": "EAST ARKANSAS CAREER CENTER",
        "district": "EAST ARKANSAS CAREER CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50007501031",
    },
    {
        "school": "PALESTINE-WHEATLEY ELEM. SCH.",
        "district": "PALESTINE-WHEATLEY SCH. DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50005100832",
    },
    {
        "school": "PALESTINE-WHEATLEY SENIOR HIGH",
        "district": "PALESTINE-WHEATLEY SCH. DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50005100833",
    },
    {
        "school": "FORREST CITY HIGH SCHOOL",
        "district": "FORREST CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50627000344",
    },
    {
        "school": "FORREST CITY JR. HIGH",
        "district": "FORREST CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50627000345",
    },
    {
        "school": "STEWART ELEMENTARY SCHOOL",
        "district": "FORREST CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50627000350",
    },
    {
        "school": "LINCOLN ACADEMY",
        "district": "FORREST CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50627001185",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "FORREST CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50627001425",
    },
    {
        "school": "OZARK MIDDLE SCHOOL",
        "district": "OZARK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51101001090",
    },
    {
        "school": "LAVACA MIDDLE SCHOOL",
        "district": "LAVACA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50873000663",
    },
    {
        "school": "MANSFIELD HIGH SCHOOL",
        "district": "MANSFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50933001036",
    },
    {
        "school": "CHARLESTON ELEMENTARY SCHOOL",
        "district": "CHARLESTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50420000157",
    },
    {
        "school": "CHARLESTON HIGH SCHOOL",
        "district": "CHARLESTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50420000158",
    },
    {
        "school": "COUNTY LINE ELEMENTARY SCHOOL",
        "district": "COUNTY LINE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50474000197",
    },
    {
        "school": "COUNTY LINE HIGH SCHOOL",
        "district": "COUNTY LINE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50474000198",
    },
    {
        "school": "ELGIN B. MILTON ELEM. SCHOOL",
        "district": "OZARK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51101000829",
    },
    {
        "school": "OZARK HIGH SCHOOL",
        "district": "OZARK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51101000830",
    },
    {
        "school": "ALMA INTERMEDIATE SCHOOL",
        "district": "ALMA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50225000003",
    },
    {
        "school": "ALMA HIGH SCHOOL",
        "district": "ALMA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50225000004",
    },
    {
        "school": "ALMA MIDDLE SCHOOL",
        "district": "ALMA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50225000005",
    },
    {
        "school": "ALMA PRIMARY SCHOOL",
        "district": "ALMA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50225001350",
    },
    {
        "school": "CEDARVILLE ELEMENTARY SCHOOL",
        "district": "CEDARVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50408000149",
    },
    {
        "school": "CEDARVILLE HIGH SCHOOL",
        "district": "CEDARVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50408000150",
    },
    {
        "school": "CEDARVILLE MIDDLE SCHOOL",
        "district": "CEDARVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50408000332",
    },
    {
        "school": "MOUNTAINBURG MIDDLE SCHOOL",
        "district": "MOUNTAINBURG SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51026000372",
    },
    {
        "school": "MOUNTAINBURG ELEMENTARY SCHOOL",
        "district": "MOUNTAINBURG SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51026000750",
    },
    {
        "school": "MOUNTAINBURG HIGH SCHOOL",
        "district": "MOUNTAINBURG SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51026000751",
    },
    {
        "school": "MARVIN PRIMARY SCHOOL",
        "district": "MULBERRY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51029000752",
    },
    {
        "school": "MULBERRY HIGH SCHOOL",
        "district": "MULBERRY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51029000753",
    },
    {
        "school": "RENA ELEMENTARY SCHOOL",
        "district": "VAN BUREN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51341000061",
    },
    {
        "school": "NORTHRIDGE MIDDLE SCHOOL",
        "district": "VAN BUREN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51341000393",
    },
    {
        "school": "CITY HEIGHTS ELEMENTARY SCHOOL",
        "district": "VAN BUREN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51341001096",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "VAN BUREN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51341001097",
    },
    {
        "school": "KING ELEMENTARY SCHOOL",
        "district": "VAN BUREN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51341001099",
    },
    {
        "school": "BUTTERFIELD JUNIOR HIGH SCHOOL",
        "district": "VAN BUREN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51341001102",
    },
    {
        "school": "VAN BUREN HIGH SCHOOL",
        "district": "VAN BUREN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51341001103",
    },
    {
        "school": "JAMES R. TATE ELEM. SCHOOL",
        "district": "VAN BUREN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51341001369",
    },
    {
        "school": "PARKVIEW ELEMENTARY SCHOOL",
        "district": "VAN BUREN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51341001371",
    },
    {
        "school": "MANSFIELD ELEMENTARY SCHOOL",
        "district": "MANSFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50933000670",
    },
    {
        "school": "MANSFIELD MIDDLE SCHOOL",
        "district": "MANSFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50933000671",
    },
    {
        "school": "WESTARK TECHNICAL CENTER",
        "district": "WESTARK TECHNICAL CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50005300626",
    },
    {
        "school": "BALLMAN ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000351",
    },
    {
        "school": "BARLING ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000352",
    },
    {
        "school": "BEARD ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000353",
    },
    {
        "school": "BELLE POINT ALTERNATIVE CENTER",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AR",
        "nces_id": "50633000354",
    },
    {
        "school": "BONNEVILLE ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000355",
    },
    {
        "school": "CARNALL ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000356",
    },
    {
        "school": "CAVANAUGH ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000357",
    },
    {
        "school": "L. A. CHAFFIN JR. HIGH SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000358",
    },
    {
        "school": "ELMER H. COOK ELEM. SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000359",
    },
    {
        "school": "WILLIAM O. DARBY JR. HIGH SCH.",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000360",
    },
    {
        "school": "FAIRVIEW ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000363",
    },
    {
        "school": "HOWARD ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000364",
    },
    {
        "school": "DORA KIMMONS JR. HIGH SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000365",
    },
    {
        "school": "HARRY C. MORRISON ELEM. SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000366",
    },
    {
        "school": "NORTHSIDE HIGH SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000367",
    },
    {
        "school": "RAYMOND F. ORR ELEM. SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000368",
    },
    {
        "school": "ALBERT PIKE ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000370",
    },
    {
        "school": "RAMSEY JUNIOR HIGH SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000371",
    },
    {
        "school": "SOUTHSIDE HIGH SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000373",
    },
    {
        "school": "SPRADLING ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000374",
    },
    {
        "school": "SUNNYMEDE ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000375",
    },
    {
        "school": "SUTTON ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000376",
    },
    {
        "school": "TRUSTY ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000377",
    },
    {
        "school": "JOHN P. WOODS ELEM. SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633000378",
    },
    {
        "school": "TILLES ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633001251",
    },
    {
        "school": "EUPER LANE ELEMENTARY SCHOOL",
        "district": "FORT SMITH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50633001358",
    },
    {
        "school": "WESTWOOD ELEMENTARY SCHOOL",
        "district": "GREENWOOD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50699000179",
    },
    {
        "school": "GREENWOOD HIGH SCHOOL",
        "district": "GREENWOOD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50699000424",
    },
    {
        "school": "GREENWOOD JUNIOR HIGH SCHOOL",
        "district": "GREENWOOD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50699000425",
    },
    {
        "school": "EAST HILLS MIDDLE SCHOOL",
        "district": "GREENWOOD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50699000463",
    },
    {
        "school": "HACKETT HIGH SCHOOL",
        "district": "HACKETT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50717000435",
    },
    {
        "school": "HACKETT ELEMENTARY SCHOOL",
        "district": "HACKETT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50717000436",
    },
    {
        "school": "LAVACA ELEMENTARY SCHOOL",
        "district": "LAVACA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50873000586",
    },
    {
        "school": "LAVACA HIGH SCHOOL",
        "district": "LAVACA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50873000587",
    },
    {
        "school": "BERGMAN MIDDLE SCHOOL",
        "district": "BERGMAN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50309001089",
    },
    {
        "school": "VALLEY SPRINGS MIDDLE SCHOOL",
        "district": "VALLEY SPRINGS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51335000678",
    },
    {
        "school": "OARK ELEMENTARY SCHOOL",
        "district": "JASPER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50824000810",
    },
    {
        "school": "OARK HIGH SCHOOL",
        "district": "JASPER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50824000811",
    },
    {
        "school": "KINGSTON ELEMENTARY SCHOOL",
        "district": "JASPER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50824000563",
    },
    {
        "school": "KINGSTON HIGH SCHOOL",
        "district": "JASPER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50824000564",
    },
    {
        "school": "NORTH ARK COLLEGE SECONDARY CENTER",
        "district": "NORTH ARKANSAS COLLEGE SECONDARY CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50006000542",
    },
    {
        "school": "ALPENA ELEMENTARY SCHOOL",
        "district": "ALPENA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50228000006",
    },
    {
        "school": "ALPENA HIGH SCHOOL",
        "district": "ALPENA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50228000007",
    },
    {
        "school": "BERGMAN ELEMENTARY SCHOOL",
        "district": "BERGMAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50309000077",
    },
    {
        "school": "BERGMAN HIGH SCHOOL",
        "district": "BERGMAN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50309000078",
    },
    {
        "school": "LEAD HILL ELEMENTARY SCHOOL",
        "district": "LEAD HILL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50342000102",
    },
    {
        "school": "LEAD HILL HIGH SCHOOL",
        "district": "LEAD HILL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50342000103",
    },
    {
        "school": "EAGLE HEIGHTS ELEM. SCHOOL",
        "district": "HARRISON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50738000449",
    },
    {
        "school": "FOREST HEIGHTS ELEM. SCHOOL",
        "district": "HARRISON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50738000450",
    },
    {
        "school": "HARRISON HIGH SCHOOL",
        "district": "HARRISON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50738000452",
    },
    {
        "school": "SKYLINE HEIGHTS ELEM. SCHOOL",
        "district": "HARRISON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50738000454",
    },
    {
        "school": "HARRISON MIDDLE SCHOOL",
        "district": "HARRISON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50738001397",
    },
    {
        "school": "OMAHA ELEMENTARY SCHOOL",
        "district": "OMAHA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51092000820",
    },
    {
        "school": "OMAHA HIGH SCHOOL",
        "district": "OMAHA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51092000821",
    },
    {
        "school": "VALLEY SPRINGS HIGH SCHOOL",
        "district": "VALLEY SPRINGS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51335001093",
    },
    {
        "school": "VALLEY SPRINGS ELEM. SCHOOL",
        "district": "VALLEY SPRINGS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51335001224",
    },
    {
        "school": "JASPER ELEMENTARY SCHOOL",
        "district": "JASPER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50824000544",
    },
    {
        "school": "JASPER HIGH SCHOOL",
        "district": "JASPER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50824000545",
    },
    {
        "school": "BLEVINS ELEMENTARY SCHOOL",
        "district": "BLEVINS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50330000089",
    },
    {
        "school": "BLEVINS HIGH SCHOOL",
        "district": "BLEVINS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50330000090",
    },
    {
        "school": "WM. JEFFERSON CLINTON PRIMARY",
        "district": "HOPE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50784000025",
    },
    {
        "school": "BERYL HENRY UPPER ELEM. SCHOOL",
        "district": "HOPE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50784000495",
    },
    {
        "school": "HOPE HIGH SCHOOL",
        "district": "HOPE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50784000498",
    },
    {
        "school": "YERGER JUNIOR HIGH SCHOOL",
        "district": "HOPE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50784000500",
    },
    {
        "school": "HOPE ACADEMY",
        "district": "HOPE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "AR",
        "nces_id": "50784000805",
    },
    {
        "school": "SPRING HILL ELEMENTARY SCHOOL",
        "district": "SPRING HILL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51263001017",
    },
    {
        "school": "SPRING HILL HIGH SCHOOL",
        "district": "SPRING HILL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51263001018",
    },
    {
        "school": "NEVADA ELEMENTARY SCHOOL",
        "district": "NEVADA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50003001398",
    },
    {
        "school": "NEVADA HIGH  SCHOOL",
        "district": "NEVADA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50003001405",
    },
    {
        "school": "PRESCOTT ELEMENTARY SCHOOL",
        "district": "PRESCOTT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51182000898",
    },
    {
        "school": "PRESCOTT HIGH SCHOOL",
        "district": "PRESCOTT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51182000899",
    },
    {
        "school": "NATIONAL PARK TECHNOLOGY CENTER",
        "district": "NATIONAL PARK TECHNOLOGY CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50005700579",
    },
    {
        "school": "CUTTER-MORNING STAR ELEM. SCH.",
        "district": "CUTTER-MORNING STAR SCH. DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50486000209",
    },
    {
        "school": "CUTTER-MORNING STAR HIGH SCH.",
        "district": "CUTTER-MORNING STAR SCH. DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50486000210",
    },
    {
        "school": "FOUNTAIN LAKE ELEMENTARY",
        "district": "FOUNTAIN LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50642000383",
    },
    {
        "school": "FOUNTAIN LAKE CHARTER HIGH SCHOOL",
        "district": "FOUNTAIN LAKE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50642000384",
    },
    {
        "school": "GARDNER MAGNET SCHOOL",
        "district": "HOT SPRINGS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50789000506",
    },
    {
        "school": "HOT SPRINGS WORLD CLASS HIGH SCHOOL",
        "district": "HOT SPRINGS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50789000509",
    },
    {
        "school": "OAKLAWN MAGNET SCHOOL",
        "district": "HOT SPRINGS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50789000511",
    },
    {
        "school": "PARK MAGNET SCHOOL",
        "district": "HOT SPRINGS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50789000512",
    },
    {
        "school": "HOT SPRINGS JUNIOR ACADEMY",
        "district": "HOT SPRINGS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50789000514",
    },
    {
        "school": "LANGSTON MAGNET SCHOOL",
        "district": "HOT SPRINGS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50789001187",
    },
    {
        "school": "JESSIEVILLE ELEMENTARY SCHOOL",
        "district": "JESSIEVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50792000515",
    },
    {
        "school": "JESSIEVILLE HIGH SCHOOL",
        "district": "JESSIEVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50792000516",
    },
    {
        "school": "LAKE HAMILTON MIDDLE SCHOOL",
        "district": "LAKE HAMILTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50861000138",
    },
    {
        "school": "LAKE HAMILTON PRIMARY SCHOOL",
        "district": "LAKE HAMILTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50861000572",
    },
    {
        "school": "LAKE HAMILTON ELEMENTARY SCH",
        "district": "LAKE HAMILTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50861000573",
    },
    {
        "school": "LAKE HAMILTON JR. HIGH SCHOOL",
        "district": "LAKE HAMILTON SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50861000574",
    },
    {
        "school": "LAKE HAMILTON HIGH SCHOOL",
        "district": "LAKE HAMILTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50861000575",
    },
    {
        "school": "LAKE HAMILTON INTERM. SCHOOL",
        "district": "LAKE HAMILTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50861001234",
    },
    {
        "school": "LAKESIDE MIDDLE SCHOOL",
        "district": "LAKESIDE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50867000394",
    },
    {
        "school": "LAKESIDE PRIMARY SCHOOL",
        "district": "LAKESIDE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50867000580",
    },
    {
        "school": "LAKESIDE INTERMEDIATE SCHOOL",
        "district": "LAKESIDE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50867001401",
    },
    {
        "school": "MOUNTAIN PINE ELEM. SCHOOL",
        "district": "MOUNTAIN PINE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51017000745",
    },
    {
        "school": "MOUNTAIN PINE HIGH SCHOOL",
        "district": "MOUNTAIN PINE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51017000746",
    },
    {
        "school": "EARLY CHILDHOOD LEARNING CNTR",
        "district": "JONESBORO SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50828000888",
    },
    {
        "school": "FOX MEADOW INTERMEDIATE CENTER",
        "district": "NETTLETON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51044000889",
    },
    {
        "school": "TRUMANN HIGH SCHOOL",
        "district": "TRUMANN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004701079",
    },
    {
        "school": "CEDAR PARK ELEMENTARY SCHOOL",
        "district": "TRUMANN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004701081",
    },
    {
        "school": "LEPANTO ELEMENTARY",
        "district": "EAST POINSETT CO. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004801345",
    },
    {
        "school": "TYRONZA ELEMENTARY",
        "district": "EAST POINSETT CO. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004801346",
    },
    {
        "school": "EAST POINSETT CO. HIGH SCHOOL",
        "district": "EAST POINSETT CO. SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004801348",
    },
    {
        "school": "HARRISBURG MIDDLE SCHOOL",
        "district": "HARRISBURG SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50735000300",
    },
    {
        "school": "HARRISBURG ELEMENTARY SCHOOL",
        "district": "HARRISBURG SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50735000446",
    },
    {
        "school": "HARRISBURG COLLEGE & CAREER PREPARATORY SCHOOL",
        "district": "HARRISBURG SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50735000447",
    },
    {
        "school": "MARKED TREE HIGH SCHOOL",
        "district": "MARKED TREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50942000687",
    },
    {
        "school": "MARKED TREE ELEMENTARY SCHOOL",
        "district": "MARKED TREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50942000689",
    },
    {
        "school": "RIVERSIDE EAST ELEM. SCHOOL",
        "district": "RIVERSIDE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001201285",
    },
    {
        "school": "RIVERSIDE WEST ELEM. SCHOOL",
        "district": "RIVERSIDE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001201287",
    },
    {
        "school": "BAY ELEMENTARY SCHOOL",
        "district": "BAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50282000050",
    },
    {
        "school": "BAY HIGH SCHOOL",
        "district": "BAY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50282000051",
    },
    {
        "school": "BROOKLAND ELEMENTARY SCHOOL",
        "district": "BROOKLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50364000115",
    },
    {
        "school": "BROOKLAND HIGH SCHOOL",
        "district": "BROOKLAND SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50364000116",
    },
    {
        "school": "BUFFALO IS. CENTRAL HS",
        "district": "BUFFALO IS. CENTRAL SCH. DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50371001271",
    },
    {
        "school": "WESTSIDE HIGH SCHOOL",
        "district": "WESTSIDE CONS. SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50402000146",
    },
    {
        "school": "WESTSIDE MIDDLE SCHOOL",
        "district": "WESTSIDE CONS. SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50402000269",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "WESTSIDE CONS. SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50402001353",
    },
    {
        "school": "ANNIE CAMP JR. HIGH SCHOOL",
        "district": "JONESBORO SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50828000547",
    },
    {
        "school": "DOUGLAS MACARTHUR JHS",
        "district": "JONESBORO SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50828000548",
    },
    {
        "school": "INTERNATIONAL STUDIES MAGNET",
        "district": "JONESBORO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50828000549",
    },
    {
        "school": "VISUAL & PERFORMING ART MAGNET",
        "district": "JONESBORO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50828000550",
    },
    {
        "school": "THE ACADEMIES AT JONESBORO HIGH SCHOOL",
        "district": "JONESBORO SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50828000551",
    },
    {
        "school": "MATH & SCIENCE MAGNET SCHOOL",
        "district": "JONESBORO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50828000552",
    },
    {
        "school": "HEALTH/WELLNESS ENVI MAGNET",
        "district": "JONESBORO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50828000553",
    },
    {
        "school": "MICROSOCIETY MAGNET SCHOOL",
        "district": "JONESBORO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50828000554",
    },
    {
        "school": "JONESBORO VOCATIONAL CENTER",
        "district": "JONESBORO SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50828000568",
    },
    {
        "school": "KINDERGARTEN CENTER",
        "district": "JONESBORO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50828001362",
    },
    {
        "school": "UNIVERSITY HEIGHTS INTERMEDIATE CENTER",
        "district": "NETTLETON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51044000060",
    },
    {
        "school": "FOX MEADOW ELEMENTARY",
        "district": "NETTLETON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51044000761",
    },
    {
        "school": "NETTLETON HIGH SCHOOL",
        "district": "NETTLETON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51044000762",
    },
    {
        "school": "UNIVERSITY HGTS. ELEM. SCHOOL",
        "district": "NETTLETON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51044000764",
    },
    {
        "school": "NETTLETON JUNIOR HIGH SCHOOL",
        "district": "NETTLETON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51044000875",
    },
    {
        "school": "VALLEY VIEW ELEMENTARY SCHOOL",
        "district": "VALLEY VIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51338001094",
    },
    {
        "school": "VALLEY VIEW HIGH SCHOOL",
        "district": "VALLEY VIEW SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51338001095",
    },
    {
        "school": "BUFFALO IS. CENTRAL EAST ELEM.",
        "district": "BUFFALO IS. CENTRAL SCH. DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50371001269",
    },
    {
        "school": "RUTH DOYLE INTERMEDIATE SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459000937",
    },
    {
        "school": "ACADEMIC CENTER FOR EXCELLENCE",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AR",
        "nces_id": "50375001019",
    },
    {
        "school": "MAUMELLE CHARTER HIGH SCHOOL",
        "district": "ACADEMICS PLUS CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50005900741",
    },
    {
        "school": "LISA ACADEMY",
        "district": "LISA ACADEMY CHARTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007401030",
    },
    {
        "school": "LISA ACADEMY HIGH",
        "district": "LISA ACADEMY CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007401107",
    },
    {
        "school": "RIDGEROAD ELEMENTARY SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068000729",
    },
    {
        "school": "MAUMELLE MIDDLE SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185001106",
    },
    {
        "school": "HARMONY GROVE MIDDLE SCHOOL",
        "district": "HARMONY GROVE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50732000661",
    },
    {
        "school": "POYEN ELEMENTARY SCHOOL",
        "district": "POYEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51173000892",
    },
    {
        "school": "POYEN HIGH SCHOOL",
        "district": "POYEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51173000893",
    },
    {
        "school": "ANNE WATSON ELEMENTARY SCHOOL",
        "district": "EAST END SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50558000267",
    },
    {
        "school": "BIGELOW HIGH SCHOOL",
        "district": "EAST END SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50558000268",
    },
    {
        "school": "PERRYVILLE ELEMENTARY SCHOOL",
        "district": "PERRYVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51134000849",
    },
    {
        "school": "PERRYVILLE HIGH SCHOOL",
        "district": "PERRYVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51134000850",
    },
    {
        "school": "THEODORE JONES ELEM. SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459000081",
    },
    {
        "school": "JIM STONE ELEMENTARY SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459000135",
    },
    {
        "school": "CONWAY JUNIOR HIGH SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459000182",
    },
    {
        "school": "CARL STUART MIDDLE SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459000183",
    },
    {
        "school": "CONWAY HIGH WEST",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459000184",
    },
    {
        "school": "ELLEN SMITH ELEMENTARY SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459000185",
    },
    {
        "school": "IDA BURNS ELEMENTARY SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459000186",
    },
    {
        "school": "BOB COURTWAY MIDDLE SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459000333",
    },
    {
        "school": "CONWAY VOCATIONAL CENTER",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50459000571",
    },
    {
        "school": "JULIA LEE MOORE ELEM. SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459001183",
    },
    {
        "school": "FLORENCE MATTISON ELEM. SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459001248",
    },
    {
        "school": "MARGUERITE VANN ELEM. SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459001355",
    },
    {
        "school": "GREENBRIER JUNIOR HIGH SCHOOL",
        "district": "GREENBRIER SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50690000270",
    },
    {
        "school": "GREENBRIER EASTSIDE ELEMENTARY",
        "district": "GREENBRIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50690000417",
    },
    {
        "school": "GREENBRIER HIGH SCHOOL",
        "district": "GREENBRIER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50690000418",
    },
    {
        "school": "GREENBRIER MIDDLE SCHOOL",
        "district": "GREENBRIER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50690001359",
    },
    {
        "school": "GREENBRIER WESTSIDE ELEMENTARY",
        "district": "GREENBRIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50690001429",
    },
    {
        "school": "GUY-PERKINS ELEMENTARY SCHOOL",
        "district": "GUY-PERKINS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50714000433",
    },
    {
        "school": "GUY-PERKINS HIGH SCHOOL",
        "district": "GUY-PERKINS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50714000434",
    },
    {
        "school": "MAYFLOWER MIDDLE SCHOOL",
        "district": "MAYFLOWER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50954000437",
    },
    {
        "school": "MAYFLOWER ELEMENTARY SCHOOL",
        "district": "MAYFLOWER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50954000697",
    },
    {
        "school": "MAYFLOWER HIGH SCHOOL",
        "district": "MAYFLOWER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50954000698",
    },
    {
        "school": "MT. VERNON/ENOLA ELEM. SCHOOL",
        "district": "MT. VERNON/ENOLA SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51008000738",
    },
    {
        "school": "MT. VERNON/ENOLA HIGH SCHOOL",
        "district": "MT. VERNON/ENOLA SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51008000739",
    },
    {
        "school": "VILONIA MIDDLE SCHOOL",
        "district": "VILONIA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51353000137",
    },
    {
        "school": "VILONIA ELEMENTARY SCHOOL",
        "district": "VILONIA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51353001109",
    },
    {
        "school": "VILONIA HIGH SCHOOL",
        "district": "VILONIA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51353001110",
    },
    {
        "school": "VILONIA PRIMARY SCHOOL",
        "district": "VILONIA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51353001430",
    },
    {
        "school": "SHERIDAN INTERMEDIATE SCHOOL",
        "district": "SHERIDAN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001500097",
    },
    {
        "school": "SHERIDAN ELEMENTARY SCHOOL",
        "district": "SHERIDAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001500996",
    },
    {
        "school": "SHERIDAN HIGH SCHOOL",
        "district": "SHERIDAN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001500997",
    },
    {
        "school": "SHERIDAN MIDDLE SCHOOL",
        "district": "SHERIDAN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001500998",
    },
    {
        "school": "CABOT HIGH SCHOOL",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375000123",
    },
    {
        "school": "EASTSIDE ELEMENTARY SCHOOL",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375000124",
    },
    {
        "school": "WARD CENTRAL ELEMENTARY",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375000170",
    },
    {
        "school": "CABOT MIDDLE SCHOOL SOUTH",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375000173",
    },
    {
        "school": "CABOT JUNIOR HIGH NORTH",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375000399",
    },
    {
        "school": "CABOT MIDDLE SCHOOL NORTH",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375000809",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375001181",
    },
    {
        "school": "CABOT JUNIOR HIGH SOUTH",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375001182",
    },
    {
        "school": "SOUTHSIDE ELEMENTARY SCHOOL",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375001351",
    },
    {
        "school": "NORTHSIDE ELEMENTARY SCHOOL",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375001375",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375001431",
    },
    {
        "school": "CARLISLE ELEMENTARY SCHOOL",
        "district": "CARLISLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50396000139",
    },
    {
        "school": "CARLISLE HIGH SCHOOL",
        "district": "CARLISLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50396000140",
    },
    {
        "school": "ENGLAND ELEMENTARY SCHOOL",
        "district": "ENGLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50585000295",
    },
    {
        "school": "ENGLAND HIGH SCHOOL",
        "district": "ENGLAND SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50585000296",
    },
    {
        "school": "LONOKE ELEMENTARY SCHOOL",
        "district": "LONOKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50906000641",
    },
    {
        "school": "LONOKE HIGH SCHOOL",
        "district": "LONOKE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50906000642",
    },
    {
        "school": "LONOKE MIDDLE SCHOOL",
        "district": "LONOKE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50906000643",
    },
    {
        "school": "LONOKE PRIMARY SCHOOL",
        "district": "LONOKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50906000644",
    },
    {
        "school": "EAST END ELEMENTARY SCHOOL",
        "district": "SHERIDAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001500995",
    },
    {
        "school": "ARK. SCHOOL FOR THE BLIND ELEM",
        "district": "ARK. SCHOOL FOR THE BLIND",
        "level": "Elementary",
        "type": "Special education school",
        "state": "AR",
        "nces_id": "50003501419",
    },
    {
        "school": "ARK. SCHOOL FOR THE BLIND H.S.",
        "district": "ARK. SCHOOL FOR THE BLIND",
        "level": "High",
        "type": "Special education school",
        "state": "AR",
        "nces_id": "50003501420",
    },
    {
        "school": "SALINE COUNTY CAREER CENTER",
        "district": "SALINE COUNTY VOCATIONAL CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50005800615",
    },
    {
        "school": "MAUMELLE CHARTER ELEMENTARY SCHOOL",
        "district": "ACADEMICS PLUS CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50005900603",
    },
    {
        "school": "MAGNESS CREEK ELEMENTARY",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375000125",
    },
    {
        "school": "M.L. KING MAGNET ELEM. SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000176",
    },
    {
        "school": "METROPOLITAN VO-TECH SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50900000453",
    },
    {
        "school": "BOOKER ARTS MAGNET ELEM. SCH.",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000604",
    },
    {
        "school": "BRADY ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000605",
    },
    {
        "school": "CARVER MAGNET ELEM. SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000606",
    },
    {
        "school": "CENTRAL HIGH SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000607",
    },
    {
        "school": "DUNBAR MAGNET MIDDLE SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000608",
    },
    {
        "school": "FAIR PARK EARLY CHILDHOOD CTR",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000609",
    },
    {
        "school": "FOREST PARK ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000611",
    },
    {
        "school": "GIBBS MAGNET ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000614",
    },
    {
        "school": "HALL HIGH SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000616",
    },
    {
        "school": "HENDERSON MIDDLE SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000617",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000619",
    },
    {
        "school": "MANN MAGNET MIDDLE SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000621",
    },
    {
        "school": "MCDERMOTT ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000622",
    },
    {
        "school": "MEADOWCLIFF ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000623",
    },
    {
        "school": "PARKVIEW MAGNET HIGH SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000627",
    },
    {
        "school": "PULASKI HEIGHTS MIDDLE SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000628",
    },
    {
        "school": "ROMINE INTERDIST. ELEM. SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000630",
    },
    {
        "school": "TERRY ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000633",
    },
    {
        "school": "WESTERN HILLS ELEM. SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000635",
    },
    {
        "school": "WILLIAMS MAGNET ELEM. SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000636",
    },
    {
        "school": "STEPHENS ELEMENTARY",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900000876",
    },
    {
        "school": "BALE ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001188",
    },
    {
        "school": "FULBRIGHT ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001189",
    },
    {
        "school": "PULASKI HEIGHTS ELEM. SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001190",
    },
    {
        "school": "ROCKEFELLER INCENTIVE ELEM.",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001217",
    },
    {
        "school": "BASELINE ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001378",
    },
    {
        "school": "DAVID O'DODD ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001381",
    },
    {
        "school": "MABELVALE ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001383",
    },
    {
        "school": "OTTER CREEK ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001384",
    },
    {
        "school": "WAKEFIELD ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001385",
    },
    {
        "school": "CLOVERDALE MIDDLE SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001387",
    },
    {
        "school": "MABELVALE MIDDLE SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001388",
    },
    {
        "school": "J.A. FAIR HIGH SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001389",
    },
    {
        "school": "MCCLELLAN MAGNET HIGH SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001390",
    },
    {
        "school": "WASHINGTON MAGNET ELEM. SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001409",
    },
    {
        "school": "AMBOY ELEMENTARY SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068000779",
    },
    {
        "school": "BOONE PARK ELEMENTARY SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068000783",
    },
    {
        "school": "CRESTWOOD ELEMENTARY SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068000784",
    },
    {
        "school": "GLENVIEW ELEMENTARY SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068000785",
    },
    {
        "school": "INDIAN HILLS ELEMENTARY SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068000786",
    },
    {
        "school": "LAKEWOOD ELEMENTARY SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068000787",
    },
    {
        "school": "LAKEWOOD MIDDLE SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068000788",
    },
    {
        "school": "MEADOW PARK ELEMENTARY SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068000792",
    },
    {
        "school": "REDWOOD PRE-SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068000800",
    },
    {
        "school": "SEVENTH STREET ELEM. SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068000804",
    },
    {
        "school": "CRYSTAL HILL ELEMENTARY",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000058",
    },
    {
        "school": "CLINTON ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000122",
    },
    {
        "school": "BAKER INTERDISTRICT ELEM. SCH.",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000903",
    },
    {
        "school": "CATO ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000906",
    },
    {
        "school": "COLLEGE STATION ELEM. SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000910",
    },
    {
        "school": "FULLER MIDDLE SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000914",
    },
    {
        "school": "HARRIS ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000916",
    },
    {
        "school": "JOE T. ROBINSON ELEM. SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000922",
    },
    {
        "school": "JOE T. ROBINSON HIGH SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000923",
    },
    {
        "school": "LANDMARK ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000927",
    },
    {
        "school": "LAWSON ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000928",
    },
    {
        "school": "OAK GROVE ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000933",
    },
    {
        "school": "SHERWOOD ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000939",
    },
    {
        "school": "SYLVAN HILLS ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000940",
    },
    {
        "school": "SYLVAN HILLS HIGH SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000941",
    },
    {
        "school": "SYLVAN HILLS MIDDLE SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000942",
    },
    {
        "school": "WILBUR D. MILLS HIGH SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185000945",
    },
    {
        "school": "OAKBROOKE ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185001239",
    },
    {
        "school": "PINE FOREST ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185001257",
    },
    {
        "school": "JOE T. ROBINSON MIDDLE SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185001258",
    },
    {
        "school": "BATES ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185001391",
    },
    {
        "school": "EAST END INTERMEDIATE SCHOOL",
        "district": "SHERIDAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001500275",
    },
    {
        "school": "BAUXITE HIGH SCHOOL",
        "district": "BAUXITE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50279000047",
    },
    {
        "school": "PINE HAVEN ELEMENTARY SCHOOL",
        "district": "BAUXITE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50279000048",
    },
    {
        "school": "ANGIE GRANT ELEMENTARY SCHOOL",
        "district": "BENTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50296000062",
    },
    {
        "school": "BENTON HIGH SCHOOL",
        "district": "BENTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50296000063",
    },
    {
        "school": "CALDWELL ELEMENTARY SCHOOL",
        "district": "BENTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50296000064",
    },
    {
        "school": "BENTON JUNIOR HIGH SCHOOL",
        "district": "BENTON SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50296000065",
    },
    {
        "school": "PERRIN ELEMENTARY SCHOOL",
        "district": "BENTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50296000066",
    },
    {
        "school": "RINGGOLD ELEMENTARY SCHOOL",
        "district": "BENTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50296000067",
    },
    {
        "school": "BENTON MIDDLE SCHOOL",
        "district": "BENTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50296000068",
    },
    {
        "school": "BRYANT HIGH SCHOOL",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369000118",
    },
    {
        "school": "BRYANT ELEMENTARY SCHOOL",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369000120",
    },
    {
        "school": "SALEM ELEMENTARY SCHOOL",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369000121",
    },
    {
        "school": "COLLEGEVILLE ELEMENTARY SCHOOL",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369000178",
    },
    {
        "school": "ROBERT L. DAVIS ELEM. SCHOOL",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369001407",
    },
    {
        "school": "SPRINGHILL ELEMENTARY SCHOOL",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369001439",
    },
    {
        "school": "BRYANT MIDDLE SCHOOL",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369001440",
    },
    {
        "school": "HARMONY GROVE HIGH SCHOOL",
        "district": "HARMONY GROVE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50732000444",
    },
    {
        "school": "WESTBROOK ELEMENTARY SCHOOL",
        "district": "HARMONY GROVE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50732000445",
    },
    {
        "school": "WALKER PRE-K CENTER",
        "district": "MAGNOLIA SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004401123",
    },
    {
        "school": "EMERSON ELEMENTARY SCHOOL",
        "district": "EMERSON-TAYLOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006800291",
    },
    {
        "school": "EMERSON HIGH SCHOOL",
        "district": "EMERSON-TAYLOR SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006800292",
    },
    {
        "school": "TAYLOR ELEMENTARY SCHOOL",
        "district": "EMERSON-TAYLOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006801062",
    },
    {
        "school": "TAYLOR HIGH SCHOOL",
        "district": "EMERSON-TAYLOR SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006801063",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "MAGNOLIA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004400653",
    },
    {
        "school": "EAST SIDE ELEMENTARY SCHOOL",
        "district": "MAGNOLIA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004400654",
    },
    {
        "school": "MAGNOLIA JR. HIGH SCHOOL",
        "district": "MAGNOLIA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004400655",
    },
    {
        "school": "MAGNOLIA HIGH SCHOOL",
        "district": "MAGNOLIA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004400656",
    },
    {
        "school": "MID-SOUTH COMM COLLEGE TECH CENTER",
        "district": "MID SOUTH COMMUNITY COLLEGE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50006300704",
    },
    {
        "school": "EARLE ELEMENTARY SCHOOL",
        "district": "EARLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50555000264",
    },
    {
        "school": "EARLE HIGH SCHOOL",
        "district": "EARLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50555000266",
    },
    {
        "school": "BRAGG ELEMENTARY SCHOOL",
        "district": "WEST MEMPHIS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50804000521",
    },
    {
        "school": "FAULK ELEMENTARY SCHOOL",
        "district": "WEST MEMPHIS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50804000522",
    },
    {
        "school": "EAST JUNIOR HIGH SCHOOL",
        "district": "WEST MEMPHIS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50804000523",
    },
    {
        "school": "MADDUX ELEMENTARY SCHOOL",
        "district": "WEST MEMPHIS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50804000525",
    },
    {
        "school": "RICHLAND ELEMENTARY SCHOOL",
        "district": "WEST MEMPHIS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50804000526",
    },
    {
        "school": "WEAVER ELEMENTARY SCHOOL",
        "district": "WEST MEMPHIS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50804000527",
    },
    {
        "school": "WEST JUNIOR HIGH SCHOOL",
        "district": "WEST MEMPHIS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50804000529",
    },
    {
        "school": "WONDER JUNIOR HIGH SCHOOL",
        "district": "WEST MEMPHIS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50804000532",
    },
    {
        "school": "HERBERT CARTER GLOBAL COMMUNITY MAGNET SCHOOL",
        "district": "MARION SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50939000681",
    },
    {
        "school": "MARION HIGH SCHOOL",
        "district": "MARION SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50939000682",
    },
    {
        "school": "MARION JUNIOR HIGH SCHOOL",
        "district": "MARION SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50939000683",
    },
    {
        "school": "MTN HOME HIGH CAREER ACADEMICS",
        "district": "MOUNTAIN HOME SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004300676",
    },
    {
        "school": "NELSON WILKS HERRON ELEMENTARY",
        "district": "MOUNTAIN HOME SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004300740",
    },
    {
        "school": "PINKSTON MIDDLE SCHOOL",
        "district": "MOUNTAIN HOME SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004300742",
    },
    {
        "school": "MOUNTAIN HOME KINDERGARTEN",
        "district": "MOUNTAIN HOME SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004301236",
    },
    {
        "school": "MOUNTAIN HOME JR. HIGH SCHOOL",
        "district": "MOUNTAIN HOME SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004301340",
    },
    {
        "school": "AMANDA GIST ELEMENTARY SCHOOL",
        "district": "COTTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50468000193",
    },
    {
        "school": "COTTER HIGH SCHOOL",
        "district": "COTTER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50468000194",
    },
    {
        "school": "ARRIE GOFORTH ELEMENTARY SCHOOL",
        "district": "NORFORK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51056000773",
    },
    {
        "school": "NORFORK HIGH SCHOOL",
        "district": "NORFORK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51056000774",
    },
    {
        "school": "GREENE CO. TECH PRIMARY SCHOOL",
        "district": "GREENE CO. TECH SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51308000963",
    },
    {
        "school": "MARMADUKE ELEMENTARY SCHOOL",
        "district": "MARMADUKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001600690",
    },
    {
        "school": "MARMADUKE HIGH SCHOOL",
        "district": "MARMADUKE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001600691",
    },
    {
        "school": "PARAGOULD JUNIOR HIGH",
        "district": "PARAGOULD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001700395",
    },
    {
        "school": "BALDWIN ELEMENTARY SCHOOL",
        "district": "PARAGOULD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001701289",
    },
    {
        "school": "WOODROW WILSON ELEM. SCHOOL",
        "district": "PARAGOULD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001701292",
    },
    {
        "school": "PARAGOULD HIGH SCHOOL",
        "district": "PARAGOULD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001701295",
    },
    {
        "school": "OAK GROVE MIDDLE SCHOOL",
        "district": "PARAGOULD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001701296",
    },
    {
        "school": "GREENE CTY TECH ELEM. SCHOOL",
        "district": "GREENE CO. TECH SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51308000015",
    },
    {
        "school": "GREENE CO. TECH HIGH SCHOOL",
        "district": "GREENE CO. TECH SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51308001066",
    },
    {
        "school": "GREENE CO. TECH INTERM. SCHOOL",
        "district": "GREENE CO. TECH SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51308001067",
    },
    {
        "school": "GREEN CO. TECH JR. HIGH SCHOOL",
        "district": "GREENE CO. TECH SCHOOL DIST.",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51308001368",
    },
    {
        "school": "RISON ELEMENTARY SCHOOL",
        "district": "CLEVELAND COUNTY SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006700950",
    },
    {
        "school": "RISON HIGH SCHOOL",
        "district": "CLEVELAND COUNTY SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006700951",
    },
    {
        "school": "WOODLAWN ELEMENTARY SCHOOL",
        "district": "WOODLAWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51440001171",
    },
    {
        "school": "WOODLAWN HIGH SCHOOL",
        "district": "WOODLAWN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51440001172",
    },
    {
        "school": "BROWN ELEMENTARY SCHOOL",
        "district": "STAR CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002801041",
    },
    {
        "school": "STAR CITY HIGH SCHOOL",
        "district": "STAR CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002801042",
    },
    {
        "school": "STAR CITY MIDDLE SCHOOL",
        "district": "STAR CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002801043",
    },
    {
        "school": "BROADMOOR ELEMENTARY SCHOOL",
        "district": "PINE BLUFF SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002600857",
    },
    {
        "school": "PINE BLUFF HIGH SCHOOL",
        "district": "PINE BLUFF SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002600867",
    },
    {
        "school": "THIRTY-FOURTH AVE. ELEM. SCH.",
        "district": "PINE BLUFF SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002600872",
    },
    {
        "school": "JACK ROBEY JR. HIGH SCHOOL",
        "district": "PINE BLUFF SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002601338",
    },
    {
        "school": "MATTHEWS ELEMENTARY SCHOOL",
        "district": "DOLLARWAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50541000251",
    },
    {
        "school": "ROBERT F MOREHEAD MIDDLE SCHOO",
        "district": "DOLLARWAY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50541000252",
    },
    {
        "school": "DOLLARWAY HIGH SCHOOL",
        "district": "DOLLARWAY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50541000253",
    },
    {
        "school": "COLEMAN ELEMENTARY SCHOOL",
        "district": "WATSON CHAPEL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51393001136",
    },
    {
        "school": "EDGEWOOD ELEMENTARY SCHOOL",
        "district": "WATSON CHAPEL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51393001137",
    },
    {
        "school": "L. L. OWEN ELEMENTARY SCHOOL",
        "district": "WATSON CHAPEL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51393001138",
    },
    {
        "school": "WATSON CHAPEL HIGH SCHOOL",
        "district": "WATSON CHAPEL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51393001140",
    },
    {
        "school": "WATSON CHAPEL JR. HIGH SCHOOL",
        "district": "WATSON CHAPEL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51393001212",
    },
    {
        "school": "HARDIN ELEMENTARY SCHOOL",
        "district": "WHITE HALL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51414001152",
    },
    {
        "school": "MOODY ELEMENTARY SCHOOL",
        "district": "WHITE HALL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51414001153",
    },
    {
        "school": "TAYLOR ELEMENTARY SCHOOL",
        "district": "WHITE HALL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51414001155",
    },
    {
        "school": "WHITE HALL HIGH SCHOOL",
        "district": "WHITE HALL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51414001156",
    },
    {
        "school": "WHITE HALL JUNIOR HIGH SCHOOL",
        "district": "WHITE HALL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51414001247",
    },
    {
        "school": "GANDY ELEMENTARY SCHOOL",
        "district": "WHITE HALL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51414001262",
    },
    {
        "school": "OLA ELEMENTARY SCHOOL",
        "district": "TWO RIVERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007900818",
    },
    {
        "school": "ATKINS ELEMENTARY SCHOOL",
        "district": "ATKINS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50261000032",
    },
    {
        "school": "ATKINS HIGH SCHOOL",
        "district": "ATKINS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50261000033",
    },
    {
        "school": "ATKINS MIDDLE SCHOOL",
        "district": "ATKINS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50261000438",
    },
    {
        "school": "DOVER ELEMENTARY SCHOOL",
        "district": "DOVER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50543000256",
    },
    {
        "school": "DOVER HIGH SCHOOL",
        "district": "DOVER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50543000257",
    },
    {
        "school": "DOVER MIDDLE SCHOOL",
        "district": "DOVER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50543000439",
    },
    {
        "school": "HECTOR ELEMENTARY SCHOOL",
        "district": "HECTOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50762000471",
    },
    {
        "school": "HECTOR HIGH SCHOOL",
        "district": "HECTOR SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50762000472",
    },
    {
        "school": "POTTSVILLE MIDDLE GRADE",
        "district": "POTTSVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51170000401",
    },
    {
        "school": "POTTSVILLE ELEMENTARY SCHOOL",
        "district": "POTTSVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51170000890",
    },
    {
        "school": "POTTSVILLE HIGH SCHOOL",
        "district": "POTTSVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51170000891",
    },
    {
        "school": "RUSSELLVILLE UPPER ELEM. SCH.",
        "district": "RUSSELLVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51206000175",
    },
    {
        "school": "CRAWFORD ELEMENTARY SCHOOL",
        "district": "RUSSELLVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51206000966",
    },
    {
        "school": "DWIGHT ELEMENTARY SCHOOL",
        "district": "RUSSELLVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51206000967",
    },
    {
        "school": "RUSSELLVILLE JR. HIGH SCHOOL",
        "district": "RUSSELLVILLE SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51206000968",
    },
    {
        "school": "LONDON ELEMENTARY SCHOOL",
        "district": "RUSSELLVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51206000969",
    },
    {
        "school": "OAKLAND HEIGHTS ELEM. SCHOOL",
        "district": "RUSSELLVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51206000970",
    },
    {
        "school": "RUSSELLVILLE HIGH SCHOOL",
        "district": "RUSSELLVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51206000971",
    },
    {
        "school": "RUSSELLVILLE MIDDLE SCHOOL",
        "district": "RUSSELLVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51206000972",
    },
    {
        "school": "SEQUOYAH ELEMENTARY SCHOOL",
        "district": "RUSSELLVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51206000973",
    },
    {
        "school": "CENTER VALLEY ELEM. SCHOOL",
        "district": "RUSSELLVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51206001376",
    },
    {
        "school": "WESTERN YELL CO. ELEM. SCHOOL",
        "district": "WESTERN YELL CO. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004101312",
    },
    {
        "school": "WESTERN YELL CO. HIGH SCHOOL",
        "district": "WESTERN YELL CO. SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004101315",
    },
    {
        "school": "S.C. TUCKER ELEMENTARY SCHOOL",
        "district": "DANVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50489000211",
    },
    {
        "school": "DANVILLE HIGH SCHOOL",
        "district": "DANVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50489000212",
    },
    {
        "school": "DARDANELLE ELEMENTARY SCHOOL",
        "district": "DARDANELLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50493000213",
    },
    {
        "school": "DARDANELLE HIGH SCHOOL",
        "district": "DARDANELLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50493000214",
    },
    {
        "school": "DARDANELLE MIDDLE SCHOOL",
        "district": "DARDANELLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50493000215",
    },
    {
        "school": "DARDANELLE PRIMARY SCHOOL",
        "district": "DARDANELLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50493000243",
    },
    {
        "school": "ASU AREA CAREER CENTER",
        "district": "ASU AREA CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50005600657",
    },
    {
        "school": "H.L. LUBKER ELEMENTARY SCHOOL",
        "district": "BALD KNOB SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50270000037",
    },
    {
        "school": "BALD KNOB HIGH SCHOOL",
        "district": "BALD KNOB SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50270000038",
    },
    {
        "school": "BALD KNOB MIDDLE SCHOOL",
        "district": "BALD KNOB SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50270000128",
    },
    {
        "school": "BEEBE ELEMENTARY SCHOOL",
        "district": "BEEBE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50288000054",
    },
    {
        "school": "BEEBE JUNIOR HIGH SCHOOL",
        "district": "BEEBE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50288000055",
    },
    {
        "school": "BEEBE HIGH SCHOOL",
        "district": "BEEBE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50288000057",
    },
    {
        "school": "BEEBE MIDDLE SCHOOL",
        "district": "BEEBE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50288000474",
    },
    {
        "school": "BRADFORD ELEMENTARY SCHOOL",
        "district": "BRADFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50348000106",
    },
    {
        "school": "BRADFORD HIGH SCHOOL",
        "district": "BRADFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50348000107",
    },
    {
        "school": "WHITE CO. CENTRAL ELEM. SCHOOL",
        "district": "WHITE CO. CENTRAL SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50417000155",
    },
    {
        "school": "WHITE CO. CENTRAL HIGH SCHOOL",
        "district": "WHITE CO. CENTRAL SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50417000156",
    },
    {
        "school": "RIVERVIEW HIGH SCHOOL",
        "district": "RIVERVIEW SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50840000242",
    },
    {
        "school": "KENSETT ELEMENTARY SCHOOL",
        "district": "RIVERVIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50840000559",
    },
    {
        "school": "JUDSONIA ELEMENTARY SCHOOL",
        "district": "RIVERVIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50840001442",
    },
    {
        "school": "PANGBURN ELEMENTARY SCHOOL",
        "district": "PANGBURN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51107000834",
    },
    {
        "school": "PANGBURN HIGH SCHOOL",
        "district": "PANGBURN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51107000835",
    },
    {
        "school": "ROSE BUD ELEMENTARY SCHOOL",
        "district": "ROSE BUD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51200000961",
    },
    {
        "school": "ROSE BUD HIGH SCHOOL",
        "district": "ROSE BUD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51200000962",
    },
    {
        "school": "MCRAE ELEMENTARY SCHOOL",
        "district": "SEARCY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51221000984",
    },
    {
        "school": "SEARCY HIGH SCHOOL",
        "district": "SEARCY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51221000985",
    },
    {
        "school": "AHLF JUNIOR HIGH SCHOOL",
        "district": "SEARCY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51221000986",
    },
    {
        "school": "SIDNEY DEENER ELEM. SCHOOL",
        "district": "SEARCY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51221000988",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "SEARCY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51221001444",
    },
    {
        "school": "GENOA CENTRAL ELEM. SCHOOL",
        "district": "GENOA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50411000151",
    },
    {
        "school": "GENOA CENTRAL HIGH SCHOOL",
        "district": "GENOA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50411000152",
    },
    {
        "school": "GARY E. COBB MIDDLE SCHOOL",
        "district": "GENOA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50411000286",
    },
    {
        "school": "PAULETTE SMITH MIDDLE SCHOOL",
        "district": "FOUKE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50636000299",
    },
    {
        "school": "FOUKE ELEMENTARY SCHOOL",
        "district": "FOUKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50636000379",
    },
    {
        "school": "FOUKE HIGH SCHOOL",
        "district": "FOUKE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50636000380",
    },
    {
        "school": "TEXARKANA AREA VOCATIONAL CENTER",
        "district": "TEXARKANA SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "51311000593",
    },
    {
        "school": "ARKANSAS HIGH SCHOOL",
        "district": "TEXARKANA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51311001068",
    },
    {
        "school": "COLLEGE HILL ELEMENTARY SCHOOL",
        "district": "TEXARKANA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51311001070",
    },
    {
        "school": "COLLEGE HILL MIDDLE",
        "district": "TEXARKANA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51311001071",
    },
    {
        "school": "FAIRVIEW ELEMENTARY SCHOOL",
        "district": "TEXARKANA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51311001072",
    },
    {
        "school": "NORTH HEIGHTS JR. HIGH SCHOOL",
        "district": "TEXARKANA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51311001073",
    },
    {
        "school": "UNION ELEMENTARY SCHOOL",
        "district": "TEXARKANA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51311001074",
    },
    {
        "school": "VERA KILPATRICK ELEM. SCHOOL",
        "district": "TEXARKANA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51311001075",
    },
    {
        "school": "EDWARD D. TRICE ELEM. SCHOOL",
        "district": "TEXARKANA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51311001264",
    },
    {
        "school": "KIPP DELTA COLLEGE PREPARATORY SCHOOL",
        "district": "KIPP DELTA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006200659",
    },
    {
        "school": "BARTON ELEMENTARY SCHOOL",
        "district": "BARTON-LEXA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50273000039",
    },
    {
        "school": "BARTON HIGH SCHOOL",
        "district": "BARTON-LEXA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50273000040",
    },
    {
        "school": "CENTRAL HIGH SCHOOL",
        "district": "HELENA/ W.HELENA SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50768000476",
    },
    {
        "school": "MARVELL HIGH SCHOOL",
        "district": "MARVELL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50951000694",
    },
    {
        "school": "MARVELL PRIMARY SCHOOL",
        "district": "MARVELL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50951000696",
    },
    {
        "school": "Afonotele Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000001",
    },
    {
        "school": "Alataua-Lua Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000002",
    },
    {
        "school": "Alofau Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000003",
    },
    {
        "school": "Aua Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000004",
    },
    {
        "school": "A.P Lutali",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000005",
    },
    {
        "school": "Faga'itua High School",
        "district": "American Samoa Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000007",
    },
    {
        "school": "Faleasao Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000009",
    },
    {
        "school": "Fitiuta Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000010",
    },
    {
        "school": "Lauli'i Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000011",
    },
    {
        "school": "Le'atele Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000012",
    },
    {
        "school": "Leone High School",
        "district": "American Samoa Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000013",
    },
    {
        "school": "Leone Midkiff Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000014",
    },
    {
        "school": "Lupelele Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000015",
    },
    {
        "school": "Manu'a High School",
        "district": "American Samoa Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000016",
    },
    {
        "school": "Manulele Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000017",
    },
    {
        "school": "Matafao Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000019",
    },
    {
        "school": "Matatula Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000020",
    },
    {
        "school": "Mt. Alava Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000021",
    },
    {
        "school": "Tafuna Elementary",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000022",
    },
    {
        "school": "Olomoana Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000023",
    },
    {
        "school": "Olosega Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000024",
    },
    {
        "school": "Peter Coleman Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000025",
    },
    {
        "school": "Pavaiai Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000026",
    },
    {
        "school": "Samoana High School",
        "district": "American Samoa Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000028",
    },
    {
        "school": "Siliaga Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000029",
    },
    {
        "school": "Tafuna High School",
        "district": "American Samoa Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000031",
    },
    {
        "school": "Nu'uuli Vocational Technical High School",
        "district": "American Samoa Department of Education",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AS",
        "nces_id": "600003000032",
    },
    {
        "school": "Masefau Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000033",
    },
    {
        "school": "CTD - Cochise Technology School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034502577",
    },
    {
        "school": "CVIT - San Carlos High School",
        "district": "Cobre Valley Institute of Technology District (79391)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40031602677",
    },
    {
        "school": "Benjamin Franklin Charter School - Power",
        "district": "Benjamin Franklin Charter School - Queen Creek (4355)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40006502685",
    },
    {
        "school": "International Commerce High School - Phoenix",
        "district": "International Commerce Secondary Schools Inc. (4334)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40010702650",
    },
    {
        "school": "Imagine Desert West Elementary",
        "district": "Imagine Charter Elementary at Desert West Inc. (88367)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40043802653",
    },
    {
        "school": "Great Hearts Academies - Chandler Prep",
        "district": "Chandler Preparatory Academy (88299)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40044002681",
    },
    {
        "school": "Imagine Surprise Middle",
        "district": "Imagine Middle at Surprise Inc. (88372)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40044102658",
    },
    {
        "school": "Imagine East Mesa Middle",
        "district": "Imagine Middle at East Mesa Inc. (88369)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40044202683",
    },
    {
        "school": "Imagine Camelback Elementary",
        "district": "Imagine Charter Elementary at Camelback Inc. (88365)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40044502676",
    },
    {
        "school": "South Ridge High School",
        "district": "American Charter Schools Foundation d.b.a. South R (88334)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40044702671",
    },
    {
        "school": "Verrado High School",
        "district": "Agua Fria Union High School District (4289)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40045002592",
    },
    {
        "school": "Nueva Vista School / Arizona State Hospital",
        "district": "ARIZONA STATE HOSPITAL (6415)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40045502588",
    },
    {
        "school": "West-MEC - Horizon High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502635",
    },
    {
        "school": "West-MEC - Shadow Mountain High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502641",
    },
    {
        "school": "West-MEC - Liberty High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502648",
    },
    {
        "school": "West-MEC - Paradise Valley High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502654",
    },
    {
        "school": "West-MEC - Pinnacle High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502664",
    },
    {
        "school": "West-MEC - Valley Vista High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502669",
    },
    {
        "school": "West-MEC - Verrado High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502680",
    },
    {
        "school": "West-MEC - North Canyon High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502686",
    },
    {
        "school": "Westpark Elementary School",
        "district": "Buckeye Elementary District (4269)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40138002642",
    },
    {
        "school": "Audrey & Robert Ryan Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002587",
    },
    {
        "school": "Chandler Traditional Academy - Independence",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002646",
    },
    {
        "school": "Sonoran Heights Elementary",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002649",
    },
    {
        "school": "Parkview Elementary",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002655",
    },
    {
        "school": "Western Peaks Elementary",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002679",
    },
    {
        "school": "Valley Vista High School",
        "district": "Dysart Unified District (4243)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002684",
    },
    {
        "school": "Highland Park Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340002662",
    },
    {
        "school": "Cortina Elementary",
        "district": "Higley Unified School District (4248)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378002663",
    },
    {
        "school": "Wildfire Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593002668",
    },
    {
        "school": "Amberlea Elementary School",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621002570",
    },
    {
        "school": "Liberty High School",
        "district": "Peoria Unified School District (4237)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625002586",
    },
    {
        "school": "Vistancia Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625002657",
    },
    {
        "school": "Phoenix Union Bioscience High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633002670",
    },
    {
        "school": "Copper Ridge Math and Science Academy",
        "district": "Scottsdale Unified District (4240)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757002640",
    },
    {
        "school": "Deer Valley Online Learning Program",
        "district": "Deer Valley Unified District (4246)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775002591",
    },
    {
        "school": "Canyon Springs STEM Academy",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775002636",
    },
    {
        "school": "TAPBI",
        "district": "Tempe Union High School District (4287)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40834002583",
    },
    {
        "school": "White Cliffs Middle School",
        "district": "Kingman Unified School District (79598)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029502661",
    },
    {
        "school": "Desert Sky Community School",
        "district": "Desert Sky Community School Inc. (88308)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40044802638",
    },
    {
        "school": "Desert Willow Elementary School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171002574",
    },
    {
        "school": "Anthem Elementary School",
        "district": "Florence Unified School District (4437)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292002637",
    },
    {
        "school": "Santa Cruz Elementary School",
        "district": "Maricopa Unified School District (4441)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40472002665",
    },
    {
        "school": "American Heritage Academy - Camp Verde",
        "district": "Edkey Inc. dba American Heritage Academy  (6365)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40013002569",
    },
    {
        "school": "Acorn Montessori Charter School Inc. - West",
        "district": "Acorn Montessori Charter School (79437)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40032002576",
    },
    {
        "school": "Desert Star Community School",
        "district": "Desert Star Community School Inc. (88321)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40043902644",
    },
    {
        "school": "Prescott Valley School",
        "district": "Prescott Valley Charter School (88317)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40044402321",
    },
    {
        "school": "NAVIT - St. Johns High School",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703065",
    },
    {
        "school": "NATIVE - Chinle High School",
        "district": "Northeast Arizona Technological Institute of Vocat (81114)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061203129",
    },
    {
        "school": "NATIVE - Red Mesa High School",
        "district": "Northeast Arizona Technological Institute of Vocat (81114)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061203131",
    },
    {
        "school": "NATIVE - Window Rock High School",
        "district": "Northeast Arizona Technological Institute of Vocat (81114)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061203132",
    },
    {
        "school": "NATIVE - Sanders Valley High School",
        "district": "Northeast Arizona Technological Institute of Vocat (81114)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061203133",
    },
    {
        "school": "Tsehootsooi Dine Bi'Olta",
        "district": "Window Rock Unified District (4154)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40943002447",
    },
    {
        "school": "NATIVE - Tuba City High School",
        "district": "Northeast Arizona Technological Institute of Vocat (81114)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061202545",
    },
    {
        "school": "NAVIT - Payson High School",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703170",
    },
    {
        "school": "Parker Alternative School",
        "district": "Parker Unified School District (4510)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40598002364",
    },
    {
        "school": "Imagine Rosefield",
        "district": "Rosefield Charter Elementary School Inc. (87399)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40042402526",
    },
    {
        "school": "Imagine East Mesa Elementary",
        "district": "East Mesa Charter Elementary School Inc. (87401)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40042502527",
    },
    {
        "school": "Arizona Agribusiness & Equine Center Inc. - Red Mountain",
        "district": "Arizona Agribusiness & Equine Center Inc. (87403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40042602528",
    },
    {
        "school": "Arizona Connections Academy",
        "district": "Arizona Connections Academy Charter School Inc. (87407)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40042703160",
    },
    {
        "school": "Pillar Academy of Business & Finance",
        "district": "Pillar Charter School (87334)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40042002522",
    },
    {
        "school": "NAVIT - NAVIT Courses",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019702238",
    },
    {
        "school": "NAVIT - Holbrook High School",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703070",
    },
    {
        "school": "NAVIT - Joseph City High School",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703071",
    },
    {
        "school": "NAVIT - Winslow High School",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703072",
    },
    {
        "school": "NAVIT - Alchesay High School",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703169",
    },
    {
        "school": "NATIVE - Monument Valley High School",
        "district": "Northeast Arizona Technological Institute of Vocat (81114)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061203127",
    },
    {
        "school": "NATIVE - Pinon High School",
        "district": "Northeast Arizona Technological Institute of Vocat (81114)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061203128",
    },
    {
        "school": "NATIVE - Ganado High School",
        "district": "Northeast Arizona Technological Institute of Vocat (81114)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061203130",
    },
    {
        "school": "White Cone High School",
        "district": "Cedar Unified District (4395)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40181002544",
    },
    {
        "school": "White Cone - Inactive",
        "district": "Cedar Unified District (4395)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40181003073",
    },
    {
        "school": "Indian Wells Elementary",
        "district": "Holbrook Unified District (4389)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40382002239",
    },
    {
        "school": "Joseph City Junior High School",
        "district": "Joseph City Unified District (4388)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40401002542",
    },
    {
        "school": "Snowflake Preschool",
        "district": "Snowflake Unified District (4391)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40782002543",
    },
    {
        "school": "Vernon Elementary School",
        "district": "Vernon Elementary District (4162)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002201354",
    },
    {
        "school": "NAVIT - Round Valley High School",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019701946",
    },
    {
        "school": "Alpine Elementary School",
        "district": "Alpine Elementary District (4161)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40063000019",
    },
    {
        "school": "Chinle Elementary School",
        "district": "Chinle Unified District (4158)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40194000135",
    },
    {
        "school": "Canyon De Chelly Elementary School",
        "district": "Chinle Unified District (4158)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40194000136",
    },
    {
        "school": "Chinle High School",
        "district": "Chinle Unified District (4158)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40194000137",
    },
    {
        "school": "Chinle Junior High School",
        "district": "Chinle Unified District (4158)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40194000138",
    },
    {
        "school": "Many Farms Elementary School",
        "district": "Chinle Unified District (4158)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40194000140",
    },
    {
        "school": "Tsaile Elementary School",
        "district": "Chinle Unified District (4158)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40194000145",
    },
    {
        "school": "Turquoise Dawn Alternative - Closed",
        "district": "Chinle Unified District (4158)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40194001139",
    },
    {
        "school": "Mesa View Elementary",
        "district": "Chinle Unified District (4158)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40194001488",
    },
    {
        "school": "Concho Elementary School",
        "district": "Concho Elementary District (4160)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40219000154",
    },
    {
        "school": "Ganado Primary School",
        "district": "Ganado Unified School District (4157)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40329000251",
    },
    {
        "school": "Ganado High School",
        "district": "Ganado Unified School District (4157)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40329000252",
    },
    {
        "school": "Ganado Intermediate School",
        "district": "Ganado Unified School District (4157)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40329000253",
    },
    {
        "school": "Ganado Middle School",
        "district": "Ganado Unified School District (4157)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40329000254",
    },
    {
        "school": "Mcnary Elementary School",
        "district": "Mcnary Elementary District (4163)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40486000376",
    },
    {
        "school": "Sanders Elementary School",
        "district": "Sanders Unified District (4156)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40674000572",
    },
    {
        "school": "Sanders Middle School",
        "district": "Sanders Unified District (4156)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40674001043",
    },
    {
        "school": "Valley High School",
        "district": "Sanders Unified District (4156)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40674001142",
    },
    {
        "school": "Red Mesa Elementary School",
        "district": "Red Mesa Unified District (4159)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40687000141",
    },
    {
        "school": "Red Mesa High School",
        "district": "Red Mesa Unified District (4159)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40687000142",
    },
    {
        "school": "Round Rock Elementary School",
        "district": "Red Mesa Unified District (4159)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40687000143",
    },
    {
        "school": "Red Mesa Junior High School",
        "district": "Red Mesa Unified District (4159)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40687000206",
    },
    {
        "school": "Round Valley Middle School",
        "district": "Round Valley Unified District (4155)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40713000617",
    },
    {
        "school": "Round Valley High School",
        "district": "Round Valley Unified District (4155)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40713001044",
    },
    {
        "school": "Round Valley Elementary School",
        "district": "Round Valley Unified District (4155)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40713001484",
    },
    {
        "school": "Coronado Elementary School",
        "district": "St Johns Unified District (4153)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40808000702",
    },
    {
        "school": "St Johns High School",
        "district": "St Johns Unified District (4153)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40808001049",
    },
    {
        "school": "St Johns Middle School",
        "district": "St Johns Unified District (4153)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40808001105",
    },
    {
        "school": "Integrated Preschool",
        "district": "Window Rock Unified District (4154)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40943000155",
    },
    {
        "school": "Tsehootsooi Intermediate Learning Center",
        "district": "Window Rock Unified District (4154)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40943000967",
    },
    {
        "school": "Tsehootsooi Middle School",
        "district": "Window Rock Unified District (4154)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40943000968",
    },
    {
        "school": "Window Rock High School",
        "district": "Window Rock Unified District (4154)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40943000970",
    },
    {
        "school": "Tsehootsooi Primary Learning Center",
        "district": "Window Rock Unified District (4154)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40943001648",
    },
    {
        "school": "Salome Elementary School",
        "district": "Salome Consolidated Elementary District (4514)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000500629",
    },
    {
        "school": "Salome High School",
        "district": "Bicentennial Union High School District (4515)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40116000062",
    },
    {
        "school": "Bouse Elementary School",
        "district": "Bouse Elementary District (4513)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40129000071",
    },
    {
        "school": "Parker High School",
        "district": "Parker Unified School District (4510)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40598000457",
    },
    {
        "school": "Blake Primary School",
        "district": "Parker Unified School District (4510)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40598000493",
    },
    {
        "school": "Le Pera Elementary School",
        "district": "Parker Unified School District (4510)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40598000494",
    },
    {
        "school": "Wallace Elementary School",
        "district": "Parker Unified School District (4510)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40598000495",
    },
    {
        "school": "Wallace Jr High School",
        "district": "Parker Unified School District (4510)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40598001977",
    },
    {
        "school": "Ehrenberg Elementary School",
        "district": "Quartzsite Elementary District (4511)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40678000573",
    },
    {
        "school": "Quartzsite Elementary School",
        "district": "Quartzsite Elementary District (4511)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40678001559",
    },
    {
        "school": "Wenden Elementary School",
        "district": "Wenden Elementary District (4512)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40912000949",
    },
    {
        "school": "Pinon Elementary School",
        "district": "Pinon Unified District (4390)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002301352",
    },
    {
        "school": "Pinon Accelerated Middle School",
        "district": "Pinon Unified District (4390)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002301355",
    },
    {
        "school": "Pinon High School",
        "district": "Pinon Unified District (4390)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002301524",
    },
    {
        "school": "Capps Elementary School",
        "district": "Heber-Overgaard Unified District (4392)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002601389",
    },
    {
        "school": "Mogollon Jr High School",
        "district": "Heber-Overgaard Unified District (4392)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002601459",
    },
    {
        "school": "Mogollon High School",
        "district": "Heber-Overgaard Unified District (4392)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002601460",
    },
    {
        "school": "Mountain Meadows Primary",
        "district": "Heber-Overgaard Unified District (4392)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002601767",
    },
    {
        "school": "Shonto Preparatory Technology High School",
        "district": "Shonto Governing Board of Education Inc. (6353)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40015401770",
    },
    {
        "school": "NAVIT - Snowflake High School",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019701943",
    },
    {
        "school": "NAVIT - Show Low High School",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019701944",
    },
    {
        "school": "NAVIT - Blue Ridge High School",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019701945",
    },
    {
        "school": "NAVIT - Mogollon High School (Heber-Overgaard)",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019701947",
    },
    {
        "school": "Jeddito School",
        "district": "Cedar Unified District (4395)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40181000325",
    },
    {
        "school": "Holbrook High School",
        "district": "Holbrook Unified District (4389)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40382000298",
    },
    {
        "school": "Holbrook Junior High School",
        "district": "Holbrook Unified District (4389)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40382000299",
    },
    {
        "school": "Hulet Elementary School",
        "district": "Holbrook Unified District (4389)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40382000300",
    },
    {
        "school": "Park Elementary School",
        "district": "Holbrook Unified District (4389)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40382000301",
    },
    {
        "school": "Joseph City Elementary School",
        "district": "Joseph City Unified District (4388)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40401000321",
    },
    {
        "school": "Joseph City High School",
        "district": "Joseph City Unified District (4388)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40401000322",
    },
    {
        "school": "Monument Valley High School",
        "district": "Kayenta Unified School District #27 (4396)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40406000324",
    },
    {
        "school": "Kayenta Elementary School",
        "district": "Kayenta Unified School District #27 (4396)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40406001160",
    },
    {
        "school": "Kayenta Middle School",
        "district": "Kayenta Unified School District #27 (4396)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40406001161",
    },
    {
        "school": "Navajo County Instruction for Success (NCIS)",
        "district": "Navajo County Accommodation District #99 (4386)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40550001237",
    },
    {
        "school": "Blue Ridge Elementary School",
        "district": "Blue Ridge Unified School District No. 32 (4397)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40658000560",
    },
    {
        "school": "Blue Ridge High School",
        "district": "Blue Ridge Unified School District No. 32 (4397)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40658000561",
    },
    {
        "school": "Blue Ridge Jr High School",
        "district": "Blue Ridge Unified School District No. 32 (4397)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40658001140",
    },
    {
        "school": "Whipple Ranch Elementary School",
        "district": "Show Low Unified District (4393)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40770000672",
    },
    {
        "school": "Show Low High School",
        "district": "Show Low Unified District (4393)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40770000673",
    },
    {
        "school": "Show Low Junior High School",
        "district": "Show Low Unified District (4393)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40770000674",
    },
    {
        "school": "Linden Elementary School",
        "district": "Show Low Unified District (4393)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40770001253",
    },
    {
        "school": "Nikolaus Homestead Elementary School",
        "district": "Show Low Unified District (4393)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40770001435",
    },
    {
        "school": "White Mountain Institute",
        "district": "Show Low Unified District (4393)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40770001941",
    },
    {
        "school": "Alchesay High School",
        "district": "Whiteriver Unified District (4394)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40916000005",
    },
    {
        "school": "Whiteriver Elementary",
        "district": "Whiteriver Unified District (4394)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40916000951",
    },
    {
        "school": "Canyon Day Junior High School",
        "district": "Whiteriver Unified District (4394)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40916000952",
    },
    {
        "school": "Cradleboard School",
        "district": "Whiteriver Unified District (4394)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40916001768",
    },
    {
        "school": "Seven Mile School",
        "district": "Whiteriver Unified District (4394)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40916002190",
    },
    {
        "school": "Bonnie Brennan School",
        "district": "Winslow Unified District (4387)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40946000971",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Winslow Unified District (4387)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40946000973",
    },
    {
        "school": "Washington School",
        "district": "Winslow Unified District (4387)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40946000974",
    },
    {
        "school": "Winslow High School",
        "district": "Winslow Unified District (4387)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40946000975",
    },
    {
        "school": "Winslow Junior High School",
        "district": "Winslow Unified District (4387)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40946000976",
    },
    {
        "school": "Northern AZ Academy for Career Dev. - Taylor",
        "district": "Career Development Inc. (4400)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40007700943",
    },
    {
        "school": "Taylor Intermediate School",
        "district": "Snowflake Unified District (4391)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40782000331",
    },
    {
        "school": "Highland Primary School",
        "district": "Snowflake Unified District (4391)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40782000692",
    },
    {
        "school": "Snowflake High School",
        "district": "Snowflake Unified District (4391)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40782000694",
    },
    {
        "school": "Snowflake Junior High School",
        "district": "Snowflake Unified District (4391)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40782000695",
    },
    {
        "school": "Taylor Elementary School",
        "district": "Snowflake Unified District (4391)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40782000696",
    },
    {
        "school": "Snowflake Intermediate School",
        "district": "Snowflake Unified District (4391)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40782001938",
    },
    {
        "school": "Ponderosa High School",
        "district": "Coconino County Accommodation School District (10386)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40016302429",
    },
    {
        "school": "Tse'yaato' High School",
        "district": "Coconino County Accommodation School District (10386)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40016303138",
    },
    {
        "school": "CAVIAT - Grand Canyon High School",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034702240",
    },
    {
        "school": "CAVIAT - Page High School",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034702269",
    },
    {
        "school": "CAVIAT - Fredonia High School",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034702270",
    },
    {
        "school": "CAVIAT - Williams High School",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034702271",
    },
    {
        "school": "CAVIAT - Coconino High School",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034702470",
    },
    {
        "school": "CAVIAT - Flagstaff High School",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034702471",
    },
    {
        "school": "The Peak School",
        "district": "PEAK School Inc. The (79866)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40035002286",
    },
    {
        "school": "Pine Forest School",
        "district": "Pine Forest Education Association Inc. (4201)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40001800496",
    },
    {
        "school": "Flagstaff Arts And Leadership Academy",
        "district": "Flagstaff Arts And Leadership Academy (4202)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40001900498",
    },
    {
        "school": "Montessori Charter School of Flagstaff - Campus",
        "district": "Flagstaff Montessori L.L.C. (4205)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002001179",
    },
    {
        "school": "Mountain School",
        "district": "Mountain School Inc. (4203)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40009601174",
    },
    {
        "school": "Northland Preparatory Academy",
        "district": "Northland Preparatory Academy (4204)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40009701178",
    },
    {
        "school": "Flagstaff Junior Academy",
        "district": "Flagstaff Junior Academy (4207)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40009801180",
    },
    {
        "school": "STAR Charter School",
        "district": "Painted Desert Demonstration Projects Inc. (79086)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40021302100",
    },
    {
        "school": "Neil V Christensen School - Closed",
        "district": "Flagstaff Unified District (4192)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000211",
    },
    {
        "school": "Coconino High School",
        "district": "Flagstaff Unified District (4192)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000212",
    },
    {
        "school": "Mount Elden Middle School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000214",
    },
    {
        "school": "Flagstaff High School",
        "district": "Flagstaff Unified District (4192)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000215",
    },
    {
        "school": "Flagstaff Middle School - Closed",
        "district": "Flagstaff Unified District (4192)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000216",
    },
    {
        "school": "W F Killip Elementary School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000217",
    },
    {
        "school": "Lura Kinsey Elementary School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000218",
    },
    {
        "school": "Leupp Public School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000219",
    },
    {
        "school": "Eva Marshall Elementary School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000220",
    },
    {
        "school": "Charles W Sechrist Elementary School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000222",
    },
    {
        "school": "South Beaver Elementary School - Closed",
        "district": "Flagstaff Unified District (4192)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000224",
    },
    {
        "school": "John Q Thomas Elementary School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286000225",
    },
    {
        "school": "Renaissance Magnet Middle School - Closed",
        "district": "Flagstaff Unified District (4192)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286001157",
    },
    {
        "school": "Summit High School",
        "district": "Flagstaff Unified District (4192)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40286001158",
    },
    {
        "school": "Thomas M Knoles Elementary School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286001363",
    },
    {
        "school": "Sturgeon Cromer Elementary School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286001364",
    },
    {
        "school": "Manuel DeMiguel Elementary School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286001463",
    },
    {
        "school": "Sinagua High School - Closed",
        "district": "Flagstaff Unified District (4192)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286001464",
    },
    {
        "school": "Weitzel's Puente de Hozho Bilingual Magnet School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286002097",
    },
    {
        "school": "Fredonia Elementary School",
        "district": "Fredonia-Moccasin Unified District (4195)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40308000241",
    },
    {
        "school": "Fredonia High School",
        "district": "Fredonia-Moccasin Unified District (4195)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40308000242",
    },
    {
        "school": "Grand Canyon Elementary",
        "district": "Grand Canyon Unified District (4194)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40355000290",
    },
    {
        "school": "Grand Canyon High School",
        "district": "Grand Canyon Unified District (4194)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40355000291",
    },
    {
        "school": "Maine Consolidated School",
        "district": "Maine Consolidated School District (4199)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40453000361",
    },
    {
        "school": "Page Middle School",
        "district": "Page Unified District (4196)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40582000468",
    },
    {
        "school": "Page High School",
        "district": "Page Unified District (4196)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40582000469",
    },
    {
        "school": "Desert View Elementary Intermediate",
        "district": "Page Unified District (4196)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40582001078",
    },
    {
        "school": "Lake View Elementary Primary",
        "district": "Page Unified District (4196)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40582001312",
    },
    {
        "school": "Tuba City High School",
        "district": "Tuba City Unified School District #15 (4197)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40868000812",
    },
    {
        "school": "Tuba City Junior High School",
        "district": "Tuba City Unified School District #15 (4197)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40868000814",
    },
    {
        "school": "Tuba City Elementary School",
        "district": "Tuba City Unified School District #15 (4197)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40868000815",
    },
    {
        "school": "Dzil Libei Elementary School",
        "district": "Tuba City Unified School District #15 (4197)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40868001152",
    },
    {
        "school": "Tsinaabaas Habitiin Elementary School",
        "district": "Tuba City Unified School District #15 (4197)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40868001153",
    },
    {
        "school": "Nizhoni Accelerated Academy",
        "district": "Tuba City Unified School District #15 (4197)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40868001822",
    },
    {
        "school": "Williams High School",
        "district": "Williams Unified District (4193)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40931000960",
    },
    {
        "school": "Williams Elementary/Middle School",
        "district": "Williams Unified District (4193)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40931001118",
    },
    {
        "school": "Moccasin Elementary School",
        "district": "Fredonia-Moccasin Unified District (4195)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40308000243",
    },
    {
        "school": "Sedona Red Rock Junior/Senior High School",
        "district": "Sedona-Oak Creek JUSD #9 (4467)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40973301040",
    },
    {
        "school": "West Sedona Elementary School",
        "district": "Sedona-Oak Creek JUSD #9 (4467)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40973301512",
    },
    {
        "school": "Telesis Preparatory",
        "district": "Telesis Center for Learning Inc. (79218)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40024803089",
    },
    {
        "school": "Mt Tipton Elementary School",
        "district": "Kingman Unified School District (79598)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029500149",
    },
    {
        "school": "Mohave Accelerated Elementary School",
        "district": "Mohave Accelerated Elementary School Inc. (85516)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40041302411",
    },
    {
        "school": "Academy of Building Industries",
        "district": "Academy of Building Industries Inc. (85540)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40041402412",
    },
    {
        "school": "Havasuonline",
        "district": "Lake Havasu Unified District (4368)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40428002538",
    },
    {
        "school": "Beaver Dam High School",
        "district": "Littlefield Unified District (4374)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40441002418",
    },
    {
        "school": "El Capitan Public School",
        "district": "Colorado City Unified District (4370)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002101276",
    },
    {
        "school": "Colorado City High School",
        "district": "Colorado City Unified District (4370)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002101277",
    },
    {
        "school": "Colorado City Jr High School",
        "district": "Colorado City Unified District (4370)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002101523",
    },
    {
        "school": "Kingman Academy of Learning - Primary School",
        "district": "Kingman Academy Of Learning (4383)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40007401604",
    },
    {
        "school": "Kingman Academy of Learning - Intermediate School",
        "district": "Kingman Academy Of Learning (4383)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40007401605",
    },
    {
        "school": "Kingman Academy of Learning - Middle School",
        "district": "Kingman Academy Of Learning (4383)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40007401759",
    },
    {
        "school": "Kingman Academy of Learning - High School",
        "district": "Kingman Academy Of Learning (4383)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40007402185",
    },
    {
        "school": "Young Scholars Academy",
        "district": "Young Scholars Academy Charter School Corp. (4385)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40007500893",
    },
    {
        "school": "River Valley High School",
        "district": "Colorado River Union High School District (4381)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40008200006",
    },
    {
        "school": "Mohave High School",
        "district": "Colorado River Union High School District (4381)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40008201457",
    },
    {
        "school": "Telesis Preparatory Academy",
        "district": "Telesis Center for Learning Inc. (79218)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40024801923",
    },
    {
        "school": "Mohave Accelerated Learning Center",
        "district": "Mohave Accelerated Learning Center (79498)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40028002186",
    },
    {
        "school": "Masada Charter School",
        "district": "Masada Charter School Inc. (79499)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40028102187",
    },
    {
        "school": "Kingman Middle School",
        "district": "Kingman Unified School District (79598)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029500326",
    },
    {
        "school": "La Senita Elementary",
        "district": "Kingman Unified School District (79598)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029500327",
    },
    {
        "school": "Manzanita Elementary",
        "district": "Kingman Unified School District (79598)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029500328",
    },
    {
        "school": "Kingman High School",
        "district": "Kingman Unified School District (79598)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029500881",
    },
    {
        "school": "Hualapai Elementary",
        "district": "Kingman Unified School District (79598)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029501126",
    },
    {
        "school": "Cerbat Elementary",
        "district": "Kingman Unified School District (79598)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029501495",
    },
    {
        "school": "Black Mountain Elementary School",
        "district": "Kingman Unified School District (79598)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029501544",
    },
    {
        "school": "Bullhead City Middle School",
        "district": "Bullhead City School District (4378)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40150000085",
    },
    {
        "school": "Coyote Canyon School",
        "district": "Bullhead City School District (4378)",
        "level": "Elementary",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40150000855",
    },
    {
        "school": "Desert Valley School",
        "district": "Bullhead City School District (4378)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40150001053",
    },
    {
        "school": "Diamondback Elementary School",
        "district": "Bullhead City School District (4378)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40150001528",
    },
    {
        "school": "Fox Creek Jr High School",
        "district": "Bullhead City School District (4378)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40150001757",
    },
    {
        "school": "Sunrise Elementary",
        "district": "Bullhead City School District (4378)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40150002184",
    },
    {
        "school": "Cedar Hills School",
        "district": "Hackberry School District (4371)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40366000065",
    },
    {
        "school": "Havasupai Elementary School",
        "district": "Lake Havasu Unified District (4368)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40428000337",
    },
    {
        "school": "Thunderbolt Middle School",
        "district": "Lake Havasu Unified District (4368)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40428000338",
    },
    {
        "school": "Smoketree Elementary School",
        "district": "Lake Havasu Unified District (4368)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40428000339",
    },
    {
        "school": "Starline Elementary School",
        "district": "Lake Havasu Unified District (4368)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40428000340",
    },
    {
        "school": "Lake Havasu High School",
        "district": "Lake Havasu Unified District (4368)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40428000433",
    },
    {
        "school": "Nautilus Elementary School",
        "district": "Lake Havasu Unified District (4368)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40428001129",
    },
    {
        "school": "Oro Grande Classical Academy",
        "district": "Lake Havasu Unified District (4368)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40428001130",
    },
    {
        "school": "Daytona Middle School",
        "district": "Lake Havasu Unified District (4368)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40428001756",
    },
    {
        "school": "Jamaica Elementary School",
        "district": "Lake Havasu Unified District (4368)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40428002182",
    },
    {
        "school": "Beaver Dam Elementary",
        "district": "Littlefield Unified District (4374)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40441001302",
    },
    {
        "school": "Mohave Valley Junior High School",
        "district": "Mohave Valley Elementary District (4379)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40519001414",
    },
    {
        "school": "Fort Mohave Elementary School",
        "district": "Mohave Valley Elementary District (4379)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40519001415",
    },
    {
        "school": "Camp Mohave Elementary School",
        "district": "Mohave Valley Elementary District (4379)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40519001758",
    },
    {
        "school": "Owens Elementary School",
        "district": "Owens School District No.6 (4373)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40573000466",
    },
    {
        "school": "Peach Springs School",
        "district": "Peach Springs Unified District (4369)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40612000502",
    },
    {
        "school": "Music Mountain Jr./Sr. High School",
        "district": "Peach Springs Unified District (4369)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40612002033",
    },
    {
        "school": "Topock Elementary School",
        "district": "Topock Elementary District (4376)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40864001259",
    },
    {
        "school": "Valentine Elementary School",
        "district": "Valentine Elementary District (4380)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40888000910",
    },
    {
        "school": "Yucca Elementary School",
        "district": "Yucca Elementary District (4377)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40957000323",
    },
    {
        "school": "Pinnacle Charter High School",
        "district": "Pinnacle Education-Kino Inc. (81009)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40062502157",
    },
    {
        "school": "Mexicayotl Charter School",
        "district": "Mexicayotl Academy Inc. (4463)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40015001793",
    },
    {
        "school": "Patagonia Montessori School",
        "district": "Patagonia Montessori Elementary School (79069)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40026302083",
    },
    {
        "school": "Montessori De Santa Cruz - St. Ann's Hall",
        "district": "Santa Cruz Valley Opportunities in Education Inc. (79066)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40026402084",
    },
    {
        "school": "A J Mitchell Elementary School",
        "district": "Nogales Unified District (4457)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40553000451",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Nogales Unified District (4457)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40553000453",
    },
    {
        "school": "Mary L Welty Elementary School",
        "district": "Nogales Unified District (4457)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40553000454",
    },
    {
        "school": "Nogales High School",
        "district": "Nogales Unified District (4457)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40553000455",
    },
    {
        "school": "Wade Carpenter Middle School",
        "district": "Nogales Unified District (4457)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40553000456",
    },
    {
        "school": "Robert Bracker Elementary",
        "district": "Nogales Unified District (4457)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40553001034",
    },
    {
        "school": "Desert Shadows Middle School",
        "district": "Nogales Unified District (4457)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40553001238",
    },
    {
        "school": "Challenger Elementary School",
        "district": "Nogales Unified District (4457)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40553001310",
    },
    {
        "school": "Francisco Vasquez De Coronado Elementary School",
        "district": "Nogales Unified District (4457)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40553001470",
    },
    {
        "school": "Pierson High School",
        "district": "Nogales Unified District (4457)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40553001552",
    },
    {
        "school": "Patagonia Elementary School",
        "district": "Patagonia Elementary District (4460)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40600000497",
    },
    {
        "school": "Patagonia Union High School",
        "district": "Patagonia Union High School District (4462)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40603000499",
    },
    {
        "school": "Little Red Schoolhouse",
        "district": "Santa Cruz Elementary District (4459)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40750000633",
    },
    {
        "school": "Calabasas School",
        "district": "Santa Cruz Valley Unified District (4458)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40752000634",
    },
    {
        "school": "Mountain View School",
        "district": "Santa Cruz Valley Unified District (4458)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40752000635",
    },
    {
        "school": "San Cayetano Elementary School",
        "district": "Santa Cruz Valley Unified District (4458)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40752000637",
    },
    {
        "school": "Rio Rico High School",
        "district": "Santa Cruz Valley Unified District (4458)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40752001036",
    },
    {
        "school": "Elgin Elementary School",
        "district": "Sonoita Elementary District (4461)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40792000699",
    },
    {
        "school": "High Desert Middle School",
        "district": "Globe Unified District (4208)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40350002422",
    },
    {
        "school": "Dr. Charles A. Bejarano Elementary School",
        "district": "Miami Unified District (4211)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40503003134",
    },
    {
        "school": "AMCS at Anthem dba Caurus Academy",
        "district": "Arizona Montessori Charter School at Anthem (85749)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40041502414",
    },
    {
        "school": "Liberty High School",
        "district": "Liberty High School (4216)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40009901182",
    },
    {
        "school": "Destiny School",
        "district": "Destiny School Inc. (6258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40033901939",
    },
    {
        "school": "Globe High School",
        "district": "Globe Unified District (4208)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40350000287",
    },
    {
        "school": "Copper Rim Elementary School",
        "district": "Globe Unified District (4208)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40350000289",
    },
    {
        "school": "Hayden High School",
        "district": "Hayden-Winkelman Unified District (4212)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40373000293",
    },
    {
        "school": "Leonor Hambly K-8",
        "district": "Hayden-Winkelman Unified District (4212)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40373000295",
    },
    {
        "school": "Miami Junior Senior High School",
        "district": "Miami Unified District (4211)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40503001077",
    },
    {
        "school": "Lee Kornegay Intermediate School",
        "district": "Miami Unified District (4211)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40503001134",
    },
    {
        "school": "Tonto Basin Elementary",
        "district": "Tonto Basin Elementary District (4215)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40576000467",
    },
    {
        "school": "Payson High School",
        "district": "Payson Unified District (4209)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40607000500",
    },
    {
        "school": "Rim Country Middle School",
        "district": "Payson Unified District (4209)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40607000501",
    },
    {
        "school": "Julia Randall Elementary School",
        "district": "Payson Unified District (4209)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40607001088",
    },
    {
        "school": "Payson Elementary School",
        "district": "Payson Unified District (4209)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40607001423",
    },
    {
        "school": "Payson Center for Success High School",
        "district": "Payson Unified District (4209)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40607001823",
    },
    {
        "school": "Pine Strawberry Elementary School",
        "district": "Pine Strawberry Elementary District (4214)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40651000559",
    },
    {
        "school": "San Carlos High School",
        "district": "San Carlos Unified District (4210)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40696000526",
    },
    {
        "school": "Rice School",
        "district": "San Carlos Unified District (4210)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40696001353",
    },
    {
        "school": "San Carlos High School",
        "district": "San Carlos Unified District (4210)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40696001502",
    },
    {
        "school": "Rice Elementary School",
        "district": "San Carlos Unified District (4210)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40696001656",
    },
    {
        "school": "Young Elementary School",
        "district": "Young Elementary District (4213)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40954000978",
    },
    {
        "school": "Young High School",
        "district": "Young Elementary District (4213)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40954001119",
    },
    {
        "school": "Lone Mountain Elementary School",
        "district": "Cave Creek Unified District (4244)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000102344",
    },
    {
        "school": "Horseshoe Trails Elementary School",
        "district": "Cave Creek Unified District (4244)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000102484",
    },
    {
        "school": "Montessori Education Centre Charter School - North Campus",
        "district": "Montessori Education Centre Charter School (4363)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40007202264",
    },
    {
        "school": "Ombudsman - Charter Northwest",
        "district": "Ombudsman Educational Services Ltd.a subsidiary  (4323)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40010302329",
    },
    {
        "school": "Humanities and Sciences Academy Arizona",
        "district": "Humanities and Sciences Academy of the United Stat (4337)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40010803162",
    },
    {
        "school": "Career Success Jr/Sr High School - North Phoenix",
        "district": "Career Success Schools (79047)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40021902328",
    },
    {
        "school": "Career Success School - Sage Campus",
        "district": "Career Success Schools (79047)",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40021902338",
    },
    {
        "school": "Robert L. Duffy High School",
        "district": "Career Success Schools (79047)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40021902367",
    },
    {
        "school": "Imagine Cortez Park Elementary",
        "district": "Pathfinder Charter School Foundation (79024)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40023002171",
    },
    {
        "school": "Avalon Elementary",
        "district": "Excalibur Charter Schools Inc. (79214)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40023503157",
    },
    {
        "school": "Arts Academy at Estrella Mountain",
        "district": "P.L.C. Charter Schools (6235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40023902533",
    },
    {
        "school": "Calibre Academy Surprise",
        "district": "Calibre Academy (79055)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40031002370",
    },
    {
        "school": "E-Institute at Surprise",
        "district": "E-Institute Charter Schools Inc. (79059)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40031103144",
    },
    {
        "school": "Canyon Pointe Academy",
        "district": "Pointe Schools (79455)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40032702291",
    },
    {
        "school": "Pinnacle Pointe Academy",
        "district": "Pointe Schools (79455)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40032702372",
    },
    {
        "school": "Primavera - Online",
        "district": "American Virtual Academy (79461)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40032903159",
    },
    {
        "school": "Estrella High School",
        "district": "American Charter Schools Foundation d.b.a. Estrell (79873)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40035201898",
    },
    {
        "school": "Peoria Accelerated High School",
        "district": "American Charter Schools Foundation d.b.a. Peoria  (79875)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40035301896",
    },
    {
        "school": "Sun Valley High School",
        "district": "American Charter Schools Foundation d.b.a. Sun Val (79877)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40035401733",
    },
    {
        "school": "West Phoenix High School",
        "district": "American Charter Schools Foundation d.b.a. West Ph (79879)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40035501734",
    },
    {
        "school": "Challenger Basic School",
        "district": "Challenger Basic School Inc. (79886)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40035902292",
    },
    {
        "school": "Intelli-School",
        "district": "SC Jensen Corporation Inc. dba Intelli-School (79951)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40036302300",
    },
    {
        "school": "Intelli-School - Metro Center",
        "district": "PAS Charter Inc. dba Intelli-School (79953)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40036400804",
    },
    {
        "school": "Desert Marigold School",
        "district": "Valley of the Sun Waldorf Education Association d (79957)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40036602302",
    },
    {
        "school": "Midtown Primary School",
        "district": "Midtown Primary School (79994)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40037001597",
    },
    {
        "school": "Imagine Bell Canyon",
        "district": "Bell Canyon Charter School Inc (79983)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40037402169",
    },
    {
        "school": "Imagine Cortez Park Middle",
        "district": "Cortez Park Charter Middle School Inc. (79988)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40037602313",
    },
    {
        "school": "Imagine West Gilbert Middle",
        "district": "West Gilbert Charter Middle School Inc. (79990)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40037702314",
    },
    {
        "school": "Desert Hills High School",
        "district": "American Charter Schools Foundation d.b.a. Desert  (79872)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40038401899",
    },
    {
        "school": "Crestview College Preparatory High School",
        "district": "American Charter Schools Foundation d.b.a. Crestvi (79874)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40038502016",
    },
    {
        "school": "Kaizen Education Foundation dba Summit High School",
        "district": "Kaizen Education Foundation dba Summit High School (79876)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40038601894",
    },
    {
        "school": "Kaizen Education Foundation dba Quest High School",
        "district": "Kaizen Education Foundation dba Tempe Accelerated  (79878)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40038701735",
    },
    {
        "school": "Kaizen Education Foundation dba Maya High School",
        "district": "Kaizen Education Foundation dba Maya High School (79882)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40038901737",
    },
    {
        "school": "Camelback Academy",
        "district": "Camelback Education Inc (79905)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40039002289",
    },
    {
        "school": "Midtown High School",
        "district": "Vista Charter School (79907)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40039103074",
    },
    {
        "school": "Precision Academy",
        "district": "Avondale Learning dba Precision Academy (79929)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40039402323",
    },
    {
        "school": "Leading Edge Academy Gilbert Elementary",
        "district": "LEAD Charter Schools (79967)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40039502305",
    },
    {
        "school": "Leading Edge Academy Gilbert Early College",
        "district": "LEAD Charter Schools (79967)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40039502536",
    },
    {
        "school": "All Aboard Charter School",
        "district": "All Aboard Charter School (79969)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40039602306",
    },
    {
        "school": "Learning Foundation",
        "district": "CAFA Inc. dba Learning Foundation Performing Arts (79971)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40039703119",
    },
    {
        "school": "Montessori Academy",
        "district": "Montessori Academy Inc. (80011)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40039902325",
    },
    {
        "school": "New World Educational Center",
        "district": "New World Educational Center (78882)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40040101866",
    },
    {
        "school": "Westland School",
        "district": "Cholla Academy (5186)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40040201860",
    },
    {
        "school": "Cornerstone Charter School",
        "district": "Cornerstone Charter SchoolInc (79077)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40040502053",
    },
    {
        "school": "Happy Valley School",
        "district": "Happy Valley School Inc. (79081)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40040602036",
    },
    {
        "school": "AAEC - SMCC Campus",
        "district": "Arizona Agribusiness & Equine Center Inc. (85816)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40041701588",
    },
    {
        "school": "East Valley High School",
        "district": "Legacy Education Group (87349)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40042302525",
    },
    {
        "school": "Country Gardens Charter School",
        "district": "Country Gardens Charter Schools (79074)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40042901994",
    },
    {
        "school": "Desert Edge High School",
        "district": "Agua Fria Union High School District (4289)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40045002273",
    },
    {
        "school": "Desert Heights Charter School",
        "district": "Desert Heights Charter Schools (81099)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40061002056",
    },
    {
        "school": "Phoenix College Preparatory Academy",
        "district": "MCCCD on behalf of Phoenix College Preparatory Aca (81174)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40061403158",
    },
    {
        "school": "West-MEC - Ironwood High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502390",
    },
    {
        "school": "West-MEC - Cactus High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502391",
    },
    {
        "school": "West-MEC - Sunrise Mountain High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502392",
    },
    {
        "school": "West-MEC - Willow Canyon High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502393",
    },
    {
        "school": "West-MEC - Desert Edge High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502394",
    },
    {
        "school": "West-MEC - Estrella Foothills High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502395",
    },
    {
        "school": "West-MEC - Tonopah Valley High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502440",
    },
    {
        "school": "West-MEC - Raymond S. Kellis",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502441",
    },
    {
        "school": "West-MEC - Washington High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502506",
    },
    {
        "school": "West-MEC - Thunderbird High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502507",
    },
    {
        "school": "West-MEC - Sunnyslope High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502508",
    },
    {
        "school": "West-MEC - Moon Valley High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502509",
    },
    {
        "school": "West-MEC - Independence High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502510",
    },
    {
        "school": "West-MEC - Greenway High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502511",
    },
    {
        "school": "West-MEC - Glendale High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502512",
    },
    {
        "school": "West-MEC - Cortez High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502513",
    },
    {
        "school": "West-MEC - Apollo High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502514",
    },
    {
        "school": "West-MEC - Boulder Creek High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502515",
    },
    {
        "school": "West-MEC - Barry Goldwater High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502516",
    },
    {
        "school": "West-MEC - Deer Valley High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502517",
    },
    {
        "school": "West-MEC - Mountain Ridge High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502518",
    },
    {
        "school": "West-MEC - Sandra Day O'Connor High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502519",
    },
    {
        "school": "West-MEC - Wickenburg High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502520",
    },
    {
        "school": "West-MEC - Central Campus",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502521",
    },
    {
        "school": "West-MEC - Centennial High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503148",
    },
    {
        "school": "West-MEC - Peoria High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503149",
    },
    {
        "school": "West-MEC - Dysart High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503150",
    },
    {
        "school": "West-MEC - Millennium High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503151",
    },
    {
        "school": "West-MEC - Agua Fria High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503152",
    },
    {
        "school": "West-MEC - Buckeye Union High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503153",
    },
    {
        "school": "New School for the Arts Middle School",
        "district": "New School for the Arts Middle School (80985)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40061603094",
    },
    {
        "school": "South Pointe High School",
        "district": "American Charter Schools Foundation d.b.a. South P (80989)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40061803095",
    },
    {
        "school": "Pinnacle High School - Tempe",
        "district": "Pinnacle Education-Tempe Inc. (81001)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40062100688",
    },
    {
        "school": "Pinnacle Online High School",
        "district": "Pinnacle Education-Tempe Inc. (81001)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40062103161",
    },
    {
        "school": "Hope High School",
        "district": "Blueprint Education (81041)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40063603108",
    },
    {
        "school": "Hope High School Online",
        "district": "Blueprint Education (81041)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40063603163",
    },
    {
        "school": "Arizona Conservatory for Arts and Academics Elementary Schoo",
        "district": "Edkey Inc. - Redwood Academy (81043)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40063702032",
    },
    {
        "school": "Pathfinder Academy",
        "district": "Edkey Inc. - Pathfinder Academy (81045)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40063801796",
    },
    {
        "school": "Edkey Inc. - Sequoia Deaf School",
        "district": "Edkey Inc. - Sequoia School for the Deaf and Hard (81050)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40064002031",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Heritage Elementary School (81076)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40064903114",
    },
    {
        "school": "Integrity Education Centre",
        "district": "Integrity Education Incorporated (5174)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40065001846",
    },
    {
        "school": "Arizona Conservatory for Arts and Academics",
        "district": "Edkey Inc. - Arizona Conservatory for Arts and Ac (79981)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40065303069",
    },
    {
        "school": "Great Hearts Academies - Veritas Prep",
        "district": "Veritas Preparatory Academy (80992)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40065503096",
    },
    {
        "school": "Desert Star",
        "district": "Avondale Elementary District (4272)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096002255",
    },
    {
        "school": "Desert Thunder",
        "district": "Avondale Elementary District (4272)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096002381",
    },
    {
        "school": "Centerra Mirage STEM Academy",
        "district": "Avondale Elementary District (4272)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096002494",
    },
    {
        "school": "Brunson-Lee Elementary School",
        "district": "Balsz Elementary District (4268)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40105003142",
    },
    {
        "school": "Sundance Elementary",
        "district": "Buckeye Elementary District (4269)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40138002490",
    },
    {
        "school": "Buckeye Elementary School",
        "district": "Buckeye Elementary District (4269)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40138002492",
    },
    {
        "school": "Bales Elementary School",
        "district": "Buckeye Elementary District (4269)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40138003123",
    },
    {
        "school": "Manuel Pena Jr. School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168003122",
    },
    {
        "school": "Basha High School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002250",
    },
    {
        "school": "Santan Junior High School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002251",
    },
    {
        "school": "Chandler Traditional Academy - Liberty Campus",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002346",
    },
    {
        "school": "T. Dale Hancock Elementary School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002379",
    },
    {
        "school": "Navarrete Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002380",
    },
    {
        "school": "Willie & Coy Payne Jr. High",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002478",
    },
    {
        "school": "Chandler Traditional Academy-Freedom",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002479",
    },
    {
        "school": "Santan Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002480",
    },
    {
        "school": "Countryside Elementary School",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002340",
    },
    {
        "school": "Marley Park Elementary",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002401",
    },
    {
        "school": "Thompson Ranch Elementary",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002402",
    },
    {
        "school": "Sunset Hills Elementary",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002481",
    },
    {
        "school": "Rancho Gabriela",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002482",
    },
    {
        "school": "Ashton Ranch Elementary School",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269003124",
    },
    {
        "school": "Cimarron Springs Elementary",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269003125",
    },
    {
        "school": "Willow Canyon High School",
        "district": "Dysart Unified District (4243)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269003126",
    },
    {
        "school": "Sun Canyon School",
        "district": "Fowler Elementary District (4273)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40306002355",
    },
    {
        "school": "Tuscano Elementary School",
        "district": "Fowler Elementary District (4273)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40306002495",
    },
    {
        "school": "Western Valley Elementary School",
        "district": "Fowler Elementary District (4273)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40306003084",
    },
    {
        "school": "Western Valley Middle School",
        "district": "Fowler Elementary District (4273)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40306003085",
    },
    {
        "school": "Desert Ridge High",
        "district": "Gilbert Unified District (4239)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340002283",
    },
    {
        "school": "Canyon Rim Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340002284",
    },
    {
        "school": "South Valley Jr. High",
        "district": "Gilbert Unified District (4239)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340002432",
    },
    {
        "school": "Meridian",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340002476",
    },
    {
        "school": "Spectrum Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340003146",
    },
    {
        "school": "Gilbert Classical Academy - Closed",
        "district": "Gilbert Unified District (4239)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340003147",
    },
    {
        "school": "Desert Spirit",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342002281",
    },
    {
        "school": "Sunset Vista",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342002493",
    },
    {
        "school": "Power Ranch Elementary",
        "district": "Higley Unified School District (4248)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378002356",
    },
    {
        "school": "Gateway Pointe Elementary",
        "district": "Higley Unified School District (4248)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378002477",
    },
    {
        "school": "Continued Hope High Schools",
        "district": "Maricopa County Regional School District (4234)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40386002365",
    },
    {
        "school": "Moya Elementary",
        "district": "Isaac Elementary District (4259)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396002282",
    },
    {
        "school": "Cheatham Elementary School",
        "district": "Laveen Elementary District (4276)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40429002398",
    },
    {
        "school": "Westar Elementary School",
        "district": "Liberty Elementary District (4266)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40432002383",
    },
    {
        "school": "Freedom Elementary School",
        "district": "Liberty Elementary District (4266)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40432002489",
    },
    {
        "school": "Corte Sierra Elementary School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438002342",
    },
    {
        "school": "Dreaming Summit Elementary",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438002430",
    },
    {
        "school": "Verrado Middle School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438002431",
    },
    {
        "school": "Barbara B. Robey Elementary School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438002499",
    },
    {
        "school": "Collier Elementary School",
        "district": "Littleton Elementary District (4278)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40444002247",
    },
    {
        "school": "Quentin Elementary School",
        "district": "Littleton Elementary District (4278)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40444002435",
    },
    {
        "school": "Country Place Elementary",
        "district": "Littleton Elementary District (4278)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40444002497",
    },
    {
        "school": "Zaharis Elementary",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497002280",
    },
    {
        "school": "Early Education Center",
        "district": "Mesa Unified District (4235)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497002337",
    },
    {
        "school": "Mountain Trail Middle School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593002266",
    },
    {
        "school": "Pinnacle Peak Preparatory",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593002268",
    },
    {
        "school": "Echo Mountain Intermediate School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593002343",
    },
    {
        "school": "Palomino Intermediate School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593003104",
    },
    {
        "school": "Rio Vista Elementary",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621002274",
    },
    {
        "school": "Sunset Ridge Elementary School",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621002385",
    },
    {
        "school": "Westwind Elementary School",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621003077",
    },
    {
        "school": "Peoria eCampus",
        "district": "Peoria Unified School District (4237)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625002396",
    },
    {
        "school": "Raymond S. Kellis",
        "district": "Peoria Unified School District (4237)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625002426",
    },
    {
        "school": "Peoria Flex Academy",
        "district": "Peoria Unified School District (4237)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40625002475",
    },
    {
        "school": "Parkridge Elementary",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625003145",
    },
    {
        "school": "ACE Day & Night School  - Closed",
        "district": "Phoenix Elementary District (4256)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630003174",
    },
    {
        "school": "Jack Barnes Elementary School",
        "district": "Queen Creek Unified District (4245)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681002369",
    },
    {
        "school": "Frances Brandon-Pickett Elementary",
        "district": "Queen Creek Unified District (4245)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681002485",
    },
    {
        "school": "Kings Ridge School",
        "district": "Riverside Elementary District (4257)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40702002487",
    },
    {
        "school": "Bernard Black Elementary School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708002498",
    },
    {
        "school": "Tonopah Valley High School",
        "district": "Saddle Mountain Unified School District (4254)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40717002483",
    },
    {
        "school": "Sandra Day O'Connor High School",
        "district": "Deer Valley Unified District (4246)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775002357",
    },
    {
        "school": "Gavilan Peak School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775002358",
    },
    {
        "school": "Boulder Creek High School",
        "district": "Deer Valley Unified District (4246)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775002433",
    },
    {
        "school": "Diamond Canyon School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775002434",
    },
    {
        "school": "West Wing School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775002486",
    },
    {
        "school": "Terramar Academy of the Arts",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775003098",
    },
    {
        "school": "Sunset Ridge School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775003099",
    },
    {
        "school": "Ward Traditional Academy",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831003112",
    },
    {
        "school": "Desert Oasis Elementary School",
        "district": "Tolleson Elementary District (4264)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40849002488",
    },
    {
        "school": "La Joya Community High School",
        "district": "Tolleson Union High School District (4288)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40852002339",
    },
    {
        "school": "Copper Canyon High School",
        "district": "Tolleson Union High School District (4288)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40852002416",
    },
    {
        "school": "Hurley Ranch Elementary",
        "district": "Union Elementary District (4277)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40882002496",
    },
    {
        "school": "EVIT - Tempe Auto",
        "district": "East Valley Institute of Technology (4516)",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102189",
    },
    {
        "school": "EVIT - Apache Junction High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102233",
    },
    {
        "school": "EVIT - Gilbert High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102234",
    },
    {
        "school": "EVIT - Fountain Hills Vocational Center",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102235",
    },
    {
        "school": "EVIT - Higley High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102272",
    },
    {
        "school": "EVIT - Queen Creek High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102377",
    },
    {
        "school": "EVIT - Mesa High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102456",
    },
    {
        "school": "EVIT - Westwood High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102457",
    },
    {
        "school": "EVIT - Mountain View High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102458",
    },
    {
        "school": "EVIT - Dobson High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102459",
    },
    {
        "school": "EVIT - Red Mountain High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102460",
    },
    {
        "school": "EVIT - Skyline High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102461",
    },
    {
        "school": "EVIT - Tempe High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102462",
    },
    {
        "school": "EVIT - McClintock High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102463",
    },
    {
        "school": "EVIT - Marcos De Niza High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102464",
    },
    {
        "school": "EVIT - Corona Del Sol High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102465",
    },
    {
        "school": "EVIT - Mountain Pointe High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102466",
    },
    {
        "school": "EVIT - Desert Vista High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102467",
    },
    {
        "school": "EVIT - Arcadia High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102501",
    },
    {
        "school": "EVIT - Coronado High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102502",
    },
    {
        "school": "EVIT - Saguaro High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102503",
    },
    {
        "school": "EVIT - Chaparral High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102504",
    },
    {
        "school": "EVIT - Desert Mountain High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102505",
    },
    {
        "school": "EVIT - Basha High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973103081",
    },
    {
        "school": "EVIT - Hamilton High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973103087",
    },
    {
        "school": "Skyview High School",
        "district": "Kaizen Education Foundation dba Skyview High Schoo (79880)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40038801736",
    },
    {
        "school": "Alta Vista High School",
        "district": "American Charter Schools Foundation d.b.a. Alta Vi (80995)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40061903097",
    },
    {
        "school": "CAVIT - Central Arizona Valley Institute of Technology",
        "district": "Central Arizona Valley Institute of Technology (79385)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034802241",
    },
    {
        "school": "CAVIT - Santa Cruz Valley Union High School",
        "district": "Central Arizona Valley Institute of Technology (79385)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034802275",
    },
    {
        "school": "CAVIT - Maricopa Unified",
        "district": "Central Arizona Valley Institute of Technology (79385)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034802276",
    },
    {
        "school": "CAVIT - Florence Unified",
        "district": "Central Arizona Valley Institute of Technology (79385)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034802277",
    },
    {
        "school": "CAVIT - Coolidge High School",
        "district": "Central Arizona Valley Institute of Technology (79385)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034802278",
    },
    {
        "school": "CAVIT - Casa Grande Union High School",
        "district": "Central Arizona Valley Institute of Technology (79385)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034802279",
    },
    {
        "school": "Vista Grove Preparatory Academy Middle School",
        "district": "Kaizen Education Foundation dba Vista Grove Prepar (79871)",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40035102148",
    },
    {
        "school": "Apache Trail High School",
        "district": "American Charter Schools Foundation d.b.a. Apache  (79883)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40035701732",
    },
    {
        "school": "Akimel O'Otham Pee Posh (K-2)",
        "district": "Akimel O Otham Pee Posh Charter School Inc. (5978)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40040301989",
    },
    {
        "school": "Akimel O'Otham Pee Posh (3-5)",
        "district": "Akimel O'Otham Pee Posh Charter School Inc. (78966)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40040401993",
    },
    {
        "school": "Pinnacle High School - Casa Grande",
        "district": "Pinnacle Education-Casa Grande Inc. (81011)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40062601886",
    },
    {
        "school": "Mountain Shadows Education Center - Closed",
        "district": "Apache Junction Unified District (4443)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079002345",
    },
    {
        "school": "Copper Basin",
        "district": "Florence Unified School District (4437)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292002436",
    },
    {
        "school": "Skyline Ranch Elementary School",
        "district": "Florence Unified School District (4437)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292002559",
    },
    {
        "school": "Jack Harmon Elementary School",
        "district": "J O Combs Unified School District (4445)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40399002561",
    },
    {
        "school": "Kathryn Sue Simonton Elementary",
        "district": "J O Combs Unified School District (4445)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40399003067",
    },
    {
        "school": "Pima Butte Elementary School",
        "district": "Maricopa Unified School District (4441)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40472002560",
    },
    {
        "school": "Santa Rosa Elementary School",
        "district": "Maricopa Unified School District (4441)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40472003113",
    },
    {
        "school": "CVIT - Miami High School",
        "district": "Cobre Valley Institute of Technology District (79391)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40031602101",
    },
    {
        "school": "CVIT - Hayden High School",
        "district": "Cobre Valley Institute of Technology District (79391)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40031602102",
    },
    {
        "school": "Black Mountain Elementary School",
        "district": "Cave Creek Unified District (4244)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000100120",
    },
    {
        "school": "Desert Sun Academy",
        "district": "Cave Creek Unified District (4244)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000100616",
    },
    {
        "school": "Desert Arroyo Middle School",
        "district": "Cave Creek Unified District (4244)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000101203",
    },
    {
        "school": "Cactus Shadows High School",
        "district": "Cave Creek Unified District (4244)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000101204",
    },
    {
        "school": "Sonoran Trails Middle School",
        "district": "Cave Creek Unified District (4244)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000101871",
    },
    {
        "school": "Desert Willow Elementary School",
        "district": "Cave Creek Unified District (4244)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000101872",
    },
    {
        "school": "Ridgeline Academy Inc.",
        "district": "Ridgeline Academy Inc. (4301)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40003100689",
    },
    {
        "school": "Mesa Arts Academy",
        "district": "Boys & Girls Clubs of the East Valley dba Mesa Art (4305)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40003300703",
    },
    {
        "school": "Reid Traditional Schools' Valley Academy",
        "district": "Reid Traditional Schools' Valley Academy Inc. (4306)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40003400707",
    },
    {
        "school": "Foothills Academy",
        "district": "Foothills Academy (4309)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40003600709",
    },
    {
        "school": "Bennett Academy",
        "district": "Twenty First Century Charter School Inc. Bennett  (4310)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40003700712",
    },
    {
        "school": "Gateway Early College High School",
        "district": "Maricopa County Community College District dba Gat (4314)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40004100718",
    },
    {
        "school": "New School for the Arts",
        "district": "New School For The Arts (4316)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40004300733",
    },
    {
        "school": "Salt River High School",
        "district": "Salt River Pima-Maricopa  Community Schools (4320)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40004700744",
    },
    {
        "school": "NFL YET College Prep Academy",
        "district": "Espiritu Community Development Corp. (4335)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40005200752",
    },
    {
        "school": "Heritage Academy",
        "district": "Heritage Academy Inc. (4336)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40005300754",
    },
    {
        "school": "Villa Montessori - Phoenix Campus",
        "district": "Villa Montessori Charter School (4339)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40005400756",
    },
    {
        "school": "EduPreneurship Student Center (ESC) Phoenix",
        "district": "EduPreneurship Inc. (4341)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40005501731",
    },
    {
        "school": "Arizona School For The Arts",
        "district": "Arizona School For The Arts (4345)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40005600781",
    },
    {
        "school": "City View High School",
        "district": "Arizona Call-a-Teen Youth Resources Inc. (4346)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40005700784",
    },
    {
        "school": "Intelli-School - Paradise Valley",
        "district": "Intelli-School Inc. (4352)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40006101742",
    },
    {
        "school": "Benjamin Franklin Charter School - Crismon",
        "district": "Benjamin Franklin Charter School - Queen Creek (4355)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40006501599",
    },
    {
        "school": "Benjamin Franklin Charter School - Gilbert",
        "district": "Benjamin Franklin Charter School - Queen Creek (4355)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40006501600",
    },
    {
        "school": "Victory High School - Campus",
        "district": "Victory High School Inc. (4358)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40006701901",
    },
    {
        "school": "Montessori Day Public Schools Chartered - Tempe",
        "district": "Montessori Day Public Schools Chartered Inc. (4359)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40006800825",
    },
    {
        "school": "Montessori Day Public Schools Chartered - Mountainside",
        "district": "Montessori Day Public Schools Chartered Inc. (4359)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40006801745",
    },
    {
        "school": "Khalsa Montessori Elementary School - Phoenix",
        "district": "Khalsa Montessori Elementary Schools (4360)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40006900826",
    },
    {
        "school": "Tempe Preparatory Academy",
        "district": "Tempe Preparatory Academy (4361)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40007000831",
    },
    {
        "school": "Bright Beginnings School #1",
        "district": "Bright Beginnings School Inc. (4362)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40007100832",
    },
    {
        "school": "Montessori Education Centre Charter School - Mesa",
        "district": "Montessori Education Centre Charter School (4363)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40007200834",
    },
    {
        "school": "Hearn Academy The - A Ball Charter School",
        "district": "Ball Charter Schools (Hearn) (4294)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40010001714",
    },
    {
        "school": "Friendly House Academia Del Pueblo Elem",
        "district": "Friendly House Inc. (4303)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40010201582",
    },
    {
        "school": "Ombudsman - Charter East",
        "district": "Ombudsman Educational Services Ltd.a subsidiary  (4323)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40010301583",
    },
    {
        "school": "Ombudsman - Charter West",
        "district": "Ombudsman Educational Services Ltd.a subsidiary  (4323)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40010301724",
    },
    {
        "school": "Ombudsman - Charter Metro",
        "district": "Ombudsman Educational Services Ltd.a subsidiary  (4323)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40010302008",
    },
    {
        "school": "Ombudsman - Charter Northeast",
        "district": "Ombudsman Educational Services Ltd.a subsidiary  (4323)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40010302139",
    },
    {
        "school": "Hillcrest Academy",
        "district": "Hillcrest Academy Inc. (4328)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40010501587",
    },
    {
        "school": "AAEC - Paradise Valley",
        "district": "Arizona Agribusiness & Equine Center Inc. (4331)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40010601892",
    },
    {
        "school": "Humanities and Sciences High School - Phoenix",
        "district": "International Commerce Secondary Schools Inc. (4334)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40010701590",
    },
    {
        "school": "International Commerce High School - Tempe",
        "district": "Humanities and Sciences Academy of the United Stat (4337)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40010802145",
    },
    {
        "school": "Humanities and Science High School - Tempe",
        "district": "Humanities and Sciences Academy of the United Stat (4337)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40010802146",
    },
    {
        "school": "Phoenix Advantage Charter School",
        "district": "Phoenix Advantage Charter School Inc. (4338)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40010901592",
    },
    {
        "school": "Center for Educational Excellence",
        "district": "Allen-Cochran Enterprises Inc. (4347)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011101594",
    },
    {
        "school": "American Leadership Academy Gilbert K-6",
        "district": "American Leadership Academy Inc. (4348)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011201595",
    },
    {
        "school": "Fountain Hills Charter School",
        "district": "Fountain Hills Charter School (4356)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011301601",
    },
    {
        "school": "Accelerated Learning Center",
        "district": "Accelerated Learning Center Inc. (4297)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40012101581",
    },
    {
        "school": "ACCLAIM Academy",
        "district": "Acclaim Charter School (4325)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40012201585",
    },
    {
        "school": "Genesis Academy",
        "district": "Genesis Program Inc. (4332)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40012401589",
    },
    {
        "school": "Challenge Charter School",
        "district": "Challenge School Inc. (6362)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40013501748",
    },
    {
        "school": "Girls Leadership Academy of Arizona",
        "district": "Florence Crittenton Services of Arizona Inc. (4300)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40014401717",
    },
    {
        "school": "Gem Charter School",
        "district": "Gem Charter School Inc. (6372)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40014501750",
    },
    {
        "school": "Kaizen Education Foundation dba El Dorado High School",
        "district": "Kaizen Education Foundation dba El Dorado High Sch (4342)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40014901897",
    },
    {
        "school": "New Horizon School for the Performing Arts",
        "district": "New Horizon School for the Performing Arts (4366)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40015101747",
    },
    {
        "school": "Learning Institute The",
        "district": "Phoenix School of Academic Excellence The (6379)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40015301902",
    },
    {
        "school": "Sequoia Choice School Arizona Distance Learning School",
        "district": "Edkey Inc. - Sequoia Choice Schools (4329)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40015701728",
    },
    {
        "school": "Keystone Montessori Charter School",
        "district": "Keystone Montessori Charter School Inc. (10878)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40016501755",
    },
    {
        "school": "Benchmark School",
        "district": "Benchmark School Inc. (10972)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40018101889",
    },
    {
        "school": "Cambridge Academy East",
        "district": "Cambridge Academy  East  Inc (78888)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40018201890",
    },
    {
        "school": "Dobson Academy The - A Ball Charter School",
        "district": "Ball Charter Schools (Dobson) (79204)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40018401713",
    },
    {
        "school": "SABIS International",
        "district": "Phoenix Education Management LLC (4340)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40018502147",
    },
    {
        "school": "Stepping Stones Academy",
        "district": "Stepping Stones Academy (10966)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40018701906",
    },
    {
        "school": "Liberty Traditional Charter School",
        "district": "Liberty Traditional Charter School (10968)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40019001908",
    },
    {
        "school": "Champion Schools",
        "district": "Fit Kids Inc. dba Champion Schools (78783)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40019101909",
    },
    {
        "school": "Mission Montessori Academy",
        "district": "Little Lamb Community School (79050)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40021702010",
    },
    {
        "school": "Burke Basic School",
        "district": "American Basic Schools LLC (79215)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40021801913",
    },
    {
        "school": "Tech Campus",
        "district": "Career Success Schools (79047)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40021902011",
    },
    {
        "school": "Kaizen Education Foundation dba South Pointe Elementary Scho",
        "district": "Kaizen Education Foundation dba South Pointe Eleme (79233)",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40022101921",
    },
    {
        "school": "Horizon Honors Secondary School",
        "district": "Horizon Community Learning Center Inc. (79264)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40022501887",
    },
    {
        "school": "South Pointe Junior High School",
        "district": "Kaizen Education Foundation dba South Pointe Junio (78965)",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40022702017",
    },
    {
        "school": "Milestones Charter School",
        "district": "Milestones Charter School (79207)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40022901918",
    },
    {
        "school": "James Madison Preparatory School",
        "district": "James Madison Preparatory School (79063)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40023102021",
    },
    {
        "school": "Self Development Charter School",
        "district": "Self Development Charter School (79072)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40023202022",
    },
    {
        "school": "Paramount Academy",
        "district": "Paramount Education Studies Inc (79205)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40023701925",
    },
    {
        "school": "Metropolitan Arts Institute",
        "district": "Metropolitan Arts Institute Inc. (5181)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40023801854",
    },
    {
        "school": "Paradise Honors Elementary School",
        "district": "Paragon Management Inc. (5180)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40024102029",
    },
    {
        "school": "Skyline Prep High School",
        "district": "Skyline Schools Inc. (79084)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40024302030",
    },
    {
        "school": "Sequoia Secondary School",
        "district": "Edkey Inc. - Sequoia Charter School (6446)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40024401855",
    },
    {
        "school": "Sequoia Elementary School",
        "district": "Edkey Inc. - Sequoia Charter School (6446)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40024402153",
    },
    {
        "school": "Student Choice High School",
        "district": "GAR LLC dba Student Choice High School (78997)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40027302013",
    },
    {
        "school": "Career and College Prep",
        "district": "AIBT Non-Profit Charter High School - Phoenix (79053)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40027402020",
    },
    {
        "school": "Academy with Community Partners",
        "district": "Academy with Community Partners  Inc (79213)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40027601841",
    },
    {
        "school": "Deer Valley Academy",
        "district": "Deer Valley Charter Schools Inc. (79496)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40027802168",
    },
    {
        "school": "Imagine West Gilbert Elementary",
        "district": "West Gilbert Charter Elementary School Inc. (79497)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40027902170",
    },
    {
        "school": "Lehi Montessori",
        "district": "Montessori House Inc. d.b.a. Lehi Montessori  (79548)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40028502173",
    },
    {
        "school": "Premier Charter High School",
        "district": "Premier Charter High School (79569)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40028802176",
    },
    {
        "school": "Pan-American Charter School",
        "district": "Pan-American Elementary Charter (79578)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029002177",
    },
    {
        "school": "Legacy Elementary School",
        "district": "Legacy Schools (79660)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029802143",
    },
    {
        "school": "Arizona Preparatory Academy",
        "district": "North Star Charter School Inc. (79701)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40030302181",
    },
    {
        "school": "E-Institute at Union Hills",
        "district": "E-Institute Charter Schools Inc. (79059)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40031102151",
    },
    {
        "school": "Pinnacle Charter High School",
        "district": "Pinnacle Education-WMCB Inc. (79439)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40032102155",
    },
    {
        "school": "Crown Charter School",
        "district": "Crown Charter School Inc (79443)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40032302159",
    },
    {
        "school": "Arizona Charter Academy",
        "district": "Success School (79453)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40032602162",
    },
    {
        "school": "North Pointe Preparatory",
        "district": "Pointe Schools (79455)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40032702163",
    },
    {
        "school": "Crown Point High School",
        "district": "James Sandoval Preparatory High School (79475)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40033202165",
    },
    {
        "school": "Noah Webster Schools- Mesa",
        "district": "Noah Webster Schools - Mesa (10760)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40034001940",
    },
    {
        "school": "Agua Fria High School",
        "district": "Agua Fria Union High School District (4289)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40045000001",
    },
    {
        "school": "Millennium High School",
        "district": "Agua Fria Union High School District (4289)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40045001884",
    },
    {
        "school": "Aguila Elementary School",
        "district": "Aguila Elementary District (4249)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40048000002",
    },
    {
        "school": "James W. Rice Elementary School",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060000007",
    },
    {
        "school": "Barcelona Elementary School",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060000008",
    },
    {
        "school": "Catalina Ventura School",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060000009",
    },
    {
        "school": "Cordova Elementary School",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060000010",
    },
    {
        "school": "Granada Elementary School-East Campus",
        "district": "Alhambra Elementary District (4280)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060000012",
    },
    {
        "school": "R E Simpson School",
        "district": "Alhambra Elementary District (4280)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060000015",
    },
    {
        "school": "Sevilla Elementary School-East Campus",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060000016",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060000018",
    },
    {
        "school": "Alhambra Traditional School",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060001283",
    },
    {
        "school": "Granada Elementary School-West Campus",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060001486",
    },
    {
        "school": "Carol G. Peck Elementary School",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060001707",
    },
    {
        "school": "Sevilla Elementary School-West Campus",
        "district": "Alhambra Elementary District (4280)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060002002",
    },
    {
        "school": "Arlington Elementary School",
        "district": "Arlington Elementary District (4274)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40084000044",
    },
    {
        "school": "Michael Anderson",
        "district": "Avondale Elementary District (4272)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096000049",
    },
    {
        "school": "Lattie Coor",
        "district": "Avondale Elementary District (4272)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096000051",
    },
    {
        "school": "Eliseo C. Felix School",
        "district": "Avondale Elementary District (4272)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096001154",
    },
    {
        "school": "Wildflower Accelerated Academy",
        "district": "Avondale Elementary District (4272)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096001878",
    },
    {
        "school": "Pat Tillman Middle School",
        "district": "Balsz Elementary District (4268)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40105000054",
    },
    {
        "school": "David Crockett Elementary School",
        "district": "Balsz Elementary District (4268)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40105000055",
    },
    {
        "school": "Griffith Elementary School",
        "district": "Balsz Elementary District (4268)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40105000056",
    },
    {
        "school": "Buckeye Union High School",
        "district": "Buckeye Union High School District (4284)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40141000075",
    },
    {
        "school": "Estrella Foothills High School",
        "district": "Buckeye Union High School District (4284)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40141002137",
    },
    {
        "school": "Cartwright School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000089",
    },
    {
        "school": "Charles W. Harris School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000091",
    },
    {
        "school": "Desert Sands Middle School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000092",
    },
    {
        "school": "Estrella Middle School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000093",
    },
    {
        "school": "Frank Borman School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000094",
    },
    {
        "school": "Glenn L. Downs School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000095",
    },
    {
        "school": "Heatherbrae School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000096",
    },
    {
        "school": "Holiday Park School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000097",
    },
    {
        "school": "John F. Long",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000098",
    },
    {
        "school": "Justine Spitalny School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000100",
    },
    {
        "school": "Palm Lane",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000101",
    },
    {
        "school": "Peralta School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000102",
    },
    {
        "school": "Starlight Park School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000104",
    },
    {
        "school": "Sunset School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168000105",
    },
    {
        "school": "Byron A. Barry School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168001054",
    },
    {
        "school": "Tomahawk School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168001055",
    },
    {
        "school": "G. Frank Davidson",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168001709",
    },
    {
        "school": "Marc T. Atkinson Middle School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168002005",
    },
    {
        "school": "Bret R. Tarver",
        "district": "Cartwright Elementary District (4282)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168002135",
    },
    {
        "school": "Sanborn Elementary School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187000013",
    },
    {
        "school": "Chandler High School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187000123",
    },
    {
        "school": "San Marcos Elementary School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187000125",
    },
    {
        "school": "Galveston Elementary School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187000128",
    },
    {
        "school": "Hartford Sylvia Encinas Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187000129",
    },
    {
        "school": "Knox Gifted Academy",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187000131",
    },
    {
        "school": "Willis Junior High School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187000133",
    },
    {
        "school": "Dr Howard K Conley Elementary School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187000615",
    },
    {
        "school": "Frye Elementary School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001058",
    },
    {
        "school": "Weinberg Elementary School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001155",
    },
    {
        "school": "John M Andersen Elementary School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001206",
    },
    {
        "school": "Chandler Traditional Academy-Humphrey",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001289",
    },
    {
        "school": "Shumway Leadership Academy",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001359",
    },
    {
        "school": "Chandler Traditional Academy - Goodman",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001399",
    },
    {
        "school": "John M Andersen Jr High School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001400",
    },
    {
        "school": "Anna Marie Jacobson  Elementary School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001532",
    },
    {
        "school": "Bogle Junior High School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001533",
    },
    {
        "school": "Rudy G Bologna Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001675",
    },
    {
        "school": "Robert and Danell Tarwater Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001676",
    },
    {
        "school": "Hamilton High School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001677",
    },
    {
        "school": "Pathways Learning Center",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001678",
    },
    {
        "school": "Basha Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187001996",
    },
    {
        "school": "Jane D. Hull Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002125",
    },
    {
        "school": "Creighton Elementary School",
        "district": "Creighton Elementary District (4263)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40243000174",
    },
    {
        "school": "Larry C Kennedy School",
        "district": "Creighton Elementary District (4263)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40243000176",
    },
    {
        "school": "Loma Linda Elementary School",
        "district": "Creighton Elementary District (4263)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40243000177",
    },
    {
        "school": "Monte Vista Elementary School",
        "district": "Creighton Elementary District (4263)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40243000178",
    },
    {
        "school": "Papago School",
        "district": "Creighton Elementary District (4263)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40243000179",
    },
    {
        "school": "Biltmore Preparatory Academy",
        "district": "Creighton Elementary District (4263)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40243000180",
    },
    {
        "school": "William T Machan Elementary School",
        "district": "Creighton Elementary District (4263)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40243000181",
    },
    {
        "school": "Gateway School",
        "district": "Creighton Elementary District (4263)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40243001704",
    },
    {
        "school": "Compass Center",
        "district": "Creighton Elementary District (4263)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40243001998",
    },
    {
        "school": "Excelencia School",
        "district": "Creighton Elementary District (4263)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40243001999",
    },
    {
        "school": "Dysart Elementary School",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269000197",
    },
    {
        "school": "Dysart High School",
        "district": "Dysart Unified District (4243)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269000198",
    },
    {
        "school": "El Mirage School",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269000199",
    },
    {
        "school": "Luke Elementary School",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269000200",
    },
    {
        "school": "Surprise Elementary School",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269000201",
    },
    {
        "school": "Kingswood Elementary School",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269001462",
    },
    {
        "school": "West Point Elementary School",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002126",
    },
    {
        "school": "Fountain Hills High School",
        "district": "Fountain Hills Unified District (4247)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40304000038",
    },
    {
        "school": "Fountain Hills Middle School",
        "district": "Fountain Hills Unified District (4247)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40304000639",
    },
    {
        "school": "McDowell Mountain Elementary School",
        "district": "Fountain Hills Unified District (4247)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40304001296",
    },
    {
        "school": "Fowler Elementary School",
        "district": "Fowler Elementary District (4273)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40306000240",
    },
    {
        "school": "Santa Maria Middle School",
        "district": "Fowler Elementary District (4273)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40306000679",
    },
    {
        "school": "Sunridge Elementary School",
        "district": "Fowler Elementary District (4273)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40306001159",
    },
    {
        "school": "Gila Bend Elementary",
        "district": "Gila Bend Unified District (4238)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40331000255",
    },
    {
        "school": "Gila Bend High School",
        "district": "Gila Bend Unified District (4238)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40331000256",
    },
    {
        "school": "Highland High School",
        "district": "Gilbert Unified District (4239)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340000246",
    },
    {
        "school": "Gilbert Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340000257",
    },
    {
        "school": "Gilbert High School",
        "district": "Gilbert Unified District (4239)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340000258",
    },
    {
        "school": "Greenfield Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340000260",
    },
    {
        "school": "Patterson Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340000261",
    },
    {
        "school": "Mesquite Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340000265",
    },
    {
        "school": "Greenfield Junior High School",
        "district": "Gilbert Unified District (4239)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340000594",
    },
    {
        "school": "Playa del Rey Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340000595",
    },
    {
        "school": "Towne Meadows Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340000596",
    },
    {
        "school": "Sonoma Ranch Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340000601",
    },
    {
        "school": "Superstition Springs Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340000602",
    },
    {
        "school": "Neely Traditional Academy",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001064",
    },
    {
        "school": "Finley Farms Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001192",
    },
    {
        "school": "Pioneer Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001215",
    },
    {
        "school": "Mesquite Jr High School",
        "district": "Gilbert Unified District (4239)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001216",
    },
    {
        "school": "Islands Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001365",
    },
    {
        "school": "Houston Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001366",
    },
    {
        "school": "Burk Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001401",
    },
    {
        "school": "Val Vista Lakes Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001490",
    },
    {
        "school": "Harris Elementary School",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001537",
    },
    {
        "school": "Highland Jr High School",
        "district": "Gilbert Unified District (4239)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001669",
    },
    {
        "school": "Mesquite High School",
        "district": "Gilbert Unified District (4239)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001670",
    },
    {
        "school": "Oak Tree Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001838",
    },
    {
        "school": "Settlers Point Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001839",
    },
    {
        "school": "Carol Rae Ranch Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001984",
    },
    {
        "school": "Boulder Creek Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001985",
    },
    {
        "school": "Ashland Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340001986",
    },
    {
        "school": "Desert Ridge Jr. High",
        "district": "Gilbert Unified District (4239)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340002112",
    },
    {
        "school": "Augusta Ranch Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340002114",
    },
    {
        "school": "Discovery School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342000058",
    },
    {
        "school": "Glendale American School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342000262",
    },
    {
        "school": "Bicentennial North School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342000263",
    },
    {
        "school": "Glenn F Burton School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342000264",
    },
    {
        "school": "Harold W Smith School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342000266",
    },
    {
        "school": "Isaac E Imes School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342000267",
    },
    {
        "school": "Melvin E Sine School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342000268",
    },
    {
        "school": "Glendale Landmark School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342000269",
    },
    {
        "school": "Don Mensendick School",
        "district": "Glendale Elementary District (4271)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342000270",
    },
    {
        "school": "Horizon School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342000271",
    },
    {
        "school": "William C Jack School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342000272",
    },
    {
        "school": "Desert Garden Elementary School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342001254",
    },
    {
        "school": "Challenger Middle School",
        "district": "Glendale Elementary District (4271)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342001402",
    },
    {
        "school": "Bicentennial South School",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342001538",
    },
    {
        "school": "Coyote Ridge",
        "district": "Glendale Elementary District (4271)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40342002121",
    },
    {
        "school": "Apollo High School",
        "district": "Glendale Union High School District (4285)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40345000275",
    },
    {
        "school": "Cortez High School",
        "district": "Glendale Union High School District (4285)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40345000277",
    },
    {
        "school": "Glendale High School",
        "district": "Glendale Union High School District (4285)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40345000278",
    },
    {
        "school": "Greenway High School",
        "district": "Glendale Union High School District (4285)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40345000279",
    },
    {
        "school": "Moon Valley High School",
        "district": "Glendale Union High School District (4285)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40345000280",
    },
    {
        "school": "Sunnyslope High School",
        "district": "Glendale Union High School District (4285)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40345000281",
    },
    {
        "school": "Thunderbird High School",
        "district": "Glendale Union High School District (4285)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40345000282",
    },
    {
        "school": "Washington High School",
        "district": "Glendale Union High School District (4285)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40345000283",
    },
    {
        "school": "Independence High School",
        "district": "Glendale Union High School District (4285)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40345000284",
    },
    {
        "school": "Glendale Union High School District Online Learning Academy",
        "district": "Glendale Union High School District (4285)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40345001574",
    },
    {
        "school": "Higley Traditional Academy",
        "district": "Higley Unified School District (4248)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378001392",
    },
    {
        "school": "Coronado Elementary School",
        "district": "Higley Unified School District (4248)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378001987",
    },
    {
        "school": "San Tan Elementary",
        "district": "Higley Unified School District (4248)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378002118",
    },
    {
        "school": "Higley High School",
        "district": "Higley Unified School District (4248)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378002119",
    },
    {
        "school": "Alta E Butler School",
        "district": "Isaac Elementary District (4259)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396000314",
    },
    {
        "school": "Isaac Middle School",
        "district": "Isaac Elementary District (4259)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396000315",
    },
    {
        "school": "Mitchell Elementary School",
        "district": "Isaac Elementary District (4259)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396000316",
    },
    {
        "school": "P T Coe Elementary School",
        "district": "Isaac Elementary District (4259)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396000317",
    },
    {
        "school": "J B Sutton Elementary School",
        "district": "Isaac Elementary District (4259)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396000318",
    },
    {
        "school": "Joseph Zito Elementary School",
        "district": "Isaac Elementary District (4259)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396000319",
    },
    {
        "school": "Pueblo Del Sol Middle School",
        "district": "Isaac Elementary District (4259)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396000650",
    },
    {
        "school": "Esperanza Elementary School",
        "district": "Isaac Elementary District (4259)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396001542",
    },
    {
        "school": "Bret Tarver Education Complex",
        "district": "Isaac Elementary District (4259)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396001543",
    },
    {
        "school": "Morris K. Udall Escuela de Bellas Artes",
        "district": "Isaac Elementary District (4259)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396001876",
    },
    {
        "school": "Kyrene Akimel A-Al Middle School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000083",
    },
    {
        "school": "Kyrene de la Mirada School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000099",
    },
    {
        "school": "Kyrene de la Esperanza School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000297",
    },
    {
        "school": "Kyrene de las Lomas School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000332",
    },
    {
        "school": "Kyrene Middle School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000334",
    },
    {
        "school": "Kyrene del Norte School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000335",
    },
    {
        "school": "C I Waggoner School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000336",
    },
    {
        "school": "Kyrene Aprende Middle School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000653",
    },
    {
        "school": "Kyrene de las Brisas School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000656",
    },
    {
        "school": "Kyrene de los Cerritos School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000660",
    },
    {
        "school": "Kyrene Altadena Middle School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000665",
    },
    {
        "school": "Kyrene de las Manitas School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423000677",
    },
    {
        "school": "Kyrene de los Ninos School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001127",
    },
    {
        "school": "Kyrene del Cielo School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001128",
    },
    {
        "school": "Kyrene de la Paloma School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001231",
    },
    {
        "school": "Kyrene de la Colina School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001299",
    },
    {
        "school": "Kyrene del Pueblo Middle School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001300",
    },
    {
        "school": "Kyrene Traditional Academy",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001370",
    },
    {
        "school": "Kyrene de la Mariposa School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001371",
    },
    {
        "school": "Kyrene De Los Lagos School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001405",
    },
    {
        "school": "Kyrene Monte Vista School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001466",
    },
    {
        "school": "Kyrene Centennial Middle School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001496",
    },
    {
        "school": "Kyrene de la Sierra School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001546",
    },
    {
        "school": "Kyrene de la Estrella Elementary School",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423001877",
    },
    {
        "school": "Kyrene del Milenio",
        "district": "Kyrene Elementary District (4267)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40423002000",
    },
    {
        "school": "Laveen Elementary School",
        "district": "Laveen Elementary District (4276)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40429000341",
    },
    {
        "school": "Maurice C. Cash Elementary School",
        "district": "Laveen Elementary District (4276)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40429000342",
    },
    {
        "school": "Vista del Sur Accelerated",
        "district": "Laveen Elementary District (4276)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40429001391",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Liberty Elementary District (4266)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40432000343",
    },
    {
        "school": "Estrella Mountain Elementary School",
        "district": "Liberty Elementary District (4266)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40432001467",
    },
    {
        "school": "Rainbow Valley Elementary School",
        "district": "Liberty Elementary District (4266)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40432002133",
    },
    {
        "school": "Litchfield Elementary School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438000344",
    },
    {
        "school": "Scott L Libby Elementary School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438000345",
    },
    {
        "school": "Palm Valley Elementary",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438001420",
    },
    {
        "school": "Western Sky Middle School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438001547",
    },
    {
        "school": "Rancho Santa Fe Elementary School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438001881",
    },
    {
        "school": "White Tanks Learning Center",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40438002003",
    },
    {
        "school": "Wigwam Creek Middle School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438002004",
    },
    {
        "school": "Littleton Elementary School",
        "district": "Littleton Elementary District (4278)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40444000347",
    },
    {
        "school": "Underdown Learning Center",
        "district": "Littleton Elementary District (4278)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40444000348",
    },
    {
        "school": "Madison Heights Elementary School",
        "district": "Madison Elementary District (4270)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40450000353",
    },
    {
        "school": "Madison Meadows School",
        "district": "Madison Elementary District (4270)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40450000354",
    },
    {
        "school": "Madison #1 Elementary School",
        "district": "Madison Elementary District (4270)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40450000355",
    },
    {
        "school": "Madison Park School",
        "district": "Madison Elementary District (4270)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40450000357",
    },
    {
        "school": "Madison Richard Simis School",
        "district": "Madison Elementary District (4270)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40450000358",
    },
    {
        "school": "Madison Rose Lane School",
        "district": "Madison Elementary District (4270)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40450000359",
    },
    {
        "school": "Madison Camelview Elementary",
        "district": "Madison Elementary District (4270)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40450000678",
    },
    {
        "school": "Franklin West Elementary",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000118",
    },
    {
        "school": "Kerr Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000229",
    },
    {
        "school": "Entz Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000230",
    },
    {
        "school": "Adams Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000378",
    },
    {
        "school": "Alma Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000379",
    },
    {
        "school": "Carson Junior  High School",
        "district": "Mesa Unified District (4235)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000380",
    },
    {
        "school": "Edison Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000382",
    },
    {
        "school": "Eisenhower Center for Innovation",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000383",
    },
    {
        "school": "Emerson Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000384",
    },
    {
        "school": "Field Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000385",
    },
    {
        "school": "Franklin East Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000386",
    },
    {
        "school": "Fremont Junior High School",
        "district": "Mesa Unified District (4235)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000387",
    },
    {
        "school": "Hale Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000388",
    },
    {
        "school": "Michael T. Hughes Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000389",
    },
    {
        "school": "Holmes Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000391",
    },
    {
        "school": "Irving Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000393",
    },
    {
        "school": "Salk Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000394",
    },
    {
        "school": "Kino Junior High School",
        "district": "Mesa Unified District (4235)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000396",
    },
    {
        "school": "Lehi Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000397",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000398",
    },
    {
        "school": "Lindbergh Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000399",
    },
    {
        "school": "Longfellow Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000400",
    },
    {
        "school": "Lowell Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000401",
    },
    {
        "school": "MacArthur Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000402",
    },
    {
        "school": "Mesa High School",
        "district": "Mesa Unified District (4235)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000404",
    },
    {
        "school": "Mountain View High School",
        "district": "Mesa Unified District (4235)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000406",
    },
    {
        "school": "Power Learning Center",
        "district": "Mesa Unified District (4235)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000407",
    },
    {
        "school": "Poston Junior High School",
        "district": "Mesa Unified District (4235)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000409",
    },
    {
        "school": "Powell Junior High School",
        "district": "Mesa Unified District (4235)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000410",
    },
    {
        "school": "Redbird Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000411",
    },
    {
        "school": "Rhodes Junior High School",
        "district": "Mesa Unified District (4235)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000412",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000413",
    },
    {
        "school": "Stevenson Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000415",
    },
    {
        "school": "Taft Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000416",
    },
    {
        "school": "Washington Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000417",
    },
    {
        "school": "Webster Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000418",
    },
    {
        "school": "Westwood High School",
        "district": "Mesa Unified District (4235)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000419",
    },
    {
        "school": "Whitman Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000420",
    },
    {
        "school": "Whittier Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000421",
    },
    {
        "school": "Red Mountain Ranch Elementary",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000551",
    },
    {
        "school": "Bush Elementary",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000553",
    },
    {
        "school": "Sunridge Learning Center",
        "district": "Mesa Unified District (4235)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000555",
    },
    {
        "school": "McKellips Learning Center",
        "district": "Mesa Unified District (4235)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000578",
    },
    {
        "school": "Stapley Junior High School",
        "district": "Mesa Unified District (4235)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497000580",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001070",
    },
    {
        "school": "Keller Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001071",
    },
    {
        "school": "Pomeroy Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001072",
    },
    {
        "school": "Highland Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001073",
    },
    {
        "school": "Crismon Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001074",
    },
    {
        "school": "Dobson High School",
        "district": "Mesa Unified District (4235)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001132",
    },
    {
        "school": "Robson Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001166",
    },
    {
        "school": "Sirrine Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001167",
    },
    {
        "school": "Las Sendas Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001186",
    },
    {
        "school": "Eagleridge Enrichment Program",
        "district": "Mesa Unified District (4235)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001188",
    },
    {
        "school": "Johnson Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001233",
    },
    {
        "school": "Taylor Junior High School",
        "district": "Mesa Unified District (4235)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001234",
    },
    {
        "school": "Hendrix Junior High School",
        "district": "Mesa Unified District (4235)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001235",
    },
    {
        "school": "O'Connor Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001305",
    },
    {
        "school": "Frost Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001373",
    },
    {
        "school": "Mendoza Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001374",
    },
    {
        "school": "Ishikawa Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001375",
    },
    {
        "school": "Shepherd Junior High School",
        "district": "Mesa Unified District (4235)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001376",
    },
    {
        "school": "Madison Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001409",
    },
    {
        "school": "Sousa Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001410",
    },
    {
        "school": "Red Mountain High School",
        "district": "Mesa Unified District (4235)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001411",
    },
    {
        "school": "Hermosa Vista Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001469",
    },
    {
        "school": "Falcon Hill Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001497",
    },
    {
        "school": "Porter Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001550",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001667",
    },
    {
        "school": "Patterson Elementary",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001827",
    },
    {
        "school": "Skyline High School",
        "district": "Mesa Unified District (4235)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001830",
    },
    {
        "school": "East Valley Academy",
        "district": "Mesa Unified District (4235)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40497001831",
    },
    {
        "school": "Mesa Distance Learning Program",
        "district": "Mesa Unified District (4235)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001832",
    },
    {
        "school": "Guerrero Elementary School",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497001981",
    },
    {
        "school": "Brinton Elementary",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497002108",
    },
    {
        "school": "Red Mountain Center for Early Education",
        "district": "Mesa Unified District (4235)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40497002109",
    },
    {
        "school": "Smith Junior High School",
        "district": "Mesa Unified District (4235)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497002110",
    },
    {
        "school": "Mobile Elementary School",
        "district": "Mobile Elementary District (4253)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40510000431",
    },
    {
        "school": "Morristown Elementary School",
        "district": "Morristown Elementary District (4251)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40534000442",
    },
    {
        "school": "Arthur M Hamilton School",
        "district": "Murphy Elementary District (4265)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40540000446",
    },
    {
        "school": "William R Sullivan Elementary School",
        "district": "Murphy Elementary District (4265)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40540000447",
    },
    {
        "school": "Jack L Kuban Elementary School",
        "district": "Murphy Elementary District (4265)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40540001309",
    },
    {
        "school": "Nadaburg Elementary School",
        "district": "Nadaburg Unified School District (4252)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40546000449",
    },
    {
        "school": "Clarendon School",
        "district": "Osborn Elementary District (4262)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40567000459",
    },
    {
        "school": "Encanto School",
        "district": "Osborn Elementary District (4262)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40567000460",
    },
    {
        "school": "Osborn Middle School",
        "district": "Osborn Elementary District (4262)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40567000461",
    },
    {
        "school": "Solano School",
        "district": "Osborn Elementary District (4262)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40567000464",
    },
    {
        "school": "Longview Elementary School",
        "district": "Osborn Elementary District (4262)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40567001170",
    },
    {
        "school": "Palo Verde Elementary School",
        "district": "Palo Verde Elementary District (4275)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40585000470",
    },
    {
        "school": "Cactus View Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000126",
    },
    {
        "school": "Greenway Middle School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000130",
    },
    {
        "school": "Copper Canyon Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000276",
    },
    {
        "school": "Campo Bello Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000475",
    },
    {
        "school": "Desert Cove Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000477",
    },
    {
        "school": "Desert Shadows Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000478",
    },
    {
        "school": "Desert Shadows Middle School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000479",
    },
    {
        "school": "Indian Bend Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000482",
    },
    {
        "school": "Larkspur Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000483",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000484",
    },
    {
        "school": "Mercury Mine Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000485",
    },
    {
        "school": "Palomino Primary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000487",
    },
    {
        "school": "North Canyon High School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000488",
    },
    {
        "school": "Shadow Mountain High School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000491",
    },
    {
        "school": "Shea Middle School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000492",
    },
    {
        "school": "Sonoran Sky Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000606",
    },
    {
        "school": "Whispering Wind Academy",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000610",
    },
    {
        "school": "Boulder Creek Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593000611",
    },
    {
        "school": "Sandpiper Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001081",
    },
    {
        "school": "Echo Mountain Primary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001083",
    },
    {
        "school": "Horizon High School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001084",
    },
    {
        "school": "Sunrise Middle School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001136",
    },
    {
        "school": "Desert Trails Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001195",
    },
    {
        "school": "Vista Verde Middle School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001218",
    },
    {
        "school": "Explorer Middle School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001230",
    },
    {
        "school": "Desert Springs Preparatory Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001239",
    },
    {
        "school": "Eagle Ridge Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001240",
    },
    {
        "school": "Roadrunner School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40593001313",
    },
    {
        "school": "North Ranch Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001378",
    },
    {
        "school": "Quail Run Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001419",
    },
    {
        "school": "Hidden Hills Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001471",
    },
    {
        "school": "Paradise Valley High School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001553",
    },
    {
        "school": "Grayhawk Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001672",
    },
    {
        "school": "Sunset Canyon School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001869",
    },
    {
        "school": "Pinnacle High School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593001995",
    },
    {
        "school": "Desert Mirage Elementary School",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621000304",
    },
    {
        "school": "Desert Horizon Elementary School",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621000505",
    },
    {
        "school": "Pendergast Elementary School",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621000506",
    },
    {
        "school": "Westwind Intermediate School - Closed",
        "district": "Pendergast Elementary District (4283)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621001089",
    },
    {
        "school": "Villa De Paz Elementary School",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621001241",
    },
    {
        "school": "Garden Lakes Elementary School",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621001499",
    },
    {
        "school": "Copper King Elementary",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621001573",
    },
    {
        "school": "Canyon Breeze Elementary",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621002006",
    },
    {
        "school": "Sonoran Sky Elementary School",
        "district": "Pendergast Elementary District (4283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621002136",
    },
    {
        "school": "Marshall Ranch Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000132",
    },
    {
        "school": "Santa Fe Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000238",
    },
    {
        "school": "Alta Loma School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000507",
    },
    {
        "school": "Cactus High School",
        "district": "Peoria Unified School District (4237)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000508",
    },
    {
        "school": "Desert Palms Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000510",
    },
    {
        "school": "Ira A Murphy",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000511",
    },
    {
        "school": "Kachina Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000512",
    },
    {
        "school": "Peoria Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000513",
    },
    {
        "school": "Peoria High School",
        "district": "Peoria Unified School District (4237)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000514",
    },
    {
        "school": "Pioneer Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000515",
    },
    {
        "school": "Paseo Verde Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000584",
    },
    {
        "school": "Desert Harbor Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000585",
    },
    {
        "school": "Cheyenne Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000586",
    },
    {
        "school": "Sunrise Mountain High School",
        "district": "Peoria Unified School District (4237)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625000589",
    },
    {
        "school": "Heritage School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001090",
    },
    {
        "school": "Foothills Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001091",
    },
    {
        "school": "Copperwood School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001092",
    },
    {
        "school": "Sundance Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001137",
    },
    {
        "school": "Cotton Boll School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001242",
    },
    {
        "school": "Oakwood Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001243",
    },
    {
        "school": "Ironwood High School",
        "district": "Peoria Unified School District (4237)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001315",
    },
    {
        "school": "Desert Valley Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001316",
    },
    {
        "school": "Sahuaro Ranch Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001380",
    },
    {
        "school": "Oasis Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001424",
    },
    {
        "school": "Sun Valley Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001425",
    },
    {
        "school": "Sky View Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001473",
    },
    {
        "school": "Centennial High School",
        "district": "Peoria Unified School District (4237)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001500",
    },
    {
        "school": "Apache Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001501",
    },
    {
        "school": "Canyon Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001554",
    },
    {
        "school": "Frontier Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001668",
    },
    {
        "school": "Country Meadows Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001982",
    },
    {
        "school": "Coyote Hills Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625001983",
    },
    {
        "school": "Zuni Hills Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625002111",
    },
    {
        "school": "Phoenix Prep Academy",
        "district": "Phoenix Elementary District (4256)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630000148",
    },
    {
        "school": "Mary Mcleod Bethune School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630000518",
    },
    {
        "school": "Paul Dunbar Lawrence School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630000520",
    },
    {
        "school": "Thomas A Edison School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630000521",
    },
    {
        "school": "Ralph Waldo Emerson Elementary School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630000522",
    },
    {
        "school": "Garfield School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630000525",
    },
    {
        "school": "Maie Bartlett Heard School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630000530",
    },
    {
        "school": "Silvestre S Herrera School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630000531",
    },
    {
        "school": "Kenilworth Elementary School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630000533",
    },
    {
        "school": "Lowell Elementary School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630000535",
    },
    {
        "school": "Whittier Elementary School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630000537",
    },
    {
        "school": "Capitol Elementary School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630001028",
    },
    {
        "school": "Magnet Traditional School",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630001555",
    },
    {
        "school": "Augustus H. Shaw Montessori",
        "district": "Phoenix Elementary District (4256)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630002129",
    },
    {
        "school": "Alhambra High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633000538",
    },
    {
        "school": "Metro Tech High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633000539",
    },
    {
        "school": "Camelback High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633000540",
    },
    {
        "school": "Carl Hayden High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633000541",
    },
    {
        "school": "Central High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633000542",
    },
    {
        "school": "Maryvale High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633000549",
    },
    {
        "school": "South Mountain High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633000552",
    },
    {
        "school": "Trevor Browne High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633000554",
    },
    {
        "school": "North High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633001244",
    },
    {
        "school": "Bostrom Alternative Center",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40633001382",
    },
    {
        "school": "Cesar Chavez High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633001882",
    },
    {
        "school": "Linda Abril Educational Academy",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40633002138",
    },
    {
        "school": "Queen Creek Elementary School",
        "district": "Queen Creek Unified District (4245)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681000574",
    },
    {
        "school": "Desert Mountain Elementary",
        "district": "Queen Creek Unified District (4245)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681001232",
    },
    {
        "school": "Queen Creek Middle School",
        "district": "Queen Creek Unified District (4245)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681001322",
    },
    {
        "school": "Queen Creek High School",
        "district": "Queen Creek Unified District (4245)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681001383",
    },
    {
        "school": "Riverside Traditional School",
        "district": "Riverside Elementary District (4257)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40702000581",
    },
    {
        "school": "T G Barr School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708000582",
    },
    {
        "school": "C O Greenfield School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708000587",
    },
    {
        "school": "C J Jorgensen School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708000588",
    },
    {
        "school": "John F Kennedy Elementary School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708000592",
    },
    {
        "school": "V H Lassen Elementary School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708000593",
    },
    {
        "school": "Martin Luther King Early Childhood Center",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708000597",
    },
    {
        "school": "Percy L Julian School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708000599",
    },
    {
        "school": "Amy L. Houston Academy",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708000600",
    },
    {
        "school": "Cesar E Chavez Community School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708000605",
    },
    {
        "school": "Irene Lopez School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708000607",
    },
    {
        "school": "Sunland Elementary School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708000609",
    },
    {
        "school": "Valley View School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708001100",
    },
    {
        "school": "Ignacio Conchos School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708001143",
    },
    {
        "school": "John R Davis School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708001144",
    },
    {
        "school": "Maxine O Bush Elementary School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708001324",
    },
    {
        "school": "Southwest Elementary School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708001325",
    },
    {
        "school": "Ed & Verma Pastor Elementary School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708001879",
    },
    {
        "school": "Cloves C Campbell Sr Elementary School",
        "district": "Roosevelt Elementary District (4279)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40708001880",
    },
    {
        "school": "Ruth Fisher Middle School",
        "district": "Saddle Mountain Unified School District (4254)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40717000620",
    },
    {
        "school": "Aztec Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000274",
    },
    {
        "school": "Desert Canyon Middle School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000603",
    },
    {
        "school": "Desert Mountain High School",
        "district": "Scottsdale Unified District (4240)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000604",
    },
    {
        "school": "Arcadia High School",
        "district": "Scottsdale Unified District (4240)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000640",
    },
    {
        "school": "Chaparral High School",
        "district": "Scottsdale Unified District (4240)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000641",
    },
    {
        "school": "Cherokee Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000642",
    },
    {
        "school": "Cocopah Middle School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000643",
    },
    {
        "school": "Coronado High School",
        "district": "Scottsdale Unified District (4240)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000644",
    },
    {
        "school": "Hohokam Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000646",
    },
    {
        "school": "Hopi Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000647",
    },
    {
        "school": "Ingleside Middle School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000648",
    },
    {
        "school": "Kiva Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000651",
    },
    {
        "school": "Mohave Middle School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000654",
    },
    {
        "school": "Navajo Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000655",
    },
    {
        "school": "Pima Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000657",
    },
    {
        "school": "Pueblo Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000658",
    },
    {
        "school": "Saguaro High School",
        "district": "Scottsdale Unified District (4240)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000659",
    },
    {
        "school": "Tavan Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000662",
    },
    {
        "school": "Tonalea K-8",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000663",
    },
    {
        "school": "Yavapai Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757000666",
    },
    {
        "school": "Cochise Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757001102",
    },
    {
        "school": "Cheyenne Traditional School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757001194",
    },
    {
        "school": "Anasazi Elementary",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757001327",
    },
    {
        "school": "Laguna Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757001384",
    },
    {
        "school": "Sequoya Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757001434",
    },
    {
        "school": "Redfield Elementary School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757001475",
    },
    {
        "school": "Echo Canyon K-8",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757001561",
    },
    {
        "school": "Mountainside Middle School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757001562",
    },
    {
        "school": "Desert Canyon Elementary",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757001671",
    },
    {
        "school": "Copper Ridge School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757002115",
    },
    {
        "school": "Copper Ridge Middle School",
        "district": "Scottsdale Unified District (4240)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757002116",
    },
    {
        "school": "Sentinel Elementary School",
        "district": "Sentinel Elementary District (4250)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40768000669",
    },
    {
        "school": "Las Brisas Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775000296",
    },
    {
        "school": "Desert Mountain School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775000622",
    },
    {
        "school": "Mountain Ridge High School",
        "district": "Deer Valley Unified District (4246)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775000636",
    },
    {
        "school": "Constitution Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775000675",
    },
    {
        "school": "Deer Valley Middle School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775000676",
    },
    {
        "school": "New River Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775000681",
    },
    {
        "school": "Park Meadows Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775000682",
    },
    {
        "school": "Village Meadows Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775000684",
    },
    {
        "school": "Deer Valley High School",
        "district": "Deer Valley Unified District (4246)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001045",
    },
    {
        "school": "Mirage Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001047",
    },
    {
        "school": "Sunrise Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001048",
    },
    {
        "school": "Bellair Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001146",
    },
    {
        "school": "Desert Sky Middle School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001147",
    },
    {
        "school": "Copper Creek Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001250",
    },
    {
        "school": "Greenbrier Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001255",
    },
    {
        "school": "Mountain Shadows Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001330",
    },
    {
        "school": "Barry Goldwater High School",
        "district": "Deer Valley Unified District (4246)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001331",
    },
    {
        "school": "Arrowhead Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001436",
    },
    {
        "school": "Hillcrest Middle School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001503",
    },
    {
        "school": "Esperanza Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001504",
    },
    {
        "school": "Desert Sage Elementary School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001563",
    },
    {
        "school": "Paseo Hills School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001679",
    },
    {
        "school": "Highland Lakes School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001873",
    },
    {
        "school": "Anthem School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001874",
    },
    {
        "school": "Legend Springs Elementary",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775001997",
    },
    {
        "school": "Sierra Verde STEAM Academy",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775002127",
    },
    {
        "school": "Stetson Hills School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775002128",
    },
    {
        "school": "Aguilar School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000763",
    },
    {
        "school": "Arredondo Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000764",
    },
    {
        "school": "Broadmor Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000765",
    },
    {
        "school": "Carminati School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000767",
    },
    {
        "school": "Connolly Middle School",
        "district": "Tempe School District (4258)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000768",
    },
    {
        "school": "Curry Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000769",
    },
    {
        "school": "Evans Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000772",
    },
    {
        "school": "Fuller Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000773",
    },
    {
        "school": "Gililland Middle School",
        "district": "Tempe School District (4258)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000775",
    },
    {
        "school": "Holdeman Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000776",
    },
    {
        "school": "Hudson Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000777",
    },
    {
        "school": "Laird Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000778",
    },
    {
        "school": "Nevitt Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000782",
    },
    {
        "school": "Rover Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000783",
    },
    {
        "school": "Scales Technology Academy",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000785",
    },
    {
        "school": "Flora Thew Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000786",
    },
    {
        "school": "Frank Elementary School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000787",
    },
    {
        "school": "Wood School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831000789",
    },
    {
        "school": "Fees College Preparatory Middle School",
        "district": "Tempe School District (4258)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831001107",
    },
    {
        "school": "Getz School",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831001258",
    },
    {
        "school": "Intervention Learning Program",
        "district": "Tempe School District (4258)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831002130",
    },
    {
        "school": "Desert Vista High School",
        "district": "Tempe Union High School District (4287)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40834000680",
    },
    {
        "school": "Corona Del Sol High School",
        "district": "Tempe Union High School District (4287)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40834000790",
    },
    {
        "school": "Marcos De Niza High School",
        "district": "Tempe Union High School District (4287)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40834000793",
    },
    {
        "school": "Mcclintock High School",
        "district": "Tempe Union High School District (4287)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40834000794",
    },
    {
        "school": "Tempe High School",
        "district": "Tempe Union High School District (4287)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40834000795",
    },
    {
        "school": "Mountain Pointe High School",
        "district": "Tempe Union High School District (4287)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40834001567",
    },
    {
        "school": "Compadre High School",
        "district": "Tempe Union High School District (4287)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40834001576",
    },
    {
        "school": "Kiser Elementary School",
        "district": "Paloma School District (4255)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40843000799",
    },
    {
        "school": "Porfirio H. Gonzales Elementary School",
        "district": "Tolleson Elementary District (4264)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40849001477",
    },
    {
        "school": "Arizona Desert Elementary School",
        "district": "Tolleson Elementary District (4264)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40849001705",
    },
    {
        "school": "Sheely Farms Elementary School",
        "district": "Tolleson Elementary District (4264)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40849002132",
    },
    {
        "school": "Tolleson Union High School",
        "district": "Tolleson Union High School District (4288)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40852000805",
    },
    {
        "school": "Westview High School",
        "district": "Tolleson Union High School District (4288)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40852001478",
    },
    {
        "school": "Union Elementary School",
        "district": "Union Elementary District (4277)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40882000908",
    },
    {
        "school": "Abraham Lincoln Traditional School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000652",
    },
    {
        "school": "Acacia Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000915",
    },
    {
        "school": "Alta Vista Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000916",
    },
    {
        "school": "Arroyo Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000917",
    },
    {
        "school": "Cactus Wren Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000919",
    },
    {
        "school": "Chaparral Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000920",
    },
    {
        "school": "Cholla Middle School",
        "district": "Washington Elementary School District (4260)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000921",
    },
    {
        "school": "Desert Foothills Middle School",
        "district": "Washington Elementary School District (4260)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000922",
    },
    {
        "school": "Desert View Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000923",
    },
    {
        "school": "Ironwood Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000926",
    },
    {
        "school": "Lakeview Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000927",
    },
    {
        "school": "Lookout Mountain School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000928",
    },
    {
        "school": "Manzanita Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000929",
    },
    {
        "school": "Maryland Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000930",
    },
    {
        "school": "Moon Mountain School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000931",
    },
    {
        "school": "Mountain View Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000932",
    },
    {
        "school": "Ocotillo School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000933",
    },
    {
        "school": "Orangewood School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000934",
    },
    {
        "school": "Palo Verde Middle School",
        "district": "Washington Elementary School District (4260)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000935",
    },
    {
        "school": "Richard E Miller School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000936",
    },
    {
        "school": "Roadrunner Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000937",
    },
    {
        "school": "Royal Palm Middle School",
        "district": "Washington Elementary School District (4260)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000938",
    },
    {
        "school": "Sahuaro School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000939",
    },
    {
        "school": "Shaw Butte School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000941",
    },
    {
        "school": "Sunburst School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000942",
    },
    {
        "school": "Sunnyslope Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000944",
    },
    {
        "school": "Sunset School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000945",
    },
    {
        "school": "Tumbleweed Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000946",
    },
    {
        "school": "Washington Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906000947",
    },
    {
        "school": "John Jacobs Elementary School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906001116",
    },
    {
        "school": "Sweetwater School",
        "district": "Washington Elementary School District (4260)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906001117",
    },
    {
        "school": "Mountain Sky Middle School",
        "district": "Washington Elementary School District (4260)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40906001272",
    },
    {
        "school": "Vulture Peak Middle School",
        "district": "Wickenburg Unified District (4236)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40919000953",
    },
    {
        "school": "Wickenburg High School",
        "district": "Wickenburg Unified District (4236)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40919000955",
    },
    {
        "school": "Hassayampa Elementary School",
        "district": "Wickenburg Unified District (4236)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40919001834",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Wilson Elementary District (4261)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40939000964",
    },
    {
        "school": "Wilson Primary School",
        "district": "Wilson Elementary District (4261)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40939001483",
    },
    {
        "school": "EVIT - Scottsdale Vocational Center",
        "district": "East Valley Institute of Technology (4516)",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973100305",
    },
    {
        "school": "EVIT - East Valley Institute of Technology",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973101514",
    },
    {
        "school": "EVIT - Chandler High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973101515",
    },
    {
        "school": "Sequoia Village School",
        "district": "Edkey Inc. - Sequoia Village School (79211)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40024601856",
    },
    {
        "school": "CVIT - Superior High School",
        "district": "Cobre Valley Institute of Technology District (79391)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40031602103",
    },
    {
        "school": "Cactus Canyon Junior High",
        "district": "Apache Junction Unified District (4443)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079000040",
    },
    {
        "school": "Four Peaks Elementary School",
        "district": "Apache Junction Unified District (4443)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079000041",
    },
    {
        "school": "Apache Junction High School",
        "district": "Apache Junction Unified District (4443)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079000043",
    },
    {
        "school": "Desert Vista Elementary School",
        "district": "Apache Junction Unified District (4443)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079001461",
    },
    {
        "school": "Peralta Trail Elementary School",
        "district": "Apache Junction Unified District (4443)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079002212",
    },
    {
        "school": "Casa Grande Middle School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171000106",
    },
    {
        "school": "Cottonwood Elementary School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171000107",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171000109",
    },
    {
        "school": "Palo Verde School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171000111",
    },
    {
        "school": "Saguaro Elementary School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171000112",
    },
    {
        "school": "Mesquite Elementary School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171001027",
    },
    {
        "school": "Cholla Elementary School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171001056",
    },
    {
        "school": "Ironwood School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171001357",
    },
    {
        "school": "Cactus Middle School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171002213",
    },
    {
        "school": "Casa Grande Union High School",
        "district": "Casa Grande Union High School District (4453)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40174000113",
    },
    {
        "school": "Coolidge High School",
        "district": "Coolidge Unified District (4442)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40232000158",
    },
    {
        "school": "West Elementary School",
        "district": "Coolidge Unified District (4442)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40232000164",
    },
    {
        "school": "Barely Bears",
        "district": "Coolidge Unified District (4442)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40232001025",
    },
    {
        "school": "McCray Elementary School",
        "district": "Coolidge Unified District (4442)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40232001208",
    },
    {
        "school": "Coolidge Jr. High School",
        "district": "Coolidge Unified District (4442)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40232001534",
    },
    {
        "school": "Mary C  O'Brien Elementary School",
        "district": "Mary C O'Brien Accommodation District (4435)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40274000203",
    },
    {
        "school": "Villa Oasis Interscholastic Center For Education (voice)",
        "district": "Mary C O'Brien Accommodation District (4435)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40274001625",
    },
    {
        "school": "Curiel School",
        "district": "Eloy Elementary District (4448)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40279000207",
    },
    {
        "school": "Eloy Junior High School",
        "district": "Eloy Elementary District (4448)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40279000209",
    },
    {
        "school": "Eloy Intermediate School",
        "district": "Eloy Elementary District (4448)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40279001060",
    },
    {
        "school": "Florence K-8",
        "district": "Florence Unified School District (4437)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292000227",
    },
    {
        "school": "Florence High School",
        "district": "Florence Unified School District (4437)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292000228",
    },
    {
        "school": "Walker Butte K-8",
        "district": "Florence Unified School District (4437)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292002210",
    },
    {
        "school": "J. O. Combs Middle School",
        "district": "J O Combs Unified School District (4445)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40399000320",
    },
    {
        "school": "Avenue B School - Closed",
        "district": "Mammoth-San Manuel Unified District (4439)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40457000362",
    },
    {
        "school": "First Avenue Elementary School",
        "district": "Mammoth-San Manuel Unified District (4439)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40457000363",
    },
    {
        "school": "Mammoth Elementary School",
        "district": "Mammoth-San Manuel Unified District (4439)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40457000364",
    },
    {
        "school": "San Manuel Jr. High School",
        "district": "Mammoth-San Manuel Unified District (4439)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40457000365",
    },
    {
        "school": "San Manuel High School",
        "district": "Mammoth-San Manuel Unified District (4439)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40457000366",
    },
    {
        "school": "Maricopa Elementary School",
        "district": "Maricopa Unified School District (4441)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40472000371",
    },
    {
        "school": "Maricopa High School",
        "district": "Maricopa Unified School District (4441)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40472000372",
    },
    {
        "school": "Maricopa Wells Middle School",
        "district": "Maricopa Unified School District (4441)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40472001468",
    },
    {
        "school": "Mountain Vista School",
        "district": "Oracle Elementary District (4444)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40564001416",
    },
    {
        "school": "Picacho School",
        "district": "Picacho Elementary District (4452)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40636000556",
    },
    {
        "school": "Ray JR/SR High School",
        "district": "Ray Unified District (4438)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40685000576",
    },
    {
        "school": "Ray Elementary School",
        "district": "Ray Unified District (4438)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40685001474",
    },
    {
        "school": "Red Rock Elementary School",
        "district": "Red Rock Elementary District (4447)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40690000577",
    },
    {
        "school": "Sacaton Elementary",
        "district": "Sacaton Elementary District (4449)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40720000621",
    },
    {
        "school": "Sacaton Middle School",
        "district": "Sacaton Elementary District (4449)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40720001176",
    },
    {
        "school": "Santa Cruz Valley Union High School",
        "district": "Santa Cruz Valley Union High School District (4454)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40753000638",
    },
    {
        "school": "Stanfield Elementary School",
        "district": "Stanfield Elementary District (4451)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40813000705",
    },
    {
        "school": "John F Kennedy School",
        "district": "Superior Unified School District (4440)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40823000758",
    },
    {
        "school": "Superior Junior/Senior High School",
        "district": "Superior Unified School District (4440)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40823000760",
    },
    {
        "school": "Toltec Elementary School",
        "district": "Toltec School District (4450)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40855000806",
    },
    {
        "school": "VACTE - Mingus Union High School",
        "district": "Valley Academy for Career and Technology Education (79397)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034102243",
    },
    {
        "school": "VACTE - Camp Verde Unified School District",
        "district": "Valley Academy for Career and Technology Education (79397)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034102248",
    },
    {
        "school": "VACTE - Sedona-Oak Creek Joint Unified School District",
        "district": "Valley Academy for Career and Technology Education (79397)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034102249",
    },
    {
        "school": "VACTE - Valley Academy for Career and Technology Education",
        "district": "Valley Academy for Career and Technology Education (79397)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034102565",
    },
    {
        "school": "Camp Verde Accommodation School",
        "district": "Camp Verde Unified District (4470)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40160003173",
    },
    {
        "school": "Granville Elementary School",
        "district": "Humboldt Unified District (4469)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40387002563",
    },
    {
        "school": "Bradshaw Mountain Online Academy",
        "district": "Humboldt Unified District (4469)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40387002564",
    },
    {
        "school": "Del Rio Elementary School",
        "district": "Chino Valley Unified District (4474)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000300147",
    },
    {
        "school": "Heritage Middle School",
        "district": "Chino Valley Unified District (4474)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000301198",
    },
    {
        "school": "Chino Valley High School",
        "district": "Chino Valley Unified District (4474)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000301458",
    },
    {
        "school": "Territorial Early Childhood Center",
        "district": "Chino Valley Unified District (4474)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000301969",
    },
    {
        "school": "Clarkdale-Jerome Elementary School",
        "district": "Clarkdale-Jerome Elementary District (4486)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000400912",
    },
    {
        "school": "Sedona Charter School",
        "district": "Sedona Charter School Inc. (4492)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40008901063",
    },
    {
        "school": "Mingus Springs Charter School",
        "district": "Mingus Springs Charter School (4493)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40009001066",
    },
    {
        "school": "Franklin Phonetic Primary School",
        "district": "Franklin Phonetic Primary School Inc. (4495)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40009201075",
    },
    {
        "school": "Skyview School",
        "district": "Skyview School Inc. (4496)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40009301086",
    },
    {
        "school": "American Heritage Academy - Cottonwood",
        "district": "Edkey Inc. dba American Heritage Academy  (6365)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40013001803",
    },
    {
        "school": "Mountain Oak Charter School",
        "district": "Mountain Oak Charter School Inc. (78873)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40020801970",
    },
    {
        "school": "Park View Middle School",
        "district": "Park View School Inc. (10970)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40020901973",
    },
    {
        "school": "Willow Creek Charter School",
        "district": "Painted Pony Ranch Charter School (10967)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40021001974",
    },
    {
        "school": "Tri-City College Prep High School",
        "district": "Mary Ellen Halvorson Educational Foundation. dba:  (10965)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40021101975",
    },
    {
        "school": "PACE Preparatory Academy",
        "district": "PACE Preparatory Academy Inc. (79068)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40026602089",
    },
    {
        "school": "Valley Preparatory Academy",
        "district": "Kestrel Schools Inc. (79065)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40026702091",
    },
    {
        "school": "Yavapai County High School",
        "district": "Yavapai Accommodation School District (79379)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40031502217",
    },
    {
        "school": "Acorn Montessori Charter School",
        "district": "Acorn Montessori Charter School (79437)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40032002227",
    },
    {
        "school": "Verde Valley Montessori School - A Center for Creative Educa",
        "district": "A Center for Creative Education (79457)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40032802228",
    },
    {
        "school": "Ash Fork Elementary School",
        "district": "Ash Fork Joint Unified District (4471)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40091000047",
    },
    {
        "school": "Ash Fork High School",
        "district": "Ash Fork Joint Unified District (4471)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40091000048",
    },
    {
        "school": "Ash Fork Middle School",
        "district": "Ash Fork Joint Unified District (4471)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40091001059",
    },
    {
        "school": "Bagdad Elementary School",
        "district": "Bagdad Unified District (4468)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40100000052",
    },
    {
        "school": "Bagdad Middle / Senior High School",
        "district": "Bagdad Unified District (4468)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40100000053",
    },
    {
        "school": "Beaver Creek School",
        "district": "Beaver Creek Elementary District (4481)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40108000059",
    },
    {
        "school": "Camp Verde Elementary School",
        "district": "Camp Verde Unified District (4470)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40160000086",
    },
    {
        "school": "Camp Verde High School",
        "district": "Camp Verde Unified District (4470)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40160000087",
    },
    {
        "school": "Camp Verde Middle School",
        "district": "Camp Verde Unified District (4470)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40160001529",
    },
    {
        "school": "Canon School",
        "district": "Canon Elementary District (4484)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40165000088",
    },
    {
        "school": "Congress Elementary School",
        "district": "Congress Elementary District (4479)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40222002220",
    },
    {
        "school": "Oak Creek Elementary School",
        "district": "Cottonwood-Oak Creek Elementary District (4487)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40237000165",
    },
    {
        "school": "Cottonwood Education Services",
        "district": "Cottonwood-Oak Creek Elementary District (4487)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40237000166",
    },
    {
        "school": "Crown King Elementary School",
        "district": "Crown King Elementary District (4483)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40246000182",
    },
    {
        "school": "Bradshaw Mountain High School",
        "district": "Humboldt Unified District (4469)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40387000306",
    },
    {
        "school": "Bradshaw Mountain Middle School",
        "district": "Humboldt Unified District (4469)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40387000307",
    },
    {
        "school": "Lake Valley Elementary School",
        "district": "Humboldt Unified District (4469)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40387000308",
    },
    {
        "school": "Coyote Springs Elementary School",
        "district": "Humboldt Unified District (4469)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40387000381",
    },
    {
        "school": "Glassford Hill Middle School",
        "district": "Humboldt Unified District (4469)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40387001041",
    },
    {
        "school": "Liberty Traditional School",
        "district": "Humboldt Unified District (4469)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40387001057",
    },
    {
        "school": "Humboldt Elementary School",
        "district": "Humboldt Unified District (4469)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40387001228",
    },
    {
        "school": "Mountain View Elementary School",
        "district": "Humboldt Unified District (4469)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40387001465",
    },
    {
        "school": "Kirkland Elementary School",
        "district": "Kirkland Elementary District (4480)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40417000330",
    },
    {
        "school": "Mayer Elementary School",
        "district": "Mayer Unified School District (4473)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40482000374",
    },
    {
        "school": "Mayer High School",
        "district": "Mayer Unified School District (4473)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40482000375",
    },
    {
        "school": "Mingus Union High School",
        "district": "Mingus Union High School District (4488)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40507000430",
    },
    {
        "school": "Discovery Gardens Preschool",
        "district": "Prescott Unified District (4466)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40673000352",
    },
    {
        "school": "Granite Mountain Middle School",
        "district": "Prescott Unified District (4466)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40673000565",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Prescott Unified District (4466)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40673000566",
    },
    {
        "school": "Prescott High School",
        "district": "Prescott Unified District (4466)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40673000568",
    },
    {
        "school": "Prescott Mile High Middle School",
        "district": "Prescott Unified District (4466)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40673000569",
    },
    {
        "school": "Taylor Hicks School",
        "district": "Prescott Unified District (4466)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40673000570",
    },
    {
        "school": "Washington Traditional School",
        "district": "Prescott Unified District (4466)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40673000571",
    },
    {
        "school": "Abia Judd Elementary School",
        "district": "Prescott Unified District (4466)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40673001433",
    },
    {
        "school": "Seligman Elementary School",
        "district": "Seligman Unified District (4472)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40763000667",
    },
    {
        "school": "Seligman High School",
        "district": "Seligman Unified District (4472)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40763000668",
    },
    {
        "school": "Skull Valley Elementary School",
        "district": "Skull Valley Elementary District (4478)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40777000390",
    },
    {
        "school": "Hillside Elementary School",
        "district": "Hillside Elementary District (4482)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40846000800",
    },
    {
        "school": "Yarnell Elementary School",
        "district": "Yarnell Elementary District (4485)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40951000977",
    },
    {
        "school": "GIFT - Gila Institute for Technology",
        "district": "Gila Institute for Technology (79387)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034902242",
    },
    {
        "school": "GIFT - Safford High School",
        "district": "Gila Institute for Technology (79387)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034902252",
    },
    {
        "school": "GIFT - Pima High School",
        "district": "Gila Institute for Technology (79387)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034902253",
    },
    {
        "school": "GIFT - Ft. Thomas High School",
        "district": "Gila Institute for Technology (79387)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034902254",
    },
    {
        "school": "GIFT - Thatcher High School",
        "district": "Gila Institute for Technology (79387)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034902263",
    },
    {
        "school": "GIFT - Duncan High School",
        "district": "Gila Institute for Technology (79387)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034902399",
    },
    {
        "school": "GIFT - Mt. Graham High School",
        "district": "Gila Institute for Technology (79387)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034903080",
    },
    {
        "school": "Pima Junior High School",
        "district": "Pima Unified District (4220)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40644003111",
    },
    {
        "school": "Ruth Powell Elementary School",
        "district": "Safford Unified District (4218)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40724002267",
    },
    {
        "school": "Bonita Elementary School",
        "district": "Bonita Elementary District (4224)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40126000070",
    },
    {
        "school": "Triumphant Learning Center",
        "district": "Triumphant Learning Center (4225)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002800528",
    },
    {
        "school": "Discovery Plus Academy",
        "district": "Discovery Plus Academy (6357)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40014101657",
    },
    {
        "school": "Dan Hinton Accommodation School",
        "district": "Graham County Special Services (4217)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40248001210",
    },
    {
        "school": "Fort Thomas Elementary School",
        "district": "Fort Thomas Unified District (4221)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40320000248",
    },
    {
        "school": "Fort Thomas High School",
        "district": "Fort Thomas Unified District (4221)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40320000249",
    },
    {
        "school": "Pima Elementary School",
        "district": "Pima Unified District (4220)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40644000557",
    },
    {
        "school": "Pima High School",
        "district": "Pima Unified District (4220)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40644000558",
    },
    {
        "school": "Mt Graham High School",
        "district": "Safford Unified District (4218)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40724000527",
    },
    {
        "school": "Dorothy Stinson School",
        "district": "Safford Unified District (4218)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40724000623",
    },
    {
        "school": "Safford High School",
        "district": "Safford Unified District (4218)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40724000624",
    },
    {
        "school": "Safford Middle School",
        "district": "Safford Unified District (4218)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40724001029",
    },
    {
        "school": "Lafe Nelson School",
        "district": "Safford Unified District (4218)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40724001030",
    },
    {
        "school": "Solomon Elementary School",
        "district": "Solomon Elementary District (4222)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40786000697",
    },
    {
        "school": "Jack Daley Primary School",
        "district": "Thatcher Unified District (4219)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40841000796",
    },
    {
        "school": "Thatcher Elementary School",
        "district": "Thatcher Unified District (4219)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40841000797",
    },
    {
        "school": "Thatcher Middle School",
        "district": "Thatcher Unified District (4219)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40841000798",
    },
    {
        "school": "Thatcher High School",
        "district": "Thatcher Unified District (4219)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40841001110",
    },
    {
        "school": "Blue Elementary School",
        "district": "Blue Elementary District (4231)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40123000069",
    },
    {
        "school": "Duncan Elementary",
        "district": "Duncan Unified District (4228)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40260000195",
    },
    {
        "school": "Duncan High School",
        "district": "Duncan Unified District (4228)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40260000196",
    },
    {
        "school": "Duncan Primary",
        "district": "Duncan Unified District (4228)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40260001292",
    },
    {
        "school": "Metcalf Elementary School",
        "district": "Morenci Unified District (4230)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40532000438",
    },
    {
        "school": "Morenci High School",
        "district": "Morenci Unified District (4230)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40532000441",
    },
    {
        "school": "Center for Academic Success #4",
        "district": "Center for Academic Success Inc. (4191)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40001602442",
    },
    {
        "school": "Center for Academic Success #5",
        "district": "Center for Academic Success Inc. (4191)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40001602443",
    },
    {
        "school": "San Pedro Valley High School",
        "district": "Benson Unified School District (79226)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40021202444",
    },
    {
        "school": "CTD - Willcox High School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034502256",
    },
    {
        "school": "CTD - Valley Union High School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034502257",
    },
    {
        "school": "CTD - St. David High School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034502258",
    },
    {
        "school": "CTD - San Simon High School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034502259",
    },
    {
        "school": "CTD - Tombstone High School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034502260",
    },
    {
        "school": "CTD - Benson High School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034502261",
    },
    {
        "school": "CTD - Bowie High School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034502262",
    },
    {
        "school": "CTD - Douglas High School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034502421",
    },
    {
        "school": "Bereran Academy",
        "district": "Cochise Community Development Corporation (81027)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40063203105",
    },
    {
        "school": "Bella Vista Elementary School",
        "district": "Sierra Vista Unified District (4175)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40146003062",
    },
    {
        "school": "Center for Academic Success The #1",
        "district": "Center for Academic Success Inc. (4191)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40001600476",
    },
    {
        "school": "Center for Academic Success The #2",
        "district": "Center for Academic Success Inc. (4191)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40001600481",
    },
    {
        "school": "Center for Academic Success The #3",
        "district": "Center for Academic Success Inc. (4191)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40001601942",
    },
    {
        "school": "Benson Primary School",
        "district": "Benson Unified School District (79226)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40021200060",
    },
    {
        "school": "Benson High School",
        "district": "Benson Unified School District (79226)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40021200061",
    },
    {
        "school": "Benson Middle School",
        "district": "Benson Unified School District (79226)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40021201120",
    },
    {
        "school": "Omega Alpha Academy School",
        "district": "Omega Alpha Academy (79503)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40028402095",
    },
    {
        "school": "Visions Unlimited Academy",
        "district": "Visions Unlimited Academy Inc. (79671)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029902099",
    },
    {
        "school": "Apache Elementary School",
        "district": "Apache Elementary District (4178)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40075000039",
    },
    {
        "school": "Ash Creek Elementary",
        "district": "Ash Creek Elementary District (4187)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40087000046",
    },
    {
        "school": "Bisbee High School",
        "district": "Bisbee Unified District (4169)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40118000063",
    },
    {
        "school": "Lowell School",
        "district": "Bisbee Unified District (4169)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40118000064",
    },
    {
        "school": "Greenway Primary School",
        "district": "Bisbee Unified District (4169)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40118000066",
    },
    {
        "school": "Bisbee Middle School",
        "district": "Bisbee Unified District (4169)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40118001817",
    },
    {
        "school": "Bowie Elementary School",
        "district": "Bowie Unified District (4171)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40133000072",
    },
    {
        "school": "Bowie High School",
        "district": "Bowie Unified District (4171)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40133000073",
    },
    {
        "school": "Carmichael Elementary School",
        "district": "Sierra Vista Unified District (4175)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40146000077",
    },
    {
        "school": "Joyce Clark Middle School",
        "district": "Sierra Vista Unified District (4175)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40146000078",
    },
    {
        "school": "Village Meadows Elementary School",
        "district": "Sierra Vista Unified District (4175)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40146000080",
    },
    {
        "school": "Buena High School",
        "district": "Sierra Vista Unified District (4175)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40146000081",
    },
    {
        "school": "Pueblo Del Sol Elementary School",
        "district": "Sierra Vista Unified District (4175)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40146001050",
    },
    {
        "school": "Town & Country Elementary School",
        "district": "Sierra Vista Unified District (4175)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40146001051",
    },
    {
        "school": "Huachuca Mountain Elementary School",
        "district": "Sierra Vista Unified District (4175)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40146001356",
    },
    {
        "school": "Cochise Elementary School",
        "district": "Cochise Elementary District (4177)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40213000152",
    },
    {
        "school": "Double Adobe Elementary School",
        "district": "Double Adobe Elementary District (4179)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40249000183",
    },
    {
        "school": "Early Learning Center",
        "district": "Douglas Unified District (4174)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40253000184",
    },
    {
        "school": "Paul H Huber Jr High School",
        "district": "Douglas Unified District (4174)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40253000185",
    },
    {
        "school": "Clawson School",
        "district": "Douglas Unified District (4174)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40253000186",
    },
    {
        "school": "Douglas High School",
        "district": "Douglas Unified District (4174)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40253000187",
    },
    {
        "school": "Joe Carlson Elementary School",
        "district": "Douglas Unified District (4174)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40253000190",
    },
    {
        "school": "Faras Elementary School",
        "district": "Douglas Unified District (4174)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40253000191",
    },
    {
        "school": "Sarah Marley School",
        "district": "Douglas Unified District (4174)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40253000192",
    },
    {
        "school": "Stevenson Elementary School",
        "district": "Douglas Unified District (4174)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40253000193",
    },
    {
        "school": "Ray Borane Middle School",
        "district": "Douglas Unified District (4174)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40253000194",
    },
    {
        "school": "Maryvale School",
        "district": "Douglas Unified District (4174)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40253001291",
    },
    {
        "school": "Elfrida Elementary School",
        "district": "Elfrida Elementary District (4185)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40276000204",
    },
    {
        "school": "Colonel Johnston Elementary School",
        "district": "Fort Huachuca Accommodation District (4167)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40315000244",
    },
    {
        "school": "Colonel Smith Middle School",
        "district": "Fort Huachuca Accommodation District (4167)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40315000245",
    },
    {
        "school": "General Myer Elementary School",
        "district": "Fort Huachuca Accommodation District (4167)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40315000247",
    },
    {
        "school": "Mcneal Elementary School",
        "district": "McNeal Elementary District (4181)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40492000377",
    },
    {
        "school": "Naco Elementary School",
        "district": "Naco Elementary District (4176)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40543000448",
    },
    {
        "school": "Palominas Elementary School",
        "district": "Palominas Elementary District (4180)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40588000471",
    },
    {
        "school": "Coronado Elementary School",
        "district": "Palominas Elementary District (4180)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40588001498",
    },
    {
        "school": "Valley View Elementary School",
        "district": "Palominas Elementary District (4180)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40588001818",
    },
    {
        "school": "Pearce Elementary School",
        "district": "Pearce Elementary District (4186)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40615000503",
    },
    {
        "school": "Pomerene Elementary School",
        "district": "Pomerene Elementary District (4188)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40663000562",
    },
    {
        "school": "San Simon School",
        "district": "San Simon Unified District (4172)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40743000631",
    },
    {
        "school": "St David Elementary School",
        "district": "St David Unified District (4173)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40802000700",
    },
    {
        "school": "St David High School",
        "district": "St David Unified District (4173)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40802000701",
    },
    {
        "school": "Huachuca City School",
        "district": "Tombstone Unified District (4168)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40860000807",
    },
    {
        "school": "Tombstone High School",
        "district": "Tombstone Unified District (4168)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40860000809",
    },
    {
        "school": "Walter J Meyer School",
        "district": "Tombstone Unified District (4168)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40860000810",
    },
    {
        "school": "Valley Union High School",
        "district": "Valley Union High School District (4190)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40891000911",
    },
    {
        "school": "Willcox Elementary School",
        "district": "Willcox Unified District (4170)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40925000956",
    },
    {
        "school": "Willcox High School",
        "district": "Willcox Unified District (4170)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40925000957",
    },
    {
        "school": "Willcox Middle School",
        "district": "Willcox Unified District (4170)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40925000958",
    },
    {
        "school": "BASIS Scottsdale",
        "district": "BASIS Charter Schools Inc. (81078)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060803115",
    },
    {
        "school": "EDGE High School - Northwest",
        "district": "Edge School Inc. The (4421)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40007802386",
    },
    {
        "school": "Academy of Tucson Middle School",
        "district": "Academy of Tucson Inc. (78897)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40020202312",
    },
    {
        "school": "Academy of Tucson Elementary School",
        "district": "Academy of Tucson Inc. (78897)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40020203141",
    },
    {
        "school": "Children Reaching for the Sky Preparatory",
        "district": "Griffin Foundation Inc. The (79500)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40034302246",
    },
    {
        "school": "Nosotros Academy",
        "district": "Nosotros Inc (79881)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40035602287",
    },
    {
        "school": "La Paloma Academy",
        "district": "Arizona Community Development Corporation (79947)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40036102299",
    },
    {
        "school": "La Paloma Academy (Lakeside)",
        "district": "Arizona Community Development Corporation (79947)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40036103165",
    },
    {
        "school": "Pima Partnership School The",
        "district": "Pima Prevention Partnership dba Pima Partnership S (79959)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40036702303",
    },
    {
        "school": "Academy of Math and Science",
        "district": "Academy of Mathematics and Science Inc. (79961)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40036802037",
    },
    {
        "school": "Tucson International Academy",
        "district": "Tucson International Academy Inc. (79979)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40037302311",
    },
    {
        "school": "Tucson International Academy Midvale",
        "district": "Tucson International Academy Inc. (79979)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40037302397",
    },
    {
        "school": "Toltecali High School",
        "district": "CPLC Community Schools dba Toltecalli High School (80032)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40038202331",
    },
    {
        "school": "Lifelong Learning Academy",
        "district": "Lifelong Learning Research Institute Inc. (79926)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40039302297",
    },
    {
        "school": "City High School",
        "district": "CITY Center for Collaborative Learning (85448)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40040702404",
    },
    {
        "school": "Satori Charter School",
        "district": "Satori Inc. (85454)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40040902406",
    },
    {
        "school": "Arizona Virtual Academy",
        "district": "Portable Practical Educational Preparation Inc. ( (87405)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40043202200",
    },
    {
        "school": "Ajo High School",
        "district": "Ajo Unified District (4409)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40052003063",
    },
    {
        "school": "Adventure School",
        "district": "Educational Impact Inc. (81123)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40061302553",
    },
    {
        "school": "Canyon Rose Academy",
        "district": "Canyon Rose Academy Inc. (81029)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40063303106",
    },
    {
        "school": "Marana Distance Learning",
        "district": "Marana Unified District (4404)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463002548",
    },
    {
        "school": "Robles Elementary School",
        "district": "Altar Valley Elementary District (4418)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40477002400",
    },
    {
        "school": "Billy Lane Lauffer Middle School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817002549",
    },
    {
        "school": "Tanque Verde High School",
        "district": "Tanque Verde Unified District (4408)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40828002550",
    },
    {
        "school": "Laura N. Banks Elementary",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880002335",
    },
    {
        "school": "Henry Hank Oyama",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880002336",
    },
    {
        "school": "Catalina Online Learning Experience",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880002547",
    },
    {
        "school": "Pantano Middle School",
        "district": "Vail Unified District (4413)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885002439",
    },
    {
        "school": "Corona Foothills Middle School",
        "district": "Vail Unified District (4413)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885002551",
    },
    {
        "school": "Empire High School",
        "district": "Vail Unified District (4413)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885002552",
    },
    {
        "school": "Sycamore Elementary School",
        "district": "Vail Unified District (4413)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885003083",
    },
    {
        "school": "Pantano High School",
        "district": "Vail Unified District (4413)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40885003175",
    },
    {
        "school": "PPEP TEC - Raul H. Castro Learning Center",
        "district": "Portable Practical Educational Preparation Inc. ( (4431)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40008301015",
    },
    {
        "school": "PPEP TEC - Colin L. Powell Learning Center",
        "district": "Portable Practical Educational Preparation Inc. ( (4431)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40008301018",
    },
    {
        "school": "PPEP TEC - Manuel Borjorquez Learning Center-CLOSED",
        "district": "Portable Practical Educational Preparation Inc. ( (4431)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40008301021",
    },
    {
        "school": "AmeriSchools Academy - Camelback",
        "district": "The Charter Foundation Inc. (6355)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40013101781",
    },
    {
        "school": "Edge High School - Himmel Park",
        "district": "Edge School Inc. The (4421)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40007801006",
    },
    {
        "school": "Alternative Computerized Education (ACE) Charter High School",
        "district": "Tucson Youth Development/ACE Charter High School (4422)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40007901008",
    },
    {
        "school": "Presidio School",
        "district": "Presidio School (4425)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40008101010",
    },
    {
        "school": "PPEP TEC - Celestino Fernandez Learning Center",
        "district": "Portable Practical Educational Preparation Inc. ( (4431)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40008301011",
    },
    {
        "school": "Hermosa Montessori Charter",
        "district": "Hermosa Montessori Charter School (4426)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011501617",
    },
    {
        "school": "Pepe Barron Academy",
        "district": "Luz Academy of Tucson Inc (4427)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40012501619",
    },
    {
        "school": "Montessori Schoolhouse",
        "district": "Montessori Schoolhouse of Tucson Inc. (4428)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40012601620",
    },
    {
        "school": "Montessori Schoolhouse",
        "district": "Montessori Schoolhouse of Tucson Inc. (4428)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40012601778",
    },
    {
        "school": "Accelerated Learning Laboratory",
        "district": "Accelerated Elementary and Secondary Schools (6364)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40012901790",
    },
    {
        "school": "AmeriSchools Academy - Country Club",
        "district": "The Charter Foundation Inc. (6355)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40013102070",
    },
    {
        "school": "BASIS Tucson Primary",
        "district": "BASIS Charter Schools Inc. (6361)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40013401786",
    },
    {
        "school": "Ha:san Preparatory & Leadership School",
        "district": "Ha:san Educational Services (6369)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40014701787",
    },
    {
        "school": "Tucson Preparatory School",
        "district": "Tucson Preparatory School (6374)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40015901791",
    },
    {
        "school": "Vision Charter School",
        "district": "Vision Charter School Inc. (4430)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40016001779",
    },
    {
        "school": "Pima Vocational High School",
        "district": "Pima County (4420)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40020102069",
    },
    {
        "school": "Academy of Tucson High School",
        "district": "Academy of Tucson Inc. (78897)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40020201959",
    },
    {
        "school": "Mountain Rose Academy",
        "district": "Mountain Rose Academy Inc. (10879)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40020401962",
    },
    {
        "school": "Great Expectations Academy",
        "district": "Great Expectations Academy (10974)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40020501963",
    },
    {
        "school": "Sonoran Science Academy - Tucson",
        "district": "Daisy Education Corporation dba Sonoran Science Ac (79049)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40022302199",
    },
    {
        "school": "Southern Arizona Community Academy",
        "district": "Southern Arizona Community Academy Inc. (79000)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40025402074",
    },
    {
        "school": "Tucson Country Day School",
        "district": "Tucson Country Day School Inc. (79073)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40025502075",
    },
    {
        "school": "Carden of Tucson",
        "district": "Carden of Tucson Inc. (78858)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40025802079",
    },
    {
        "school": "Southgate Academy",
        "district": "Southgate Academy Inc. (79085)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40025902080",
    },
    {
        "school": "Eastpointe High School",
        "district": "Eastpointe High School Inc. (78833)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40026101916",
    },
    {
        "school": "Highland Free School",
        "district": "Highland Free School (79061)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40027502077",
    },
    {
        "school": "Pepe Barron Middle School",
        "district": "El Centro for the Study of Primary and Secondary E (79640)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029602209",
    },
    {
        "school": "Khalsa School",
        "district": "Khalsa Family Services (79420)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40031702202",
    },
    {
        "school": "Southside Community School",
        "district": "Aprender Tucson (79426)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40031802203",
    },
    {
        "school": "Desert Rose Academy Charter School",
        "district": "Desert Rose AcademyInc. (79441)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40032202205",
    },
    {
        "school": "Compass High School",
        "district": "Compass High School Inc. (79467)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40033002206",
    },
    {
        "school": "Ajo Elementary School",
        "district": "Ajo Unified District (4409)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40052000003",
    },
    {
        "school": "Amphitheater Middle School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000020",
    },
    {
        "school": "Coronado K-8 School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000021",
    },
    {
        "school": "Marion Donaldson Elementary School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000022",
    },
    {
        "school": "E C Nash School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000023",
    },
    {
        "school": "Frances Owen Holaway Elementary School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000025",
    },
    {
        "school": "Helen Keeling Elementary School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000026",
    },
    {
        "school": "L M Prince School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000027",
    },
    {
        "school": "Lawrence W Cross Middle School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000028",
    },
    {
        "school": "Lulu Walker School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000029",
    },
    {
        "school": "Rillito Center",
        "district": "Amphitheater Unified District (4406)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40068000030",
    },
    {
        "school": "Winifred Harelson Elementary School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000031",
    },
    {
        "school": "Amphitheater High School",
        "district": "Amphitheater Unified District (4406)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000032",
    },
    {
        "school": "Canyon Del Oro High School",
        "district": "Amphitheater Unified District (4406)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068000033",
    },
    {
        "school": "Richard B Wilson Jr School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068001001",
    },
    {
        "school": "Mesa Verde Elementary School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068001031",
    },
    {
        "school": "Rio Vista Elementary School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068001286",
    },
    {
        "school": "Copper Creek Elementary School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068001394",
    },
    {
        "school": "La Cima Middle School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068001525",
    },
    {
        "school": "Painted Sky Elementary School",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068002066",
    },
    {
        "school": "Ironwood Ridge High School",
        "district": "Amphitheater Unified District (4406)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068002198",
    },
    {
        "school": "Catalina Foothills High School",
        "district": "Catalina Foothills Unified District (4410)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40176000011",
    },
    {
        "school": "Orange Grove Middle School",
        "district": "Catalina Foothills Unified District (4410)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40176000116",
    },
    {
        "school": "Sunrise Drive Elementary School",
        "district": "Catalina Foothills Unified District (4410)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40176000117",
    },
    {
        "school": "Ventana Vista Elementary School",
        "district": "Catalina Foothills Unified District (4410)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40176001002",
    },
    {
        "school": "Manzanita School",
        "district": "Catalina Foothills Unified District (4410)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40176001032",
    },
    {
        "school": "Canyon View Elementary School",
        "district": "Catalina Foothills Unified District (4410)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40176001358",
    },
    {
        "school": "Esperero Canyon Middle School",
        "district": "Catalina Foothills Unified District (4410)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40176001487",
    },
    {
        "school": "Catalina Foothills Valley View Early Learning Center",
        "district": "Catalina Foothills Unified District (4410)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40176001531",
    },
    {
        "school": "Continental Elementary School",
        "district": "Continental Elementary District (4416)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40225000156",
    },
    {
        "school": "Flowing Wells High School",
        "district": "Flowing Wells Unified District (4405)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40301000231",
    },
    {
        "school": "Flowing Wells Junior High School",
        "district": "Flowing Wells Unified District (4405)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40301000232",
    },
    {
        "school": "Homer Davis Elementary School",
        "district": "Flowing Wells Unified District (4405)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40301000233",
    },
    {
        "school": "Laguna Elementary School",
        "district": "Flowing Wells Unified District (4405)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40301000236",
    },
    {
        "school": "Walter Douglas Elementary School",
        "district": "Flowing Wells Unified District (4405)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40301000237",
    },
    {
        "school": "J Robert Hendricks Elementary School",
        "district": "Flowing Wells Unified District (4405)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40301001000",
    },
    {
        "school": "Robert Richardson Elementary School",
        "district": "Flowing Wells Unified District (4405)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40301001033",
    },
    {
        "school": "Centennial Elementary School",
        "district": "Flowing Wells Unified District (4405)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40301001489",
    },
    {
        "school": "Sentinel Peak High School",
        "district": "Flowing Wells Unified District (4405)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40301001611",
    },
    {
        "school": "Emily Meschter Early Learning Center",
        "district": "Flowing Wells Unified District (4405)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40301002065",
    },
    {
        "school": "Baboquivari High School",
        "district": "Baboquivari Unified School District #40 (4412)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40395000310",
    },
    {
        "school": "Baboquivari Middle School",
        "district": "Baboquivari Unified School District #40 (4412)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40395000311",
    },
    {
        "school": "Indian Oasis Primary Elementary School",
        "district": "Baboquivari Unified School District #40 (4412)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40395000312",
    },
    {
        "school": "Indian Oasis Intermediate School to Baboquivari Middle Schoo",
        "district": "Baboquivari Unified School District #40 (4412)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40395000313",
    },
    {
        "school": "Quail Run Elementary School",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463000333",
    },
    {
        "school": "Marjorie W Estes Elementary School",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463000367",
    },
    {
        "school": "Marana Middle School",
        "district": "Marana Unified District (4404)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463000368",
    },
    {
        "school": "Butterfield Elementary School",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463000369",
    },
    {
        "school": "Marana High School",
        "district": "Marana Unified District (4404)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463000370",
    },
    {
        "school": "Coyote Trail Elementary School",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463000984",
    },
    {
        "school": "A. C. E.",
        "district": "Marana Unified District (4404)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463000999",
    },
    {
        "school": "Tortolita Middle School",
        "district": "Marana Unified District (4404)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463001131",
    },
    {
        "school": "Degrazia Elementary School",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463001163",
    },
    {
        "school": "Picture Rocks Elementary",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463001164",
    },
    {
        "school": "Roadrunner Elementary School",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463001165",
    },
    {
        "school": "Mountain View High School",
        "district": "Marana Unified District (4404)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463001372",
    },
    {
        "school": "Ironwood Elementary School",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463001408",
    },
    {
        "school": "Twin Peaks Elementary School",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463002197",
    },
    {
        "school": "Altar Valley Middle School",
        "district": "Altar Valley Elementary District (4418)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40477001005",
    },
    {
        "school": "Sahuarita Primary School",
        "district": "Sahuarita Unified District (4411)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40730000625",
    },
    {
        "school": "Sahuarita High School",
        "district": "Sahuarita Unified District (4411)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40730000626",
    },
    {
        "school": "Sahuarita Middle School",
        "district": "Sahuarita Unified District (4411)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40730000627",
    },
    {
        "school": "Sopori Elementary School",
        "district": "Sahuarita Unified District (4411)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40730000628",
    },
    {
        "school": "Sahuarita Intermediate School",
        "district": "Sahuarita Unified District (4411)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40730002196",
    },
    {
        "school": "San Fernando Elementary School",
        "district": "San Fernando Elementary District (4414)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40738000630",
    },
    {
        "school": "STAR Academic High School",
        "district": "Sunnyside Unified District (4407)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40817000153",
    },
    {
        "school": "Apollo Middle School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817000706",
    },
    {
        "school": "Craycroft Elementary School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817000710",
    },
    {
        "school": "Drexel Elementary School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817000715",
    },
    {
        "school": "Elvira Elementary School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817000719",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817000723",
    },
    {
        "school": "Los Ninos Elementary School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817000727",
    },
    {
        "school": "Mission Manor Elementary School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817000735",
    },
    {
        "school": "Santa Clara Elementary School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817000739",
    },
    {
        "school": "Sunnyside High School",
        "district": "Sunnyside Unified District (4407)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817000743",
    },
    {
        "school": "Ocotillo Early Learning Elementary School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817000751",
    },
    {
        "school": "Esperanza Elementary School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817001106",
    },
    {
        "school": "Sierra 2-8 School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817001149",
    },
    {
        "school": "Gallego Primary Fine Arts Magnet",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817001177",
    },
    {
        "school": "Los Amigos Elementary School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817001386",
    },
    {
        "school": "Desert View High School",
        "district": "Sunnyside Unified District (4407)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817001438",
    },
    {
        "school": "Summit View Elementary",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817001612",
    },
    {
        "school": "Challenger Middle School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817001613",
    },
    {
        "school": "Tanque Verde Elementary School",
        "district": "Tanque Verde Unified District (4408)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40828000761",
    },
    {
        "school": "Emily Gray Junior High School",
        "district": "Tanque Verde Unified District (4408)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40828000762",
    },
    {
        "school": "Agua Caliente School",
        "district": "Tanque Verde Unified District (4408)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40828001150",
    },
    {
        "school": "Alice Vail Middle School",
        "district": "Tucson Unified District (4403)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000817",
    },
    {
        "school": "Rogers Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000818",
    },
    {
        "school": "Annie Kellond Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000819",
    },
    {
        "school": "Borman Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000824",
    },
    {
        "school": "Sabino High School",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000827",
    },
    {
        "school": "C E Rose Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000828",
    },
    {
        "school": "Dietz K-8 School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000836",
    },
    {
        "school": "Doolen Middle School",
        "district": "Tucson Unified District (4403)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000837",
    },
    {
        "school": "Drachman Primary Magnet School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000838",
    },
    {
        "school": "Duffy Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000839",
    },
    {
        "school": "Dunham Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000840",
    },
    {
        "school": "Irene Erickson Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000841",
    },
    {
        "school": "Booth-Fickett Math/Science Magnet School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000842",
    },
    {
        "school": "Ford Elementary",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000843",
    },
    {
        "school": "Fruchthendler Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000845",
    },
    {
        "school": "Gale Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000846",
    },
    {
        "school": "Gridley Middle School",
        "district": "Tucson Unified District (4403)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000848",
    },
    {
        "school": "Anna Henry Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000850",
    },
    {
        "school": "Holladay Intermediate Magnet School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000851",
    },
    {
        "school": "Hollinger K-8 School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000852",
    },
    {
        "school": "Howell Peter Elementary",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000853",
    },
    {
        "school": "Hudlow Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000854",
    },
    {
        "school": "Julia Keen Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000857",
    },
    {
        "school": "Anna Lawrence Intermediate School",
        "district": "Tucson Unified District (4403)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000858",
    },
    {
        "school": "Lineweaver Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000859",
    },
    {
        "school": "Lowell H Smith Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000860",
    },
    {
        "school": "Lynn Urquides",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000861",
    },
    {
        "school": "Magee Middle School",
        "district": "Tucson Unified District (4403)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000863",
    },
    {
        "school": "Mansfeld Middle Magnet School",
        "district": "Tucson Unified District (4403)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000864",
    },
    {
        "school": "Manzo Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000865",
    },
    {
        "school": "Marshall Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000866",
    },
    {
        "school": "Miles-Exploratory Learning Center",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000869",
    },
    {
        "school": "Mission View Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000870",
    },
    {
        "school": "Myers-Ganoung Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000871",
    },
    {
        "school": "Roberts Naylor",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000872",
    },
    {
        "school": "Ochoa Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000873",
    },
    {
        "school": "Pistor Middle School",
        "district": "Tucson Unified District (4403)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000874",
    },
    {
        "school": "Pueblo Gardens Elementary",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000875",
    },
    {
        "school": "Reynolds Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000876",
    },
    {
        "school": "Davidson Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000878",
    },
    {
        "school": "Robison Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000880",
    },
    {
        "school": "Roskruge Bilingual Elementary School - Closed",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000882",
    },
    {
        "school": "Safford Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000885",
    },
    {
        "school": "Safford K-8 School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000886",
    },
    {
        "school": "Sam Hughes Elementary",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000887",
    },
    {
        "school": "Secrist Middle School",
        "district": "Tucson Unified District (4403)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000889",
    },
    {
        "school": "Harold Steele Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000890",
    },
    {
        "school": "Tolson Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000891",
    },
    {
        "school": "Utterback Middle School",
        "district": "Tucson Unified District (4403)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000896",
    },
    {
        "school": "Van Buskirk Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000897",
    },
    {
        "school": "Van Horne Elementary School - Closed",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000898",
    },
    {
        "school": "Vesey Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000899",
    },
    {
        "school": "W Arthur Sewel Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000900",
    },
    {
        "school": "Frances J Warren Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000902",
    },
    {
        "school": "Wheeler Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000903",
    },
    {
        "school": "John E White Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000904",
    },
    {
        "school": "W V Whitmore Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000905",
    },
    {
        "school": "John B Wright Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000906",
    },
    {
        "school": "Wrightstown Elementary - Closed",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000907",
    },
    {
        "school": "Robins Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000966",
    },
    {
        "school": "Valencia Middle School",
        "district": "Tucson Unified District (4403)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880000972",
    },
    {
        "school": "Jefferson Park Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001111",
    },
    {
        "school": "Miller Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001112",
    },
    {
        "school": "Tully Elementary Accelerated Magnet School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001113",
    },
    {
        "school": "Blenman Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001260",
    },
    {
        "school": "Catalina High School",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001261",
    },
    {
        "school": "Bonillas Elementary Basic Curriculum Magnet School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001262",
    },
    {
        "school": "Palo Verde High Magnet School",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001263",
    },
    {
        "school": "Borton Primary Magnet School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001264",
    },
    {
        "school": "Carrillo Intermediate Magnet School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001266",
    },
    {
        "school": "Cavett Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001267",
    },
    {
        "school": "Tucson Magnet High School",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001268",
    },
    {
        "school": "Cragin Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001269",
    },
    {
        "school": "University High School",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001441",
    },
    {
        "school": "Bloom Elementary",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001442",
    },
    {
        "school": "Cholla High School",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001443",
    },
    {
        "school": "Pueblo High School",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001445",
    },
    {
        "school": "Rincon High School",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001446",
    },
    {
        "school": "Sahuaro High School",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001447",
    },
    {
        "school": "Santa Rita High School",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001448",
    },
    {
        "school": "Collier Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001449",
    },
    {
        "school": "Davis Bilingual Magnet School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001452",
    },
    {
        "school": "Maldonado Amelia Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001454",
    },
    {
        "school": "Ida Flood Dodge Traditional Middle Magnet School",
        "district": "Tucson Unified District (4403)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001455",
    },
    {
        "school": "Soleng Tom Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001479",
    },
    {
        "school": "Raul Grijalva Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001481",
    },
    {
        "school": "Roskruge Bilingual Magnet Middle School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001506",
    },
    {
        "school": "Project More High School",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40880001508",
    },
    {
        "school": "Teenage Parent Program - TAPP",
        "district": "Tucson Unified District (4403)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40880001509",
    },
    {
        "school": "Harriet Johnson Primary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001569",
    },
    {
        "school": "Mary Meredith K-12 School",
        "district": "Tucson Unified District (4403)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40880001606",
    },
    {
        "school": "Downtown Alternative High School",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880001609",
    },
    {
        "school": "Mary Meredith High School",
        "district": "Tucson Unified District (4403)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880002063",
    },
    {
        "school": "Old Vail Middle School",
        "district": "Vail Unified District (4413)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885000909",
    },
    {
        "school": "Desert Willow Elementary School",
        "district": "Vail Unified District (4413)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885001003",
    },
    {
        "school": "Acacia Elementary School",
        "district": "Vail Unified District (4413)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885001510",
    },
    {
        "school": "Mesquite Elementary School",
        "district": "Vail Unified District (4413)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885001954",
    },
    {
        "school": "Vail Academy & High School",
        "district": "Vail Unified District (4413)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885001955",
    },
    {
        "school": "Civano Community K-8 School",
        "district": "Vail Unified District (4413)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885001956",
    },
    {
        "school": "Cottonwood Elementary School",
        "district": "Vail Unified District (4413)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885002193",
    },
    {
        "school": "Desert Sky Middle School",
        "district": "Vail Unified District (4413)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885002194",
    },
    {
        "school": "Cienega High School",
        "district": "Vail Unified District (4413)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885002195",
    },
    {
        "school": "PPEP TEC - Alice S. Paul Learning Center",
        "district": "Portable Practical Educational Preparation Inc. ( (4431)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40008301014",
    },
    {
        "school": "PPEP TEC - Cesar Chavez Learning Center",
        "district": "Portable Practical Educational Preparation Inc. ( (4431)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40008301016",
    },
    {
        "school": "PPEP TEC - Jose Yepez Learning Center",
        "district": "Portable Practical Educational Preparation Inc. ( (4431)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40008301017",
    },
    {
        "school": "AmeriSchools Academy - Yuma",
        "district": "The Charter Foundation Inc. (6355)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40013101960",
    },
    {
        "school": "Desert View Middle & High School",
        "district": "Carpe Diem Collegiate High School (80001)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40038102319",
    },
    {
        "school": "Gary A. Knox Elementary School",
        "district": "Crane Elementary District (4501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240002424",
    },
    {
        "school": "Salida Del Sol Elementary",
        "district": "Crane Elementary District (4501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240002425",
    },
    {
        "school": "Southwest Jr. High School",
        "district": "Gadsden Elementary District (4505)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40324002388",
    },
    {
        "school": "Ed Pastor Elementary 4",
        "district": "Gadsden Elementary District (4505)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40324002389",
    },
    {
        "school": "Cesar Chavez Elementary",
        "district": "Gadsden Elementary District (4505)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40324003066",
    },
    {
        "school": "Desert View Elementary",
        "district": "Gadsden Elementary District (4505)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40324003116",
    },
    {
        "school": "Valle Del Encanto Learning Center",
        "district": "Somerton Elementary District (4500)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40789002568",
    },
    {
        "school": "Ron Watson Middle School",
        "district": "Yuma Elementary District (4499)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960002427",
    },
    {
        "school": "Sunrise Elementary School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960002567",
    },
    {
        "school": "San Luis High School",
        "district": "Yuma Union High School District (4507)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40963003076",
    },
    {
        "school": "AZTEC High School",
        "district": "Az-Tec High School (4508)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40009401109",
    },
    {
        "school": "Educational Opportunity Center",
        "district": "Yuma Private Industry Council Inc. (4509)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40009501114",
    },
    {
        "school": "Desert View Academy",
        "district": "Juniper Tree Academy (79064)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40026802092",
    },
    {
        "school": "Harvest Preparatory Academy",
        "district": "Harvest Power Community Development Group Inc. (79501)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40028202232",
    },
    {
        "school": "Antelope Union High School",
        "district": "Antelope Union High School District (4506)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40072000034",
    },
    {
        "school": "Crane Middle School",
        "district": "Crane Elementary District (4501)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240000014",
    },
    {
        "school": "H L Suverkrup Elementary School",
        "district": "Crane Elementary District (4501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240000017",
    },
    {
        "school": "Ronald Reagan Fundamental School",
        "district": "Crane Elementary District (4501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240000036",
    },
    {
        "school": "Valley Horizon Elementary School",
        "district": "Crane Elementary District (4501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240000037",
    },
    {
        "school": "Pueblo Elementary School",
        "district": "Crane Elementary District (4501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240000171",
    },
    {
        "school": "Rancho Viejo Elementary School",
        "district": "Crane Elementary District (4501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240001087",
    },
    {
        "school": "Centennial Middle School",
        "district": "Crane Elementary District (4501)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240001976",
    },
    {
        "school": "Gadsden Elementary School",
        "district": "Gadsden Elementary District (4505)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40324000250",
    },
    {
        "school": "San Luis Middle School",
        "district": "Gadsden Elementary District (4505)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40324001101",
    },
    {
        "school": "San Luis Pre-School",
        "district": "Gadsden Elementary District (4505)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40324001108",
    },
    {
        "school": "Rio Colorado Elementary School",
        "district": "Gadsden Elementary District (4505)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40324001213",
    },
    {
        "school": "Arizona Desert Elementary School",
        "district": "Gadsden Elementary District (4505)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40324001806",
    },
    {
        "school": "Dateland Elementary School",
        "district": "Hyder Elementary District (4502)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40390000309",
    },
    {
        "school": "Mohawk Valley School",
        "district": "Mohawk Valley Elementary District (4503)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40522000436",
    },
    {
        "school": "Somerton Middle School",
        "district": "Somerton Elementary District (4500)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40789000698",
    },
    {
        "school": "Orange Grove Elementary School",
        "district": "Somerton Elementary District (4500)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40789001256",
    },
    {
        "school": "Desert Sonora Elementary School",
        "district": "Somerton Elementary District (4500)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40789001565",
    },
    {
        "school": "Tierra Del Sol Elementary School",
        "district": "Somerton Elementary District (4500)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40789001566",
    },
    {
        "school": "Wellton Elementary School",
        "district": "Wellton Elementary District (4504)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40909000948",
    },
    {
        "school": "Alice Byrne Elementary School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000981",
    },
    {
        "school": "C W Mcgraw Elementary School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000982",
    },
    {
        "school": "George Washington Carver Elementary School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000983",
    },
    {
        "school": "Fourth Avenue Junior High School",
        "district": "Yuma Elementary District (4499)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000985",
    },
    {
        "school": "Gila Vista Jr High School",
        "district": "Yuma Elementary District (4499)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000986",
    },
    {
        "school": "James B Rolle School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000988",
    },
    {
        "school": "James D Price School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000989",
    },
    {
        "school": "Mary E  Post Elementary School",
        "district": "Yuma Elementary District (4499)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000990",
    },
    {
        "school": "O C Johnson School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000991",
    },
    {
        "school": "Palmcroft Elementary School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000992",
    },
    {
        "school": "Pecan Grove Elementary School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000993",
    },
    {
        "school": "R Pete Woodard Jr High School",
        "district": "Yuma Elementary District (4499)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000994",
    },
    {
        "school": "Roosevelt School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960000995",
    },
    {
        "school": "Mary A Otondo Elementary School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960001572",
    },
    {
        "school": "Desert Mesa Elementary School",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960001804",
    },
    {
        "school": "Castle Dome Middle School",
        "district": "Yuma Elementary District (4499)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960001805",
    },
    {
        "school": "Vista High School",
        "district": "Yuma Union High School District (4507)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40963000157",
    },
    {
        "school": "Kofa High School",
        "district": "Yuma Union High School District (4507)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40963000996",
    },
    {
        "school": "Yuma High School",
        "district": "Yuma Union High School District (4507)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40963000997",
    },
    {
        "school": "Cibola High School",
        "district": "Yuma Union High School District (4507)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40963001388",
    },
    {
        "school": "Ruby Bridges Elementary",
        "district": "Alameda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177011549",
    },
    {
        "school": "Stonebrae Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674011550",
    },
    {
        "school": "United for Success Academy",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805011909",
    },
    {
        "school": "Coliseum College Prep Academy",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805011920",
    },
    {
        "school": "Elmhurst United Middle",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805011961",
    },
    {
        "school": "Fred T. Korematsu Discovery Academy",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805011977",
    },
    {
        "school": "East Bay Arts High",
        "district": "San Lorenzo Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63471011567",
    },
    {
        "school": "Academy for Change",
        "district": "Chico Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60837011853",
    },
    {
        "school": "Golden Hills Elementary",
        "district": "Palermo Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62954011570",
    },
    {
        "school": "Orchard Park",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285011904",
    },
    {
        "school": "Adams (J. Douglas) Middle",
        "district": "Brentwood Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60591011574",
    },
    {
        "school": "Iron House Elementary",
        "district": "Oakley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62808011575",
    },
    {
        "school": "Live Oak Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513011880",
    },
    {
        "school": "Dougherty Valley High",
        "district": "San Ramon Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513011990",
    },
    {
        "school": "Russell Ranch Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389011989",
    },
    {
        "school": "Harvest Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797011948",
    },
    {
        "school": "Reagan Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903011587",
    },
    {
        "school": "Clovis North High",
        "district": "Clovis Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903011855",
    },
    {
        "school": "Granite Ridge Intermediate",
        "district": "Clovis Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903012015",
    },
    {
        "school": "Bud Rank Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903012029",
    },
    {
        "school": "Deborah A. Williams Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455011895",
    },
    {
        "school": "Mario G. Olmos Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455011998",
    },
    {
        "school": "Ronald W. Reagan Elementary",
        "district": "Kingsburg Elementary Charter",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61980011915",
    },
    {
        "school": "Ronald W. Reagan Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525011999",
    },
    {
        "school": "Trillium Charter",
        "district": "Pacific Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62943011947",
    },
    {
        "school": "Enrique Camarena Jr. High",
        "district": "Calexico Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60690011595",
    },
    {
        "school": "Cesar Chavez Elementary",
        "district": "Calexico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60690011897",
    },
    {
        "school": "El Camino Real Elementary",
        "district": "Arvin Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60327011908",
    },
    {
        "school": "Stonecreek Junior High",
        "district": "Panama-Buena Vista Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639011597",
    },
    {
        "school": "Old River Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639012036",
    },
    {
        "school": "La Vina Middle",
        "district": "Delano Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089011598",
    },
    {
        "school": "Horizon Elementary",
        "district": "Greenfield Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61605011600",
    },
    {
        "school": "Frontier High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954011601",
    },
    {
        "school": "Hacienda Elementary",
        "district": "Mojave Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62523011964",
    },
    {
        "school": "Veterans Elementary",
        "district": "Norris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62745011866",
    },
    {
        "school": "American Elementary",
        "district": "Rosedale Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63348011603",
    },
    {
        "school": "Westpark Elementary",
        "district": "Southern Kern Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63762011604",
    },
    {
        "school": "Teresa Burke Elementary",
        "district": "Wasco Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64140012045",
    },
    {
        "school": "Corcoran Academy",
        "district": "Corcoran Joint Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60969011955",
    },
    {
        "school": "Hamilton Elementary",
        "district": "Hanford Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61647011606",
    },
    {
        "school": "SOAR High (Students On Academic Rise)",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60282011610",
    },
    {
        "school": "Jane Addams Middle",
        "district": "Lawndale Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62121011612",
    },
    {
        "school": "Lucille J. Smith Elementary",
        "district": "Lawndale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62121011613",
    },
    {
        "school": "George De La Torre Jr. Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011644",
    },
    {
        "school": "Frank del Olmo Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011645",
    },
    {
        "school": "Charles H. Kim Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011646",
    },
    {
        "school": "Huntington Park Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011647",
    },
    {
        "school": "Wilshire Park Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011648",
    },
    {
        "school": "William Jefferson Clinton Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011649",
    },
    {
        "school": "School of Business and Tourism at Contreras Learning Complex",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011650",
    },
    {
        "school": "East Valley Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011651",
    },
    {
        "school": "Arleta High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011652",
    },
    {
        "school": "Panorama High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011653",
    },
    {
        "school": "Hesby Oaks Leadership Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011654",
    },
    {
        "school": "Contreras Lrng Center-Los Angeles Sch of Global Studies",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011888",
    },
    {
        "school": "Lopez Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132011671",
    },
    {
        "school": "Rowland Assistive Technology Academy",
        "district": "Rowland Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63375011676",
    },
    {
        "school": "Sequoia School",
        "district": "William S. Hart Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251011675",
    },
    {
        "school": "Centennial Independent Study",
        "district": "Golden Valley Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006811949",
    },
    {
        "school": "Coarsegold Elementary",
        "district": "Yosemite Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60016000936",
    },
    {
        "school": "Yosemite High",
        "district": "Yosemite Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60016007023",
    },
    {
        "school": "Meadowbrook Community Day",
        "district": "Yosemite Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60016007168",
    },
    {
        "school": "Ahwahnee High",
        "district": "Yosemite Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60016007902",
    },
    {
        "school": "Raymond Granite High",
        "district": "Yosemite Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60016009210",
    },
    {
        "school": "Rivergold Elementary",
        "district": "Yosemite Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60016010252",
    },
    {
        "school": "Evergreen High",
        "district": "Yosemite Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60016010254",
    },
    {
        "school": "Ronald Reagan Elementary",
        "district": "Chowchilla Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60852011852",
    },
    {
        "school": "Cesar Chavez Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334011678",
    },
    {
        "school": "Madera South High",
        "district": "Madera Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334011679",
    },
    {
        "school": "John J. Pershing Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334011926",
    },
    {
        "school": "Marin County Juvenile Court",
        "district": "Marin County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101811913",
    },
    {
        "school": "Joe Stefani",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460011688",
    },
    {
        "school": "Winfield Elementary",
        "district": "Winton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64296012038",
    },
    {
        "school": "Floyd A. Schelby",
        "district": "Merced County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102011944",
    },
    {
        "school": "Marina High",
        "district": "Monterey Peninsula Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553011697",
    },
    {
        "school": "Monterey Peninsula Unified School District Community Day",
        "district": "Monterey Peninsula Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62553011941",
    },
    {
        "school": "Jack Franscioni Elementary",
        "district": "Soledad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63705011698",
    },
    {
        "school": "William & Marian Ghidotti High",
        "district": "Nevada Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62688011700",
    },
    {
        "school": "Forest Charter",
        "district": "Nevada County Office of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102311839",
    },
    {
        "school": "Twin Ridges Home Study Charter",
        "district": "Nevada County Office of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102311877",
    },
    {
        "school": "Bitney Prep High",
        "district": "Nevada County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102311975",
    },
    {
        "school": "Yuba River Charter",
        "district": "Nevada County Office of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102311992",
    },
    {
        "school": "Orange Grove Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261011958",
    },
    {
        "school": "Arroyo Vista Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744011701",
    },
    {
        "school": "San Juan Hills High",
        "district": "Capistrano Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744011854",
    },
    {
        "school": "Capistrano Home/Virtual",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60744011903",
    },
    {
        "school": "Early College High",
        "district": "Newport-Mesa Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62724011702",
    },
    {
        "school": "Twelve Bridges Middle",
        "district": "Western Placer Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64214011705",
    },
    {
        "school": "Lincoln Crossing Elementary",
        "district": "Western Placer Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64214011847",
    },
    {
        "school": "Sierra Vista",
        "district": "Placer County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102511859",
    },
    {
        "school": "Earl Warren Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002712001",
    },
    {
        "school": "Temecula Luiseno Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002811838",
    },
    {
        "school": "Lisa J. Mails Elementary",
        "district": "Murrieta Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002911921",
    },
    {
        "school": "Phillip M. Stokoe Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243011845",
    },
    {
        "school": "Lake Hills Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243012032",
    },
    {
        "school": "Tournament Hills Elementary",
        "district": "Beaumont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60429011956",
    },
    {
        "school": "Coral Mountain Academy",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907011720",
    },
    {
        "school": "Bobby Duke Middle",
        "district": "Coachella Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907011969",
    },
    {
        "school": "Eleanor Roosevelt High",
        "district": "Corona-Norco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985011709",
    },
    {
        "school": "River Heights Intermediate",
        "district": "Corona-Norco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985011710",
    },
    {
        "school": "Eastvale Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985011711",
    },
    {
        "school": "John F. Kennedy High",
        "district": "Corona-Norco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60985011712",
    },
    {
        "school": "Dr. Bernice Jameson Todd Academy",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985011861",
    },
    {
        "school": "Rosa Parks Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985011994",
    },
    {
        "school": "Ronald Reagan Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111011713",
    },
    {
        "school": "Colonel Mitchell Paige Middle",
        "district": "Desert Sands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111011714",
    },
    {
        "school": "Tahquitz High",
        "district": "Hemet Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692012024",
    },
    {
        "school": "Evans Ranch Elementary",
        "district": "Menifee Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454011716",
    },
    {
        "school": "Railway Elementary",
        "district": "Perris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63018011717",
    },
    {
        "school": "Sky View Elementary",
        "district": "Perris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63018011718",
    },
    {
        "school": "Heritage High",
        "district": "Perris Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63021011848",
    },
    {
        "school": "Mark Twain Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315011719",
    },
    {
        "school": "Mesa View Elementary",
        "district": "Romoland Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63339011886",
    },
    {
        "school": "Triple Crown Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113511724",
    },
    {
        "school": "March Middle",
        "district": "Val Verde Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113511725",
    },
    {
        "school": "Heron",
        "district": "Natomas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003611734",
    },
    {
        "school": "Natomas Pacific Pathways Prep",
        "district": "Natomas Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003611735",
    },
    {
        "school": "Barrett Ranch Elementary",
        "district": "Dry Creek Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61149011703",
    },
    {
        "school": "Carroll Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233011726",
    },
    {
        "school": "Navigator Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389011729",
    },
    {
        "school": "Vista del Lago High",
        "district": "Folsom-Cordova Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389011932",
    },
    {
        "school": "John Morse Therapeutic Center",
        "district": "Sacramento City Unified",
        "level": "Middle",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63384011917",
    },
    {
        "school": "Sitting Bull Academy",
        "district": "Apple Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001711747",
    },
    {
        "school": "West Creek Elementary",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171011736",
    },
    {
        "school": "Challenges Community Day",
        "district": "Barstow Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60402011946",
    },
    {
        "school": "Chaparral Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846011737",
    },
    {
        "school": "Perdew Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296011841",
    },
    {
        "school": "Kathy Binks Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392011962",
    },
    {
        "school": "Riverside Preparatory",
        "district": "Oro Grande",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62895011863",
    },
    {
        "school": "Judson & Brown Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207011740",
    },
    {
        "school": "Juanita Blakely Jones Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417011741",
    },
    {
        "school": "Tiefort View Intermediate",
        "district": "Silver Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63682011743",
    },
    {
        "school": "Vista Verde Elementary",
        "district": "Snowline Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697011744",
    },
    {
        "school": "West Palms Conservatory",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104011914",
    },
    {
        "school": "Los Coches Creek Middle",
        "district": "Cajon Valley Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681011751",
    },
    {
        "school": "Poinsettia Elementary",
        "district": "Carlsbad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750011987",
    },
    {
        "school": "Wolf Canyon Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861011875",
    },
    {
        "school": "Cesar Chavez Middle",
        "district": "Oceanside Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825011922",
    },
    {
        "school": "Louise Foussat Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825012011",
    },
    {
        "school": "Monterey Ridge Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153011757",
    },
    {
        "school": "Normal Heights Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011765",
    },
    {
        "school": "Lincoln High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011939",
    },
    {
        "school": "Rodriguez Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011973",
    },
    {
        "school": "Joyner Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432012000",
    },
    {
        "school": "San Elijo Elementary",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488011771",
    },
    {
        "school": "Olympian High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864011768",
    },
    {
        "school": "Maryland Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119011769",
    },
    {
        "school": "Feinstein (Dianne) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441011772",
    },
    {
        "school": "George Lincoln Mosher",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223011774",
    },
    {
        "school": "Woodbridge",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223011775",
    },
    {
        "school": "New Vision High",
        "district": "Manteca Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62361011776",
    },
    {
        "school": "Mossdale Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361011959",
    },
    {
        "school": "John Marshall Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801011778",
    },
    {
        "school": "Maxine Hong Kingston Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801011779",
    },
    {
        "school": "Pittman Charter",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801011780",
    },
    {
        "school": "Wilhelmina Henry Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801011781",
    },
    {
        "school": "John C. Fremont Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801011782",
    },
    {
        "school": "Alexander Hamilton Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801011783",
    },
    {
        "school": "Lange (Dorothea) Elementary",
        "district": "Lucia Mar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308011785",
    },
    {
        "school": "Gateway Center",
        "district": "San Mateo County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103311960",
    },
    {
        "school": "Margaret J. Kemp",
        "district": "San Mateo County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103312003",
    },
    {
        "school": "Taylor Mountain Elementary",
        "district": "Bellevue Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60438011843",
    },
    {
        "school": "Don Callejon",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543011797",
    },
    {
        "school": "North Cottonwood",
        "district": "Cottonwood Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60999011802",
    },
    {
        "school": "Happy Valley Community Day",
        "district": "Happy Valley Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61657011803",
    },
    {
        "school": "Weir Preparatory Academy",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336011891",
    },
    {
        "school": "Cordelia Hills Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336011938",
    },
    {
        "school": "Rolling Hills Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336011995",
    },
    {
        "school": "Forestville Academy",
        "district": "Forestville Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61401012023",
    },
    {
        "school": "Santa Rosa Charter School for the Arts",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581011850",
    },
    {
        "school": "Adelante High",
        "district": "Riverbank Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006111814",
    },
    {
        "school": "Riverbank Language Academy",
        "district": "Riverbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006111925",
    },
    {
        "school": "La Rosa Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813011808",
    },
    {
        "school": "James C. Enochs High",
        "district": "Modesto City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62515011812",
    },
    {
        "school": "Paradise Charter",
        "district": "Paradise Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62979011813",
    },
    {
        "school": "Crossroads Elementary",
        "district": "Sylvan Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867011851",
    },
    {
        "school": "Mary Ann Sanders Elementary",
        "district": "Sylvan Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867011872",
    },
    {
        "school": "Riverbend Elementary",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347011930",
    },
    {
        "school": "Feather River Academy",
        "district": "Sutter County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104211997",
    },
    {
        "school": "Sequoia Middle",
        "district": "Porterville Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006411825",
    },
    {
        "school": "Butterfield Charter",
        "district": "Porterville Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006412042",
    },
    {
        "school": "Burton Community Day",
        "district": "Burton Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60657011821",
    },
    {
        "school": "Buena Vista Community Day",
        "district": "Pleasant View Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63105011822",
    },
    {
        "school": "Mission Valley Elementary",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987012002",
    },
    {
        "school": "Cottonwood Creek Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116011824",
    },
    {
        "school": "Rio Del Mar",
        "district": "Rio Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63276011833",
    },
    {
        "school": "Rio Vista Middle",
        "district": "Rio Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63276011957",
    },
    {
        "school": "Fred T. Korematsu Elementary at Mace Ranch",
        "district": "Davis Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062011834",
    },
    {
        "school": "Clarksburg Middle",
        "district": "River Delta Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63311011731",
    },
    {
        "school": "Cesar Chavez Community",
        "district": "Yolo County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104911976",
    },
    {
        "school": "Riverside Meadows Intermediate",
        "district": "Plumas Lake Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63118011836",
    },
    {
        "school": "Thomas E. Mathews Community",
        "district": "Yuba County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104811993",
    },
    {
        "school": "Amador County ROP",
        "district": "Amador County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60008910738",
    },
    {
        "school": "Calaveras County Special Education (SELPA)",
        "district": "Calaveras County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100310746",
    },
    {
        "school": "Oakendell Community",
        "district": "Calaveras County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100311572",
    },
    {
        "school": "Glenn County ROP",
        "district": "Glenn County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60009910791",
    },
    {
        "school": "Lassen ROP",
        "district": "Lassen ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60007910822",
    },
    {
        "school": "Modoc County ROP",
        "district": "Modoc County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60008110966",
    },
    {
        "school": "Mono County ROP",
        "district": "Mono County ROC/P",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60015510968",
    },
    {
        "school": "Plumas County ROP",
        "district": "Plumas County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60008311011",
    },
    {
        "school": "Plumas County Community",
        "district": "Plumas County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69110210576",
    },
    {
        "school": "Plumas County Opportunity",
        "district": "Plumas County Office of Education",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69110211706",
    },
    {
        "school": "William R. Rouse ROP",
        "district": "WIlliam (R) Rouse ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60012611469",
    },
    {
        "school": "Siskiyou County ROP",
        "district": "Siskiyou ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60012711472",
    },
    {
        "school": "Diamond Valley Elementary",
        "district": "Alpine County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60207000090",
    },
    {
        "school": "Alpine County Secondary Community Day",
        "district": "Alpine County Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60207006968",
    },
    {
        "school": "Alpine County Opportunity",
        "district": "Alpine County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69105806965",
    },
    {
        "school": "North Star Independent Study",
        "district": "Amador County Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60245006975",
    },
    {
        "school": "Independence High (Continuation)",
        "district": "Amador County Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60245008785",
    },
    {
        "school": "Amador High",
        "district": "Amador County Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245008786",
    },
    {
        "school": "Argonaut High",
        "district": "Amador County Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245008787",
    },
    {
        "school": "Ione Elementary",
        "district": "Amador County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245008788",
    },
    {
        "school": "Jackson Elementary",
        "district": "Amador County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245008789",
    },
    {
        "school": "Pine Grove Elementary STEM Magnet",
        "district": "Amador County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245008790",
    },
    {
        "school": "Pioneer Magnet School for the Visual and Performing Arts",
        "district": "Amador County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245008791",
    },
    {
        "school": "Plymouth Elementary",
        "district": "Amador County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245008792",
    },
    {
        "school": "Sutter Creek Elementary",
        "district": "Amador County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245008793",
    },
    {
        "school": "Jackson Junior High",
        "district": "Amador County Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245009300",
    },
    {
        "school": "Ione Junior High",
        "district": "Amador County Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245009301",
    },
    {
        "school": "Amador County Special Education",
        "district": "Amador County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100106970",
    },
    {
        "school": "County Community",
        "district": "Amador County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100109474",
    },
    {
        "school": "Bret Harte Union High",
        "district": "Bret Harte Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60594000537",
    },
    {
        "school": "Vallecito Continuation High",
        "district": "Bret Harte Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60594000538",
    },
    {
        "school": "John Vierra High",
        "district": "Bret Harte Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60594006991",
    },
    {
        "school": "Calaveras High",
        "district": "Calaveras Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60687000625",
    },
    {
        "school": "Gold Strike High",
        "district": "Calaveras Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60687000627",
    },
    {
        "school": "Mokelumne Hill Elementary",
        "district": "Calaveras Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60687000628",
    },
    {
        "school": "Rail Road Flat Elementary",
        "district": "Calaveras Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60687000629",
    },
    {
        "school": "San Andreas Elementary",
        "district": "Calaveras Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60687000630",
    },
    {
        "school": "Valley Springs Elementary",
        "district": "Calaveras Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60687000631",
    },
    {
        "school": "West Point Elementary",
        "district": "Calaveras Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60687000632",
    },
    {
        "school": "Toyon Middle",
        "district": "Calaveras Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60687008803",
    },
    {
        "school": "Calaveras Unified Alternative-Sierra Hills Education Center",
        "district": "Calaveras Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60687009340",
    },
    {
        "school": "Jenny Lind Elementary",
        "district": "Calaveras Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60687009522",
    },
    {
        "school": "Mark Twain Elementary",
        "district": "Mark Twain Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62397003609",
    },
    {
        "school": "Copperopolis Elementary",
        "district": "Mark Twain Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62397009578",
    },
    {
        "school": "Avery Middle",
        "district": "Vallecito Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64068002907",
    },
    {
        "school": "Albert A. Michelson Elementary",
        "district": "Vallecito Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64068006715",
    },
    {
        "school": "Hazel Fischer Elementary",
        "district": "Vallecito Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64068006716",
    },
    {
        "school": "Home School Academy (Alternative)",
        "district": "Vallecito Union",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64068007000",
    },
    {
        "school": "Mountain Oaks",
        "district": "Calaveras County Office of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69100308686",
    },
    {
        "school": "Calaveras River Academy",
        "district": "Calaveras County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100309215",
    },
    {
        "school": "Colusa High",
        "district": "Colusa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60957000966",
    },
    {
        "school": "George T. Egling Middle",
        "district": "Colusa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60957000967",
    },
    {
        "school": "James M. Burchfield Primary",
        "district": "Colusa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60957000968",
    },
    {
        "school": "Colusa Alternative Home",
        "district": "Colusa Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60957004434",
    },
    {
        "school": "Colusa Alternative High (Continuation)",
        "district": "Colusa Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60957008128",
    },
    {
        "school": "Maxwell Elementary",
        "district": "Maxwell Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62415003641",
    },
    {
        "school": "Maxwell Sr High",
        "district": "Maxwell Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62415003642",
    },
    {
        "school": "Arbuckle Alternative High (Continuation)",
        "district": "Pierce Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63036002931",
    },
    {
        "school": "Arbuckle Elementary",
        "district": "Pierce Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63036004734",
    },
    {
        "school": "Grand Island Elementary",
        "district": "Pierce Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63036004735",
    },
    {
        "school": "Pierce High",
        "district": "Pierce Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63036004736",
    },
    {
        "school": "Lloyd G. Johnson Junior High",
        "district": "Pierce Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63036008941",
    },
    {
        "school": "Indian Valley Elementary",
        "district": "Stony Creek Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63807006442",
    },
    {
        "school": "Mid Valley High (Continuation)",
        "district": "Williams Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64254000117",
    },
    {
        "school": "Williams Primary Elementary",
        "district": "Williams Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64254006963",
    },
    {
        "school": "Williams Junior/Senior High",
        "district": "Williams Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64254006964",
    },
    {
        "school": "S. William Abel Community",
        "district": "Colusa County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100407491",
    },
    {
        "school": "Coastal Buttes",
        "district": "Colusa County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100407910",
    },
    {
        "school": "North Valley High (Continuation)",
        "district": "Orland Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004507089",
    },
    {
        "school": "Orland High",
        "district": "Orland Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004507090",
    },
    {
        "school": "Fairview Elementary",
        "district": "Orland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004507091",
    },
    {
        "school": "Price Intermediate",
        "district": "Orland Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004507093",
    },
    {
        "school": "Orland Community Day",
        "district": "Orland Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004508484",
    },
    {
        "school": "Capay Joint Union Elementary",
        "district": "Capay Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60741000682",
    },
    {
        "school": "Lake Elementary",
        "district": "Lake Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62061002475",
    },
    {
        "school": "Plaza Elementary",
        "district": "Plaza Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63087004790",
    },
    {
        "school": "Princeton Elementary",
        "district": "Princeton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63162004901",
    },
    {
        "school": "Princeton Junior-Senior High",
        "district": "Princeton Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63162004902",
    },
    {
        "school": "Elk Creek Elementary",
        "district": "Stony Creek Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63807006440",
    },
    {
        "school": "Elk Creek Junior-Senior High",
        "district": "Stony Creek Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63807006441",
    },
    {
        "school": "Bidwell Point High (Continuation)",
        "district": "Stony Creek Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63807009644",
    },
    {
        "school": "Murdock Elementary",
        "district": "Willows Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64271006977",
    },
    {
        "school": "Willows High",
        "district": "Willows Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64271006978",
    },
    {
        "school": "Willows Intermediate",
        "district": "Willows Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64271006979",
    },
    {
        "school": "Willows Community High",
        "district": "Willows Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64271007370",
    },
    {
        "school": "William Finch",
        "district": "Glenn County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100808479",
    },
    {
        "school": "Glenn County Special Education",
        "district": "Glenn County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100809221",
    },
    {
        "school": "Herlong High",
        "district": "Fort Sage Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001109065",
    },
    {
        "school": "Fort Sage Middle",
        "district": "Fort Sage Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001109066",
    },
    {
        "school": "Sierra Primary",
        "district": "Fort Sage Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001109068",
    },
    {
        "school": "Big Valley Jr. Sr. High",
        "district": "Big Valley Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60501000482",
    },
    {
        "school": "Big Valley Elementary",
        "district": "Big Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60501000483",
    },
    {
        "school": "Janesville Elementary",
        "district": "Janesville Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61878002275",
    },
    {
        "school": "Johnstonville Elementary",
        "district": "Johnstonville Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61905002304",
    },
    {
        "school": "Lassen High",
        "district": "Lassen Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62106002532",
    },
    {
        "school": "Lassen Community Day",
        "district": "Lassen Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62106007104",
    },
    {
        "school": "Juniper Ridge Elementary",
        "district": "Ravendale-Termo Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63183004912",
    },
    {
        "school": "Richmond Elementary",
        "district": "Richmond Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63252005005",
    },
    {
        "school": "Shaffer Elementary",
        "district": "Shaffer Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63642006200",
    },
    {
        "school": "Diamond View Middle",
        "district": "Susanville Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63855006471",
    },
    {
        "school": "McKinley Elementary",
        "district": "Susanville Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63855006472",
    },
    {
        "school": "Meadow View",
        "district": "Susanville Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63855010230",
    },
    {
        "school": "Fletcher Walker Elementary",
        "district": "Westwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64230006922",
    },
    {
        "school": "Westwood High",
        "district": "Westwood Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64230006924",
    },
    {
        "school": "Lassen County Special Education",
        "district": "Lassen County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69101507124",
    },
    {
        "school": "Greeley Hill Elementary",
        "district": "Mariposa County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62394003599",
    },
    {
        "school": "Yosemite National Park El Portal",
        "district": "Mariposa County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62394003600",
    },
    {
        "school": "Mariposa County High",
        "district": "Mariposa County Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62394003602",
    },
    {
        "school": "Mariposa Elementary",
        "district": "Mariposa County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62394003603",
    },
    {
        "school": "Woodland Elementary",
        "district": "Mariposa County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62394003607",
    },
    {
        "school": "Yosemite National Park Valley Elementary",
        "district": "Mariposa County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62394003608",
    },
    {
        "school": "Sierra Home",
        "district": "Mariposa County Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62394006039",
    },
    {
        "school": "Spring Hill High (Continuation)",
        "district": "Mariposa County Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62394008895",
    },
    {
        "school": "Lake Don Pedro Elementary",
        "district": "Mariposa County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62394008897",
    },
    {
        "school": "Coulterville High",
        "district": "Mariposa County Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62394009576",
    },
    {
        "school": "Yosemite Park High",
        "district": "Mariposa County Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62394009577",
    },
    {
        "school": "Spring Hill Opportunity",
        "district": "Mariposa County Office of Education",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69109000651",
    },
    {
        "school": "County Community",
        "district": "Mariposa County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69109003303",
    },
    {
        "school": "Monarch Academy",
        "district": "Mariposa County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69109008161",
    },
    {
        "school": "Surprise Valley Elementary",
        "district": "Surprise Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63852006469",
    },
    {
        "school": "Surprise Valley High",
        "district": "Surprise Valley Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63852006470",
    },
    {
        "school": "Modoc County Special Education",
        "district": "Modoc County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69109303758",
    },
    {
        "school": "Mammoth Middle",
        "district": "Mammoth Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62353003336",
    },
    {
        "school": "Mammoth Elementary",
        "district": "Mammoth Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62353003567",
    },
    {
        "school": "Mammoth High",
        "district": "Mammoth Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62353003568",
    },
    {
        "school": "Sierra High (Continuation)",
        "district": "Mammoth Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62353010259",
    },
    {
        "school": "Jan Work Community",
        "district": "Mono County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69105206046",
    },
    {
        "school": "Chester Elementary",
        "district": "Plumas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63117004818",
    },
    {
        "school": "Chester Junior/Senior High",
        "district": "Plumas Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63117004819",
    },
    {
        "school": "Greenville Elementary",
        "district": "Plumas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63117004820",
    },
    {
        "school": "Greenville Junior/Senior High",
        "district": "Plumas Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63117004821",
    },
    {
        "school": "Portola Junior/Senior High",
        "district": "Plumas Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63117004825",
    },
    {
        "school": "Quincy Elementary",
        "district": "Plumas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63117004826",
    },
    {
        "school": "Quincy Junior/Senior High",
        "district": "Plumas Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63117004827",
    },
    {
        "school": "Almanor High (Continuation)",
        "district": "Plumas Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63117007824",
    },
    {
        "school": "Beckwourth (Jim) High (Continuation)",
        "district": "Plumas Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63117007825",
    },
    {
        "school": "C. Roy Carmichael Elementary",
        "district": "Plumas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63117010272",
    },
    {
        "school": "Portola Opportunity",
        "district": "Plumas County Office of Education",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69110208554",
    },
    {
        "school": "Downieville Elementary",
        "district": "Sierra-Plumas Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63678006226",
    },
    {
        "school": "Downieville Junior-Senior High",
        "district": "Sierra-Plumas Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63678006227",
    },
    {
        "school": "Loyalton Elementary",
        "district": "Sierra-Plumas Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63678006228",
    },
    {
        "school": "Loyalton High",
        "district": "Sierra-Plumas Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63678006229",
    },
    {
        "school": "Sierra Pass (Continuation)",
        "district": "Sierra-Plumas Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63678007445",
    },
    {
        "school": "Sierra County Special Education",
        "district": "Sierra County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69112008098",
    },
    {
        "school": "Big Springs Elementary",
        "district": "Big Springs Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60498000481",
    },
    {
        "school": "Bogus Elementary",
        "district": "Bogus Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60549000500",
    },
    {
        "school": "Butte Valley High",
        "district": "Butte Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60658000590",
    },
    {
        "school": "Butte Valley Elementary",
        "district": "Butte Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60658000592",
    },
    {
        "school": "Cascade High",
        "district": "Butte Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60658002824",
    },
    {
        "school": "Picard Community Day Elementary",
        "district": "Butte Valley Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60658007454",
    },
    {
        "school": "Butteville Elementary",
        "district": "Butteville Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60669000593",
    },
    {
        "school": "Delphic Elementary",
        "district": "Delphic Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61098001214",
    },
    {
        "school": "Dunsmuir Elementary",
        "district": "Dunsmuir Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61167001292",
    },
    {
        "school": "Dunsmuir High",
        "district": "Dunsmuir Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61170001294",
    },
    {
        "school": "Dunsmuir Joint Union High Community Day",
        "district": "Dunsmuir Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61170007828",
    },
    {
        "school": "Forks of Salmon Elementary",
        "district": "Forks of Salmon Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61404001607",
    },
    {
        "school": "Gazelle Elementary",
        "district": "Gazelle Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61497001902",
    },
    {
        "school": "Grenada Elementary",
        "district": "Grenada Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61611002011",
    },
    {
        "school": "Happy Camp Elementary",
        "district": "Happy Camp Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61653002087",
    },
    {
        "school": "Hornbrook Elementary",
        "district": "Hornbrook Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61762002193",
    },
    {
        "school": "Junction Elementary",
        "district": "Junction Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61923002309",
    },
    {
        "school": "Klamath River Elementary",
        "district": "Klamath River Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61992002387",
    },
    {
        "school": "Little Shasta Elementary",
        "district": "Little Shasta Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62196002609",
    },
    {
        "school": "McCloud Elementary",
        "district": "McCloud Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62421003644",
    },
    {
        "school": "Montague Elementary",
        "district": "Montague Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62538003785",
    },
    {
        "school": "Mt. Shasta Elementary",
        "district": "Mt. Shasta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62604003898",
    },
    {
        "school": "Sisson",
        "district": "Mt. Shasta Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62604003899",
    },
    {
        "school": "Seiad Elementary",
        "district": "Seiad Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63624006181",
    },
    {
        "school": "Happy Camp High",
        "district": "Siskiyou Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63694006277",
    },
    {
        "school": "McCloud High",
        "district": "Siskiyou Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63694006278",
    },
    {
        "school": "Mt. Shasta High",
        "district": "Siskiyou Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63694006279",
    },
    {
        "school": "Weed High",
        "district": "Siskiyou Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63694006280",
    },
    {
        "school": "Tulelake Continuation High",
        "district": "Tulelake Basin Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63994003335",
    },
    {
        "school": "Tulelake High",
        "district": "Tulelake Basin Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63994006623",
    },
    {
        "school": "Tulelake Basin Elementary",
        "district": "Tulelake Basin Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63994006624",
    },
    {
        "school": "Weed Elementary",
        "district": "Weed Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64198006873",
    },
    {
        "school": "Willow Creek Elementary",
        "district": "Willow Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64260006973",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Yreka Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64338007024",
    },
    {
        "school": "Jackson Street Elementary",
        "district": "Yreka Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64338007026",
    },
    {
        "school": "Yreka Community Day",
        "district": "Yreka Union Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64338010427",
    },
    {
        "school": "Yreka High",
        "district": "Yreka Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64341007027",
    },
    {
        "school": "Yreka Union High Community Day",
        "district": "Yreka Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64341007452",
    },
    {
        "school": "Discovery High",
        "district": "Yreka Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64341007904",
    },
    {
        "school": "Siskiyou County Special Education",
        "district": "Siskiyou County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69103807221",
    },
    {
        "school": "J. Everett Barr Court",
        "district": "Siskiyou County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103809252",
    },
    {
        "school": "Mill Street Elementary",
        "district": "Orland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004507092",
    },
    {
        "school": "Valley High",
        "district": "Mountain Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60001809106",
    },
    {
        "school": "Hayfork High",
        "district": "Mountain Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001809107",
    },
    {
        "school": "Hayfork Elementary",
        "district": "Mountain Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001809108",
    },
    {
        "school": "Burnt Ranch Elementary",
        "district": "Burnt Ranch Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60651000587",
    },
    {
        "school": "Coffee Creek Elementary",
        "district": "Coffee Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60924000938",
    },
    {
        "school": "Douglas City Elementary",
        "district": "Douglas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61143001259",
    },
    {
        "school": "Junction City Elementary",
        "district": "Junction City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61917002307",
    },
    {
        "school": "Lewiston Elementary",
        "district": "Lewiston Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62148002569",
    },
    {
        "school": "Trinity Center Elementary",
        "district": "Trinity Center Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63975006603",
    },
    {
        "school": "Trinity County Special Education",
        "district": "Trinity County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104407233",
    },
    {
        "school": "Trinity County Juvenile Hall",
        "district": "Trinity County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104410444",
    },
    {
        "school": "Antelope Elementary",
        "district": "Eastern Sierra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61187001323",
    },
    {
        "school": "Bridgeport Elementary",
        "district": "Eastern Sierra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61187001324",
    },
    {
        "school": "Coleville High",
        "district": "Eastern Sierra Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61187001325",
    },
    {
        "school": "Edna Beaman Elementary",
        "district": "Eastern Sierra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61187001326",
    },
    {
        "school": "Lee Vining Elementary",
        "district": "Eastern Sierra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61187001327",
    },
    {
        "school": "Lee Vining High",
        "district": "Eastern Sierra Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61187001328",
    },
    {
        "school": "Alturas Elementary",
        "district": "Modoc Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62519003762",
    },
    {
        "school": "Modoc High",
        "district": "Modoc Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62519003764",
    },
    {
        "school": "Modoc Middle",
        "district": "Modoc Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62519003765",
    },
    {
        "school": "State Line Elementary",
        "district": "Modoc Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62519003767",
    },
    {
        "school": "Warner High",
        "district": "Modoc Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62519003768",
    },
    {
        "school": "High Desert Community Day",
        "district": "Modoc Joint Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62519008526",
    },
    {
        "school": "North Kern Vocational Training Center",
        "district": "North Kern Vocational Training Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60007410812",
    },
    {
        "school": "Kern County ROP",
        "district": "Kern County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60007510813",
    },
    {
        "school": "Kern High ROC",
        "district": "Kern High ROC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60007610814",
    },
    {
        "school": "San Lauren Elementary",
        "district": "Beardsley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60426010807",
    },
    {
        "school": "Berkshire Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639010503",
    },
    {
        "school": "Cesar E. Chavez High",
        "district": "Delano Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61086011206",
    },
    {
        "school": "Harvest Elementary",
        "district": "Delano Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089010808",
    },
    {
        "school": "Shirley Lane Elementary",
        "district": "Fairfax Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61329010809",
    },
    {
        "school": "Fairfax Jr. High",
        "district": "Fairfax Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61329011599",
    },
    {
        "school": "McKee Middle",
        "district": "Greenfield Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61605011210",
    },
    {
        "school": "Valle Verde Elementary",
        "district": "Greenfield Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61605011218",
    },
    {
        "school": "Golden Valley High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954011297",
    },
    {
        "school": "Sequoia Elementary",
        "district": "Richland Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62145010810",
    },
    {
        "school": "Patriot Elementary",
        "district": "Rosedale Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63348010507",
    },
    {
        "school": "Frazier Mountain High",
        "district": "El Tejon Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002604544",
    },
    {
        "school": "El Tejon Elementary",
        "district": "El Tejon Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002609485",
    },
    {
        "school": "Frazier Park Elementary",
        "district": "El Tejon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002609486",
    },
    {
        "school": "Haven Drive Middle",
        "district": "Arvin Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60327000245",
    },
    {
        "school": "Sierra Vista Elementary",
        "district": "Arvin Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60327000246",
    },
    {
        "school": "Bear Mountain Elementary",
        "district": "Arvin Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60327000413",
    },
    {
        "school": "Casa Loma Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000290",
    },
    {
        "school": "Chipman Junior High",
        "district": "Bakersfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000292",
    },
    {
        "school": "College Heights Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000293",
    },
    {
        "school": "Compton Junior High",
        "district": "Bakersfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000294",
    },
    {
        "school": "Curran Middle",
        "district": "Bakersfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000295",
    },
    {
        "school": "Henry Eissler Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000296",
    },
    {
        "school": "Emerson Middle",
        "district": "Bakersfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000297",
    },
    {
        "school": "Frank West Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000298",
    },
    {
        "school": "Franklin Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000299",
    },
    {
        "school": "Fremont Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000300",
    },
    {
        "school": "Harding Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000302",
    },
    {
        "school": "Caroline Harris Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000303",
    },
    {
        "school": "Horace Mann Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000304",
    },
    {
        "school": "Hort Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000305",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000306",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000307",
    },
    {
        "school": "McKinley Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000308",
    },
    {
        "school": "Mt. Vernon Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000309",
    },
    {
        "school": "Munsey Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000310",
    },
    {
        "school": "Colonel Howard Nichols Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000311",
    },
    {
        "school": "Myra A. Noble Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000312",
    },
    {
        "school": "Bessie E. Owens Primary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000313",
    },
    {
        "school": "Leo G. Pauly Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000314",
    },
    {
        "school": "Pioneer Drive Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000315",
    },
    {
        "school": "Rafer Johnson Childrens Center",
        "district": "Bakersfield City",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000316",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000317",
    },
    {
        "school": "Sierra Middle",
        "district": "Bakersfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000318",
    },
    {
        "school": "Voorhies Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000319",
    },
    {
        "school": "Washington Middle",
        "district": "Bakersfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000320",
    },
    {
        "school": "Wayside Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000321",
    },
    {
        "school": "William Penn Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000322",
    },
    {
        "school": "Williams Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363000323",
    },
    {
        "school": "Walter Stiern Middle",
        "district": "Bakersfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363002021",
    },
    {
        "school": "Cesar E. Chavez Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363003095",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363007098",
    },
    {
        "school": "Sequoia Middle",
        "district": "Bakersfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363007099",
    },
    {
        "school": "Downtown Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363007101",
    },
    {
        "school": "Bessie E. Owens Intermediate",
        "district": "Bakersfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363007992",
    },
    {
        "school": "Ramon Garza Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363009712",
    },
    {
        "school": "Stella I. Hills Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363009713",
    },
    {
        "school": "Dr. Juliet Thorner Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363009714",
    },
    {
        "school": "Beardsley Junior High",
        "district": "Beardsley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60426000385",
    },
    {
        "school": "Beardsley Elementary",
        "district": "Beardsley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60426008797",
    },
    {
        "school": "North Beardsley Elementary",
        "district": "Beardsley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60426008798",
    },
    {
        "school": "Belridge Elementary",
        "district": "Belridge Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60456000420",
    },
    {
        "school": "Blake Elementary",
        "district": "Blake Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60525000497",
    },
    {
        "school": "Buena Vista Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639000561",
    },
    {
        "school": "Earl Warren Junior High",
        "district": "Panama-Buena Vista Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639003104",
    },
    {
        "school": "Bill L. Williams Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639005790",
    },
    {
        "school": "Ronald Reagan Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639007503",
    },
    {
        "school": "Amy B. Seibert Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009327",
    },
    {
        "school": "Fred L. Thompson Junior High",
        "district": "Panama-Buena Vista Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009328",
    },
    {
        "school": "Panama Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009329",
    },
    {
        "school": "Stine Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009330",
    },
    {
        "school": "Wayne Van Horn Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009331",
    },
    {
        "school": "Charles H. Castle Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009332",
    },
    {
        "school": "Stockdale Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009333",
    },
    {
        "school": "O. J. Actis Junior High",
        "district": "Panama-Buena Vista Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009334",
    },
    {
        "school": "Louise Sandrini Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009335",
    },
    {
        "school": "Sing Lum Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009336",
    },
    {
        "school": "Laurelglen Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009337",
    },
    {
        "school": "Tevis Junior High",
        "district": "Panama-Buena Vista Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009338",
    },
    {
        "school": "Leo B. Hart Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009339",
    },
    {
        "school": "Roy W. Loudon Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639009520",
    },
    {
        "school": "Christa McAuliffe Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639010221",
    },
    {
        "school": "Buttonwillow Elementary",
        "district": "Buttonwillow Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60672000594",
    },
    {
        "school": "Piute Mountain Elementary",
        "district": "Caliente Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60696008121",
    },
    {
        "school": "Delano High",
        "district": "Delano Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61086001206",
    },
    {
        "school": "Valley High",
        "district": "Delano Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61086007693",
    },
    {
        "school": "Cecil Avenue Math and Science Academy",
        "district": "Delano Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089001208",
    },
    {
        "school": "Del Vista Math and Science Academy",
        "district": "Delano Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089001209",
    },
    {
        "school": "Fremont Elementary",
        "district": "Delano Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089001210",
    },
    {
        "school": "Terrace Elementary",
        "district": "Delano Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089001211",
    },
    {
        "school": "Princeton Street Elementary",
        "district": "Delano Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089002034",
    },
    {
        "school": "Albany Park Elementary",
        "district": "Delano Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089007275",
    },
    {
        "school": "Almond Tree Middle",
        "district": "Delano Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089007504",
    },
    {
        "school": "Morningside",
        "district": "Delano Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089008493",
    },
    {
        "school": "Di Giorgio Elementary",
        "district": "Di Giorgio Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61113001236",
    },
    {
        "school": "Orangewood Elementary",
        "district": "Edison Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61194001331",
    },
    {
        "school": "Edison Middle",
        "district": "Edison Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61194007697",
    },
    {
        "school": "Elk Hills Elementary",
        "district": "Elk Hills Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61236001415",
    },
    {
        "school": "Virginia Avenue Elementary",
        "district": "Fairfax Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61329001507",
    },
    {
        "school": "Columbia Elementary",
        "district": "Fruitvale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61470004514",
    },
    {
        "school": "Endeavour Elementary",
        "district": "Fruitvale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61470004526",
    },
    {
        "school": "Quailwood Elementary",
        "district": "Fruitvale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61470007722",
    },
    {
        "school": "Fruitvale Junior High",
        "district": "Fruitvale Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61470008142",
    },
    {
        "school": "Discovery Elementary",
        "district": "Fruitvale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61470010222",
    },
    {
        "school": "General Shafter Elementary",
        "district": "General Shafter Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61500001903",
    },
    {
        "school": "Fairview Elementary",
        "district": "Greenfield Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61605002004",
    },
    {
        "school": "Greenfield Middle",
        "district": "Greenfield Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61605002005",
    },
    {
        "school": "Plantation Elementary",
        "district": "Greenfield Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61605002007",
    },
    {
        "school": "Planz Elementary",
        "district": "Greenfield Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61605002008",
    },
    {
        "school": "Raffaello Palla Elementary",
        "district": "Greenfield Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61605002035",
    },
    {
        "school": "Leon H. Ollivier Middle",
        "district": "Greenfield Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61605003105",
    },
    {
        "school": "W. A. Kendrick Elementary",
        "district": "Greenfield Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61605009551",
    },
    {
        "school": "Centennial High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954002041",
    },
    {
        "school": "Arvin High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954002339",
    },
    {
        "school": "Bakersfield High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954002340",
    },
    {
        "school": "Central Valley High (Continuation)",
        "district": "Kern High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61954002342",
    },
    {
        "school": "East Bakersfield High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954002343",
    },
    {
        "school": "Foothill High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954002344",
    },
    {
        "school": "Highland High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954002345",
    },
    {
        "school": "Kern Valley High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954002347",
    },
    {
        "school": "North High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954002350",
    },
    {
        "school": "Nueva Continuation High",
        "district": "Kern High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61954002351",
    },
    {
        "school": "Shafter High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954002352",
    },
    {
        "school": "South High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954002353",
    },
    {
        "school": "Vista Continuation High",
        "district": "Kern High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61954002355",
    },
    {
        "school": "West High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954002356",
    },
    {
        "school": "Ridgeview High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954003116",
    },
    {
        "school": "Kern Workforce 2000 Academy",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954004529",
    },
    {
        "school": "Liberty High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954007994",
    },
    {
        "school": "Vista West Continuation High",
        "district": "Kern High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61954009145",
    },
    {
        "school": "Stockdale High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954010223",
    },
    {
        "school": "Kernville Elementary",
        "district": "Kernville Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61959002357",
    },
    {
        "school": "Woodrow W. Wallace Elementary",
        "district": "Kernville Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61959002358",
    },
    {
        "school": "Lakeside",
        "district": "Lakeside Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62073002489",
    },
    {
        "school": "Donald E. Suburu",
        "district": "Lakeside Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62073007505",
    },
    {
        "school": "Alicante Avenue Elementary",
        "district": "Lamont Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62085002501",
    },
    {
        "school": "Lamont Elementary",
        "district": "Lamont Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62085002502",
    },
    {
        "school": "Mountain View Middle",
        "district": "Lamont Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62085002503",
    },
    {
        "school": "Myrtle Avenue Elementary",
        "district": "Lamont Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62085002504",
    },
    {
        "school": "Redwood Elementary",
        "district": "Richland Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62145009564",
    },
    {
        "school": "Richland Junior High",
        "district": "Richland Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62145009565",
    },
    {
        "school": "Golden Oak Elementary",
        "district": "Richland Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62145009566",
    },
    {
        "school": "Linns Valley-Poso Flat Elementary",
        "district": "Linns Valley-Poso Flat Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62190002597",
    },
    {
        "school": "Lost Hills Elementary",
        "district": "Lost Hills Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62295003505",
    },
    {
        "school": "A. M. Thomas Middle",
        "district": "Lost Hills Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62295007772",
    },
    {
        "school": "Maple Elementary",
        "district": "Maple Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62376003594",
    },
    {
        "school": "Maricopa Elementary",
        "district": "Maricopa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62382003596",
    },
    {
        "school": "Maricopa High",
        "district": "Maricopa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62382003597",
    },
    {
        "school": "Browning Road STEAM Academy",
        "district": "McFarland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62423003645",
    },
    {
        "school": "Kern Avenue Elementary",
        "district": "McFarland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62423003646",
    },
    {
        "school": "McFarland High",
        "district": "McFarland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62423007315",
    },
    {
        "school": "McFarland Independent",
        "district": "McFarland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62423007779",
    },
    {
        "school": "San Joaquin High (Continuation)",
        "district": "McFarland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62423007780",
    },
    {
        "school": "McFarland Junior High",
        "district": "McFarland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62423008898",
    },
    {
        "school": "McKittrick Elementary",
        "district": "McKittrick Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62433003653",
    },
    {
        "school": "Midway Elementary",
        "district": "Midway Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62478003709",
    },
    {
        "school": "California City Middle",
        "district": "Mojave Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62523002042",
    },
    {
        "school": "Mojave Elementary",
        "district": "Mojave Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62523003769",
    },
    {
        "school": "Mojave Jr./Sr. High",
        "district": "Mojave Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62523003771",
    },
    {
        "school": "Robert P. Ulrich Elementary",
        "district": "Mojave Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62523003773",
    },
    {
        "school": "Boron Junior-Senior High",
        "district": "Muroc Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62649003994",
    },
    {
        "school": "Desert Junior-Senior High",
        "district": "Muroc Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62649003995",
    },
    {
        "school": "Irving L. Branch Elementary",
        "district": "Muroc Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62649003999",
    },
    {
        "school": "West Boron Elementary",
        "district": "Muroc Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62649004001",
    },
    {
        "school": "Norris Elementary",
        "district": "Norris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62745004136",
    },
    {
        "school": "William B. Bimat Elementary",
        "district": "Norris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62745008703",
    },
    {
        "school": "Norris Middle",
        "district": "Norris Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62745008920",
    },
    {
        "school": "Olive Drive Elementary",
        "district": "Norris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62745009595",
    },
    {
        "school": "Pond Elementary",
        "district": "Pond Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63135004865",
    },
    {
        "school": "Rio Bravo-Greeley Elementary",
        "district": "Rio Bravo-Greeley Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63271005085",
    },
    {
        "school": "Rio Bravo Elementary",
        "district": "Rio Bravo-Greeley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63271008496",
    },
    {
        "school": "Del Rio Elementary",
        "district": "Rosedale Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63348000415",
    },
    {
        "school": "Almondale Elementary",
        "district": "Rosedale Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63348003149",
    },
    {
        "school": "Rosedale Middle",
        "district": "Rosedale Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63348005174",
    },
    {
        "school": "Rosedale-North Elementary",
        "district": "Rosedale Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63348005175",
    },
    {
        "school": "Independence Elementary",
        "district": "Rosedale Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63348007102",
    },
    {
        "school": "Freedom Middle",
        "district": "Rosedale Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63348008495",
    },
    {
        "school": "Centennial Elementary",
        "district": "Rosedale Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63348010033",
    },
    {
        "school": "Semitropic Elementary",
        "district": "Semitropic Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63633006192",
    },
    {
        "school": "Gateway Elementary",
        "district": "Sierra Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680000434",
    },
    {
        "school": "Burroughs High",
        "district": "Sierra Sands Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680006232",
    },
    {
        "school": "Inyokern Elementary",
        "district": "Sierra Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680006234",
    },
    {
        "school": "James Monroe Middle",
        "district": "Sierra Sands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680006235",
    },
    {
        "school": "Las Flores Elementary",
        "district": "Sierra Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680006236",
    },
    {
        "school": "Mesquite Continuation High",
        "district": "Sierra Sands Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63680006237",
    },
    {
        "school": "Murray Middle",
        "district": "Sierra Sands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680006238",
    },
    {
        "school": "Pierce Elementary",
        "district": "Sierra Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680006239",
    },
    {
        "school": "Richmond Elementary",
        "district": "Sierra Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680006241",
    },
    {
        "school": "Faller Elementary",
        "district": "Sierra Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680006242",
    },
    {
        "school": "South Fork Elementary",
        "district": "South Fork Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63747006331",
    },
    {
        "school": "Abraham Lincoln Alternative",
        "district": "Southern Kern Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63762002045",
    },
    {
        "school": "Rare Earth High (Continuation)",
        "district": "Southern Kern Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63762006372",
    },
    {
        "school": "Rosamond Elementary",
        "district": "Southern Kern Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63762006373",
    },
    {
        "school": "Rosamond High Early College Campus",
        "district": "Southern Kern Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63762006374",
    },
    {
        "school": "Tropico Middle",
        "district": "Southern Kern Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63762006375",
    },
    {
        "school": "Highland Elementary",
        "district": "Standard Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63789006389",
    },
    {
        "school": "Standard Elementary",
        "district": "Standard Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63789006390",
    },
    {
        "school": "Standard Middle",
        "district": "Standard Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63789006391",
    },
    {
        "school": "Wingland Elementary",
        "district": "Standard Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63789006392",
    },
    {
        "school": "Conley Elementary",
        "district": "Taft City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63870006504",
    },
    {
        "school": "Lincoln Junior High",
        "district": "Taft City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63870006506",
    },
    {
        "school": "Parkview Elementary",
        "district": "Taft City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63870006507",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Taft City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63870006508",
    },
    {
        "school": "Taft Primary",
        "district": "Taft City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63870006509",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Taft City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63870008993",
    },
    {
        "school": "Buena Vista High (Continuation)",
        "district": "Taft Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63873006510",
    },
    {
        "school": "Taft Union High",
        "district": "Taft Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63873006511",
    },
    {
        "school": "Jacobsen Middle",
        "district": "Tehachapi Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63888006528",
    },
    {
        "school": "Tehachapi High",
        "district": "Tehachapi Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63888006529",
    },
    {
        "school": "Tompkins Elementary",
        "district": "Tehachapi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63888006530",
    },
    {
        "school": "Monroe High (Continuation)",
        "district": "Tehachapi Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63888007886",
    },
    {
        "school": "Golden Hills Elementary",
        "district": "Tehachapi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63888008994",
    },
    {
        "school": "Cummings Valley Elementary",
        "district": "Tehachapi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63888010110",
    },
    {
        "school": "Sunset",
        "district": "Vineland Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64113006783",
    },
    {
        "school": "Vineland Elementary",
        "district": "Vineland Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64113006784",
    },
    {
        "school": "John L. Prueitt Elementary",
        "district": "Wasco Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64140000417",
    },
    {
        "school": "Karl F. Clemens Elementary",
        "district": "Wasco Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64140006845",
    },
    {
        "school": "Palm Avenue Middle",
        "district": "Wasco Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64140006846",
    },
    {
        "school": "Thomas Jefferson Middle",
        "district": "Wasco Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64140006847",
    },
    {
        "school": "Wasco High",
        "district": "Wasco Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64143006849",
    },
    {
        "school": "Wasco Independence High",
        "district": "Wasco Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64143010225",
    },
    {
        "school": "Kern County Special Education",
        "district": "Kern County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69101207112",
    },
    {
        "school": "Kern County Community",
        "district": "Kern County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101207502",
    },
    {
        "school": "Valley Oaks Charter",
        "district": "Kern County Office of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69101208491",
    },
    {
        "school": "Kern County Juvenile Court",
        "district": "Kern County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101209226",
    },
    {
        "school": "Shoshone Elementary",
        "district": "Death Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61068010502",
    },
    {
        "school": "Big Pine Elementary",
        "district": "Big Pine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60495000479",
    },
    {
        "school": "Big Pine High",
        "district": "Big Pine Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60495000480",
    },
    {
        "school": "Tecopa-Francis Elementary",
        "district": "Death Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61068001187",
    },
    {
        "school": "Death Valley High Academy",
        "district": "Death Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61068007096",
    },
    {
        "school": "Shoshone High (Continuation)",
        "district": "Death Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61068007981",
    },
    {
        "school": "Lo-Inyo Elementary",
        "district": "Lone Pine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62244002692",
    },
    {
        "school": "Lone Pine High",
        "district": "Lone Pine Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62244002693",
    },
    {
        "school": "Owens Valley High",
        "district": "Owens Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62919004500",
    },
    {
        "school": "Owens Valley Elementary",
        "district": "Owens Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62919007097",
    },
    {
        "school": "Round Valley Elementary",
        "district": "Round Valley Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63369005193",
    },
    {
        "school": "Jill Kinmont Boothe",
        "district": "Inyo County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101100411",
    },
    {
        "school": "Butte County ROP",
        "district": "Butte County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60009010744",
    },
    {
        "school": "Loma Vista",
        "district": "Chico Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60837010469",
    },
    {
        "school": "Ishi Hills Middle",
        "district": "Oroville City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62910010742",
    },
    {
        "school": "Heritage Community Day",
        "district": "Thermalito Union Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63918010470",
    },
    {
        "school": "Plumas Avenue Elementary",
        "district": "Thermalito Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63918010743",
    },
    {
        "school": "Pioneer Community Day",
        "district": "Thermalito Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63918011181",
    },
    {
        "school": "McKinley Elementary",
        "district": "Gridley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005102012",
    },
    {
        "school": "Sycamore Middle",
        "district": "Gridley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005102013",
    },
    {
        "school": "Wilson Elementary",
        "district": "Gridley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005102014",
    },
    {
        "school": "Esperanza High (Continuation)",
        "district": "Gridley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60005102015",
    },
    {
        "school": "Gridley High",
        "district": "Gridley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005102016",
    },
    {
        "school": "Bangor Elementary",
        "district": "Bangor Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60378000346",
    },
    {
        "school": "Biggs Elementary",
        "district": "Biggs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60504000485",
    },
    {
        "school": "Biggs High",
        "district": "Biggs Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60504000486",
    },
    {
        "school": "Richvale Elementary",
        "district": "Biggs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60504000487",
    },
    {
        "school": "Bidwell Junior High",
        "district": "Chico Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000812",
    },
    {
        "school": "Chapman Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000813",
    },
    {
        "school": "Chico Junior High",
        "district": "Chico Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000814",
    },
    {
        "school": "Chico High",
        "district": "Chico Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000815",
    },
    {
        "school": "Citrus Avenue Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000816",
    },
    {
        "school": "Fair View High (Continuation)",
        "district": "Chico Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60837000818",
    },
    {
        "school": "Hooker Oak Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60837000820",
    },
    {
        "school": "Marigold Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000821",
    },
    {
        "school": "McManus (John A.) Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000822",
    },
    {
        "school": "Neal Dow Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000823",
    },
    {
        "school": "Parkview Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000825",
    },
    {
        "school": "Pleasant Valley High",
        "district": "Chico Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000827",
    },
    {
        "school": "Rosedale Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000828",
    },
    {
        "school": "Shasta Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837000829",
    },
    {
        "school": "Sierra View Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60837000830",
    },
    {
        "school": "Emma Wilson Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837001947",
    },
    {
        "school": "Marsh (Harry M.) Junior High",
        "district": "Chico Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837007945",
    },
    {
        "school": "Oakdale",
        "district": "Chico Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60837008450",
    },
    {
        "school": "Little Chico Creek Elementary",
        "district": "Chico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60837010191",
    },
    {
        "school": "Durham Elementary",
        "district": "Durham Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61173001295",
    },
    {
        "school": "Durham High",
        "district": "Durham Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61173001296",
    },
    {
        "school": "Durham Intermediate",
        "district": "Durham Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61173008824",
    },
    {
        "school": "Concow Elementary",
        "district": "Golden Feather Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61548001964",
    },
    {
        "school": "Manzanita Elementary",
        "district": "Manzanita Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62370003592",
    },
    {
        "school": "Central Middle",
        "district": "Oroville City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62910004489",
    },
    {
        "school": "Oakdale Heights Elementary",
        "district": "Oroville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62910004491",
    },
    {
        "school": "Ophir Elementary",
        "district": "Oroville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62910004492",
    },
    {
        "school": "Stanford Avenue Elementary",
        "district": "Oroville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62910004493",
    },
    {
        "school": "Wyandotte Academy",
        "district": "Oroville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62910004494",
    },
    {
        "school": "Las Plumas High",
        "district": "Oroville Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62913004495",
    },
    {
        "school": "Oroville High",
        "district": "Oroville Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62913004496",
    },
    {
        "school": "Prospect High (Continuation)",
        "district": "Oroville Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62913004497",
    },
    {
        "school": "Oroville High Community Day",
        "district": "Oroville Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62913007947",
    },
    {
        "school": "Helen M. Wilcox Elementary",
        "district": "Palermo Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62954004556",
    },
    {
        "school": "Honcut",
        "district": "Palermo Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62954004557",
    },
    {
        "school": "Palermo",
        "district": "Palermo Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62954004558",
    },
    {
        "school": "Palermo Union Community Day (K-8)",
        "district": "Palermo Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62954007490",
    },
    {
        "school": "Paradise Elementary",
        "district": "Paradise Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62982004638",
    },
    {
        "school": "Paradise Intermediate",
        "district": "Paradise Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62982004639",
    },
    {
        "school": "Paradise Senior High",
        "district": "Paradise Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62982004640",
    },
    {
        "school": "Ponderosa Elementary",
        "district": "Paradise Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62982004641",
    },
    {
        "school": "Ridgeview High (Continuation)",
        "district": "Paradise Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62982004642",
    },
    {
        "school": "Cedarwood Elementary",
        "district": "Paradise Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62982005712",
    },
    {
        "school": "Honey Run Academy Secondary",
        "district": "Paradise Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62982008451",
    },
    {
        "school": "Pine Ridge",
        "district": "Paradise Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62982008937",
    },
    {
        "school": "Berry Creek Elementary",
        "district": "Pioneer Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63052004742",
    },
    {
        "school": "Nelson Avenue Middle",
        "district": "Thermalito Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63918006544",
    },
    {
        "school": "Poplar Avenue Elementary",
        "district": "Thermalito Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63918006545",
    },
    {
        "school": "Sierra Avenue Elementary",
        "district": "Thermalito Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63918006546",
    },
    {
        "school": "Hearthstone School",
        "district": "Butte County Office of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69100205704",
    },
    {
        "school": "Table Mountain",
        "district": "Butte County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100209213",
    },
    {
        "school": "Butte County Special Education",
        "district": "Butte County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100209214",
    },
    {
        "school": "Lake County ROP",
        "district": "Lake County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60007810820",
    },
    {
        "school": "Kelseyville Community Day",
        "district": "Kelseyville Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61932010511",
    },
    {
        "school": "Blue Heron",
        "district": "Konocti Unified",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62007010818",
    },
    {
        "school": "Lloyd Hance Community",
        "district": "Lake County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101410510",
    },
    {
        "school": "Ed Donaldson Education Center",
        "district": "Kelseyville Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61932002323",
    },
    {
        "school": "Kelseyville Elementary",
        "district": "Kelseyville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61932002324",
    },
    {
        "school": "Kelseyville High",
        "district": "Kelseyville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61932002325",
    },
    {
        "school": "Riviera Elementary",
        "district": "Kelseyville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61932004574",
    },
    {
        "school": "Mountain Vista Middle",
        "district": "Kelseyville Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61932009382",
    },
    {
        "school": "Burns Valley",
        "district": "Konocti Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62007002398",
    },
    {
        "school": "Carle (William C.) High (Continuation)",
        "district": "Konocti Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62007002399",
    },
    {
        "school": "East Lake",
        "district": "Konocti Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62007002400",
    },
    {
        "school": "Lower Lake High",
        "district": "Konocti Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62007002401",
    },
    {
        "school": "Highlands Academy",
        "district": "Konocti Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62007002402",
    },
    {
        "school": "Lower Lake Elementary",
        "district": "Konocti Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62007002403",
    },
    {
        "school": "Richard H. Lewis Alternative",
        "district": "Konocti Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62007003176",
    },
    {
        "school": "Pomo",
        "district": "Konocti Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62007010228",
    },
    {
        "school": "Clear Lake High",
        "district": "Lakeport Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62067002484",
    },
    {
        "school": "Lakeport Elementary",
        "district": "Lakeport Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62067002485",
    },
    {
        "school": "Natural High (Continuation)",
        "district": "Lakeport Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62067002486",
    },
    {
        "school": "Terrace Middle",
        "district": "Lakeport Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62067002487",
    },
    {
        "school": "Lakeport Alternative (Home School)",
        "district": "Lakeport Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62067008712",
    },
    {
        "school": "Lucerne Elementary",
        "district": "Lucerne Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62304003514",
    },
    {
        "school": "Coyote Valley Elementary",
        "district": "Middletown Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62475000437",
    },
    {
        "school": "Minnie Cannon Elementary",
        "district": "Middletown Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62475003706",
    },
    {
        "school": "Loconoma Valley High",
        "district": "Middletown Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62475003707",
    },
    {
        "school": "Middletown High",
        "district": "Middletown Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62475003708",
    },
    {
        "school": "Cobb Mountain Elementary",
        "district": "Middletown Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62475008901",
    },
    {
        "school": "Middletown Middle",
        "district": "Middletown Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62475009155",
    },
    {
        "school": "Renaissance Court",
        "district": "Lake County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101407934",
    },
    {
        "school": "Del Norte County ROP",
        "district": "Del Norte County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60009310765",
    },
    {
        "school": "Elk Creek",
        "district": "Del Norte County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69106310762",
    },
    {
        "school": "Bess Maxwell Elementary",
        "district": "Del Norte County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61077001191",
    },
    {
        "school": "Crescent Elk Middle",
        "district": "Del Norte County Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61077001192",
    },
    {
        "school": "Del Norte High",
        "district": "Del Norte County Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61077001193",
    },
    {
        "school": "Joe Hamilton Elementary",
        "district": "Del Norte County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61077001194",
    },
    {
        "school": "Margaret Keating Elementary",
        "district": "Del Norte County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61077001195",
    },
    {
        "school": "Mountain Elementary",
        "district": "Del Norte County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61077001196",
    },
    {
        "school": "Pine Grove Elementary",
        "district": "Del Norte County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61077001197",
    },
    {
        "school": "Redwood Elementary",
        "district": "Del Norte County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61077001198",
    },
    {
        "school": "Smith River Elementary",
        "district": "Del Norte County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61077001199",
    },
    {
        "school": "Sunset High",
        "district": "Del Norte County Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61077001200",
    },
    {
        "school": "Mary Peacock Elementary",
        "district": "Del Norte County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61077005574",
    },
    {
        "school": "Del Norte Community",
        "district": "Del Norte County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69106308462",
    },
    {
        "school": "Castle Rock",
        "district": "Del Norte County Office of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69106308694",
    },
    {
        "school": "Imperial Valley ROP",
        "district": "Imperial Valley ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60010110803",
    },
    {
        "school": "Barbara Worth Junior High",
        "district": "Brawley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60579000520",
    },
    {
        "school": "Miguel Hidalgo Elementary",
        "district": "Brawley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60579000521",
    },
    {
        "school": "J. W. Oakley Elementary",
        "district": "Brawley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60579000522",
    },
    {
        "school": "Myron D. Witter Elementary",
        "district": "Brawley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60579008487",
    },
    {
        "school": "Phil D. Swing Elementary",
        "district": "Brawley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60579008488",
    },
    {
        "school": "Brawley Union High",
        "district": "Brawley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60582000524",
    },
    {
        "school": "Desert Valley High (Continuation)",
        "district": "Brawley Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60582000525",
    },
    {
        "school": "Renaissance",
        "district": "Brawley Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60582007095",
    },
    {
        "school": "Aurora High (Continuation)",
        "district": "Calexico Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60690000633",
    },
    {
        "school": "Calexico High",
        "district": "Calexico Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60690000634",
    },
    {
        "school": "Dool Elementary",
        "district": "Calexico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60690000636",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Calexico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60690000637",
    },
    {
        "school": "Kennedy Gardens Elementary",
        "district": "Calexico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60690000638",
    },
    {
        "school": "Mains Elementary",
        "district": "Calexico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60690000639",
    },
    {
        "school": "Rockwood Elementary",
        "district": "Calexico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60690000640",
    },
    {
        "school": "William Moreno Junior High",
        "district": "Calexico Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60690002010",
    },
    {
        "school": "Blanche Charles Elementary",
        "district": "Calexico Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60690009117",
    },
    {
        "school": "Calipatria High",
        "district": "Calipatria Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60699000643",
    },
    {
        "school": "Bill E. Young Jr. Middle",
        "district": "Calipatria Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60699000644",
    },
    {
        "school": "Grace Smith Elementary",
        "district": "Calipatria Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60699000645",
    },
    {
        "school": "Fremont Primary",
        "district": "Calipatria Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60699008804",
    },
    {
        "school": "Central Union High",
        "district": "Central Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60801000771",
    },
    {
        "school": "Desert Oasis High (Continuation)",
        "district": "Central Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60801000772",
    },
    {
        "school": "Southwest High",
        "district": "Central Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60801004486",
    },
    {
        "school": "De Anza Magnet",
        "district": "El Centro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203001332",
    },
    {
        "school": "Desert Garden Elementary",
        "district": "El Centro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203001333",
    },
    {
        "school": "Harding Elementary",
        "district": "El Centro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203001334",
    },
    {
        "school": "Margaret Hedrick Elementary",
        "district": "El Centro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203001335",
    },
    {
        "school": "Kennedy Middle",
        "district": "El Centro Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203001336",
    },
    {
        "school": "Lincoln Elementary",
        "district": "El Centro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203001337",
    },
    {
        "school": "McKinley Elementary",
        "district": "El Centro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203001338",
    },
    {
        "school": "Washington Elementary",
        "district": "El Centro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203001339",
    },
    {
        "school": "Wilson Jr. High",
        "district": "El Centro Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203001340",
    },
    {
        "school": "Sunflower Elementary",
        "district": "El Centro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203005787",
    },
    {
        "school": "Martin Luther King Jr. Elementary",
        "district": "El Centro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203009797",
    },
    {
        "school": "Heber Elementary",
        "district": "Heber Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61683002144",
    },
    {
        "school": "Emmett S. Finley Elementary",
        "district": "Holtville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61743002184",
    },
    {
        "school": "Holtville High",
        "district": "Holtville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61743002185",
    },
    {
        "school": "Holtville Junior High",
        "district": "Holtville Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61743002186",
    },
    {
        "school": "Pine Elementary",
        "district": "Holtville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61743002187",
    },
    {
        "school": "Sam Webb Continuation",
        "district": "Holtville Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61743002188",
    },
    {
        "school": "Ben Hulse Elementary",
        "district": "Imperial Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61821002240",
    },
    {
        "school": "Frank M. Wright Middle",
        "district": "Imperial Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61821002241",
    },
    {
        "school": "Imperial Ave. Holbrook High",
        "district": "Imperial Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61821002242",
    },
    {
        "school": "Imperial High",
        "district": "Imperial Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61821002243",
    },
    {
        "school": "T. L. Waggoner Elementary",
        "district": "Imperial Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61821008489",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Magnolia Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62346003566",
    },
    {
        "school": "McCabe Elementary",
        "district": "McCabe Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62418003643",
    },
    {
        "school": "Meadows Elementary",
        "district": "Meadows Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62439003655",
    },
    {
        "school": "Mulberry Elementary",
        "district": "Mulberry Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62643003992",
    },
    {
        "school": "Bill M. Manes High",
        "district": "San Pasqual Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63507005929",
    },
    {
        "school": "San Pasqual Valley Elementary",
        "district": "San Pasqual Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63507005930",
    },
    {
        "school": "San Pasqual Valley High",
        "district": "San Pasqual Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63507005931",
    },
    {
        "school": "San Pasqual Middle",
        "district": "San Pasqual Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63507008975",
    },
    {
        "school": "Seeley Elementary",
        "district": "Seeley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63621006180",
    },
    {
        "school": "Westmorland Elementary",
        "district": "Westmorland Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64218006919",
    },
    {
        "school": "Imperial County Special Education",
        "district": "Imperial County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69101007929",
    },
    {
        "school": "Imperial County Juvenile Hall/Community",
        "district": "Imperial County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101009224",
    },
    {
        "school": "Humboldt County ROP",
        "district": "Humboldt County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60010010802",
    },
    {
        "school": "Six Rivers Charter High",
        "district": "Northern Humboldt Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60303010800",
    },
    {
        "school": "Academy of the Redwoods",
        "district": "Fortuna Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61419010801",
    },
    {
        "school": "Eel River Community",
        "district": "Humboldt County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100910793",
    },
    {
        "school": "Eureka Community",
        "district": "Humboldt County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100910794",
    },
    {
        "school": "Southern Humboldt Community",
        "district": "Humboldt County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100910795",
    },
    {
        "school": "Humboldt County Office of Education Court",
        "district": "Humboldt County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100910797",
    },
    {
        "school": "Humboldt County Office of Education Juvenile Hall Court",
        "district": "Humboldt County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100910798",
    },
    {
        "school": "Ferndale Elementary",
        "district": "Ferndale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003701550",
    },
    {
        "school": "Ferndale High",
        "district": "Ferndale Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003701551",
    },
    {
        "school": "Mattole Triple Junction High",
        "district": "Mattole Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003801994",
    },
    {
        "school": "Mattole Elementary",
        "district": "Mattole Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003803640",
    },
    {
        "school": "Honeydew Elementary",
        "district": "Mattole Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003809400",
    },
    {
        "school": "Alice Birney Elementary",
        "district": "Eureka City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005201475",
    },
    {
        "school": "Catherine L. Zane Middle",
        "district": "Eureka City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005201476",
    },
    {
        "school": "Eureka Senior High",
        "district": "Eureka City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005201477",
    },
    {
        "school": "Grant Elementary",
        "district": "Eureka City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005201479",
    },
    {
        "school": "Lafayette Elementary",
        "district": "Eureka City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005201481",
    },
    {
        "school": "Washington Elementary",
        "district": "Eureka City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005201484",
    },
    {
        "school": "Zoe Barnum High",
        "district": "Eureka City Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60005201487",
    },
    {
        "school": "Sunny Brae Middle",
        "district": "Arcata Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60300000236",
    },
    {
        "school": "Arcata Elementary",
        "district": "Arcata Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60300000237",
    },
    {
        "school": "Arcata High",
        "district": "Northern Humboldt Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60303000238",
    },
    {
        "school": "McKinleyville High",
        "district": "Northern Humboldt Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60303000239",
    },
    {
        "school": "Pacific Coast High (Continuation)",
        "district": "Northern Humboldt Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60303007261",
    },
    {
        "school": "Mad River High (Continuation)",
        "district": "Northern Humboldt Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60303007262",
    },
    {
        "school": "Big Lagoon Elementary",
        "district": "Big Lagoon Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60489000477",
    },
    {
        "school": "Blue Lake Union Elementary",
        "district": "Blue Lake Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60540000499",
    },
    {
        "school": "Bridgeville Elementary",
        "district": "Bridgeville Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60600000539",
    },
    {
        "school": "Cuddeback Elementary",
        "district": "Cuddeback Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61023001113",
    },
    {
        "school": "Cutten Elementary",
        "district": "Cutten Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61038001163",
    },
    {
        "school": "Ridgewood Elementary",
        "district": "Cutten Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61038001164",
    },
    {
        "school": "Fieldbrook Elementary",
        "district": "Fieldbrook Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61374001553",
    },
    {
        "school": "East High (Continuation)",
        "district": "Fortuna Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61419001619",
    },
    {
        "school": "Fortuna Union High",
        "district": "Fortuna Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61419001620",
    },
    {
        "school": "Freshwater Elementary",
        "district": "Freshwater Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61452001702",
    },
    {
        "school": "Freshwater Charter Middle",
        "district": "Freshwater Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61452007974",
    },
    {
        "school": "Garfield Elementary",
        "district": "Garfield Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61491001890",
    },
    {
        "school": "Green Point Elementary",
        "district": "Green Point Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61599002003",
    },
    {
        "school": "Hydesville Elementary",
        "district": "Hydesville Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61812002237",
    },
    {
        "school": "Jacoby Creek",
        "district": "Jacoby Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61866002271",
    },
    {
        "school": "Captain John Continuation High",
        "district": "Klamath-Trinity Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61995002388",
    },
    {
        "school": "Hoopa Valley Elementary",
        "district": "Klamath-Trinity Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61995002389",
    },
    {
        "school": "Hoopa Valley High",
        "district": "Klamath-Trinity Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61995002390",
    },
    {
        "school": "Jack Norton Elementary",
        "district": "Klamath-Trinity Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61995002391",
    },
    {
        "school": "Orleans Elementary",
        "district": "Klamath-Trinity Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61995002392",
    },
    {
        "school": "Trinity Valley Elementary",
        "district": "Klamath-Trinity Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61995002393",
    },
    {
        "school": "Weitchpec Elementary",
        "district": "Klamath-Trinity Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61995002394",
    },
    {
        "school": "Kneeland Elementary",
        "district": "Kneeland Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61998002395",
    },
    {
        "school": "Loleta Elementary",
        "district": "Loleta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62232002671",
    },
    {
        "school": "Maple Creek Elementary",
        "district": "Maple Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62373003593",
    },
    {
        "school": "Dow's Prairie Elementary",
        "district": "McKinleyville Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62430003650",
    },
    {
        "school": "McKinleyville Middle",
        "district": "McKinleyville Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62430003651",
    },
    {
        "school": "Morris Elementary",
        "district": "McKinleyville Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62430003652",
    },
    {
        "school": "Orick Elementary",
        "district": "Orick Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62883004469",
    },
    {
        "school": "Pacific Union Elementary",
        "district": "Pacific Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62943004533",
    },
    {
        "school": "Peninsula Union",
        "district": "Peninsula Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63009004708",
    },
    {
        "school": "Eagle Prairie Elementary",
        "district": "Rio Dell Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63273005086",
    },
    {
        "school": "Monument Middle",
        "district": "Rio Dell Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63273005087",
    },
    {
        "school": "Stanwood A. Murphy Elementary",
        "district": "Scotia Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63610006171",
    },
    {
        "school": "Pine Hill Elementary",
        "district": "South Bay Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63735006313",
    },
    {
        "school": "South Bay Elementary",
        "district": "South Bay Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63735006314",
    },
    {
        "school": "Casterlin Elementary",
        "district": "Southern Humboldt Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63759006365",
    },
    {
        "school": "Osprey Learning Center",
        "district": "Southern Humboldt Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63759006366",
    },
    {
        "school": "Redway Elementary",
        "district": "Southern Humboldt Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63759006368",
    },
    {
        "school": "South Fork Junior - Senior High",
        "district": "Southern Humboldt Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63759006369",
    },
    {
        "school": "Whitethorn Elementary",
        "district": "Southern Humboldt Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63759006370",
    },
    {
        "school": "Osprey Learning Center (Alternative)",
        "district": "Southern Humboldt Joint Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63759007880",
    },
    {
        "school": "Hoaglin-Zenia Elementary",
        "district": "Southern Trinity Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63763006376",
    },
    {
        "school": "Southern Trinity High",
        "district": "Southern Trinity Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63763006377",
    },
    {
        "school": "Van Duzen Elementary",
        "district": "Southern Trinity Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63763006378",
    },
    {
        "school": "Mt. Lassic High (Continuation)",
        "district": "Southern Trinity Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63763010335",
    },
    {
        "school": "Trinidad Union",
        "district": "Trinidad Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63972006602",
    },
    {
        "school": "Glen Paul",
        "district": "Humboldt County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100909223",
    },
    {
        "school": "Valley ROP",
        "district": "Valley ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60009710787",
    },
    {
        "school": "Fresno ROP",
        "district": "Fresno ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60009810788",
    },
    {
        "school": "River Bluff Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797010493",
    },
    {
        "school": "Rio Vista Middle",
        "district": "Central Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797010494",
    },
    {
        "school": "James K. Polk Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797010786",
    },
    {
        "school": "Riverview Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903010483",
    },
    {
        "school": "Freedom Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903010484",
    },
    {
        "school": "James S. Fugman Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903010771",
    },
    {
        "school": "Woods (Harold L.) Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903010772",
    },
    {
        "school": "Clovis Community Day Elementary",
        "district": "Clovis Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60903011359",
    },
    {
        "school": "Clovis Community Day Secondary",
        "district": "Clovis Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60903011586",
    },
    {
        "school": "Fowler Academy Community Day (9-12)",
        "district": "Fowler Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61425010773",
    },
    {
        "school": "Hamilton Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455010488",
    },
    {
        "school": "Phoenix Elementary Academy Community Day",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61455010490",
    },
    {
        "school": "Molly S. Bakman Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455010777",
    },
    {
        "school": "Akira Yokomi Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455010778",
    },
    {
        "school": "Design Science Middle College High",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61455010779",
    },
    {
        "school": "Liberty Elementary",
        "district": "Kerman Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61949010495",
    },
    {
        "school": "A. L. Conner Elementary",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970010780",
    },
    {
        "school": "Thomas Law Reed Elementary",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970010781",
    },
    {
        "school": "Orange Cove High",
        "district": "Kings Canyon Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970010782",
    },
    {
        "school": "S Ben Benavidez Elementary",
        "district": "Parlier Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62991010783",
    },
    {
        "school": "Violet Heintz Education Academy",
        "district": "Fresno County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100710481",
    },
    {
        "school": "Mendota Continuation High",
        "district": "Mendota Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60002200374",
    },
    {
        "school": "Mendota High",
        "district": "Mendota Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002200395",
    },
    {
        "school": "Mendota Community Day",
        "district": "Mendota Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60002207970",
    },
    {
        "school": "McCabe Elementary",
        "district": "Mendota Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002209292",
    },
    {
        "school": "Mendota Junior High",
        "district": "Mendota Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002209293",
    },
    {
        "school": "Washington Elementary",
        "district": "Mendota Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002209294",
    },
    {
        "school": "Riverdale Elementary",
        "district": "Riverdale Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004005118",
    },
    {
        "school": "Fipps Primary",
        "district": "Riverdale Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004005119",
    },
    {
        "school": "Riverdale High",
        "district": "Riverdale Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004005120",
    },
    {
        "school": "Horizon High",
        "district": "Riverdale Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004007830",
    },
    {
        "school": "Caruthers Elementary",
        "district": "Caruthers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006700730",
    },
    {
        "school": "Caruthers High",
        "district": "Caruthers Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006700731",
    },
    {
        "school": "MARC High",
        "district": "Caruthers Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006700732",
    },
    {
        "school": "Alvina Elementary Charter",
        "district": "Alvina Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60237000127",
    },
    {
        "school": "Big Creek Elementary",
        "district": "Big Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60486000476",
    },
    {
        "school": "Burrel Elementary",
        "district": "Burrel Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60654000588",
    },
    {
        "school": "William Saroyan Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797003035",
    },
    {
        "school": "John Steinbeck Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797004485",
    },
    {
        "school": "Central High East Campus",
        "district": "Central Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797005777",
    },
    {
        "school": "Norman Liddell Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797007499",
    },
    {
        "school": "Biola-Pershing Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797007665",
    },
    {
        "school": "El Capitan Middle",
        "district": "Central Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797007667",
    },
    {
        "school": "Herndon-Barstow Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797007668",
    },
    {
        "school": "Houghton-Kearney Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797007669",
    },
    {
        "school": "Pershing Continuation High",
        "district": "Central Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60797007672",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797007673",
    },
    {
        "school": "Teague Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797007674",
    },
    {
        "school": "Madison Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797009123",
    },
    {
        "school": "Central Unified Alternative/Opportunity",
        "district": "Central Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60797009345",
    },
    {
        "school": "McKinley Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797009346",
    },
    {
        "school": "Clay Elementary",
        "district": "Clay Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60885000897",
    },
    {
        "school": "Buchanan High",
        "district": "Clovis Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000367",
    },
    {
        "school": "Clark Intermediate",
        "district": "Clovis Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000903",
    },
    {
        "school": "Clovis High",
        "district": "Clovis Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000904",
    },
    {
        "school": "Clovis West High",
        "district": "Clovis Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000906",
    },
    {
        "school": "Cole Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000907",
    },
    {
        "school": "Dry Creek Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000908",
    },
    {
        "school": "Fort Washington Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000909",
    },
    {
        "school": "Gateway High (Continuation)",
        "district": "Clovis Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60903000910",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000911",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000913",
    },
    {
        "school": "Miramonte Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000914",
    },
    {
        "school": "Nelson Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000915",
    },
    {
        "school": "Sierra Vista Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000916",
    },
    {
        "school": "Tarpey Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000917",
    },
    {
        "school": "Temperance-Kutner Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000918",
    },
    {
        "school": "Weldon Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903000919",
    },
    {
        "school": "Garfield Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903001982",
    },
    {
        "school": "Maple Creek Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903004482",
    },
    {
        "school": "Cedarwood Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903005744",
    },
    {
        "school": "Copper Hills Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903005747",
    },
    {
        "school": "Clovis East High",
        "district": "Clovis Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903007959",
    },
    {
        "school": "Clovis Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903007960",
    },
    {
        "school": "Reyburn Intermediate",
        "district": "Clovis Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903007961",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903008125",
    },
    {
        "school": "Century Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903008466",
    },
    {
        "school": "Kastner Intermediate",
        "district": "Clovis Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903008810",
    },
    {
        "school": "Mickey Cox Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903008811",
    },
    {
        "school": "Gettysburg Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903009127",
    },
    {
        "school": "Fancher Creek Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903009530",
    },
    {
        "school": "Valley Oak Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903009531",
    },
    {
        "school": "Enterprise Alternative",
        "district": "Clovis Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60903009760",
    },
    {
        "school": "Pinedale Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903009761",
    },
    {
        "school": "Red Bank Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903009762",
    },
    {
        "school": "Alta Sierra Intermediate",
        "district": "Clovis Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903010202",
    },
    {
        "school": "Liberty Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903010203",
    },
    {
        "school": "Sunset Elementary",
        "district": "Coalinga-Huron Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60912000931",
    },
    {
        "school": "Coalinga High",
        "district": "Coalinga-Huron Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60912000933",
    },
    {
        "school": "Huron Elementary",
        "district": "Coalinga-Huron Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60912000934",
    },
    {
        "school": "Cambridge High",
        "district": "Coalinga-Huron Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60912000935",
    },
    {
        "school": "Huron Middle",
        "district": "Coalinga-Huron Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60912005748",
    },
    {
        "school": "Coalinga Middle",
        "district": "Coalinga-Huron Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60912007686",
    },
    {
        "school": "Miles W. Culwell Community Day",
        "district": "Coalinga-Huron Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60912008696",
    },
    {
        "school": "Chesnut High (Continuation)",
        "district": "Coalinga-Huron Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60912010205",
    },
    {
        "school": "Henry F. Bishop Elementary",
        "district": "Coalinga-Huron Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60912010206",
    },
    {
        "school": "Annie E. Cheney Kindergarten",
        "district": "Coalinga-Huron Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60912010207",
    },
    {
        "school": "Nell Dawson Elementary",
        "district": "Coalinga-Huron Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60912010208",
    },
    {
        "school": "Arthur E. Mills Intermediate",
        "district": "Firebaugh-Las Deltas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61384001559",
    },
    {
        "school": "El Puente High",
        "district": "Firebaugh-Las Deltas Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61384001560",
    },
    {
        "school": "Firebaugh High",
        "district": "Firebaugh-Las Deltas Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61384001561",
    },
    {
        "school": "Firebaugh Middle",
        "district": "Firebaugh-Las Deltas Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61384001562",
    },
    {
        "school": "Hazel M. Bailey Primary",
        "district": "Firebaugh-Las Deltas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61384001563",
    },
    {
        "school": "Fowler Academy Continuation",
        "district": "Fowler Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61425001637",
    },
    {
        "school": "Fowler High",
        "district": "Fowler Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61425001638",
    },
    {
        "school": "Fremont Elementary",
        "district": "Fowler Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61425001639",
    },
    {
        "school": "Malaga Elementary",
        "district": "Fowler Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61425001640",
    },
    {
        "school": "Marshall Elementary",
        "district": "Fowler Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61425001641",
    },
    {
        "school": "John Sutter Middle",
        "district": "Fowler Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61425007496",
    },
    {
        "school": "Addams Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001703",
    },
    {
        "school": "Ahwahnee Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001704",
    },
    {
        "school": "Aynesworth Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001705",
    },
    {
        "school": "Baird Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001706",
    },
    {
        "school": "Birney Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001708",
    },
    {
        "school": "Bullard High",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001711",
    },
    {
        "school": "Burroughs Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001712",
    },
    {
        "school": "Calwa Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001713",
    },
    {
        "school": "Centennial Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001715",
    },
    {
        "school": "Columbia Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001716",
    },
    {
        "school": "Cooper Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001717",
    },
    {
        "school": "Del Mar Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001719",
    },
    {
        "school": "Dewolf Continuation High",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61455001720",
    },
    {
        "school": "Easterby Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001721",
    },
    {
        "school": "Eaton Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001722",
    },
    {
        "school": "Edison High",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001723",
    },
    {
        "school": "Ericson Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001724",
    },
    {
        "school": "Ewing Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001725",
    },
    {
        "school": "Fremont Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001728",
    },
    {
        "school": "Fresno High",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001730",
    },
    {
        "school": "Fort Miller Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001731",
    },
    {
        "school": "Gibson Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001732",
    },
    {
        "school": "Heaton Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001735",
    },
    {
        "school": "Herbert Hoover High",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001737",
    },
    {
        "school": "Holland Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001738",
    },
    {
        "school": "Homan Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001739",
    },
    {
        "school": "Jackson Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001741",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001742",
    },
    {
        "school": "King Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001743",
    },
    {
        "school": "Kings Canyon Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001744",
    },
    {
        "school": "Kirk Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001745",
    },
    {
        "school": "Kratt Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001746",
    },
    {
        "school": "Lane Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001747",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001748",
    },
    {
        "school": "Lowell Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001749",
    },
    {
        "school": "Malloch Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001750",
    },
    {
        "school": "Mayfair Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001751",
    },
    {
        "school": "McCardle Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001752",
    },
    {
        "school": "McLane High",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001754",
    },
    {
        "school": "Muir Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001755",
    },
    {
        "school": "Norseman Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001756",
    },
    {
        "school": "Powers-Ginsburg Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001758",
    },
    {
        "school": "Pyle Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001759",
    },
    {
        "school": "Robinson Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001760",
    },
    {
        "school": "Roeding Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001761",
    },
    {
        "school": "Roosevelt High",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001762",
    },
    {
        "school": "Rowell Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001763",
    },
    {
        "school": "Scandinavian Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001764",
    },
    {
        "school": "Sequoia Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001765",
    },
    {
        "school": "Slater Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001767",
    },
    {
        "school": "Starr Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001768",
    },
    {
        "school": "Sunset Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001769",
    },
    {
        "school": "Tehipite Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001770",
    },
    {
        "school": "Tenaya Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001771",
    },
    {
        "school": "Thomas Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001772",
    },
    {
        "school": "Tioga Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001773",
    },
    {
        "school": "Turner Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001774",
    },
    {
        "school": "Viking Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001775",
    },
    {
        "school": "Vinland Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001776",
    },
    {
        "school": "Webster Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001778",
    },
    {
        "school": "Wilson Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001779",
    },
    {
        "school": "Winchell Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001780",
    },
    {
        "school": "Wishon Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001781",
    },
    {
        "school": "Wolters Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001782",
    },
    {
        "school": "Yosemite Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455001783",
    },
    {
        "school": "Cambridge Continuation High",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61455001986",
    },
    {
        "school": "Susan B. Anthony Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455003007",
    },
    {
        "school": "Edith B. Storey Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455003010",
    },
    {
        "school": "Ann B. Leavenworth",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455003019",
    },
    {
        "school": "Fulton",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61455003024",
    },
    {
        "school": "Elizabeth Terronez Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455004484",
    },
    {
        "school": "J. E. Young Academic Center",
        "district": "Fresno Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61455005749",
    },
    {
        "school": "Ayer Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455007285",
    },
    {
        "school": "Forkner Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455007286",
    },
    {
        "school": "Lawless Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455007720",
    },
    {
        "school": "Sunnyside High",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455007963",
    },
    {
        "school": "Florence E. Rata",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61455007964",
    },
    {
        "school": "Irwin O. Addicott Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61455007966",
    },
    {
        "school": "Bullard Talent",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455008141",
    },
    {
        "school": "David L. Greenberg Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455008470",
    },
    {
        "school": "Erma Duncan Polytechnical High",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455008841",
    },
    {
        "school": "Figarden Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455008842",
    },
    {
        "school": "Manchester Gate",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455008843",
    },
    {
        "school": "Edison Computech",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455008844",
    },
    {
        "school": "Miguel Hidalgo Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455008845",
    },
    {
        "school": "Ezekiel Balderas Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455010209",
    },
    {
        "school": "Enterprise High",
        "district": "Kerman Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61949008865",
    },
    {
        "school": "Kerman High",
        "district": "Kerman Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61949008866",
    },
    {
        "school": "Kerman-Floyd Elementary",
        "district": "Kerman Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61949008867",
    },
    {
        "school": "Kerman Middle",
        "district": "Kerman Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61949008868",
    },
    {
        "school": "Sun Empire Elementary",
        "district": "Kerman Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61949008869",
    },
    {
        "school": "Alta Elementary",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002363",
    },
    {
        "school": "Citrus Middle",
        "district": "Kings Canyon Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002364",
    },
    {
        "school": "Dunlap Elementary",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002365",
    },
    {
        "school": "General Grant Middle",
        "district": "Kings Canyon Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002366",
    },
    {
        "school": "Great Western Elementary",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002367",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002368",
    },
    {
        "school": "Kings Canyon Continuation",
        "district": "Kings Canyon Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61970002369",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002370",
    },
    {
        "school": "McCord Elementary",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002371",
    },
    {
        "school": "Navelencia Middle",
        "district": "Kings Canyon Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002373",
    },
    {
        "school": "Reedley High",
        "district": "Kings Canyon Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002374",
    },
    {
        "school": "Riverview Elementary",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002375",
    },
    {
        "school": "Sheridan Elementary",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002376",
    },
    {
        "school": "Washington Elementary",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970002377",
    },
    {
        "school": "Mountain View (Alternative)",
        "district": "Kings Canyon Joint Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61970009385",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Kingsburg Elementary Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61980002380",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Kingsburg Elementary Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61980002381",
    },
    {
        "school": "Washington Elementary",
        "district": "Kingsburg Elementary Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61980002382",
    },
    {
        "school": "Central Valley Home",
        "district": "Kingsburg Elementary Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61980007085",
    },
    {
        "school": "Rafer Johnson Junior High",
        "district": "Kingsburg Elementary Charter",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61980009558",
    },
    {
        "school": "Kingsburg High",
        "district": "Kingsburg Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61983002383",
    },
    {
        "school": "Oasis Continuation High",
        "district": "Kingsburg Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61983002384",
    },
    {
        "school": "Laton Middle",
        "district": "Laton Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62115002534",
    },
    {
        "school": "Laton Elementary",
        "district": "Laton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62115002536",
    },
    {
        "school": "Laton High",
        "district": "Laton Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62115002537",
    },
    {
        "school": "Monroe Elementary",
        "district": "Monroe Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62529003774",
    },
    {
        "school": "Orange Center Elementary",
        "district": "Orange Center",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62853004417",
    },
    {
        "school": "Pacific Union Elementary",
        "district": "Pacific Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62940004532",
    },
    {
        "school": "Mathew J Brletic Elementary",
        "district": "Parlier Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62991004655",
    },
    {
        "school": "John C Martinez Elementary",
        "district": "Parlier Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62991004656",
    },
    {
        "school": "Parlier High",
        "district": "Parlier Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62991004657",
    },
    {
        "school": "Cesar E Chavez Elementary",
        "district": "Parlier Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62991004659",
    },
    {
        "school": "Parlier Junior High",
        "district": "Parlier Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62991007498",
    },
    {
        "school": "Pine Ridge Elementary",
        "district": "Pine Ridge Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63039004737",
    },
    {
        "school": "Raisin City Elementary",
        "district": "Raisin City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63168004904",
    },
    {
        "school": "Centerville Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005968",
    },
    {
        "school": "Del Rey Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005969",
    },
    {
        "school": "Fairmont Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005970",
    },
    {
        "school": "Jackson Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005971",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005972",
    },
    {
        "school": "John S. Wash Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005973",
    },
    {
        "school": "Kings River High (Continuation)",
        "district": "Sanger Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63525005974",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005975",
    },
    {
        "school": "Lone Star Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005976",
    },
    {
        "school": "Madison Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005977",
    },
    {
        "school": "Sanger High",
        "district": "Sanger Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005978",
    },
    {
        "school": "Washington Academic Middle",
        "district": "Sanger Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005979",
    },
    {
        "school": "Wilson Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525005980",
    },
    {
        "school": "Hallmark Charter",
        "district": "Sanger Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525007967",
    },
    {
        "school": "Community Day",
        "district": "Sanger Unified",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63525008473",
    },
    {
        "school": "Quail Lake Environmental Charter",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525008474",
    },
    {
        "school": "Sanger Academy Charter",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525008475",
    },
    {
        "school": "Taft High",
        "district": "Sanger Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63525010074",
    },
    {
        "school": "Abraham Lincoln Middle",
        "district": "Selma Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63627001989",
    },
    {
        "school": "Eric White Elementary",
        "district": "Selma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63627006182",
    },
    {
        "school": "James Garfield Elementary",
        "district": "Selma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63627006183",
    },
    {
        "school": "Heartland High (Continuation)",
        "district": "Selma Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63627006184",
    },
    {
        "school": "Indianola Elementary",
        "district": "Selma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63627006185",
    },
    {
        "school": "Andrew Jackson Elementary",
        "district": "Selma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63627006186",
    },
    {
        "school": "Theodore Roosevelt Elementary",
        "district": "Selma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63627006187",
    },
    {
        "school": "Selma High",
        "district": "Selma Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63627006188",
    },
    {
        "school": "Terry Elementary",
        "district": "Selma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63627006189",
    },
    {
        "school": "George Washington Elementary",
        "district": "Selma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63627006190",
    },
    {
        "school": "Woodrow Wilson Elementary",
        "district": "Selma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63627006191",
    },
    {
        "school": "Selma Independent",
        "district": "Selma Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63627008476",
    },
    {
        "school": "Sandy Bluffs Alternative Education Center",
        "district": "Sierra Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63680500399",
    },
    {
        "school": "Sierra High",
        "district": "Sierra Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680500401",
    },
    {
        "school": "Lodge Pole Elementary (Alternative)",
        "district": "Sierra Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63680503059",
    },
    {
        "school": "Oak Meadow Community Day",
        "district": "Sierra Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63680507971",
    },
    {
        "school": "Washington Colony Elementary",
        "district": "Washington Colony Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64146006850",
    },
    {
        "school": "West Park Charter Academy",
        "district": "West Park Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64206003032",
    },
    {
        "school": "West Park Elementary",
        "district": "West Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64206006888",
    },
    {
        "school": "Alice M. Worsley",
        "district": "Fresno County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100709219",
    },
    {
        "school": "Fresno County Special Education",
        "district": "Fresno County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100709220",
    },
    {
        "school": "Rio Del Rey High (Continuation)",
        "district": "Golden Plains Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69113410212",
    },
    {
        "school": "Tranquillity High",
        "district": "Golden Plains Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113410214",
    },
    {
        "school": "Cantua Elementary",
        "district": "Golden Plains Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113410215",
    },
    {
        "school": "Helm Elementary",
        "district": "Golden Plains Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113410216",
    },
    {
        "school": "San Joaquin Elementary",
        "district": "Golden Plains Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113410217",
    },
    {
        "school": "Tranquillity Elementary",
        "district": "Golden Plains Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113410218",
    },
    {
        "school": "Kings County ROP",
        "district": "Kings County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60007710817",
    },
    {
        "school": "Crossroads Charter",
        "district": "Armona Union Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60318011283",
    },
    {
        "school": "Kings Lake Education Center",
        "district": "Corcoran Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60969011284",
    },
    {
        "school": "Joseph M. Simas",
        "district": "Hanford Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61647010816",
    },
    {
        "school": "Lemoore University Elementary Charter",
        "district": "Lemoore Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62136011285",
    },
    {
        "school": "Armona Elementary",
        "district": "Armona Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60318000243",
    },
    {
        "school": "Parkview Middle",
        "district": "Armona Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60318000244",
    },
    {
        "school": "Akers Elementary",
        "district": "Central Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60798000765",
    },
    {
        "school": "Central Elementary",
        "district": "Central Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60798000766",
    },
    {
        "school": "R. J. Neutra",
        "district": "Central Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60798000767",
    },
    {
        "school": "Stratford Elementary",
        "district": "Central Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60798000768",
    },
    {
        "school": "Corcoran High",
        "district": "Corcoran Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60969001035",
    },
    {
        "school": "John C. Fremont Elementary",
        "district": "Corcoran Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60969001036",
    },
    {
        "school": "John Muir Middle",
        "district": "Corcoran Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60969001037",
    },
    {
        "school": "Mark Twain Elementary",
        "district": "Corcoran Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60969001039",
    },
    {
        "school": "Bret Harte Elementary",
        "district": "Corcoran Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60969008814",
    },
    {
        "school": "Jefferson Academy",
        "district": "Hanford Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61647002079",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Hanford Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61647002080",
    },
    {
        "school": "Monroe Elementary",
        "district": "Hanford Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61647002081",
    },
    {
        "school": "Lee Richmond Elementary",
        "district": "Hanford Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61647002082",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Hanford Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61647002083",
    },
    {
        "school": "Woodrow Wilson Junior High",
        "district": "Hanford Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61647002084",
    },
    {
        "school": "John F. Kennedy Junior High",
        "district": "Hanford Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61647003154",
    },
    {
        "school": "Martin Luther King Jr. Elementary",
        "district": "Hanford Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61647005804",
    },
    {
        "school": "Hanford Elementary Community Day",
        "district": "Hanford Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61647008707",
    },
    {
        "school": "George Washington Elementary",
        "district": "Hanford Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61647009844",
    },
    {
        "school": "Hanford High",
        "district": "Hanford Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61650002085",
    },
    {
        "school": "Earl F. Johnson High (Continuation)",
        "district": "Hanford Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61650002086",
    },
    {
        "school": "Hanford Community Day",
        "district": "Hanford Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61650007103",
    },
    {
        "school": "Hanford West High",
        "district": "Hanford Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61650007506",
    },
    {
        "school": "Island Elementary",
        "district": "Island Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61851002268",
    },
    {
        "school": "Kings River-Hardwick Elementary",
        "district": "Kings River-Hardwick Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61977002379",
    },
    {
        "school": "Kit Carson Elementary",
        "district": "Kit Carson Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61989002386",
    },
    {
        "school": "Mid Valley Alternative Charter",
        "district": "Kit Carson Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61989004566",
    },
    {
        "school": "Lakeside Elementary",
        "district": "Lakeside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62076002491",
    },
    {
        "school": "Lemoore Elementary",
        "district": "Lemoore Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62136002557",
    },
    {
        "school": "Meadow Lane Elementary",
        "district": "Lemoore Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62136002558",
    },
    {
        "school": "P. W. Engvall Elementary",
        "district": "Lemoore Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62136002559",
    },
    {
        "school": "Liberty Middle",
        "district": "Lemoore Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62136003169",
    },
    {
        "school": "Cinnamon Elementary",
        "district": "Lemoore Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62136008709",
    },
    {
        "school": "Lemoore High",
        "district": "Lemoore Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62140002561",
    },
    {
        "school": "Jamison (Donald C.) High (Continuation)",
        "district": "Lemoore Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62140002562",
    },
    {
        "school": "Pioneer Elementary",
        "district": "Pioneer Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63051004741",
    },
    {
        "school": "Pioneer Middle",
        "district": "Pioneer Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63051010226",
    },
    {
        "school": "Adelante High",
        "district": "Reef-Sunset Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63227002047",
    },
    {
        "school": "Avenal Elementary",
        "district": "Reef-Sunset Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63227007334",
    },
    {
        "school": "Avenal High",
        "district": "Reef-Sunset Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63227007335",
    },
    {
        "school": "Kettleman City Elementary",
        "district": "Reef-Sunset Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63227007336",
    },
    {
        "school": "Sunrise High (Continuation)",
        "district": "Reef-Sunset Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63227007337",
    },
    {
        "school": "Reef-Sunset Secondary Community Day",
        "district": "Reef-Sunset Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63227007999",
    },
    {
        "school": "Reef-Sunset Primary Community Day",
        "district": "Reef-Sunset Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63227008000",
    },
    {
        "school": "Tamarack Elementary",
        "district": "Reef-Sunset Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63227008710",
    },
    {
        "school": "Reef Sunset Middle",
        "district": "Reef-Sunset Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63227010227",
    },
    {
        "school": "J. C. Montgomery",
        "district": "Kings County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101309227",
    },
    {
        "school": "Kings County Special Education",
        "district": "Kings County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69101309228",
    },
    {
        "school": "Westside Elementary",
        "district": "Westside Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64221006920",
    },
    {
        "school": "La Puente Valley ROP",
        "district": "La Puente Valley ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60010310916",
    },
    {
        "school": "East San Gabriel Valley ROP",
        "district": "East San Gabriel Valley ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60010510918",
    },
    {
        "school": "Tri-Cities ROP",
        "district": "Tri-Cities ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60010610919",
    },
    {
        "school": "Southern California ROC",
        "district": "Southern California ROC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60010710920",
    },
    {
        "school": "Long Beach Unified School District ROP",
        "district": "Long Beach Unified ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60010810921",
    },
    {
        "school": "Los Angeles Unified School District ROCP",
        "district": "Los Angeles Unified ROCP",
        "level": "Adult Education",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60010910922",
    },
    {
        "school": "Los Angeles County ROP",
        "district": "Los Angeles County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60011010923",
    },
    {
        "school": "Hart ROP",
        "district": "Hart ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60011110924",
    },
    {
        "school": "Antelope Valley ROP",
        "district": "Antelope Valley ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60011210925",
    },
    {
        "school": "Compton Unified ROP",
        "district": "Compton Unified ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60011310926",
    },
    {
        "school": "San Antonio ROP",
        "district": "San Antonio ROP",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60011410927",
    },
    {
        "school": "Century High",
        "district": "Alhambra Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60015310928",
    },
    {
        "school": "Alhambra High",
        "district": "Alhambra Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310929",
    },
    {
        "school": "Mark Keppel High",
        "district": "Alhambra Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310930",
    },
    {
        "school": "San Gabriel High",
        "district": "Alhambra Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310931",
    },
    {
        "school": "Independence High (Alternative)",
        "district": "Alhambra Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60015310932",
    },
    {
        "school": "Brightwood Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310934",
    },
    {
        "school": "Emery Park Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310935",
    },
    {
        "school": "Fremont Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310936",
    },
    {
        "school": "Garfield Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310937",
    },
    {
        "school": "Granada Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310938",
    },
    {
        "school": "Marguerita Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310939",
    },
    {
        "school": "Martha Baldwin Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310940",
    },
    {
        "school": "Monterey Highlands Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310941",
    },
    {
        "school": "Park Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310942",
    },
    {
        "school": "Ramona Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310943",
    },
    {
        "school": "Repetto Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310944",
    },
    {
        "school": "William Northrup Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310945",
    },
    {
        "school": "Ynez Elementary",
        "district": "Alhambra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015310946",
    },
    {
        "school": "R. Rex Parris High",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60282010514",
    },
    {
        "school": "Eastside High",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60282010823",
    },
    {
        "school": "William J. (Pete) Knight High",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60282011346",
    },
    {
        "school": "Northlake Hills Elementary",
        "district": "Castaic Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60774011330",
    },
    {
        "school": "Clinton William Jefferson",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962011323",
    },
    {
        "school": "Valley Community Day",
        "district": "Hacienda la Puente Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61632511282",
    },
    {
        "school": "Grandview College Preparatory Academy",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632511364",
    },
    {
        "school": "Hawthorne Math and Science Academy",
        "district": "Hawthorne",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61668011295",
    },
    {
        "school": "Endeavour Middle",
        "district": "Lancaster Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088010826",
    },
    {
        "school": "Alice C. Stelle Middle",
        "district": "Las Virgenes Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100011298",
    },
    {
        "school": "Dolores Huerta Elementary",
        "district": "Lennox",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62142011299",
    },
    {
        "school": "Chavez Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250010828",
    },
    {
        "school": "Select Community Day (Secondary)",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62250011291",
    },
    {
        "school": "CDS Secondary",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271010519",
    },
    {
        "school": "Columbus Avenue",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010527",
    },
    {
        "school": "CDS Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271010528",
    },
    {
        "school": "MacArthur Park Elem Sch for the Visual and Perf Arts",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010529",
    },
    {
        "school": "Dr. Theodore T. Alexander Jr. Science Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010839",
    },
    {
        "school": "Richard A. Alonzo Community Day",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271010842",
    },
    {
        "school": "Middle College High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010843",
    },
    {
        "school": "Dr. Richard A. Vladovic Harbor Teacher Preparation Academy",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010844",
    },
    {
        "school": "Bellingham Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010854",
    },
    {
        "school": "Maple Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010855",
    },
    {
        "school": "Stanford Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010856",
    },
    {
        "school": "Charles White Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010857",
    },
    {
        "school": "Harmony Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010858",
    },
    {
        "school": "Vista Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010859",
    },
    {
        "school": "Southeast Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010860",
    },
    {
        "school": "Orthopaedic Hospital",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271010861",
    },
    {
        "school": "Northridge Academy High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010862",
    },
    {
        "school": "International Studies Lrng Center at Legacy High Sch Complex",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010863",
    },
    {
        "school": "Olympic Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010872",
    },
    {
        "school": "Garza (Carmen Lomas) Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010873",
    },
    {
        "school": "Danny J. Bakewell Sr. Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010874",
    },
    {
        "school": "Hooper Avenue Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010875",
    },
    {
        "school": "Mariposa-Nabi Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010876",
    },
    {
        "school": "Hollywood Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010877",
    },
    {
        "school": "Washington Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010878",
    },
    {
        "school": "Harvard Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010879",
    },
    {
        "school": "Pacific Boulevard",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010880",
    },
    {
        "school": "Ricardo Lizarraga Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010881",
    },
    {
        "school": "John W. Mack Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010882",
    },
    {
        "school": "Maywood Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010883",
    },
    {
        "school": "Panorama City Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010884",
    },
    {
        "school": "Kingsley Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010885",
    },
    {
        "school": "Hope Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010886",
    },
    {
        "school": "Cesar Chavez Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010887",
    },
    {
        "school": "South East High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010888",
    },
    {
        "school": "Maywood Academy High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010889",
    },
    {
        "school": "William J. Johnston Community Day",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271011307",
    },
    {
        "school": "Richard Riordan Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011310",
    },
    {
        "school": "Aggeler Community Day",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271011315",
    },
    {
        "school": "Lake Street Primary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011617",
    },
    {
        "school": "Martha Escutia Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011618",
    },
    {
        "school": "Lexington Avenue Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011619",
    },
    {
        "school": "Middleton Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011620",
    },
    {
        "school": "Amanecer Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011621",
    },
    {
        "school": "Aurora Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011622",
    },
    {
        "school": "Rosa Parks Learning Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011623",
    },
    {
        "school": "Maurice Sendak Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011624",
    },
    {
        "school": "Madison Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011625",
    },
    {
        "school": "Santee Education Complex",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271011626",
    },
    {
        "school": "Cal Burke High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271011627",
    },
    {
        "school": "Frida Kahlo High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271011629",
    },
    {
        "school": "Helen Keller Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316010900",
    },
    {
        "school": "Thurgood Marshall Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316010901",
    },
    {
        "school": "Cesar Chavez Middle",
        "district": "Lynwood Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316010902",
    },
    {
        "school": "Marco Antonio Firebaugh High",
        "district": "Lynwood Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316010903",
    },
    {
        "school": "Hosler Middle",
        "district": "Lynwood Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316011670",
    },
    {
        "school": "Oak Hills Elementary",
        "district": "Newhall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62718010904",
    },
    {
        "school": "Dr. J. Michael McGrath Elementary",
        "district": "Newhall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62718011317",
    },
    {
        "school": "Pico Canyon Elementary",
        "district": "Newhall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62718011329",
    },
    {
        "school": "Desert Willow Fine Arts Sci and Tech Magnet Acad",
        "district": "Palmdale Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958010905",
    },
    {
        "school": "Yellen Learning Center",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62958011305",
    },
    {
        "school": "Palos Verdes High",
        "district": "Palos Verdes Peninsula Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970010532",
    },
    {
        "school": "Leona Jackson",
        "district": "Paramount Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985010906",
    },
    {
        "school": "Howard Tanner",
        "district": "Paramount Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985010907",
    },
    {
        "school": "McKinley",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994010533",
    },
    {
        "school": "Pantera Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132010534",
    },
    {
        "school": "Cortez Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132011672",
    },
    {
        "school": "Bridgeport Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597010535",
    },
    {
        "school": "Tesoro del Valle Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597010910",
    },
    {
        "school": "Fair Oaks Ranch Community",
        "district": "Sulphur Springs Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63822010536",
    },
    {
        "school": "Gene Drevno Community Day",
        "district": "Torrance Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63942011674",
    },
    {
        "school": "Anaverde Hills",
        "district": "Westside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212010911",
    },
    {
        "school": "Esperanza Elementary",
        "district": "Westside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212011319",
    },
    {
        "school": "Golden Valley High",
        "district": "William S. Hart Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251010912",
    },
    {
        "school": "Rancho Pico Junior High",
        "district": "William S. Hart Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251010913",
    },
    {
        "school": "West Ranch High",
        "district": "William S. Hart Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251010914",
    },
    {
        "school": "Rio Norte Junior High",
        "district": "William S. Hart Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251011320",
    },
    {
        "school": "Wilsona Achievement Academy",
        "district": "Wilsona Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64281010537",
    },
    {
        "school": "North Orange County ROP",
        "district": "North Orange County ROP-Adult",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60012110996",
    },
    {
        "school": "College and Career Advantage",
        "district": "College and Career Advantage",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60012210997",
    },
    {
        "school": "Coastline ROP",
        "district": "Coastline ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60012310998",
    },
    {
        "school": "Central Orange County CTE Partnership (CTEp)",
        "district": "Central Orange County CTE Partnership (CTEp)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60012410999",
    },
    {
        "school": "Bridges Community Day",
        "district": "Capistrano Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60744010568",
    },
    {
        "school": "Laguna Niguel Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744010569",
    },
    {
        "school": "Oso Grande Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744010984",
    },
    {
        "school": "Ladera Ranch Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744011233",
    },
    {
        "school": "Ladera Ranch Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744011248",
    },
    {
        "school": "Vista del Mar Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744011266",
    },
    {
        "school": "Vista del Mar Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744011267",
    },
    {
        "school": "Canyon Vista Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744011268",
    },
    {
        "school": "Robert C. Fisler Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473010985",
    },
    {
        "school": "Garden Park Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488010570",
    },
    {
        "school": "Orange Unified Pre-K SDC",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865010986",
    },
    {
        "school": "Melrose Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066010987",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066010988",
    },
    {
        "school": "Segerstrom High",
        "district": "Santa Ana Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531010990",
    },
    {
        "school": "Manuel Esqueda Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531010991",
    },
    {
        "school": "Arnold O. Beckman High",
        "district": "Tustin Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015010994",
    },
    {
        "school": "Hicks Canyon Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015010995",
    },
    {
        "school": "Oak Creek Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450010572",
    },
    {
        "school": "ACCESS County Community",
        "district": "Orange County Department of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102410567",
    },
    {
        "school": "Vasquez High",
        "district": "Acton-Agua Dulce Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60000103278",
    },
    {
        "school": "Meadowlark Elementary",
        "district": "Acton-Agua Dulce Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60000107534",
    },
    {
        "school": "High Desert",
        "district": "Acton-Agua Dulce Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60000109444",
    },
    {
        "school": "Aurelia Pennekamp Elementary",
        "district": "Manhattan Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002503570",
    },
    {
        "school": "Grand View Elementary",
        "district": "Manhattan Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002503573",
    },
    {
        "school": "Meadows Avenue Elementary",
        "district": "Manhattan Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002503575",
    },
    {
        "school": "Pacific Elementary",
        "district": "Manhattan Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002503576",
    },
    {
        "school": "Opal Robinson Elementary",
        "district": "Manhattan Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002505922",
    },
    {
        "school": "Mira Costa High",
        "district": "Manhattan Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002506328",
    },
    {
        "school": "Manhattan Beach Middle",
        "district": "Manhattan Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002507535",
    },
    {
        "school": "Patricia Dreizler Continuation High",
        "district": "Redondo Beach Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60003202227",
    },
    {
        "school": "Adams Middle",
        "district": "Redondo Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003204949",
    },
    {
        "school": "Alta Vista Elementary",
        "district": "Redondo Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003204950",
    },
    {
        "school": "Beryl Heights Elementary",
        "district": "Redondo Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003204951",
    },
    {
        "school": "Birney Elementary",
        "district": "Redondo Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003204952",
    },
    {
        "school": "Parras (Nick G.) Middle",
        "district": "Redondo Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003204955",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Redondo Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003204956",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Redondo Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003204957",
    },
    {
        "school": "Madison Elementary",
        "district": "Redondo Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003204958",
    },
    {
        "school": "Tulita Elementary",
        "district": "Redondo Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003204960",
    },
    {
        "school": "Washington Elementary",
        "district": "Redondo Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003204961",
    },
    {
        "school": "Redondo Union High",
        "district": "Redondo Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003206330",
    },
    {
        "school": "Aloha Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000001",
    },
    {
        "school": "Artesia High",
        "district": "ABC Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000002",
    },
    {
        "school": "Bragg Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000004",
    },
    {
        "school": "Burbank (Luther) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000005",
    },
    {
        "school": "Carmenita Middle",
        "district": "ABC Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000007",
    },
    {
        "school": "Carver (Charles J.) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000008",
    },
    {
        "school": "Cerritos Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000009",
    },
    {
        "school": "Cerritos High",
        "district": "ABC Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000010",
    },
    {
        "school": "Elliott (William F) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000011",
    },
    {
        "school": "Ross (Faye) Middle",
        "district": "ABC Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000012",
    },
    {
        "school": "Furgeson (Venn W.) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000013",
    },
    {
        "school": "Gahr (Richard) High",
        "district": "ABC Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000014",
    },
    {
        "school": "Gonsalves (Joe A.) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000015",
    },
    {
        "school": "Haskell (Pliny Fisk) Middle",
        "district": "ABC Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000016",
    },
    {
        "school": "Hawaiian Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000017",
    },
    {
        "school": "Juarez (Benito) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000018",
    },
    {
        "school": "Kennedy (John F.) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000019",
    },
    {
        "school": "Fedde (Pharis F.) Middle",
        "district": "ABC Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000020",
    },
    {
        "school": "Leal (Frank C.) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000021",
    },
    {
        "school": "Melbourne (Ella P.) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000022",
    },
    {
        "school": "Niemes (John H.) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000023",
    },
    {
        "school": "Nixon (Patricia) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000024",
    },
    {
        "school": "Palms Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000025",
    },
    {
        "school": "Stowers(Cecil B.) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000026",
    },
    {
        "school": "Tetzlaff (Martin B.) Middle",
        "district": "ABC Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000027",
    },
    {
        "school": "Tracy (Wilbur) High (Continuation)",
        "district": "ABC Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60162000028",
    },
    {
        "school": "Whitney (Gretchen) High",
        "district": "ABC Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000029",
    },
    {
        "school": "Willow Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000030",
    },
    {
        "school": "Wittmann (Helen) Elementary",
        "district": "ABC Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162000031",
    },
    {
        "school": "ABC Secondary (Alternative)",
        "district": "ABC Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60162010232",
    },
    {
        "school": "Antelope Valley High",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60282000203",
    },
    {
        "school": "Desert Winds Continuation High",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60282000204",
    },
    {
        "school": "Palmdale High",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60282000205",
    },
    {
        "school": "Quartz Hill High",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60282000206",
    },
    {
        "school": "Lancaster High",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60282004582",
    },
    {
        "school": "Phoenix High Community Day",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60282005827",
    },
    {
        "school": "Highland High",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60282009515",
    },
    {
        "school": "Littlerock High",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60282009516",
    },
    {
        "school": "Arcadia High",
        "district": "Arcadia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60297000223",
    },
    {
        "school": "Baldwin Stocker Elementary",
        "district": "Arcadia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60297000224",
    },
    {
        "school": "Camino Grove Elementary",
        "district": "Arcadia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60297000226",
    },
    {
        "school": "Richard Henry Dana Middle",
        "district": "Arcadia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60297000227",
    },
    {
        "school": "First Avenue Middle",
        "district": "Arcadia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60297000228",
    },
    {
        "school": "Foothills Middle",
        "district": "Arcadia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60297000229",
    },
    {
        "school": "Highland Oaks Elementary",
        "district": "Arcadia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60297000230",
    },
    {
        "school": "Holly Avenue Elementary",
        "district": "Arcadia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60297000231",
    },
    {
        "school": "Hugo Reid Elementary",
        "district": "Arcadia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60297000232",
    },
    {
        "school": "Longley Way Elementary",
        "district": "Arcadia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60297000233",
    },
    {
        "school": "Rancho Learning Center (Alternative)",
        "district": "Arcadia Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60297009302",
    },
    {
        "school": "Azusa High",
        "district": "Azusa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000268",
    },
    {
        "school": "Center Middle",
        "district": "Azusa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000269",
    },
    {
        "school": "Henry Dalton Elementary",
        "district": "Azusa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000270",
    },
    {
        "school": "Alice M. Ellington Elementary",
        "district": "Azusa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000271",
    },
    {
        "school": "Foothill Middle",
        "district": "Azusa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000272",
    },
    {
        "school": "Gladstone High",
        "district": "Azusa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000273",
    },
    {
        "school": "Victor F. Hodge Elementary",
        "district": "Azusa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000275",
    },
    {
        "school": "Charles H. Lee Elementary",
        "district": "Azusa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000277",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Azusa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000278",
    },
    {
        "school": "Clifford D. Murray Elementary",
        "district": "Azusa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000280",
    },
    {
        "school": "Paramount Elementary",
        "district": "Azusa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000281",
    },
    {
        "school": "W. R. Powell Elementary",
        "district": "Azusa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000282",
    },
    {
        "school": "Sierra High",
        "district": "Azusa Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60360000283",
    },
    {
        "school": "Slauson Intermediate",
        "district": "Azusa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000284",
    },
    {
        "school": "Valleydale Elementary",
        "district": "Azusa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360000285",
    },
    {
        "school": "Baldwin Park High",
        "district": "Baldwin Park Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000324",
    },
    {
        "school": "Charles Bursch Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000325",
    },
    {
        "school": "Central Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000326",
    },
    {
        "school": "Charles D. Jones Junior High",
        "district": "Baldwin Park Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000327",
    },
    {
        "school": "De Anza Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000328",
    },
    {
        "school": "Elwin Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000329",
    },
    {
        "school": "Foster Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000330",
    },
    {
        "school": "Ernest R. Geddes Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000331",
    },
    {
        "school": "Kenmore Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000332",
    },
    {
        "school": "Jerry D. Holland Middle",
        "district": "Baldwin Park Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000333",
    },
    {
        "school": "Margaret Heath Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000334",
    },
    {
        "school": "North Park Continuation High",
        "district": "Baldwin Park Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60369000335",
    },
    {
        "school": "Olive Middle",
        "district": "Baldwin Park Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000336",
    },
    {
        "school": "Pleasant View Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000337",
    },
    {
        "school": "Sierra Vista High",
        "district": "Baldwin Park Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000338",
    },
    {
        "school": "Sierra Vista Junior High",
        "district": "Baldwin Park Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000339",
    },
    {
        "school": "Tracy Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000340",
    },
    {
        "school": "Vineland Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000341",
    },
    {
        "school": "Walnut Elementary",
        "district": "Baldwin Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369000342",
    },
    {
        "school": "Santa Fe Fundamental",
        "district": "Baldwin Park Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60369010233",
    },
    {
        "school": "Bassett Senior High",
        "district": "Bassett Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60411000371",
    },
    {
        "school": "Edgewood Academy",
        "district": "Bassett Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60411000372",
    },
    {
        "school": "Nueva Vista Continuation High",
        "district": "Bassett Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60411000375",
    },
    {
        "school": "Sunkist Elementary",
        "district": "Bassett Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60411000376",
    },
    {
        "school": "Torch Middle",
        "district": "Bassett Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60411000377",
    },
    {
        "school": "J. E. Van Wig Elementary",
        "district": "Bassett Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60411000378",
    },
    {
        "school": "Don Julian Elementary",
        "district": "Bassett Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60411007263",
    },
    {
        "school": "Bellflower High",
        "district": "Bellflower Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444000396",
    },
    {
        "school": "Stephen Foster Elementary",
        "district": "Bellflower Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444000397",
    },
    {
        "school": "Thomas Jefferson Elementary",
        "district": "Bellflower Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444000398",
    },
    {
        "school": "Esther Lindstrom Elementary",
        "district": "Bellflower Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444000400",
    },
    {
        "school": "Mayfair High",
        "district": "Bellflower Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444000402",
    },
    {
        "school": "Ernie Pyle Elementary",
        "district": "Bellflower Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444000403",
    },
    {
        "school": "Ramona Elementary",
        "district": "Bellflower Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444000404",
    },
    {
        "school": "Somerset Continuation High",
        "district": "Bellflower Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60444000408",
    },
    {
        "school": "Washington Elementary",
        "district": "Bellflower Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444000410",
    },
    {
        "school": "Bellflower Alternative Education Center",
        "district": "Bellflower Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60444005832",
    },
    {
        "school": "Albert Baxter Elementary",
        "district": "Bellflower Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444005836",
    },
    {
        "school": "Intensive Learning Center",
        "district": "Bellflower Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444007513",
    },
    {
        "school": "Frank E. Woodruff Elementary",
        "district": "Bellflower Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444008118",
    },
    {
        "school": "Craig Williams Elementary",
        "district": "Bellflower Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60444009115",
    },
    {
        "school": "Moreno High (Continuation)",
        "district": "Beverly Hills Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60483000470",
    },
    {
        "school": "Beverly Hills High",
        "district": "Beverly Hills Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60483000471",
    },
    {
        "school": "Beverly Vista Elementary",
        "district": "Beverly Hills Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60483000472",
    },
    {
        "school": "El Rodeo Elementary",
        "district": "Beverly Hills Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60483000473",
    },
    {
        "school": "Hawthorne Elementary",
        "district": "Beverly Hills Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60483000474",
    },
    {
        "school": "Horace Mann Elementary",
        "district": "Beverly Hills Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60483000475",
    },
    {
        "school": "Allen Avenue Elementary",
        "district": "Bonita Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561000503",
    },
    {
        "school": "Arma J. Shull Elementary",
        "district": "Bonita Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561000504",
    },
    {
        "school": "Bonita High",
        "district": "Bonita Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561000505",
    },
    {
        "school": "Chaparral High (Continuation)",
        "district": "Bonita Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60561000506",
    },
    {
        "school": "Fred Ekstrand Elementary",
        "district": "Bonita Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561000507",
    },
    {
        "school": "Gladstone Elementary",
        "district": "Bonita Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561000508",
    },
    {
        "school": "Grace Miller Elementary",
        "district": "Bonita Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561000509",
    },
    {
        "school": "J. Marion Roynon Elementary",
        "district": "Bonita Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561000510",
    },
    {
        "school": "La Verne Heights Elementary",
        "district": "Bonita Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561000511",
    },
    {
        "school": "Lone Hill Middle",
        "district": "Bonita Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561000512",
    },
    {
        "school": "Ramona Middle",
        "district": "Bonita Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561000513",
    },
    {
        "school": "San Dimas High",
        "district": "Bonita Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561000514",
    },
    {
        "school": "Vista (Alternative)",
        "district": "Bonita Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60561005840",
    },
    {
        "school": "Oak Mesa Elementary",
        "district": "Bonita Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60561010235",
    },
    {
        "school": "Burbank High",
        "district": "Burbank Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000563",
    },
    {
        "school": "Burroughs High",
        "district": "Burbank Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000564",
    },
    {
        "school": "Walt Disney Elementary",
        "district": "Burbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000565",
    },
    {
        "school": "Thomas Edison Elementary",
        "district": "Burbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000566",
    },
    {
        "school": "Ralph Emerson Elementary",
        "district": "Burbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000567",
    },
    {
        "school": "Bret Harte Elementary",
        "district": "Burbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000568",
    },
    {
        "school": "Thomas Jefferson Elementary",
        "district": "Burbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000569",
    },
    {
        "school": "David Starr Jordan Middle",
        "district": "Burbank Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000570",
    },
    {
        "school": "Luther Burbank Middle",
        "district": "Burbank Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000571",
    },
    {
        "school": "William McKinley Elementary",
        "district": "Burbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000573",
    },
    {
        "school": "Joaquin Miller Elementary",
        "district": "Burbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000574",
    },
    {
        "school": "John Muir Middle",
        "district": "Burbank Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000576",
    },
    {
        "school": "Providencia Elementary",
        "district": "Burbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000577",
    },
    {
        "school": "Theodore Roosevelt Elementary",
        "district": "Burbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000578",
    },
    {
        "school": "R. L. Stevenson Elementary",
        "district": "Burbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000579",
    },
    {
        "school": "George Washington Elementary",
        "district": "Burbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645000580",
    },
    {
        "school": "Magnolia Park",
        "district": "Burbank Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60645005849",
    },
    {
        "school": "Burbank USD Community Day",
        "district": "Burbank Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60645008013",
    },
    {
        "school": "Monterey High (Continuation)",
        "district": "Burbank Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60645008120",
    },
    {
        "school": "Castaic Elementary",
        "district": "Castaic Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60774000738",
    },
    {
        "school": "Castaic Middle",
        "district": "Castaic Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60774009121",
    },
    {
        "school": "Live Oak Elementary",
        "district": "Castaic Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60774009341",
    },
    {
        "school": "Hawthorne High",
        "district": "Centinela Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60792000756",
    },
    {
        "school": "Leuzinger High",
        "district": "Centinela Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60792000759",
    },
    {
        "school": "R. K. Lloyde High",
        "district": "Centinela Valley Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60792000760",
    },
    {
        "school": "Lawndale High",
        "district": "Centinela Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60792007515",
    },
    {
        "school": "Arrow High (Continuation)",
        "district": "Charter Oak Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60819000798",
    },
    {
        "school": "Badillo Elementary",
        "district": "Charter Oak Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60819000799",
    },
    {
        "school": "Cedargrove Elementary",
        "district": "Charter Oak Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60819000800",
    },
    {
        "school": "Charter Oak High",
        "district": "Charter Oak Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60819000801",
    },
    {
        "school": "Glen Oak Elementary",
        "district": "Charter Oak Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60819000802",
    },
    {
        "school": "Royal Oak Middle",
        "district": "Charter Oak Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60819000804",
    },
    {
        "school": "Washington Elementary",
        "district": "Charter Oak Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60819000806",
    },
    {
        "school": "Willow Elementary",
        "district": "Charter Oak Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60819000807",
    },
    {
        "school": "Oak Knoll Alternative",
        "district": "Charter Oak Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60819005854",
    },
    {
        "school": "Bridges Community Day",
        "district": "Charter Oak Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60819005856",
    },
    {
        "school": "Chaparral Elementary",
        "district": "Claremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60876000886",
    },
    {
        "school": "Claremont High",
        "district": "Claremont Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60876000887",
    },
    {
        "school": "Condit Elementary",
        "district": "Claremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60876000888",
    },
    {
        "school": "Danbury Special Education",
        "district": "Claremont Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60876000889",
    },
    {
        "school": "El Roble Intermediate",
        "district": "Claremont Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60876000890",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Claremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60876000891",
    },
    {
        "school": "Oakmont Elementary",
        "district": "Claremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60876000892",
    },
    {
        "school": "San Antonio High (Continuation)",
        "district": "Claremont Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60876000893",
    },
    {
        "school": "Sumner Elementary",
        "district": "Claremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60876000894",
    },
    {
        "school": "Sycamore Elementary",
        "district": "Claremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60876000895",
    },
    {
        "school": "Vista del Valle Elementary",
        "district": "Claremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60876000896",
    },
    {
        "school": "Community Day",
        "district": "Claremont Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60876008015",
    },
    {
        "school": "Anderson Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000969",
    },
    {
        "school": "Ralph Bunche Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000970",
    },
    {
        "school": "Bunche Middle",
        "district": "Compton Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000971",
    },
    {
        "school": "Bursch Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000972",
    },
    {
        "school": "Carver Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000974",
    },
    {
        "school": "Centennial High",
        "district": "Compton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000975",
    },
    {
        "school": "Compton High",
        "district": "Compton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000976",
    },
    {
        "school": "Dickison Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000977",
    },
    {
        "school": "Dominguez High",
        "district": "Compton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000978",
    },
    {
        "school": "Ronald E. McNair Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000979",
    },
    {
        "school": "Emerson Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000980",
    },
    {
        "school": "Foster Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000982",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000983",
    },
    {
        "school": "Kelly Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000984",
    },
    {
        "school": "Robert F. Kennedy Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000985",
    },
    {
        "school": "Martin Luther King Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000986",
    },
    {
        "school": "Laurel Street Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000987",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000989",
    },
    {
        "school": "Mayo Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000990",
    },
    {
        "school": "McKinley Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000991",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000993",
    },
    {
        "school": "Roosevelt Middle",
        "district": "Compton Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000994",
    },
    {
        "school": "Rosecrans Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000995",
    },
    {
        "school": "Tibby Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962000996",
    },
    {
        "school": "Walton Middle",
        "district": "Compton Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962001000",
    },
    {
        "school": "Washington Elementary",
        "district": "Compton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962001001",
    },
    {
        "school": "Whaley Middle",
        "district": "Compton Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962001002",
    },
    {
        "school": "Willowbrook Middle",
        "district": "Compton Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962001003",
    },
    {
        "school": "Cesar Chavez Continuation High",
        "district": "Compton Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60962002220",
    },
    {
        "school": "Enterprise Middle",
        "district": "Compton Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962004608",
    },
    {
        "school": "Compton Community Day High",
        "district": "Compton Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60962007148",
    },
    {
        "school": "Thurgood Marshall",
        "district": "Compton Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962007149",
    },
    {
        "school": "Compton Community Day Middle",
        "district": "Compton Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60962007158",
    },
    {
        "school": "Davis Middle",
        "district": "Compton Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962007272",
    },
    {
        "school": "Barranca Elementary",
        "district": "Covina-Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001087",
    },
    {
        "school": "Ben Lomond Elementary",
        "district": "Covina-Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001088",
    },
    {
        "school": "Fairvalley High (Continuation)",
        "district": "Covina-Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61005001090",
    },
    {
        "school": "Covina High",
        "district": "Covina-Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001093",
    },
    {
        "school": "Cypress Elementary",
        "district": "Covina-Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001094",
    },
    {
        "school": "Grovecenter Elementary",
        "district": "Covina-Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001096",
    },
    {
        "school": "Las Palmas Middle",
        "district": "Covina-Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001098",
    },
    {
        "school": "Manzanita Elementary",
        "district": "Covina-Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001099",
    },
    {
        "school": "Merwin Elementary",
        "district": "Covina-Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001100",
    },
    {
        "school": "Mesa Elementary",
        "district": "Covina-Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001101",
    },
    {
        "school": "Northview High",
        "district": "Covina-Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001102",
    },
    {
        "school": "Rowland Avenue Elementary",
        "district": "Covina-Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001103",
    },
    {
        "school": "Sierra Vista Middle",
        "district": "Covina-Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001104",
    },
    {
        "school": "South Hills High",
        "district": "Covina-Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001105",
    },
    {
        "school": "Traweek Middle",
        "district": "Covina-Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005001106",
    },
    {
        "school": "Workman Avenue Elementary",
        "district": "Covina-Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005007690",
    },
    {
        "school": "Culver City Middle",
        "district": "Culver City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61026001115",
    },
    {
        "school": "Culver City High",
        "district": "Culver City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61026001116",
    },
    {
        "school": "El Rincon Elementary",
        "district": "Culver City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61026001118",
    },
    {
        "school": "Farragut Elementary",
        "district": "Culver City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61026001119",
    },
    {
        "school": "Linwood E. Howe Elementary",
        "district": "Culver City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61026001120",
    },
    {
        "school": "La Ballona Elementary",
        "district": "Culver City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61026001121",
    },
    {
        "school": "El Marino Elementary",
        "district": "Culver City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61026003192",
    },
    {
        "school": "Culver Park High",
        "district": "Culver City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61026007691",
    },
    {
        "school": "Alameda Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001260",
    },
    {
        "school": "Carpenter (C. C.) Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001261",
    },
    {
        "school": "Columbus (Christopher) High",
        "district": "Downey Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61146001262",
    },
    {
        "school": "Downey High",
        "district": "Downey Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001264",
    },
    {
        "school": "Doty (Wendy Lopour) Middle",
        "district": "Downey Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001265",
    },
    {
        "school": "Gallatin Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001266",
    },
    {
        "school": "Gauldin (A.L.) Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001267",
    },
    {
        "school": "Griffiths (Gordon) Middle",
        "district": "Downey Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001268",
    },
    {
        "school": "Imperial Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001269",
    },
    {
        "school": "Price (Maude) Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001271",
    },
    {
        "school": "Rio Hondo Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001273",
    },
    {
        "school": "Rio San Gabriel Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001274",
    },
    {
        "school": "Sussman (Edward A.) Middle",
        "district": "Downey Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001275",
    },
    {
        "school": "Ward (E. W.) Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001277",
    },
    {
        "school": "Warren (Earl) High",
        "district": "Downey Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001278",
    },
    {
        "school": "Stauffer (Mary R.) Middle",
        "district": "Downey Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001279",
    },
    {
        "school": "Williams (Spencer V.) Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146001280",
    },
    {
        "school": "Unsworth (Edith) Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146003196",
    },
    {
        "school": "Old River Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146007107",
    },
    {
        "school": "Lewis (Ed C.) Elementary",
        "district": "Downey Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61146010237",
    },
    {
        "school": "Andres Duarte Arts Academy (PK-8)",
        "district": "Duarte Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61152001282",
    },
    {
        "school": "Beardslee Dual Language Immersion Academy (PK-8)",
        "district": "Duarte Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61152001283",
    },
    {
        "school": "Duarte High",
        "district": "Duarte Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61152001284",
    },
    {
        "school": "Maxwell Academy (PK-8)",
        "district": "Duarte Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61152001285",
    },
    {
        "school": "Mt. Olive Innovation and Technology High",
        "district": "Duarte Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61152001286",
    },
    {
        "school": "Royal Oaks STEAM Academy (K-8)",
        "district": "Duarte Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61152001288",
    },
    {
        "school": "Valley View Acad of Tech and Creative Lrng (TK-6)",
        "district": "Duarte Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61152001289",
    },
    {
        "school": "Ceres Elementary",
        "district": "East Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001311",
    },
    {
        "school": "East Whittier Middle",
        "district": "East Whittier City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001312",
    },
    {
        "school": "Evergreen Elementary",
        "district": "East Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001313",
    },
    {
        "school": "Granada Middle",
        "district": "East Whittier City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001314",
    },
    {
        "school": "Hillview Middle",
        "district": "East Whittier City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001315",
    },
    {
        "school": "La Colima Elementary",
        "district": "East Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001316",
    },
    {
        "school": "Laurel Elementary",
        "district": "East Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001317",
    },
    {
        "school": "Mulberry Elementary",
        "district": "East Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001318",
    },
    {
        "school": "Murphy Ranch Elementary",
        "district": "East Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001319",
    },
    {
        "school": "Ocean View Elementary",
        "district": "East Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001320",
    },
    {
        "school": "Orchard Dale Elementary",
        "district": "East Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001321",
    },
    {
        "school": "Scott Avenue Elementary",
        "district": "East Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185001322",
    },
    {
        "school": "Leffingwell Elementary",
        "district": "East Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61185007696",
    },
    {
        "school": "Eastside Elementary",
        "district": "Eastside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61191001329",
    },
    {
        "school": "Tierra Bonita Elementary",
        "district": "Eastside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61191007108",
    },
    {
        "school": "Columbia Elementary",
        "district": "Eastside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61191009131",
    },
    {
        "school": "Gifford C. Cole Middle",
        "district": "Eastside Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61191009533",
    },
    {
        "school": "Cherrylee Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001345",
    },
    {
        "school": "Cleminson Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001346",
    },
    {
        "school": "Columbia Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001347",
    },
    {
        "school": "Cortada Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001348",
    },
    {
        "school": "Durfee Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001349",
    },
    {
        "school": "Gidley Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001350",
    },
    {
        "school": "Legore Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001351",
    },
    {
        "school": "New Lexington Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001354",
    },
    {
        "school": "Potrero Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001356",
    },
    {
        "school": "Rio Hondo Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001357",
    },
    {
        "school": "Rio Vista Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001358",
    },
    {
        "school": "Shirpser Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001359",
    },
    {
        "school": "Thompson Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61209001360",
    },
    {
        "school": "Wilkerson Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001361",
    },
    {
        "school": "Wright Elementary",
        "district": "El Monte City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61209001362",
    },
    {
        "school": "South El Monte High",
        "district": "El Monte Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61212000439",
    },
    {
        "school": "Arroyo High",
        "district": "El Monte Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61212001363",
    },
    {
        "school": "El Monte High",
        "district": "El Monte Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61212001364",
    },
    {
        "school": "Mountain View High",
        "district": "El Monte Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61212001365",
    },
    {
        "school": "Rosemead High",
        "district": "El Monte Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61212001366",
    },
    {
        "school": "Fernando R. Ledesma Continuation High",
        "district": "El Monte Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61212001367",
    },
    {
        "school": "El Monte Union High School Community Day",
        "district": "El Monte Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61212007516",
    },
    {
        "school": "Birney Tech Academy",
        "district": "El Rancho Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001369",
    },
    {
        "school": "STEAM Academy @ Burke",
        "district": "El Rancho Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001370",
    },
    {
        "school": "Durfee Elementary",
        "district": "El Rancho Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001371",
    },
    {
        "school": "El Rancho High",
        "district": "El Rancho Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001372",
    },
    {
        "school": "Magee Academy of Arts & Sciences",
        "district": "El Rancho Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001373",
    },
    {
        "school": "North Park Academy of the Arts",
        "district": "El Rancho Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001376",
    },
    {
        "school": "North Ranchito Elementary",
        "district": "El Rancho Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001377",
    },
    {
        "school": "Rio Vista Elementary",
        "district": "El Rancho Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001380",
    },
    {
        "school": "Rivera Elementary",
        "district": "El Rancho Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001381",
    },
    {
        "school": "Rivera Middle",
        "district": "El Rancho Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001382",
    },
    {
        "school": "Ruben Salazar Continuation",
        "district": "El Rancho Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61218001383",
    },
    {
        "school": "South Ranchito Dual Language Academy",
        "district": "El Rancho Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001385",
    },
    {
        "school": "Valencia Academy of the Arts",
        "district": "El Rancho Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218001386",
    },
    {
        "school": "Center Street Elementary",
        "district": "El Segundo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61221001387",
    },
    {
        "school": "El Segundo High",
        "district": "El Segundo Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61221001388",
    },
    {
        "school": "El Segundo Middle",
        "district": "El Segundo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61221001389",
    },
    {
        "school": "Richmond Street Elementary",
        "district": "El Segundo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61221008501",
    },
    {
        "school": "Arena High (Continuation)",
        "district": "El Segundo Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61221008826",
    },
    {
        "school": "Dewey Avenue Elementary",
        "district": "Garvey Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61494001892",
    },
    {
        "school": "Rice (Eldridge) Elementary",
        "district": "Garvey Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61494001893",
    },
    {
        "school": "Sanchez (George I.) Elementary",
        "district": "Garvey Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61494001894",
    },
    {
        "school": "Willard (Frances E.) Elementary",
        "district": "Garvey Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61494001895",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Garvey Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61494001896",
    },
    {
        "school": "Monterey Vista Elementary",
        "district": "Garvey Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61494001899",
    },
    {
        "school": "Emerson (Ralph Waldo) Elementary",
        "district": "Garvey Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61494001900",
    },
    {
        "school": "Garvey (Richard) Intermediate",
        "district": "Garvey Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61494001901",
    },
    {
        "school": "Temple (Roger W.) Intermediate",
        "district": "Garvey Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61494007288",
    },
    {
        "school": "Bitely (Arlene) Elementary",
        "district": "Garvey Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61494008850",
    },
    {
        "school": "Verdugo Academy",
        "district": "Glendale Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61524000440",
    },
    {
        "school": "Balboa Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001919",
    },
    {
        "school": "Cerritos Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001920",
    },
    {
        "school": "Columbus Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001922",
    },
    {
        "school": "Crescenta Valley High",
        "district": "Glendale Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001923",
    },
    {
        "school": "Daily (Allan F.) High (Continuation)",
        "district": "Glendale Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61524001924",
    },
    {
        "school": "Dunsmore Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001925",
    },
    {
        "school": "Thomas Edison Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001926",
    },
    {
        "school": "Benjamin Franklin Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001928",
    },
    {
        "school": "John C. Fremont Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001929",
    },
    {
        "school": "College View",
        "district": "Glendale Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61524001930",
    },
    {
        "school": "Glendale High",
        "district": "Glendale Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001931",
    },
    {
        "school": "Glenoaks Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001932",
    },
    {
        "school": "Herbert Hoover High",
        "district": "Glendale Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001933",
    },
    {
        "school": "Thomas Jefferson Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001934",
    },
    {
        "school": "Mark Keppel Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001935",
    },
    {
        "school": "La Crescenta Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001936",
    },
    {
        "school": "Abraham Lincoln Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001937",
    },
    {
        "school": "Horace Mann Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001938",
    },
    {
        "school": "John Marshall Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001939",
    },
    {
        "school": "Monte Vista Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001940",
    },
    {
        "school": "Mountain Avenue Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001941",
    },
    {
        "school": "John Muir Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001942",
    },
    {
        "school": "Theodore Roosevelt Middle",
        "district": "Glendale Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001943",
    },
    {
        "school": "Rosemont Middle",
        "district": "Glendale Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001944",
    },
    {
        "school": "Eleanor J. Toll Middle",
        "district": "Glendale Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001946",
    },
    {
        "school": "Verdugo Woodlands Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001948",
    },
    {
        "school": "R. D. White Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001949",
    },
    {
        "school": "Woodrow Wilson Middle",
        "district": "Glendale Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524001950",
    },
    {
        "school": "Anderson W. Clark Magnet High",
        "district": "Glendale Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524007518",
    },
    {
        "school": "Valley View Elementary",
        "district": "Glendale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524007519",
    },
    {
        "school": "Jewel City Community Day",
        "district": "Glendale Unified",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61524008019",
    },
    {
        "school": "Cullen Elementary",
        "district": "Glendora Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61527001952",
    },
    {
        "school": "Glendora High",
        "district": "Glendora Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61527001953",
    },
    {
        "school": "Goddard Middle",
        "district": "Glendora Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61527001954",
    },
    {
        "school": "La Fetra Elementary",
        "district": "Glendora Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61527001955",
    },
    {
        "school": "Sandburg Middle",
        "district": "Glendora Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61527001956",
    },
    {
        "school": "Sellers Elementary",
        "district": "Glendora Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61527001957",
    },
    {
        "school": "Stanton Elementary",
        "district": "Glendora Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61527001958",
    },
    {
        "school": "Sutherland Elementary",
        "district": "Glendora Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61527001959",
    },
    {
        "school": "Whitcomb Continuation High",
        "district": "Glendora Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61527001960",
    },
    {
        "school": "Gorman Elementary",
        "district": "Gorman Joint",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61560001979",
    },
    {
        "school": "Baldwin Academy",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502036",
    },
    {
        "school": "Bixby Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502037",
    },
    {
        "school": "California Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502038",
    },
    {
        "school": "Del Valle Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502040",
    },
    {
        "school": "Grazide Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502046",
    },
    {
        "school": "Kwis Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502048",
    },
    {
        "school": "La Puente High",
        "district": "Hacienda la Puente Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502049",
    },
    {
        "school": "Lassalette",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502051",
    },
    {
        "school": "Los Altos Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502052",
    },
    {
        "school": "Los Altos High",
        "district": "Hacienda la Puente Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502053",
    },
    {
        "school": "Los Molinos Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502054",
    },
    {
        "school": "Los Robles Academy",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502055",
    },
    {
        "school": "Mesa Robles",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502056",
    },
    {
        "school": "Nelson Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502057",
    },
    {
        "school": "Newton Middle",
        "district": "Hacienda la Puente Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502058",
    },
    {
        "school": "Orange Grove Middle",
        "district": "Hacienda la Puente Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502059",
    },
    {
        "school": "Palm Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502060",
    },
    {
        "school": "Sierra Vista Middle",
        "district": "Hacienda la Puente Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502062",
    },
    {
        "school": "Sparks Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502063",
    },
    {
        "school": "Sparks Middle",
        "district": "Hacienda la Puente Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502064",
    },
    {
        "school": "Sunset Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502065",
    },
    {
        "school": "Sunset",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61632502066",
    },
    {
        "school": "Temple Academy",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502067",
    },
    {
        "school": "Valinda School of Academics",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502068",
    },
    {
        "school": "Valley Alternative High (Continuation)",
        "district": "Hacienda la Puente Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61632502069",
    },
    {
        "school": "Wedgeworth Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502070",
    },
    {
        "school": "Glen A. Wilson High",
        "district": "Hacienda la Puente Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502072",
    },
    {
        "school": "Wing Lane Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502073",
    },
    {
        "school": "William Workman High",
        "district": "Hacienda la Puente Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502074",
    },
    {
        "school": "Workman Elementary",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632502075",
    },
    {
        "school": "Fairgrove Academy",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632507159",
    },
    {
        "school": "Puente Hills High",
        "district": "Hacienda la Puente Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61632509143",
    },
    {
        "school": "Eucalyptus",
        "district": "Hawthorne",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61668002093",
    },
    {
        "school": "Hawthorne Middle",
        "district": "Hawthorne",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61668002094",
    },
    {
        "school": "Jefferson",
        "district": "Hawthorne",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61668002095",
    },
    {
        "school": "Ramona",
        "district": "Hawthorne",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61668002096",
    },
    {
        "school": "Washington",
        "district": "Hawthorne",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61668002097",
    },
    {
        "school": "York",
        "district": "Hawthorne",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61668002099",
    },
    {
        "school": "Bud Carson Middle",
        "district": "Hawthorne",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61668002100",
    },
    {
        "school": "Zela Davis",
        "district": "Hawthorne",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61668002101",
    },
    {
        "school": "Prairie Vista Middle",
        "district": "Hawthorne",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61668007520",
    },
    {
        "school": "Kornblum",
        "district": "Hawthorne",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61668008503",
    },
    {
        "school": "Hermosa View Elementary",
        "district": "Hermosa Beach City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61704002103",
    },
    {
        "school": "Hermosa Valley Elementary",
        "district": "Hermosa Beach City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61704002162",
    },
    {
        "school": "Hughes-Elizabeth Lakes",
        "district": "Hughes-Elizabeth Lakes Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61788007291",
    },
    {
        "school": "Bennett/Kew TK-6 Elementary",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002247",
    },
    {
        "school": "Centinela Elementary",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002248",
    },
    {
        "school": "Crozier (George W.) Middle",
        "district": "Inglewood Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002249",
    },
    {
        "school": "Highland Elementary",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002251",
    },
    {
        "school": "Hudnall (Claude) Elementary",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002253",
    },
    {
        "school": "Inglewood High",
        "district": "Inglewood Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002254",
    },
    {
        "school": "Kelso (William H.) Elementary",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002255",
    },
    {
        "school": "La Tijera K-8 Charter School Academy of Excellence",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002257",
    },
    {
        "school": "Warren Lane TK-7 Elementary",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002258",
    },
    {
        "school": "Morningside High",
        "district": "Inglewood Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002260",
    },
    {
        "school": "Oak Street Elementary",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002261",
    },
    {
        "school": "Frank D. Parent",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002262",
    },
    {
        "school": "Beulah Payne P-8 STEAM Academy",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002263",
    },
    {
        "school": "Woodworth-Monroe K-8 Academy",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002264",
    },
    {
        "school": "Worthington Elementary",
        "district": "Inglewood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839002265",
    },
    {
        "school": "Inglewood Continuation High",
        "district": "Inglewood Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61839003213",
    },
    {
        "school": "City Honors International Preparatory High",
        "district": "Inglewood Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61839008716",
    },
    {
        "school": "Keppel Academy",
        "district": "Keppel Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61944002331",
    },
    {
        "school": "Alpine Elementary",
        "district": "Keppel Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61944002332",
    },
    {
        "school": "Antelope Elementary",
        "district": "Keppel Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61944002333",
    },
    {
        "school": "Lake Los Angeles Elementary",
        "district": "Keppel Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61944008861",
    },
    {
        "school": "Pearblossom Elementary",
        "district": "Keppel Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61944009557",
    },
    {
        "school": "Daisy Gibson Elementary",
        "district": "Keppel Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61944010238",
    },
    {
        "school": "La Canada Elementary",
        "district": "La Canada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62013002407",
    },
    {
        "school": "La Canada High",
        "district": "La Canada Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62013002408",
    },
    {
        "school": "Paradise Canyon Elementary",
        "district": "La Canada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62013002409",
    },
    {
        "school": "Palm Crest Elementary",
        "district": "La Canada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62013009386",
    },
    {
        "school": "Desert View Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088002505",
    },
    {
        "school": "El Dorado Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088002506",
    },
    {
        "school": "Joshua Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088002507",
    },
    {
        "school": "Linda Verde Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088002508",
    },
    {
        "school": "Mariposa Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088002509",
    },
    {
        "school": "Monte Vista Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088002510",
    },
    {
        "school": "Piute Middle",
        "district": "Lancaster Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088002512",
    },
    {
        "school": "Sierra Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088002513",
    },
    {
        "school": "Sunnydale Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088002514",
    },
    {
        "school": "Lancaster Alternative and Virtual Academies",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62088005857",
    },
    {
        "school": "New Vista Middle",
        "district": "Lancaster Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088005860",
    },
    {
        "school": "The Leadership Academy",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62088008022",
    },
    {
        "school": "Amargosa Creek Middle",
        "district": "Lancaster Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088008717",
    },
    {
        "school": "Nancy Cory Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088009559",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088009560",
    },
    {
        "school": "Jack Northrop Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088009561",
    },
    {
        "school": "West Wind Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088009884",
    },
    {
        "school": "Bay Laurel Elementary",
        "district": "Las Virgenes Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100000442",
    },
    {
        "school": "Agoura High",
        "district": "Las Virgenes Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100002518",
    },
    {
        "school": "Calabasas High",
        "district": "Las Virgenes Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100002519",
    },
    {
        "school": "Chaparral Elementary",
        "district": "Las Virgenes Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100002520",
    },
    {
        "school": "Indian Hills Continuation High",
        "district": "Las Virgenes Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62100002521",
    },
    {
        "school": "Lindero Canyon Middle",
        "district": "Las Virgenes Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100002522",
    },
    {
        "school": "Lupin Hill Elementary",
        "district": "Las Virgenes Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100002523",
    },
    {
        "school": "Round Meadow Elementary",
        "district": "Las Virgenes Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100002524",
    },
    {
        "school": "Sumac Elementary",
        "district": "Las Virgenes Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100002525",
    },
    {
        "school": "White Oak Elementary",
        "district": "Las Virgenes Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100002526",
    },
    {
        "school": "Willow Elementary",
        "district": "Las Virgenes Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100002527",
    },
    {
        "school": "Arthur E. Wright Middle",
        "district": "Las Virgenes Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100002528",
    },
    {
        "school": "Yerba Buena Elementary",
        "district": "Las Virgenes Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100002529",
    },
    {
        "school": "Billy Mitchell Elementary",
        "district": "Lawndale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62121002540",
    },
    {
        "school": "F. D. Roosevelt Elementary",
        "district": "Lawndale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62121002541",
    },
    {
        "school": "Mark Twain Elementary",
        "district": "Lawndale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62121002543",
    },
    {
        "school": "Will Rogers Middle",
        "district": "Lawndale Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62121002544",
    },
    {
        "school": "William Anderson Elementary",
        "district": "Lawndale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62121002545",
    },
    {
        "school": "William Green Elementary",
        "district": "Lawndale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62121002546",
    },
    {
        "school": "Buford Elementary",
        "district": "Lennox",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62142002563",
    },
    {
        "school": "Felton Elementary",
        "district": "Lennox",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62142002564",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Lennox",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62142002565",
    },
    {
        "school": "Moffett Elementary",
        "district": "Lennox",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62142002566",
    },
    {
        "school": "Lennox Middle",
        "district": "Lennox",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62142009147",
    },
    {
        "school": "Cresson Elementary",
        "district": "Little Lake City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62193002598",
    },
    {
        "school": "Jersey Avenue Elementary",
        "district": "Little Lake City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62193002601",
    },
    {
        "school": "Lake Center Middle",
        "district": "Little Lake City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62193002602",
    },
    {
        "school": "Lakeland Elementary",
        "district": "Little Lake City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62193002603",
    },
    {
        "school": "Lakeside Middle",
        "district": "Little Lake City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62193002604",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Little Lake City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62193002605",
    },
    {
        "school": "William W. Orr Elementary",
        "district": "Little Lake City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62193002606",
    },
    {
        "school": "Paddison Elementary",
        "district": "Little Lake City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62193002607",
    },
    {
        "school": "Studebaker Elementary",
        "district": "Little Lake City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62193002608",
    },
    {
        "school": "Addams Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002695",
    },
    {
        "school": "Bancroft Middle",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002697",
    },
    {
        "school": "Barton Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002698",
    },
    {
        "school": "Birney Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002699",
    },
    {
        "school": "Bixby Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002700",
    },
    {
        "school": "Bryant Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002701",
    },
    {
        "school": "Burbank Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002702",
    },
    {
        "school": "Burcham Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002703",
    },
    {
        "school": "Bobbie Smith Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002704",
    },
    {
        "school": "Carver Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002706",
    },
    {
        "school": "Cleveland Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002707",
    },
    {
        "school": "Jessie Nelson Academy",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002708",
    },
    {
        "school": "Cubberley K-8",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002709",
    },
    {
        "school": "Edison Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002711",
    },
    {
        "school": "Emerson Parkside Academy",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002712",
    },
    {
        "school": "Franklin Classical Middle",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002713",
    },
    {
        "school": "Fremont Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002714",
    },
    {
        "school": "Gant Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002715",
    },
    {
        "school": "Garfield Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002716",
    },
    {
        "school": "Gompers K-8",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002717",
    },
    {
        "school": "Grant Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002718",
    },
    {
        "school": "Hamilton Middle",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002719",
    },
    {
        "school": "Harte Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002720",
    },
    {
        "school": "Henry",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002721",
    },
    {
        "school": "Holmes Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002723",
    },
    {
        "school": "Hoover Middle",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002724",
    },
    {
        "school": "Hudson K-8",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002725",
    },
    {
        "school": "Hughes Middle",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002726",
    },
    {
        "school": "Jefferson Leadership Academies",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002727",
    },
    {
        "school": "Jordan High",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002728",
    },
    {
        "school": "Kettering Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002730",
    },
    {
        "school": "King Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002731",
    },
    {
        "school": "Lafayette Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002732",
    },
    {
        "school": "Lakewood High",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002733",
    },
    {
        "school": "Olivia Nieto Herrera Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002734",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002735",
    },
    {
        "school": "Lindbergh STEM Academy",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002736",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002737",
    },
    {
        "school": "Los Cerritos Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002738",
    },
    {
        "school": "Lowell Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002739",
    },
    {
        "school": "MacArthur Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002740",
    },
    {
        "school": "Madison Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002741",
    },
    {
        "school": "Mann Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002742",
    },
    {
        "school": "Marshall Academy of the Arts",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002743",
    },
    {
        "school": "McKinley Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002744",
    },
    {
        "school": "Millikan High",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002745",
    },
    {
        "school": "Muir K-8",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002747",
    },
    {
        "school": "Naples Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002748",
    },
    {
        "school": "Newcomb Academy",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002749",
    },
    {
        "school": "Polytechnic High",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002751",
    },
    {
        "school": "Prisk Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002752",
    },
    {
        "school": "Reid High",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62250002753",
    },
    {
        "school": "Riley Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002754",
    },
    {
        "school": "Rogers Middle",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002755",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002756",
    },
    {
        "school": "Signal Hill Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002757",
    },
    {
        "school": "Stanford Middle",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002758",
    },
    {
        "school": "Stephens Middle",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002759",
    },
    {
        "school": "Stevenson Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002760",
    },
    {
        "school": "Tincher Preparatory",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002762",
    },
    {
        "school": "Twain Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002764",
    },
    {
        "school": "Washington Middle",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002765",
    },
    {
        "school": "Webster Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002766",
    },
    {
        "school": "Whittier Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002767",
    },
    {
        "school": "Willard Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002768",
    },
    {
        "school": "Wilson High",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250002769",
    },
    {
        "school": "Robinson Academy",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250003226",
    },
    {
        "school": "Cabrillo High",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250005870",
    },
    {
        "school": "Avalon K-12",
        "district": "Long Beach Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250007299",
    },
    {
        "school": "Powell Academy for Success",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250008025",
    },
    {
        "school": "Renaissance High School for the Arts",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250008720",
    },
    {
        "school": "Jenny Oropeza Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250009568",
    },
    {
        "school": "California Academy of Mathematics and Science",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250009901",
    },
    {
        "school": "Alvarado Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250009902",
    },
    {
        "school": "Educational Partnership High",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62250010239",
    },
    {
        "school": "Sara Coughlin Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271000444",
    },
    {
        "school": "Esperanza Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271000451",
    },
    {
        "school": "Walnut Park Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271000453",
    },
    {
        "school": "Frank Lanterman",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271002112",
    },
    {
        "school": "Youth Opportunities Unlimited",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002128",
    },
    {
        "school": "Los Angeles Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002143",
    },
    {
        "school": "John Adams Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002800",
    },
    {
        "school": "Jane Addams Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002801",
    },
    {
        "school": "William Tell Aggeler Opportunity High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002802",
    },
    {
        "school": "Albion Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002803",
    },
    {
        "school": "Aldama Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002804",
    },
    {
        "school": "Alexandria Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002805",
    },
    {
        "school": "John R. Wooden High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002806",
    },
    {
        "school": "Allesandro Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002807",
    },
    {
        "school": "Alta Loma Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002808",
    },
    {
        "school": "Ambler Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002809",
    },
    {
        "school": "Amestoy Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002811",
    },
    {
        "school": "Anatola Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002812",
    },
    {
        "school": "Andasol Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002814",
    },
    {
        "school": "Angel's Gate (Continuation)",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002815",
    },
    {
        "school": "Angeles Mesa Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002816",
    },
    {
        "school": "Ann Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002817",
    },
    {
        "school": "Annalee Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002818",
    },
    {
        "school": "Annandale Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002819",
    },
    {
        "school": "Apperson Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002820",
    },
    {
        "school": "Aragon Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002821",
    },
    {
        "school": "Westside Global Awareness Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002822",
    },
    {
        "school": "Mid-City's Prescott School of Enriched Sciences",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002823",
    },
    {
        "school": "Arlington Heights Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002825",
    },
    {
        "school": "Arminta Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002826",
    },
    {
        "school": "Ascot Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002827",
    },
    {
        "school": "Atwater Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002828",
    },
    {
        "school": "Audubon Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002829",
    },
    {
        "school": "Dan M. Issacs Avalon High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002830",
    },
    {
        "school": "Avalon Gardens Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002831",
    },
    {
        "school": "Balboa Gifted/High Ability Magnet Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002833",
    },
    {
        "school": "Baldwin Hills Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002834",
    },
    {
        "school": "Hubert Howe Bancroft Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002836",
    },
    {
        "school": "Bandini Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002837",
    },
    {
        "school": "Phineas Banning Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002838",
    },
    {
        "school": "Barton Hill Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002839",
    },
    {
        "school": "Bassett Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002840",
    },
    {
        "school": "Beachy Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002841",
    },
    {
        "school": "Beckford Charter for Enriched Studies",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002842",
    },
    {
        "school": "Beethoven Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002843",
    },
    {
        "school": "Bell Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002844",
    },
    {
        "school": "Belvedere Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002848",
    },
    {
        "school": "Belvedere Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002850",
    },
    {
        "school": "Berendo Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002853",
    },
    {
        "school": "Bertrand Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002855",
    },
    {
        "school": "Mary McLeod Bethune Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002856",
    },
    {
        "school": "Blythe Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002858",
    },
    {
        "school": "Bonita Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002859",
    },
    {
        "school": "Braddock Drive Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002860",
    },
    {
        "school": "Brainard Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002861",
    },
    {
        "school": "Breed Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002862",
    },
    {
        "school": "Brentwood Science",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002863",
    },
    {
        "school": "Bridge Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002864",
    },
    {
        "school": "Broad Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002865",
    },
    {
        "school": "Broadacres Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002866",
    },
    {
        "school": "Broadway Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002867",
    },
    {
        "school": "Brockton Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002868",
    },
    {
        "school": "Brooklyn Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002869",
    },
    {
        "school": "Bryson Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002870",
    },
    {
        "school": "Buchanan Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002871",
    },
    {
        "school": "Budlong Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002872",
    },
    {
        "school": "Luther Burbank Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002873",
    },
    {
        "school": "Burbank Boulevard Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002874",
    },
    {
        "school": "John Burroughs Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002875",
    },
    {
        "school": "Bushnell Way Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002877",
    },
    {
        "school": "Richard E. Byrd Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002878",
    },
    {
        "school": "Cabrillo Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002882",
    },
    {
        "school": "Cahuenga Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002883",
    },
    {
        "school": "Calabash Charter Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002884",
    },
    {
        "school": "Calahan Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002885",
    },
    {
        "school": "Calvert Charter for Enriched Studies",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002886",
    },
    {
        "school": "Camellia Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002887",
    },
    {
        "school": "Canfield Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002888",
    },
    {
        "school": "Canoga Park Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002889",
    },
    {
        "school": "Canoga Park Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002890",
    },
    {
        "school": "Cantara Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002891",
    },
    {
        "school": "Canterbury Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002892",
    },
    {
        "school": "Canyon Charter Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002894",
    },
    {
        "school": "Capistrano Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002895",
    },
    {
        "school": "Andrew Carnegie Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002896",
    },
    {
        "school": "Caroldale Learning Community",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002897",
    },
    {
        "school": "Carpenter Community Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002898",
    },
    {
        "school": "Carson Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002899",
    },
    {
        "school": "Carson Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002900",
    },
    {
        "school": "Carthay Elementary Of Environmental Studies Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002901",
    },
    {
        "school": "George Washington Carver Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002902",
    },
    {
        "school": "Castelar Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002903",
    },
    {
        "school": "Castle Heights Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002904",
    },
    {
        "school": "Castlebay Lane Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002905",
    },
    {
        "school": "Catskill Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002906",
    },
    {
        "school": "Central High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002908",
    },
    {
        "school": "Century Park Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002909",
    },
    {
        "school": "Chandler Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002910",
    },
    {
        "school": "Chapman Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002911",
    },
    {
        "school": "Charnock Road Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002913",
    },
    {
        "school": "Chase Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002914",
    },
    {
        "school": "Chatsworth Park ES Urban Planning/Comm Development Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002915",
    },
    {
        "school": "Chatsworth Charter High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002916",
    },
    {
        "school": "Cheremoya Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002917",
    },
    {
        "school": "Cheviot Hills Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002918",
    },
    {
        "school": "Cienega Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002919",
    },
    {
        "school": "Cimarron Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002920",
    },
    {
        "school": "City Terrace Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002921",
    },
    {
        "school": "Grover Cleveland Charter High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002923",
    },
    {
        "school": "Clifford Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002924",
    },
    {
        "school": "Clover Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002925",
    },
    {
        "school": "Coeur D'Alene Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002926",
    },
    {
        "school": "Cohasset Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002927",
    },
    {
        "school": "Coldwater Canyon Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002928",
    },
    {
        "school": "Colfax Charter Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002929",
    },
    {
        "school": "Coliseum Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002930",
    },
    {
        "school": "Christopher Columbus Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002933",
    },
    {
        "school": "Commonwealth Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002934",
    },
    {
        "school": "Community Magnet Charter Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002935",
    },
    {
        "school": "Compton Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002936",
    },
    {
        "school": "Corona Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002938",
    },
    {
        "school": "Betty Plasencia Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002939",
    },
    {
        "school": "Cowan Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002940",
    },
    {
        "school": "Crenshaw Sci Tech Engr Math and Med Magnet",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002941",
    },
    {
        "school": "Crescent Heights Boulevard Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002942",
    },
    {
        "school": "Crestwood Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002943",
    },
    {
        "school": "Glenn Hammond Curtiss Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002944",
    },
    {
        "school": "Christopher Dena Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002945",
    },
    {
        "school": "Dahlia Heights Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002946",
    },
    {
        "school": "Richard Henry Dana Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002947",
    },
    {
        "school": "Danube Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002948",
    },
    {
        "school": "Darby Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002949",
    },
    {
        "school": "Dayton Heights Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002950",
    },
    {
        "school": "Dearborn Elementary Charter Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002951",
    },
    {
        "school": "Del Amo Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002952",
    },
    {
        "school": "Delevan Drive Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002954",
    },
    {
        "school": "Denker Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002955",
    },
    {
        "school": "Dixie Canyon Community Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002959",
    },
    {
        "school": "Rudecinda Sepulveda Dodson Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002960",
    },
    {
        "school": "Dolores Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002962",
    },
    {
        "school": "Dominguez Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002963",
    },
    {
        "school": "Dorris Place Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002964",
    },
    {
        "school": "Susan Miller Dorsey Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002965",
    },
    {
        "school": "Charles Drew Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002966",
    },
    {
        "school": "Tom Bradley Global Awareness Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002967",
    },
    {
        "school": "Dyer Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002968",
    },
    {
        "school": "Eagle Rock Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002969",
    },
    {
        "school": "Eagle Rock High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002970",
    },
    {
        "school": "Eagle Tree Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002971",
    },
    {
        "school": "Amelia Earhart Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002972",
    },
    {
        "school": "Eastman Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002974",
    },
    {
        "school": "Thomas A. Edison Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002975",
    },
    {
        "school": "Albert Einstein Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002976",
    },
    {
        "school": "El Dorado Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002978",
    },
    {
        "school": "El Oro Way Charter For Enriched Studies",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002979",
    },
    {
        "school": "El Sereno Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002980",
    },
    {
        "school": "El Sereno Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002982",
    },
    {
        "school": "Elizabeth Learning Center",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002983",
    },
    {
        "school": "Ellington (Duke) High (Continuation)",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002984",
    },
    {
        "school": "Elysian Heights ES Arts Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002985",
    },
    {
        "school": "Emelita Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002986",
    },
    {
        "school": "Emerson Community Charter",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002987",
    },
    {
        "school": "Encino Charter Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002990",
    },
    {
        "school": "Erwin Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002991",
    },
    {
        "school": "Eshelman Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002992",
    },
    {
        "school": "Euclid Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002993",
    },
    {
        "school": "Evergreen Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002994",
    },
    {
        "school": "Evergreen Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271002995",
    },
    {
        "school": "Fair Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002996",
    },
    {
        "school": "Fairburn Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002997",
    },
    {
        "school": "Fairfax Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002998",
    },
    {
        "school": "Farmdale Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271002999",
    },
    {
        "school": "Fernangeles Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003001",
    },
    {
        "school": "Fifteenth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003002",
    },
    {
        "school": "Fifty-Fourth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003003",
    },
    {
        "school": "Fifty-Ninth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003004",
    },
    {
        "school": "Fifty-Second Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003005",
    },
    {
        "school": "Figueroa Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003006",
    },
    {
        "school": "Hillery T. Broadous Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003008",
    },
    {
        "school": "First Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003009",
    },
    {
        "school": "Alexander Fleming Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003011",
    },
    {
        "school": "Fletcher Drive Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003012",
    },
    {
        "school": "Florence Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003013",
    },
    {
        "school": "Ford Boulevard Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003014",
    },
    {
        "school": "Forty-Ninth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003015",
    },
    {
        "school": "Forty-Second Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003016",
    },
    {
        "school": "Foshay Learning Center",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003017",
    },
    {
        "school": "Fourth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003018",
    },
    {
        "school": "John H. Francis Polytechnic",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003020",
    },
    {
        "school": "Benjamin Franklin Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003021",
    },
    {
        "school": "Franklin Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003022",
    },
    {
        "school": "John C. Fremont Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003023",
    },
    {
        "school": "Fries Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003026",
    },
    {
        "school": "Robert Frost Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003027",
    },
    {
        "school": "Fullbright Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003028",
    },
    {
        "school": "Robert Fulton College Preparatory",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003029",
    },
    {
        "school": "Henry T. Gage Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003030",
    },
    {
        "school": "Gardena Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003033",
    },
    {
        "school": "Gardena Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003034",
    },
    {
        "school": "Gardner Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003036",
    },
    {
        "school": "James A. Garfield Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003037",
    },
    {
        "school": "Garvanza Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003038",
    },
    {
        "school": "Gates Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003039",
    },
    {
        "school": "Gault Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003040",
    },
    {
        "school": "Germain Academy For Academic Achievement",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003041",
    },
    {
        "school": "Glassell Park ES Sci Tech Engr Arts and Math Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003042",
    },
    {
        "school": "Gledhill Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003043",
    },
    {
        "school": "Glen Alta Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003044",
    },
    {
        "school": "Glenfeliz Boulevard Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003045",
    },
    {
        "school": "Glenwood Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003046",
    },
    {
        "school": "Samuel Gompers Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003047",
    },
    {
        "school": "Graham Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003048",
    },
    {
        "school": "Granada Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003049",
    },
    {
        "school": "Grand View Boulevard Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003051",
    },
    {
        "school": "Ulysses S. Grant Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003052",
    },
    {
        "school": "Grant Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003053",
    },
    {
        "school": "Grape Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003054",
    },
    {
        "school": "Zane Grey Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003055",
    },
    {
        "school": "Gridley Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003056",
    },
    {
        "school": "Griffin Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003057",
    },
    {
        "school": "Griffith Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003058",
    },
    {
        "school": "Gulf Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003060",
    },
    {
        "school": "Haddon Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003061",
    },
    {
        "school": "George Ellery Hale Charter Academy",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003062",
    },
    {
        "school": "Halldale Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003063",
    },
    {
        "school": "Alexander Hamilton Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003064",
    },
    {
        "school": "Hamlin Charter Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003065",
    },
    {
        "school": "William R. Anton Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003066",
    },
    {
        "school": "Hancock Park Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003067",
    },
    {
        "school": "Harbor City Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003068",
    },
    {
        "school": "Harding Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003069",
    },
    {
        "school": "Harold McAlister High (Opportunity)",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003070",
    },
    {
        "school": "Harrison Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003071",
    },
    {
        "school": "Hart Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003072",
    },
    {
        "school": "Bret Harte Preparatory Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003073",
    },
    {
        "school": "Haskell Elem Sci Tech Engr Arts And Math (STEAM) Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003074",
    },
    {
        "school": "Hawaiian Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003075",
    },
    {
        "school": "Hazeltine Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003077",
    },
    {
        "school": "Heliotrope Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003078",
    },
    {
        "school": "Patrick Henry Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003079",
    },
    {
        "school": "Herrick Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003080",
    },
    {
        "school": "Highland Park Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003082",
    },
    {
        "school": "Hillcrest Drive Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003084",
    },
    {
        "school": "Hillside Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003085",
    },
    {
        "school": "Hobart Boulevard Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003086",
    },
    {
        "school": "Hollenbeck Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003087",
    },
    {
        "school": "Hollywood Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003088",
    },
    {
        "school": "Oliver Wendell Holmes Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003089",
    },
    {
        "school": "Holmes Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003090",
    },
    {
        "school": "Hooper Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003091",
    },
    {
        "school": "Hoover Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003092",
    },
    {
        "school": "John Hope Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003093",
    },
    {
        "school": "Hubbard Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003094",
    },
    {
        "school": "Humphreys Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003096",
    },
    {
        "school": "Huntington Drive Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003097",
    },
    {
        "school": "Huntington Park Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003098",
    },
    {
        "school": "YES Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003099",
    },
    {
        "school": "Independence Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003100",
    },
    {
        "school": "Washington Irving Mid Sch Math Music and Engr Magnet",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003102",
    },
    {
        "school": "Ivanhoe Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003103",
    },
    {
        "school": "Thomas Jefferson Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003106",
    },
    {
        "school": "Joaquin Miller Career and Transition Center",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271003107",
    },
    {
        "school": "John F. Kennedy High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003108",
    },
    {
        "school": "David Starr Jordan Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003109",
    },
    {
        "school": "Joseph Pomeroy Widney Career Prep and Transition Center",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271003110",
    },
    {
        "school": "Justice Street Academy Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003111",
    },
    {
        "school": "Robert F. Kennedy Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003112",
    },
    {
        "school": "Kenter Canyon Elementary Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003113",
    },
    {
        "school": "Kentwood Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003114",
    },
    {
        "school": "Kester Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003115",
    },
    {
        "school": "Thomas Starr King Middle School Film and Media Magnet",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003117",
    },
    {
        "school": "Kittridge Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003118",
    },
    {
        "school": "Knollwood Preparatory Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003119",
    },
    {
        "school": "La Salle Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003120",
    },
    {
        "school": "Lanai Road Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003121",
    },
    {
        "school": "Robert Hill Lane Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003122",
    },
    {
        "school": "Langdon Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003123",
    },
    {
        "school": "Lankershim Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003124",
    },
    {
        "school": "Lassen Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003125",
    },
    {
        "school": "Latona Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003126",
    },
    {
        "school": "Laurel Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003127",
    },
    {
        "school": "Ernest Lawrence Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003128",
    },
    {
        "school": "Joseph Le Conte Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003129",
    },
    {
        "school": "Leapwood Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003130",
    },
    {
        "school": "Leland Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003131",
    },
    {
        "school": "Lemay Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003132",
    },
    {
        "school": "Robert H. Lewis Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003134",
    },
    {
        "school": "Liberty Boulevard Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003135",
    },
    {
        "school": "Liggett Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003136",
    },
    {
        "school": "Lillian Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003137",
    },
    {
        "school": "Limerick Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003138",
    },
    {
        "school": "Abraham Lincoln Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003139",
    },
    {
        "school": "Lockhurst Drive Charter Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003141",
    },
    {
        "school": "Lockwood Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003142",
    },
    {
        "school": "Logan Academy of Global Ecology",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003143",
    },
    {
        "school": "Loma Vista Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003144",
    },
    {
        "school": "Lomita Math/Science/Technology Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003145",
    },
    {
        "school": "Jack London Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003146",
    },
    {
        "school": "Lorena Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003147",
    },
    {
        "school": "Loreto Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003148",
    },
    {
        "school": "Lorne Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003150",
    },
    {
        "school": "Los Angeles Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003151",
    },
    {
        "school": "Los Feliz Science/Tech/Engineer/Math/Medicine Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003152",
    },
    {
        "school": "Loyola Village Fine And Performing Arts Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003153",
    },
    {
        "school": "Charles Maclay Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003155",
    },
    {
        "school": "James Madison Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003156",
    },
    {
        "school": "Magnolia Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003157",
    },
    {
        "school": "Main Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003158",
    },
    {
        "school": "Malabar Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003159",
    },
    {
        "school": "Manchester Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003160",
    },
    {
        "school": "Manhattan Place Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003161",
    },
    {
        "school": "Manual Arts Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003163",
    },
    {
        "school": "Mar Vista Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003164",
    },
    {
        "school": "Marianna Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003165",
    },
    {
        "school": "Marina del Rey Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003166",
    },
    {
        "school": "Mark Twain Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003167",
    },
    {
        "school": "Edwin Markham Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003168",
    },
    {
        "school": "Marquez Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003170",
    },
    {
        "school": "John Marshall Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003171",
    },
    {
        "school": "Marvin Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003172",
    },
    {
        "school": "Mayall Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003174",
    },
    {
        "school": "Mayberry Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003175",
    },
    {
        "school": "McKinley Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003177",
    },
    {
        "school": "Melrose Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003178",
    },
    {
        "school": "Melvin Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003179",
    },
    {
        "school": "Menlo Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003180",
    },
    {
        "school": "Metropolitan Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003181",
    },
    {
        "school": "Meyler Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003182",
    },
    {
        "school": "Micheltorena Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003183",
    },
    {
        "school": "Middleton Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003184",
    },
    {
        "school": "Miles Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003185",
    },
    {
        "school": "Loren Miller Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003186",
    },
    {
        "school": "Robert A. Millikan Affiliated Charter & Perf Arts Magnet Mid",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003187",
    },
    {
        "school": "Miramonte Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003188",
    },
    {
        "school": "Mission Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003189",
    },
    {
        "school": "Moneta Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003190",
    },
    {
        "school": "John B. Monlux Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003191",
    },
    {
        "school": "James Monroe High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003193",
    },
    {
        "school": "Monte Vista Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003195",
    },
    {
        "school": "Monterey Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003197",
    },
    {
        "school": "Morningside Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003198",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003199",
    },
    {
        "school": "Mt. Gleason Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003200",
    },
    {
        "school": "Mt. Lukens Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003201",
    },
    {
        "school": "Johnnie Cochran Jr. Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003202",
    },
    {
        "school": "Mt. Washington Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003203",
    },
    {
        "school": "John Muir Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003204",
    },
    {
        "school": "William Mulholland Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003205",
    },
    {
        "school": "Multnomah Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003206",
    },
    {
        "school": "Murchison Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003207",
    },
    {
        "school": "Napa Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003208",
    },
    {
        "school": "Nathaniel Narbonne Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003209",
    },
    {
        "school": "Nestle Avenue Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003210",
    },
    {
        "school": "Nevada Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003211",
    },
    {
        "school": "Nevin Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003212",
    },
    {
        "school": "Harris Newmark Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003214",
    },
    {
        "school": "Florence Nightingale Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003215",
    },
    {
        "school": "Chester W. Nimitz Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003216",
    },
    {
        "school": "Ninety-Fifth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003218",
    },
    {
        "school": "Ninety-Ninth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003219",
    },
    {
        "school": "Ninety-Second Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003220",
    },
    {
        "school": "Charles W. Barrett Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003221",
    },
    {
        "school": "Ninety-Sixth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003222",
    },
    {
        "school": "Ninety-Third Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003223",
    },
    {
        "school": "Alfred B. Nobel Charter Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003225",
    },
    {
        "school": "Noble Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003227",
    },
    {
        "school": "Normandie Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003228",
    },
    {
        "school": "Normont Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003229",
    },
    {
        "school": "North Hollywood Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003230",
    },
    {
        "school": "Northridge Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003231",
    },
    {
        "school": "Norwood Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003232",
    },
    {
        "school": "O'Melveny Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003233",
    },
    {
        "school": "Odyssey Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003235",
    },
    {
        "school": "Olive Vista Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003236",
    },
    {
        "school": "One Hundred Eighteenth Street",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003237",
    },
    {
        "school": "One Hundred Eighty-Sixth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003238",
    },
    {
        "school": "Lovelia P. Flournoy Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003239",
    },
    {
        "school": "San Antonio Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003240",
    },
    {
        "school": "One Hundred Fifty-Sixth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003241",
    },
    {
        "school": "One Hundred Fifty-Third Street",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003242",
    },
    {
        "school": "One Hundred Ninth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003243",
    },
    {
        "school": "Florence Griffith Joyner Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003244",
    },
    {
        "school": "One Hundred Seventh Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003246",
    },
    {
        "school": "One Hundred Sixteenth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003248",
    },
    {
        "school": "One Hundred Thirty-Fifth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003249",
    },
    {
        "school": "One Hundred Twelfth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003250",
    },
    {
        "school": "One Hundred Twenty-Second Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003251",
    },
    {
        "school": "Open Charter Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003252",
    },
    {
        "school": "Osceola Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003254",
    },
    {
        "school": "Overland Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003256",
    },
    {
        "school": "Owensmouth Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003257",
    },
    {
        "school": "Oxnard Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003258",
    },
    {
        "school": "Palisades Charter Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003260",
    },
    {
        "school": "Pacoima Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003263",
    },
    {
        "school": "Palms Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003266",
    },
    {
        "school": "Palms Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003267",
    },
    {
        "school": "Park Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003269",
    },
    {
        "school": "Park Western Place Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003270",
    },
    {
        "school": "Woodland Hills Academy",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003271",
    },
    {
        "school": "Parmelee Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003272",
    },
    {
        "school": "Paseo del Rey Fundamental",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003274",
    },
    {
        "school": "George S. Patton Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003276",
    },
    {
        "school": "Robert E. Peary Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003277",
    },
    {
        "school": "Phoenix Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003279",
    },
    {
        "school": "Pinewood Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003280",
    },
    {
        "school": "Plainview Academic Charter Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003281",
    },
    {
        "school": "Playa del Rey Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003283",
    },
    {
        "school": "Plummer Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003284",
    },
    {
        "school": "Point Fermin Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003285",
    },
    {
        "school": "Pomelo Community Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003286",
    },
    {
        "school": "George K. Porter Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003287",
    },
    {
        "school": "Gaspar De Portola Charter Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003289",
    },
    {
        "school": "President Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003291",
    },
    {
        "school": "Pueblo de Los Angeles Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003292",
    },
    {
        "school": "Purche Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003293",
    },
    {
        "school": "Queen Anne Place Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003294",
    },
    {
        "school": "Ramona Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003295",
    },
    {
        "school": "Ramona Opportunity High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003296",
    },
    {
        "school": "Ranchito Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003297",
    },
    {
        "school": "Raymond Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003298",
    },
    {
        "school": "Walter Reed Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003299",
    },
    {
        "school": "Reseda Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003300",
    },
    {
        "school": "Reseda Charter High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003301",
    },
    {
        "school": "Paul Revere Charter Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003302",
    },
    {
        "school": "Richland Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003305",
    },
    {
        "school": "Morris K. Hamasaki Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003306",
    },
    {
        "school": "Rio Vista Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003309",
    },
    {
        "school": "Ritter Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003310",
    },
    {
        "school": "Riverside Drive Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003311",
    },
    {
        "school": "Rockdale Visual & Performing Arts Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003312",
    },
    {
        "school": "Simon Rodia Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003313",
    },
    {
        "school": "Will Rogers Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003314",
    },
    {
        "school": "Theodore Roosevelt Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003315",
    },
    {
        "school": "Roscoe Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003316",
    },
    {
        "school": "Roscomare Road Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003317",
    },
    {
        "school": "Rosemont Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003318",
    },
    {
        "school": "Rosewood Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003319",
    },
    {
        "school": "Rowan Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003320",
    },
    {
        "school": "Russell Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003321",
    },
    {
        "school": "San Antonio Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003322",
    },
    {
        "school": "San Fernando Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003323",
    },
    {
        "school": "San Fernando Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003324",
    },
    {
        "school": "San Fernando Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003325",
    },
    {
        "school": "San Gabriel Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003326",
    },
    {
        "school": "San Jose Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003328",
    },
    {
        "school": "San Pascual Elem Sci Tech Engr Arts And Math (STEAM) Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003329",
    },
    {
        "school": "San Pedro Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003330",
    },
    {
        "school": "San Pedro Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003331",
    },
    {
        "school": "Martin Luther King Jr. Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003332",
    },
    {
        "school": "Saticoy Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003334",
    },
    {
        "school": "Saturn Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003337",
    },
    {
        "school": "Second Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003338",
    },
    {
        "school": "Selma Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003339",
    },
    {
        "school": "Francisco Sepulveda Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003340",
    },
    {
        "school": "Serrania Avenue Charter For Enriched Studies",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003343",
    },
    {
        "school": "Seventh Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003344",
    },
    {
        "school": "Seventy-Fifth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003345",
    },
    {
        "school": "Seventy-Fourth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003346",
    },
    {
        "school": "Sharp Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003347",
    },
    {
        "school": "Shenandoah Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003348",
    },
    {
        "school": "Sheridan Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003349",
    },
    {
        "school": "Sherman Oaks Elementary Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003351",
    },
    {
        "school": "Shirley Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003352",
    },
    {
        "school": "Short Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003353",
    },
    {
        "school": "Sierra Park Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003354",
    },
    {
        "school": "Sierra Vista Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003355",
    },
    {
        "school": "Sixth Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003356",
    },
    {
        "school": "Gil Garcetti Learning Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003357",
    },
    {
        "school": "Sixty-First Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003358",
    },
    {
        "school": "Sixty-Sixth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003359",
    },
    {
        "school": "Solano Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003360",
    },
    {
        "school": "Soto Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003362",
    },
    {
        "school": "South Gate Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003363",
    },
    {
        "school": "South Gate Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003364",
    },
    {
        "school": "South Park Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003365",
    },
    {
        "school": "South Shores/CSUDH Visual and Performing Arts",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003366",
    },
    {
        "school": "Stagg Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003368",
    },
    {
        "school": "Stanford Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003369",
    },
    {
        "school": "State Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003370",
    },
    {
        "school": "Nora Sterry Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003371",
    },
    {
        "school": "Robert Louis Stevenson College and Career Preparatory",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003372",
    },
    {
        "school": "Stonehurst Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003374",
    },
    {
        "school": "Stoner Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003375",
    },
    {
        "school": "Stoney Point Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003376",
    },
    {
        "school": "Strathern Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003377",
    },
    {
        "school": "Sun Valley Magnet",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003378",
    },
    {
        "school": "Sunland Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003379",
    },
    {
        "school": "Sunny Brae Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003380",
    },
    {
        "school": "Superior Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003381",
    },
    {
        "school": "John A. Sutter Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003382",
    },
    {
        "school": "Sylmar Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003384",
    },
    {
        "school": "Sylmar Charter High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003385",
    },
    {
        "school": "Sylvan Park Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003386",
    },
    {
        "school": "Taft Charter High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003387",
    },
    {
        "school": "Taper Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003388",
    },
    {
        "school": "Tarzana Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003390",
    },
    {
        "school": "Telfair Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003391",
    },
    {
        "school": "Tenth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003393",
    },
    {
        "school": "Third Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003394",
    },
    {
        "school": "Thirty-Second Street USC Performing Arts",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003395",
    },
    {
        "school": "Birdielee V. Bright Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003396",
    },
    {
        "school": "Thomas Riley High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003397",
    },
    {
        "school": "Henry David Thoreau Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003398",
    },
    {
        "school": "Toland Way Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003399",
    },
    {
        "school": "Toluca Lake Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003400",
    },
    {
        "school": "Topanga Elementary Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003401",
    },
    {
        "school": "Topeka Charter School For Advanced Studies",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003402",
    },
    {
        "school": "Towne Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003403",
    },
    {
        "school": "Trinity Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003404",
    },
    {
        "school": "Tulsa Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003406",
    },
    {
        "school": "Tweedy Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003407",
    },
    {
        "school": "Twentieth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003408",
    },
    {
        "school": "Twenty-Eighth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003409",
    },
    {
        "school": "Twenty-Fourth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003410",
    },
    {
        "school": "Two Hundred Thirty-Second Place",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003411",
    },
    {
        "school": "Union Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003412",
    },
    {
        "school": "University High School Charter",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003413",
    },
    {
        "school": "Utah Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003414",
    },
    {
        "school": "Valerio Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003415",
    },
    {
        "school": "Lake Balboa College Preparatory Magnet K-12",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003416",
    },
    {
        "school": "Valley View Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003417",
    },
    {
        "school": "Van Deene Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003418",
    },
    {
        "school": "Van Gogh Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003419",
    },
    {
        "school": "Van Ness Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003420",
    },
    {
        "school": "Van Nuys Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003421",
    },
    {
        "school": "Van Nuys Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003422",
    },
    {
        "school": "Van Nuys Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003424",
    },
    {
        "school": "Vanalden Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003425",
    },
    {
        "school": "Vena Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003427",
    },
    {
        "school": "Venice Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003429",
    },
    {
        "school": "Verdugo Hills Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003430",
    },
    {
        "school": "Vermont Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003431",
    },
    {
        "school": "Vernon City Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003432",
    },
    {
        "school": "Victoria Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003433",
    },
    {
        "school": "Victory Boulevard Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003434",
    },
    {
        "school": "View Park Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003435",
    },
    {
        "school": "Vine Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003436",
    },
    {
        "school": "Vinedale Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003437",
    },
    {
        "school": "Vintage Math/Science/Technology Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003438",
    },
    {
        "school": "Virgil Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003439",
    },
    {
        "school": "Virginia Road Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003440",
    },
    {
        "school": "Wadsworth Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003441",
    },
    {
        "school": "Walgrove Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003442",
    },
    {
        "school": "Warner Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003443",
    },
    {
        "school": "George Washington Preparatory High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003444",
    },
    {
        "school": "Daniel Webster Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003445",
    },
    {
        "school": "Lenicia B. Weemes Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003446",
    },
    {
        "school": "Weigand Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003447",
    },
    {
        "school": "Welby Way Charter Elem Sch And Gifted-High Ability Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003448",
    },
    {
        "school": "West Athens Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003449",
    },
    {
        "school": "West Hollywood Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003451",
    },
    {
        "school": "West Hollywood Opportunity",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003452",
    },
    {
        "school": "West Vernon Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003454",
    },
    {
        "school": "WESM Health/Sports Medicine",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003455",
    },
    {
        "school": "Western Avenue Technology Magnet",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003456",
    },
    {
        "school": "Westminster Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003457",
    },
    {
        "school": "Westport Heights Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003458",
    },
    {
        "school": "Westwood Charter Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003459",
    },
    {
        "school": "Stephen M. White Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003460",
    },
    {
        "school": "White Point Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003461",
    },
    {
        "school": "Wilbur Charter For Enriched Academics",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003462",
    },
    {
        "school": "Wilmington Mid Sci Tech Engr Arts Math (STEAM) Magnet",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003463",
    },
    {
        "school": "Wilmington Park Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003464",
    },
    {
        "school": "Wilshire Crest Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003465",
    },
    {
        "school": "Woodrow Wilson Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003466",
    },
    {
        "school": "Wilton Place Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003467",
    },
    {
        "school": "Winnetka Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003469",
    },
    {
        "school": "Wonderland Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003470",
    },
    {
        "school": "Woodcrest Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003471",
    },
    {
        "school": "Woodlake Elementary Community Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003472",
    },
    {
        "school": "Woodland Hills Elementary Charter For Enriched Studies",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003473",
    },
    {
        "school": "Woodlawn Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003474",
    },
    {
        "school": "Orville Wright Engineering and Design Magnet",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003475",
    },
    {
        "school": "Yorkdale Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271003476",
    },
    {
        "school": "Whitney Young Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271003477",
    },
    {
        "school": "Gratts Learning Academy for Young Scholars (GLAYS)",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271005887",
    },
    {
        "school": "Tri-C Community Day",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271007115",
    },
    {
        "school": "City of Angels",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271007118",
    },
    {
        "school": "Garden Grove Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271007119",
    },
    {
        "school": "Independence Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271007120",
    },
    {
        "school": "Haynes Charter For Enriched Studies",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271007521",
    },
    {
        "school": "Los Angeles Academy Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271007523",
    },
    {
        "school": "Benjamin Banneker Career and Transition Center",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271007750",
    },
    {
        "school": "Belmont Senior High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271007751",
    },
    {
        "school": "Berenece Carlson Home Hospital",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271007753",
    },
    {
        "school": "Fishburn Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271007755",
    },
    {
        "school": "Sven Lokrantz Special Education Center",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271007756",
    },
    {
        "school": "Downtown Business High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271007757",
    },
    {
        "school": "Charles Leroy Lowman Special Ed and Career Transition Center",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271007758",
    },
    {
        "school": "Marlton",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271007759",
    },
    {
        "school": "James J. McBride Special Education Center",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271007760",
    },
    {
        "school": "Alfonso B. Perez Special Education Center",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271007762",
    },
    {
        "school": "Boyle Heights Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271007763",
    },
    {
        "school": "Sophia T. Salvin Special Education Center",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271007764",
    },
    {
        "school": "Ernest P. Willenberg Special Education Center",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271007766",
    },
    {
        "school": "Whitman Continuation",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271007768",
    },
    {
        "school": "Windsor Hills Math Science",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271007770",
    },
    {
        "school": "Newcastle Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271008026",
    },
    {
        "school": "Primary Academy for Success",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271008029",
    },
    {
        "school": "Ninth Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271008157",
    },
    {
        "school": "Sunrise Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271008158",
    },
    {
        "school": "Ellen Ochoa Learning Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271008510",
    },
    {
        "school": "Lafayette Park Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271008722",
    },
    {
        "school": "Diane S. Leichman Career Preparatory and Transition Center",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62271008886",
    },
    {
        "school": "Los Angeles Center for Enriched Studies",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271008887",
    },
    {
        "school": "Arroyo Seco Museum Science",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271008888",
    },
    {
        "school": "King/Drew Medical Magnet High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271009150",
    },
    {
        "school": "Sherman Oaks Center for Enriched Studies",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271009151",
    },
    {
        "school": "Pio Pico Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271009152",
    },
    {
        "school": "Montara Avenue Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271009394",
    },
    {
        "school": "Teresa Hughes Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271009395",
    },
    {
        "school": "Parthenia Academy of Arts and Technology",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271009572",
    },
    {
        "school": "San Miguel Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271009573",
    },
    {
        "school": "Francisco Bravo Medical Magnet High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271010240",
    },
    {
        "school": "Burton Street Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010241",
    },
    {
        "school": "Leo Politi Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010242",
    },
    {
        "school": "Nueva Vista Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271010243",
    },
    {
        "school": "Aeolian Elementary",
        "district": "Los Nietos",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62289003499",
    },
    {
        "school": "Los Nietos Middle",
        "district": "Los Nietos",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62289003500",
    },
    {
        "school": "Ada S. Nelson Elementary",
        "district": "Los Nietos",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62289003501",
    },
    {
        "school": "Rancho Santa Gertrudes Elementary",
        "district": "Los Nietos",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62289003502",
    },
    {
        "school": "Jordan Elementary",
        "district": "Lowell Joint",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62301003507",
    },
    {
        "school": "Meadow Green Elementary",
        "district": "Lowell Joint",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62301003510",
    },
    {
        "school": "Rancho-Starbuck Intermediate",
        "district": "Lowell Joint",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62301003512",
    },
    {
        "school": "Janie P. Abbott Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316003531",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316003533",
    },
    {
        "school": "Lindbergh Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316003534",
    },
    {
        "school": "Lugo Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316003535",
    },
    {
        "school": "Lynwood High",
        "district": "Lynwood Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316003536",
    },
    {
        "school": "Will Rogers Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316003537",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316003538",
    },
    {
        "school": "Mark Twain Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316003539",
    },
    {
        "school": "Vista High",
        "district": "Lynwood Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62316003540",
    },
    {
        "school": "Washington Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316003541",
    },
    {
        "school": "Wilson Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316003542",
    },
    {
        "school": "Lynwood Middle",
        "district": "Lynwood Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316007527",
    },
    {
        "school": "Rosa Parks Elementary",
        "district": "Lynwood Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62316008031",
    },
    {
        "school": "Bradoaks Elementary",
        "district": "Monrovia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62532003775",
    },
    {
        "school": "Canyon Oaks High",
        "district": "Monrovia Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62532003776",
    },
    {
        "school": "Clifton Middle",
        "district": "Monrovia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62532003777",
    },
    {
        "school": "Mayflower Elementary",
        "district": "Monrovia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62532003778",
    },
    {
        "school": "Monroe Elementary",
        "district": "Monrovia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62532003779",
    },
    {
        "school": "Monrovia High",
        "district": "Monrovia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62532003780",
    },
    {
        "school": "Plymouth Elementary",
        "district": "Monrovia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62532003781",
    },
    {
        "school": "Santa Fe Computer Science Magnet",
        "district": "Monrovia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62532003782",
    },
    {
        "school": "Wild Rose School of Creative",
        "district": "Monrovia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62532003783",
    },
    {
        "school": "Mountain Park",
        "district": "Monrovia Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62532008725",
    },
    {
        "school": "Bandini Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003788",
    },
    {
        "school": "Bell Gardens Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003789",
    },
    {
        "school": "Bell Gardens High",
        "district": "Montebello Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003790",
    },
    {
        "school": "Bell Gardens Intermediate",
        "district": "Montebello Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003791",
    },
    {
        "school": "Bella Vista Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003792",
    },
    {
        "school": "Cesar E. Chavez Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003793",
    },
    {
        "school": "Joseph A. Gascon Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003794",
    },
    {
        "school": "Eastmont Intermediate",
        "district": "Montebello Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003795",
    },
    {
        "school": "Fremont Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003796",
    },
    {
        "school": "Garfield Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003797",
    },
    {
        "school": "Greenwood Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003798",
    },
    {
        "school": "La Merced Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003799",
    },
    {
        "school": "La Merced Intermediate",
        "district": "Montebello Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003800",
    },
    {
        "school": "Macy Intermediate",
        "district": "Montebello Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003801",
    },
    {
        "school": "Montebello Gardens Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003802",
    },
    {
        "school": "Montebello High",
        "district": "Montebello Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003803",
    },
    {
        "school": "Montebello Intermediate",
        "district": "Montebello Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003804",
    },
    {
        "school": "Montebello Park Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003805",
    },
    {
        "school": "Potrero Heights Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003806",
    },
    {
        "school": "Rosewood Park",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003807",
    },
    {
        "school": "Schurr High",
        "district": "Montebello Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003808",
    },
    {
        "school": "Suva Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003809",
    },
    {
        "school": "Suva Intermediate",
        "district": "Montebello Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003810",
    },
    {
        "school": "Vail High (Continuation)",
        "district": "Montebello Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62547003811",
    },
    {
        "school": "Washington Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003812",
    },
    {
        "school": "Wilcox Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003813",
    },
    {
        "school": "Winter Gardens Elementary",
        "district": "Montebello Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547003814",
    },
    {
        "school": "Montebello Community Day",
        "district": "Montebello Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62547008726",
    },
    {
        "school": "Alfred S. Madrid Middle",
        "district": "Mountain View Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619000454",
    },
    {
        "school": "Baker Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619003911",
    },
    {
        "school": "Charles T. Kranz Intermediate",
        "district": "Mountain View Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619003912",
    },
    {
        "school": "Cogswell Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619003913",
    },
    {
        "school": "La Primaria Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619003914",
    },
    {
        "school": "Jerry Voorhis Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619003915",
    },
    {
        "school": "Maxson Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619003916",
    },
    {
        "school": "Miramonte Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619003917",
    },
    {
        "school": "Monte Vista Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619003918",
    },
    {
        "school": "Parkview Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619003919",
    },
    {
        "school": "Willard F. Payne Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619003920",
    },
    {
        "school": "Twin Lakes Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62619008913",
    },
    {
        "school": "Meadows Elementary",
        "district": "Newhall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62718004094",
    },
    {
        "school": "Newhall Elementary",
        "district": "Newhall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62718004095",
    },
    {
        "school": "Old Orchard Elementary",
        "district": "Newhall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62718004096",
    },
    {
        "school": "Peachland Avenue Elementary",
        "district": "Newhall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62718004097",
    },
    {
        "school": "Wiley Canyon Elementary",
        "district": "Newhall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62718004098",
    },
    {
        "school": "Stevenson Ranch Elementary",
        "district": "Newhall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62718004595",
    },
    {
        "school": "Valencia Valley Elementary",
        "district": "Newhall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62718009410",
    },
    {
        "school": "Corvallis Middle",
        "district": "Norwalk-La Mirada Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769002145",
    },
    {
        "school": "Reginald M. Benton Middle",
        "district": "Norwalk-La Mirada Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769002165",
    },
    {
        "school": "John Dolland Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004158",
    },
    {
        "school": "John Foster Dulles Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004159",
    },
    {
        "school": "Eastwood Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004160",
    },
    {
        "school": "Earl E. Edmondson Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004161",
    },
    {
        "school": "El Camino High (Continuation)",
        "district": "Norwalk-La Mirada Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62769004162",
    },
    {
        "school": "Escalona Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004163",
    },
    {
        "school": "Foster Road Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004165",
    },
    {
        "school": "Gardenhill Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004166",
    },
    {
        "school": "Anna M. Glazier Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004167",
    },
    {
        "school": "John H. Glenn High",
        "district": "Norwalk-La Mirada Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004168",
    },
    {
        "school": "Arlie F. Hutchinson Middle",
        "district": "Norwalk-La Mirada Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004170",
    },
    {
        "school": "D. D. Johnston Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004171",
    },
    {
        "school": "La Mirada High",
        "district": "Norwalk-La Mirada Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004172",
    },
    {
        "school": "La Pluma Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004173",
    },
    {
        "school": "Loretta Lampton Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004174",
    },
    {
        "school": "Thomas B. Moffitt Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004176",
    },
    {
        "school": "Julia B. Morrison Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004177",
    },
    {
        "school": "New River Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004179",
    },
    {
        "school": "Norwalk High",
        "district": "Norwalk-La Mirada Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004180",
    },
    {
        "school": "Arturo Sanchez Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004181",
    },
    {
        "school": "John H. Nuffer Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004182",
    },
    {
        "school": "Nettie L. Waite Middle",
        "district": "Norwalk-La Mirada Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769004184",
    },
    {
        "school": "Los Alisos Middle",
        "district": "Norwalk-La Mirada Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769007123",
    },
    {
        "school": "Los Coyotes Middle",
        "district": "Norwalk-La Mirada Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769008032",
    },
    {
        "school": "Cesar Chavez Elementary",
        "district": "Norwalk-La Mirada Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769008922",
    },
    {
        "school": "Barrel Springs Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958002166",
    },
    {
        "school": "Palmdale Learning Plaza",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958002169",
    },
    {
        "school": "Ocotillo Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958004572",
    },
    {
        "school": "Manzanita Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958004573",
    },
    {
        "school": "Tamarisk Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958004576",
    },
    {
        "school": "Tumbleweed Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958004577",
    },
    {
        "school": "Yucca Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958004578",
    },
    {
        "school": "Cimarron Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958007129",
    },
    {
        "school": "Quail Valley Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958007528",
    },
    {
        "school": "Shadow Hills Engineering and Design Magnet Academy",
        "district": "Palmdale Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958007529",
    },
    {
        "school": "Golden Poppy Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958008727",
    },
    {
        "school": "Los Amigos - Dual Immersion",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62958008728",
    },
    {
        "school": "Cactus Medical Health and Technology Magnet Academy",
        "district": "Palmdale Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958008933",
    },
    {
        "school": "Desert Rose Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958008934",
    },
    {
        "school": "Joshua Hills Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958009172",
    },
    {
        "school": "Chaparral Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958009173",
    },
    {
        "school": "Palm Tree Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958009421",
    },
    {
        "school": "Buena Vista Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958009606",
    },
    {
        "school": "Mesquite Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958009608",
    },
    {
        "school": "Summerwind Elementary",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958009609",
    },
    {
        "school": "Cornerstone at Pedregal Elementary",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970003247",
    },
    {
        "school": "Lunada Bay Elementary",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970004609",
    },
    {
        "school": "Palos Verdes Intermediate",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970004610",
    },
    {
        "school": "Mira Catalina Elementary",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970004612",
    },
    {
        "school": "Montemalaga Elementary",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970004615",
    },
    {
        "school": "Point Vicente Elementary",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970004618",
    },
    {
        "school": "Rancho Vista Elementary",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970004619",
    },
    {
        "school": "Miraleste Intermediate",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970004620",
    },
    {
        "school": "Silver Spur Elementary",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970004622",
    },
    {
        "school": "Soleado Elementary",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970004623",
    },
    {
        "school": "Vista Grande Elementary",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970004625",
    },
    {
        "school": "Dapplegray Elementary",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970008039",
    },
    {
        "school": "Rancho del Mar High (Continuation)",
        "district": "Palos Verdes Peninsula Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62970008173",
    },
    {
        "school": "Ridgecrest Intermediate",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970008514",
    },
    {
        "school": "Palos Verdes Peninsula High",
        "district": "Palos Verdes Peninsula Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970010246",
    },
    {
        "school": "Captain Raymond Collins",
        "district": "Paramount Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985004645",
    },
    {
        "school": "Wesley Gaines",
        "district": "Paramount Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985004646",
    },
    {
        "school": "Buena Vista High",
        "district": "Paramount Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62985004647",
    },
    {
        "school": "Hollydale",
        "district": "Paramount Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985004648",
    },
    {
        "school": "Mark Keppel",
        "district": "Paramount Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985004649",
    },
    {
        "school": "Abraham Lincoln",
        "district": "Paramount Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985004650",
    },
    {
        "school": "Los Cerritos",
        "district": "Paramount Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985004651",
    },
    {
        "school": "Major Lynn Mokler",
        "district": "Paramount Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985004652",
    },
    {
        "school": "Paramount High",
        "district": "Paramount Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985004653",
    },
    {
        "school": "Theodore Roosevelt",
        "district": "Paramount Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985004654",
    },
    {
        "school": "Frank J. Zamboni",
        "district": "Paramount Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985007134",
    },
    {
        "school": "Paramount Unified Community Day",
        "district": "Paramount Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62985007530",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Paramount Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985008516",
    },
    {
        "school": "Harry Wirtz Elementary",
        "district": "Paramount Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985009986",
    },
    {
        "school": "Altadena Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004661",
    },
    {
        "school": "Blair High",
        "district": "Pasadena Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004662",
    },
    {
        "school": "Don Benito Fundamental",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004665",
    },
    {
        "school": "Charles W. Eliot Middle",
        "district": "Pasadena Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004667",
    },
    {
        "school": "Field (Eugene) Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004668",
    },
    {
        "school": "Rose City High (Continuation)",
        "district": "Pasadena Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62994004669",
    },
    {
        "school": "Franklin Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004670",
    },
    {
        "school": "Hamilton Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004671",
    },
    {
        "school": "Jackson Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004673",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004674",
    },
    {
        "school": "Longfellow (Henry W.) Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004677",
    },
    {
        "school": "Madison Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004678",
    },
    {
        "school": "Marshall Fundamental",
        "district": "Pasadena Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004679",
    },
    {
        "school": "John Muir High",
        "district": "Pasadena Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004681",
    },
    {
        "school": "Norma Coombs Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004683",
    },
    {
        "school": "Pasadena High",
        "district": "Pasadena Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004684",
    },
    {
        "school": "San Rafael Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004686",
    },
    {
        "school": "Sierra Madre Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004687",
    },
    {
        "school": "Washington Middle",
        "district": "Pasadena Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004689",
    },
    {
        "school": "Webster Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004690",
    },
    {
        "school": "Willard Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004691",
    },
    {
        "school": "Woodrow Wilson Middle",
        "district": "Pasadena Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994004692",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994007816",
    },
    {
        "school": "Washington Elementary",
        "district": "Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994008729",
    },
    {
        "school": "San Antonio Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132003255",
    },
    {
        "school": "Alcott Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004834",
    },
    {
        "school": "Allison Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004835",
    },
    {
        "school": "Armstrong Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004836",
    },
    {
        "school": "Arroyo Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004837",
    },
    {
        "school": "Diamond Point Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004838",
    },
    {
        "school": "Emerson Middle",
        "district": "Pomona Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004839",
    },
    {
        "school": "Fremont Academy of Engineering and Design",
        "district": "Pomona Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004840",
    },
    {
        "school": "Ganesha High",
        "district": "Pomona Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004841",
    },
    {
        "school": "Garey High",
        "district": "Pomona Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004842",
    },
    {
        "school": "Golden Springs Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004843",
    },
    {
        "school": "Harrison Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004845",
    },
    {
        "school": "Marshall Middle",
        "district": "Pomona Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004846",
    },
    {
        "school": "Kellogg Polytechnic Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004847",
    },
    {
        "school": "Kingsley Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004848",
    },
    {
        "school": "Lexington Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004849",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004850",
    },
    {
        "school": "Lorbeer Middle",
        "district": "Pomona Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004851",
    },
    {
        "school": "Madison Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004852",
    },
    {
        "school": "Montvue Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004853",
    },
    {
        "school": "Barfield Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004854",
    },
    {
        "school": "Palomares Academy of Health Science",
        "district": "Pomona Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004855",
    },
    {
        "school": "Park West High (Continuation)",
        "district": "Pomona Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63132004856",
    },
    {
        "school": "Philadelphia Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004857",
    },
    {
        "school": "Pomona High",
        "district": "Pomona Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004858",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004859",
    },
    {
        "school": "San Jose Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004860",
    },
    {
        "school": "Simons Middle",
        "district": "Pomona Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004861",
    },
    {
        "school": "Washington Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004862",
    },
    {
        "school": "Westmont Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004863",
    },
    {
        "school": "La Verne Science and Technology Charter",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132004864",
    },
    {
        "school": "Diamond Ranch High",
        "district": "Pomona Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132007136",
    },
    {
        "school": "Decker Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132007332",
    },
    {
        "school": "Village Academy High School at Indian Hill",
        "district": "Pomona Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63132008730",
    },
    {
        "school": "Vejar Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132010000",
    },
    {
        "school": "Ranch Hills Elementary",
        "district": "Pomona Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132010001",
    },
    {
        "school": "Pomona Alternative",
        "district": "Pomona Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63132010247",
    },
    {
        "school": "Encinita Elementary",
        "district": "Rosemead Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63357005178",
    },
    {
        "school": "Mildred B. Janson Elementary",
        "district": "Rosemead Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63357005179",
    },
    {
        "school": "Muscatel Middle",
        "district": "Rosemead Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63357005180",
    },
    {
        "school": "Savannah Elementary",
        "district": "Rosemead Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63357005181",
    },
    {
        "school": "Emma W. Shuey Elementary",
        "district": "Rosemead Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63357005182",
    },
    {
        "school": "Alvarado Intermediate",
        "district": "Rowland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005197",
    },
    {
        "school": "Blandford Elementary",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005198",
    },
    {
        "school": "Giano Intermediate",
        "district": "Rowland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005200",
    },
    {
        "school": "Hollingworth Elementary",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005201",
    },
    {
        "school": "Hurley Elementary",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005202",
    },
    {
        "school": "Jellick Elementary",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005203",
    },
    {
        "school": "John A. Rowland High",
        "district": "Rowland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005204",
    },
    {
        "school": "Killian Elementary",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005205",
    },
    {
        "school": "Nogales High",
        "district": "Rowland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005207",
    },
    {
        "school": "Northam Elementary",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005208",
    },
    {
        "school": "Rorimer Elementary",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005210",
    },
    {
        "school": "Rowland Elementary",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005211",
    },
    {
        "school": "Santana High (Continuation)",
        "district": "Rowland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63375005212",
    },
    {
        "school": "Shelyn Elementary",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005213",
    },
    {
        "school": "Villacorta Elementary",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005214",
    },
    {
        "school": "Ybarra Academy for the Arts and Technology",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005215",
    },
    {
        "school": "Yorbita Elementary",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375005216",
    },
    {
        "school": "Rowland Unified Community Day",
        "district": "Rowland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63375005918",
    },
    {
        "school": "Stanley G. Oswalt Academy",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375008956",
    },
    {
        "school": "Coolidge Elementary",
        "district": "San Gabriel Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63442500523",
    },
    {
        "school": "Jefferson Middle",
        "district": "San Gabriel Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63442500557",
    },
    {
        "school": "McKinley Elementary",
        "district": "San Gabriel Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63442500572",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "San Gabriel Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63442500575",
    },
    {
        "school": "Washington Elementary",
        "district": "San Gabriel Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63442500585",
    },
    {
        "school": "Wilson Elementary",
        "district": "San Gabriel Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63442500611",
    },
    {
        "school": "Gabrielino High",
        "district": "San Gabriel Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63442503273",
    },
    {
        "school": "Del Mar High",
        "district": "San Gabriel Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63442507166",
    },
    {
        "school": "Carver Elementary",
        "district": "San Marino Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63486005884",
    },
    {
        "school": "Huntington Middle",
        "district": "San Marino Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63486005885",
    },
    {
        "school": "San Marino High",
        "district": "San Marino Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63486005886",
    },
    {
        "school": "Valentine Elementary",
        "district": "San Marino Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63486005888",
    },
    {
        "school": "Malibu High",
        "district": "Santa Monica-Malibu Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570002173",
    },
    {
        "school": "John Adams Middle",
        "district": "Santa Monica-Malibu Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570006085",
    },
    {
        "school": "Edison Elementary",
        "district": "Santa Monica-Malibu Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570006089",
    },
    {
        "school": "Franklin Elementary",
        "district": "Santa Monica-Malibu Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570006090",
    },
    {
        "school": "Grant Elementary",
        "district": "Santa Monica-Malibu Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570006091",
    },
    {
        "school": "Lincoln Middle",
        "district": "Santa Monica-Malibu Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570006093",
    },
    {
        "school": "McKinley Elementary",
        "district": "Santa Monica-Malibu Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570006096",
    },
    {
        "school": "John Muir Elementary",
        "district": "Santa Monica-Malibu Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570006097",
    },
    {
        "school": "Olympic High (Continuation)",
        "district": "Santa Monica-Malibu Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63570006098",
    },
    {
        "school": "Will Rogers Elementary",
        "district": "Santa Monica-Malibu Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570006100",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Santa Monica-Malibu Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570006101",
    },
    {
        "school": "Santa Monica High",
        "district": "Santa Monica-Malibu Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570006102",
    },
    {
        "school": "Webster Elementary",
        "district": "Santa Monica-Malibu Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570006104",
    },
    {
        "school": "Malibu Elementary",
        "district": "Santa Monica-Malibu Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570007138",
    },
    {
        "school": "Santa Monica Alternative (K-8)",
        "district": "Santa Monica-Malibu Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63570007360",
    },
    {
        "school": "Mountainview Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597003259",
    },
    {
        "school": "Cedarcreek Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597006153",
    },
    {
        "school": "Emblem Academy",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597006154",
    },
    {
        "school": "Highlands Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597006155",
    },
    {
        "school": "Rio Vista Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597006157",
    },
    {
        "school": "Rosedell Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597006158",
    },
    {
        "school": "Santa Clarita Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597006159",
    },
    {
        "school": "Skyblue Mesa Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597006160",
    },
    {
        "school": "Plum Canyon Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597007532",
    },
    {
        "school": "North Park Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597008063",
    },
    {
        "school": "Charles Helmers Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597009193",
    },
    {
        "school": "James Foster Elementary",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597009637",
    },
    {
        "school": "Arroyo Vista Elementary",
        "district": "South Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63750006332",
    },
    {
        "school": "Marengo Elementary",
        "district": "South Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63750006333",
    },
    {
        "school": "Monterey Hills Elementary",
        "district": "South Pasadena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63750006334",
    },
    {
        "school": "South Pasadena Middle",
        "district": "South Pasadena Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63750006337",
    },
    {
        "school": "South Pasadena Senior High",
        "district": "South Pasadena Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63750006338",
    },
    {
        "school": "Howard J. McKibben Elementary",
        "district": "South Whittier Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63756006357",
    },
    {
        "school": "Lake Marie Elementary",
        "district": "South Whittier Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63756006358",
    },
    {
        "school": "Loma Vista Elementary",
        "district": "South Whittier Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63756006359",
    },
    {
        "school": "Los Altos Elementary",
        "district": "South Whittier Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63756006360",
    },
    {
        "school": "Richard L. Graves Middle",
        "district": "South Whittier Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63756006361",
    },
    {
        "school": "Carmela Elementary",
        "district": "South Whittier Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63756007143",
    },
    {
        "school": "Monte Vista Middle",
        "district": "South Whittier Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63756008990",
    },
    {
        "school": "Leona H. Cox Community Elementary",
        "district": "Sulphur Springs Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63822006446",
    },
    {
        "school": "Mint Canyon Community Elementary",
        "district": "Sulphur Springs Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63822006447",
    },
    {
        "school": "Mitchell Community Elementary",
        "district": "Sulphur Springs Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63822006448",
    },
    {
        "school": "Sulphur Springs Community Elementary",
        "district": "Sulphur Springs Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63822006450",
    },
    {
        "school": "Valley View Community Elementary",
        "district": "Sulphur Springs Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63822007883",
    },
    {
        "school": "Pinetree Community Elementary",
        "district": "Sulphur Springs Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63822009448",
    },
    {
        "school": "Canyon Springs Community Elementary",
        "district": "Sulphur Springs Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63822010249",
    },
    {
        "school": "Dr. Doug Sears Learning Center",
        "district": "Temple City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63898002195",
    },
    {
        "school": "Cloverly Elementary",
        "district": "Temple City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63898006534",
    },
    {
        "school": "Emperor Elementary",
        "district": "Temple City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63898006535",
    },
    {
        "school": "La Rosa Elementary",
        "district": "Temple City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63898006536",
    },
    {
        "school": "Longden Elementary",
        "district": "Temple City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63898006537",
    },
    {
        "school": "Oak Avenue Intermediate",
        "district": "Temple City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63898006538",
    },
    {
        "school": "Temple City High",
        "district": "Temple City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63898006540",
    },
    {
        "school": "Temple City Alternative",
        "district": "Temple City Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63898007145",
    },
    {
        "school": "Jefferson Middle",
        "district": "Torrance Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942002213",
    },
    {
        "school": "Edward J. Richardson Middle",
        "district": "Torrance Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942002214",
    },
    {
        "school": "John Adams Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006549",
    },
    {
        "school": "Anza Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006550",
    },
    {
        "school": "Arlington Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006551",
    },
    {
        "school": "Joseph Arnold Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006552",
    },
    {
        "school": "Calle Mayor Middle",
        "district": "Torrance Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006553",
    },
    {
        "school": "Evelyn Carr Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006554",
    },
    {
        "school": "Casimir Middle",
        "district": "Torrance Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006555",
    },
    {
        "school": "Edison Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006557",
    },
    {
        "school": "Fern Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006558",
    },
    {
        "school": "Hickory Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006559",
    },
    {
        "school": "J. H. Hull Middle",
        "district": "Torrance Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006560",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006563",
    },
    {
        "school": "Bert M. Lynn Middle",
        "district": "Torrance Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006564",
    },
    {
        "school": "Madrona Middle",
        "district": "Torrance Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006565",
    },
    {
        "school": "Philip Magruder Middle",
        "district": "Torrance Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006566",
    },
    {
        "school": "North High",
        "district": "Torrance Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006568",
    },
    {
        "school": "Riviera Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006570",
    },
    {
        "school": "Seaside Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006571",
    },
    {
        "school": "Shery (Kurt T.) High (Continuation)",
        "district": "Torrance Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63942006572",
    },
    {
        "school": "South High",
        "district": "Torrance Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006573",
    },
    {
        "school": "Torrance Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006575",
    },
    {
        "school": "Torrance High",
        "district": "Torrance Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006576",
    },
    {
        "school": "Towers Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006577",
    },
    {
        "school": "Victor Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006578",
    },
    {
        "school": "Walteria Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006579",
    },
    {
        "school": "West High",
        "district": "Torrance Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006580",
    },
    {
        "school": "Howard Wood Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006581",
    },
    {
        "school": "Yukon Elementary",
        "district": "Torrance Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942006582",
    },
    {
        "school": "Dean L. Shively",
        "district": "Valle Lindo Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64065006713",
    },
    {
        "school": "New Temple",
        "district": "Valle Lindo Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64065006714",
    },
    {
        "school": "Castle Rock Elementary",
        "district": "Walnut Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128006833",
    },
    {
        "school": "Chaparral Middle",
        "district": "Walnut Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128006834",
    },
    {
        "school": "Collegewood Elementary",
        "district": "Walnut Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128006835",
    },
    {
        "school": "Cyrus J. Morris Elementary",
        "district": "Walnut Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128006836",
    },
    {
        "school": "Ron Hockwalt Academies (Continuation)",
        "district": "Walnut Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64128006837",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Walnut Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128006838",
    },
    {
        "school": "Maple Hill Elementary",
        "district": "Walnut Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128006839",
    },
    {
        "school": "Suzanne Middle",
        "district": "Walnut Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128006840",
    },
    {
        "school": "Vejar Elementary",
        "district": "Walnut Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128006841",
    },
    {
        "school": "Walnut Elementary",
        "district": "Walnut Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128006842",
    },
    {
        "school": "Walnut High",
        "district": "Walnut Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128006843",
    },
    {
        "school": "Diamond Bar High",
        "district": "Walnut Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128007894",
    },
    {
        "school": "Quail Summit Elementary",
        "district": "Walnut Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128009205",
    },
    {
        "school": "Leonard G. Westhoff Elementary",
        "district": "Walnut Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128009653",
    },
    {
        "school": "South Pointe Middle",
        "district": "Walnut Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64128009654",
    },
    {
        "school": "Hollencrest Middle",
        "district": "West Covina Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200004607",
    },
    {
        "school": "California Elementary",
        "district": "West Covina Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200006874",
    },
    {
        "school": "Cameron Elementary",
        "district": "West Covina Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200006875",
    },
    {
        "school": "Coronado High (Continuation)",
        "district": "West Covina Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64200006876",
    },
    {
        "school": "Merced Elementary",
        "district": "West Covina Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200006880",
    },
    {
        "school": "Merlinda Elementary",
        "district": "West Covina Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200006881",
    },
    {
        "school": "Monte Vista Elementary",
        "district": "West Covina Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200006882",
    },
    {
        "school": "Orangewood Elementary",
        "district": "West Covina Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200006883",
    },
    {
        "school": "Vine Elementary",
        "district": "West Covina Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200006884",
    },
    {
        "school": "Wescove Elementary",
        "district": "West Covina Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200006885",
    },
    {
        "school": "West Covina High",
        "district": "West Covina Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200006886",
    },
    {
        "school": "Edgewood Middle",
        "district": "West Covina Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200009463",
    },
    {
        "school": "Hillview Middle",
        "district": "Westside Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212002217",
    },
    {
        "school": "Sundown Elementary",
        "district": "Westside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212003262",
    },
    {
        "school": "Del Sur Senior Elementary",
        "district": "Westside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212006889",
    },
    {
        "school": "Joe Walker Middle",
        "district": "Westside Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212006890",
    },
    {
        "school": "Leona Valley Elementary",
        "district": "Westside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212006891",
    },
    {
        "school": "Quartz Hill Elementary",
        "district": "Westside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212006892",
    },
    {
        "school": "Valley View Elementary",
        "district": "Westside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212006893",
    },
    {
        "school": "Rancho Vista Elementary",
        "district": "Westside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212009655",
    },
    {
        "school": "Cottonwood Elementary",
        "district": "Westside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212010141",
    },
    {
        "school": "Walter F. Dexter Middle",
        "district": "Whittier City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245006936",
    },
    {
        "school": "Katherine Edwards Middle",
        "district": "Whittier City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245006937",
    },
    {
        "school": "Lou Henry Hoover Elementary",
        "district": "Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245006939",
    },
    {
        "school": "Lydia Jackson Elementary",
        "district": "Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245006940",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245006942",
    },
    {
        "school": "Mill Elementary",
        "district": "Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245006943",
    },
    {
        "school": "Wallen L. Andrews Elementary",
        "district": "Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245006944",
    },
    {
        "school": "Orange Grove Elementary",
        "district": "Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245006945",
    },
    {
        "school": "Daniel Phelan Elementary",
        "district": "Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245006946",
    },
    {
        "school": "Christian Sorensen Elementary",
        "district": "Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245006947",
    },
    {
        "school": "West Whittier Elementary",
        "district": "Whittier City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245006949",
    },
    {
        "school": "Sierra Vista High (Alternative)",
        "district": "Whittier Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64248000496",
    },
    {
        "school": "California High",
        "district": "Whittier Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64248006950",
    },
    {
        "school": "La Serna High",
        "district": "Whittier Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64248006952",
    },
    {
        "school": "Pioneer High",
        "district": "Whittier Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64248006953",
    },
    {
        "school": "Santa Fe High",
        "district": "Whittier Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64248006954",
    },
    {
        "school": "Whittier High",
        "district": "Whittier Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64248006955",
    },
    {
        "school": "Frontier High (Continuation)",
        "district": "Whittier Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64248009008",
    },
    {
        "school": "Valencia High",
        "district": "William S. Hart Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251003264",
    },
    {
        "school": "La Mesa Junior High",
        "district": "William S. Hart Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251003268",
    },
    {
        "school": "Arroyo Seco Junior High",
        "district": "William S. Hart Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251006956",
    },
    {
        "school": "Bowman (Jereann) High (Continuation)",
        "district": "William S. Hart Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64251006957",
    },
    {
        "school": "Canyon High",
        "district": "William S. Hart Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251006958",
    },
    {
        "school": "William S. Hart High",
        "district": "William S. Hart Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251006959",
    },
    {
        "school": "Placerita Junior High",
        "district": "William S. Hart Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251006960",
    },
    {
        "school": "Saugus High",
        "district": "William S. Hart Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251006961",
    },
    {
        "school": "Sierra Vista Junior High",
        "district": "William S. Hart Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251006962",
    },
    {
        "school": "Learning Post High (Alternative)",
        "district": "William S. Hart Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64251007369",
    },
    {
        "school": "Academy of the Canyons",
        "district": "William S. Hart Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251008517",
    },
    {
        "school": "Challenger Middle",
        "district": "Wilsona Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64281009208",
    },
    {
        "school": "Vista San Gabriel Elementary",
        "district": "Wilsona Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64281009209",
    },
    {
        "school": "International Polytechnic High",
        "district": "Los Angeles County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69107804580",
    },
    {
        "school": "Renaissance County Community",
        "district": "Los Angeles County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69107808010",
    },
    {
        "school": "L.A. County High School for the Arts",
        "district": "Los Angeles County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69107809663",
    },
    {
        "school": "Macy Elementary",
        "district": "Lowell Joint",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62301003509",
    },
    {
        "school": "Olita Elementary",
        "district": "Lowell Joint",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62301003511",
    },
    {
        "school": "El Portal Elementary",
        "district": "Lowell Joint",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62301005900",
    },
    {
        "school": "Barton (Clara) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000148",
    },
    {
        "school": "Edison (Thomas) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000149",
    },
    {
        "school": "Franklin (Benjamin) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000150",
    },
    {
        "school": "Gauer (Melbourne A.) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000151",
    },
    {
        "school": "Guinn (James M.) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000152",
    },
    {
        "school": "Henry (Patrick) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000153",
    },
    {
        "school": "Jefferson (Thomas) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000154",
    },
    {
        "school": "Juarez (Benito) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000155",
    },
    {
        "school": "Lincoln (Abraham) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000157",
    },
    {
        "school": "Loara Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000158",
    },
    {
        "school": "Madison (James) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000159",
    },
    {
        "school": "Mann (Horace) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000160",
    },
    {
        "school": "Marshall (John) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000161",
    },
    {
        "school": "Price (Adelaide) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000163",
    },
    {
        "school": "Revere (Paul) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000164",
    },
    {
        "school": "Roosevelt (Theodore) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000165",
    },
    {
        "school": "Ross (Betsy) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000166",
    },
    {
        "school": "Stoddard (Alexander J.) Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000167",
    },
    {
        "school": "Sunkist Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261000168",
    },
    {
        "school": "Olive Street Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261006092",
    },
    {
        "school": "Westmont Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261008240",
    },
    {
        "school": "Anaheim High",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000169",
    },
    {
        "school": "Ball Junior High",
        "district": "Anaheim Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000170",
    },
    {
        "school": "Brookhurst Junior High",
        "district": "Anaheim Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000171",
    },
    {
        "school": "Cypress High",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000172",
    },
    {
        "school": "Dale Junior High",
        "district": "Anaheim Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000173",
    },
    {
        "school": "Gilbert High (Continuation)",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60263000174",
    },
    {
        "school": "Hope",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60263000175",
    },
    {
        "school": "Katella High",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000176",
    },
    {
        "school": "John F. Kennedy High",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000177",
    },
    {
        "school": "Lexington Junior High",
        "district": "Anaheim Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000179",
    },
    {
        "school": "Loara High",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000180",
    },
    {
        "school": "Magnolia High",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000182",
    },
    {
        "school": "Orangeview Junior High",
        "district": "Anaheim Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000184",
    },
    {
        "school": "Savanna High",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000187",
    },
    {
        "school": "South Junior High",
        "district": "Anaheim Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000188",
    },
    {
        "school": "Sycamore Junior High",
        "district": "Anaheim Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000189",
    },
    {
        "school": "Walker Junior High",
        "district": "Anaheim Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000191",
    },
    {
        "school": "Western High",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263000192",
    },
    {
        "school": "Oxford Academy",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60263007580",
    },
    {
        "school": "Polaris High (Alternative)",
        "district": "Anaheim Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60263008115",
    },
    {
        "school": "Arovista Elementary",
        "district": "Brea-Olinda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60588000526",
    },
    {
        "school": "Brea Junior High",
        "district": "Brea-Olinda Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60588000527",
    },
    {
        "school": "Brea Canyon High (Continuation)",
        "district": "Brea-Olinda Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60588000528",
    },
    {
        "school": "Brea-Olinda High",
        "district": "Brea-Olinda Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60588000529",
    },
    {
        "school": "Laurel Elem Magnet Sch of Innovation and Career Explr",
        "district": "Brea-Olinda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60588000530",
    },
    {
        "school": "Mariposa Elementary",
        "district": "Brea-Olinda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60588000531",
    },
    {
        "school": "Olinda Elementary",
        "district": "Brea-Olinda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60588000532",
    },
    {
        "school": "Fanning Academy of Science and Technology",
        "district": "Brea-Olinda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60588000533",
    },
    {
        "school": "Brea Country Hills Elementary",
        "district": "Brea-Olinda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60588007652",
    },
    {
        "school": "Gordon H. Beatty Elementary",
        "district": "Buena Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60636000552",
    },
    {
        "school": "Buena Park Junior High",
        "district": "Buena Park Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60636000553",
    },
    {
        "school": "Arthur F. Corey Elementary",
        "district": "Buena Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60636000554",
    },
    {
        "school": "Charles G. Emery Elementary",
        "district": "Buena Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60636000555",
    },
    {
        "school": "Carl E. Gilbert Elementary",
        "district": "Buena Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60636000556",
    },
    {
        "school": "Mabel L. Pendleton Elementary",
        "district": "Buena Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60636000559",
    },
    {
        "school": "James A. Whitaker Elementary",
        "district": "Buena Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60636000560",
    },
    {
        "school": "Capistrano Valley High",
        "district": "Capistrano Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000685",
    },
    {
        "school": "Castille Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000686",
    },
    {
        "school": "Concordia Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000687",
    },
    {
        "school": "Dana Hills High",
        "district": "Capistrano Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000689",
    },
    {
        "school": "Del Obispo Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000690",
    },
    {
        "school": "Carl Hankey Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000691",
    },
    {
        "school": "Harold Ambuehl Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000692",
    },
    {
        "school": "Las Palmas Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000693",
    },
    {
        "school": "Marco Forster Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000694",
    },
    {
        "school": "Moulton Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000695",
    },
    {
        "school": "Niguel Hills Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000696",
    },
    {
        "school": "Palisades Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000698",
    },
    {
        "school": "Richard Henry Dana Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000699",
    },
    {
        "school": "San Clemente High",
        "district": "Capistrano Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000701",
    },
    {
        "school": "San Juan Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000702",
    },
    {
        "school": "Junipero Serra High",
        "district": "Capistrano Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60744000703",
    },
    {
        "school": "Shorecliffs Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000704",
    },
    {
        "school": "Viejo Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000705",
    },
    {
        "school": "Arroyo Vista Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744000745",
    },
    {
        "school": "Aliso Niguel High",
        "district": "Capistrano Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744002328",
    },
    {
        "school": "Aliso Viejo Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744002334",
    },
    {
        "school": "Bathgate Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744003361",
    },
    {
        "school": "Hidden Hills Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744003367",
    },
    {
        "school": "Clarence Lobo Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744003373",
    },
    {
        "school": "John Malcom Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744003383",
    },
    {
        "school": "Wood Canyon Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744003389",
    },
    {
        "school": "Oak Grove Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744006094",
    },
    {
        "school": "Las Flores Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744007187",
    },
    {
        "school": "Wagon Wheel Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744007188",
    },
    {
        "school": "Newhart Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744007270",
    },
    {
        "school": "Bernice Ayer Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744007587",
    },
    {
        "school": "Don Juan Avila Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744008537",
    },
    {
        "school": "Don Juan Avila Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744008538",
    },
    {
        "school": "Las Flores Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744008539",
    },
    {
        "school": "Kinoshita Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744008540",
    },
    {
        "school": "Tijeras Creek Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744008541",
    },
    {
        "school": "Richard Henry Dana Exceptional Needs",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60744008543",
    },
    {
        "school": "Tesoro High",
        "district": "Capistrano Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744008750",
    },
    {
        "school": "Chaparral Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744008751",
    },
    {
        "school": "Marblehead Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744008752",
    },
    {
        "school": "Marian Bergeson Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744009118",
    },
    {
        "school": "Truman Benedict Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744009119",
    },
    {
        "school": "George White Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744009523",
    },
    {
        "school": "Philip J. Reilly Elementary",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744009745",
    },
    {
        "school": "Buena Terra Elementary",
        "district": "Centralia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60807000773",
    },
    {
        "school": "Danbrook Elementary",
        "district": "Centralia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60807000775",
    },
    {
        "school": "Glen H. Dysinger Sr. Elementary",
        "district": "Centralia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60807000776",
    },
    {
        "school": "Los Coyotes Elementary",
        "district": "Centralia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60807000778",
    },
    {
        "school": "George B. Miller Elementary",
        "district": "Centralia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60807000779",
    },
    {
        "school": "San Marino Elementary",
        "district": "Centralia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60807000780",
    },
    {
        "school": "Raymond Temple Elementary",
        "district": "Centralia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60807000781",
    },
    {
        "school": "Centralia Elementary",
        "district": "Centralia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60807002335",
    },
    {
        "school": "A. E. Arnold Elementary",
        "district": "Cypress Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61044001166",
    },
    {
        "school": "Clara J. King Elementary",
        "district": "Cypress Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61044001169",
    },
    {
        "school": "Steve Luther Elementary",
        "district": "Cypress Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61044001170",
    },
    {
        "school": "Frank Vessels Elementary",
        "district": "Cypress Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61044001174",
    },
    {
        "school": "Margaret Landell Elementary",
        "district": "Cypress Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61044002336",
    },
    {
        "school": "Juliet Morris Elementary",
        "district": "Cypress Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61044009129",
    },
    {
        "school": "Courreges (Roch) Elementary",
        "district": "Fountain Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61422001622",
    },
    {
        "school": "Cox (James H.) Elementary",
        "district": "Fountain Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61422001623",
    },
    {
        "school": "Fulton (Harry C.) Middle",
        "district": "Fountain Valley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61422001625",
    },
    {
        "school": "Gisler (Robert) Elementary",
        "district": "Fountain Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61422001626",
    },
    {
        "school": "Masuda (Kazuo) Middle",
        "district": "Fountain Valley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61422001628",
    },
    {
        "school": "Newland (William T.) Elementary",
        "district": "Fountain Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61422001630",
    },
    {
        "school": "Oka (Isojiro) Elementary",
        "district": "Fountain Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61422001632",
    },
    {
        "school": "Plavan (Urbain H.) Elementary",
        "district": "Fountain Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61422001633",
    },
    {
        "school": "Talbert (Samuel E.) Middle",
        "district": "Fountain Valley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61422001634",
    },
    {
        "school": "Tamura (Hisamatsu) Elementary",
        "district": "Fountain Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61422001635",
    },
    {
        "school": "Acacia Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001790",
    },
    {
        "school": "Commonwealth Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001791",
    },
    {
        "school": "Fern Drive Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001792",
    },
    {
        "school": "Golden Hill Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001793",
    },
    {
        "school": "Hermosa Drive Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001794",
    },
    {
        "school": "Ladera Vista Junior High School of the Arts",
        "district": "Fullerton Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001795",
    },
    {
        "school": "Laguna Road Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001796",
    },
    {
        "school": "Nicolas Junior High",
        "district": "Fullerton Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001798",
    },
    {
        "school": "Orangethorpe Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001799",
    },
    {
        "school": "Pacific Drive Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001800",
    },
    {
        "school": "D. Russell Parks Junior High",
        "district": "Fullerton Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001801",
    },
    {
        "school": "Raymond Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001802",
    },
    {
        "school": "Richman Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001803",
    },
    {
        "school": "Rolling Hills Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001804",
    },
    {
        "school": "Sunset Lane Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001805",
    },
    {
        "school": "Valencia Park Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001806",
    },
    {
        "school": "Woodcrest Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473001808",
    },
    {
        "school": "Maple Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473006099",
    },
    {
        "school": "Beechwood Elementary",
        "district": "Fullerton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61473008241",
    },
    {
        "school": "Buena Park High",
        "district": "Fullerton Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61476001809",
    },
    {
        "school": "Fullerton Union High",
        "district": "Fullerton Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61476001810",
    },
    {
        "school": "La Habra High",
        "district": "Fullerton Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61476001811",
    },
    {
        "school": "La Vista High (Continuation)",
        "district": "Fullerton Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61476001812",
    },
    {
        "school": "Sonora High",
        "district": "Fullerton Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61476001814",
    },
    {
        "school": "Sunny Hills High",
        "district": "Fullerton Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61476001815",
    },
    {
        "school": "Troy High",
        "district": "Fullerton Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61476001816",
    },
    {
        "school": "La Sierra High (Alternative)",
        "district": "Fullerton Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61476007723",
    },
    {
        "school": "Brookhurst Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488000751",
    },
    {
        "school": "Izaak Walton Intermediate",
        "district": "Garden Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488000753",
    },
    {
        "school": "Ocia A. Peters Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488000754",
    },
    {
        "school": "Alamitos Intermediate",
        "district": "Garden Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001822",
    },
    {
        "school": "Ethan B. Allen Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001823",
    },
    {
        "school": "Susan B. Anthony Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001824",
    },
    {
        "school": "Loyal Barker Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001825",
    },
    {
        "school": "Hilton D. Bell Intermediate",
        "district": "Garden Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001826",
    },
    {
        "school": "Bolsa Grande High",
        "district": "Garden Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001827",
    },
    {
        "school": "Bryant Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001829",
    },
    {
        "school": "Clinton Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001833",
    },
    {
        "school": "A. G. Cook Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001834",
    },
    {
        "school": "Genevieve M. Crosby Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001835",
    },
    {
        "school": "Leroy L. Doig Intermediate",
        "district": "Garden Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001836",
    },
    {
        "school": "Dwight D. Eisenhower Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001838",
    },
    {
        "school": "Enders Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001839",
    },
    {
        "school": "Ethel M. Evans Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001840",
    },
    {
        "school": "Excelsior Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001841",
    },
    {
        "school": "Faylane Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001842",
    },
    {
        "school": "Stephen R. Fitz Intermediate",
        "district": "Garden Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001843",
    },
    {
        "school": "Garden Grove High",
        "district": "Garden Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001844",
    },
    {
        "school": "Gilbert Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001846",
    },
    {
        "school": "R. F. Hazard Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001848",
    },
    {
        "school": "Heritage Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001849",
    },
    {
        "school": "Merton E. Hill Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001851",
    },
    {
        "school": "James Irvine Intermediate",
        "district": "Garden Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001852",
    },
    {
        "school": "Donald S. Jordan Intermediate",
        "district": "Garden Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001853",
    },
    {
        "school": "La Quinta High",
        "district": "Garden Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001854",
    },
    {
        "school": "Dr. Walter C. Ralston Intermediate",
        "district": "Garden Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001856",
    },
    {
        "school": "Ernest O. Lawrence Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001857",
    },
    {
        "school": "Los Amigos High",
        "district": "Garden Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001858",
    },
    {
        "school": "John Marshall Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001860",
    },
    {
        "school": "Sarah McGarvin Intermediate",
        "district": "Garden Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001861",
    },
    {
        "school": "Mitchell Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001862",
    },
    {
        "school": "James Monroe Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001863",
    },
    {
        "school": "Morningside Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001864",
    },
    {
        "school": "John Murdy Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001865",
    },
    {
        "school": "Newhope Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001866",
    },
    {
        "school": "Mamie L. Northcutt Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001867",
    },
    {
        "school": "Pacifica High",
        "district": "Garden Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001868",
    },
    {
        "school": "Thomas Paine Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001869",
    },
    {
        "school": "Parkview Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001870",
    },
    {
        "school": "Patton Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001871",
    },
    {
        "school": "Post Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001873",
    },
    {
        "school": "Rancho Alamitos High",
        "district": "Garden Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001874",
    },
    {
        "school": "Riverdale Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001875",
    },
    {
        "school": "Rosita Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001876",
    },
    {
        "school": "Edward Russell Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001877",
    },
    {
        "school": "Santiago High",
        "district": "Garden Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001878",
    },
    {
        "school": "Stanford Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001881",
    },
    {
        "school": "Agnes Ware Stanley Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001882",
    },
    {
        "school": "Sunnyside Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001883",
    },
    {
        "school": "C. C. Violette Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001884",
    },
    {
        "school": "Wakeham Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001885",
    },
    {
        "school": "Earl Warren Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001887",
    },
    {
        "school": "Woodbury Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001888",
    },
    {
        "school": "Louis G. Zeyen Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488001889",
    },
    {
        "school": "Mark Twain Special Center",
        "district": "Garden Grove Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61488002337",
    },
    {
        "school": "Jordan Secondary Learning Center",
        "district": "Garden Grove Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61488002338",
    },
    {
        "school": "Linton T. Simmons Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488007588",
    },
    {
        "school": "Marie L. Hare High",
        "district": "Garden Grove Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61488007724",
    },
    {
        "school": "Louis Lake Intermediate",
        "district": "Garden Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488008753",
    },
    {
        "school": "Leo Carrillo Elementary",
        "district": "Garden Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488009371",
    },
    {
        "school": "Ethel Dwyer Middle",
        "district": "Huntington Beach City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61803002215",
    },
    {
        "school": "John H. Eader Elementary",
        "district": "Huntington Beach City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61803002216",
    },
    {
        "school": "Ralph E. Hawes Elementary",
        "district": "Huntington Beach City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61803002218",
    },
    {
        "school": "S. A. Moffett Elementary",
        "district": "Huntington Beach City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61803002221",
    },
    {
        "school": "Joseph R. Perry Elementary",
        "district": "Huntington Beach City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61803002222",
    },
    {
        "school": "Agnes L. Smith Elementary",
        "district": "Huntington Beach City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61803002224",
    },
    {
        "school": "Isaac L. Sowers Middle",
        "district": "Huntington Beach City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61803002225",
    },
    {
        "school": "John R. Peterson Elementary",
        "district": "Huntington Beach City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61803007190",
    },
    {
        "school": "Huntington Seacliff Elementary",
        "district": "Huntington Beach City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61803008242",
    },
    {
        "school": "Edison High",
        "district": "Huntington Beach Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61806002226",
    },
    {
        "school": "Fountain Valley High",
        "district": "Huntington Beach Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61806002228",
    },
    {
        "school": "Huntington Beach High",
        "district": "Huntington Beach Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61806002230",
    },
    {
        "school": "Marina High",
        "district": "Huntington Beach Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61806002232",
    },
    {
        "school": "Ocean View High",
        "district": "Huntington Beach Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61806002233",
    },
    {
        "school": "Westminster High",
        "district": "Huntington Beach Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61806002234",
    },
    {
        "school": "Valley Vista High (Continuation)",
        "district": "Huntington Beach Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61806002235",
    },
    {
        "school": "Coast High",
        "district": "Huntington Beach Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61806008856",
    },
    {
        "school": "El Cerrito Elementary",
        "district": "La Habra City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62019002411",
    },
    {
        "school": "Imperial Middle",
        "district": "La Habra City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62019002412",
    },
    {
        "school": "Ladera Palma Elementary",
        "district": "La Habra City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62019002413",
    },
    {
        "school": "Las Lomas Elementary",
        "district": "La Habra City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62019002414",
    },
    {
        "school": "Las Positas Elementary",
        "district": "La Habra City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62019002415",
    },
    {
        "school": "Sierra Vista Elementary",
        "district": "La Habra City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62019002416",
    },
    {
        "school": "Walnut Elementary",
        "district": "La Habra City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62019002419",
    },
    {
        "school": "Washington Middle",
        "district": "La Habra City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62019002420",
    },
    {
        "school": "Arbolita Elementary",
        "district": "La Habra City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62019007589",
    },
    {
        "school": "El Morro Elementary",
        "district": "Laguna Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62037002453",
    },
    {
        "school": "Laguna Beach High",
        "district": "Laguna Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62037002454",
    },
    {
        "school": "Thurston Middle",
        "district": "Laguna Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62037002455",
    },
    {
        "school": "Top of the World Elementary",
        "district": "Laguna Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62037002456",
    },
    {
        "school": "Richard Henry Lee Elementary",
        "district": "Los Alamitos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62259000794",
    },
    {
        "school": "Oak Middle",
        "district": "Los Alamitos Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62259004805",
    },
    {
        "school": "Jack L. Weaver Elementary",
        "district": "Los Alamitos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62259006163",
    },
    {
        "school": "Francis Hopkinson Elementary",
        "district": "Los Alamitos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62259007301",
    },
    {
        "school": "Los Alamitos Elementary",
        "district": "Los Alamitos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62259007303",
    },
    {
        "school": "Los Alamitos High",
        "district": "Los Alamitos Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62259007304",
    },
    {
        "school": "Sharon Christa McAuliffe Middle",
        "district": "Los Alamitos Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62259007306",
    },
    {
        "school": "Rossmoor Elementary",
        "district": "Los Alamitos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62259007307",
    },
    {
        "school": "J. H. McGaugh Elementary",
        "district": "Los Alamitos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62259008885",
    },
    {
        "school": "Lord Baden-Powell",
        "district": "Magnolia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62343003558",
    },
    {
        "school": "Walt Disney",
        "district": "Magnolia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62343003559",
    },
    {
        "school": "Dr. Peter Marshall",
        "district": "Magnolia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62343003560",
    },
    {
        "school": "Mattie Lou Maxwell",
        "district": "Magnolia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62343003561",
    },
    {
        "school": "Robert M. Pyles STEM Academy",
        "district": "Magnolia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62343003562",
    },
    {
        "school": "Jonas E. Salk",
        "district": "Magnolia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62343003563",
    },
    {
        "school": "Dr. Albert Schweitzer",
        "district": "Magnolia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62343003564",
    },
    {
        "school": "Esther L. Walter",
        "district": "Magnolia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62343003565",
    },
    {
        "school": "Juliette Low School of the Arts",
        "district": "Magnolia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62343007191",
    },
    {
        "school": "Abraham Lincoln Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724000755",
    },
    {
        "school": "Victoria Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724002341",
    },
    {
        "school": "Roy O. Andersen Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004104",
    },
    {
        "school": "California Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004106",
    },
    {
        "school": "College Park Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004107",
    },
    {
        "school": "Corona del Mar High",
        "district": "Newport-Mesa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004109",
    },
    {
        "school": "Costa Mesa High",
        "district": "Newport-Mesa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004110",
    },
    {
        "school": "Horace Ensign Intermediate",
        "district": "Newport-Mesa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004113",
    },
    {
        "school": "Estancia High",
        "district": "Newport-Mesa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004114",
    },
    {
        "school": "Harbor View Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004115",
    },
    {
        "school": "Heinz Kaiser Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004116",
    },
    {
        "school": "Killybrooke Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004117",
    },
    {
        "school": "Mariners Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004120",
    },
    {
        "school": "Back Bay High",
        "district": "Newport-Mesa Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62724004122",
    },
    {
        "school": "Newport Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004123",
    },
    {
        "school": "Newport Harbor High",
        "district": "Newport-Mesa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004124",
    },
    {
        "school": "Newport Heights Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004125",
    },
    {
        "school": "Paularino Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004127",
    },
    {
        "school": "Pomona Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004128",
    },
    {
        "school": "Sonora Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004130",
    },
    {
        "school": "Charles W. Tewinkle Middle",
        "district": "Newport-Mesa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004131",
    },
    {
        "school": "Whittier Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004132",
    },
    {
        "school": "Wilson Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724004133",
    },
    {
        "school": "Everett A. Rea Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724007193",
    },
    {
        "school": "Maude B. Davis Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724007194",
    },
    {
        "school": "Eastbluff Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724008244",
    },
    {
        "school": "Newport Coast Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724008544",
    },
    {
        "school": "Monte Vista High",
        "district": "Newport-Mesa Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62724008919",
    },
    {
        "school": "Adams Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724009593",
    },
    {
        "school": "Woodland Elementary",
        "district": "Newport-Mesa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724009594",
    },
    {
        "school": "Circle View Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004328",
    },
    {
        "school": "College View Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004329",
    },
    {
        "school": "Golden View Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004332",
    },
    {
        "school": "Harbour View Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004333",
    },
    {
        "school": "Hope View Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004335",
    },
    {
        "school": "Lake View Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004336",
    },
    {
        "school": "Marine View Middle",
        "district": "Ocean View",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004338",
    },
    {
        "school": "Mesa View Middle",
        "district": "Ocean View",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004340",
    },
    {
        "school": "Oak View Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004342",
    },
    {
        "school": "Spring View Middle",
        "district": "Ocean View",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004346",
    },
    {
        "school": "Star View Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004347",
    },
    {
        "school": "Sun View Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004348",
    },
    {
        "school": "Village View Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004349",
    },
    {
        "school": "Vista View Middle",
        "district": "Ocean View",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004350",
    },
    {
        "school": "Westmont Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814004351",
    },
    {
        "school": "Anaheim Hills Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004418",
    },
    {
        "school": "California Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004419",
    },
    {
        "school": "Cambridge Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004420",
    },
    {
        "school": "Canyon High",
        "district": "Orange Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004421",
    },
    {
        "school": "Canyon Hills",
        "district": "Orange Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62865004422",
    },
    {
        "school": "Cerro Villa Middle",
        "district": "Orange Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004423",
    },
    {
        "school": "Crescent Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004424",
    },
    {
        "school": "El Modena High",
        "district": "Orange Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004425",
    },
    {
        "school": "El Rancho Charter",
        "district": "Orange Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004426",
    },
    {
        "school": "Esplanade Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004427",
    },
    {
        "school": "Fairhaven Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004428",
    },
    {
        "school": "Fletcher Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004429",
    },
    {
        "school": "Handy Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004430",
    },
    {
        "school": "Imperial Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004432",
    },
    {
        "school": "Jordan Academy of Language and Computer Science",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004433",
    },
    {
        "school": "Lampson Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004435",
    },
    {
        "school": "La Veta Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004436",
    },
    {
        "school": "Linda Vista Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004437",
    },
    {
        "school": "Nohl Canyon Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004439",
    },
    {
        "school": "Orange High",
        "district": "Orange Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004441",
    },
    {
        "school": "Palmyra Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004442",
    },
    {
        "school": "Panorama Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004443",
    },
    {
        "school": "Portola Middle",
        "district": "Orange Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004446",
    },
    {
        "school": "Prospect Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004447",
    },
    {
        "school": "Richland Continuation High",
        "district": "Orange Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62865004448",
    },
    {
        "school": "Serrano Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004451",
    },
    {
        "school": "Sycamore Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004453",
    },
    {
        "school": "Taft Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004454",
    },
    {
        "school": "Villa Park Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004455",
    },
    {
        "school": "Villa Park High",
        "district": "Orange Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004456",
    },
    {
        "school": "West Orange Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004458",
    },
    {
        "school": "Yorba Middle",
        "district": "Orange Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865004459",
    },
    {
        "school": "McPherson Magnet",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865007195",
    },
    {
        "school": "Canyon Rim Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865007196",
    },
    {
        "school": "Olive Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865008245",
    },
    {
        "school": "Running Springs Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865008246",
    },
    {
        "school": "Chapman Hills Elementary",
        "district": "Orange Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62865009419",
    },
    {
        "school": "Brookhaven Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004755",
    },
    {
        "school": "El Camino Real Continuation High",
        "district": "Placentia-Yorba Linda Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63066004756",
    },
    {
        "school": "El Dorado High",
        "district": "Placentia-Yorba Linda Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004757",
    },
    {
        "school": "Esperanza High",
        "district": "Placentia-Yorba Linda Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004758",
    },
    {
        "school": "Fairmont Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004759",
    },
    {
        "school": "George Key",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63066004760",
    },
    {
        "school": "Glenknoll Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004761",
    },
    {
        "school": "Glenview Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004762",
    },
    {
        "school": "Golden Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004763",
    },
    {
        "school": "John O. Tynes Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004764",
    },
    {
        "school": "Kraemer Middle",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004765",
    },
    {
        "school": "Morse Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004766",
    },
    {
        "school": "Rio Vista Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004768",
    },
    {
        "school": "Ruby Drive Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004769",
    },
    {
        "school": "Sierra Vista Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004770",
    },
    {
        "school": "Topaz Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004771",
    },
    {
        "school": "Col. J. K. Tuffree Middle",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004772",
    },
    {
        "school": "Valencia High",
        "district": "Placentia-Yorba Linda Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004773",
    },
    {
        "school": "Van Buren Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004774",
    },
    {
        "school": "Charles Wagner Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004775",
    },
    {
        "school": "Woodsboro Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004776",
    },
    {
        "school": "Bernardo Yorba Middle",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066004777",
    },
    {
        "school": "La Entrada High",
        "district": "Placentia-Yorba Linda Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63066006103",
    },
    {
        "school": "Parkview",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63066008754",
    },
    {
        "school": "Travis Ranch",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066009177",
    },
    {
        "school": "Mabel M. Paine Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066009613",
    },
    {
        "school": "Rose Drive Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066009614",
    },
    {
        "school": "Yorba Linda Middle",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066009615",
    },
    {
        "school": "Linda Vista Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066009616",
    },
    {
        "school": "Bryant Ranch Elementary",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066009996",
    },
    {
        "school": "Lake Forest Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386000769",
    },
    {
        "school": "Portola Hills Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386000770",
    },
    {
        "school": "Rancho Santa Margarita Intermediate",
        "district": "Saddleback Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386002404",
    },
    {
        "school": "Robinson Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386003453",
    },
    {
        "school": "Foothill Ranch Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386003468",
    },
    {
        "school": "Cordillera Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005293",
    },
    {
        "school": "Del Cerro Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005294",
    },
    {
        "school": "De Portola Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005295",
    },
    {
        "school": "El Toro High",
        "district": "Saddleback Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005296",
    },
    {
        "school": "Esperanza Education Center",
        "district": "Saddleback Valley Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63386005297",
    },
    {
        "school": "Ralph A. Gates Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005298",
    },
    {
        "school": "Glen Yermo Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005299",
    },
    {
        "school": "La Madera Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005300",
    },
    {
        "school": "La Paz Intermediate",
        "district": "Saddleback Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005301",
    },
    {
        "school": "Laguna Hills High",
        "district": "Saddleback Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005303",
    },
    {
        "school": "Linda Vista Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005304",
    },
    {
        "school": "Lomarena Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005305",
    },
    {
        "school": "Los Alisos Intermediate",
        "district": "Saddleback Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005306",
    },
    {
        "school": "Mission Viejo High",
        "district": "Saddleback Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005307",
    },
    {
        "school": "Montevideo Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005308",
    },
    {
        "school": "Olivewood Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005310",
    },
    {
        "school": "Rancho Canada Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005311",
    },
    {
        "school": "San Joaquin Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005312",
    },
    {
        "school": "Santiago STEAM Magnet Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005313",
    },
    {
        "school": "Serrano Intermediate",
        "district": "Saddleback Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005314",
    },
    {
        "school": "Silverado High",
        "district": "Saddleback Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63386005315",
    },
    {
        "school": "Trabuco Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005316",
    },
    {
        "school": "Valencia Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386005317",
    },
    {
        "school": "SVUSD Virtual Academy (Alternative)",
        "district": "Saddleback Valley Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63386007199",
    },
    {
        "school": "Melinda Heights Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386007200",
    },
    {
        "school": "Del Lago Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386007341",
    },
    {
        "school": "Trabuco Hills High",
        "district": "Saddleback Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386008957",
    },
    {
        "school": "Trabuco Mesa Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386009186",
    },
    {
        "school": "Cielo Vista Elementary",
        "district": "Saddleback Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386010043",
    },
    {
        "school": "George Washington Carver Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531000757",
    },
    {
        "school": "Martin R. Heninger Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531000758",
    },
    {
        "school": "Walker Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531002346",
    },
    {
        "school": "Cesar E. Chavez High",
        "district": "Santa Ana Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63531004767",
    },
    {
        "school": "Adams Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005981",
    },
    {
        "school": "Gerald P. Carr Intermediate",
        "district": "Santa Ana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005982",
    },
    {
        "school": "Diamond Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005983",
    },
    {
        "school": "Thomas A. Edison Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005984",
    },
    {
        "school": "Franklin Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005985",
    },
    {
        "school": "Fremont Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005986",
    },
    {
        "school": "Greenville Fundamental Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005987",
    },
    {
        "school": "Carl Harvey Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005988",
    },
    {
        "school": "Hoover Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005989",
    },
    {
        "school": "Andrew Jackson Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005990",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005991",
    },
    {
        "school": "Julia C. Lathrop Intermediate",
        "district": "Santa Ana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005992",
    },
    {
        "school": "Abraham Lincoln Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005993",
    },
    {
        "school": "Lowell Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005994",
    },
    {
        "school": "Madison Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005995",
    },
    {
        "school": "Martin Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005996",
    },
    {
        "school": "McFadden Intermediate",
        "district": "Santa Ana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005997",
    },
    {
        "school": "Monroe Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531005999",
    },
    {
        "school": "Monte Vista Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006000",
    },
    {
        "school": "Lorin Griset Academy",
        "district": "Santa Ana Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63531006001",
    },
    {
        "school": "John Muir Fundamental Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006002",
    },
    {
        "school": "Theodore Roosevelt Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006003",
    },
    {
        "school": "Saddleback High",
        "district": "Santa Ana Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006004",
    },
    {
        "school": "Santa Ana High",
        "district": "Santa Ana Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006005",
    },
    {
        "school": "Santiago Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006006",
    },
    {
        "school": "Sierra Preparatory Academy",
        "district": "Santa Ana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006007",
    },
    {
        "school": "Taft Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006009",
    },
    {
        "school": "Valley High",
        "district": "Santa Ana Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006011",
    },
    {
        "school": "Washington Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006012",
    },
    {
        "school": "Willard Intermediate",
        "district": "Santa Ana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006013",
    },
    {
        "school": "Wilson Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006014",
    },
    {
        "school": "Martin Luther King Jr. Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531006148",
    },
    {
        "school": "Middle College High",
        "district": "Santa Ana Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63531007197",
    },
    {
        "school": "Wallace R. Davis Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531007198",
    },
    {
        "school": "REACH Academy",
        "district": "Santa Ana Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63531007593",
    },
    {
        "school": "Raymond A. Villa Fundamental Intermediate",
        "district": "Santa Ana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531007596",
    },
    {
        "school": "Romero-Cruz Academy",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531007597",
    },
    {
        "school": "Douglas MacArthur Fundamental Intermediate",
        "district": "Santa Ana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531007862",
    },
    {
        "school": "Jim Thorpe Fundamental",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531008248",
    },
    {
        "school": "Gonzalo Felicitas Mendez Fundamental Intermediate",
        "district": "Santa Ana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531008548",
    },
    {
        "school": "Jose Sepulveda Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531008979",
    },
    {
        "school": "John F. Kennedy Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531009440",
    },
    {
        "school": "Century High",
        "district": "Santa Ana Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531009633",
    },
    {
        "school": "Garfield Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531009634",
    },
    {
        "school": "Pio Pico Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531010265",
    },
    {
        "school": "Cerritos Elementary",
        "district": "Savanna Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63603006165",
    },
    {
        "school": "Hansen Elementary",
        "district": "Savanna Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63603006166",
    },
    {
        "school": "Twila Reid Elementary",
        "district": "Savanna Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63603006169",
    },
    {
        "school": "Holder Elementary",
        "district": "Savanna Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63603009194",
    },
    {
        "school": "Barbara Benson Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015000774",
    },
    {
        "school": "C. E. Utt Middle",
        "district": "Tustin Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015003488",
    },
    {
        "school": "Tustin Ranch Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015004783",
    },
    {
        "school": "Arroyo Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006633",
    },
    {
        "school": "Columbus Tustin Middle",
        "district": "Tustin Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006635",
    },
    {
        "school": "A. G. Currie Middle",
        "district": "Tustin Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006636",
    },
    {
        "school": "Helen Estock Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006637",
    },
    {
        "school": "Foothill High",
        "district": "Tustin Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006638",
    },
    {
        "school": "Robert Heideman Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006639",
    },
    {
        "school": "Hewes Middle",
        "district": "Tustin Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006640",
    },
    {
        "school": "Hillview High (Continuation)",
        "district": "Tustin Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64015006641",
    },
    {
        "school": "Loma Vista Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006642",
    },
    {
        "school": "W. R. Nelson Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006644",
    },
    {
        "school": "Jeane Thorman Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006646",
    },
    {
        "school": "Tustin High",
        "district": "Tustin Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006647",
    },
    {
        "school": "Tustin Memorial Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015006648",
    },
    {
        "school": "Tustin Connect",
        "district": "Tustin Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64015007201",
    },
    {
        "school": "Guin Foss Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015007202",
    },
    {
        "school": "Peters Canyon Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015007203",
    },
    {
        "school": "Pioneer Middle",
        "district": "Tustin Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015008250",
    },
    {
        "school": "Red Hill Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015008756",
    },
    {
        "school": "Ladera Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015008757",
    },
    {
        "school": "Myford Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015008758",
    },
    {
        "school": "Benjamin F. Beswick Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015009001",
    },
    {
        "school": "Jessie Hayden Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215002349",
    },
    {
        "school": "Willmore Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215003428",
    },
    {
        "school": "Anderson Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006901",
    },
    {
        "school": "Helen Stacey Middle",
        "district": "Westminster",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006903",
    },
    {
        "school": "Demille Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006904",
    },
    {
        "school": "Eastwood Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006905",
    },
    {
        "school": "Fryberger Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006907",
    },
    {
        "school": "Johnson Middle",
        "district": "Westminster",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006908",
    },
    {
        "school": "Meairs Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006910",
    },
    {
        "school": "Schmitt Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006912",
    },
    {
        "school": "Schroeder Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006913",
    },
    {
        "school": "Sequoia Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006914",
    },
    {
        "school": "Warner Middle",
        "district": "Westminster",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006916",
    },
    {
        "school": "Webber Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215006917",
    },
    {
        "school": "Finley Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215010266",
    },
    {
        "school": "South Lake Middle",
        "district": "Irvine Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450003493",
    },
    {
        "school": "Stonegate Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007050",
    },
    {
        "school": "Bonita Canyon Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007051",
    },
    {
        "school": "College Park Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007052",
    },
    {
        "school": "Culverdale Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007053",
    },
    {
        "school": "Deerfield Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007054",
    },
    {
        "school": "Eastshore Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007055",
    },
    {
        "school": "Woodbury Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007056",
    },
    {
        "school": "Greentree Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007058",
    },
    {
        "school": "Irvine High",
        "district": "Irvine Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007059",
    },
    {
        "school": "Lakeside Middle",
        "district": "Irvine Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007060",
    },
    {
        "school": "Rancho San Joaquin Middle",
        "district": "Irvine Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007062",
    },
    {
        "school": "Creekside High",
        "district": "Irvine Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "68450007063",
    },
    {
        "school": "Santiago Hills Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007064",
    },
    {
        "school": "Stone Creek Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007065",
    },
    {
        "school": "Turtle Rock Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007066",
    },
    {
        "school": "University High",
        "district": "Irvine Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007067",
    },
    {
        "school": "University Park Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007068",
    },
    {
        "school": "Venado Middle",
        "district": "Irvine Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007069",
    },
    {
        "school": "Vista Verde",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007070",
    },
    {
        "school": "Alderwood Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007373",
    },
    {
        "school": "Northwood Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007374",
    },
    {
        "school": "Sierra Vista Middle",
        "district": "Irvine Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007375",
    },
    {
        "school": "Woodbridge High",
        "district": "Irvine Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007376",
    },
    {
        "school": "Canyon View Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450007598",
    },
    {
        "school": "Northwood High",
        "district": "Irvine Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450008251",
    },
    {
        "school": "Plaza Vista",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450008252",
    },
    {
        "school": "Brywood Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450009211",
    },
    {
        "school": "Meadow Park Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450009212",
    },
    {
        "school": "Alternative Education-San Joaquin High",
        "district": "Irvine Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "68450009467",
    },
    {
        "school": "Springbrook Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450009468",
    },
    {
        "school": "Westpark Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450010267",
    },
    {
        "school": "OCCS:CHEP/PCHS",
        "district": "Orange County Department of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102407578",
    },
    {
        "school": "Orange County Special Education",
        "district": "Orange County Department of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102407991",
    },
    {
        "school": "ACCESS Juvenile Hall",
        "district": "Orange County Department of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102409236",
    },
    {
        "school": "Liberty High",
        "district": "Golden Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006810542",
    },
    {
        "school": "Ranchos Middle",
        "district": "Golden Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006810543",
    },
    {
        "school": "Lincoln Community Day",
        "district": "Golden Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006811680",
    },
    {
        "school": "Sierra View Elementary",
        "district": "Golden Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006811682",
    },
    {
        "school": "Manzanita Community Day",
        "district": "Chawanakee Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60011607169",
    },
    {
        "school": "Chawanakee Academy Charter",
        "district": "Chawanakee Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60011607170",
    },
    {
        "school": "North Fork Elementary",
        "district": "Chawanakee Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60011609296",
    },
    {
        "school": "Spring Valley Elementary",
        "district": "Chawanakee Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60011609482",
    },
    {
        "school": "Mountain Oaks High",
        "district": "Chawanakee Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60011610544",
    },
    {
        "school": "Jack G. Desmond Middle",
        "district": "Madera Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334010953",
    },
    {
        "school": "Nishimoto Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334010954",
    },
    {
        "school": "Pioneer Technical Center",
        "district": "Madera County Superintendent of Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101710539",
    },
    {
        "school": "Webster Elementary",
        "district": "Golden Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006807312",
    },
    {
        "school": "Independence Continuation High",
        "district": "Golden Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006808144",
    },
    {
        "school": "Alview Elementary",
        "district": "Alview-Dairyland Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60236000125",
    },
    {
        "school": "Dairyland Elementary",
        "district": "Alview-Dairyland Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60236000126",
    },
    {
        "school": "Fresno Flats Community Day",
        "district": "Bass Lake Joint Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60408007167",
    },
    {
        "school": "Oakhurst Elementary",
        "district": "Bass Lake Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60408009306",
    },
    {
        "school": "Oak Creek Intermediate",
        "district": "Bass Lake Joint Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60408009307",
    },
    {
        "school": "Wasuma Elementary",
        "district": "Bass Lake Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60408010250",
    },
    {
        "school": "Fairmead Elementary",
        "district": "Chowchilla Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60852000848",
    },
    {
        "school": "Merle L. Fuller Elementary",
        "district": "Chowchilla Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60852000849",
    },
    {
        "school": "Stephens Elementary",
        "district": "Chowchilla Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60852000850",
    },
    {
        "school": "Wilson Middle",
        "district": "Chowchilla Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60852000851",
    },
    {
        "school": "Chowchilla Union High",
        "district": "Chowchilla Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60855000852",
    },
    {
        "school": "Gateway High (Continuation)",
        "district": "Chowchilla Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60855007678",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334003282",
    },
    {
        "school": "John Adams Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334003543",
    },
    {
        "school": "Dixieland Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334003544",
    },
    {
        "school": "Howard Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334003546",
    },
    {
        "school": "La Vina Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334003547",
    },
    {
        "school": "Madera High",
        "district": "Madera Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334003548",
    },
    {
        "school": "Millview Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334003550",
    },
    {
        "school": "James Monroe Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334003551",
    },
    {
        "school": "Sierra Vista Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334003553",
    },
    {
        "school": "Thomas Jefferson Middle",
        "district": "Madera Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334003555",
    },
    {
        "school": "George Washington Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334003556",
    },
    {
        "school": "Furman (Duane E.) High (Independent Study Program)",
        "district": "Madera Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62334004611",
    },
    {
        "school": "Martin Luther King Jr. Middle",
        "district": "Madera Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334004613",
    },
    {
        "school": "James Madison Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334006019",
    },
    {
        "school": "Berenda Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334008894",
    },
    {
        "school": "Alpha Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334009397",
    },
    {
        "school": "Raymond-Knowles Elementary",
        "district": "Raymond-Knowles Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63192004918",
    },
    {
        "school": "Gould Educational Center",
        "district": "Madera County Superintendent of Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69101707126",
    },
    {
        "school": "Juvenile Hall (Endeavor/Voyager Secondary)",
        "district": "Madera County Superintendent of Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101708131",
    },
    {
        "school": "Enterprise Secondary",
        "district": "Madera County Superintendent of Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101709021",
    },
    {
        "school": "Harmony Elementary",
        "district": "Delhi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003910965",
    },
    {
        "school": "Merced County ROP",
        "district": "Merced County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60011910964",
    },
    {
        "school": "Atwater Senior Academy",
        "district": "Atwater Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60342011167",
    },
    {
        "school": "Lorena Falasco Elementary",
        "district": "Los Banos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274010962",
    },
    {
        "school": "Sequoia High",
        "district": "Merced Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62466011689",
    },
    {
        "school": "Cesar E. Chavez Middle",
        "district": "Planada Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63084010555",
    },
    {
        "school": "Merced Scholars Charter",
        "district": "Merced County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102010960",
    },
    {
        "school": "Valley Atwater Community",
        "district": "Merced County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102010961",
    },
    {
        "school": "Bryant Middle",
        "district": "Dos Palos Oro Loma Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003301255",
    },
    {
        "school": "Dos Palos Elementary",
        "district": "Dos Palos Oro Loma Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003301256",
    },
    {
        "school": "Dos Palos High",
        "district": "Dos Palos Oro Loma Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003301258",
    },
    {
        "school": "Bernhard Marks Elementary",
        "district": "Dos Palos Oro Loma Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003304680",
    },
    {
        "school": "Westside High",
        "district": "Dos Palos Oro Loma Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60003307695",
    },
    {
        "school": "El Capitan Elementary",
        "district": "Delhi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003901212",
    },
    {
        "school": "Schendel Elementary",
        "district": "Delhi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003901213",
    },
    {
        "school": "Delhi High",
        "district": "Delhi Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003907540",
    },
    {
        "school": "Delhi Middle",
        "district": "Delhi Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003907541",
    },
    {
        "school": "Aileen Colburn Elementary",
        "district": "Atwater Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60342000256",
    },
    {
        "school": "Bellevue Elementary",
        "district": "Atwater Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60342000257",
    },
    {
        "school": "Elmer Wood Elementary",
        "district": "Atwater Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60342000258",
    },
    {
        "school": "Mitchell Elementary",
        "district": "Atwater Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60342000259",
    },
    {
        "school": "Mitchell Intermediate",
        "district": "Atwater Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60342000260",
    },
    {
        "school": "Shaffer Elementary",
        "district": "Atwater Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60342000261",
    },
    {
        "school": "Thomas Olaeta Elementary",
        "district": "Atwater Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60342000262",
    },
    {
        "school": "Peggy Heller Elementary",
        "district": "Atwater Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60342004672",
    },
    {
        "school": "Ballico-Cressey Community Charter",
        "district": "Ballico-Cressey Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60375000344",
    },
    {
        "school": "Cressey Elementary",
        "district": "Ballico-Cressey Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60375000345",
    },
    {
        "school": "El Nido Elementary",
        "district": "El Nido Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61215001368",
    },
    {
        "school": "Gustine Elementary",
        "district": "Gustine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632302032",
    },
    {
        "school": "Gustine High",
        "district": "Gustine Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632302033",
    },
    {
        "school": "Pioneer High (Continuation)",
        "district": "Gustine Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61632308853",
    },
    {
        "school": "Romero Elementary",
        "district": "Gustine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632309552",
    },
    {
        "school": "Gustine Middle",
        "district": "Gustine Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632309842",
    },
    {
        "school": "Elim Elementary",
        "district": "Hilmar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61722002176",
    },
    {
        "school": "Hilmar High",
        "district": "Hilmar Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61722002177",
    },
    {
        "school": "Merquin Elementary",
        "district": "Hilmar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61722002178",
    },
    {
        "school": "Colony Basic Skills Alternative High",
        "district": "Hilmar Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61722007180",
    },
    {
        "school": "Irwin High (Continuation)",
        "district": "Hilmar Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61722009855",
    },
    {
        "school": "Hilmar Middle",
        "district": "Hilmar Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61722009856",
    },
    {
        "school": "Le Grand Elementary",
        "district": "Le Grand Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62124002547",
    },
    {
        "school": "Le Grand High",
        "district": "Le Grand Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62127002548",
    },
    {
        "school": "Granada High",
        "district": "Le Grand Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62127009563",
    },
    {
        "school": "Campus Park Elementary",
        "district": "Livingston Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62217002637",
    },
    {
        "school": "Livingston Middle",
        "district": "Livingston Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62217002639",
    },
    {
        "school": "Selma Herndon Elementary",
        "district": "Livingston Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62217008739",
    },
    {
        "school": "Yamato Colony Elementary",
        "district": "Livingston Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62217009893",
    },
    {
        "school": "Charleston Elementary",
        "district": "Los Banos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274003478",
    },
    {
        "school": "Henry Miller Elementary",
        "district": "Los Banos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274003479",
    },
    {
        "school": "Los Banos Elementary",
        "district": "Los Banos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274003480",
    },
    {
        "school": "Los Banos High",
        "district": "Los Banos Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274003481",
    },
    {
        "school": "Los Banos Junior High",
        "district": "Los Banos Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274003482",
    },
    {
        "school": "R. M. Miano Elementary",
        "district": "Los Banos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274003483",
    },
    {
        "school": "San Luis High (Continuation)",
        "district": "Los Banos Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62274003484",
    },
    {
        "school": "Volta Elementary",
        "district": "Los Banos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274003485",
    },
    {
        "school": "Westside Union Elementary",
        "district": "Los Banos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274008219",
    },
    {
        "school": "McSwain Elementary",
        "district": "McSwain Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62436003654",
    },
    {
        "school": "Herbert H. Cruickshank Middle",
        "district": "Merced City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003307",
    },
    {
        "school": "Ada Givens Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003686",
    },
    {
        "school": "Charles Wright Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003687",
    },
    {
        "school": "Donn B. Chenoweth Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003688",
    },
    {
        "school": "Franklin Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003689",
    },
    {
        "school": "Herbert Hoover Middle",
        "district": "Merced City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003690",
    },
    {
        "school": "John C. Fremont Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003691",
    },
    {
        "school": "John Muir Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003692",
    },
    {
        "school": "Luther Burbank Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003693",
    },
    {
        "school": "Margaret Sheehy Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003694",
    },
    {
        "school": "Rudolph Rivera Middle",
        "district": "Merced City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003695",
    },
    {
        "school": "Tenaya Middle",
        "district": "Merced City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460003696",
    },
    {
        "school": "Don Stowell Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460007539",
    },
    {
        "school": "Merced City School District Community Day",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62460008740",
    },
    {
        "school": "Allan Peterson Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460008899",
    },
    {
        "school": "Leontine Gracey Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460008900",
    },
    {
        "school": "Alicia Reyes Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460009581",
    },
    {
        "school": "Washington Elementary",
        "district": "Merced River Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62463003698",
    },
    {
        "school": "Golden Valley High",
        "district": "Merced Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62466003308",
    },
    {
        "school": "Atwater High",
        "district": "Merced Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62466003699",
    },
    {
        "school": "Livingston High",
        "district": "Merced Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62466003700",
    },
    {
        "school": "Merced High",
        "district": "Merced Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62466003702",
    },
    {
        "school": "Yosemite High (Continuation)",
        "district": "Merced Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62466003703",
    },
    {
        "school": "Independence High (Alternative)",
        "district": "Merced Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62466008164",
    },
    {
        "school": "Buhach Colony High",
        "district": "Merced Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62466008741",
    },
    {
        "school": "Plainsburg Union Elementary",
        "district": "Plainsburg Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63081004788",
    },
    {
        "school": "Planada Elementary",
        "district": "Planada Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63084004789",
    },
    {
        "school": "Snelling-Merced Falls Elementary",
        "district": "Snelling-Merced Falls Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63696006281",
    },
    {
        "school": "Pioneer Elementary",
        "district": "Weaver Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64188003327",
    },
    {
        "school": "Weaver Middle",
        "district": "Weaver Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64188006871",
    },
    {
        "school": "Frank Sparkes Elementary",
        "district": "Winton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64296006988",
    },
    {
        "school": "Sybil N. Crookham Elementary",
        "district": "Winton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64296006989",
    },
    {
        "school": "Winton Middle",
        "district": "Winton",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64296010150",
    },
    {
        "school": "Merced County Special Education",
        "district": "Merced County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102007147",
    },
    {
        "school": "Valley Merced Community",
        "district": "Merced County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102008217",
    },
    {
        "school": "Valley Los Banos Community",
        "district": "Merced County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102008737",
    },
    {
        "school": "Merced County Juvenile Court",
        "district": "Merced County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102009233",
    },
    {
        "school": "Fox Road Elementary",
        "district": "Hughson Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006011342",
    },
    {
        "school": "East Stanislaus High",
        "district": "Oakdale Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006210697",
    },
    {
        "school": "Sierra View Elementary",
        "district": "Oakdale Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006211500",
    },
    {
        "school": "Yosemite ROP",
        "district": "Yosemite ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60014411499",
    },
    {
        "school": "John H. Pitman High",
        "district": "Turlock Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811503",
    },
    {
        "school": "Roselawn High",
        "district": "Turlock Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60015811504",
    },
    {
        "school": "Turlock High",
        "district": "Turlock Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811505",
    },
    {
        "school": "Turlock Junior High",
        "district": "Turlock Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811506",
    },
    {
        "school": "Crowell Elementary",
        "district": "Turlock Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811508",
    },
    {
        "school": "Cunningham Elementary",
        "district": "Turlock Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811509",
    },
    {
        "school": "Julien Elementary",
        "district": "Turlock Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811510",
    },
    {
        "school": "Osborn Two-Way Immersion Academy",
        "district": "Turlock Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811511",
    },
    {
        "school": "Wakefield Elementary",
        "district": "Turlock Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811512",
    },
    {
        "school": "Walter M. Brown Elementary",
        "district": "Turlock Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811513",
    },
    {
        "school": "Dennis G. Earl Elementary",
        "district": "Turlock Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811515",
    },
    {
        "school": "Marvin A. Dutcher Middle",
        "district": "Turlock Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811516",
    },
    {
        "school": "Sandra Tovar Medeiros Elementary",
        "district": "Turlock Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015811816",
    },
    {
        "school": "Whitmore Charter School of Art & Technology",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813011487",
    },
    {
        "school": "Whitmore Charter High",
        "district": "Ceres Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813011488",
    },
    {
        "school": "Central Valley High",
        "district": "Ceres Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813011489",
    },
    {
        "school": "Joel J. Hidahl Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813011490",
    },
    {
        "school": "M. Robert Adkison Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813011491",
    },
    {
        "school": "Sinclear Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813011492",
    },
    {
        "school": "Norman N. Glick Middle",
        "district": "Empire Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61269011171",
    },
    {
        "school": "Barbara Spratling Middle",
        "district": "Keyes Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61962010692",
    },
    {
        "school": "Foothill Community Day",
        "district": "Newman-Crows Landing Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62720011332",
    },
    {
        "school": "Hunt Elementary",
        "district": "Newman-Crows Landing Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62720011360",
    },
    {
        "school": "Apricot Valley Elementary",
        "district": "Patterson Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63003011495",
    },
    {
        "school": "Salida Elementary",
        "district": "Salida Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63390010694",
    },
    {
        "school": "Salida Middle School - Vella Campus",
        "district": "Salida Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63390011496",
    },
    {
        "school": "Mary Lou Dieterich Elementary",
        "district": "Stanislaus Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63795011497",
    },
    {
        "school": "Freedom Elementary",
        "district": "Sylvan Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867010695",
    },
    {
        "school": "Daniel J. Savage Middle",
        "district": "Sylvan Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867011498",
    },
    {
        "school": "Stanislaus Military Academy at Teel",
        "district": "Stanislaus County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104111486",
    },
    {
        "school": "Emilie J. Ross Middle",
        "district": "Hughson Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006002208",
    },
    {
        "school": "Hughson Elementary",
        "district": "Hughson Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006002209",
    },
    {
        "school": "Hughson High",
        "district": "Hughson Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006002212",
    },
    {
        "school": "Dickens (Billy Joe) High (Continuation)",
        "district": "Hughson Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006004164",
    },
    {
        "school": "Riverbank High",
        "district": "Riverbank Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006104232",
    },
    {
        "school": "California Avenue Elementary",
        "district": "Riverbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006105114",
    },
    {
        "school": "Cardozo Middle",
        "district": "Riverbank Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006105115",
    },
    {
        "school": "Oakdale High",
        "district": "Oakdale Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006204231",
    },
    {
        "school": "Cloverland Elementary",
        "district": "Oakdale Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006204233",
    },
    {
        "school": "Fair Oaks Elementary",
        "district": "Oakdale Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006204234",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Oakdale Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006204235",
    },
    {
        "school": "Oakdale Junior High",
        "district": "Oakdale Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006204236",
    },
    {
        "school": "Oakdale Charter",
        "district": "Oakdale Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006206752",
    },
    {
        "school": "Valley Oak Junior and Senior High",
        "district": "Oakdale Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006206757",
    },
    {
        "school": "Waterford Junior",
        "district": "Waterford Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006306868",
    },
    {
        "school": "Waterford High",
        "district": "Waterford Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006308657",
    },
    {
        "school": "Argus High (Continuation)",
        "district": "Ceres Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60813000782",
    },
    {
        "school": "Carroll Fowler Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813000783",
    },
    {
        "school": "Caswell Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813000784",
    },
    {
        "school": "Ceres High",
        "district": "Ceres Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813000785",
    },
    {
        "school": "Don Pedro Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813000786",
    },
    {
        "school": "Mae Hensley Junior High",
        "district": "Ceres Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813000787",
    },
    {
        "school": "Walter White Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813000788",
    },
    {
        "school": "Westport Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813000789",
    },
    {
        "school": "Samuel Vaughn Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813004126",
    },
    {
        "school": "Blaker-Kinser Junior High",
        "district": "Ceres Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813004129",
    },
    {
        "school": "Endeavor Alternative",
        "district": "Ceres Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60813005472",
    },
    {
        "school": "Virginia Parks Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813009526",
    },
    {
        "school": "Chatom Elementary",
        "district": "Chatom Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60825000808",
    },
    {
        "school": "Mountain View Middle",
        "district": "Chatom Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60825000809",
    },
    {
        "school": "Denair High",
        "district": "Denair Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61104001218",
    },
    {
        "school": "Denair Elementary",
        "district": "Denair Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61104008653",
    },
    {
        "school": "Denair Middle",
        "district": "Denair Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61104008654",
    },
    {
        "school": "Denair Charter Academy",
        "district": "Denair Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61104010438",
    },
    {
        "school": "Capistrano Elementary",
        "district": "Empire Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61269001429",
    },
    {
        "school": "Empire Elementary",
        "district": "Empire Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61269001430",
    },
    {
        "school": "Christine Sipherd Elementary",
        "district": "Empire Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61269001432",
    },
    {
        "school": "Alice N. Stroud Elementary",
        "district": "Empire Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61269004134",
    },
    {
        "school": "Bernard L. Hughes Elementary",
        "district": "Empire Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61269009536",
    },
    {
        "school": "Gratton Elementary",
        "district": "Gratton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61581001999",
    },
    {
        "school": "Hart-Ransom Elementary",
        "district": "Hart-Ransom Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61665002092",
    },
    {
        "school": "Hart-Ransom Academic Charter",
        "district": "Hart-Ransom Union Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61665005478",
    },
    {
        "school": "Hickman Elementary",
        "district": "Hickman Community Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61716002171",
    },
    {
        "school": "Hickman Charter",
        "district": "Hickman Community Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61716005507",
    },
    {
        "school": "Hickman Middle",
        "district": "Hickman Community Charter",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61716008411",
    },
    {
        "school": "Keyes Elementary",
        "district": "Keyes Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61962002359",
    },
    {
        "school": "Keyes to Learning Charter",
        "district": "Keyes Union",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61962006745",
    },
    {
        "school": "Knights Ferry Elementary",
        "district": "Knights Ferry Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62001002396",
    },
    {
        "school": "Elihu Beard Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003726",
    },
    {
        "school": "Bret Harte Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003727",
    },
    {
        "school": "Burbank Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003728",
    },
    {
        "school": "El Vista Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003729",
    },
    {
        "school": "Enslen Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003730",
    },
    {
        "school": "Catherine Everett Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003731",
    },
    {
        "school": "Fairview Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003732",
    },
    {
        "school": "Franklin Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003733",
    },
    {
        "school": "John Fremont Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003735",
    },
    {
        "school": "William Garrison Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003738",
    },
    {
        "school": "La Loma Junior High",
        "district": "Modesto City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003740",
    },
    {
        "school": "Lakewood Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003741",
    },
    {
        "school": "Mark Twain Junior High",
        "district": "Modesto City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003742",
    },
    {
        "school": "James Marshall Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003743",
    },
    {
        "school": "John Muir Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003745",
    },
    {
        "school": "Robertson Road Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003747",
    },
    {
        "school": "Roosevelt Junior High",
        "district": "Modesto City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003748",
    },
    {
        "school": "Rose Avenue Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003749",
    },
    {
        "school": "Shackelford Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003750",
    },
    {
        "school": "Sonoma Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003751",
    },
    {
        "school": "Tuolumne Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003754",
    },
    {
        "school": "Wilson Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003756",
    },
    {
        "school": "Orville Wright Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513003757",
    },
    {
        "school": "Harriette Kirschen Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513008903",
    },
    {
        "school": "Alberta Martone Elementary",
        "district": "Modesto City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513009156",
    },
    {
        "school": "Evelyn Hanshaw Middle",
        "district": "Modesto City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62513010333",
    },
    {
        "school": "Peter Johansen High",
        "district": "Modesto City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62515001807",
    },
    {
        "school": "Fred C. Beyer High",
        "district": "Modesto City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62515003734",
    },
    {
        "school": "Robert Elliott Alternative Education Center",
        "district": "Modesto City High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62515003737",
    },
    {
        "school": "Grace M. Davis High",
        "district": "Modesto City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62515003739",
    },
    {
        "school": "Modesto High",
        "district": "Modesto City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62515003744",
    },
    {
        "school": "Thomas Downey High",
        "district": "Modesto City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62515003753",
    },
    {
        "school": "Bonita Elementary",
        "district": "Newman-Crows Landing Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62720004099",
    },
    {
        "school": "Orestimba High",
        "district": "Newman-Crows Landing Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62720004100",
    },
    {
        "school": "Von Renner Elementary",
        "district": "Newman-Crows Landing Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62720004101",
    },
    {
        "school": "Yolo Junior High",
        "district": "Newman-Crows Landing Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62720004102",
    },
    {
        "school": "Newman-Crows Landing Independent Study",
        "district": "Newman-Crows Landing Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62720006764",
    },
    {
        "school": "West Side Valley High (Continuation)",
        "district": "Newman-Crows Landing Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62720007798",
    },
    {
        "school": "Paradise Elementary",
        "district": "Paradise Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62979004636",
    },
    {
        "school": "Grayson Elementary",
        "district": "Patterson Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63003004699",
    },
    {
        "school": "Las Palmas Elementary",
        "district": "Patterson Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63003004701",
    },
    {
        "school": "Northmead Elementary",
        "district": "Patterson Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63003004702",
    },
    {
        "school": "Patterson High",
        "district": "Patterson Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63003004703",
    },
    {
        "school": "Creekside Middle",
        "district": "Patterson Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63003004704",
    },
    {
        "school": "Del Puerto High",
        "district": "Patterson Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63003010334",
    },
    {
        "school": "Roberts Ferry Union Elementary",
        "district": "Roberts Ferry Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63321005164",
    },
    {
        "school": "Dena Boer",
        "district": "Salida Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63390006759",
    },
    {
        "school": "Sisk Elementary",
        "district": "Salida Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63390009432",
    },
    {
        "school": "Shiloh Elementary",
        "district": "Shiloh Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63666006214",
    },
    {
        "school": "Josephine Chrysler Elementary",
        "district": "Stanislaus Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63795006393",
    },
    {
        "school": "George Eisenhut Elementary",
        "district": "Stanislaus Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63795006394",
    },
    {
        "school": "Prescott Junior High",
        "district": "Stanislaus Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63795006396",
    },
    {
        "school": "Stanislaus Elementary",
        "district": "Stanislaus Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63795006397",
    },
    {
        "school": "Agnes M. Baptist Elementary",
        "district": "Stanislaus Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63795009643",
    },
    {
        "school": "Orchard Elementary",
        "district": "Sylvan Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867001813",
    },
    {
        "school": "Elizabeth Ustach Middle",
        "district": "Sylvan Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867001828",
    },
    {
        "school": "Coleman F. Brown Elementary",
        "district": "Sylvan Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867006497",
    },
    {
        "school": "Stockard Coffee Elementary",
        "district": "Sylvan Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867006498",
    },
    {
        "school": "Sherwood Elementary",
        "district": "Sylvan Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867006499",
    },
    {
        "school": "Somerset Middle",
        "district": "Sylvan Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867006500",
    },
    {
        "school": "Standiford Elementary",
        "district": "Sylvan Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867006501",
    },
    {
        "school": "Sylvan Elementary",
        "district": "Sylvan Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867006502",
    },
    {
        "school": "Woodrow Elementary",
        "district": "Sylvan Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63867006503",
    },
    {
        "school": "Valley Home Elementary",
        "district": "Valley Home Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64080006742",
    },
    {
        "school": "Stanislaus County Special Education",
        "district": "Stanislaus County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104107228",
    },
    {
        "school": "Petersen Alternative Center for Education",
        "district": "Stanislaus County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104107887",
    },
    {
        "school": "Stanislaus County West Campus",
        "district": "Stanislaus County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104109050",
    },
    {
        "school": "Napa County ROP",
        "district": "Napa County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60008010978",
    },
    {
        "school": "Valley Oak High",
        "district": "Napa Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62664010563",
    },
    {
        "school": "Canyon Oaks Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664010976",
    },
    {
        "school": "Harvest Middle",
        "district": "Napa Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664011258",
    },
    {
        "school": "Napa Valley Independent Studies",
        "district": "Napa Valley Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62664011271",
    },
    {
        "school": "Calistoga Elementary",
        "district": "Calistoga Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60702000646",
    },
    {
        "school": "Calistoga Junior/Senior High",
        "district": "Calistoga Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60702000647",
    },
    {
        "school": "Palisades High (Continuation)",
        "district": "Calistoga Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60702007657",
    },
    {
        "school": "Howell Mountain Elementary",
        "district": "Howell Mountain Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61776002196",
    },
    {
        "school": "Alta Heights Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004011",
    },
    {
        "school": "Bel Aire Park Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004012",
    },
    {
        "school": "Browns Valley Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004013",
    },
    {
        "school": "Donaldson Way Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004017",
    },
    {
        "school": "McPherson Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004020",
    },
    {
        "school": "Mt. George International",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004021",
    },
    {
        "school": "Napa High",
        "district": "Napa Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004022",
    },
    {
        "school": "Napa Junction Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004023",
    },
    {
        "school": "Northwood Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004024",
    },
    {
        "school": "Phillips Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004026",
    },
    {
        "school": "Pueblo Vista Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004027",
    },
    {
        "school": "Redwood Middle",
        "district": "Napa Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004028",
    },
    {
        "school": "Shearer Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004031",
    },
    {
        "school": "Silverado Middle",
        "district": "Napa Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004032",
    },
    {
        "school": "Snow Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004033",
    },
    {
        "school": "Vichy Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004036",
    },
    {
        "school": "Vintage High",
        "district": "Napa Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004037",
    },
    {
        "school": "West Park Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004038",
    },
    {
        "school": "Napa Valley Language Academy",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004039",
    },
    {
        "school": "Yountville Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004041",
    },
    {
        "school": "River Middle",
        "district": "Napa Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664004695",
    },
    {
        "school": "New Technology High",
        "district": "Napa Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62664006081",
    },
    {
        "school": "American Canyon Middle",
        "district": "Napa Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664007575",
    },
    {
        "school": "Pope Valley Elementary",
        "district": "Pope Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63138004866",
    },
    {
        "school": "Saint Helena Elementary",
        "district": "Saint Helena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63783006386",
    },
    {
        "school": "Saint Helena High",
        "district": "Saint Helena Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63783006387",
    },
    {
        "school": "Robert Louis Stevenson Intermediate",
        "district": "Saint Helena Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63783006388",
    },
    {
        "school": "Saint Helena Primary",
        "district": "Saint Helena Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63783008533",
    },
    {
        "school": "Napa County Community",
        "district": "Napa County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102207574",
    },
    {
        "school": "Napa County Juvenile Hall/Court",
        "district": "Napa County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102209235",
    },
    {
        "school": "Career Education Center",
        "district": "Ventura County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60014811540",
    },
    {
        "school": "Mountain Vista",
        "district": "Fillmore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61380011538",
    },
    {
        "school": "Oak Park Independent",
        "district": "Oak Park Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62785011539",
    },
    {
        "school": "Thurgood Marshall Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922011374",
    },
    {
        "school": "La Mariposa",
        "district": "Pleasant Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099010710",
    },
    {
        "school": "Las Colinas Middle",
        "district": "Pleasant Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099011372",
    },
    {
        "school": "Rancho Rosal Elementary",
        "district": "Pleasant Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099011831",
    },
    {
        "school": "Arroyo Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684010712",
    },
    {
        "school": "Gateway Community",
        "district": "Ventura County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104710708",
    },
    {
        "school": "Oak Park High",
        "district": "Oak Park Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62785007253",
    },
    {
        "school": "Briggs Elementary",
        "district": "Briggs Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60603000540",
    },
    {
        "school": "Olivelands Elementary",
        "district": "Briggs Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60603009325",
    },
    {
        "school": "Acacia Magnet School for Enriched Learning",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001004",
    },
    {
        "school": "Aspen Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001005",
    },
    {
        "school": "Banyan Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001006",
    },
    {
        "school": "Colina Middle",
        "district": "Conejo Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001007",
    },
    {
        "school": "Conejo Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001008",
    },
    {
        "school": "Conejo Valley High (Continuation)",
        "district": "Conejo Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60964001010",
    },
    {
        "school": "Cypress Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001011",
    },
    {
        "school": "Glenwood Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001012",
    },
    {
        "school": "Ladera STARS Academy",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001014",
    },
    {
        "school": "Los Cerritos Middle",
        "district": "Conejo Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001015",
    },
    {
        "school": "Madrona Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001016",
    },
    {
        "school": "Maple Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001018",
    },
    {
        "school": "Newbury Park High",
        "district": "Conejo Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001020",
    },
    {
        "school": "Redwood Middle",
        "district": "Conejo Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001022",
    },
    {
        "school": "Sequoia Middle",
        "district": "Conejo Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001023",
    },
    {
        "school": "Thousand Oaks High",
        "district": "Conejo Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001024",
    },
    {
        "school": "Walnut Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001027",
    },
    {
        "school": "Weathersfield Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001029",
    },
    {
        "school": "Westlake Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001030",
    },
    {
        "school": "Westlake High",
        "district": "Conejo Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001031",
    },
    {
        "school": "Westlake Hills Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001032",
    },
    {
        "school": "Wildwood Elementary",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964001033",
    },
    {
        "school": "Lang Ranch",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964007933",
    },
    {
        "school": "Sycamore Canyon",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964010454",
    },
    {
        "school": "Fillmore Middle",
        "district": "Fillmore Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61380001554",
    },
    {
        "school": "Fillmore Senior High",
        "district": "Fillmore Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61380001555",
    },
    {
        "school": "Piru Elementary",
        "district": "Fillmore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61380001556",
    },
    {
        "school": "San Cayetano Elementary",
        "district": "Fillmore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61380001557",
    },
    {
        "school": "Rio Vista Elementary",
        "district": "Fillmore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61380001558",
    },
    {
        "school": "Sierra High",
        "district": "Fillmore Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61380007710",
    },
    {
        "school": "Richard Bard Elementary",
        "district": "Hueneme Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61785002197",
    },
    {
        "school": "Charles Blackstock Junior High",
        "district": "Hueneme Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61785002198",
    },
    {
        "school": "E. O. Green Junior High",
        "district": "Hueneme Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61785002199",
    },
    {
        "school": "Julien Hathaway Elementary",
        "district": "Hueneme Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61785002200",
    },
    {
        "school": "Art Haycox Elementary",
        "district": "Hueneme Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61785002201",
    },
    {
        "school": "Hollywood Beach Elementary",
        "district": "Hueneme Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61785002202",
    },
    {
        "school": "Hueneme Elementary",
        "district": "Hueneme Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61785002203",
    },
    {
        "school": "Ansgar Larsen Elementary",
        "district": "Hueneme Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61785002204",
    },
    {
        "school": "Parkview Elementary",
        "district": "Hueneme Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61785002205",
    },
    {
        "school": "Sunkist Elementary",
        "district": "Hueneme Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61785002206",
    },
    {
        "school": "Fred L. Williams Elementary",
        "district": "Hueneme Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61785002207",
    },
    {
        "school": "Mesa Elementary",
        "district": "Mesa Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62472003705",
    },
    {
        "school": "Mesa Verde Middle",
        "district": "Moorpark Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62569004325",
    },
    {
        "school": "Flory Academy of Sciences and Technology",
        "district": "Moorpark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62569007783",
    },
    {
        "school": "Moorpark High",
        "district": "Moorpark Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62569007784",
    },
    {
        "school": "Peach Hill Academy",
        "district": "Moorpark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62569007785",
    },
    {
        "school": "Chaparral Middle",
        "district": "Moorpark Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62569007786",
    },
    {
        "school": "Walnut Canyon Elementary",
        "district": "Moorpark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62569007935",
    },
    {
        "school": "Community High",
        "district": "Moorpark Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62569008166",
    },
    {
        "school": "Campus Canyon Elementary",
        "district": "Moorpark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62569009157",
    },
    {
        "school": "Mountain Meadows Elementary",
        "district": "Moorpark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62569009158",
    },
    {
        "school": "Arroyo West Elementary",
        "district": "Moorpark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62569010342",
    },
    {
        "school": "The High School at Moorpark College",
        "district": "Moorpark Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62569010455",
    },
    {
        "school": "Mupu Elementary",
        "district": "Mupu Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62646003993",
    },
    {
        "school": "Red Oak Elementary",
        "district": "Oak Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62785002854",
    },
    {
        "school": "Brookside Elementary",
        "district": "Oak Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62785007251",
    },
    {
        "school": "Oak View High",
        "district": "Oak Park Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62785007799",
    },
    {
        "school": "Medea Creek Middle",
        "district": "Oak Park Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62785009414",
    },
    {
        "school": "Oak Hills Elementary",
        "district": "Oak Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62785009415",
    },
    {
        "school": "Laguna Vista Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62817004352",
    },
    {
        "school": "Mar Vista Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62817004353",
    },
    {
        "school": "Ocean View Junior High",
        "district": "Ocean View",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62817004354",
    },
    {
        "school": "Tierra Vista Elementary",
        "district": "Ocean View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62817004355",
    },
    {
        "school": "Chaparral High",
        "district": "Ojai Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62827004375",
    },
    {
        "school": "Matilija Middle",
        "district": "Ojai Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62827004376",
    },
    {
        "school": "Meiners Oaks Elementary",
        "district": "Ojai Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62827004377",
    },
    {
        "school": "Mira Monte Elementary",
        "district": "Ojai Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62827004378",
    },
    {
        "school": "Nordhoff High",
        "district": "Ojai Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62827004379",
    },
    {
        "school": "San Antonio Elementary",
        "district": "Ojai Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62827004380",
    },
    {
        "school": "Topa Topa Elementary",
        "district": "Ojai Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62827004382",
    },
    {
        "school": "Emilie Ritchen Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922001855",
    },
    {
        "school": "R.J. Frank Academy of Marine Science & Engineering",
        "district": "Oxnard",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004240",
    },
    {
        "school": "Curren Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004501",
    },
    {
        "school": "Driffill Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004502",
    },
    {
        "school": "Fremont Academy of Environmental Science & Innovative Design",
        "district": "Oxnard",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004504",
    },
    {
        "school": "Harrington Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004505",
    },
    {
        "school": "Cesar E. Chavez Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004507",
    },
    {
        "school": "Kamala Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004508",
    },
    {
        "school": "Lemonwood Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004509",
    },
    {
        "school": "Marina West Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004510",
    },
    {
        "school": "McKinna Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004511",
    },
    {
        "school": "Rose Avenue Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004513",
    },
    {
        "school": "Sierra Linda Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922004515",
    },
    {
        "school": "Elm Street Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922006804",
    },
    {
        "school": "Norman R. Brekke Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922007476",
    },
    {
        "school": "San Miguel",
        "district": "Oxnard",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922007809",
    },
    {
        "school": "Haydock Academy of Arts & Sciences",
        "district": "Oxnard",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922007922",
    },
    {
        "school": "Ramona Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922008665",
    },
    {
        "school": "Christa McAuliffe Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922009598",
    },
    {
        "school": "Adolfo Camarillo High",
        "district": "Oxnard Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62927004516",
    },
    {
        "school": "Channel Islands High",
        "district": "Oxnard Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62927004517",
    },
    {
        "school": "Frontier High",
        "district": "Oxnard Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62927004518",
    },
    {
        "school": "Hueneme High",
        "district": "Oxnard Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62927004519",
    },
    {
        "school": "Oxnard High",
        "district": "Oxnard Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62927004520",
    },
    {
        "school": "Rio Mesa High",
        "district": "Oxnard Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62927004521",
    },
    {
        "school": "Pacifica High",
        "district": "Oxnard Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62927010452",
    },
    {
        "school": "Tierra Linda Elementary",
        "district": "Pleasant Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099004311",
    },
    {
        "school": "Camarillo Heights Elementary",
        "district": "Pleasant Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099004796",
    },
    {
        "school": "Dos Caminos Elementary",
        "district": "Pleasant Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099004797",
    },
    {
        "school": "Pleasant Valley School of Engineering and Arts",
        "district": "Pleasant Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099004798",
    },
    {
        "school": "Las Posas Elementary",
        "district": "Pleasant Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099004800",
    },
    {
        "school": "Los Primeros School of Sciences & Arts",
        "district": "Pleasant Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099004803",
    },
    {
        "school": "Monte Vista Middle",
        "district": "Pleasant Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099004804",
    },
    {
        "school": "Santa Rosa Technology Magnet",
        "district": "Pleasant Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099004806",
    },
    {
        "school": "Rio del Valle Middle",
        "district": "Rio Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63276005089",
    },
    {
        "school": "Rio Lindo Elementary",
        "district": "Rio Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63276005090",
    },
    {
        "school": "Rio Plaza Elementary",
        "district": "Rio Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63276005091",
    },
    {
        "school": "Rio Real Elementary",
        "district": "Rio Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63276005092",
    },
    {
        "school": "Rio Rosales",
        "district": "Rio Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63276008667",
    },
    {
        "school": "Rio del Norte",
        "district": "Rio Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63276010453",
    },
    {
        "school": "Santa Clara Elementary",
        "district": "Santa Clara Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63549006057",
    },
    {
        "school": "Apollo High",
        "district": "Simi Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63684006245",
    },
    {
        "school": "Atherwood Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006248",
    },
    {
        "school": "Berylwood Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006250",
    },
    {
        "school": "Big Springs Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006251",
    },
    {
        "school": "Crestview Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006252",
    },
    {
        "school": "Garden Grove Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006253",
    },
    {
        "school": "Hillside Middle",
        "district": "Simi Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006255",
    },
    {
        "school": "Hollow Hills Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006256",
    },
    {
        "school": "Katherine Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006258",
    },
    {
        "school": "Knolls Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006259",
    },
    {
        "school": "Madera Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006261",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006262",
    },
    {
        "school": "Park View Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006263",
    },
    {
        "school": "Royal High",
        "district": "Simi Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006264",
    },
    {
        "school": "Santa Susana Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006265",
    },
    {
        "school": "Simi Valley High",
        "district": "Simi Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006268",
    },
    {
        "school": "Sinaloa Middle",
        "district": "Simi Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006269",
    },
    {
        "school": "Sycamore Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006270",
    },
    {
        "school": "Township Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006271",
    },
    {
        "school": "Valley View Middle",
        "district": "Simi Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006272",
    },
    {
        "school": "Vista Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006273",
    },
    {
        "school": "White Oak Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006275",
    },
    {
        "school": "Santa Susana High",
        "district": "Simi Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684006815",
    },
    {
        "school": "Wood Ranch Elementary",
        "district": "Simi Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63684007927",
    },
    {
        "school": "Monte Vista",
        "district": "Simi Valley Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63684009639",
    },
    {
        "school": "Somis Elementary",
        "district": "Somis Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63714006296",
    },
    {
        "school": "Pacific High",
        "district": "Ventura Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64098001872",
    },
    {
        "school": "El Camino High",
        "district": "Ventura Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64098001880",
    },
    {
        "school": "Anacapa Middle",
        "district": "Ventura Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006743",
    },
    {
        "school": "Balboa Middle",
        "district": "Ventura Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006746",
    },
    {
        "school": "Blanche Reynolds Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006747",
    },
    {
        "school": "Buena High",
        "district": "Ventura Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006748",
    },
    {
        "school": "Cabrillo Middle",
        "district": "Ventura Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006749",
    },
    {
        "school": "De Anza Academy of Technology and the Arts",
        "district": "Ventura Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006750",
    },
    {
        "school": "E. P. Foster Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006751",
    },
    {
        "school": "Elmhurst Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006753",
    },
    {
        "school": "Juanamaria Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006754",
    },
    {
        "school": "Loma Vista Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006755",
    },
    {
        "school": "Montalvo Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006758",
    },
    {
        "school": "Pierpont Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006761",
    },
    {
        "school": "Poinsettia Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006762",
    },
    {
        "school": "Portola Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006763",
    },
    {
        "school": "Academy of Technology & Leadership at Saticoy",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006765",
    },
    {
        "school": "Junipero Serra Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006766",
    },
    {
        "school": "Sheridan Way Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006767",
    },
    {
        "school": "Ventura High",
        "district": "Ventura Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006768",
    },
    {
        "school": "Will Rogers Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098006770",
    },
    {
        "school": "Homestead (Alternative)",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64098007931",
    },
    {
        "school": "Citrus Glen Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098008433",
    },
    {
        "school": "Foothill Technology High",
        "district": "Ventura Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098008668",
    },
    {
        "school": "Sunset Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098008669",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098009004",
    },
    {
        "school": "Mound Elementary",
        "district": "Ventura Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64098009456",
    },
    {
        "school": "Providence",
        "district": "Ventura County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104709258",
    },
    {
        "school": "Ventura County Special Education",
        "district": "Ventura County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104709260",
    },
    {
        "school": "Mountain High",
        "district": "Summerville Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63828010706",
    },
    {
        "school": "Connections Visual and Performing Arts Academy",
        "district": "Summerville Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63828010707",
    },
    {
        "school": "Belleview Elementary",
        "district": "Belleview Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60450000412",
    },
    {
        "school": "Columbia Elementary",
        "district": "Columbia Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60948000962",
    },
    {
        "school": "Curtis Creek Elementary",
        "district": "Curtis Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61032001155",
    },
    {
        "school": "Jamestown Elementary",
        "district": "Jamestown Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61869002272",
    },
    {
        "school": "Sonora Elementary",
        "district": "Sonora Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63723006305",
    },
    {
        "school": "Sonora High",
        "district": "Sonora Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63726006306",
    },
    {
        "school": "Dario Cassina High",
        "district": "Sonora Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63726006307",
    },
    {
        "school": "Theodore Bird High",
        "district": "Sonora Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63726009445",
    },
    {
        "school": "Soulsbyville Elementary",
        "district": "Soulsbyville Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63732006312",
    },
    {
        "school": "Summerville Elementary",
        "district": "Summerville Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63825006451",
    },
    {
        "school": "Summerville High",
        "district": "Summerville Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63828006452",
    },
    {
        "school": "Long Barn High",
        "district": "Summerville Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63828009645",
    },
    {
        "school": "South Fork High",
        "district": "Summerville Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63828010105",
    },
    {
        "school": "Cold Springs High",
        "district": "Summerville Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63828010338",
    },
    {
        "school": "Twain Harte",
        "district": "Twain Harte",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64020007475",
    },
    {
        "school": "Tuolumne County Community/ISP",
        "district": "Tuolumne County Superintendent of Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104601850",
    },
    {
        "school": "Tuolumne County Special Education",
        "district": "Tuolumne County Superintendent of Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104607471",
    },
    {
        "school": "Tioga High",
        "district": "Big Oak Flat-Groveland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113710339",
    },
    {
        "school": "Don Pedro High",
        "district": "Big Oak Flat-Groveland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113710340",
    },
    {
        "school": "Tenaya Elementary",
        "district": "Big Oak Flat-Groveland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113710341",
    },
    {
        "school": "Tehama County ROP",
        "district": "Tehama County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60014611524",
    },
    {
        "school": "Woodson Elementary",
        "district": "Corning Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60978011523",
    },
    {
        "school": "Antelope Elementary",
        "district": "Antelope Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60276000201",
    },
    {
        "school": "Berrendos Middle",
        "district": "Antelope Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60276000202",
    },
    {
        "school": "Maywood Middle",
        "district": "Corning Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60978001040",
    },
    {
        "school": "Olive View Elementary",
        "district": "Corning Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60978001041",
    },
    {
        "school": "West Street Elementary",
        "district": "Corning Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60978001042",
    },
    {
        "school": "Rancho Tehama Elementary",
        "district": "Corning Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60978004178",
    },
    {
        "school": "Columbia Academy",
        "district": "Corning Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60978007459",
    },
    {
        "school": "Centennial Continuation High",
        "district": "Corning Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60981001043",
    },
    {
        "school": "Corning High",
        "district": "Corning Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60981001044",
    },
    {
        "school": "Elkins Elementary",
        "district": "Elkins Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61242001416",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Evergreen Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61317001500",
    },
    {
        "school": "Evergreen Middle",
        "district": "Evergreen Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61317004183",
    },
    {
        "school": "Evergreen Community Day School (5-8)",
        "district": "Evergreen Union",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61317007461",
    },
    {
        "school": "Flournoy Elementary",
        "district": "Flournoy Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61386001564",
    },
    {
        "school": "Gerber Elementary",
        "district": "Gerber Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61509001904",
    },
    {
        "school": "Kirkwood Elementary",
        "district": "Kirkwood Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61986002385",
    },
    {
        "school": "Lassen View Elementary",
        "district": "Lassen View Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62109002533",
    },
    {
        "school": "Los Molinos Elementary",
        "district": "Los Molinos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62286003496",
    },
    {
        "school": "Los Molinos High",
        "district": "Los Molinos Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62286003497",
    },
    {
        "school": "Vina Elementary",
        "district": "Los Molinos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62286003498",
    },
    {
        "school": "Bidwell Elementary",
        "district": "Red Bluff Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63198004920",
    },
    {
        "school": "Jackson Heights Elementary",
        "district": "Red Bluff Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63198004921",
    },
    {
        "school": "Vista Preparatory Academy",
        "district": "Red Bluff Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63198004922",
    },
    {
        "school": "Red Bluff Community Day",
        "district": "Red Bluff Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63198007464",
    },
    {
        "school": "William M. Metteer Elementary",
        "district": "Red Bluff Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63198009181",
    },
    {
        "school": "Red Bluff High",
        "district": "Red Bluff Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63201004923",
    },
    {
        "school": "Salisbury High (Continuation)",
        "district": "Red Bluff Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63201004924",
    },
    {
        "school": "Reeds Creek Elementary",
        "district": "Reeds Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63225004979",
    },
    {
        "school": "Richfield Elementary",
        "district": "Richfield Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63240005000",
    },
    {
        "school": "Tehama County Special Education",
        "district": "Tehama County Department of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104307232",
    },
    {
        "school": "Tehama Oaks High",
        "district": "Tehama County Department of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104309256",
    },
    {
        "school": "Lincoln Street",
        "district": "Tehama County Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69104310442",
    },
    {
        "school": "Shasta-Trinity ROP",
        "district": "Shasta-Trinity ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60012511468",
    },
    {
        "school": "Anderson New Technology High",
        "district": "Anderson Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60270010671",
    },
    {
        "school": "Columbia-East Valley K-6 Community Day",
        "district": "Columbia Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60945011272",
    },
    {
        "school": "Shasta Lake",
        "district": "Gateway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61495011804",
    },
    {
        "school": "North State Independence High",
        "district": "Shasta Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63660010676",
    },
    {
        "school": "Anderson High",
        "district": "Anderson Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60270000196",
    },
    {
        "school": "North Valley High",
        "district": "Anderson Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60270000197",
    },
    {
        "school": "Oakview High (Alternative)",
        "district": "Anderson Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60270005415",
    },
    {
        "school": "Anderson Community Day",
        "district": "Anderson Union High",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60270007439",
    },
    {
        "school": "West Valley High",
        "district": "Anderson Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60270007642",
    },
    {
        "school": "Bella Vista Elementary",
        "district": "Bella Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60435000392",
    },
    {
        "school": "Black Butte Elementary",
        "district": "Black Butte Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60522000493",
    },
    {
        "school": "Black Butte Junior High",
        "district": "Black Butte Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60522007440",
    },
    {
        "school": "Anderson Middle",
        "district": "Cascade Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60768000733",
    },
    {
        "school": "Anderson Heights Elementary",
        "district": "Cascade Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60768000734",
    },
    {
        "school": "Meadow Lane Elementary",
        "district": "Cascade Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60768000735",
    },
    {
        "school": "North State Aspire Academy",
        "district": "Cascade Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60768007441",
    },
    {
        "school": "Castle Rock Elementary",
        "district": "Castle Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60777000739",
    },
    {
        "school": "Columbia Elementary",
        "district": "Columbia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60945000961",
    },
    {
        "school": "Mountain View Middle",
        "district": "Columbia Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60945008635",
    },
    {
        "school": "West Cottonwood Junior High",
        "district": "Cottonwood Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60999001086",
    },
    {
        "school": "Alta Mesa Elementary",
        "district": "Enterprise Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61281001439",
    },
    {
        "school": "Lassen View Elementary",
        "district": "Enterprise Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61281001440",
    },
    {
        "school": "Mistletoe Elementary",
        "district": "Enterprise Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61281001441",
    },
    {
        "school": "Parsons Junior High",
        "district": "Enterprise Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61281001442",
    },
    {
        "school": "Rother Elementary",
        "district": "Enterprise Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61281001443",
    },
    {
        "school": "Shasta Meadows Elementary",
        "district": "Enterprise Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61281001444",
    },
    {
        "school": "Boulder Creek Elementary",
        "district": "Enterprise Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61281002810",
    },
    {
        "school": "Burney Junior-Senior High",
        "district": "Fall River Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61347001533",
    },
    {
        "school": "Burney Elementary",
        "district": "Fall River Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61347001534",
    },
    {
        "school": "Fall River Elementary",
        "district": "Fall River Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61347001535",
    },
    {
        "school": "Fall River Junior-Senior High",
        "district": "Fall River Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61347001536",
    },
    {
        "school": "Mt. Burney Special Education Center",
        "district": "Fall River Joint Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61347001537",
    },
    {
        "school": "Soldier Mountain High (Continuation)",
        "district": "Fall River Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61347007814",
    },
    {
        "school": "Mountain View High (Continuation)",
        "district": "Fall River Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61347008137",
    },
    {
        "school": "Fall River Community Day",
        "district": "Fall River Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61347008371",
    },
    {
        "school": "Burney Community Day",
        "district": "Fall River Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61347008376",
    },
    {
        "school": "Burney Elementary Community Day",
        "district": "Fall River Joint Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61347010417",
    },
    {
        "school": "Fall River Elementary Community Day",
        "district": "Fall River Joint Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61347010418",
    },
    {
        "school": "French Gulch-Whiskeytown Elementary",
        "district": "French Gulch-Whiskeytown Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61449001701",
    },
    {
        "school": "Mountain Lakes High",
        "district": "Gateway Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61495001631",
    },
    {
        "school": "Gateway Educational Options",
        "district": "Gateway Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61495001636",
    },
    {
        "school": "Central Valley High",
        "district": "Gateway Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61495001667",
    },
    {
        "school": "Buckeye School of the Arts",
        "district": "Gateway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61495001682",
    },
    {
        "school": "Grand Oaks Elementary",
        "district": "Gateway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61495002880",
    },
    {
        "school": "Gateway Community Day",
        "district": "Gateway Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61495008638",
    },
    {
        "school": "Grant Elementary",
        "district": "Grant Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61569001980",
    },
    {
        "school": "Happy Valley Elementary",
        "district": "Happy Valley Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61657002089",
    },
    {
        "school": "Happy Valley Primary",
        "district": "Happy Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61657002090",
    },
    {
        "school": "Igo-Ono Elementary",
        "district": "Igo Ono Platina Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61816002238",
    },
    {
        "school": "Indian Springs Elementary",
        "district": "Indian Springs Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61827002246",
    },
    {
        "school": "Junction Elementary",
        "district": "Junction Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61920002308",
    },
    {
        "school": "Millville Elementary",
        "district": "Millville Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62493003723",
    },
    {
        "school": "Montgomery Creek Elementary",
        "district": "Mountain Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62704004078",
    },
    {
        "school": "North Cow Creek Elementary",
        "district": "North Cow Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62751004138",
    },
    {
        "school": "Oak Run Elementary",
        "district": "Oak Run Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62787004227",
    },
    {
        "school": "Pacheco Elementary",
        "district": "Pacheco Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62928004522",
    },
    {
        "school": "Prairie Elementary",
        "district": "Pacheco Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62928004523",
    },
    {
        "school": "Bonny View Elementary",
        "district": "Redding Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63204004925",
    },
    {
        "school": "Cypress Elementary",
        "district": "Redding Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63204004926",
    },
    {
        "school": "Juniper",
        "district": "Redding Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63204004927",
    },
    {
        "school": "Manzanita Elementary",
        "district": "Redding Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63204004928",
    },
    {
        "school": "Sequoia Middle",
        "district": "Redding Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63204004929",
    },
    {
        "school": "Sycamore Elementary",
        "district": "Redding Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63204004930",
    },
    {
        "school": "Redding Community Day",
        "district": "Redding Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63204008385",
    },
    {
        "school": "Turtle Bay",
        "district": "Redding Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63204009182",
    },
    {
        "school": "Shasta Elementary",
        "district": "Shasta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63657006208",
    },
    {
        "school": "Enterprise High",
        "district": "Shasta Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63660006210",
    },
    {
        "school": "Shasta High",
        "district": "Shasta Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63660006213",
    },
    {
        "school": "Freedom High",
        "district": "Shasta Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63660007822",
    },
    {
        "school": "Pioneer Continuation High",
        "district": "Shasta Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63660008637",
    },
    {
        "school": "Foothill High",
        "district": "Shasta Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63660010326",
    },
    {
        "school": "Whitmore Elementary",
        "district": "Whitmore Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64242006935",
    },
    {
        "school": "Shasta County Juvenile Court",
        "district": "Shasta County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103702799",
    },
    {
        "school": "Shasta County Special Education",
        "district": "Shasta County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69103707220",
    },
    {
        "school": "Cottonwood Canyon Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002710587",
    },
    {
        "school": "Canyon Lake Middle",
        "district": "Lake Elsinore Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002710588",
    },
    {
        "school": "Lakeside High",
        "district": "Lake Elsinore Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002711036",
    },
    {
        "school": "Ronald Reagan Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002711037",
    },
    {
        "school": "Susan H. Nelson",
        "district": "Temecula Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60002810589",
    },
    {
        "school": "Great Oak High",
        "district": "Temecula Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002811038",
    },
    {
        "school": "Alamos Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002811039",
    },
    {
        "school": "Bella Vista Middle",
        "district": "Temecula Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002811040",
    },
    {
        "school": "Crowne Hill Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002811041",
    },
    {
        "school": "Susan La Vorgna Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002811042",
    },
    {
        "school": "Tony Tobin Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002811043",
    },
    {
        "school": "French Valley Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002811170",
    },
    {
        "school": "Erle Stanley Gardner Middle",
        "district": "Temecula Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002811187",
    },
    {
        "school": "Warm Springs Middle",
        "district": "Murrieta Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002910590",
    },
    {
        "school": "Antelope Hills Elementary",
        "district": "Murrieta Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002911044",
    },
    {
        "school": "Monte Vista Elementary",
        "district": "Murrieta Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002911239",
    },
    {
        "school": "Murrieta Canyon Academy",
        "district": "Murrieta Valley Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60002911241",
    },
    {
        "school": "Vista Murrieta High",
        "district": "Murrieta Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002911249",
    },
    {
        "school": "Riverside County ROP",
        "district": "Riverside County Office Of Education ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60009411035",
    },
    {
        "school": "Ysmael Villegas Middle",
        "district": "Alvord Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243010578",
    },
    {
        "school": "Three Rings Ranch Elementary",
        "district": "Beaumont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60429010579",
    },
    {
        "school": "Brookside Elementary",
        "district": "Beaumont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60429011012",
    },
    {
        "school": "San Gorgonio Middle",
        "district": "Beaumont Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60429011013",
    },
    {
        "school": "Sundance Elementary",
        "district": "Beaumont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60429011219",
    },
    {
        "school": "Toro Canyon Middle",
        "district": "Coachella Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907011174",
    },
    {
        "school": "Desert Mirage High",
        "district": "Coachella Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907011175",
    },
    {
        "school": "Las Palmitas Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907011176",
    },
    {
        "school": "Corona Ranch Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985010580",
    },
    {
        "school": "Orange Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985010581",
    },
    {
        "school": "Dwight D. Eisenhower Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985011014",
    },
    {
        "school": "Harada Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985011015",
    },
    {
        "school": "Temescal Valley Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985011245",
    },
    {
        "school": "Clara Barton Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985011246",
    },
    {
        "school": "El Cerrito Middle",
        "district": "Corona-Norco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985011247",
    },
    {
        "school": "Orange Grove High",
        "district": "Corona-Norco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60985011708",
    },
    {
        "school": "Benjamin Franklin Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111011016",
    },
    {
        "school": "Carrillo Ranch Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111011017",
    },
    {
        "school": "Dr. Reynaldo J. Carreon Jr. Academy",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111011244",
    },
    {
        "school": "Cawston Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692011018",
    },
    {
        "school": "Diamond Valley Middle",
        "district": "Hemet Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692011019",
    },
    {
        "school": "Hamilton High",
        "district": "Hemet Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692011020",
    },
    {
        "school": "Hamilton Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692011021",
    },
    {
        "school": "Family Tree Learning Center",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61692011022",
    },
    {
        "school": "McSweeny Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692011164",
    },
    {
        "school": "Harmony Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692011261",
    },
    {
        "school": "Bell Mountain Middle",
        "district": "Menifee Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454010582",
    },
    {
        "school": "Freedom Crest Elementary",
        "district": "Menifee Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454011185",
    },
    {
        "school": "Oak Meadows Elementary",
        "district": "Menifee Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454011715",
    },
    {
        "school": "Vista del Lago High",
        "district": "Moreno Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580010583",
    },
    {
        "school": "TownGate Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580011024",
    },
    {
        "school": "Alessandro",
        "district": "Moreno Valley Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62580011025",
    },
    {
        "school": "La Jolla Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580011026",
    },
    {
        "school": "Ramona Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580011027",
    },
    {
        "school": "Chaparral Hills Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580011028",
    },
    {
        "school": "Rio Vista Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955011029",
    },
    {
        "school": "Enchanted Hills Elementary",
        "district": "Perris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63018010584",
    },
    {
        "school": "California Military Institute",
        "district": "Perris Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63021011184",
    },
    {
        "school": "John F. Kennedy Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315010585",
    },
    {
        "school": "Lake Mathews Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315011183",
    },
    {
        "school": "Patricia Beatty Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315012047",
    },
    {
        "school": "Estudillo Elementary",
        "district": "San Jacinto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444011032",
    },
    {
        "school": "Clayton A. Record Jr. Elementary",
        "district": "San Jacinto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444011033",
    },
    {
        "school": "Mountain Heights Academy",
        "district": "San Jacinto Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444011034",
    },
    {
        "school": "Riverside County Community",
        "district": "Riverside County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102610577",
    },
    {
        "school": "Columbia Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113511045",
    },
    {
        "school": "Citrus Hill High",
        "district": "Val Verde Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113511047",
    },
    {
        "school": "Lasselle Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113511048",
    },
    {
        "school": "Avalon Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113511049",
    },
    {
        "school": "Sierra Vista Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113511232",
    },
    {
        "school": "Lakeside Middle",
        "district": "Val Verde Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113511243",
    },
    {
        "school": "Val Verde Student Success Academy",
        "district": "Val Verde Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69113511723",
    },
    {
        "school": "Cypress School of the Arts",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001411119",
    },
    {
        "school": "Vanguard Preparatory",
        "district": "Apple Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001711122",
    },
    {
        "school": "Colton-Redlands-Yucaipa ROP",
        "district": "Colton-Redlands-Yucaipa ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60013011115",
    },
    {
        "school": "Baldy View ROP",
        "district": "Baldy View ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60013111116",
    },
    {
        "school": "San Bernardino County ROP",
        "district": "San Bernardino County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60013211117",
    },
    {
        "school": "Morgan Kincaid Preparatory",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171010603",
    },
    {
        "school": "George Visual and Performing Arts Magnet and Middle",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171011089",
    },
    {
        "school": "Columbia Middle",
        "district": "Adelanto Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171011090",
    },
    {
        "school": "Theodore Vick Elementary",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171011091",
    },
    {
        "school": "Victoria Magathan Elementary",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171011092",
    },
    {
        "school": "Los Osos High",
        "district": "Chaffey Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60816010605",
    },
    {
        "school": "Colony High",
        "district": "Chaffey Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60816010606",
    },
    {
        "school": "Chino Valley Learning Academy",
        "district": "Chino Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60846010607",
    },
    {
        "school": "Edwin Rhodes Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846011309",
    },
    {
        "school": "Michael G. Wickman Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846011325",
    },
    {
        "school": "Liberty Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846011326",
    },
    {
        "school": "Sycamore Hills Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939010608",
    },
    {
        "school": "Grapeland Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296010609",
    },
    {
        "school": "Heritage Intermediate",
        "district": "Etiwanda Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296010610",
    },
    {
        "school": "Etiwanda Colony Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296011094",
    },
    {
        "school": "Day Creek Intermediate",
        "district": "Etiwanda Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296011095",
    },
    {
        "school": "Sierra Lakes Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392010611",
    },
    {
        "school": "Ted Porter Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392010612",
    },
    {
        "school": "Wayne Ruble Middle",
        "district": "Fontana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392011096",
    },
    {
        "school": "Dorothy Grant Innovations Academy",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392011097",
    },
    {
        "school": "Summit High",
        "district": "Fontana Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392011099",
    },
    {
        "school": "Almond Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392011362",
    },
    {
        "school": "Beech Avenue Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392011837",
    },
    {
        "school": "Montera Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847011318",
    },
    {
        "school": "Vista Grande Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847011354",
    },
    {
        "school": "Beattie Middle",
        "district": "Redlands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207011101",
    },
    {
        "school": "Highland Grove Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207011102",
    },
    {
        "school": "Wilmer Amina Carter High",
        "district": "Rialto Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237011103",
    },
    {
        "school": "Cesar E. Chavez Middle",
        "district": "San Bernardino City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417011106",
    },
    {
        "school": "Roger Anton Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417011107",
    },
    {
        "school": "Silver Valley Academy",
        "district": "Silver Valley Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63682010616",
    },
    {
        "school": "University Preparatory",
        "district": "Victor Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697211114",
    },
    {
        "school": "Challenger School of Sports and Fitness",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104011109",
    },
    {
        "school": "Galileo Academy 101",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104011110",
    },
    {
        "school": "Endeavour School of Exploration",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104011111",
    },
    {
        "school": "Green Valley Independent Study",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64356011215",
    },
    {
        "school": "Oak View High School & Education Center",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64356011216",
    },
    {
        "school": "Community School/Independent Alternative Education",
        "district": "San Bernardino County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102911088",
    },
    {
        "school": "Sea View Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907000928",
    },
    {
        "school": "West Shores High",
        "district": "Coachella Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907007685",
    },
    {
        "school": "California School for the Deaf-Riverside",
        "district": "CA Sch for the Deaf-Riverside (State Special Schl)",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60000710348",
    },
    {
        "school": "Tuscany Hills Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002702451",
    },
    {
        "school": "Donald Graham Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002702452",
    },
    {
        "school": "David A. Brown Middle",
        "district": "Lake Elsinore Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002705011",
    },
    {
        "school": "William Collier Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002707605",
    },
    {
        "school": "Ortega High",
        "district": "Lake Elsinore Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60002709488",
    },
    {
        "school": "Elsinore High",
        "district": "Lake Elsinore Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002709489",
    },
    {
        "school": "Elsinore Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002709490",
    },
    {
        "school": "Machado Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002709491",
    },
    {
        "school": "Wildomar Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002709492",
    },
    {
        "school": "Elsinore Middle",
        "district": "Lake Elsinore Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002709493",
    },
    {
        "school": "Terra Cotta Middle",
        "district": "Lake Elsinore Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002709496",
    },
    {
        "school": "Railroad Canyon Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002709497",
    },
    {
        "school": "Withrow Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002709498",
    },
    {
        "school": "Temescal Canyon High",
        "district": "Lake Elsinore Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002710280",
    },
    {
        "school": "Luiseno",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002710281",
    },
    {
        "school": "Rice Canyon Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002710352",
    },
    {
        "school": "Vail Ranch Middle",
        "district": "Temecula Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002803647",
    },
    {
        "school": "Paloma Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002805012",
    },
    {
        "school": "Pauba Valley Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002806276",
    },
    {
        "school": "Chaparral High",
        "district": "Temecula Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002807222",
    },
    {
        "school": "Vintage Hills Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002807223",
    },
    {
        "school": "Helen Hunt Jackson Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002808270",
    },
    {
        "school": "Abby Reinke Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002808271",
    },
    {
        "school": "James L. Day Middle",
        "district": "Temecula Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002808272",
    },
    {
        "school": "Temecula Valley High",
        "district": "Temecula Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002809499",
    },
    {
        "school": "Rancho Vista High",
        "district": "Temecula Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60002809500",
    },
    {
        "school": "Temecula Middle",
        "district": "Temecula Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002809501",
    },
    {
        "school": "Vail Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002809502",
    },
    {
        "school": "Rancho Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002809503",
    },
    {
        "school": "Margarita Middle",
        "district": "Temecula Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002809505",
    },
    {
        "school": "Temecula Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002809506",
    },
    {
        "school": "Nicolas Valley Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002809684",
    },
    {
        "school": "Red Hawk Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002810282",
    },
    {
        "school": "Ysabel Barnett Elementary",
        "district": "Temecula Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002810353",
    },
    {
        "school": "Thompson Middle",
        "district": "Murrieta Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002903649",
    },
    {
        "school": "Tovashal Elementary",
        "district": "Murrieta Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002906282",
    },
    {
        "school": "Cole Canyon Elementary",
        "district": "Murrieta Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002908565",
    },
    {
        "school": "Murrieta Elementary",
        "district": "Murrieta Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002909507",
    },
    {
        "school": "Avaxat Elementary",
        "district": "Murrieta Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002909508",
    },
    {
        "school": "Alta Murrieta Elementary",
        "district": "Murrieta Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002909509",
    },
    {
        "school": "E. Hale Curran Elementary",
        "district": "Murrieta Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002909510",
    },
    {
        "school": "Rail Ranch Elementary",
        "district": "Murrieta Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002909511",
    },
    {
        "school": "Murrieta Valley High",
        "district": "Murrieta Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002909685",
    },
    {
        "school": "Shivela Middle",
        "district": "Murrieta Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002909686",
    },
    {
        "school": "Daniel N. Buchanan Elementary",
        "district": "Murrieta Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002910354",
    },
    {
        "school": "Alvord Continuation High",
        "district": "Alvord Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60243000128",
    },
    {
        "school": "Arizona Middle",
        "district": "Alvord Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000129",
    },
    {
        "school": "Arlanza Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000130",
    },
    {
        "school": "Collett Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000131",
    },
    {
        "school": "Foothill Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000132",
    },
    {
        "school": "La Granada Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000133",
    },
    {
        "school": "La Sierra High",
        "district": "Alvord Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000134",
    },
    {
        "school": "Loma Vista Middle",
        "district": "Alvord Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000135",
    },
    {
        "school": "Myra Linn Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000136",
    },
    {
        "school": "Norte Vista High",
        "district": "Alvord Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000137",
    },
    {
        "school": "Allan Orrenmaa Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000138",
    },
    {
        "school": "Terrace Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000139",
    },
    {
        "school": "Twinhill Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000140",
    },
    {
        "school": "Wells Middle",
        "district": "Alvord Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243000141",
    },
    {
        "school": "Rosemary Kennedy Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243008260",
    },
    {
        "school": "S. Christa McAuliffe Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243008784",
    },
    {
        "school": "Promenade Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243009299",
    },
    {
        "school": "Valley View Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243009514",
    },
    {
        "school": "Banning High",
        "district": "Banning Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60384000347",
    },
    {
        "school": "Central Elementary",
        "district": "Banning Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60384000348",
    },
    {
        "school": "Hemmerling Elementary",
        "district": "Banning Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60384000350",
    },
    {
        "school": "Hoffer Elementary",
        "district": "Banning Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60384000351",
    },
    {
        "school": "New Horizon High",
        "district": "Banning Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60384000352",
    },
    {
        "school": "Nicolet Middle",
        "district": "Banning Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60384003574",
    },
    {
        "school": "Banning Independent Study",
        "district": "Banning Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60384008555",
    },
    {
        "school": "Cabazon Elementary",
        "district": "Banning Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60384009305",
    },
    {
        "school": "Beaumont Senior High",
        "district": "Beaumont Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60429000386",
    },
    {
        "school": "Mountain View Middle",
        "district": "Beaumont Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60429000387",
    },
    {
        "school": "Palm Innovation Academy",
        "district": "Beaumont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60429000388",
    },
    {
        "school": "Glen View High",
        "district": "Beaumont Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60429008261",
    },
    {
        "school": "Coachella Valley High",
        "district": "Coachella Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907000920",
    },
    {
        "school": "Valle del Sol Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907000921",
    },
    {
        "school": "John Kelley Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907000922",
    },
    {
        "school": "La Familia Continuation High",
        "district": "Coachella Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60907000923",
    },
    {
        "school": "Mecca Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907000924",
    },
    {
        "school": "Oasis Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907000925",
    },
    {
        "school": "Palm View Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907000926",
    },
    {
        "school": "Peter Pendleton Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907000927",
    },
    {
        "school": "Valley View Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907000929",
    },
    {
        "school": "Westside Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907000930",
    },
    {
        "school": "Cahuilla Desert Academy Junior High",
        "district": "Coachella Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907005008",
    },
    {
        "school": "Saul Martinez Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907007604",
    },
    {
        "school": "Mountain Vista Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907008563",
    },
    {
        "school": "Cesar Chavez Elementary",
        "district": "Coachella Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907009764",
    },
    {
        "school": "Lee V. Pollard High",
        "district": "Corona-Norco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60985000853",
    },
    {
        "school": "Corona Vista High",
        "district": "Corona-Norco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60985000905",
    },
    {
        "school": "William McKinley Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985000932",
    },
    {
        "school": "John Adams Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001045",
    },
    {
        "school": "Auburndale Intermediate",
        "district": "Corona-Norco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001046",
    },
    {
        "school": "Corona-Norco Alternative",
        "district": "Corona-Norco Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60985001047",
    },
    {
        "school": "Corona Fundamental Intermediate",
        "district": "Corona-Norco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001048",
    },
    {
        "school": "Corona High",
        "district": "Corona-Norco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001049",
    },
    {
        "school": "Coronita Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001050",
    },
    {
        "school": "Garretson Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001053",
    },
    {
        "school": "Highland Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001054",
    },
    {
        "school": "Home Gardens Academy",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001055",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001057",
    },
    {
        "school": "Lincoln Fundamental Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001058",
    },
    {
        "school": "Norco Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001059",
    },
    {
        "school": "Norco Intermediate",
        "district": "Corona-Norco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001060",
    },
    {
        "school": "Norco High",
        "district": "Corona-Norco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001061",
    },
    {
        "school": "Parkridge Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001062",
    },
    {
        "school": "Letha Raney Intermediate",
        "district": "Corona-Norco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001063",
    },
    {
        "school": "Riverview Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001064",
    },
    {
        "school": "Sierra Vista Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001065",
    },
    {
        "school": "John Stallings Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001066",
    },
    {
        "school": "Vicentia Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001067",
    },
    {
        "school": "Victress Bower School for Exceptional Students",
        "district": "Corona-Norco Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60985001068",
    },
    {
        "school": "George Washington Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985001069",
    },
    {
        "school": "Santiago High",
        "district": "Corona-Norco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985004959",
    },
    {
        "school": "Susan B. Anthony Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985004978",
    },
    {
        "school": "Cesar Chavez Academy",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985007209",
    },
    {
        "school": "Benjamin Franklin Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985008262",
    },
    {
        "school": "Citrus Hills Intermediate",
        "district": "Corona-Norco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985008263",
    },
    {
        "school": "Woodrow Wilson Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985008559",
    },
    {
        "school": "Foothill Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985009354",
    },
    {
        "school": "Prado View Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985009355",
    },
    {
        "school": "Centennial High",
        "district": "Corona-Norco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985009532",
    },
    {
        "school": "Eagle Mountain Elementary",
        "district": "Desert Center Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61110001221",
    },
    {
        "school": "Herbert Hoover Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111001225",
    },
    {
        "school": "Indio High",
        "district": "Desert Sands Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111001226",
    },
    {
        "school": "Andrew Jackson Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111001227",
    },
    {
        "school": "Thomas Jefferson Middle",
        "district": "Desert Sands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111001228",
    },
    {
        "school": "John F. Kennedy Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111001229",
    },
    {
        "school": "Abraham Lincoln Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111001230",
    },
    {
        "school": "Palm Desert Charter Middle",
        "district": "Desert Sands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111001231",
    },
    {
        "school": "Theodore Roosevelt Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111001232",
    },
    {
        "school": "Martin Van Buren Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111001233",
    },
    {
        "school": "George Washington Charter",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111001234",
    },
    {
        "school": "La Quinta High",
        "district": "Desert Sands Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111003582",
    },
    {
        "school": "James Earl Carter Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111006219",
    },
    {
        "school": "Amistad High (Continuation)",
        "district": "Desert Sands Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61111007694",
    },
    {
        "school": "Lyndon B. Johnson Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111008264",
    },
    {
        "school": "Horizon",
        "district": "Desert Sands Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61111008560",
    },
    {
        "school": "John Glenn Middle School of International Studies",
        "district": "Desert Sands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111008765",
    },
    {
        "school": "Amelia Earhart Elementary School of International Studies",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111008766",
    },
    {
        "school": "Palm Desert High",
        "district": "Desert Sands Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111008819",
    },
    {
        "school": "Harry S. Truman Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111008820",
    },
    {
        "school": "La Quinta Middle",
        "district": "Desert Sands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111009358",
    },
    {
        "school": "James Madison Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111009785",
    },
    {
        "school": "James Monroe Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111009786",
    },
    {
        "school": "Gerald R. Ford Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111010274",
    },
    {
        "school": "Indio Middle",
        "district": "Desert Sands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111010275",
    },
    {
        "school": "Bautista Creek Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692000943",
    },
    {
        "school": "Acacia Middle",
        "district": "Hemet Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692002148",
    },
    {
        "school": "Alessandro High",
        "district": "Hemet Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61692002149",
    },
    {
        "school": "Cottonwood Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692002150",
    },
    {
        "school": "Hemet High",
        "district": "Hemet Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692002154",
    },
    {
        "school": "Idyllwild Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692002155",
    },
    {
        "school": "Little Lake Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692002156",
    },
    {
        "school": "Ramona Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692002157",
    },
    {
        "school": "Whittier Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692002158",
    },
    {
        "school": "Winchester Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692002159",
    },
    {
        "school": "Dartmouth Middle",
        "district": "Hemet Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692003586",
    },
    {
        "school": "Valle Vista Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692009144",
    },
    {
        "school": "Helen Hunt Jackson College Prep High",
        "district": "Hemet Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61692009555",
    },
    {
        "school": "West Valley High",
        "district": "Hemet Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692009852",
    },
    {
        "school": "Fruitvale Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692010276",
    },
    {
        "school": "Jacob Wiens Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692010349",
    },
    {
        "school": "Granite Hill Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926000992",
    },
    {
        "school": "Glen Avon Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002310",
    },
    {
        "school": "Ina Arbuckle Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002311",
    },
    {
        "school": "Jurupa Middle",
        "district": "Jurupa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002312",
    },
    {
        "school": "Mission Bell Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002313",
    },
    {
        "school": "Mission Middle",
        "district": "Jurupa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002314",
    },
    {
        "school": "Nueva Vista Continuation High",
        "district": "Jurupa Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61926002315",
    },
    {
        "school": "Pacific Avenue Academy of Music",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002316",
    },
    {
        "school": "Pedley Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002317",
    },
    {
        "school": "Rubidoux High",
        "district": "Jurupa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002318",
    },
    {
        "school": "Rustic Lane Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002319",
    },
    {
        "school": "Troth Street Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002320",
    },
    {
        "school": "Van Buren Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002321",
    },
    {
        "school": "West Riverside Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002322",
    },
    {
        "school": "Stone Avenue Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926002418",
    },
    {
        "school": "Mira Loma Middle",
        "district": "Jurupa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926004980",
    },
    {
        "school": "Peralta Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926006247",
    },
    {
        "school": "Sky Country Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926008149",
    },
    {
        "school": "Indian Hills Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926008860",
    },
    {
        "school": "Camino Real Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926009380",
    },
    {
        "school": "Sunnyslope Elementary",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926009381",
    },
    {
        "school": "Jurupa Valley High",
        "district": "Jurupa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926009556",
    },
    {
        "school": "Callie Kirkpatrick Elementary",
        "district": "Menifee Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454000997",
    },
    {
        "school": "Ridgemoor Elementary",
        "district": "Menifee Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454007212",
    },
    {
        "school": "Menifee Valley Middle",
        "district": "Menifee Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454009402",
    },
    {
        "school": "Chester W. Morrison Elementary",
        "district": "Menifee Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454009580",
    },
    {
        "school": "Seneca Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580001009",
    },
    {
        "school": "Moreno Valley Community Learning Center",
        "district": "Moreno Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580003589",
    },
    {
        "school": "Armada Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580003863",
    },
    {
        "school": "Edgemont Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580003865",
    },
    {
        "school": "Midland Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580003866",
    },
    {
        "school": "Moreno Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580003867",
    },
    {
        "school": "March Mountain High",
        "district": "Moreno Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62580003868",
    },
    {
        "school": "Moreno Valley High",
        "district": "Moreno Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580003869",
    },
    {
        "school": "Sunnymead Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580003870",
    },
    {
        "school": "Bayside Community Day",
        "district": "Moreno Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62580007213",
    },
    {
        "school": "Sunnymeadows Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580008167",
    },
    {
        "school": "March Valley",
        "district": "Moreno Valley Unified",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62580008561",
    },
    {
        "school": "Canyon Springs High",
        "district": "Moreno Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580008906",
    },
    {
        "school": "Butterfield Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580008907",
    },
    {
        "school": "Honey Hollow Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580008908",
    },
    {
        "school": "Serrano Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580008909",
    },
    {
        "school": "Sugar Hill Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580008910",
    },
    {
        "school": "Vista Heights Middle",
        "district": "Moreno Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009159",
    },
    {
        "school": "Creekside Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009160",
    },
    {
        "school": "Cloverdale Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009162",
    },
    {
        "school": "Valley View High",
        "district": "Moreno Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009404",
    },
    {
        "school": "Mountain View Middle",
        "district": "Moreno Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009405",
    },
    {
        "school": "Bear Valley Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009582",
    },
    {
        "school": "Badger Springs Middle",
        "district": "Moreno Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009583",
    },
    {
        "school": "Sunnymead Middle",
        "district": "Moreno Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009585",
    },
    {
        "school": "Box Springs Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009586",
    },
    {
        "school": "Hendrick Ranch Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009587",
    },
    {
        "school": "Hidden Springs Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009588",
    },
    {
        "school": "North Ridge Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009934",
    },
    {
        "school": "Ridge Crest Elementary",
        "district": "Moreno Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580009935",
    },
    {
        "school": "Landmark Middle",
        "district": "Moreno Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580010277",
    },
    {
        "school": "Palm Middle",
        "district": "Moreno Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580010278",
    },
    {
        "school": "Valley View Elementary",
        "district": "Nuview Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62778002426",
    },
    {
        "school": "Nuview Elementary",
        "district": "Nuview Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62778004202",
    },
    {
        "school": "Mountain Shadows Middle",
        "district": "Nuview Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62778009962",
    },
    {
        "school": "Nuview Bridge Early College High",
        "district": "Nuview Union",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62778010350",
    },
    {
        "school": "Bubbling Wells Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955001025",
    },
    {
        "school": "Agua Caliente Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004559",
    },
    {
        "school": "Cahuilla Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004560",
    },
    {
        "school": "Cathedral City Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004561",
    },
    {
        "school": "Cielo Vista Charter",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004562",
    },
    {
        "school": "Nellie N. Coffman Middle",
        "district": "Palm Springs Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004563",
    },
    {
        "school": "Raymond Cree Middle",
        "district": "Palm Springs Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004564",
    },
    {
        "school": "Bella Vista Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004565",
    },
    {
        "school": "Katherine Finchy Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004567",
    },
    {
        "school": "Palm Springs High",
        "district": "Palm Springs Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004569",
    },
    {
        "school": "Rancho Mirage Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004570",
    },
    {
        "school": "Vista del Monte Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004571",
    },
    {
        "school": "James Workman Middle",
        "district": "Palm Springs Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955004981",
    },
    {
        "school": "Two Bunch Palms Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955007602",
    },
    {
        "school": "Julius Corsini Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955007810",
    },
    {
        "school": "Desert Hot Springs High",
        "district": "Palm Springs Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955008267",
    },
    {
        "school": "Mt. San Jacinto High",
        "district": "Palm Springs Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62955008931",
    },
    {
        "school": "Della S. Lindley Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955008932",
    },
    {
        "school": "Landau Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955009420",
    },
    {
        "school": "Desert Springs Middle",
        "district": "Palm Springs Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955009602",
    },
    {
        "school": "Sunny Sands Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955009603",
    },
    {
        "school": "Cathedral City High",
        "district": "Palm Springs Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955010279",
    },
    {
        "school": "Felix J. Appleby Elementary",
        "district": "Palo Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62964004599",
    },
    {
        "school": "Ruth Brown Elementary",
        "district": "Palo Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62964004601",
    },
    {
        "school": "Palo Verde High",
        "district": "Palo Verde Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62964004602",
    },
    {
        "school": "Twin Palms Continuation",
        "district": "Palo Verde Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62964004603",
    },
    {
        "school": "Margaret White Elementary",
        "district": "Palo Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62964004604",
    },
    {
        "school": "Palms Elementary",
        "district": "Perris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63018003601",
    },
    {
        "school": "Good Hope Elementary",
        "district": "Perris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63018004710",
    },
    {
        "school": "Perris Elementary",
        "district": "Perris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63018004711",
    },
    {
        "school": "Innovative Horizons Charter",
        "district": "Perris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63018008940",
    },
    {
        "school": "Perris High",
        "district": "Perris Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63021004712",
    },
    {
        "school": "Perris Lake High (Continuation)",
        "district": "Perris Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63021004713",
    },
    {
        "school": "Paloma Valley High",
        "district": "Perris Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63021004992",
    },
    {
        "school": "Pinacate Middle",
        "district": "Perris Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63021009176",
    },
    {
        "school": "Raincross High (Continuation)",
        "district": "Riverside Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63315003613",
    },
    {
        "school": "Amelia Earhart Middle",
        "district": "Riverside Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005006",
    },
    {
        "school": "Tomas Rivera Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005007",
    },
    {
        "school": "Adams Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005129",
    },
    {
        "school": "Alcott Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005130",
    },
    {
        "school": "Arlington High",
        "district": "Riverside Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005131",
    },
    {
        "school": "Bryant Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005132",
    },
    {
        "school": "Castle View Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005133",
    },
    {
        "school": "Central Middle",
        "district": "Riverside Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005134",
    },
    {
        "school": "Chemawa Middle",
        "district": "Riverside Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005135",
    },
    {
        "school": "Emerson Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005136",
    },
    {
        "school": "Fremont Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005137",
    },
    {
        "school": "Matthew Gage Middle",
        "district": "Riverside Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005138",
    },
    {
        "school": "Harrison Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005140",
    },
    {
        "school": "Hawthorne Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005141",
    },
    {
        "school": "Highgrove Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005142",
    },
    {
        "school": "Highland Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005143",
    },
    {
        "school": "Jackson Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005145",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005146",
    },
    {
        "school": "Liberty Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005147",
    },
    {
        "school": "Abraham Lincoln Continuation",
        "district": "Riverside Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63315005148",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005149",
    },
    {
        "school": "Madison Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005150",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005151",
    },
    {
        "school": "Monroe Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005152",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005153",
    },
    {
        "school": "John W. North High",
        "district": "Riverside Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005154",
    },
    {
        "school": "Pachappa Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005155",
    },
    {
        "school": "Polytechnic High",
        "district": "Riverside Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005156",
    },
    {
        "school": "Ramona High",
        "district": "Riverside Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005157",
    },
    {
        "school": "Sierra Middle",
        "district": "Riverside Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005158",
    },
    {
        "school": "Sunshine Special Education",
        "district": "Riverside Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63315005159",
    },
    {
        "school": "University Heights Middle",
        "district": "Riverside Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005160",
    },
    {
        "school": "Victoria Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005161",
    },
    {
        "school": "Washington Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005162",
    },
    {
        "school": "Woodcrest Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315005163",
    },
    {
        "school": "Summit View Independent Study",
        "district": "Riverside Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63315008183",
    },
    {
        "school": "Martin Luther King Jr. High",
        "district": "Riverside Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315008268",
    },
    {
        "school": "William Howard Taft Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315009624",
    },
    {
        "school": "Opportunity Program",
        "district": "Riverside Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63315010029",
    },
    {
        "school": "Benjamin Franklin Elementary",
        "district": "Riverside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315010030",
    },
    {
        "school": "Romoland Elementary",
        "district": "Romoland Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63339005173",
    },
    {
        "school": "Harvest Valley Elementary",
        "district": "Romoland Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63339010032",
    },
    {
        "school": "Monte Vista Middle",
        "district": "San Jacinto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444005691",
    },
    {
        "school": "Mountain View High",
        "district": "San Jacinto Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63444005692",
    },
    {
        "school": "San Jacinto Elementary",
        "district": "San Jacinto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444005693",
    },
    {
        "school": "San Jacinto High",
        "district": "San Jacinto Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444005694",
    },
    {
        "school": "North Mountain Middle",
        "district": "San Jacinto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444007603",
    },
    {
        "school": "De Anza Elementary",
        "district": "San Jacinto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444009190",
    },
    {
        "school": "Park Hill Elementary",
        "district": "San Jacinto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444010060",
    },
    {
        "school": "Riverside County Juvenile Court",
        "district": "Riverside County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102607567",
    },
    {
        "school": "Riverside County Special Education",
        "district": "Riverside County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102609031",
    },
    {
        "school": "Vista Verde Middle",
        "district": "Val Verde Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113501028",
    },
    {
        "school": "Tomas Rivera Middle",
        "district": "Val Verde Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113502468",
    },
    {
        "school": "Manuel L. Real Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113507224",
    },
    {
        "school": "Rancho Verde High",
        "district": "Val Verde Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113510283",
    },
    {
        "school": "Val Verde High",
        "district": "Val Verde Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69113510284",
    },
    {
        "school": "Mead Valley Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113510285",
    },
    {
        "school": "Val Verde Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113510286",
    },
    {
        "school": "Rainbow Ridge Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113510287",
    },
    {
        "school": "Victoriano Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113510288",
    },
    {
        "school": "Mary McLeod Bethune Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113510290",
    },
    {
        "school": "Topaz Preparatory Academy",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001403904",
    },
    {
        "school": "Sultana High",
        "district": "Hesperia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001405093",
    },
    {
        "school": "Shadow Ridge",
        "district": "Hesperia Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60001407287",
    },
    {
        "school": "Mesquite Trails Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001407295",
    },
    {
        "school": "Hesperia Community Day",
        "district": "Hesperia Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60001408296",
    },
    {
        "school": "Hesperia High",
        "district": "Hesperia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409072",
    },
    {
        "school": "Mojave High",
        "district": "Hesperia Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60001409073",
    },
    {
        "school": "Joshua Circle Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409074",
    },
    {
        "school": "Juniper Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409075",
    },
    {
        "school": "Eucalyptus Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409076",
    },
    {
        "school": "Hesperia Junior High",
        "district": "Hesperia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409077",
    },
    {
        "school": "Mesa Grande Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409078",
    },
    {
        "school": "Kingston Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409079",
    },
    {
        "school": "Maple Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409080",
    },
    {
        "school": "Cottonwood Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409081",
    },
    {
        "school": "Lime Street Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409082",
    },
    {
        "school": "Hollyvale Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409476",
    },
    {
        "school": "Carmel Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409477",
    },
    {
        "school": "Ranchero Middle",
        "district": "Hesperia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001409676",
    },
    {
        "school": "Mountain View High",
        "district": "Lucerne Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60001503907",
    },
    {
        "school": "Lucerne Valley Elementary",
        "district": "Lucerne Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001509083",
    },
    {
        "school": "Lucerne Valley Middle",
        "district": "Lucerne Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001509084",
    },
    {
        "school": "Lucerne Valley High",
        "district": "Lucerne Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001510305",
    },
    {
        "school": "Hillside High",
        "district": "Upland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60001609085",
    },
    {
        "school": "Upland High",
        "district": "Upland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609086",
    },
    {
        "school": "Baldy View Elementary",
        "district": "Upland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609087",
    },
    {
        "school": "Cabrillo Elementary",
        "district": "Upland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609088",
    },
    {
        "school": "Citrus Elementary",
        "district": "Upland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609089",
    },
    {
        "school": "Foothill Knolls Academy of Innovation",
        "district": "Upland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609090",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Upland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609091",
    },
    {
        "school": "Pioneer Junior High",
        "district": "Upland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609092",
    },
    {
        "school": "Sierra Vista Elementary",
        "district": "Upland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609093",
    },
    {
        "school": "Sycamore Elementary",
        "district": "Upland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609094",
    },
    {
        "school": "Upland Elementary",
        "district": "Upland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609095",
    },
    {
        "school": "Upland Junior High",
        "district": "Upland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609096",
    },
    {
        "school": "Valencia Elementary",
        "district": "Upland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609097",
    },
    {
        "school": "Pepper Tree Elementary",
        "district": "Upland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001609678",
    },
    {
        "school": "Rio Vista School of Applied Learning",
        "district": "Apple Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001701149",
    },
    {
        "school": "Sycamore Rocks Elementary",
        "district": "Apple Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001705167",
    },
    {
        "school": "Granite Hills High",
        "district": "Apple Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001708297",
    },
    {
        "school": "High Desert Premier Academy",
        "district": "Apple Valley Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60001708588",
    },
    {
        "school": "Apple Valley High",
        "district": "Apple Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001709098",
    },
    {
        "school": "Mariana Academy",
        "district": "Apple Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001709100",
    },
    {
        "school": "Rancho Verde Elementary",
        "district": "Apple Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001709101",
    },
    {
        "school": "Yucca Loma Elementary",
        "district": "Apple Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001709102",
    },
    {
        "school": "Desert Knolls Elementary",
        "district": "Apple Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001709103",
    },
    {
        "school": "Sandia Elementary",
        "district": "Apple Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001709272",
    },
    {
        "school": "Adelanto Elementary",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171000038",
    },
    {
        "school": "Donald F. Bradach Elementary",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171007613",
    },
    {
        "school": "Mesa Linda Middle",
        "district": "Adelanto Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171008288",
    },
    {
        "school": "Westside Park Elementary",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171009110",
    },
    {
        "school": "Eagle Ranch Elementary",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171009690",
    },
    {
        "school": "Alta Loma Elementary",
        "district": "Alta Loma Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216000093",
    },
    {
        "school": "Alta Loma Junior High",
        "district": "Alta Loma Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216000094",
    },
    {
        "school": "Carnelian Elementary",
        "district": "Alta Loma Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216000095",
    },
    {
        "school": "Jasper Elementary",
        "district": "Alta Loma Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216000096",
    },
    {
        "school": "Floyd M. Stork Elementary",
        "district": "Alta Loma Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216000097",
    },
    {
        "school": "Banyan Elementary",
        "district": "Alta Loma Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216007259",
    },
    {
        "school": "Deer Canyon Elementary",
        "district": "Alta Loma Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216007640",
    },
    {
        "school": "Hermosa Elementary",
        "district": "Alta Loma Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216008114",
    },
    {
        "school": "Victoria Groves Elementary",
        "district": "Alta Loma Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216009298",
    },
    {
        "school": "Vineyard Junior High",
        "district": "Alta Loma Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216009697",
    },
    {
        "school": "Baker Elementary",
        "district": "Baker Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60361000286",
    },
    {
        "school": "Baker High",
        "district": "Baker Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60361000287",
    },
    {
        "school": "Baker Junior High",
        "district": "Baker Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60361010304",
    },
    {
        "school": "Barstow High",
        "district": "Barstow Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60402000355",
    },
    {
        "school": "Barstow Junior High",
        "district": "Barstow Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60402000356",
    },
    {
        "school": "Cameron Elementary",
        "district": "Barstow Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60402000357",
    },
    {
        "school": "Central High (Continuation)",
        "district": "Barstow Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60402000358",
    },
    {
        "school": "Crestline Elementary",
        "district": "Barstow Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60402000359",
    },
    {
        "school": "Henderson Elementary",
        "district": "Barstow Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60402000360",
    },
    {
        "school": "Lenwood Elementary",
        "district": "Barstow Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60402000363",
    },
    {
        "school": "Montara Elementary",
        "district": "Barstow Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60402000364",
    },
    {
        "school": "Skyline North Elementary",
        "district": "Barstow Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60402000365",
    },
    {
        "school": "Big Bear High",
        "district": "Bear Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60423000381",
    },
    {
        "school": "Big Bear Middle",
        "district": "Bear Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60423000382",
    },
    {
        "school": "Fallsvale",
        "district": "Bear Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60423000383",
    },
    {
        "school": "North Shore Elementary",
        "district": "Bear Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60423000384",
    },
    {
        "school": "Baldwin Lane Elementary",
        "district": "Bear Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60423005028",
    },
    {
        "school": "Chautauqua High (Continuation)",
        "district": "Bear Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60423007264",
    },
    {
        "school": "Big Bear Elementary",
        "district": "Bear Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60423008796",
    },
    {
        "school": "Central Elementary",
        "district": "Central Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60795000761",
    },
    {
        "school": "Cucamonga Middle",
        "district": "Central Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60795000762",
    },
    {
        "school": "Dona Merced Elementary",
        "district": "Central Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60795000763",
    },
    {
        "school": "Valle Vista Elementary",
        "district": "Central Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60795000764",
    },
    {
        "school": "Ruth Musser Middle",
        "district": "Central Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60795001117",
    },
    {
        "school": "Bear Gulch Elementary",
        "district": "Central Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60795008124",
    },
    {
        "school": "Coyote Canyon Elementary",
        "district": "Central Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60795009122",
    },
    {
        "school": "Alta Loma High",
        "district": "Chaffey Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60816000790",
    },
    {
        "school": "Chaffey High",
        "district": "Chaffey Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60816000791",
    },
    {
        "school": "Montclair High",
        "district": "Chaffey Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60816000793",
    },
    {
        "school": "Ontario High",
        "district": "Chaffey Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60816000795",
    },
    {
        "school": "Valley View High (Continuation)",
        "district": "Chaffey Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60816000797",
    },
    {
        "school": "Rancho Cucamonga High",
        "district": "Chaffey Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60816001122",
    },
    {
        "school": "Chaffey Community Day",
        "district": "Chaffey Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60816007260",
    },
    {
        "school": "Etiwanda High",
        "district": "Chaffey Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60816008807",
    },
    {
        "school": "Boys Republic High",
        "district": "Chino Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60846000832",
    },
    {
        "school": "Buena Vista Continuation High",
        "district": "Chino Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60846000833",
    },
    {
        "school": "Anna A. Borba Fundamental Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846000834",
    },
    {
        "school": "Chino High",
        "district": "Chino Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846000835",
    },
    {
        "school": "Alicia Cortez Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846000836",
    },
    {
        "school": "Dickson Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846000837",
    },
    {
        "school": "Don Antonio Lugo High",
        "district": "Chino Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846000838",
    },
    {
        "school": "Glenmeade Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846000841",
    },
    {
        "school": "Magnolia Junior High",
        "district": "Chino Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846000843",
    },
    {
        "school": "E. J. Marshall Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846000844",
    },
    {
        "school": "Newman Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846000845",
    },
    {
        "school": "Ramona Junior High",
        "district": "Chino Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846000846",
    },
    {
        "school": "Walnut Avenue Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846000847",
    },
    {
        "school": "Woodcrest Junior High",
        "district": "Chino Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846002585",
    },
    {
        "school": "Country Springs Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846003822",
    },
    {
        "school": "Hidden Trails Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846005036",
    },
    {
        "school": "Lyle S. Briggs Fundamental",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846007676",
    },
    {
        "school": "Levi H. Dickey Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846007677",
    },
    {
        "school": "Robert O. Townsend Junior High",
        "district": "Chino Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846008808",
    },
    {
        "school": "Gerald F. Litel Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846009124",
    },
    {
        "school": "Eagle Canyon Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846009125",
    },
    {
        "school": "Oak Ridge Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846009348",
    },
    {
        "school": "Howard Cattle Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846009349",
    },
    {
        "school": "Rolling Ridge Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846009527",
    },
    {
        "school": "Butterfield Ranch Elementary",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846009528",
    },
    {
        "school": "Ruben S. Ayala High",
        "district": "Chino Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846009757",
    },
    {
        "school": "Canyon Hills Junior High",
        "district": "Chino Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846010299",
    },
    {
        "school": "Chino Hills High",
        "district": "Chino Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846010360",
    },
    {
        "school": "Bloomington High",
        "district": "Colton Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000944",
    },
    {
        "school": "Joe Baca",
        "district": "Colton Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000945",
    },
    {
        "school": "Colton High",
        "district": "Colton Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000946",
    },
    {
        "school": "Colton Middle",
        "district": "Colton Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000947",
    },
    {
        "school": "Crestmore Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000948",
    },
    {
        "school": "Grand Terrace Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000949",
    },
    {
        "school": "Ulysses Grant Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000950",
    },
    {
        "school": "Abraham Lincoln Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000951",
    },
    {
        "school": "Mary B. Lewis Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000952",
    },
    {
        "school": "William McKinley Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000953",
    },
    {
        "school": "Paul Rogers Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000954",
    },
    {
        "school": "Ruth Grimes Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000955",
    },
    {
        "school": "Slover Mountain High (Continuation)",
        "district": "Colton Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60939000956",
    },
    {
        "school": "Terrace Hills Middle",
        "district": "Colton Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000957",
    },
    {
        "school": "Terrace View Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000958",
    },
    {
        "school": "Walter Zimmerman Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000959",
    },
    {
        "school": "Woodrow Wilson Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939000960",
    },
    {
        "school": "Ruth O. Harris Middle",
        "district": "Colton Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939002599",
    },
    {
        "school": "Michael D'Arcy Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939006353",
    },
    {
        "school": "Alice Birney Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939007687",
    },
    {
        "school": "Washington High",
        "district": "Colton Joint Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60939008126",
    },
    {
        "school": "Gerald A. Smith Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939008127",
    },
    {
        "school": "Reche Canyon Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939009352",
    },
    {
        "school": "Jurupa Vista Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939009767",
    },
    {
        "school": "Cooley Ranch Elementary",
        "district": "Colton Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939010300",
    },
    {
        "school": "Etiwanda Intermediate",
        "district": "Etiwanda Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296001471",
    },
    {
        "school": "Summit Intermediate",
        "district": "Etiwanda Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296001472",
    },
    {
        "school": "Carleton P. Lightfoot Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296003826",
    },
    {
        "school": "Terra Vista Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296003831",
    },
    {
        "school": "East Heritage Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296003846",
    },
    {
        "school": "David W. Long Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296008289",
    },
    {
        "school": "Cecilia Lucero Solorio Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296008585",
    },
    {
        "school": "Windrows Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296009133",
    },
    {
        "school": "Caryn Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296009365",
    },
    {
        "school": "West Heritage Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296009540",
    },
    {
        "school": "John L. Golden Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296010361",
    },
    {
        "school": "Canyon Crest Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001123",
    },
    {
        "school": "Mango Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001124",
    },
    {
        "school": "Alder Middle",
        "district": "Fontana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001585",
    },
    {
        "school": "Eric Birch High (Continuation)",
        "district": "Fontana Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61392001586",
    },
    {
        "school": "Cypress Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001587",
    },
    {
        "school": "Fontana High",
        "district": "Fontana Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001589",
    },
    {
        "school": "Fontana Middle",
        "district": "Fontana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001590",
    },
    {
        "school": "Juniper Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001591",
    },
    {
        "school": "Live Oak Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001593",
    },
    {
        "school": "Maple Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001594",
    },
    {
        "school": "North Tamarind Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001595",
    },
    {
        "school": "Oleander Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001596",
    },
    {
        "school": "Palmetto Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001597",
    },
    {
        "school": "Poplar Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001598",
    },
    {
        "school": "Randall Pepper Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001600",
    },
    {
        "school": "Redwood Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001601",
    },
    {
        "school": "Sequoia Middle",
        "district": "Fontana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001602",
    },
    {
        "school": "South Tamarind Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001603",
    },
    {
        "school": "West Randall Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392001604",
    },
    {
        "school": "Hemlock Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392002600",
    },
    {
        "school": "Harry S. Truman Middle",
        "district": "Fontana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392006402",
    },
    {
        "school": "Date Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392007265",
    },
    {
        "school": "Tokay Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392007718",
    },
    {
        "school": "Henry J. Kaiser High",
        "district": "Fontana Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392008290",
    },
    {
        "school": "Citrus Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392008291",
    },
    {
        "school": "Locust Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392009136",
    },
    {
        "school": "Southridge Tech Middle",
        "district": "Fontana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392009137",
    },
    {
        "school": "Citrus High (Continuation)",
        "district": "Fontana Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61392009367",
    },
    {
        "school": "Virginia Primrose Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392009543",
    },
    {
        "school": "Almeria Middle",
        "district": "Fontana Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392009544",
    },
    {
        "school": "Oak Park Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392009545",
    },
    {
        "school": "Shadow Hills Elementary",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392009546",
    },
    {
        "school": "Fontana A. B. Miller High",
        "district": "Fontana Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392010301",
    },
    {
        "school": "Chaparral Academy of Technology",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392010362",
    },
    {
        "school": "Cucamonga Elementary",
        "district": "Cucamonga Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61630001110",
    },
    {
        "school": "Los Amigos Elementary",
        "district": "Cucamonga Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61630001111",
    },
    {
        "school": "Rancho Cucamonga Middle",
        "district": "Cucamonga Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61630001112",
    },
    {
        "school": "Ontario Center",
        "district": "Cucamonga Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61630009841",
    },
    {
        "school": "Helendale Elementary",
        "district": "Helendale Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61686002146",
    },
    {
        "school": "Riverview Middle",
        "district": "Helendale Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61686009376",
    },
    {
        "school": "Joshua Tree Elementary",
        "district": "Morongo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586003885",
    },
    {
        "school": "Morongo Valley Elementary",
        "district": "Morongo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586003887",
    },
    {
        "school": "Oasis Elementary",
        "district": "Morongo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586003888",
    },
    {
        "school": "Palm Vista Elementary",
        "district": "Morongo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586003889",
    },
    {
        "school": "Black Rock Alternative/Continuation",
        "district": "Morongo Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62586003890",
    },
    {
        "school": "Twentynine Palms Elementary",
        "district": "Morongo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586003891",
    },
    {
        "school": "Twentynine Palms High",
        "district": "Morongo Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586003892",
    },
    {
        "school": "Twentynine Palms Junior High",
        "district": "Morongo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586003893",
    },
    {
        "school": "Yucca Valley Elementary",
        "district": "Morongo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586003894",
    },
    {
        "school": "Yucca Valley High",
        "district": "Morongo Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586003895",
    },
    {
        "school": "Onaga Elementary",
        "district": "Morongo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586005039",
    },
    {
        "school": "Yucca Mesa Elementary",
        "district": "Morongo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586008912",
    },
    {
        "school": "La Contenta Middle",
        "district": "Morongo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586009163",
    },
    {
        "school": "Friendly Hills Elementary",
        "district": "Morongo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586009164",
    },
    {
        "school": "Condor Elementary",
        "district": "Morongo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586009939",
    },
    {
        "school": "Landers Elementary",
        "district": "Morongo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586009940",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62622003921",
    },
    {
        "school": "Grace Yokley Middle",
        "district": "Mountain View Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62622007789",
    },
    {
        "school": "Creek View Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62622008914",
    },
    {
        "school": "Ranch View Elementary",
        "district": "Mountain View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62622010302",
    },
    {
        "school": "Mt. Baldy Joint Elementary",
        "district": "Mt. Baldy Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62634003932",
    },
    {
        "school": "Needles High",
        "district": "Needles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62676004057",
    },
    {
        "school": "Vista Colorado Elementary",
        "district": "Needles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62676004059",
    },
    {
        "school": "Educational Training Center",
        "district": "Needles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62676007618",
    },
    {
        "school": "Needles Middle",
        "district": "Needles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62676009951",
    },
    {
        "school": "Arroyo Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004387",
    },
    {
        "school": "Berlyn Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004388",
    },
    {
        "school": "Bon View Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004389",
    },
    {
        "school": "Corona Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004390",
    },
    {
        "school": "Richard Haynes Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004392",
    },
    {
        "school": "De Anza Middle",
        "district": "Ontario-Montclair",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004393",
    },
    {
        "school": "Del Norte Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004394",
    },
    {
        "school": "Edison Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004395",
    },
    {
        "school": "El Camino Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004396",
    },
    {
        "school": "Elderberry Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004397",
    },
    {
        "school": "Euclid Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004398",
    },
    {
        "school": "Hawthorne Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004399",
    },
    {
        "school": "Ray Wiltsey Middle",
        "district": "Ontario-Montclair",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004400",
    },
    {
        "school": "Kingsley Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004401",
    },
    {
        "school": "Lehigh Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004402",
    },
    {
        "school": "Mariposa Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004406",
    },
    {
        "school": "Mission Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004407",
    },
    {
        "school": "Monte Vista Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004408",
    },
    {
        "school": "Moreno Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004409",
    },
    {
        "school": "Ramona Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004410",
    },
    {
        "school": "Serrano Middle",
        "district": "Ontario-Montclair",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004411",
    },
    {
        "school": "Sultana Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004412",
    },
    {
        "school": "Vernon Middle",
        "district": "Ontario-Montclair",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004413",
    },
    {
        "school": "Vina Danks Middle",
        "district": "Ontario-Montclair",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004414",
    },
    {
        "school": "Vineyard Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847004415",
    },
    {
        "school": "Oaks Middle",
        "district": "Ontario-Montclair",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847006433",
    },
    {
        "school": "Howard Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847007805",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847007806",
    },
    {
        "school": "Buena Vista Arts-Integrated",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847008925",
    },
    {
        "school": "Central Language Academy",
        "district": "Ontario-Montclair",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62847009417",
    },
    {
        "school": "Oro Grande Elementary",
        "district": "Oro Grande",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62895004480",
    },
    {
        "school": "Bryn Mawr Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207002617",
    },
    {
        "school": "Cope Middle",
        "district": "Redlands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004932",
    },
    {
        "school": "Crafton Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004933",
    },
    {
        "school": "Franklin Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004936",
    },
    {
        "school": "Kimberly Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004937",
    },
    {
        "school": "Kingsbury Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004938",
    },
    {
        "school": "Lugonia Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004939",
    },
    {
        "school": "Mariposa Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004940",
    },
    {
        "school": "McKinley Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004941",
    },
    {
        "school": "Mentone Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004942",
    },
    {
        "school": "Moore Middle",
        "district": "Redlands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004944",
    },
    {
        "school": "Orangewood High (Continuation)",
        "district": "Redlands Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63207004945",
    },
    {
        "school": "Redlands Senior High",
        "district": "Redlands Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004946",
    },
    {
        "school": "Smiley Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004947",
    },
    {
        "school": "Victoria Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207004948",
    },
    {
        "school": "Redlands East Valley High",
        "district": "Redlands Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207007268",
    },
    {
        "school": "Cram Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207007269",
    },
    {
        "school": "Clement Middle",
        "district": "Redlands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207007274",
    },
    {
        "school": "Arroyo Verde Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207009619",
    },
    {
        "school": "Rialto High",
        "district": "Rialto Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237001126",
    },
    {
        "school": "Edward Fitzgerald Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237003847",
    },
    {
        "school": "Ernest Garcia Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237003848",
    },
    {
        "school": "Ethel Kucera Middle",
        "district": "Rialto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237003852",
    },
    {
        "school": "Bemis Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004986",
    },
    {
        "school": "Boyd Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004987",
    },
    {
        "school": "Casey Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004988",
    },
    {
        "school": "Dunn Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004989",
    },
    {
        "school": "Eisenhower Senior High",
        "district": "Rialto Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004990",
    },
    {
        "school": "Frisbie Middle",
        "district": "Rialto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004991",
    },
    {
        "school": "Kelley Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004993",
    },
    {
        "school": "Kolb Middle",
        "district": "Rialto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004994",
    },
    {
        "school": "Morgan Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004995",
    },
    {
        "school": "Myers Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004996",
    },
    {
        "school": "Preston Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004997",
    },
    {
        "school": "Rialto Middle",
        "district": "Rialto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004998",
    },
    {
        "school": "Trapp Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237004999",
    },
    {
        "school": "Milor Continuation High",
        "district": "Rialto Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63237007338",
    },
    {
        "school": "William G. Jehue Middle",
        "district": "Rialto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237007621",
    },
    {
        "school": "Sam V. Curtis Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237007622",
    },
    {
        "school": "Henry Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237007829",
    },
    {
        "school": "Helen L. Dollahan Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237008949",
    },
    {
        "school": "Samuel W. Simpson Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237009183",
    },
    {
        "school": "Elizabeth T. Hughbanks Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237009427",
    },
    {
        "school": "Zupanic High",
        "district": "Rialto Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63237010019",
    },
    {
        "school": "Georgia Morris Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237010020",
    },
    {
        "school": "Lake Arrowhead Elementary",
        "district": "Rim of the World Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63261005070",
    },
    {
        "school": "Mary P. Henck Intermediate",
        "district": "Rim of the World Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63261005071",
    },
    {
        "school": "Mountain High",
        "district": "Rim of the World Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63261005073",
    },
    {
        "school": "Rim of the World Senior High",
        "district": "Rim of the World Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63261005074",
    },
    {
        "school": "Charles Hoffman Elementary",
        "district": "Rim of the World Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63261005075",
    },
    {
        "school": "Valley of Enchantment Elementary",
        "district": "Rim of the World Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63261005076",
    },
    {
        "school": "North Verdemont Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417001131",
    },
    {
        "school": "Palm Avenue Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005054",
    },
    {
        "school": "Arrowhead Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005345",
    },
    {
        "school": "Arrowview Middle",
        "district": "San Bernardino City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005346",
    },
    {
        "school": "Barton Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005347",
    },
    {
        "school": "Belvedere Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005348",
    },
    {
        "school": "Bradley Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005349",
    },
    {
        "school": "Captain Leland Norton Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005350",
    },
    {
        "school": "Cajon High",
        "district": "San Bernardino City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005351",
    },
    {
        "school": "Manuel A. Salinas Creative Arts Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005352",
    },
    {
        "school": "Cole Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005353",
    },
    {
        "school": "Curtis Middle",
        "district": "San Bernardino City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005354",
    },
    {
        "school": "Cypress Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005355",
    },
    {
        "school": "Davidson Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005356",
    },
    {
        "school": "Del Rosa Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005357",
    },
    {
        "school": "Emmerton Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005359",
    },
    {
        "school": "Golden Valley Middle",
        "district": "San Bernardino City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005361",
    },
    {
        "school": "Hunt Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005362",
    },
    {
        "school": "Kendall Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005363",
    },
    {
        "school": "Kimbark Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005364",
    },
    {
        "school": "Lankershim Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005365",
    },
    {
        "school": "Lincoln Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005366",
    },
    {
        "school": "Lytle Creek Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005367",
    },
    {
        "school": "Marshall Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005368",
    },
    {
        "school": "Monterey Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005370",
    },
    {
        "school": "Mt. Vernon Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005371",
    },
    {
        "school": "Muscoy Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005373",
    },
    {
        "school": "Newmark Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005374",
    },
    {
        "school": "North Park Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005375",
    },
    {
        "school": "Oehl Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005376",
    },
    {
        "school": "Parkside Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005378",
    },
    {
        "school": "Ramona-Alessandro Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005379",
    },
    {
        "school": "Richardson Prep Hi",
        "district": "San Bernardino City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005380",
    },
    {
        "school": "Riley Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005381",
    },
    {
        "school": "Rio Vista Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005382",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005383",
    },
    {
        "school": "San Bernardino High",
        "district": "San Bernardino City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005384",
    },
    {
        "school": "San Gorgonio High",
        "district": "San Bernardino City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005385",
    },
    {
        "school": "Serrano Middle",
        "district": "San Bernardino City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005386",
    },
    {
        "school": "Shandin Hills Middle",
        "district": "San Bernardino City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005387",
    },
    {
        "school": "Thompson Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005388",
    },
    {
        "school": "Urbita Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005389",
    },
    {
        "school": "Vermont Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005390",
    },
    {
        "school": "Warm Springs Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005391",
    },
    {
        "school": "Wilson Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417005392",
    },
    {
        "school": "Fairfax Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417007277",
    },
    {
        "school": "Anderson",
        "district": "San Bernardino City Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63417007342",
    },
    {
        "school": "Carmack",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63417007343",
    },
    {
        "school": "San Andreas High",
        "district": "San Bernardino City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63417007344",
    },
    {
        "school": "Sierra High",
        "district": "San Bernardino City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63417007345",
    },
    {
        "school": "Yvonne Harmon",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63417007346",
    },
    {
        "school": "STAR at Anderson Community Day",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63417007629",
    },
    {
        "school": "Martin Luther King Jr. Middle",
        "district": "San Bernardino City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417008185",
    },
    {
        "school": "Highland Pacific Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417008959",
    },
    {
        "school": "Hillside Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417009187",
    },
    {
        "school": "Howard Inghram Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417009434",
    },
    {
        "school": "Del Vallejo Middle",
        "district": "San Bernardino City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417009435",
    },
    {
        "school": "Alternative Learning Center",
        "district": "San Bernardino City Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63417010048",
    },
    {
        "school": "Pacific High",
        "district": "San Bernardino City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417010049",
    },
    {
        "school": "E. Neal Roberts Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417010303",
    },
    {
        "school": "Arroyo Valley High",
        "district": "San Bernardino City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417010365",
    },
    {
        "school": "Middle College High",
        "district": "San Bernardino City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63417010366",
    },
    {
        "school": "Newberry Springs Elementary",
        "district": "Silver Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63682007255",
    },
    {
        "school": "Calico Continuation High",
        "district": "Silver Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63682007256",
    },
    {
        "school": "Silver Valley High",
        "district": "Silver Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63682007257",
    },
    {
        "school": "Yermo Elementary",
        "district": "Silver Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63682007258",
    },
    {
        "school": "Congressman Jerry Lewis Elementary",
        "district": "Silver Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63682007873",
    },
    {
        "school": "Fort Irwin Middle",
        "district": "Silver Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63682008198",
    },
    {
        "school": "Snowline Academy",
        "district": "Snowline Joint Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63697001140",
    },
    {
        "school": "Heritage",
        "district": "Snowline Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697005069",
    },
    {
        "school": "Quail Valley Middle",
        "district": "Snowline Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697005084",
    },
    {
        "school": "Chaparral High",
        "district": "Snowline Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63697007874",
    },
    {
        "school": "Phelan Elementary",
        "district": "Snowline Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697007875",
    },
    {
        "school": "Serrano High",
        "district": "Snowline Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697007876",
    },
    {
        "school": "Wrightwood Elementary",
        "district": "Snowline Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697007877",
    },
    {
        "school": "Pinon Mesa Middle",
        "district": "Snowline Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697008987",
    },
    {
        "school": "Baldy Mesa Elementary",
        "district": "Snowline Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697009195",
    },
    {
        "school": "Pinon Hills Elementary",
        "district": "Snowline Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697009640",
    },
    {
        "school": "Eagle Summit Community Day",
        "district": "Snowline Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63697010370",
    },
    {
        "school": "Silverado High",
        "district": "Victor Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697206461",
    },
    {
        "school": "Goodwill High",
        "district": "Victor Valley Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63697206778",
    },
    {
        "school": "Imogene Garner Hook Junior High",
        "district": "Victor Valley Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697206779",
    },
    {
        "school": "Lakeview Leadership Academy",
        "district": "Victor Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697206781",
    },
    {
        "school": "Victor Valley High",
        "district": "Victor Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697206782",
    },
    {
        "school": "Cobalt Institute of Math and Science Academy",
        "district": "Victor Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697207281",
    },
    {
        "school": "Trona Elementary",
        "district": "Trona Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63984006608",
    },
    {
        "school": "Trona High",
        "district": "Trona Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63984006609",
    },
    {
        "school": "Green Tree East Elementary",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104001135",
    },
    {
        "school": "Brentwood Elementary",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104006457",
    },
    {
        "school": "Del Rey Elementary",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104006771",
    },
    {
        "school": "Irwin Academy of Performing Arts",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104006773",
    },
    {
        "school": "Park View Elementary",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104006774",
    },
    {
        "school": "Sixth Street Prep",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104007280",
    },
    {
        "school": "Village Elementary",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104007891",
    },
    {
        "school": "Discovery School of the Arts",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104008586",
    },
    {
        "school": "Mountain View Montessori Charter",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104008587",
    },
    {
        "school": "Liberty Elementary",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104009005",
    },
    {
        "school": "Mojave Vista Elementary",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104009202",
    },
    {
        "school": "Lomitas Elementary",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104010132",
    },
    {
        "school": "Puesta del Sol Elementary",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104010133",
    },
    {
        "school": "Park View Middle",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64356001137",
    },
    {
        "school": "Calimesa Elementary",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64356007042",
    },
    {
        "school": "Dunlap Elementary",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64356007043",
    },
    {
        "school": "Green Valley High",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64356007044",
    },
    {
        "school": "Valley Elementary",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64356007045",
    },
    {
        "school": "Yucaipa High",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64356007048",
    },
    {
        "school": "Wildwood Elementary",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64356007284",
    },
    {
        "school": "Ridgeview Elementary",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64356010156",
    },
    {
        "school": "San Bernardino County Special Education",
        "district": "San Bernardino County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102907174",
    },
    {
        "school": "San Bernardino Co Juve Detention and Assessment Center",
        "district": "San Bernardino County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102909241",
    },
    {
        "school": "Central Sierra ROP",
        "district": "Central Sierra ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60009610770",
    },
    {
        "school": "Charter Montessori Valley View Campus",
        "district": "Buckeye Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60627010767",
    },
    {
        "school": "Oak Meadow Elementary",
        "district": "Buckeye Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60627011240",
    },
    {
        "school": "EDUHSD Virtual Academy at Shenandoah",
        "district": "El Dorado Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61207010478",
    },
    {
        "school": "Lake Tahoe Environmental Science Magnet",
        "district": "Lake Tahoe Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62064011581",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Rescue Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63231010769",
    },
    {
        "school": "Pleasant Grove Middle",
        "district": "Rescue Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63231011168",
    },
    {
        "school": "Blue Ridge",
        "district": "El Dorado County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100610766",
    },
    {
        "school": "Rock Creek Elementary",
        "district": "Rocklin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001310575",
    },
    {
        "school": "Ruhkala Elementary",
        "district": "Rocklin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001311009",
    },
    {
        "school": "Whitney High",
        "district": "Rocklin Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001311010",
    },
    {
        "school": "Forty-Niner ROP",
        "district": "Forty-Niner ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60008211008",
    },
    {
        "school": "Wilson C. Riles Middle",
        "district": "Center Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60790011082",
    },
    {
        "school": "Coyote Ridge Elementary",
        "district": "Dry Creek Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61149010574",
    },
    {
        "school": "Penryn Elementary",
        "district": "Loomis Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62256011704",
    },
    {
        "school": "Newcastle Charter",
        "district": "Newcastle Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62712011001",
    },
    {
        "school": "Foresthill High",
        "district": "Placer Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63075011002",
    },
    {
        "school": "Thomas Jefferson Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360011003",
    },
    {
        "school": "Blue Oaks Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360011004",
    },
    {
        "school": "Twelve Bridges Elementary",
        "district": "Western Placer Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64214011006",
    },
    {
        "school": "Foskett Ranch Elementary",
        "district": "Western Placer Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64214011007",
    },
    {
        "school": "Placer County Community Schools",
        "district": "Placer County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102510573",
    },
    {
        "school": "Inderkum High",
        "district": "Natomas Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003611084",
    },
    {
        "school": "Witter Ranch Elementary",
        "district": "Natomas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003611085",
    },
    {
        "school": "Westlake Charter",
        "district": "Natomas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003611087",
    },
    {
        "school": "Sacramento County ROP",
        "district": "Sacramento County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60009511083",
    },
    {
        "school": "Franklin High",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233010593",
    },
    {
        "school": "Toby Johnson Middle",
        "district": "Elk Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233010594",
    },
    {
        "school": "Irene B. West Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233010595",
    },
    {
        "school": "Robert J. Fite Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233010596",
    },
    {
        "school": "Elliott Ranch Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233010597",
    },
    {
        "school": "Arlene Hein Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233011060",
    },
    {
        "school": "Monterey Trail High",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233011061",
    },
    {
        "school": "Edward Harris Jr. Middle",
        "district": "Elk Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233011062",
    },
    {
        "school": "Roy Herburger Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233011063",
    },
    {
        "school": "Arnold Adreani Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233011064",
    },
    {
        "school": "Helen Carr Castello Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233011065",
    },
    {
        "school": "Katherine L. Albiani Middle",
        "district": "Elk Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233011066",
    },
    {
        "school": "Pleasant Grove High",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233011067",
    },
    {
        "school": "Edna Batey Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233011231",
    },
    {
        "school": "Folsom Cordova K-8 Community Charter",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389011068",
    },
    {
        "school": "Sandra J. Gallardo Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389011205",
    },
    {
        "school": "Lake Canyon Elementary",
        "district": "Galt Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61479011069",
    },
    {
        "school": "Robert L. McCaffrey Middle",
        "district": "Galt Joint Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61479011211",
    },
    {
        "school": "West Campus",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384010600",
    },
    {
        "school": "Arthur A. Benjamin Health Professions High",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384011078",
    },
    {
        "school": "Rosemont High",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384011191",
    },
    {
        "school": "The MET",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384011194",
    },
    {
        "school": "George Washington Carver School of Arts and Science",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384011195",
    },
    {
        "school": "New Technology High",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384011196",
    },
    {
        "school": "Marvin Marshall Preschool and Children's Center",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63462011080",
    },
    {
        "school": "Palmiter Special Education",
        "district": "Sacramento County Office of Education",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102711051",
    },
    {
        "school": "Elinor Lincoln Hickey Jr./Sr. High",
        "district": "Sacramento County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102711052",
    },
    {
        "school": "North Area Community",
        "district": "Sacramento County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102711053",
    },
    {
        "school": "El Centro Jr./Sr. High",
        "district": "Sacramento County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102711055",
    },
    {
        "school": "Sacramento County SH Special Education",
        "district": "Sacramento County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102711057",
    },
    {
        "school": "Sacramento County ED Special Education",
        "district": "Sacramento County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102711058",
    },
    {
        "school": "Yolo County ROP",
        "district": "Yolo County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60014911544",
    },
    {
        "school": "Frances Ellen Watkins Harper Junior High",
        "district": "Davis Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062011541",
    },
    {
        "school": "Bridgeway Island Elementary",
        "district": "Washington Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64158010715",
    },
    {
        "school": "Pioneer High",
        "district": "Woodland Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308011380",
    },
    {
        "school": "Otter Creek Elementary",
        "district": "Black Oak Mine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60524000362",
    },
    {
        "school": "Georgetown Elementary",
        "district": "Black Oak Mine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60524000494",
    },
    {
        "school": "Golden Sierra Junior Senior High",
        "district": "Black Oak Mine Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60524000495",
    },
    {
        "school": "Divide High",
        "district": "Black Oak Mine Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60524007650",
    },
    {
        "school": "Northside Elementary",
        "district": "Black Oak Mine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60524007651",
    },
    {
        "school": "Silva Valley Elementary",
        "district": "Buckeye Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60627000291",
    },
    {
        "school": "Buckeye Elementary",
        "district": "Buckeye Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60627000548",
    },
    {
        "school": "Camerado Springs Middle",
        "district": "Buckeye Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60627000549",
    },
    {
        "school": "William Brooks Elementary",
        "district": "Buckeye Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60627000550",
    },
    {
        "school": "Rolling Hills Middle",
        "district": "Buckeye Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60627002958",
    },
    {
        "school": "Blue Oak Elementary",
        "district": "Buckeye Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60627009326",
    },
    {
        "school": "Camino Elementary",
        "district": "Camino Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60717000656",
    },
    {
        "school": "El Dorado High",
        "district": "El Dorado Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61207001342",
    },
    {
        "school": "Independence Continuation",
        "district": "El Dorado Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61207001343",
    },
    {
        "school": "Ponderosa High",
        "district": "El Dorado Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61207001344",
    },
    {
        "school": "Oak Ridge High",
        "district": "El Dorado Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61207007279",
    },
    {
        "school": "Union Mine High",
        "district": "El Dorado Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61207007957",
    },
    {
        "school": "Gold Oak Elementary",
        "district": "Gold Oak Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61539001962",
    },
    {
        "school": "Pleasant Valley Middle",
        "district": "Gold Oak Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61539010199",
    },
    {
        "school": "Gold Trail",
        "district": "Gold Trail Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61545001963",
    },
    {
        "school": "Sutters Mill",
        "district": "Gold Trail Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61545010200",
    },
    {
        "school": "Indian Diggings Elementary",
        "district": "Indian Diggings Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61824002245",
    },
    {
        "school": "Transitional Learning Center (Continuation)",
        "district": "Lake Tahoe Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62064000301",
    },
    {
        "school": "Bijou Community",
        "district": "Lake Tahoe Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62064002477",
    },
    {
        "school": "Mt. Tallac High",
        "district": "Lake Tahoe Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62064002479",
    },
    {
        "school": "South Tahoe High",
        "district": "Lake Tahoe Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62064002481",
    },
    {
        "school": "South Tahoe Middle",
        "district": "Lake Tahoe Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62064002482",
    },
    {
        "school": "Tahoe Valley Elementary",
        "district": "Lake Tahoe Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62064002483",
    },
    {
        "school": "Sierra House Elementary",
        "district": "Lake Tahoe Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62064008873",
    },
    {
        "school": "Latrobe Elementary",
        "district": "Latrobe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62118002538",
    },
    {
        "school": "Miller's Hill",
        "district": "Latrobe",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62118008151",
    },
    {
        "school": "Herbert C. Green Middle",
        "district": "Mother Lode Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62598003897",
    },
    {
        "school": "Indian Creek Elementary",
        "district": "Mother Lode Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62598009165",
    },
    {
        "school": "Mountain Creek Middle",
        "district": "Pioneer Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63048002973",
    },
    {
        "school": "Pioneer Elementary",
        "district": "Pioneer Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63048004740",
    },
    {
        "school": "Walt Tyler Elementary",
        "district": "Pioneer Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63048007083",
    },
    {
        "school": "Edwin Markham Middle",
        "district": "Placerville Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63078004785",
    },
    {
        "school": "Louisiana Schnell Elementary",
        "district": "Placerville Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63078004786",
    },
    {
        "school": "Sierra Elementary",
        "district": "Placerville Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63078004787",
    },
    {
        "school": "Pinewood Elementary",
        "district": "Pollock Pines Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63129004832",
    },
    {
        "school": "Sierra Ridge Middle",
        "district": "Pollock Pines Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63129009423",
    },
    {
        "school": "Green Valley Elementary",
        "district": "Rescue Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63231004982",
    },
    {
        "school": "Jackson Elementary",
        "district": "Rescue Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63231004983",
    },
    {
        "school": "Rescue Elementary",
        "district": "Rescue Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63231004984",
    },
    {
        "school": "Marina Village Middle",
        "district": "Rescue Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63231008948",
    },
    {
        "school": "Lake Forest Elementary",
        "district": "Rescue Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63231010017",
    },
    {
        "school": "Silver Fork Elementary",
        "district": "Silver Fork Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63681006244",
    },
    {
        "school": "Charter Community School Home Study Academy",
        "district": "El Dorado County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100601981",
    },
    {
        "school": "Rite of Passage",
        "district": "El Dorado County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100602957",
    },
    {
        "school": "Golden Ridge",
        "district": "El Dorado County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100607386",
    },
    {
        "school": "Special Education",
        "district": "El Dorado County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100609218",
    },
    {
        "school": "Antelope Creek Elementary",
        "district": "Rocklin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001300805",
    },
    {
        "school": "Rocklin High",
        "district": "Rocklin Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001302405",
    },
    {
        "school": "Breen Elementary",
        "district": "Rocklin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001303571",
    },
    {
        "school": "Victory High",
        "district": "Rocklin Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60001306176",
    },
    {
        "school": "Twin Oaks Elementary",
        "district": "Rocklin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001308256",
    },
    {
        "school": "Granite Oaks Middle",
        "district": "Rocklin Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001308257",
    },
    {
        "school": "Spring View Middle",
        "district": "Rocklin Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001308553",
    },
    {
        "school": "Valley View Elementary",
        "district": "Rocklin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001308763",
    },
    {
        "school": "Sierra Elementary",
        "district": "Rocklin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001308764",
    },
    {
        "school": "Parker Whitney Elementary",
        "district": "Rocklin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001309069",
    },
    {
        "school": "Rocklin Elementary",
        "district": "Rocklin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001309070",
    },
    {
        "school": "Cobblestone Elementary",
        "district": "Rocklin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001310270",
    },
    {
        "school": "Bowman Charter",
        "district": "Ackerman Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60168000037",
    },
    {
        "school": "Alta-Dutch Flat Elementary",
        "district": "Alta-Dutch Flat Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60225000099",
    },
    {
        "school": "EV Cain Middle",
        "district": "Auburn Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60348000265",
    },
    {
        "school": "Rock Creek Elementary",
        "district": "Auburn Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60348000267",
    },
    {
        "school": "Auburn Elementary",
        "district": "Auburn Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60348004813",
    },
    {
        "school": "Skyridge Elementary",
        "district": "Auburn Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60348009709",
    },
    {
        "school": "Colfax Elementary",
        "district": "Colfax Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60930000940",
    },
    {
        "school": "Quail Glen Elementary",
        "district": "Dry Creek Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61149003503",
    },
    {
        "school": "Silverado Middle",
        "district": "Dry Creek Joint Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61149008253",
    },
    {
        "school": "Heritage Oak Elementary",
        "district": "Dry Creek Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61149009791",
    },
    {
        "school": "Greenhills Elementary",
        "district": "Eureka Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61308001489",
    },
    {
        "school": "Ridgeview Elementary",
        "district": "Eureka Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61308003506",
    },
    {
        "school": "Olympus Junior High",
        "district": "Eureka Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61308006167",
    },
    {
        "school": "Maidu Elementary",
        "district": "Eureka Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61308007204",
    },
    {
        "school": "Willma Cavitt Junior High",
        "district": "Eureka Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61308007707",
    },
    {
        "school": "Excelsior Elementary",
        "district": "Eureka Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61308008254",
    },
    {
        "school": "Oakhills Elementary",
        "district": "Eureka Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61308009810",
    },
    {
        "school": "Foresthill Divide",
        "district": "Foresthill Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61398001605",
    },
    {
        "school": "Franklin Elementary",
        "district": "Loomis Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62256002771",
    },
    {
        "school": "Loomis Elementary",
        "district": "Loomis Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62256002772",
    },
    {
        "school": "Placer Elementary",
        "district": "Loomis Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62256002773",
    },
    {
        "school": "H. Clarke Powers Elementary",
        "district": "Loomis Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62256008550",
    },
    {
        "school": "Newcastle Elementary",
        "district": "Newcastle Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62712004093",
    },
    {
        "school": "Weimar Hills",
        "district": "Placer Hills Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63072004779",
    },
    {
        "school": "Sierra Hills Elementary",
        "district": "Placer Hills Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63072004909",
    },
    {
        "school": "Confluence Continuation High",
        "district": "Placer Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63075004780",
    },
    {
        "school": "Colfax High",
        "district": "Placer Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63075004781",
    },
    {
        "school": "Del Oro High",
        "district": "Placer Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63075004782",
    },
    {
        "school": "Placer High",
        "district": "Placer Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63075004784",
    },
    {
        "school": "George A. Buljan Middle",
        "district": "Roseville City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360003508",
    },
    {
        "school": "Vencil Brown Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360004953",
    },
    {
        "school": "George Cirby Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360005183",
    },
    {
        "school": "Crestmont Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360005184",
    },
    {
        "school": "Warren T. Eich Middle",
        "district": "Roseville City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360005185",
    },
    {
        "school": "William Kaseberg Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360005186",
    },
    {
        "school": "Bradford Woodbridge Fundamental Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360005188",
    },
    {
        "school": "Catheryn Gates Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360008255",
    },
    {
        "school": "Robert C. Cooley Middle",
        "district": "Roseville City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360008551",
    },
    {
        "school": "Diamond Creek Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360008760",
    },
    {
        "school": "Stoneridge Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360008761",
    },
    {
        "school": "George Sargeant Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360008955",
    },
    {
        "school": "Ferris Spanger Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360010034",
    },
    {
        "school": "Woodcreek High",
        "district": "Roseville Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63363003513",
    },
    {
        "school": "Adelante High (Continuation)",
        "district": "Roseville Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63363005189",
    },
    {
        "school": "Oakmont High",
        "district": "Roseville Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63363005190",
    },
    {
        "school": "Roseville High",
        "district": "Roseville Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63363005191",
    },
    {
        "school": "Granite Bay High",
        "district": "Roseville Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63363006168",
    },
    {
        "school": "Independence High (Alternative)",
        "district": "Roseville Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63363010036",
    },
    {
        "school": "Carlin C. Coppin Elementary",
        "district": "Western Placer Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64214006894",
    },
    {
        "school": "Creekside Oaks Elementary",
        "district": "Western Placer Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64214006896",
    },
    {
        "school": "Lincoln High",
        "district": "Western Placer Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64214006897",
    },
    {
        "school": "Phoenix High (Continuation)",
        "district": "Western Placer Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64214006898",
    },
    {
        "school": "Sheridan Elementary",
        "district": "Western Placer Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64214006899",
    },
    {
        "school": "First Street Elementary",
        "district": "Western Placer Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64214008552",
    },
    {
        "school": "Glen Edwards Middle",
        "district": "Western Placer Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64214009656",
    },
    {
        "school": "Placer County Special Education",
        "district": "Placer County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102509030",
    },
    {
        "school": "Placer County Court Schools",
        "district": "Placer County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102509237",
    },
    {
        "school": "American Lakes",
        "district": "Natomas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003601095",
    },
    {
        "school": "Jefferson",
        "district": "Natomas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003601108",
    },
    {
        "school": "Bannon Creek",
        "district": "Natomas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003601114",
    },
    {
        "school": "Natomas High",
        "district": "Natomas Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003603755",
    },
    {
        "school": "Discovery High",
        "district": "Natomas Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60003606335",
    },
    {
        "school": "Natomas Middle",
        "district": "Natomas Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003608582",
    },
    {
        "school": "Natomas Park Elementary",
        "district": "Natomas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003608583",
    },
    {
        "school": "Two Rivers Elementary",
        "district": "Natomas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003610359",
    },
    {
        "school": "Arcohe Elementary",
        "district": "Arcohe Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60306000241",
    },
    {
        "school": "Oak Hill Elementary",
        "district": "Center Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60790003752",
    },
    {
        "school": "Arthur S. Dudley Elementary",
        "district": "Center Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60790007663",
    },
    {
        "school": "Cyril Spinelli Elementary",
        "district": "Center Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60790007664",
    },
    {
        "school": "Center High",
        "district": "Center Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60790008805",
    },
    {
        "school": "McClellan High (Continuation)",
        "district": "Center Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60790009343",
    },
    {
        "school": "North Country Elementary",
        "district": "Center Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60790009750",
    },
    {
        "school": "Antelope Crossing Middle",
        "district": "Dry Creek Joint Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61149003494",
    },
    {
        "school": "Olive Grove Elementary",
        "district": "Dry Creek Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61149007599",
    },
    {
        "school": "Antelope Meadows Elementary",
        "district": "Dry Creek Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61149010268",
    },
    {
        "school": "Mary Tsukamoto Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001034",
    },
    {
        "school": "Cosumnes River Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001394",
    },
    {
        "school": "Daylor (William) High (Continuation)",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61233001395",
    },
    {
        "school": "C. W. Dillard Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001396",
    },
    {
        "school": "Elk Grove Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001397",
    },
    {
        "school": "Elk Grove High",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001398",
    },
    {
        "school": "Florin Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001399",
    },
    {
        "school": "Franklin Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001400",
    },
    {
        "school": "Samuel Kennedy Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001401",
    },
    {
        "school": "Joseph Kerr Middle",
        "district": "Elk Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001402",
    },
    {
        "school": "Anna Kirchgater Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001403",
    },
    {
        "school": "Herman Leimbach Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001404",
    },
    {
        "school": "Charles E. Mack Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001405",
    },
    {
        "school": "Florence Markofer Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001406",
    },
    {
        "school": "James A. McKee Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001407",
    },
    {
        "school": "Pleasant Grove Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001409",
    },
    {
        "school": "David Reese Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001410",
    },
    {
        "school": "Prairie Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001411",
    },
    {
        "school": "James Rutter Middle",
        "district": "Elk Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001412",
    },
    {
        "school": "Sierra-Enterprise Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001413",
    },
    {
        "school": "Valley High",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233001414",
    },
    {
        "school": "Laguna Creek High",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233003662",
    },
    {
        "school": "Harriet G. Eddy Middle",
        "district": "Elk Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233003667",
    },
    {
        "school": "Elitha Donner Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233003668",
    },
    {
        "school": "Barbara Comstock Morse Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233005016",
    },
    {
        "school": "Maeola E. Beitzel Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233006286",
    },
    {
        "school": "Sheldon High",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233007226",
    },
    {
        "school": "T. R. Smedberg Middle",
        "district": "Elk Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233007234",
    },
    {
        "school": "Arthur C. Butler Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233007608",
    },
    {
        "school": "Jessie Baker",
        "district": "Elk Grove Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61233007698",
    },
    {
        "school": "Ellen Feickert Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233007699",
    },
    {
        "school": "Las Flores High (Alternative)",
        "district": "Elk Grove Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61233007700",
    },
    {
        "school": "Calvine High",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61233007701",
    },
    {
        "school": "Rio Cazadero High (Continuation)",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61233007702",
    },
    {
        "school": "Elk Grove Charter",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233008275",
    },
    {
        "school": "Joseph Sims Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233008276",
    },
    {
        "school": "Raymond Case Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233008572",
    },
    {
        "school": "Stone Lake Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233008573",
    },
    {
        "school": "Isabelle Jackson Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233008827",
    },
    {
        "school": "Foulks Ranch Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233009361",
    },
    {
        "school": "Union House Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233009362",
    },
    {
        "school": "Florin High",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233009534",
    },
    {
        "school": "John Reith Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233009535",
    },
    {
        "school": "Samuel Jackman Middle",
        "district": "Elk Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233010292",
    },
    {
        "school": "John Ehrhardt Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233010293",
    },
    {
        "school": "Alpha Technology Middle",
        "district": "Elverta Joint Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61260001423",
    },
    {
        "school": "Elverta Elementary",
        "district": "Elverta Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61260001424",
    },
    {
        "school": "Cordova Gardens Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001565",
    },
    {
        "school": "Cordova Meadows Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001567",
    },
    {
        "school": "Cordova High",
        "district": "Folsom-Cordova Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001568",
    },
    {
        "school": "Cordova Villa Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001569",
    },
    {
        "school": "Folsom High",
        "district": "Folsom-Cordova Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001570",
    },
    {
        "school": "Folsom Middle",
        "district": "Folsom-Cordova Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001571",
    },
    {
        "school": "Theodore Judah Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001572",
    },
    {
        "school": "Kinney High (Continuation)",
        "district": "Folsom-Cordova Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61389001573",
    },
    {
        "school": "Mills Middle",
        "district": "Folsom-Cordova Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001576",
    },
    {
        "school": "W. E. Mitchell Middle",
        "district": "Folsom-Cordova Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001577",
    },
    {
        "school": "Rancho Cordova Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001578",
    },
    {
        "school": "Riverview STEM Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001579",
    },
    {
        "school": "Peter J. Shields Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001580",
    },
    {
        "school": "Blanche Sprentz Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001581",
    },
    {
        "school": "White Rock Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001583",
    },
    {
        "school": "Williamson Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389001584",
    },
    {
        "school": "Natoma Station Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389005019",
    },
    {
        "school": "Prospect Community Day",
        "district": "Folsom-Cordova Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61389007609",
    },
    {
        "school": "Gold Ridge Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389007611",
    },
    {
        "school": "Folsom Lake High",
        "district": "Folsom-Cordova Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61389008280",
    },
    {
        "school": "Mather Heights Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389008575",
    },
    {
        "school": "Reymouth Special Education Center",
        "district": "Folsom-Cordova Unified",
        "level": "Not reported",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61389008576",
    },
    {
        "school": "Sutter Middle",
        "district": "Folsom-Cordova Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389008577",
    },
    {
        "school": "Carl H. Sundahl Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389009135",
    },
    {
        "school": "Oak Chan Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389009542",
    },
    {
        "school": "Walnutwood High (Independent Study)",
        "district": "Folsom-Cordova Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61389009821",
    },
    {
        "school": "Folsom Hills Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389010294",
    },
    {
        "school": "Empire Oaks Elementary",
        "district": "Folsom-Cordova Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389010355",
    },
    {
        "school": "River Oaks Elementary",
        "district": "Galt Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61479001051",
    },
    {
        "school": "Valley Oaks Elementary",
        "district": "Galt Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61479001819",
    },
    {
        "school": "Marengo Ranch Elementary",
        "district": "Galt Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61479007238",
    },
    {
        "school": "Estrellita Continuation High",
        "district": "Galt Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61482001820",
    },
    {
        "school": "Galt High",
        "district": "Galt Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61482001821",
    },
    {
        "school": "Glenwood Elementary",
        "district": "Robla Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63324003736",
    },
    {
        "school": "Main Avenue Elementary",
        "district": "Robla Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63324005027",
    },
    {
        "school": "Bell Avenue Elementary",
        "district": "Robla Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63324005165",
    },
    {
        "school": "Robla Elementary",
        "district": "Robla Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63324005166",
    },
    {
        "school": "Taylor Street Elementary",
        "district": "Robla Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63324008954",
    },
    {
        "school": "Father Keith B. Kenny",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384001089",
    },
    {
        "school": "Matsuyama Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384002539",
    },
    {
        "school": "A. M. Winn Waldorf-Inspired",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005217",
    },
    {
        "school": "Abraham Lincoln Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005218",
    },
    {
        "school": "Albert Einstein Middle",
        "district": "Sacramento City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005219",
    },
    {
        "school": "American Legion High (Continuation)",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63384005221",
    },
    {
        "school": "Bowling Green Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005224",
    },
    {
        "school": "Bret Harte Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005225",
    },
    {
        "school": "C. K. McClatchy High",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005226",
    },
    {
        "school": "Caleb Greenwood Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005227",
    },
    {
        "school": "California Middle",
        "district": "Sacramento City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005228",
    },
    {
        "school": "Camellia Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005229",
    },
    {
        "school": "Caroline Wenzel Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005230",
    },
    {
        "school": "Rosa Parks Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005231",
    },
    {
        "school": "David Lubin Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005235",
    },
    {
        "school": "Earl Warren Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005236",
    },
    {
        "school": "Edward Kemble Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005237",
    },
    {
        "school": "Elder Creek Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005238",
    },
    {
        "school": "Ethel I. Baker Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005239",
    },
    {
        "school": "Ethel Phillips Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005240",
    },
    {
        "school": "Fern Bacon Middle",
        "district": "Sacramento City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005241",
    },
    {
        "school": "Genevieve Didion",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005244",
    },
    {
        "school": "Golden Empire Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005245",
    },
    {
        "school": "H. W. Harkness Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005246",
    },
    {
        "school": "Hiram W. Johnson High",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005247",
    },
    {
        "school": "Hollywood Park Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005248",
    },
    {
        "school": "Hubert H. Bancroft Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005249",
    },
    {
        "school": "Isador Cohen Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005250",
    },
    {
        "school": "James Marshall Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005251",
    },
    {
        "school": "Leataata Floyd Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005252",
    },
    {
        "school": "John Bidwell Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005254",
    },
    {
        "school": "John Cabrillo Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005255",
    },
    {
        "school": "John D. Sloat Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005256",
    },
    {
        "school": "John F. Kennedy High",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005257",
    },
    {
        "school": "John H. Still",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005259",
    },
    {
        "school": "New Joseph Bonnheim (NJB) Community Charter",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005261",
    },
    {
        "school": "Kit Carson International Academy",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005262",
    },
    {
        "school": "Luther Burbank High",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005264",
    },
    {
        "school": "Mark Twain Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005268",
    },
    {
        "school": "Nicholas Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005269",
    },
    {
        "school": "O. W. Erlewine Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005270",
    },
    {
        "school": "Oak Ridge Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005271",
    },
    {
        "school": "Pacific Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005272",
    },
    {
        "school": "Parkway Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005273",
    },
    {
        "school": "Peter Burnett Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005274",
    },
    {
        "school": "Phoebe A. Hearst Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005276",
    },
    {
        "school": "Pony Express Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005277",
    },
    {
        "school": "Crocker/Riverside Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005278",
    },
    {
        "school": "Sam Brannan Middle",
        "district": "Sacramento City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005280",
    },
    {
        "school": "Sequoia Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005281",
    },
    {
        "school": "Susan B. Anthony Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005282",
    },
    {
        "school": "Sutter Middle",
        "district": "Sacramento City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005283",
    },
    {
        "school": "Sutterville Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005284",
    },
    {
        "school": "Tahoe Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005285",
    },
    {
        "school": "Theodore Judah Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005286",
    },
    {
        "school": "Will C. Wood Middle",
        "district": "Sacramento City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005289",
    },
    {
        "school": "William Land Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005290",
    },
    {
        "school": "Woodbine Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384005291",
    },
    {
        "school": "Capital City Independent Study",
        "district": "Sacramento City Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63384006327",
    },
    {
        "school": "Alice Birney Waldorf-Inspired",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384007242",
    },
    {
        "school": "Success Academy",
        "district": "Sacramento City Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63384008282",
    },
    {
        "school": "Martin Luther King Jr.",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384009430",
    },
    {
        "school": "Leonardo Da Vinci",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384010040",
    },
    {
        "school": "Cesar Chavez Intermediate",
        "district": "Sacramento City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384010358",
    },
    {
        "school": "Gold River Discovery Center K-8",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462002560",
    },
    {
        "school": "Arcade Fundamental Middle",
        "district": "San Juan Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005752",
    },
    {
        "school": "Arden Middle",
        "district": "San Juan Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005753",
    },
    {
        "school": "Arlington Heights Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005754",
    },
    {
        "school": "John Barrett Middle",
        "district": "San Juan Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005755",
    },
    {
        "school": "Bella Vista High",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005756",
    },
    {
        "school": "Cambridge Heights Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005757",
    },
    {
        "school": "Cameron Ranch Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005758",
    },
    {
        "school": "Carmichael Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005759",
    },
    {
        "school": "Andrew Carnegie Middle",
        "district": "San Juan Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005760",
    },
    {
        "school": "Casa Roble Fundamental High",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005761",
    },
    {
        "school": "Winston Churchill Middle",
        "district": "San Juan Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005762",
    },
    {
        "school": "Carriage Drive Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005763",
    },
    {
        "school": "Cottage Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005765",
    },
    {
        "school": "James R. Cowan Fundamental Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005766",
    },
    {
        "school": "Coyle Avenue Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005767",
    },
    {
        "school": "Del Campo High",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005769",
    },
    {
        "school": "Del Dayo Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005770",
    },
    {
        "school": "Del Paso Manor Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005771",
    },
    {
        "school": "Mary Deterding Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005772",
    },
    {
        "school": "Harry Dewey Fundamental Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005773",
    },
    {
        "school": "Dyer-Kelly Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005774",
    },
    {
        "school": "Thomas Edison Language Institute K-8",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005775",
    },
    {
        "school": "El Camino Fundamental High",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005776",
    },
    {
        "school": "Encina Preparatory High",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005778",
    },
    {
        "school": "Grand Oaks Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005781",
    },
    {
        "school": "Green Oaks Fundamental Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005782",
    },
    {
        "school": "Greer Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005783",
    },
    {
        "school": "Howe Avenue Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005785",
    },
    {
        "school": "Thomas Kelly Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005786",
    },
    {
        "school": "Kingswood K-8",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005788",
    },
    {
        "school": "La Entrada Continuation High",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63462005789",
    },
    {
        "school": "Earl Legette Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005792",
    },
    {
        "school": "Lichen K-8",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005793",
    },
    {
        "school": "Mariemont Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005795",
    },
    {
        "school": "Mariposa Avenue Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005796",
    },
    {
        "school": "Mesa Verde High",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005798",
    },
    {
        "school": "Mira Loma High",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005799",
    },
    {
        "school": "Mission Avenue Open Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005800",
    },
    {
        "school": "Northridge Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005802",
    },
    {
        "school": "Oakview Community Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005803",
    },
    {
        "school": "Orangevale Open K-8",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005805",
    },
    {
        "school": "Pasadena Avenue Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005807",
    },
    {
        "school": "Louis Pasteur Fundamental Middle",
        "district": "San Juan Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005808",
    },
    {
        "school": "Charles Peck Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005809",
    },
    {
        "school": "Pershing Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005810",
    },
    {
        "school": "Rio Americano High",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005812",
    },
    {
        "school": "Will Rogers Middle",
        "district": "San Juan Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005814",
    },
    {
        "school": "San Juan High",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005817",
    },
    {
        "school": "Albert Schweitzer Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005818",
    },
    {
        "school": "Sierra Oaks K-8",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005819",
    },
    {
        "school": "Skycrest Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005820",
    },
    {
        "school": "Ralph Richardson Center",
        "district": "San Juan Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63462005821",
    },
    {
        "school": "Starr King K-8",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005822",
    },
    {
        "school": "Sylvan Middle",
        "district": "San Juan Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005824",
    },
    {
        "school": "Twin Lakes Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005825",
    },
    {
        "school": "Whitney Avenue Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005826",
    },
    {
        "school": "Woodside K-8",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462005828",
    },
    {
        "school": "Laurel Ruff Transition",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63462007853",
    },
    {
        "school": "El Sereno Alternative Education",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63462008192",
    },
    {
        "school": "La Vista Center",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63462008193",
    },
    {
        "school": "Valley Oaks",
        "district": "San Juan Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462008195",
    },
    {
        "school": "San Juan Choices Charter",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462008284",
    },
    {
        "school": "Trajan Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462008970",
    },
    {
        "school": "Ottomon Way Elementary",
        "district": "San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462008972",
    },
    {
        "school": "Birch Lane Elementary",
        "district": "Davis Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062001175",
    },
    {
        "school": "Davis Senior High",
        "district": "Davis Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062001176",
    },
    {
        "school": "Ralph Waldo Emerson Junior High",
        "district": "Davis Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062001177",
    },
    {
        "school": "Oliver Wendell Holmes Junior High",
        "district": "Davis Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062001178",
    },
    {
        "school": "King (Martin Luther) High (Continuation)",
        "district": "Davis Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61062001179",
    },
    {
        "school": "North Davis Elementary",
        "district": "Davis Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062001180",
    },
    {
        "school": "Pioneer Elementary",
        "district": "Davis Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062001181",
    },
    {
        "school": "Cesar Chavez Elementary",
        "district": "Davis Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062001183",
    },
    {
        "school": "Robert E. Willett Elementary",
        "district": "Davis Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062001184",
    },
    {
        "school": "Patwin Elementary",
        "district": "Davis Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062001905",
    },
    {
        "school": "Fairfield Elementary",
        "district": "Davis Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062005547",
    },
    {
        "school": "Davis School for Independent Study",
        "district": "Davis Joint Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61062010344",
    },
    {
        "school": "Marguerite Montgomery Elementary",
        "district": "Davis Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062010456",
    },
    {
        "school": "Esparto Elementary",
        "district": "Esparto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61293001469",
    },
    {
        "school": "Esparto High",
        "district": "Esparto Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61293001470",
    },
    {
        "school": "Esparto Middle",
        "district": "Esparto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61293004331",
    },
    {
        "school": "Madison Community High",
        "district": "Esparto Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61293007705",
    },
    {
        "school": "Elkhorn Village Elementary",
        "district": "Washington Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64158006854",
    },
    {
        "school": "River City High",
        "district": "Washington Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64158006857",
    },
    {
        "school": "Westfield Village Elementary",
        "district": "Washington Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64158006858",
    },
    {
        "school": "Westmore Oaks Elementary",
        "district": "Washington Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64158006859",
    },
    {
        "school": "Yolo High",
        "district": "Washington Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64158006860",
    },
    {
        "school": "Southport Elementary",
        "district": "Washington Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64158007936",
    },
    {
        "school": "West Sacramento School for Independent Study",
        "district": "Washington Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64158010139",
    },
    {
        "school": "Shirley Rominger Intermediate",
        "district": "Winters Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64293006985",
    },
    {
        "school": "Winters High",
        "district": "Winters Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64293006986",
    },
    {
        "school": "Winters Middle",
        "district": "Winters Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64293006987",
    },
    {
        "school": "Wolfskill High",
        "district": "Winters Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64293007372",
    },
    {
        "school": "Beamer Elementary",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308006998",
    },
    {
        "school": "Dingle Elementary",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308006999",
    },
    {
        "school": "Freeman Elementary",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308007001",
    },
    {
        "school": "Gibson Elementary",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308007002",
    },
    {
        "school": "Lee Middle",
        "district": "Woodland Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308007005",
    },
    {
        "school": "Plainfield Elementary",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308007006",
    },
    {
        "school": "Rhoda Maxwell Elementary",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308007007",
    },
    {
        "school": "T. L. Whitehead Elementary",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308007008",
    },
    {
        "school": "Cache Creek High (Continuation)",
        "district": "Woodland Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64308007010",
    },
    {
        "school": "Woodland Senior High",
        "district": "Woodland Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308007011",
    },
    {
        "school": "Zamora Elementary",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308007012",
    },
    {
        "school": "Douglass Middle",
        "district": "Woodland Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308007901",
    },
    {
        "school": "Woodland Community Day",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64308008434",
    },
    {
        "school": "Ramon S. Tafoya Elementary",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308008435",
    },
    {
        "school": "Woodland Prairie Elementary",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308009466",
    },
    {
        "school": "Yolo County Special Education",
        "district": "Yolo County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104907243",
    },
    {
        "school": "Dan Jacobs",
        "district": "Yolo County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104910343",
    },
    {
        "school": "Mission Trails ROP",
        "district": "Mission Trails ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60012010972",
    },
    {
        "school": "Dr. Martin Luther King Jr. Academy",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195010559",
    },
    {
        "school": "King City Arts Magnet",
        "district": "King City Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61968010969",
    },
    {
        "school": "Boronda Meadows",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393010970",
    },
    {
        "school": "Carr Lake Community Day",
        "district": "Salinas Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63398010561",
    },
    {
        "school": "McKinnon",
        "district": "Santa Rita Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63579010562",
    },
    {
        "school": "New Republic Elementary",
        "district": "Santa Rita Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63579010971",
    },
    {
        "school": "Pinnacles High",
        "district": "Soledad Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63705010973",
    },
    {
        "school": "Frank Ledesma Elementary",
        "district": "Soledad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63705010974",
    },
    {
        "school": "Salinas Community",
        "district": "Monterey County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102110557",
    },
    {
        "school": "Pacific Valley (K-12)",
        "district": "Big Sur Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003109475",
    },
    {
        "school": "Gonzales High",
        "district": "Gonzales Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004607183",
    },
    {
        "school": "Fairview Middle",
        "district": "Gonzales Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004607184",
    },
    {
        "school": "La Gloria Elementary",
        "district": "Gonzales Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004607185",
    },
    {
        "school": "Alisal Community",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195000082",
    },
    {
        "school": "Bardin Elementary",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195000083",
    },
    {
        "school": "Fremont Elementary",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195000084",
    },
    {
        "school": "Jesse G. Sanchez Elementary",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195000085",
    },
    {
        "school": "Cesar E. Chavez Elementary",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195006050",
    },
    {
        "school": "Creekside Elementary",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195007550",
    },
    {
        "school": "Frank Paul Elementary",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195007639",
    },
    {
        "school": "Oscar F. Loya Elementary",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195008530",
    },
    {
        "school": "Virginia Rocca Barton Elementary",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195009111",
    },
    {
        "school": "John E. Steinbeck Elementary",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195009694",
    },
    {
        "school": "Bitterwater-Tully Elementary",
        "district": "Bitterwater-Tully Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60519000492",
    },
    {
        "school": "Bradley Elementary",
        "district": "Bradley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60573000519",
    },
    {
        "school": "Captain Cooper Elementary",
        "district": "Carmel Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60753000716",
    },
    {
        "school": "Carmel Valley High",
        "district": "Carmel Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60753000717",
    },
    {
        "school": "Carmel High",
        "district": "Carmel Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60753000718",
    },
    {
        "school": "Carmel Middle",
        "district": "Carmel Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60753000719",
    },
    {
        "school": "Carmel River Elementary",
        "district": "Carmel Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60753000720",
    },
    {
        "school": "Tularcitos Elementary",
        "district": "Carmel Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60753000723",
    },
    {
        "school": "Chualar Elementary",
        "district": "Chualar Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60858000854",
    },
    {
        "school": "Graves Elementary",
        "district": "Graves Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61587002002",
    },
    {
        "school": "Mary Chapa Academy",
        "district": "Greenfield Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61608002009",
    },
    {
        "school": "Cesar Chavez Elementary",
        "district": "Greenfield Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61608002256",
    },
    {
        "school": "Vista Verde Middle",
        "district": "Greenfield Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61608002266",
    },
    {
        "school": "Oak Avenue Elementary",
        "district": "Greenfield Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61608008852",
    },
    {
        "school": "King City High",
        "district": "South Monterey County Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61965002360",
    },
    {
        "school": "Portola-Butler Continuation High",
        "district": "South Monterey County Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61965007734",
    },
    {
        "school": "Greenfield High",
        "district": "South Monterey County Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61965008221",
    },
    {
        "school": "Chalone Peaks Middle",
        "district": "King City Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61968002361",
    },
    {
        "school": "Santa Lucia Elementary",
        "district": "King City Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61968002362",
    },
    {
        "school": "Del Rey Elementary",
        "district": "King City Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61968009146",
    },
    {
        "school": "Lagunita Elementary",
        "district": "Lagunita Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62049002472",
    },
    {
        "school": "Mission Elementary",
        "district": "Mission Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62511003725",
    },
    {
        "school": "Seaside Middle",
        "district": "Monterey Peninsula Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003341",
    },
    {
        "school": "Walter Colton",
        "district": "Monterey Peninsula Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003818",
    },
    {
        "school": "J. C. Crumpton Elementary",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003820",
    },
    {
        "school": "Central Coast High",
        "district": "Monterey Peninsula Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62553003821",
    },
    {
        "school": "Del Rey Woods Elementary",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003823",
    },
    {
        "school": "Foothill Elementary",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003825",
    },
    {
        "school": "Highland Elementary",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003828",
    },
    {
        "school": "Martin Luther King",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003829",
    },
    {
        "school": "La Mesa Elementary",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003830",
    },
    {
        "school": "Los Arboles Middle",
        "district": "Monterey Peninsula Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003832",
    },
    {
        "school": "George C. Marshall Elementary",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003837",
    },
    {
        "school": "Monterey High",
        "district": "Monterey Peninsula Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003839",
    },
    {
        "school": "Ione Olson Elementary",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003840",
    },
    {
        "school": "Ord Terrace Elementary",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003841",
    },
    {
        "school": "Seaside High",
        "district": "Monterey Peninsula Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553003843",
    },
    {
        "school": "Marina Vista Elementary",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553007181",
    },
    {
        "school": "Central Bay High (Continuation)",
        "district": "North Monterey County Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62759000684",
    },
    {
        "school": "Castroville Elementary",
        "district": "North Monterey County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62759004140",
    },
    {
        "school": "Echo Valley Elementary",
        "district": "North Monterey County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62759004141",
    },
    {
        "school": "Elkhorn Elementary",
        "district": "North Monterey County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62759004143",
    },
    {
        "school": "North Monterey County Middle",
        "district": "North Monterey County Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62759004144",
    },
    {
        "school": "North Monterey County High",
        "district": "North Monterey County Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62759004146",
    },
    {
        "school": "Prunedale Elementary",
        "district": "North Monterey County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62759004147",
    },
    {
        "school": "North Monterey County Center for Independent Study",
        "district": "North Monterey County Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62759009412",
    },
    {
        "school": "Robert Down Elementary",
        "district": "Pacific Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62937004527",
    },
    {
        "school": "Forest Grove Elementary",
        "district": "Pacific Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62937004528",
    },
    {
        "school": "Pacific Grove High",
        "district": "Pacific Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62937004530",
    },
    {
        "school": "Pacific Grove Middle",
        "district": "Pacific Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62937004531",
    },
    {
        "school": "Community High (Continuation)",
        "district": "Pacific Grove Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62937007329",
    },
    {
        "school": "Boronda Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393005319",
    },
    {
        "school": "El Gabilan Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393005320",
    },
    {
        "school": "Henry F. Kammann Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393005321",
    },
    {
        "school": "Loma Vista Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393005323",
    },
    {
        "school": "Los Padres Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393005324",
    },
    {
        "school": "Mission Park Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393005325",
    },
    {
        "school": "Monterey Park Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393005326",
    },
    {
        "school": "Natividad Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393005327",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393005328",
    },
    {
        "school": "Sherwood Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393005329",
    },
    {
        "school": "University Park Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393005331",
    },
    {
        "school": "Laurel Wood Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393010045",
    },
    {
        "school": "Harden Middle",
        "district": "Salinas Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63398000677",
    },
    {
        "school": "Everett Alvarez High",
        "district": "Salinas Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63398004694",
    },
    {
        "school": "Alisal High",
        "district": "Salinas Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63398005332",
    },
    {
        "school": "El Sausal Middle",
        "district": "Salinas Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63398005333",
    },
    {
        "school": "Mount Toro High",
        "district": "Salinas Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63398005334",
    },
    {
        "school": "North Salinas High",
        "district": "Salinas Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63398005335",
    },
    {
        "school": "Salinas High",
        "district": "Salinas Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63398005336",
    },
    {
        "school": "Washington Middle",
        "district": "Salinas Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63398005337",
    },
    {
        "school": "La Paz Middle",
        "district": "Salinas Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63398008745",
    },
    {
        "school": "San Antonio Elementary",
        "district": "San Antonio Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63405005342",
    },
    {
        "school": "San Ardo Elementary",
        "district": "San Ardo Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63408005343",
    },
    {
        "school": "San Lucas Elementary",
        "district": "San Lucas Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63477005866",
    },
    {
        "school": "La Joya Elementary",
        "district": "Santa Rita Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63579006115",
    },
    {
        "school": "Santa Rita Elementary",
        "district": "Santa Rita Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63579006116",
    },
    {
        "school": "Gavilan View Middle",
        "district": "Santa Rita Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63579007870",
    },
    {
        "school": "Main Street Middle",
        "district": "Soledad Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63705006291",
    },
    {
        "school": "San Vicente Elementary",
        "district": "Soledad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63705006292",
    },
    {
        "school": "Soledad High",
        "district": "Soledad Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63705008225",
    },
    {
        "school": "Rose Ferrero Elementary",
        "district": "Soledad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63705008746",
    },
    {
        "school": "Gabilan Elementary",
        "district": "Soledad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63705008988",
    },
    {
        "school": "Spreckels Elementary",
        "district": "Spreckels Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63771006381",
    },
    {
        "school": "Buena Vista Middle",
        "district": "Spreckels Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63771007565",
    },
    {
        "school": "San Benancio Middle",
        "district": "Washington Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64161006861",
    },
    {
        "school": "Toro Park Elementary",
        "district": "Washington Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64161006862",
    },
    {
        "school": "Washington Elementary",
        "district": "Washington Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64161006863",
    },
    {
        "school": "Monterey County Special Education",
        "district": "Monterey County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102107551",
    },
    {
        "school": "Monterey County Home Charter",
        "district": "Monterey County Office of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102108529",
    },
    {
        "school": "Wellington M. Smith Jr.",
        "district": "Monterey County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102109234",
    },
    {
        "school": "Valley Center Prep",
        "district": "Valley Center-Pauma Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006910646",
    },
    {
        "school": "Lilac",
        "district": "Valley Center-Pauma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006911158",
    },
    {
        "school": "San Diego County ROP",
        "district": "San Diego County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60013811406",
    },
    {
        "school": "Sevick Special Education",
        "district": "Cajon Valley Union",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681011752",
    },
    {
        "school": "Calavera Hills Elementary",
        "district": "Carlsbad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750010643",
    },
    {
        "school": "Calavera Hills Middle",
        "district": "Carlsbad Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750011402",
    },
    {
        "school": "Liberty Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861011125",
    },
    {
        "school": "Salt Creek Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861011126",
    },
    {
        "school": "Veterans Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861011127",
    },
    {
        "school": "Hedenkamp (Anne and William) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861011227",
    },
    {
        "school": "Torrey Hills",
        "district": "Del Mar Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61074010627",
    },
    {
        "school": "Sycamore Ridge",
        "district": "Del Mar Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61074011753",
    },
    {
        "school": "Bear Valley Middle",
        "district": "Escondido Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288011128",
    },
    {
        "school": "Farr Avenue Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288011129",
    },
    {
        "school": "Reidy Creek Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288011130",
    },
    {
        "school": "Bernardo Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288011131",
    },
    {
        "school": "Elite Academy",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61623010628",
    },
    {
        "school": "Grossmont Middle College High",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61623010630",
    },
    {
        "school": "Nichols Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825010645",
    },
    {
        "school": "Westview High",
        "district": "Poway Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153010632",
    },
    {
        "school": "Stone Ranch Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153011133",
    },
    {
        "school": "Oak Valley Middle",
        "district": "Poway Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153011134",
    },
    {
        "school": "Future Bound Independent Study Secondary",
        "district": "Ramona City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63171011172",
    },
    {
        "school": "Creative Performing and Media Arts",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432010635",
    },
    {
        "school": "San Diego International Studies",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011140",
    },
    {
        "school": "San Diego Business/Leadership",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011143",
    },
    {
        "school": "Kearny Digital Media & Design",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011145",
    },
    {
        "school": "Kearny School of Biomedical Science and Technology",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011146",
    },
    {
        "school": "Kearny College Connections",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011147",
    },
    {
        "school": "Kearny Eng Innov & Design",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011148",
    },
    {
        "school": "Crawford High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011149",
    },
    {
        "school": "San Diego Science and Technology",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011153",
    },
    {
        "school": "San Diego Metro Career and Tech",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63432011154",
    },
    {
        "school": "Golden Hill K-8",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011157",
    },
    {
        "school": "TRACE",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63432011235",
    },
    {
        "school": "Porter Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011382",
    },
    {
        "school": "Cherokee Point Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011383",
    },
    {
        "school": "Ibarra Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432011384",
    },
    {
        "school": "Canyon Crest Academy",
        "district": "San Dieguito Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63438011396",
    },
    {
        "school": "San Elijo Middle",
        "district": "San Marcos Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488011403",
    },
    {
        "school": "Mission Hills High",
        "district": "San Marcos Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488011404",
    },
    {
        "school": "Santee Success Program",
        "district": "Santee",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63588010639",
    },
    {
        "school": "Solana Pacific Elementary",
        "district": "Solana Beach Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63699011397",
    },
    {
        "school": "San Ysidro High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864010642",
    },
    {
        "school": "Otay Ranch Senior High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864011264",
    },
    {
        "school": "Eastlake Middle",
        "district": "Sweetwater Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864011269",
    },
    {
        "school": "T.H.E Leadership Academy",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119011270",
    },
    {
        "school": "Hannalei Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119011280",
    },
    {
        "school": "Foothill Oak Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119011400",
    },
    {
        "school": "North Coastal Consortium Schools",
        "district": "San Diego County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69103010620",
    },
    {
        "school": "Warner Junior/Senior High",
        "district": "Warner Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004205341",
    },
    {
        "school": "San Jose Valley Continuation High",
        "district": "Warner Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004206527",
    },
    {
        "school": "Warner Elementary",
        "district": "Warner Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004206844",
    },
    {
        "school": "Valley Center High",
        "district": "Valley Center-Pauma Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006908607",
    },
    {
        "school": "Oak Glen High",
        "district": "Valley Center-Pauma Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006908608",
    },
    {
        "school": "Pauma Elementary",
        "district": "Valley Center-Pauma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006908610",
    },
    {
        "school": "Valley Center Middle",
        "district": "Valley Center-Pauma Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006908612",
    },
    {
        "school": "Valley Center Primary",
        "district": "Valley Center-Pauma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006908613",
    },
    {
        "school": "Valley Center Elementary",
        "district": "Valley Center-Pauma Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006908614",
    },
    {
        "school": "Joan MacQueen Middle",
        "district": "Alpine Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210000092",
    },
    {
        "school": "Mountain View Learning Academy",
        "district": "Alpine Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60210007300",
    },
    {
        "school": "Shadow Hills Elementary",
        "district": "Alpine Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210009112",
    },
    {
        "school": "Boulder Oaks Elementary",
        "district": "Alpine Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210009696",
    },
    {
        "school": "Creekside Early Learning Center",
        "district": "Alpine Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210010375",
    },
    {
        "school": "Borrego Springs Elementary",
        "district": "Borrego Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60570000517",
    },
    {
        "school": "Borrego Springs High",
        "district": "Borrego Springs Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60570000518",
    },
    {
        "school": "Borrego Springs Middle",
        "district": "Borrego Springs Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60570007636",
    },
    {
        "school": "Anza Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000603",
    },
    {
        "school": "Avocado Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000604",
    },
    {
        "school": "Bostonia Language Academy",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000606",
    },
    {
        "school": "Cajon Valley Middle",
        "district": "Cajon Valley Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000607",
    },
    {
        "school": "Chase Avenue Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000608",
    },
    {
        "school": "Crest Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000609",
    },
    {
        "school": "Emerald Middle",
        "district": "Cajon Valley Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000612",
    },
    {
        "school": "Flying Hills School of Arts",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000613",
    },
    {
        "school": "Fuerte Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000614",
    },
    {
        "school": "Greenfield Middle",
        "district": "Cajon Valley Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000615",
    },
    {
        "school": "W. D. Hall Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000616",
    },
    {
        "school": "Johnson Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000617",
    },
    {
        "school": "Lexington Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000618",
    },
    {
        "school": "Madison Avenue Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000619",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000620",
    },
    {
        "school": "Meridian Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000621",
    },
    {
        "school": "Montgomery Middle",
        "district": "Cajon Valley Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000622",
    },
    {
        "school": "Naranca Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000623",
    },
    {
        "school": "Rios Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681000624",
    },
    {
        "school": "Jamacha Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681001165",
    },
    {
        "school": "Blossom Valley Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681003925",
    },
    {
        "school": "Hillsdale Middle",
        "district": "Cajon Valley Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681005234",
    },
    {
        "school": "Vista Grande Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681007655",
    },
    {
        "school": "Cajon Valley Home",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60681008590",
    },
    {
        "school": "Rancho San Diego Elementary",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60681008802",
    },
    {
        "school": "Ada W. Harris Elementary",
        "district": "Cardiff Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60747000706",
    },
    {
        "school": "Cardiff Elementary",
        "district": "Cardiff Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60747000707",
    },
    {
        "school": "Buena Vista Elementary",
        "district": "Carlsbad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750000708",
    },
    {
        "school": "Carlsbad High",
        "district": "Carlsbad Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750000709",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Carlsbad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750000710",
    },
    {
        "school": "Kelly Elementary",
        "district": "Carlsbad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750000711",
    },
    {
        "school": "Carlsbad Village Academy",
        "district": "Carlsbad Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60750000712",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Carlsbad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750000713",
    },
    {
        "school": "Valley Middle",
        "district": "Carlsbad Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750000715",
    },
    {
        "school": "Carlsbad Seaside Academy",
        "district": "Carlsbad Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60750008311",
    },
    {
        "school": "Pacific Rim Elementary",
        "district": "Carlsbad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750008312",
    },
    {
        "school": "Aviara Oaks Middle",
        "district": "Carlsbad Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750008606",
    },
    {
        "school": "Hope Elementary",
        "district": "Carlsbad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750009120",
    },
    {
        "school": "Aviara Oaks Elementary",
        "district": "Carlsbad Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750009747",
    },
    {
        "school": "Allen (Ella B.) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000855",
    },
    {
        "school": "Castle Park Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000856",
    },
    {
        "school": "Cook (Hazel Goes) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000857",
    },
    {
        "school": "Finney (Myrtle S.) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000859",
    },
    {
        "school": "Halecrest Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000860",
    },
    {
        "school": "Harborside Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000861",
    },
    {
        "school": "Hilltop Drive Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000862",
    },
    {
        "school": "Juarez-Lincoln Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000863",
    },
    {
        "school": "Kellogg (Karl H.) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000864",
    },
    {
        "school": "Lauderbach (J. Calvin) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000865",
    },
    {
        "school": "Loma Verde Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000866",
    },
    {
        "school": "Los Altos Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000867",
    },
    {
        "school": "Montgomery (John J.) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000868",
    },
    {
        "school": "Palomar Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000871",
    },
    {
        "school": "Parkview Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000872",
    },
    {
        "school": "Rice (Lilian J.) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000873",
    },
    {
        "school": "Rogers (Greg) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000874",
    },
    {
        "school": "Rohr (Fred H.) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000875",
    },
    {
        "school": "Rosebank Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000876",
    },
    {
        "school": "Silver Wing Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000877",
    },
    {
        "school": "Sunnyside Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000878",
    },
    {
        "school": "Tiffany (Burton C.) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000879",
    },
    {
        "school": "Valle Lindo Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000880",
    },
    {
        "school": "Valley Vista Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000881",
    },
    {
        "school": "Vista Square Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861000882",
    },
    {
        "school": "Olympic View Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861005253",
    },
    {
        "school": "Casillas (Joseph) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861007646",
    },
    {
        "school": "Otay Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861007680",
    },
    {
        "school": "Marshall (Thurgood) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861008298",
    },
    {
        "school": "Chula Vista Hills Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861009350",
    },
    {
        "school": "EastLake Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861009529",
    },
    {
        "school": "Clear View",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861010307",
    },
    {
        "school": "Heritage Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861010376",
    },
    {
        "school": "McMillin (Corky) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861010377",
    },
    {
        "school": "Coronado Village Elementary",
        "district": "Coronado Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60987001070",
    },
    {
        "school": "Coronado High",
        "district": "Coronado Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60987001071",
    },
    {
        "school": "Coronado Middle",
        "district": "Coronado Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60987001072",
    },
    {
        "school": "Silver Strand Elementary",
        "district": "Coronado Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60987001074",
    },
    {
        "school": "Dehesa Elementary",
        "district": "Dehesa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61071001188",
    },
    {
        "school": "Carmel Del Mar Elementary",
        "district": "Del Mar Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61074001171",
    },
    {
        "school": "Del Mar Heights Elementary",
        "district": "Del Mar Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61074001189",
    },
    {
        "school": "Del Mar Hills Elementary",
        "district": "Del Mar Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61074001190",
    },
    {
        "school": "Ashley Falls Elementary",
        "district": "Del Mar Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61074007660",
    },
    {
        "school": "Sage Canyon",
        "district": "Del Mar Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61074008591",
    },
    {
        "school": "Capri Elementary",
        "district": "Encinitas Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61275001433",
    },
    {
        "school": "Paul Ecke-Central Elementary",
        "district": "Encinitas Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61275001434",
    },
    {
        "school": "Flora Vista Elementary",
        "district": "Encinitas Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61275001435",
    },
    {
        "school": "Ocean Knoll Elementary",
        "district": "Encinitas Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61275001436",
    },
    {
        "school": "Park Dale Lane Elementary",
        "district": "Encinitas Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61275001438",
    },
    {
        "school": "Olivenhain Pioneer Elementary",
        "district": "Encinitas Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61275003928",
    },
    {
        "school": "El Camino Creek Elementary",
        "district": "Encinitas Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61275008592",
    },
    {
        "school": "La Costa Heights Elementary",
        "district": "Encinitas Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61275008830",
    },
    {
        "school": "Mission Estancia Elementary",
        "district": "Encinitas Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61275009537",
    },
    {
        "school": "Pioneer Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001172",
    },
    {
        "school": "Central Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001451",
    },
    {
        "school": "Conway Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001452",
    },
    {
        "school": "Del Dios Academy of Arts and Sciences",
        "district": "Escondido Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001453",
    },
    {
        "school": "Felicita Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001454",
    },
    {
        "school": "Glen View Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001455",
    },
    {
        "school": "Mission Middle",
        "district": "Escondido Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001456",
    },
    {
        "school": "Hidden Valley Middle",
        "district": "Escondido Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001457",
    },
    {
        "school": "Juniper Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001458",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001459",
    },
    {
        "school": "Miller Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001460",
    },
    {
        "school": "Oak Hill Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001462",
    },
    {
        "school": "Orange Glen Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001463",
    },
    {
        "school": "Rose Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288001464",
    },
    {
        "school": "Rock Springs Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288003933",
    },
    {
        "school": "North Broadway Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288007704",
    },
    {
        "school": "Rincon Middle",
        "district": "Escondido Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288008833",
    },
    {
        "school": "L. R. Green Elementary",
        "district": "Escondido Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288009538",
    },
    {
        "school": "Escondido High",
        "district": "Escondido Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61291001465",
    },
    {
        "school": "Orange Glen High",
        "district": "Escondido Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61291001466",
    },
    {
        "school": "San Pasqual High",
        "district": "Escondido Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61291001467",
    },
    {
        "school": "Valley High (Continuation)",
        "district": "Escondido Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61291001468",
    },
    {
        "school": "Fallbrook STEM Academy",
        "district": "Fallbrook Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61350001539",
    },
    {
        "school": "James E. Potter Intermediate",
        "district": "Fallbrook Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61350001540",
    },
    {
        "school": "La Paloma Elementary",
        "district": "Fallbrook Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61350001541",
    },
    {
        "school": "Mary Fay Pendleton Elementary",
        "district": "Fallbrook Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61350001543",
    },
    {
        "school": "San Onofre Elementary",
        "district": "Fallbrook Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61350001544",
    },
    {
        "school": "Fallbrook Homeschool Academy",
        "district": "Fallbrook Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61350007305",
    },
    {
        "school": "William H. Frazier Elementary",
        "district": "Fallbrook Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61350008301",
    },
    {
        "school": "Live Oak Elementary",
        "district": "Fallbrook Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61350009817",
    },
    {
        "school": "Fallbrook High",
        "district": "Fallbrook Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61353001545",
    },
    {
        "school": "Ivy High (Continuation)",
        "district": "Fallbrook Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61353001546",
    },
    {
        "school": "Oasis High (Alternative)",
        "district": "Fallbrook Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61353005258",
    },
    {
        "school": "Chaparral High",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61623002017",
    },
    {
        "school": "El Cajon Valley High",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61623002018",
    },
    {
        "school": "El Capitan High",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61623002019",
    },
    {
        "school": "Granite Hills High",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61623002020",
    },
    {
        "school": "Grossmont High",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61623002022",
    },
    {
        "school": "Monte Vista High",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61623002024",
    },
    {
        "school": "Mount Miguel High",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61623002025",
    },
    {
        "school": "Santana High",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61623002026",
    },
    {
        "school": "Valhalla High",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61623002028",
    },
    {
        "school": "West Hills High",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61623009141",
    },
    {
        "school": "Jamul Elementary",
        "district": "Jamul-Dulzura Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61873002273",
    },
    {
        "school": "Oak Grove Middle",
        "district": "Jamul-Dulzura Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61873002274",
    },
    {
        "school": "Julian High",
        "district": "Julian Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61911002305",
    },
    {
        "school": "Julian Elementary",
        "district": "Julian Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61914002306",
    },
    {
        "school": "Julian Junior High",
        "district": "Julian Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61914008859",
    },
    {
        "school": "Avondale Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002424",
    },
    {
        "school": "Bancroft Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002425",
    },
    {
        "school": "Casa de Oro Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002427",
    },
    {
        "school": "Fletcher Hills Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002428",
    },
    {
        "school": "Highlands Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002429",
    },
    {
        "school": "Kempton Street Literacy Academy",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002430",
    },
    {
        "school": "La Mesa Dale Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002431",
    },
    {
        "school": "La Mesa Arts Academy",
        "district": "La Mesa-Spring Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002432",
    },
    {
        "school": "La Presa Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002433",
    },
    {
        "school": "Sci Tech Engr Arts and Math Acad at La Presa",
        "district": "La Mesa-Spring Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002434",
    },
    {
        "school": "Lemon Avenue Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002435",
    },
    {
        "school": "Loma Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002436",
    },
    {
        "school": "Maryland Avenue Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002437",
    },
    {
        "school": "Murdock Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002438",
    },
    {
        "school": "Murray Manor Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002439",
    },
    {
        "school": "Northmont Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002440",
    },
    {
        "school": "Parkway Middle",
        "district": "La Mesa-Spring Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002441",
    },
    {
        "school": "Rancho Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002442",
    },
    {
        "school": "Rolando Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002443",
    },
    {
        "school": "Spring Valley Academy",
        "district": "La Mesa-Spring Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002445",
    },
    {
        "school": "Sweetwater Springs Elementary",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025002634",
    },
    {
        "school": "Lakeside Farms Elementary",
        "district": "Lakeside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62079002493",
    },
    {
        "school": "Lakeside Middle",
        "district": "Lakeside Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62079002494",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Lakeside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62079002495",
    },
    {
        "school": "Lindo Park Elementary",
        "district": "Lakeside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62079002496",
    },
    {
        "school": "Riverview Elementary",
        "district": "Lakeside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62079002497",
    },
    {
        "school": "Tierra del Sol Middle",
        "district": "Lakeside Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62079002498",
    },
    {
        "school": "Winter Gardens Elementary",
        "district": "Lakeside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62079002499",
    },
    {
        "school": "Lemon Crest Elementary",
        "district": "Lakeside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62079010310",
    },
    {
        "school": "Lemon Grove Academy for the Sciences and Humanities",
        "district": "Lemon Grove",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62133002549",
    },
    {
        "school": "Monterey Heights Elementary",
        "district": "Lemon Grove",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62133002551",
    },
    {
        "school": "Mt. Vernon",
        "district": "Lemon Grove",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62133002552",
    },
    {
        "school": "San Altos Elementary",
        "district": "Lemon Grove",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62133002554",
    },
    {
        "school": "San Miguel Elementary",
        "district": "Lemon Grove",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62133002555",
    },
    {
        "school": "Vista La Mesa Academy",
        "district": "Lemon Grove",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62133002556",
    },
    {
        "school": "Campo High (Continuation)",
        "district": "Mountain Empire Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62610002661",
    },
    {
        "school": "Campo Elementary",
        "district": "Mountain Empire Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62610003900",
    },
    {
        "school": "Clover Flat Elementary",
        "district": "Mountain Empire Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62610003901",
    },
    {
        "school": "Descanso Elementary",
        "district": "Mountain Empire Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62610003902",
    },
    {
        "school": "Mountain Empire High",
        "district": "Mountain Empire Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62610003906",
    },
    {
        "school": "Potrero Elementary",
        "district": "Mountain Empire Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62610003909",
    },
    {
        "school": "Hillside Junior/Senior High",
        "district": "Mountain Empire Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62610006496",
    },
    {
        "school": "Cottonwood Community Day",
        "district": "Mountain Empire Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62610007309",
    },
    {
        "school": "Central Elementary",
        "district": "National Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62667004042",
    },
    {
        "school": "El Toyon Elementary",
        "district": "National Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62667004043",
    },
    {
        "school": "Ira Harbison",
        "district": "National Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62667004044",
    },
    {
        "school": "Kimball",
        "district": "National Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62667004045",
    },
    {
        "school": "Las Palmas",
        "district": "National Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62667004046",
    },
    {
        "school": "Lincoln Acres",
        "district": "National Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62667004047",
    },
    {
        "school": "Olivewood",
        "district": "National Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62667004048",
    },
    {
        "school": "John A. Otis Elementary",
        "district": "National Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62667004049",
    },
    {
        "school": "Palmer Way",
        "district": "National Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62667004050",
    },
    {
        "school": "Rancho de la Nacion",
        "district": "National Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62667009590",
    },
    {
        "school": "Martin Luther King Jr. Middle",
        "district": "Oceanside Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825003970",
    },
    {
        "school": "Del Rio Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004357",
    },
    {
        "school": "E. G. Garrison Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004359",
    },
    {
        "school": "El Camino High",
        "district": "Oceanside Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004360",
    },
    {
        "school": "Jefferson Middle",
        "district": "Oceanside Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004361",
    },
    {
        "school": "Laurel Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004362",
    },
    {
        "school": "Libby Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004363",
    },
    {
        "school": "Lincoln Middle",
        "district": "Oceanside Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004364",
    },
    {
        "school": "Mission Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004365",
    },
    {
        "school": "North Terrace Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004366",
    },
    {
        "school": "Ocean Shores High (Continuation)",
        "district": "Oceanside Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62825004367",
    },
    {
        "school": "Oceanside High",
        "district": "Oceanside Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004368",
    },
    {
        "school": "Palmquist Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004370",
    },
    {
        "school": "San Luis Rey Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004371",
    },
    {
        "school": "Santa Margarita Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004373",
    },
    {
        "school": "South Oceanside Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825004374",
    },
    {
        "school": "Stuart Mesa Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825007717",
    },
    {
        "school": "Reynolds Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825009169",
    },
    {
        "school": "Christa McAuliffe Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825009597",
    },
    {
        "school": "Ivey Ranch Elementary",
        "district": "Oceanside Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62825010311",
    },
    {
        "school": "Adobe Bluffs Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153001203",
    },
    {
        "school": "Highland Ranch Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153001204",
    },
    {
        "school": "Mesa Verde Middle",
        "district": "Poway Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153002667",
    },
    {
        "school": "Park Village Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153003938",
    },
    {
        "school": "Abraxas Continuation High",
        "district": "Poway Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63153004883",
    },
    {
        "school": "Black Mountain Middle",
        "district": "Poway Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004884",
    },
    {
        "school": "Chaparral Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004885",
    },
    {
        "school": "Garden Road Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004886",
    },
    {
        "school": "Los Penasquitos Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004887",
    },
    {
        "school": "Meadowbrook Middle",
        "district": "Poway Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004888",
    },
    {
        "school": "Midland Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004889",
    },
    {
        "school": "Mt. Carmel High",
        "district": "Poway Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004890",
    },
    {
        "school": "Painted Rock Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004891",
    },
    {
        "school": "Pomerado Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004892",
    },
    {
        "school": "Poway High",
        "district": "Poway Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004893",
    },
    {
        "school": "Rolling Hills Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004894",
    },
    {
        "school": "Sundance Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004895",
    },
    {
        "school": "Sunset Hills Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004896",
    },
    {
        "school": "Tierra Bonita Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004897",
    },
    {
        "school": "Twin Peaks Middle",
        "district": "Poway Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004898",
    },
    {
        "school": "Valley Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004899",
    },
    {
        "school": "Westwood Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153004900",
    },
    {
        "school": "Shoal Creek Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153007679",
    },
    {
        "school": "Creekside Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153008598",
    },
    {
        "school": "Canyon View Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153009180",
    },
    {
        "school": "Bernardo Heights Middle",
        "district": "Poway Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153009425",
    },
    {
        "school": "Rancho Bernardo High",
        "district": "Poway Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153010004",
    },
    {
        "school": "Deer Canyon Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153010005",
    },
    {
        "school": "Morning Creek Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153010006",
    },
    {
        "school": "Turtleback Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153010007",
    },
    {
        "school": "Barnett Elementary",
        "district": "Ramona City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63171001207",
    },
    {
        "school": "Hanson Elementary",
        "district": "Ramona City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63171004905",
    },
    {
        "school": "Montecito High (Continuation)",
        "district": "Ramona City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63171004906",
    },
    {
        "school": "Ramona Elementary",
        "district": "Ramona City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63171004907",
    },
    {
        "school": "Ramona High",
        "district": "Ramona City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63171004908",
    },
    {
        "school": "James Dukes Elementary",
        "district": "Ramona City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63171008943",
    },
    {
        "school": "Olive Peirce Middle",
        "district": "Ramona City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63171008944",
    },
    {
        "school": "Mountain Valley Academy",
        "district": "Ramona City Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63171008945",
    },
    {
        "school": "Mt. Woodson Elementary",
        "district": "Ramona City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63171009617",
    },
    {
        "school": "R. Roger Rowe Elementary",
        "district": "Rancho Santa Fe Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63174004910",
    },
    {
        "school": "R. Roger Rowe Middle",
        "district": "Rancho Santa Fe Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63174004911",
    },
    {
        "school": "Scripps Ranch High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432002688",
    },
    {
        "school": "Kumeyaay Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432003952",
    },
    {
        "school": "Nye Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432003954",
    },
    {
        "school": "Language Academy",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005275",
    },
    {
        "school": "Dingeman Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005330",
    },
    {
        "school": "Adams Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005407",
    },
    {
        "school": "Alcott Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005408",
    },
    {
        "school": "Angier Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005410",
    },
    {
        "school": "Audubon K-8",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005411",
    },
    {
        "school": "Baker Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005412",
    },
    {
        "school": "Balboa Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005413",
    },
    {
        "school": "Barnard Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005414",
    },
    {
        "school": "Bay Park Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005416",
    },
    {
        "school": "Bell Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005419",
    },
    {
        "school": "Bird Rock Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005421",
    },
    {
        "school": "Birney Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005422",
    },
    {
        "school": "Boone Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005423",
    },
    {
        "school": "Burbank Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005426",
    },
    {
        "school": "Cabrillo Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005427",
    },
    {
        "school": "Cadman Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005428",
    },
    {
        "school": "Carson Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005429",
    },
    {
        "school": "Carver Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005430",
    },
    {
        "school": "Central Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005431",
    },
    {
        "school": "Chesterton Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005432",
    },
    {
        "school": "Chollas/Mead Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005433",
    },
    {
        "school": "Clairemont High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005434",
    },
    {
        "school": "Clay Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005435",
    },
    {
        "school": "Correia Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005437",
    },
    {
        "school": "Crown Point Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005440",
    },
    {
        "school": "Cubberley Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005441",
    },
    {
        "school": "Curie Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005442",
    },
    {
        "school": "Dailard Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005443",
    },
    {
        "school": "Dewey Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005447",
    },
    {
        "school": "Doyle Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005448",
    },
    {
        "school": "Edison Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005449",
    },
    {
        "school": "Emerson/Bandini Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005451",
    },
    {
        "school": "Encanto Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005452",
    },
    {
        "school": "Ericson Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005453",
    },
    {
        "school": "Euclid Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005454",
    },
    {
        "school": "Farb Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005456",
    },
    {
        "school": "Field Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005458",
    },
    {
        "school": "Fletcher Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005459",
    },
    {
        "school": "Florence Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005460",
    },
    {
        "school": "Foster Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005462",
    },
    {
        "school": "Franklin Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005463",
    },
    {
        "school": "Freese Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005464",
    },
    {
        "school": "Fulton K-8",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005466",
    },
    {
        "school": "Gage Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005467",
    },
    {
        "school": "Garfield High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63432005468",
    },
    {
        "school": "Grant K-8",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005469",
    },
    {
        "school": "Green Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005471",
    },
    {
        "school": "Hamilton Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005473",
    },
    {
        "school": "Hancock Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005474",
    },
    {
        "school": "Hardy Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005475",
    },
    {
        "school": "Hawthorne Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005476",
    },
    {
        "school": "Hearst Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005477",
    },
    {
        "school": "Henry High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005479",
    },
    {
        "school": "Hickman Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005480",
    },
    {
        "school": "Holmes Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005481",
    },
    {
        "school": "Hoover High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005482",
    },
    {
        "school": "Horton Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005483",
    },
    {
        "school": "Fay Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005484",
    },
    {
        "school": "Jefferson Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005485",
    },
    {
        "school": "Jerabek Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005486",
    },
    {
        "school": "John Muir Language Academy",
        "district": "San Diego Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005487",
    },
    {
        "school": "Johnson Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005488",
    },
    {
        "school": "Jones Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005489",
    },
    {
        "school": "Juarez Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005490",
    },
    {
        "school": "La Jolla Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005495",
    },
    {
        "school": "La Jolla High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005496",
    },
    {
        "school": "Lafayette Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005497",
    },
    {
        "school": "Pacific View Leadership Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005498",
    },
    {
        "school": "Lewis Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005499",
    },
    {
        "school": "Linda Vista Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005501",
    },
    {
        "school": "Lindbergh/Schweitzer Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005502",
    },
    {
        "school": "Logan K-8",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005503",
    },
    {
        "school": "Loma Portal Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005504",
    },
    {
        "school": "Longfellow K-8",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005505",
    },
    {
        "school": "Perkins K-8",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005506",
    },
    {
        "school": "Madison High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005509",
    },
    {
        "school": "Mann Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005510",
    },
    {
        "school": "Marshall Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005512",
    },
    {
        "school": "Marston Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005513",
    },
    {
        "school": "Marvin Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005514",
    },
    {
        "school": "Mason Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005515",
    },
    {
        "school": "McKinley Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005516",
    },
    {
        "school": "Miller Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005519",
    },
    {
        "school": "Mira Mesa High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005520",
    },
    {
        "school": "Miramar Ranch Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005521",
    },
    {
        "school": "Mission Bay High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005522",
    },
    {
        "school": "Montgomery Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005525",
    },
    {
        "school": "Morse High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005526",
    },
    {
        "school": "Muirlands Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005527",
    },
    {
        "school": "Oak Park Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005529",
    },
    {
        "school": "Ocean Beach Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005530",
    },
    {
        "school": "Pacific Beach Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005531",
    },
    {
        "school": "Pacific Beach Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005532",
    },
    {
        "school": "Paradise Hills Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005533",
    },
    {
        "school": "Penn Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005534",
    },
    {
        "school": "Perry Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005535",
    },
    {
        "school": "Pershing Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005536",
    },
    {
        "school": "Point Loma High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005537",
    },
    {
        "school": "Riley/New Dawn",
        "district": "San Diego Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63432005539",
    },
    {
        "school": "Rolando Park Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005540",
    },
    {
        "school": "Roosevelt International Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005541",
    },
    {
        "school": "Ross Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005542",
    },
    {
        "school": "Rowan Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005543",
    },
    {
        "school": "Sandburg Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005545",
    },
    {
        "school": "Sequoia Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005548",
    },
    {
        "school": "Serra High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005549",
    },
    {
        "school": "Sessions Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005550",
    },
    {
        "school": "Sherman Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005551",
    },
    {
        "school": "Silver Gate Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005552",
    },
    {
        "school": "Spreckels Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005553",
    },
    {
        "school": "Standley Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005554",
    },
    {
        "school": "Sunset View Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005557",
    },
    {
        "school": "Taft Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005558",
    },
    {
        "school": "Tierrasanta Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005559",
    },
    {
        "school": "Toler Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005560",
    },
    {
        "school": "Torrey Pines Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005561",
    },
    {
        "school": "Twain High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63432005562",
    },
    {
        "school": "Valencia Park Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005563",
    },
    {
        "school": "Vista Grande Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005564",
    },
    {
        "school": "Walker Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005565",
    },
    {
        "school": "Wangenheim Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005566",
    },
    {
        "school": "Washington Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005567",
    },
    {
        "school": "Webster Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005568",
    },
    {
        "school": "Wegeforth Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005569",
    },
    {
        "school": "Benchley/Weinberger Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005570",
    },
    {
        "school": "Whitman Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005571",
    },
    {
        "school": "Wilson Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432005573",
    },
    {
        "school": "Clark Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432007316",
    },
    {
        "school": "Kimbrough Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432007317",
    },
    {
        "school": "Chavez Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432007322",
    },
    {
        "school": "Rosa Parks Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432007328",
    },
    {
        "school": "ALBA",
        "district": "San Diego Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63432007682",
    },
    {
        "school": "Dana",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432007683",
    },
    {
        "school": "Marshall Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432007688",
    },
    {
        "school": "Whittier K-12",
        "district": "San Diego Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63432007837",
    },
    {
        "school": "University City High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432007838",
    },
    {
        "school": "Garfield Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432008304",
    },
    {
        "school": "San Diego SCPA",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432008962",
    },
    {
        "school": "Bethune K-8",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432008963",
    },
    {
        "school": "De Portola Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432008964",
    },
    {
        "school": "Zamorano Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432008965",
    },
    {
        "school": "Challenger Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432009189",
    },
    {
        "school": "Mt. Everest Academy",
        "district": "San Diego Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63432009437",
    },
    {
        "school": "Hage Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432010057",
    },
    {
        "school": "Scripps Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432010380",
    },
    {
        "school": "Earl Warren Middle",
        "district": "San Dieguito Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63438005575",
    },
    {
        "school": "Oak Crest Middle",
        "district": "San Dieguito Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63438005576",
    },
    {
        "school": "San Dieguito HS Academy",
        "district": "San Dieguito Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63438005577",
    },
    {
        "school": "Sunset High (Continuation)",
        "district": "San Dieguito Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63438005578",
    },
    {
        "school": "Torrey Pines High",
        "district": "San Dieguito Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63438005579",
    },
    {
        "school": "La Costa Canyon High",
        "district": "San Dieguito Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63438006516",
    },
    {
        "school": "Diegueno Middle",
        "district": "San Dieguito Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63438008186",
    },
    {
        "school": "Carmel Valley Middle",
        "district": "San Dieguito Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63438008307",
    },
    {
        "school": "La Mirada Academy",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488005889",
    },
    {
        "school": "Richland Elementary",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488005890",
    },
    {
        "school": "Twin Oaks High",
        "district": "San Marcos Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63488005891",
    },
    {
        "school": "San Marcos Elementary",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488005892",
    },
    {
        "school": "San Marcos High",
        "district": "San Marcos Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488005893",
    },
    {
        "school": "San Marcos Middle",
        "district": "San Marcos Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488005894",
    },
    {
        "school": "Woodland Park Middle",
        "district": "San Marcos Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488005895",
    },
    {
        "school": "Discovery Elementary",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488007353",
    },
    {
        "school": "Twin Oaks Elementary",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488007719",
    },
    {
        "school": "Carrillo Elementary",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488008314",
    },
    {
        "school": "La Costa Meadows Elementary",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488008974",
    },
    {
        "school": "Knob Hill Elementary",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488009439",
    },
    {
        "school": "Foothills High",
        "district": "San Marcos Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63488009629",
    },
    {
        "school": "Paloma Elementary",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488010068",
    },
    {
        "school": "San Pasqual Union Elementary",
        "district": "San Pasqual Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63504005928",
    },
    {
        "school": "La Mirada Elementary",
        "district": "San Ysidro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63522005963",
    },
    {
        "school": "San Ysidro Middle",
        "district": "San Ysidro Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63522005964",
    },
    {
        "school": "Smythe Elementary",
        "district": "San Ysidro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63522005965",
    },
    {
        "school": "Sunset Elementary",
        "district": "San Ysidro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63522005966",
    },
    {
        "school": "Ocean View Hills",
        "district": "San Ysidro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63522010382",
    },
    {
        "school": "Santee Alternative",
        "district": "Santee",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63588001222",
    },
    {
        "school": "Cajon Park Elementary",
        "district": "Santee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63588006137",
    },
    {
        "school": "Carlton Hills Elementary",
        "district": "Santee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63588006138",
    },
    {
        "school": "Carlton Oaks Elementary",
        "district": "Santee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63588006139",
    },
    {
        "school": "Chet F. Harritt Elementary",
        "district": "Santee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63588006140",
    },
    {
        "school": "Hill Creek Elementary",
        "district": "Santee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63588006141",
    },
    {
        "school": "Pepper Drive Elementary",
        "district": "Santee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63588006142",
    },
    {
        "school": "PRIDE Academy at Prospect Avenue",
        "district": "Santee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63588006143",
    },
    {
        "school": "Rio Seco Elementary",
        "district": "Santee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63588006144",
    },
    {
        "school": "Sycamore Canyon Elementary",
        "district": "Santee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63588006146",
    },
    {
        "school": "Solana Santa Fe Elementary",
        "district": "Solana Beach Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63699002691",
    },
    {
        "school": "Carmel Creek Elementary",
        "district": "Solana Beach Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63699003955",
    },
    {
        "school": "Skyline Elementary",
        "district": "Solana Beach Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63699006283",
    },
    {
        "school": "Solana Vista Elementary",
        "district": "Solana Beach Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63699006284",
    },
    {
        "school": "Solana Highlands Elementary",
        "district": "Solana Beach Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63699009196",
    },
    {
        "school": "Bayside STEAM Academy",
        "district": "South Bay Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738006315",
    },
    {
        "school": "Godfrey G. Berry Elementary",
        "district": "South Bay Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738006316",
    },
    {
        "school": "Central Elementary",
        "district": "South Bay Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738006317",
    },
    {
        "school": "Emory Elementary",
        "district": "South Bay Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738006318",
    },
    {
        "school": "Imperial Beach Charter",
        "district": "South Bay Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738006320",
    },
    {
        "school": "Nestor Language Academy Charter",
        "district": "South Bay Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738006321",
    },
    {
        "school": "George Nicoloff Elementary",
        "district": "South Bay Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738006322",
    },
    {
        "school": "Oneonta Elementary",
        "district": "South Bay Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738006323",
    },
    {
        "school": "Howard Pence Elementary",
        "district": "South Bay Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738006324",
    },
    {
        "school": "Sunnyslope Elementary",
        "district": "South Bay Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738006325",
    },
    {
        "school": "Teofilo Mendoza",
        "district": "South Bay Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738008308",
    },
    {
        "school": "Spencer Valley Elementary",
        "district": "Spencer Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63768006380",
    },
    {
        "school": "Eastlake High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864001223",
    },
    {
        "school": "Bonita Vista Middle",
        "district": "Sweetwater Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006474",
    },
    {
        "school": "Bonita Vista Senior High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006475",
    },
    {
        "school": "Castle Park Middle",
        "district": "Sweetwater Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006476",
    },
    {
        "school": "Castle Park Senior High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006477",
    },
    {
        "school": "Chula Vista Middle",
        "district": "Sweetwater Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006478",
    },
    {
        "school": "Chula Vista Senior High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006479",
    },
    {
        "school": "Granger Junior High",
        "district": "Sweetwater Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006482",
    },
    {
        "school": "Hilltop Middle",
        "district": "Sweetwater Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006483",
    },
    {
        "school": "Hilltop Senior High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006484",
    },
    {
        "school": "Mar Vista Academy",
        "district": "Sweetwater Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006485",
    },
    {
        "school": "Mar Vista Senior High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006486",
    },
    {
        "school": "Montgomery Middle",
        "district": "Sweetwater Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006487",
    },
    {
        "school": "Montgomery Senior High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006488",
    },
    {
        "school": "National City Middle",
        "district": "Sweetwater Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006489",
    },
    {
        "school": "Palomar High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63864006490",
    },
    {
        "school": "Southwest Middle",
        "district": "Sweetwater Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006491",
    },
    {
        "school": "Southwest Senior High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006492",
    },
    {
        "school": "Sweetwater High",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864006495",
    },
    {
        "school": "Rancho del Rey Middle",
        "district": "Sweetwater Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63864007348",
    },
    {
        "school": "Options Secondary",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63864007709",
    },
    {
        "school": "Sweetwater Community Day",
        "district": "Sweetwater Union High",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63864008310",
    },
    {
        "school": "Alta Vista Academy",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63864010385",
    },
    {
        "school": "Vallecitos Elementary",
        "district": "Vallecitos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64071006717",
    },
    {
        "school": "California Avenue Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "64119001246",
    },
    {
        "school": "Breeze Hill Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119001248",
    },
    {
        "school": "Mission Meadows Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119001249",
    },
    {
        "school": "Madison Middle",
        "district": "Vista Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119003968",
    },
    {
        "school": "Alta Vista High (Continuation)",
        "district": "Vista Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64119006812",
    },
    {
        "school": "Beaumont Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119006813",
    },
    {
        "school": "Bobier Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119006814",
    },
    {
        "school": "Casita Center for Science/Math/Technology",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119006816",
    },
    {
        "school": "Grapevine Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119006818",
    },
    {
        "school": "Rancho Minerva Middle",
        "district": "Vista Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119006819",
    },
    {
        "school": "Monte Vista Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119006820",
    },
    {
        "school": "Vista Academy of Visual and Performing Arts",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119006822",
    },
    {
        "school": "Vista Adult Transition Center",
        "district": "Vista Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "64119006823",
    },
    {
        "school": "Vista High",
        "district": "Vista Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119006824",
    },
    {
        "school": "Vista Innovation and Design Academy",
        "district": "Vista Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119006825",
    },
    {
        "school": "Rancho Buena Vista High",
        "district": "Vista Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119009203",
    },
    {
        "school": "Alamosa Park Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119009204",
    },
    {
        "school": "Roosevelt Middle",
        "district": "Vista Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119009459",
    },
    {
        "school": "Lake Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119009460",
    },
    {
        "school": "Empresa Elementary",
        "district": "Vista Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119009652",
    },
    {
        "school": "San Diego County Special Education",
        "district": "San Diego County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69103009244",
    },
    {
        "school": "Tri-Valley ROP",
        "district": "Tri-Valley ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60008410731",
    },
    {
        "school": "Eden Area ROP",
        "district": "Eden Area ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60008510732",
    },
    {
        "school": "Mission Valley ROCP",
        "district": "Mission Valley ROC/P",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60008610733",
    },
    {
        "school": "Alameda Science and Technology Institute",
        "district": "Alameda Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60177010547",
    },
    {
        "school": "Berkeley Technology Academy",
        "district": "Berkeley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60474011300",
    },
    {
        "school": "Core Learning Academy at Conley-Caraballo High",
        "district": "New Haven Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62691011551",
    },
    {
        "school": "Alternative Learning Academy at Conley-Caraballo High",
        "district": "New Haven Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62691011552",
    },
    {
        "school": "EnCompass Academy Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805010686",
    },
    {
        "school": "Community Day",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62805010718",
    },
    {
        "school": "ACORN Woodland Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805010730",
    },
    {
        "school": "Think College Now",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805011294",
    },
    {
        "school": "MetWest High",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805011350",
    },
    {
        "school": "McClymonds High",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805011555",
    },
    {
        "school": "Reach Academy",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805011556",
    },
    {
        "school": "Manzanita SEED Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805011557",
    },
    {
        "school": "Sankofa Academy",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805011558",
    },
    {
        "school": "Rise Community",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805011559",
    },
    {
        "school": "Contra Costa County ROP",
        "district": "Contra Costa County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60009210761",
    },
    {
        "school": "Acalanes Center for Independent Study",
        "district": "Acalanes Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60165010751",
    },
    {
        "school": "Carmen Dragon Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285010752",
    },
    {
        "school": "Dallas Ranch Middle",
        "district": "Antioch Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285011275",
    },
    {
        "school": "Lone Tree Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285011276",
    },
    {
        "school": "Bidwell Continuation High",
        "district": "Antioch Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60285011573",
    },
    {
        "school": "R. Paul Krey Elementary",
        "district": "Brentwood Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60591010474",
    },
    {
        "school": "Pioneer Elementary",
        "district": "Brentwood Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60591010753",
    },
    {
        "school": "Marsh Creek Elementary",
        "district": "Brentwood Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60591010754",
    },
    {
        "school": "Timber Point Elementary",
        "district": "Byron Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60675010475",
    },
    {
        "school": "Heritage High",
        "district": "Liberty Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62160010755",
    },
    {
        "school": "Delta View Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637010756",
    },
    {
        "school": "Hercules Middle",
        "district": "West Contra Costa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255010757",
    },
    {
        "school": "Lovonya DeJean Middle",
        "district": "West Contra Costa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255011226",
    },
    {
        "school": "Hidden Hills Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513010758",
    },
    {
        "school": "Windemere Ranch Middle",
        "district": "San Ramon Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513010759",
    },
    {
        "school": "Quail Run Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513010760",
    },
    {
        "school": "Golden Gate Community",
        "district": "Contra Costa County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100510472",
    },
    {
        "school": "Far East County Programs",
        "district": "Contra Costa County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100510748",
    },
    {
        "school": "Central County Special Education Programs",
        "district": "Contra Costa County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100510749",
    },
    {
        "school": "East County Elementary Special Education",
        "district": "Contra Costa County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100510750",
    },
    {
        "school": "Marin County ROP",
        "district": "Marin County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60011710955",
    },
    {
        "school": "San Francisco County ROP",
        "district": "San Francisco County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60013911410",
    },
    {
        "school": "Jordan (June) School for Equity",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63441011252",
    },
    {
        "school": "S.F. County Civic Center Secondary",
        "district": "San Francisco County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69111110647",
    },
    {
        "school": "San Mateo County ROP",
        "district": "San Mateo County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60014211433",
    },
    {
        "school": "Ingrid B. Lacy Middle",
        "district": "Pacifica",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62046010657",
    },
    {
        "school": "Ortega Elementary",
        "district": "Pacifica",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62046011430",
    },
    {
        "school": "California School for the Blind",
        "district": "California School for the Blind (State Special Schl)",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60000210346",
    },
    {
        "school": "California School for the Deaf-Fremont",
        "district": "California School for the Deaf-Fremont (State Special Schl)",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60000310347",
    },
    {
        "school": "Dublin Elementary",
        "district": "Dublin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001906929",
    },
    {
        "school": "James Dougherty Elementary",
        "district": "Dublin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001908443",
    },
    {
        "school": "Dublin High",
        "district": "Dublin Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001909273",
    },
    {
        "school": "Valley High (Continuation)",
        "district": "Dublin Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60001909274",
    },
    {
        "school": "Frederiksen Elementary",
        "district": "Dublin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001909275",
    },
    {
        "school": "Murray Elementary",
        "district": "Dublin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001909276",
    },
    {
        "school": "Wells Middle",
        "district": "Dublin Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001909278",
    },
    {
        "school": "Henry P. Mohr Elementary",
        "district": "Pleasanton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002006951",
    },
    {
        "school": "Thomas S. Hart Middle",
        "district": "Pleasanton Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002008444",
    },
    {
        "school": "Phoebe Apperson Hearst Elementary",
        "district": "Pleasanton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002008445",
    },
    {
        "school": "Foothill High",
        "district": "Pleasanton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002009279",
    },
    {
        "school": "Village High",
        "district": "Pleasanton Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60002009280",
    },
    {
        "school": "Amador Valley High",
        "district": "Pleasanton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002009282",
    },
    {
        "school": "Donlon Elementary",
        "district": "Pleasanton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002009283",
    },
    {
        "school": "Lydiksen Elementary",
        "district": "Pleasanton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002009284",
    },
    {
        "school": "Alisal Elementary",
        "district": "Pleasanton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002009285",
    },
    {
        "school": "Fairlands Elementary",
        "district": "Pleasanton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002009286",
    },
    {
        "school": "Valley View Elementary",
        "district": "Pleasanton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002009287",
    },
    {
        "school": "Walnut Grove Elementary",
        "district": "Pleasanton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002009288",
    },
    {
        "school": "Harvest Park Middle",
        "district": "Pleasanton Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002009289",
    },
    {
        "school": "Vintage Hills Elementary",
        "district": "Pleasanton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002009290",
    },
    {
        "school": "Pleasanton Middle",
        "district": "Pleasanton Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002009682",
    },
    {
        "school": "Sunol Glen Elementary",
        "district": "Sunol Glen Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002109291",
    },
    {
        "school": "William G. Paden Elementary",
        "district": "Alameda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177000003",
    },
    {
        "school": "Bay Farm",
        "district": "Alameda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177000006",
    },
    {
        "school": "Alameda High",
        "district": "Alameda Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177000041",
    },
    {
        "school": "Amelia Earhart Elementary",
        "district": "Alameda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177000043",
    },
    {
        "school": "Edison Elementary",
        "district": "Alameda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177000044",
    },
    {
        "school": "Encinal Junior/Senior High",
        "district": "Alameda Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177000045",
    },
    {
        "school": "Love Elementary",
        "district": "Alameda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177000047",
    },
    {
        "school": "Island High (Continuation)",
        "district": "Alameda Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60177000048",
    },
    {
        "school": "Lincoln Middle",
        "district": "Alameda Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177000049",
    },
    {
        "school": "Frank Otis Elementary",
        "district": "Alameda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177000054",
    },
    {
        "school": "Will C. Wood Middle",
        "district": "Alameda Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177000057",
    },
    {
        "school": "Franklin Elementary",
        "district": "Alameda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177004337",
    },
    {
        "school": "Albany High",
        "district": "Albany City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186000059",
    },
    {
        "school": "Albany Middle",
        "district": "Albany City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186000060",
    },
    {
        "school": "Cornell Elementary",
        "district": "Albany City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186000061",
    },
    {
        "school": "Marin Elementary",
        "district": "Albany City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186000062",
    },
    {
        "school": "MacGregor High (Continuation)",
        "district": "Albany City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60186007638",
    },
    {
        "school": "Ocean View Elementary",
        "district": "Albany City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186007937",
    },
    {
        "school": "Berkeley Arts Magnet at Whittier",
        "district": "Berkeley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474000431",
    },
    {
        "school": "Berkeley High",
        "district": "Berkeley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474000432",
    },
    {
        "school": "Emerson Elementary",
        "district": "Berkeley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474000436",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Berkeley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474000441",
    },
    {
        "school": "Martin Luther King Middle",
        "district": "Berkeley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474000443",
    },
    {
        "school": "Sylvia Mendez Elementary",
        "district": "Berkeley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474000445",
    },
    {
        "school": "Longfellow Arts and Technology Middle",
        "district": "Berkeley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474000446",
    },
    {
        "school": "Malcolm X Elementary",
        "district": "Berkeley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474000447",
    },
    {
        "school": "Oxford Elementary",
        "district": "Berkeley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474000448",
    },
    {
        "school": "Thousand Oaks Elementary",
        "district": "Berkeley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474000450",
    },
    {
        "school": "Washington Elementary",
        "district": "Berkeley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474000452",
    },
    {
        "school": "Rosa Parks Environmental Science",
        "district": "Berkeley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474006865",
    },
    {
        "school": "Cragmont Elementary",
        "district": "Berkeley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474006895",
    },
    {
        "school": "Willard Middle",
        "district": "Berkeley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474007267",
    },
    {
        "school": "John Muir Elementary",
        "district": "Berkeley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474008119",
    },
    {
        "school": "Canyon Middle",
        "district": "Castro Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780000740",
    },
    {
        "school": "Castro Valley Elementary",
        "district": "Castro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780000741",
    },
    {
        "school": "Castro Valley High",
        "district": "Castro Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780000742",
    },
    {
        "school": "Redwood Continuation High",
        "district": "Castro Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60780000744",
    },
    {
        "school": "Marshall Elementary",
        "district": "Castro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780000746",
    },
    {
        "school": "Palomares Elementary",
        "district": "Castro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780000747",
    },
    {
        "school": "Proctor Elementary",
        "district": "Castro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780000749",
    },
    {
        "school": "Roy A. Johnson High",
        "district": "Castro Valley Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60780000750",
    },
    {
        "school": "Vannoy Elementary",
        "district": "Castro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780000752",
    },
    {
        "school": "Jensen Ranch Elementary",
        "district": "Castro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780004339",
    },
    {
        "school": "Creekside Middle",
        "district": "Castro Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780006909",
    },
    {
        "school": "Chabot Elementary",
        "district": "Castro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780007661",
    },
    {
        "school": "Independent Elementary",
        "district": "Castro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780009342",
    },
    {
        "school": "Stanton Elementary",
        "district": "Castro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780009525",
    },
    {
        "school": "Anna Yates Elementary",
        "district": "Emery Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61263001425",
    },
    {
        "school": "Emery Secondary",
        "district": "Emery Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61263001426",
    },
    {
        "school": "Forest Park Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440000488",
    },
    {
        "school": "American High",
        "district": "Fremont Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001654",
    },
    {
        "school": "Joseph Azevada Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001655",
    },
    {
        "school": "John Blacow Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001656",
    },
    {
        "school": "Brier Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001657",
    },
    {
        "school": "Brookvale Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001658",
    },
    {
        "school": "Cabrillo Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001659",
    },
    {
        "school": "Centerville Junior High",
        "district": "Fremont Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001660",
    },
    {
        "school": "Joshua Chadbourne Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001661",
    },
    {
        "school": "J. Haley Durham Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001662",
    },
    {
        "school": "Glenmoor Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001663",
    },
    {
        "school": "John Gomes Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001664",
    },
    {
        "school": "Harvey Green Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001665",
    },
    {
        "school": "E. M. Grimmer Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001666",
    },
    {
        "school": "O. N. Hirsch Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001668",
    },
    {
        "school": "William Hopkins Junior High",
        "district": "Fremont Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001669",
    },
    {
        "school": "John M. Horner Junior High",
        "district": "Fremont Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001670",
    },
    {
        "school": "Irvington High",
        "district": "Fremont Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001671",
    },
    {
        "school": "John F. Kennedy High",
        "district": "Fremont Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001672",
    },
    {
        "school": "James Leitch Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001673",
    },
    {
        "school": "Tom Maloney Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001674",
    },
    {
        "school": "John G. Mattos Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001675",
    },
    {
        "school": "Steven Millard Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001676",
    },
    {
        "school": "Mission San Jose Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001677",
    },
    {
        "school": "Mission San Jose High",
        "district": "Fremont Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001678",
    },
    {
        "school": "Mission Valley Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001679",
    },
    {
        "school": "Niles Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001680",
    },
    {
        "school": "Oliveira Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001683",
    },
    {
        "school": "Parkmont Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001684",
    },
    {
        "school": "Patterson Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001685",
    },
    {
        "school": "Robertson High (Continuation)",
        "district": "Fremont Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61440001686",
    },
    {
        "school": "Thornton Junior High",
        "district": "Fremont Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001687",
    },
    {
        "school": "Vallejo Mill Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001688",
    },
    {
        "school": "G. M. Walters Middle",
        "district": "Fremont Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001689",
    },
    {
        "school": "Warm Springs Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001690",
    },
    {
        "school": "Warwick Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001691",
    },
    {
        "school": "Washington High",
        "district": "Fremont Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440001692",
    },
    {
        "school": "Circle of Independent Learning",
        "district": "Fremont Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440007479",
    },
    {
        "school": "Ardenwood Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440008138",
    },
    {
        "school": "Fred E. Weibel Elementary",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61440009139",
    },
    {
        "school": "Vista Alternative",
        "district": "Fremont Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61440009369",
    },
    {
        "school": "Bowman Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002104",
    },
    {
        "school": "Bret Harte Middle",
        "district": "Hayward Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002105",
    },
    {
        "school": "Burbank Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002106",
    },
    {
        "school": "Martin Luther King Jr. Middle",
        "district": "Hayward Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002107",
    },
    {
        "school": "Cherryland Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002108",
    },
    {
        "school": "East Avenue Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002109",
    },
    {
        "school": "Eden Gardens Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002110",
    },
    {
        "school": "Eldridge Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002111",
    },
    {
        "school": "Fairview Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002113",
    },
    {
        "school": "Glassbrook Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002114",
    },
    {
        "school": "Harder Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002115",
    },
    {
        "school": "Hayward High",
        "district": "Hayward Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002116",
    },
    {
        "school": "Cesar Chavez Middle",
        "district": "Hayward Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002118",
    },
    {
        "school": "Longwood Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002120",
    },
    {
        "school": "Lorin A. Eden Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002121",
    },
    {
        "school": "Brenkwitz High",
        "district": "Hayward Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61674002123",
    },
    {
        "school": "Mt. Eden High",
        "district": "Hayward Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002124",
    },
    {
        "school": "Palma Ceia Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002126",
    },
    {
        "school": "Park Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002127",
    },
    {
        "school": "Ruus Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002129",
    },
    {
        "school": "Schafer Park Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002130",
    },
    {
        "school": "Southgate Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002132",
    },
    {
        "school": "Tennyson High",
        "district": "Hayward Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002135",
    },
    {
        "school": "Treeview Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002136",
    },
    {
        "school": "Winton Middle",
        "district": "Hayward Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674002137",
    },
    {
        "school": "Faith Ringgold School of Arts and Science",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674005622",
    },
    {
        "school": "Tyrrell Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674008146",
    },
    {
        "school": "Strobridge Elementary",
        "district": "Hayward Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674008855",
    },
    {
        "school": "Anthony W. Ochoa Middle",
        "district": "Hayward Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674009847",
    },
    {
        "school": "Leo R. Croce Elementary",
        "district": "Livermore Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211000052",
    },
    {
        "school": "Andrew N. Christensen Middle",
        "district": "Livermore Valley Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002618",
    },
    {
        "school": "Arroyo Seco Elementary",
        "district": "Livermore Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002620",
    },
    {
        "school": "Del Valle Continuation High",
        "district": "Livermore Valley Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62211002621",
    },
    {
        "school": "Junction K-8",
        "district": "Livermore Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002622",
    },
    {
        "school": "East Avenue Middle",
        "district": "Livermore Valley Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002623",
    },
    {
        "school": "Emma C. Smith Elementary",
        "district": "Livermore Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002624",
    },
    {
        "school": "Granada High",
        "district": "Livermore Valley Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002626",
    },
    {
        "school": "Jackson Avenue Elementary",
        "district": "Livermore Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002627",
    },
    {
        "school": "Joe Michell",
        "district": "Livermore Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002628",
    },
    {
        "school": "Livermore High",
        "district": "Livermore Valley Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002630",
    },
    {
        "school": "Marylin Avenue Elementary",
        "district": "Livermore Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002631",
    },
    {
        "school": "Rancho Las Positas Elementary",
        "district": "Livermore Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002632",
    },
    {
        "school": "Sunset Elementary",
        "district": "Livermore Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002635",
    },
    {
        "school": "William Mendenhall Middle",
        "district": "Livermore Valley Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211002636",
    },
    {
        "school": "Altamont Creek Elementary",
        "district": "Livermore Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211008438",
    },
    {
        "school": "Vineyard Alternative",
        "district": "Livermore Valley Joint Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62211008877",
    },
    {
        "school": "Mountain House Elementary",
        "district": "Mountain House Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62613003910",
    },
    {
        "school": "Alvarado Elementary",
        "district": "New Haven Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62691004065",
    },
    {
        "school": "Itliong-Vera Cruz",
        "district": "New Haven Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62691004066",
    },
    {
        "school": "Hillview Crest Elementary",
        "district": "New Haven Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62691004071",
    },
    {
        "school": "James Logan High",
        "district": "New Haven Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62691004072",
    },
    {
        "school": "Cesar Chavez Middle",
        "district": "New Haven Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62691004073",
    },
    {
        "school": "Searles Elementary",
        "district": "New Haven Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62691004074",
    },
    {
        "school": "Tom Kitayama Elementary",
        "district": "New Haven Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62691007480",
    },
    {
        "school": "Guy Jr. Emanuele Elementary",
        "district": "New Haven Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62691007481",
    },
    {
        "school": "Pioneer Elementary",
        "district": "New Haven Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62691007795",
    },
    {
        "school": "Delaine Eastin Elementary",
        "district": "New Haven Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62691008675",
    },
    {
        "school": "Crossroads High (Alternative)",
        "district": "Newark Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62706001921",
    },
    {
        "school": "Birch Grove Primary",
        "district": "Newark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62706004079",
    },
    {
        "school": "Bridgepoint High (Continuation)",
        "district": "Newark Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62706004080",
    },
    {
        "school": "James A. Graham Elementary",
        "district": "Newark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62706004081",
    },
    {
        "school": "John F. Kennedy Elementary",
        "district": "Newark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62706004082",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Newark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62706004083",
    },
    {
        "school": "Newark Memorial High",
        "district": "Newark Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62706004085",
    },
    {
        "school": "Birch Grove Intermediate",
        "district": "Newark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62706004086",
    },
    {
        "school": "E. L. Musick Elementary",
        "district": "Newark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62706004087",
    },
    {
        "school": "August Schilling Elementary",
        "district": "Newark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62706004090",
    },
    {
        "school": "H. A. Snow Elementary",
        "district": "Newark Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62706004092",
    },
    {
        "school": "Newark Junior High",
        "district": "Newark Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62706007796",
    },
    {
        "school": "Allendale Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004238",
    },
    {
        "school": "Chabot Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004239",
    },
    {
        "school": "Bella Vista Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004241",
    },
    {
        "school": "Bret Harte Middle",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004242",
    },
    {
        "school": "Brookfield Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004243",
    },
    {
        "school": "Burckhalter Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004245",
    },
    {
        "school": "Carl B. Munck Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004246",
    },
    {
        "school": "Howard Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004249",
    },
    {
        "school": "Claremont Middle",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004250",
    },
    {
        "school": "Cleveland Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004251",
    },
    {
        "school": "Crocker Highlands Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004253",
    },
    {
        "school": "Dewey Academy",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62805004255",
    },
    {
        "school": "Emerson Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004260",
    },
    {
        "school": "Franklin Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004261",
    },
    {
        "school": "Frick Middle",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004263",
    },
    {
        "school": "Fruitvale Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004264",
    },
    {
        "school": "Garfield Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004265",
    },
    {
        "school": "Glenview Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004266",
    },
    {
        "school": "Grass Valley Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004269",
    },
    {
        "school": "Kaiser Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004273",
    },
    {
        "school": "New Highland Academy",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004274",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004275",
    },
    {
        "school": "Hoover Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004276",
    },
    {
        "school": "Horace Mann Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004277",
    },
    {
        "school": "Madison Park Academy 6-12",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004278",
    },
    {
        "school": "Joaquin Miller Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004280",
    },
    {
        "school": "La Escuelita Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004284",
    },
    {
        "school": "Laurel Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004287",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004289",
    },
    {
        "school": "Manzanita Community",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004294",
    },
    {
        "school": "Markham Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004296",
    },
    {
        "school": "Martin Luther King Jr. Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004297",
    },
    {
        "school": "Edna Brewer Middle",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004299",
    },
    {
        "school": "Bridges Academy",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004301",
    },
    {
        "school": "Montclair Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004302",
    },
    {
        "school": "Montera Middle",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004303",
    },
    {
        "school": "Oakland High",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004304",
    },
    {
        "school": "Oakland Technical High",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004305",
    },
    {
        "school": "Parker Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004306",
    },
    {
        "school": "Peralta Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004307",
    },
    {
        "school": "Piedmont Avenue Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004308",
    },
    {
        "school": "Prescott",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004309",
    },
    {
        "school": "Redwood Heights Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004310",
    },
    {
        "school": "Roosevelt Middle",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004312",
    },
    {
        "school": "Sequoia Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004314",
    },
    {
        "school": "Skyline High",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004315",
    },
    {
        "school": "Madison Park Academy TK-5",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004316",
    },
    {
        "school": "Esperanza Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004317",
    },
    {
        "school": "Thornhill Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004318",
    },
    {
        "school": "Westlake Middle",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805004323",
    },
    {
        "school": "Independent Study Sojourner Truth",
        "district": "Oakland Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62805005701",
    },
    {
        "school": "Rudsdale Continuation",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62805007326",
    },
    {
        "school": "Street Academy (Alternative)",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62805007804",
    },
    {
        "school": "LIFE Academy",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805008676",
    },
    {
        "school": "International Community",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805008678",
    },
    {
        "school": "Melrose Leadership Academy",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805008679",
    },
    {
        "school": "Urban Promise Academy",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805008680",
    },
    {
        "school": "Beach Elementary",
        "district": "Piedmont City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63033004729",
    },
    {
        "school": "Havens Elementary",
        "district": "Piedmont City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63033004730",
    },
    {
        "school": "Piedmont High",
        "district": "Piedmont City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63033004731",
    },
    {
        "school": "Piedmont Middle",
        "district": "Piedmont City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63033004732",
    },
    {
        "school": "Wildwood Elementary",
        "district": "Piedmont City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63033004733",
    },
    {
        "school": "Millennium High Alternative",
        "district": "Piedmont City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63033007819",
    },
    {
        "school": "Bancroft Middle",
        "district": "San Leandro Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63468005831",
    },
    {
        "school": "Garfield Elementary",
        "district": "San Leandro Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63468005833",
    },
    {
        "school": "Jefferson Elementary",
        "district": "San Leandro Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63468005834",
    },
    {
        "school": "Lincoln High (Continuation)",
        "district": "San Leandro Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63468005835",
    },
    {
        "school": "McKinley Elementary",
        "district": "San Leandro Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63468005837",
    },
    {
        "school": "Monroe Elementary",
        "district": "San Leandro Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63468005838",
    },
    {
        "school": "John Muir Middle",
        "district": "San Leandro Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63468005839",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "San Leandro Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63468005841",
    },
    {
        "school": "San Leandro High",
        "district": "San Leandro Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63468005842",
    },
    {
        "school": "Washington Elementary",
        "district": "San Leandro Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63468005843",
    },
    {
        "school": "Wilson Elementary",
        "district": "San Leandro Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63468005844",
    },
    {
        "school": "Madison Elementary",
        "district": "San Leandro Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63468007482",
    },
    {
        "school": "Arroyo High",
        "district": "San Lorenzo Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471005845",
    },
    {
        "school": "Bay Elementary",
        "district": "San Lorenzo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471005846",
    },
    {
        "school": "Colonial Acres Elementary",
        "district": "San Lorenzo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471005847",
    },
    {
        "school": "Corvallis Elementary",
        "district": "San Lorenzo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471005848",
    },
    {
        "school": "Del Rey Elementary",
        "district": "San Lorenzo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471005850",
    },
    {
        "school": "Edendale Middle",
        "district": "San Lorenzo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471005851",
    },
    {
        "school": "Hesperian Elementary",
        "district": "San Lorenzo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471005852",
    },
    {
        "school": "Hillside Elementary",
        "district": "San Lorenzo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471005853",
    },
    {
        "school": "Lorenzo Manor Elementary",
        "district": "San Lorenzo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471005855",
    },
    {
        "school": "Royal Sunset (Continuation)",
        "district": "San Lorenzo Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63471005858",
    },
    {
        "school": "San Lorenzo High",
        "district": "San Lorenzo Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471005859",
    },
    {
        "school": "Bohannon Middle",
        "district": "San Lorenzo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471007483",
    },
    {
        "school": "Dayton Elementary",
        "district": "San Lorenzo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471007484",
    },
    {
        "school": "Grant Elementary",
        "district": "San Lorenzo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471007485",
    },
    {
        "school": "Washington Manor Middle",
        "district": "San Lorenzo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471008973",
    },
    {
        "school": "Alameda County Community",
        "district": "Alameda County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69105106830",
    },
    {
        "school": "Alameda County Special Education",
        "district": "Alameda County Office of Education",
        "level": "Not reported",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69105108672",
    },
    {
        "school": "Alameda County Juvenile Hall/Court",
        "district": "Alameda County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69105109264",
    },
    {
        "school": "Acalanes High",
        "district": "Acalanes Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165000032",
    },
    {
        "school": "Campolindo High",
        "district": "Acalanes Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165000033",
    },
    {
        "school": "Las Lomas High",
        "district": "Acalanes Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165000035",
    },
    {
        "school": "Miramonte High",
        "district": "Acalanes Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165000036",
    },
    {
        "school": "Jack London Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285000156",
    },
    {
        "school": "Antioch High",
        "district": "Antioch Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285000207",
    },
    {
        "school": "Antioch Middle",
        "district": "Antioch Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285000208",
    },
    {
        "school": "Belshaw Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285000209",
    },
    {
        "school": "Fremont Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285000211",
    },
    {
        "school": "Kimball Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285000212",
    },
    {
        "school": "Live Oak High (Continuation)",
        "district": "Antioch Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60285000213",
    },
    {
        "school": "Marsh Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285000214",
    },
    {
        "school": "Mission Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285000215",
    },
    {
        "school": "Park Middle",
        "district": "Antioch Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285000216",
    },
    {
        "school": "Sutter Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285000217",
    },
    {
        "school": "Turner Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285000218",
    },
    {
        "school": "Black Diamond Middle",
        "district": "Antioch Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285004440",
    },
    {
        "school": "Deer Valley High",
        "district": "Antioch Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285005724",
    },
    {
        "school": "Grant Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285007492",
    },
    {
        "school": "Diablo Vista Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285008454",
    },
    {
        "school": "Prospects High (Alternative)",
        "district": "Antioch Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60285009517",
    },
    {
        "school": "Muir (John) Elementary",
        "district": "Antioch Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60285009703",
    },
    {
        "school": "Brentwood Elementary",
        "district": "Brentwood Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60591000534",
    },
    {
        "school": "Edna Hill Middle",
        "district": "Brentwood Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60591000535",
    },
    {
        "school": "Garin Elementary",
        "district": "Brentwood Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60591000536",
    },
    {
        "school": "William B. Bristow Middle",
        "district": "Brentwood Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60591004444",
    },
    {
        "school": "Loma Vista Elementary",
        "district": "Brentwood Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60591008455",
    },
    {
        "school": "Ron Nunn Elementary",
        "district": "Brentwood Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60591010194",
    },
    {
        "school": "Excelsior Middle",
        "district": "Byron Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60675000595",
    },
    {
        "school": "Discovery Bay Elementary",
        "district": "Byron Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60675007653",
    },
    {
        "school": "Canyon Elementary",
        "district": "Canyon Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60735000680",
    },
    {
        "school": "Carquinez Middle",
        "district": "John Swett Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61899002299",
    },
    {
        "school": "Rodeo Hills Elementary",
        "district": "John Swett Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61899002301",
    },
    {
        "school": "John Swett High",
        "district": "John Swett Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61899002302",
    },
    {
        "school": "Willow High",
        "district": "John Swett Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61899002303",
    },
    {
        "school": "Knightsen Elementary",
        "district": "Knightsen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62004002397",
    },
    {
        "school": "Burton Valley Elementary",
        "district": "Lafayette Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62031002446",
    },
    {
        "school": "Happy Valley Elementary",
        "district": "Lafayette Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62031002447",
    },
    {
        "school": "Lafayette Elementary",
        "district": "Lafayette Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62031002448",
    },
    {
        "school": "M. H. Stanley Middle",
        "district": "Lafayette Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62031002449",
    },
    {
        "school": "Springhill Elementary",
        "district": "Lafayette Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62031002450",
    },
    {
        "school": "La Paloma High (Continuation)",
        "district": "Liberty Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62160002572",
    },
    {
        "school": "Liberty High",
        "district": "Liberty Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62160002573",
    },
    {
        "school": "Freedom High",
        "district": "Liberty Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62160005726",
    },
    {
        "school": "Independence High",
        "district": "Liberty Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62160008457",
    },
    {
        "school": "Morello Park Elementary",
        "district": "Martinez Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62403000178",
    },
    {
        "school": "Vicente Martinez High",
        "district": "Martinez Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62403001966",
    },
    {
        "school": "Alhambra Senior High",
        "district": "Martinez Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62403003612",
    },
    {
        "school": "John Swett Elementary",
        "district": "Martinez Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62403003614",
    },
    {
        "school": "Las Juntas Elementary",
        "district": "Martinez Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62403003615",
    },
    {
        "school": "Martinez Junior High",
        "district": "Martinez Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62403003618",
    },
    {
        "school": "Briones (Alternative)",
        "district": "Martinez Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62403007071",
    },
    {
        "school": "John Muir Elementary",
        "district": "Martinez Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62403009579",
    },
    {
        "school": "Camino Pablo Elementary",
        "district": "Moraga Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62574003849",
    },
    {
        "school": "Donald L. Rheem Elementary",
        "district": "Moraga Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62574003850",
    },
    {
        "school": "Joaquin Moraga Intermediate",
        "district": "Moraga Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62574003851",
    },
    {
        "school": "Los Perales Elementary",
        "district": "Moraga Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62574007075",
    },
    {
        "school": "Crossroads High",
        "district": "Mt. Diablo Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62637000183",
    },
    {
        "school": "Summit High (Continuation)",
        "district": "Mt. Diablo Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62637000185",
    },
    {
        "school": "Diablo View Middle",
        "district": "Mt. Diablo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637001967",
    },
    {
        "school": "Cambridge Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637002932",
    },
    {
        "school": "Gregory Gardens Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637002956",
    },
    {
        "school": "Ayers Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003934",
    },
    {
        "school": "Bancroft Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003935",
    },
    {
        "school": "Bel Air Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003936",
    },
    {
        "school": "College Park High",
        "district": "Mt. Diablo Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003941",
    },
    {
        "school": "Concord High",
        "district": "Mt. Diablo Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003942",
    },
    {
        "school": "El Dorado Middle",
        "district": "Mt. Diablo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003944",
    },
    {
        "school": "El Monte Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003945",
    },
    {
        "school": "Fair Oaks Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003946",
    },
    {
        "school": "Foothill Middle",
        "district": "Mt. Diablo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003947",
    },
    {
        "school": "Hidden Valley Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003950",
    },
    {
        "school": "Highlands Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003951",
    },
    {
        "school": "Holbrook Language Academy",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003953",
    },
    {
        "school": "Meadow Homes Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003956",
    },
    {
        "school": "Monte Gardens Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003957",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003958",
    },
    {
        "school": "Mt. Diablo Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003959",
    },
    {
        "school": "Mt. Diablo High",
        "district": "Mt. Diablo Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003960",
    },
    {
        "school": "Northgate High",
        "district": "Mt. Diablo Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003961",
    },
    {
        "school": "Oak Grove Middle",
        "district": "Mt. Diablo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003962",
    },
    {
        "school": "Olympic Continuation High",
        "district": "Mt. Diablo Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62637003963",
    },
    {
        "school": "Pine Hollow Middle",
        "district": "Mt. Diablo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003965",
    },
    {
        "school": "Sunrise (Special Education)",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62637003966",
    },
    {
        "school": "Pleasant Hill Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003967",
    },
    {
        "school": "Riverview Middle",
        "district": "Mt. Diablo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003969",
    },
    {
        "school": "Shore Acres Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003972",
    },
    {
        "school": "Silverwood Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003973",
    },
    {
        "school": "Strandwood Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003974",
    },
    {
        "school": "Sun Terrace Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003975",
    },
    {
        "school": "Valhalla Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003977",
    },
    {
        "school": "Valle Verde Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003978",
    },
    {
        "school": "Valley View Middle",
        "district": "Mt. Diablo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003979",
    },
    {
        "school": "Walnut Acres Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003980",
    },
    {
        "school": "Westwood Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003981",
    },
    {
        "school": "Woodside Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003983",
    },
    {
        "school": "Wren Avenue Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003984",
    },
    {
        "school": "Ygnacio Valley Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003985",
    },
    {
        "school": "Ygnacio Valley High",
        "district": "Mt. Diablo Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637003986",
    },
    {
        "school": "Pleasant Hill Middle",
        "district": "Mt. Diablo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637007076",
    },
    {
        "school": "Sequoia Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637007319",
    },
    {
        "school": "Diablo Community Day",
        "district": "Mt. Diablo Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62637008458",
    },
    {
        "school": "Eagle Peak Montessori",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637008688",
    },
    {
        "school": "Sequoia Middle",
        "district": "Mt. Diablo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637008916",
    },
    {
        "school": "Rio Vista Elementary",
        "district": "Mt. Diablo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637009406",
    },
    {
        "school": "Horizons School: Independent Study",
        "district": "Mt. Diablo Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62637009946",
    },
    {
        "school": "Gateway High (Continuation)",
        "district": "Mt. Diablo Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62637010195",
    },
    {
        "school": "Prospect High (Continuation)",
        "district": "Mt. Diablo Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62637010197",
    },
    {
        "school": "Laurel Elementary",
        "district": "Oakley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62808000186",
    },
    {
        "school": "Vintage Parkway Elementary",
        "district": "Oakley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62808000190",
    },
    {
        "school": "Gehringer Elementary",
        "district": "Oakley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62808004326",
    },
    {
        "school": "Oakley Elementary",
        "district": "Oakley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62808004327",
    },
    {
        "school": "Delta Vista Middle",
        "district": "Oakley Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62808008689",
    },
    {
        "school": "O'Hara Park Middle",
        "district": "Oakley Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62808009966",
    },
    {
        "school": "Del Rey Elementary",
        "district": "Orinda Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62886004470",
    },
    {
        "school": "Glorietta Elementary",
        "district": "Orinda Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62886004471",
    },
    {
        "school": "Orinda Intermediate",
        "district": "Orinda Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62886004472",
    },
    {
        "school": "Sleepy Hollow Elementary",
        "district": "Orinda Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62886004473",
    },
    {
        "school": "Wagner Ranch Elementary",
        "district": "Orinda Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62886007077",
    },
    {
        "school": "Rancho Medanos Junior High",
        "district": "Pittsburg Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060004743",
    },
    {
        "school": "Foothill Elementary",
        "district": "Pittsburg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060004746",
    },
    {
        "school": "Heights Elementary",
        "district": "Pittsburg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060004747",
    },
    {
        "school": "Highlands Elementary",
        "district": "Pittsburg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060004748",
    },
    {
        "school": "Hillview Junior High",
        "district": "Pittsburg Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060004749",
    },
    {
        "school": "Los Medanos Elementary",
        "district": "Pittsburg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060004750",
    },
    {
        "school": "Parkside Elementary",
        "district": "Pittsburg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060004751",
    },
    {
        "school": "Pittsburg Senior High",
        "district": "Pittsburg Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060004752",
    },
    {
        "school": "Willow Cove Elementary",
        "district": "Pittsburg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060004753",
    },
    {
        "school": "Black Diamond High (Continuation)",
        "district": "Pittsburg Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63060007821",
    },
    {
        "school": "Stoneman Elementary",
        "district": "Pittsburg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060009995",
    },
    {
        "school": "Hanna Ranch Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255004445",
    },
    {
        "school": "Bayview Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005009",
    },
    {
        "school": "Collins Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005014",
    },
    {
        "school": "Coronado Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005015",
    },
    {
        "school": "Crespi Junior High",
        "district": "West Contra Costa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005017",
    },
    {
        "school": "De Anza High",
        "district": "West Contra Costa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005018",
    },
    {
        "school": "Dover Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005020",
    },
    {
        "school": "El Cerrito High",
        "district": "West Contra Costa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005022",
    },
    {
        "school": "Ellerhorst Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005026",
    },
    {
        "school": "Fairmont Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005029",
    },
    {
        "school": "Ford Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005030",
    },
    {
        "school": "Greenwood Academy",
        "district": "West Contra Costa Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63255005031",
    },
    {
        "school": "Grant Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005032",
    },
    {
        "school": "Harding Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005033",
    },
    {
        "school": "Helms Middle",
        "district": "West Contra Costa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005034",
    },
    {
        "school": "Lupine Hills Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005035",
    },
    {
        "school": "John F. Kennedy High",
        "district": "West Contra Costa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005037",
    },
    {
        "school": "Kensington Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005038",
    },
    {
        "school": "Martin Luther King Jr. Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005040",
    },
    {
        "school": "Lake Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005041",
    },
    {
        "school": "Lincoln Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005042",
    },
    {
        "school": "Madera Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005043",
    },
    {
        "school": "Mira Vista Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005044",
    },
    {
        "school": "Montalvin Manor Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005045",
    },
    {
        "school": "Murphy Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005046",
    },
    {
        "school": "Nystrom Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005047",
    },
    {
        "school": "Ohlone Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005048",
    },
    {
        "school": "Olinda Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005049",
    },
    {
        "school": "Peres Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005050",
    },
    {
        "school": "Pinole Middle",
        "district": "West Contra Costa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005051",
    },
    {
        "school": "Pinole Valley High",
        "district": "West Contra Costa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005052",
    },
    {
        "school": "Fred T. Korematsu Middle",
        "district": "West Contra Costa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005053",
    },
    {
        "school": "Richmond High",
        "district": "West Contra Costa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005055",
    },
    {
        "school": "Riverside Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005056",
    },
    {
        "school": "Shannon Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005059",
    },
    {
        "school": "Sheldon Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005060",
    },
    {
        "school": "Stege Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005061",
    },
    {
        "school": "Stewart Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005062",
    },
    {
        "school": "Tara Hills Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005063",
    },
    {
        "school": "Valley View Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005064",
    },
    {
        "school": "Verde Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005065",
    },
    {
        "school": "Washington Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005067",
    },
    {
        "school": "Wilson Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255005068",
    },
    {
        "school": "Harbour Way Elementary Community Day",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63255007080",
    },
    {
        "school": "Cesar E. Chavez Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255007081",
    },
    {
        "school": "Hercules High",
        "district": "West Contra Costa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255008691",
    },
    {
        "school": "Edward M. Downer Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255009184",
    },
    {
        "school": "Middle College High",
        "district": "West Contra Costa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255009622",
    },
    {
        "school": "Highland Elementary",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255010022",
    },
    {
        "school": "Vista High (Alternative)",
        "district": "West Contra Costa Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63255010198",
    },
    {
        "school": "Sycamore Valley Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513000289",
    },
    {
        "school": "Iron Horse Middle",
        "district": "San Ramon Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005729",
    },
    {
        "school": "Alamo Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005942",
    },
    {
        "school": "California High",
        "district": "San Ramon Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005943",
    },
    {
        "school": "Charlotte Wood Middle",
        "district": "San Ramon Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005944",
    },
    {
        "school": "Country Club Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005945",
    },
    {
        "school": "Del Amigo High (Continuation)",
        "district": "San Ramon Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63513005946",
    },
    {
        "school": "Green Valley Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005947",
    },
    {
        "school": "Greenbrook Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005948",
    },
    {
        "school": "John Baldwin Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005949",
    },
    {
        "school": "Los Cerros Middle",
        "district": "San Ramon Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005950",
    },
    {
        "school": "Montair Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005951",
    },
    {
        "school": "Monte Vista High",
        "district": "San Ramon Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005952",
    },
    {
        "school": "Montevideo Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005953",
    },
    {
        "school": "Neil A. Armstrong Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005954",
    },
    {
        "school": "Pine Valley Middle",
        "district": "San Ramon Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005955",
    },
    {
        "school": "Rancho Romero Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005956",
    },
    {
        "school": "San Ramon Valley High",
        "district": "San Ramon Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005957",
    },
    {
        "school": "Stone Valley Middle",
        "district": "San Ramon Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005958",
    },
    {
        "school": "Twin Creeks Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005959",
    },
    {
        "school": "Vista Grande Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005960",
    },
    {
        "school": "Walt Disney Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513005961",
    },
    {
        "school": "Tassajara Hills Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513007082",
    },
    {
        "school": "Bollinger Canyon Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513007356",
    },
    {
        "school": "Diablo Vista Middle",
        "district": "San Ramon Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513008460",
    },
    {
        "school": "Coyote Creek Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513008461",
    },
    {
        "school": "Venture (Alternative)",
        "district": "San Ramon Valley Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63513008976",
    },
    {
        "school": "Golden View Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513009631",
    },
    {
        "school": "Buena Vista Elementary",
        "district": "Walnut Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64125006827",
    },
    {
        "school": "Indian Valley Elementary",
        "district": "Walnut Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64125006828",
    },
    {
        "school": "Murwood Elementary",
        "district": "Walnut Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64125006829",
    },
    {
        "school": "Walnut Creek Intermediate",
        "district": "Walnut Creek Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64125006831",
    },
    {
        "school": "Walnut Heights Elementary",
        "district": "Walnut Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64125006832",
    },
    {
        "school": "Parkmead Elementary",
        "district": "Walnut Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64125009461",
    },
    {
        "school": "Floyd I. Marchus",
        "district": "Contra Costa County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100509217",
    },
    {
        "school": "Manor Elementary",
        "district": "Ross Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60000608773",
    },
    {
        "school": "White Hill Middle",
        "district": "Ross Valley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60000608774",
    },
    {
        "school": "Brookside Elementary",
        "district": "Ross Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60000608775",
    },
    {
        "school": "Wade Thomas Elementary",
        "district": "Ross Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60000608776",
    },
    {
        "school": "Bolinas-Stinson Elementary",
        "district": "Bolinas-Stinson Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60552000501",
    },
    {
        "school": "Lucas Valley Elementary",
        "district": "Miller Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61122001244",
    },
    {
        "school": "Miller Creek Middle",
        "district": "Miller Creek Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61122001247",
    },
    {
        "school": "Vallecito Elementary",
        "district": "Miller Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61122008822",
    },
    {
        "school": "Mary E. Silveira Elementary",
        "district": "Miller Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61122010255",
    },
    {
        "school": "Anthony G. Bacich Elementary",
        "district": "Kentfield Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61938002327",
    },
    {
        "school": "Adaline E. Kent Middle",
        "district": "Kentfield Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61938002329",
    },
    {
        "school": "Lagunitas Elementary",
        "district": "Lagunitas Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62052002473",
    },
    {
        "school": "San Geronimo Valley Elementary",
        "district": "Lagunitas Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62052002474",
    },
    {
        "school": "Hall Middle",
        "district": "Larkspur-Corte Madera",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62091002515",
    },
    {
        "school": "Neil Cummins Elementary",
        "district": "Larkspur-Corte Madera",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62091002516",
    },
    {
        "school": "Mill Valley Middle",
        "district": "Mill Valley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62487003712",
    },
    {
        "school": "Old Mill Elementary",
        "district": "Mill Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62487003713",
    },
    {
        "school": "Park Elementary",
        "district": "Mill Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62487003714",
    },
    {
        "school": "Tamalpais Valley Elementary",
        "district": "Mill Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62487003716",
    },
    {
        "school": "Strawberry Point Elementary",
        "district": "Mill Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62487008518",
    },
    {
        "school": "Edna Maguire Elementary",
        "district": "Mill Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62487009926",
    },
    {
        "school": "Nicasio",
        "district": "Nicasio",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62730004135",
    },
    {
        "school": "Hamilton Meadow Park",
        "district": "Novato Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772004185",
    },
    {
        "school": "Loma Verde Elementary",
        "district": "Novato Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772004187",
    },
    {
        "school": "Lu Sutton Elementary",
        "district": "Novato Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772004188",
    },
    {
        "school": "Lynwood Elementary",
        "district": "Novato Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772004189",
    },
    {
        "school": "Marin Oaks High",
        "district": "Novato Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62772004190",
    },
    {
        "school": "Novato High",
        "district": "Novato Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772004191",
    },
    {
        "school": "Olive Elementary",
        "district": "Novato Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772004192",
    },
    {
        "school": "Pleasant Valley Elementary",
        "district": "Novato Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772004193",
    },
    {
        "school": "Rancho Elementary",
        "district": "Novato Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772004194",
    },
    {
        "school": "San Marin High",
        "district": "Novato Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772004196",
    },
    {
        "school": "San Ramon Elementary",
        "district": "Novato Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772004197",
    },
    {
        "school": "Sinaloa Middle",
        "district": "Novato Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772004198",
    },
    {
        "school": "Nova Education Center",
        "district": "Novato Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62772004199",
    },
    {
        "school": "Bel Aire Elementary",
        "district": "Reed Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63216004975",
    },
    {
        "school": "Reed Elementary",
        "district": "Reed Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63216004976",
    },
    {
        "school": "Del Mar Middle",
        "district": "Reed Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63216004977",
    },
    {
        "school": "Ross Elementary",
        "district": "Ross Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63366005192",
    },
    {
        "school": "Bahia Vista Elementary",
        "district": "San Rafael City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63509005932",
    },
    {
        "school": "Coleman Elementary",
        "district": "San Rafael City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63509005933",
    },
    {
        "school": "Venetia Valley K-8",
        "district": "San Rafael City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63509005934",
    },
    {
        "school": "Glenwood Elementary",
        "district": "San Rafael City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63509005935",
    },
    {
        "school": "James B. Davidson Middle",
        "district": "San Rafael City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63509005936",
    },
    {
        "school": "Sun Valley Elementary",
        "district": "San Rafael City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63509005940",
    },
    {
        "school": "Laurel Dell Elementary",
        "district": "San Rafael City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63509006037",
    },
    {
        "school": "San Pedro Elementary",
        "district": "San Rafael City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63509009630",
    },
    {
        "school": "Madrone High Continuation",
        "district": "San Rafael City High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63511005937",
    },
    {
        "school": "San Rafael High",
        "district": "San Rafael City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63511005938",
    },
    {
        "school": "Terra Linda High",
        "district": "San Rafael City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63511005941",
    },
    {
        "school": "Bayside Martin Luther King Jr. Academy",
        "district": "Sausalito Marin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63600006162",
    },
    {
        "school": "Tomales Elementary",
        "district": "Shoreline Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63667006216",
    },
    {
        "school": "Tomales High",
        "district": "Shoreline Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63667006217",
    },
    {
        "school": "West Marin Elementary",
        "district": "Shoreline Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63667006218",
    },
    {
        "school": "Inverness Elementary",
        "district": "Shoreline Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63667007362",
    },
    {
        "school": "Redwood High",
        "district": "Tamalpais Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63879006523",
    },
    {
        "school": "San Andreas High (Continuation)",
        "district": "Tamalpais Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63879006524",
    },
    {
        "school": "Sir Francis Drake High",
        "district": "Tamalpais Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63879006525",
    },
    {
        "school": "Tamalpais High",
        "district": "Tamalpais Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63879006526",
    },
    {
        "school": "Tamiscal High (Alternative)",
        "district": "Tamalpais Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63879010109",
    },
    {
        "school": "Phoenix Academy",
        "district": "Marin County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101804617",
    },
    {
        "school": "Marin County Special Education",
        "district": "Marin County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69101807135",
    },
    {
        "school": "Marin's Community",
        "district": "Marin County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101809230",
    },
    {
        "school": "Asawa (Ruth) SF Sch of the Arts A Public School",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63441001276",
    },
    {
        "school": "Brown Jr. (Willie L) Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441002774",
    },
    {
        "school": "Marshall (Thurgood) High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441003976",
    },
    {
        "school": "Yu (Alice Fong) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005360",
    },
    {
        "school": "Chin (John Yehall) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005369",
    },
    {
        "school": "Giannini (A.P.) Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005580",
    },
    {
        "school": "Lincoln (Abraham) High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005581",
    },
    {
        "school": "Alamo Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005582",
    },
    {
        "school": "Alvarado Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005583",
    },
    {
        "school": "Aptos Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005585",
    },
    {
        "school": "Argonne Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005586",
    },
    {
        "school": "Balboa High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005587",
    },
    {
        "school": "Carmichael (Bessie)/FEC",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005590",
    },
    {
        "school": "Harte (Bret) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005591",
    },
    {
        "school": "Bryant Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005592",
    },
    {
        "school": "Lee (Edwin and Anita) Newcomer",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005596",
    },
    {
        "school": "Cleveland Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005597",
    },
    {
        "school": "Sloat (Commodore) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005598",
    },
    {
        "school": "Lau (Gordon J.) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005599",
    },
    {
        "school": "Webster (Daniel) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005600",
    },
    {
        "school": "Milk (Harvey) Civil Rights Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005601",
    },
    {
        "school": "Downtown High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63441005602",
    },
    {
        "school": "Taylor (Edward R.) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005604",
    },
    {
        "school": "El Dorado Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005605",
    },
    {
        "school": "Huerta (Dolores) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005607",
    },
    {
        "school": "Key (Francis Scott) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005609",
    },
    {
        "school": "Francisco Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005610",
    },
    {
        "school": "McCoppin (Frank) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005611",
    },
    {
        "school": "Galileo High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005612",
    },
    {
        "school": "Garfield Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005613",
    },
    {
        "school": "Peabody (George) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005614",
    },
    {
        "school": "Moscone (George R.) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005615",
    },
    {
        "school": "Carver (George Washington) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005616",
    },
    {
        "school": "Washington (George) High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005617",
    },
    {
        "school": "Glen Park Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005618",
    },
    {
        "school": "Grattan Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005620",
    },
    {
        "school": "Guadalupe Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005621",
    },
    {
        "school": "Chavez (Cesar) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005623",
    },
    {
        "school": "Hoover (Herbert) Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005624",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005625",
    },
    {
        "school": "Buena Vista/ Horace Mann K-8",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005626",
    },
    {
        "school": "Denman (James) Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005628",
    },
    {
        "school": "Lick (James) Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005629",
    },
    {
        "school": "Parker (Jean) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005630",
    },
    {
        "school": "Jefferson Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005631",
    },
    {
        "school": "Muir (John) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005633",
    },
    {
        "school": "Ortega (Jose) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005635",
    },
    {
        "school": "Serra (Junipero) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005636",
    },
    {
        "school": "Lafayette Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005637",
    },
    {
        "school": "Lakeshore Alternative Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005638",
    },
    {
        "school": "Lawton Alternative Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005639",
    },
    {
        "school": "Flynn (Leonard R.) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005640",
    },
    {
        "school": "Longfellow Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005641",
    },
    {
        "school": "Lowell High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005643",
    },
    {
        "school": "Marina Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005645",
    },
    {
        "school": "Marshall Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005646",
    },
    {
        "school": "McKinley Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005647",
    },
    {
        "school": "Miraloma Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005648",
    },
    {
        "school": "Mission Education Center",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005649",
    },
    {
        "school": "Mission High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005650",
    },
    {
        "school": "Monroe Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005651",
    },
    {
        "school": "New Traditions Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005652",
    },
    {
        "school": "Wells (Ida B.) High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63441005653",
    },
    {
        "school": "Revere (Paul) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005654",
    },
    {
        "school": "King Jr. (Martin Luther) Academic Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005655",
    },
    {
        "school": "Presidio Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005657",
    },
    {
        "school": "Parks (Rosa) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005658",
    },
    {
        "school": "Redding Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005659",
    },
    {
        "school": "Stevenson (Robert Louis) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005660",
    },
    {
        "school": "Rooftop Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005661",
    },
    {
        "school": "Roosevelt Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005662",
    },
    {
        "school": "San Francisco Community Alternative",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005663",
    },
    {
        "school": "Sanchez Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005664",
    },
    {
        "school": "Clarendon Alternative Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005666",
    },
    {
        "school": "Sheridan Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005667",
    },
    {
        "school": "Sherman Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005668",
    },
    {
        "school": "Malcolm X Academy",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005669",
    },
    {
        "school": "Spring Valley Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005670",
    },
    {
        "school": "King (Thomas Starr) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005671",
    },
    {
        "school": "Sunnyside Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005672",
    },
    {
        "school": "Sutro Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005674",
    },
    {
        "school": "Ulloa Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005676",
    },
    {
        "school": "Visitacion Valley Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005677",
    },
    {
        "school": "Visitacion Valley Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005678",
    },
    {
        "school": "West Portal Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005679",
    },
    {
        "school": "Cobb (William L.) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441005681",
    },
    {
        "school": "Sunset Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441006556",
    },
    {
        "school": "O'Connell (John) High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441007350",
    },
    {
        "school": "Life Learning Academy Charter",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441007721",
    },
    {
        "school": "Tenderloin Community",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441007732",
    },
    {
        "school": "Independence High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63441007840",
    },
    {
        "school": "Lilienthal (Claire) Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441007841",
    },
    {
        "school": "Everett Middle",
        "district": "San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441007842",
    },
    {
        "school": "Wallenberg (Raoul) Traditional High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441007845",
    },
    {
        "school": "Burton (Phillip and Sala) Academic High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441008189",
    },
    {
        "school": "Drew (Charles) College Preparatory Academy",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441008191",
    },
    {
        "school": "Yick Wo Elementary",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441008967",
    },
    {
        "school": "S.F. County Court Woodside Learning Ctr",
        "district": "San Francisco County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69111109270",
    },
    {
        "school": "S.F. County Opportunity (Hilltop)",
        "district": "San Francisco County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69111109472",
    },
    {
        "school": "S.F. County Special Education",
        "district": "San Francisco County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69111109473",
    },
    {
        "school": "Bayshore",
        "district": "Bayshore Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60420000379",
    },
    {
        "school": "Central Elementary",
        "district": "Belmont-Redwood Shores Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60453000414",
    },
    {
        "school": "Fox Elementary",
        "district": "Belmont-Redwood Shores Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60453000416",
    },
    {
        "school": "Nesbit Elementary",
        "district": "Belmont-Redwood Shores Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60453000418",
    },
    {
        "school": "Ralston Intermediate",
        "district": "Belmont-Redwood Shores Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60453000419",
    },
    {
        "school": "Cipriani Elementary",
        "district": "Belmont-Redwood Shores Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60453004019",
    },
    {
        "school": "Sandpiper Elementary",
        "district": "Belmont-Redwood Shores Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60453007417",
    },
    {
        "school": "Brisbane Elementary",
        "district": "Brisbane Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60606000541",
    },
    {
        "school": "Lipman Middle",
        "district": "Brisbane Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60606000542",
    },
    {
        "school": "Panorama Elementary",
        "district": "Brisbane Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60606000543",
    },
    {
        "school": "Burlingame Intermediate",
        "district": "Burlingame Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60648000581",
    },
    {
        "school": "Franklin Elementary",
        "district": "Burlingame Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60648000582",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Burlingame Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60648000583",
    },
    {
        "school": "McKinley Elementary",
        "district": "Burlingame Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60648000584",
    },
    {
        "school": "Washington Elementary",
        "district": "Burlingame Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60648000586",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Burlingame Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60648007418",
    },
    {
        "school": "Alvin S. Hatch Elementary",
        "district": "Cabrillo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60678000596",
    },
    {
        "school": "El Granada Elementary",
        "district": "Cabrillo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60678000597",
    },
    {
        "school": "Farallone View Elementary",
        "district": "Cabrillo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60678000598",
    },
    {
        "school": "Half Moon Bay High",
        "district": "Cabrillo Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60678000599",
    },
    {
        "school": "Kings Mountain Elementary",
        "district": "Cabrillo Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60678000600",
    },
    {
        "school": "Manuel F. Cunha Intermediate",
        "district": "Cabrillo Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60678000601",
    },
    {
        "school": "Pilarcitos Alternative High (Continuation)",
        "district": "Cabrillo Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60678000602",
    },
    {
        "school": "Crocker Middle",
        "district": "Hillsborough City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61719002172",
    },
    {
        "school": "South Hillsborough",
        "district": "Hillsborough City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61719002174",
    },
    {
        "school": "West Hillsborough",
        "district": "Hillsborough City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61719002175",
    },
    {
        "school": "North Hillsborough",
        "district": "Hillsborough City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61719009853",
    },
    {
        "school": "Benjamin Franklin Intermediate",
        "district": "Jefferson Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002278",
    },
    {
        "school": "Thomas R. Pollicita Middle",
        "district": "Jefferson Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002281",
    },
    {
        "school": "Daniel Webster Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002282",
    },
    {
        "school": "Fernando Rivera Intermediate",
        "district": "Jefferson Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002283",
    },
    {
        "school": "Franklin Delano Roosevelt Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002284",
    },
    {
        "school": "Garden Village Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002285",
    },
    {
        "school": "George Washington Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002286",
    },
    {
        "school": "John F. Kennedy Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002287",
    },
    {
        "school": "Margaret Pauline Brown Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002288",
    },
    {
        "school": "Marjorie H. Tobias Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002289",
    },
    {
        "school": "Thomas Edison Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002290",
    },
    {
        "school": "Westlake Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002291",
    },
    {
        "school": "Woodrow Wilson Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887002292",
    },
    {
        "school": "Susan B. Anthony Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61887007778",
    },
    {
        "school": "Thornton High",
        "district": "Jefferson Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61893001427",
    },
    {
        "school": "Jefferson High",
        "district": "Jefferson Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61893002293",
    },
    {
        "school": "Oceana High",
        "district": "Jefferson Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61893002294",
    },
    {
        "school": "Terra Nova High",
        "district": "Jefferson Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61893002296",
    },
    {
        "school": "Westmoor High",
        "district": "Jefferson Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61893002298",
    },
    {
        "school": "La Honda Elementary",
        "district": "La Honda-Pescadero Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62022002421",
    },
    {
        "school": "Pescadero Elementary and Middle",
        "district": "La Honda-Pescadero Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62022002422",
    },
    {
        "school": "Pescadero High",
        "district": "La Honda-Pescadero Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62022002423",
    },
    {
        "school": "Cabrillo Elementary",
        "district": "Pacifica",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62046002458",
    },
    {
        "school": "Ocean Shore Elementary",
        "district": "Pacifica",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62046002469",
    },
    {
        "school": "Vallemar Elementary",
        "district": "Pacifica",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62046002470",
    },
    {
        "school": "Sunset Ridge Elementary",
        "district": "Pacifica",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62046002471",
    },
    {
        "school": "La Entrada Middle",
        "district": "Las Lomitas Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62238002674",
    },
    {
        "school": "Las Lomitas Elementary",
        "district": "Las Lomitas Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62238002675",
    },
    {
        "school": "Encinal Elementary",
        "district": "Menlo Park City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62457003682",
    },
    {
        "school": "Hillview Middle",
        "district": "Menlo Park City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62457003683",
    },
    {
        "school": "Laurel Elementary",
        "district": "Menlo Park City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62457003684",
    },
    {
        "school": "Oak Knoll Elementary",
        "district": "Menlo Park City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62457003685",
    },
    {
        "school": "Green Hills Elementary",
        "district": "Millbrae Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62490003717",
    },
    {
        "school": "Lomita Park Elementary",
        "district": "Millbrae Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62490003718",
    },
    {
        "school": "Meadows Elementary",
        "district": "Millbrae Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62490003719",
    },
    {
        "school": "Spring Valley Elementary",
        "district": "Millbrae Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62490003721",
    },
    {
        "school": "Taylor Middle",
        "district": "Millbrae Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62490003722",
    },
    {
        "school": "Corte Madera",
        "district": "Portola Valley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63147004881",
    },
    {
        "school": "Ormondale Elementary",
        "district": "Portola Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63147004882",
    },
    {
        "school": "Belle Haven Elementary",
        "district": "Ravenswood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63186004913",
    },
    {
        "school": "Costano Elementary",
        "district": "Ravenswood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63186004915",
    },
    {
        "school": "Willow Oaks Elementary",
        "district": "Ravenswood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63186004917",
    },
    {
        "school": "Brentwood Academy",
        "district": "Ravenswood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63186008946",
    },
    {
        "school": "Clifford Elementary",
        "district": "Redwood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63213004962",
    },
    {
        "school": "Roy Cloud Elementary",
        "district": "Redwood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63213004963",
    },
    {
        "school": "Garfield Elementary",
        "district": "Redwood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63213004965",
    },
    {
        "school": "Henry Ford Elementary",
        "district": "Redwood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63213004967",
    },
    {
        "school": "Hoover Elementary",
        "district": "Redwood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63213004968",
    },
    {
        "school": "John F. Kennedy Middle",
        "district": "Redwood City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63213004970",
    },
    {
        "school": "McKinley Institute of Technology",
        "district": "Redwood City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63213004971",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Redwood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63213004972",
    },
    {
        "school": "Selby Lane Elementary",
        "district": "Redwood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63213004973",
    },
    {
        "school": "Taft Elementary",
        "district": "Redwood City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63213004974",
    },
    {
        "school": "North Star Academy",
        "district": "Redwood City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63213007422",
    },
    {
        "school": "Orion Alternative",
        "district": "Redwood City Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63213008182",
    },
    {
        "school": "Allen (Decima M.) Elementary",
        "district": "San Bruno Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63423005393",
    },
    {
        "school": "Belle Air Elementary",
        "district": "San Bruno Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63423005394",
    },
    {
        "school": "John Muir Elementary",
        "district": "San Bruno Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63423005397",
    },
    {
        "school": "Parkside Intermediate",
        "district": "San Bruno Park Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63423005398",
    },
    {
        "school": "Rollingwood Elementary",
        "district": "San Bruno Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63423005399",
    },
    {
        "school": "Portola Elementary",
        "district": "San Bruno Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63423008626",
    },
    {
        "school": "Arundel Elementary",
        "district": "San Carlos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63429005400",
    },
    {
        "school": "Brittan Acres Elementary",
        "district": "San Carlos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63429005401",
    },
    {
        "school": "Central Middle",
        "district": "San Carlos Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63429005402",
    },
    {
        "school": "Heather Elementary",
        "district": "San Carlos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63429005403",
    },
    {
        "school": "White Oaks Elementary",
        "district": "San Carlos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63429005405",
    },
    {
        "school": "Tierra Linda Middle",
        "district": "San Carlos Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63429008627",
    },
    {
        "school": "Fiesta Gardens International Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492002791",
    },
    {
        "school": "Brewer Island Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005404",
    },
    {
        "school": "Abbott Middle",
        "district": "San Mateo-Foster City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005896",
    },
    {
        "school": "Audubon Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005897",
    },
    {
        "school": "Baywood Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005899",
    },
    {
        "school": "Borel Middle",
        "district": "San Mateo-Foster City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005901",
    },
    {
        "school": "Bowditch Middle",
        "district": "San Mateo-Foster City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005902",
    },
    {
        "school": "Foster City Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005905",
    },
    {
        "school": "George Hall Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005906",
    },
    {
        "school": "Highlands Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005907",
    },
    {
        "school": "LEAD Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005908",
    },
    {
        "school": "Laurel Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005911",
    },
    {
        "school": "College Park Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005912",
    },
    {
        "school": "Meadow Heights Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005913",
    },
    {
        "school": "North Shoreview Montessori",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005914",
    },
    {
        "school": "San Mateo Park Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005915",
    },
    {
        "school": "Parkside Montessori",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005916",
    },
    {
        "school": "Sunnybrae Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492005917",
    },
    {
        "school": "Beresford Elementary",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492007781",
    },
    {
        "school": "Aragon High",
        "district": "San Mateo Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63498005919",
    },
    {
        "school": "Burlingame High",
        "district": "San Mateo Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63498005920",
    },
    {
        "school": "Capuchino High",
        "district": "San Mateo Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63498005921",
    },
    {
        "school": "Hillsdale High",
        "district": "San Mateo Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63498005923",
    },
    {
        "school": "Mills High",
        "district": "San Mateo Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63498005924",
    },
    {
        "school": "Peninsula High (Continuation)",
        "district": "San Mateo Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63498005925",
    },
    {
        "school": "San Mateo High",
        "district": "San Mateo Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63498005926",
    },
    {
        "school": "Carlmont High",
        "district": "Sequoia Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63639006194",
    },
    {
        "school": "Menlo-Atherton High",
        "district": "Sequoia Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63639006195",
    },
    {
        "school": "Redwood High",
        "district": "Sequoia Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63639006196",
    },
    {
        "school": "Sequoia High",
        "district": "Sequoia Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63639006198",
    },
    {
        "school": "Woodside High",
        "district": "Sequoia Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63639006199",
    },
    {
        "school": "Alta Loma Middle",
        "district": "South San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006339",
    },
    {
        "school": "Baden High (Continuation)",
        "district": "South San Francisco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63753006340",
    },
    {
        "school": "Buri Buri Elementary",
        "district": "South San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006341",
    },
    {
        "school": "El Camino High",
        "district": "South San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006342",
    },
    {
        "school": "Junipero Serra Elementary",
        "district": "South San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006345",
    },
    {
        "school": "Los Cerritos Elementary",
        "district": "South San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006346",
    },
    {
        "school": "Monte Verde Elementary",
        "district": "South San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006347",
    },
    {
        "school": "Parkway Heights Middle",
        "district": "South San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006348",
    },
    {
        "school": "Ponderosa Elementary",
        "district": "South San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006349",
    },
    {
        "school": "Skyline Elementary",
        "district": "South San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006351",
    },
    {
        "school": "South San Francisco High",
        "district": "South San Francisco Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006352",
    },
    {
        "school": "Spruce Elementary",
        "district": "South San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006354",
    },
    {
        "school": "Sunshine Gardens Elementary",
        "district": "South San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006355",
    },
    {
        "school": "Westborough Middle",
        "district": "South San Francisco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753006356",
    },
    {
        "school": "Martin Elementary",
        "district": "South San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753009197",
    },
    {
        "school": "Woodside Elementary",
        "district": "Woodside Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64314007013",
    },
    {
        "school": "San Mateo County Special Education",
        "district": "San Mateo County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69103309043",
    },
    {
        "school": "Hillcrest at Youth Services Center",
        "district": "San Mateo County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103309248",
    },
    {
        "school": "Bodega Bay Elementary",
        "district": "Shoreline Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63667006215",
    },
    {
        "school": "Silicon Valley Career Technical Education",
        "district": "Metro Education",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60013511457",
    },
    {
        "school": "Santa Clara County ROP-South",
        "district": "Santa Clara County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60013711459",
    },
    {
        "school": "Lrng in an Urban Comm with High Achievement (L.U.C.H.A.)",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60231011445",
    },
    {
        "school": "Renaissance Academy",
        "district": "Alum Rock Union Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60231011446",
    },
    {
        "school": "Adelante Dual Language Academy",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60231011793",
    },
    {
        "school": "Village",
        "district": "Campbell Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720011447",
    },
    {
        "school": "Sam H. Lawson Middle",
        "district": "Cupertino Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029011448",
    },
    {
        "school": "Evergreen Valley High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61182010665",
    },
    {
        "school": "Carolyn A. Clark Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314011451",
    },
    {
        "school": "Ramblewood Elementary",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437011452",
    },
    {
        "school": "Solorsano Middle",
        "district": "Gilroy Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518011203",
    },
    {
        "school": "Covington Elementary",
        "district": "Los Altos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62265011202",
    },
    {
        "school": "Gardner Bullis Elementary",
        "district": "Los Altos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62265011796",
    },
    {
        "school": "Ann Sobrato High",
        "district": "Morgan Hill Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583011453",
    },
    {
        "school": "Ellen Fletcher Middle",
        "district": "Palo Alto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961011454",
    },
    {
        "school": "Cienega Elementary",
        "district": "Cienega Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60864000883",
    },
    {
        "school": "Ladd Lane Elementary",
        "district": "Hollister",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61734002179",
    },
    {
        "school": "R. O. Hardin Elementary",
        "district": "Hollister",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61734002180",
    },
    {
        "school": "Rancho San Justo",
        "district": "Hollister",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61734002181",
    },
    {
        "school": "Sunnyslope Elementary",
        "district": "Hollister",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61734002182",
    },
    {
        "school": "Maze Middle",
        "district": "Hollister",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61734003760",
    },
    {
        "school": "Gabilan Hills",
        "district": "Hollister",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61734007252",
    },
    {
        "school": "Calaveras Elementary",
        "district": "Hollister",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61734008147",
    },
    {
        "school": "Cerra Vista Elementary",
        "district": "Hollister",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61734009378",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61881002276",
    },
    {
        "school": "Spring Grove Elementary",
        "district": "North County Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62748004137",
    },
    {
        "school": "Panoche Elementary",
        "district": "Panoche Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62977004635",
    },
    {
        "school": "San Benito High",
        "district": "San Benito High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63414005344",
    },
    {
        "school": "San Andreas Continuation High",
        "district": "San Benito High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63414008958",
    },
    {
        "school": "Southside Elementary",
        "district": "Southside Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63765006379",
    },
    {
        "school": "Tres Pinos Elementary",
        "district": "Tres Pinos Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63969006601",
    },
    {
        "school": "Willow Grove Elementary",
        "district": "Willow Grove Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64263006974",
    },
    {
        "school": "San Benito County Opportunity",
        "district": "San Benito County Office of Education",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102809240",
    },
    {
        "school": "San Benito County Juvenile Hall Court",
        "district": "San Benito County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102810171",
    },
    {
        "school": "Anzar High",
        "district": "Aromas - San Juan Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113603761",
    },
    {
        "school": "San Juan",
        "district": "Aromas - San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113610297",
    },
    {
        "school": "Aromas",
        "district": "Aromas - San Juan Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113610298",
    },
    {
        "school": "Clyde Arbuckle Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000100",
    },
    {
        "school": "Sylvia Cassell Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000101",
    },
    {
        "school": "Horace Cureton Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000102",
    },
    {
        "school": "A. J. Dorsa Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000103",
    },
    {
        "school": "Clyde L. Fischer Middle",
        "district": "Alum Rock Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000104",
    },
    {
        "school": "Joseph George Middle",
        "district": "Alum Rock Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000105",
    },
    {
        "school": "Aptitud Community Academy at Goss",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000106",
    },
    {
        "school": "O. S. Hubbard Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000107",
    },
    {
        "school": "Linda Vista Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000108",
    },
    {
        "school": "Lyndale Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000109",
    },
    {
        "school": "Lee Mathson Middle",
        "district": "Alum Rock Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000110",
    },
    {
        "school": "Cesar Chavez Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000111",
    },
    {
        "school": "Millard McCollam Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000112",
    },
    {
        "school": "Donald J. Meyer Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000113",
    },
    {
        "school": "Ocala Middle",
        "district": "Alum Rock Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000116",
    },
    {
        "school": "Thomas P. Ryan Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000120",
    },
    {
        "school": "San Antonio Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000121",
    },
    {
        "school": "William Sheppard Middle",
        "district": "Alum Rock Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231000122",
    },
    {
        "school": "Ben Painter Elementary",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231008782",
    },
    {
        "school": "Brooktree Elementary",
        "district": "Berryessa Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000457",
    },
    {
        "school": "Cherrywood Elementary",
        "district": "Berryessa Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000458",
    },
    {
        "school": "Laneview Elementary",
        "district": "Berryessa Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000459",
    },
    {
        "school": "Majestic Way Elementary",
        "district": "Berryessa Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000460",
    },
    {
        "school": "Morrill Middle",
        "district": "Berryessa Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000461",
    },
    {
        "school": "Noble Elementary",
        "district": "Berryessa Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000462",
    },
    {
        "school": "Northwood Elementary",
        "district": "Berryessa Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000463",
    },
    {
        "school": "Piedmont Middle",
        "district": "Berryessa Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000464",
    },
    {
        "school": "Ruskin Elementary",
        "district": "Berryessa Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000465",
    },
    {
        "school": "Sierramont Middle",
        "district": "Berryessa Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000466",
    },
    {
        "school": "Summerdale Elementary",
        "district": "Berryessa Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000467",
    },
    {
        "school": "Toyon Elementary",
        "district": "Berryessa Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000468",
    },
    {
        "school": "Vinci Park Elementary",
        "district": "Berryessa Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60480000469",
    },
    {
        "school": "Berryessa Union Elementary",
        "district": "Berryessa Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60480010400",
    },
    {
        "school": "Bagby Elementary",
        "district": "Cambrian",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60714000650",
    },
    {
        "school": "Fammatre Elementary",
        "district": "Cambrian",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60714000652",
    },
    {
        "school": "Farnham Charter",
        "district": "Cambrian",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60714000653",
    },
    {
        "school": "Price Charter Middle",
        "district": "Cambrian",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60714000654",
    },
    {
        "school": "Sartorette Charter",
        "district": "Cambrian",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60714000655",
    },
    {
        "school": "Blackford Elementary",
        "district": "Campbell Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720000657",
    },
    {
        "school": "Capri Elementary",
        "district": "Campbell Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720000663",
    },
    {
        "school": "Castlemont Elementary",
        "district": "Campbell Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720000664",
    },
    {
        "school": "Forest Hill Elementary",
        "district": "Campbell Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720000667",
    },
    {
        "school": "Lynhaven Elementary",
        "district": "Campbell Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720000670",
    },
    {
        "school": "Marshall Lane Elementary",
        "district": "Campbell Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720000671",
    },
    {
        "school": "Monroe Middle",
        "district": "Campbell Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720000672",
    },
    {
        "school": "Rolling Hills Middle",
        "district": "Campbell Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720000674",
    },
    {
        "school": "Rosemary",
        "district": "Campbell Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720000675",
    },
    {
        "school": "Sherman Oaks Elementary",
        "district": "Campbell Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720007427",
    },
    {
        "school": "Boynton High",
        "district": "Campbell Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60723000658",
    },
    {
        "school": "Del Mar High",
        "district": "Campbell Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60723000665",
    },
    {
        "school": "Prospect High",
        "district": "Campbell Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60723000673",
    },
    {
        "school": "Westmont High",
        "district": "Campbell Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60723000676",
    },
    {
        "school": "Leigh High",
        "district": "Campbell Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60723008122",
    },
    {
        "school": "Branham High",
        "district": "Campbell Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60723008350",
    },
    {
        "school": "Blue Hills Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001125",
    },
    {
        "school": "Cupertino Middle",
        "district": "Cupertino Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001127",
    },
    {
        "school": "Manuel De Vargas Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001128",
    },
    {
        "school": "Nelson S. Dilworth Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001129",
    },
    {
        "school": "Dwight D. Eisenhower Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001132",
    },
    {
        "school": "William Faria Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001133",
    },
    {
        "school": "Garden Gate Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001134",
    },
    {
        "school": "Warren E. Hyde Middle",
        "district": "Cupertino Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001136",
    },
    {
        "school": "John F. Kennedy Middle",
        "district": "Cupertino Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001138",
    },
    {
        "school": "Abraham Lincoln Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001139",
    },
    {
        "school": "R. I. Meyerholz Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001141",
    },
    {
        "school": "Joaquin Miller Middle",
        "district": "Cupertino Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001142",
    },
    {
        "school": "Montclaire Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001143",
    },
    {
        "school": "John Muir Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001144",
    },
    {
        "school": "Chester W. Nimitz Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001146",
    },
    {
        "school": "William Regnart Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001150",
    },
    {
        "school": "Stevens Creek Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001152",
    },
    {
        "school": "Louis E. Stocklmeir Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001153",
    },
    {
        "school": "West Valley Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029001154",
    },
    {
        "school": "D. J. Sedgwick Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029004034",
    },
    {
        "school": "Murdock-Portal Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029005406",
    },
    {
        "school": "C. B. Eaton Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029007787",
    },
    {
        "school": "L. P. Collins Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029008815",
    },
    {
        "school": "Christa McAuliffe Elementary",
        "district": "Cupertino Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61029009356",
    },
    {
        "school": "Foothill High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61182001300",
    },
    {
        "school": "Andrew P. Hill High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61182001301",
    },
    {
        "school": "Independence High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61182001302",
    },
    {
        "school": "James Lick High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61182001303",
    },
    {
        "school": "Mt. Pleasant High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61182001304",
    },
    {
        "school": "Oak Grove High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61182001305",
    },
    {
        "school": "William C. Overfelt High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61182001306",
    },
    {
        "school": "Piedmont Hills High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61182001307",
    },
    {
        "school": "Santa Teresa High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61182001308",
    },
    {
        "school": "Silver Creek High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61182001309",
    },
    {
        "school": "Yerba Buena High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61182001310",
    },
    {
        "school": "Apollo High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61182006643",
    },
    {
        "school": "Phoenix High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61182010318",
    },
    {
        "school": "Pegasus High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61182010320",
    },
    {
        "school": "Cadwallader Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314001490",
    },
    {
        "school": "Cedar Grove Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314001491",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314001492",
    },
    {
        "school": "George V. LeyVa Intermediate",
        "district": "Evergreen Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314001493",
    },
    {
        "school": "Holly Oak Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314001494",
    },
    {
        "school": "John J. Montgomery Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314001495",
    },
    {
        "school": "Katherine R. Smith Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314001496",
    },
    {
        "school": "Laurelwood Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314001497",
    },
    {
        "school": "O. B. Whaley Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314001498",
    },
    {
        "school": "Quimby Oak Middle",
        "district": "Evergreen Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314001499",
    },
    {
        "school": "Silver Oak Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314004054",
    },
    {
        "school": "Norwood Creek Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314007708",
    },
    {
        "school": "Tom Matsumoto Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314007788",
    },
    {
        "school": "James Franklin Smith Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314008631",
    },
    {
        "school": "Millbrook Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314008836",
    },
    {
        "school": "Dove Hill Elementary",
        "district": "Evergreen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314009366",
    },
    {
        "school": "Chaboya Middle",
        "district": "Evergreen Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61314010321",
    },
    {
        "school": "Bridges Academy",
        "district": "Franklin-McKinley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437001643",
    },
    {
        "school": "Franklin Elementary",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437001644",
    },
    {
        "school": "G. W. Hellyer Elementary",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437001645",
    },
    {
        "school": "Captain Jason M. Dahl Elementary",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437001646",
    },
    {
        "school": "Robert F. Kennedy Elementary",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437001647",
    },
    {
        "school": "Los Arboles Literacy and Technology Academy",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437001648",
    },
    {
        "school": "McKinley Elementary",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437001649",
    },
    {
        "school": "Santee Elementary",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437001650",
    },
    {
        "school": "Lairon College Preparatory Academy",
        "district": "Franklin-McKinley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437001651",
    },
    {
        "school": "Stonegate Elementary",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437001652",
    },
    {
        "school": "Sylvandale Middle",
        "district": "Franklin-McKinley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437001653",
    },
    {
        "school": "Shirakawa (George Sr.) Elementary",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437008352",
    },
    {
        "school": "Windmill Springs Elementary",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437008840",
    },
    {
        "school": "Jeanne R. Meadows Elementary",
        "district": "Franklin-McKinley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437009827",
    },
    {
        "school": "Cupertino High",
        "district": "Fremont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61443001695",
    },
    {
        "school": "Fremont High",
        "district": "Fremont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61443001696",
    },
    {
        "school": "Homestead High",
        "district": "Fremont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61443001697",
    },
    {
        "school": "Lynbrook High",
        "district": "Fremont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61443001698",
    },
    {
        "school": "Monta Vista High",
        "district": "Fremont Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61443001699",
    },
    {
        "school": "Community Day",
        "district": "Fremont Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61443008353",
    },
    {
        "school": "Luigi Aprea Elementary",
        "district": "Gilroy Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518001908",
    },
    {
        "school": "El Roble Elementary",
        "district": "Gilroy Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518001909",
    },
    {
        "school": "Eliot Elementary",
        "district": "Gilroy Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518001910",
    },
    {
        "school": "Gilroy High",
        "district": "Gilroy Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518001911",
    },
    {
        "school": "Glen View Elementary",
        "district": "Gilroy Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518001912",
    },
    {
        "school": "Las Animas Elementary",
        "district": "Gilroy Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518001914",
    },
    {
        "school": "Mt. Madonna High",
        "district": "Gilroy Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61518001915",
    },
    {
        "school": "Rucker Elementary",
        "district": "Gilroy Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518001916",
    },
    {
        "school": "South Valley Middle",
        "district": "Gilroy Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518001918",
    },
    {
        "school": "Brownell Middle",
        "district": "Gilroy Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518004070",
    },
    {
        "school": "Antonio Del Buono Elementary",
        "district": "Gilroy Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518008355",
    },
    {
        "school": "Rod Kelley Elementary",
        "district": "Gilroy Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518009140",
    },
    {
        "school": "Lakeside Elementary",
        "district": "Lakeside Joint",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62070002488",
    },
    {
        "school": "C. T. English Middle",
        "district": "Loma Prieta Joint Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62235002672",
    },
    {
        "school": "Loma Prieta Elementary",
        "district": "Loma Prieta Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62235002673",
    },
    {
        "school": "Almond Elementary",
        "district": "Los Altos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62265002782",
    },
    {
        "school": "Georgina P. Blach Junior High",
        "district": "Los Altos Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62265002783",
    },
    {
        "school": "Ardis G. Egan Junior High",
        "district": "Los Altos Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62265002786",
    },
    {
        "school": "Loyola Elementary",
        "district": "Los Altos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62265002787",
    },
    {
        "school": "Oak Avenue Elementary",
        "district": "Los Altos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62265002788",
    },
    {
        "school": "Santa Rita Elementary",
        "district": "Los Altos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62265002789",
    },
    {
        "school": "Springer Elementary",
        "district": "Los Altos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62265002790",
    },
    {
        "school": "Los Gatos High",
        "district": "Los Gatos-Saratoga Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62280003486",
    },
    {
        "school": "Saratoga High",
        "district": "Los Gatos-Saratoga Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62280003487",
    },
    {
        "school": "Blossom Hill Elementary",
        "district": "Los Gatos Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62283003489",
    },
    {
        "school": "Daves Avenue Elementary",
        "district": "Los Gatos Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62283003490",
    },
    {
        "school": "Lexington Elementary",
        "district": "Los Gatos Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62283003491",
    },
    {
        "school": "Louise Van Meter Elementary",
        "district": "Los Gatos Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62283003492",
    },
    {
        "school": "Raymond J. Fisher Middle",
        "district": "Los Gatos Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62283003495",
    },
    {
        "school": "Luther Burbank Elementary",
        "district": "Luther Burbank",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62313003530",
    },
    {
        "school": "William Burnett Elementary",
        "district": "Milpitas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450003663",
    },
    {
        "school": "Calaveras Hills",
        "district": "Milpitas Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62450003664",
    },
    {
        "school": "Curtner Elementary",
        "district": "Milpitas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450003665",
    },
    {
        "school": "Milpitas High",
        "district": "Milpitas Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450003666",
    },
    {
        "school": "Marshall Pomeroy Elementary",
        "district": "Milpitas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450003669",
    },
    {
        "school": "Rancho Milpitas Middle",
        "district": "Milpitas Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450003670",
    },
    {
        "school": "Robert Randall Elementary",
        "district": "Milpitas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450003671",
    },
    {
        "school": "Alexander Rose Elementary",
        "district": "Milpitas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450003672",
    },
    {
        "school": "John Sinnott Elementary",
        "district": "Milpitas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450003674",
    },
    {
        "school": "Anthony Spangler Elementary",
        "district": "Milpitas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450003675",
    },
    {
        "school": "Joseph Weller Elementary",
        "district": "Milpitas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450003676",
    },
    {
        "school": "Pearl Zanker Elementary",
        "district": "Milpitas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450003677",
    },
    {
        "school": "Thomas Russell Middle",
        "district": "Milpitas Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450009401",
    },
    {
        "school": "Country Lane Elementary",
        "district": "Moreland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62577003853",
    },
    {
        "school": "Easterbrook Discovery",
        "district": "Moreland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62577003854",
    },
    {
        "school": "Moreland Middle",
        "district": "Moreland",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62577003855",
    },
    {
        "school": "George C. Payne Elementary",
        "district": "Moreland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62577003856",
    },
    {
        "school": "Gussie M. Baker Elementary",
        "district": "Moreland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62577003857",
    },
    {
        "school": "Leroy Anderson Elementary",
        "district": "Moreland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62577003860",
    },
    {
        "school": "Lewis H. Britton Middle",
        "district": "Morgan Hill Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583003871",
    },
    {
        "school": "Central High (Continuation)",
        "district": "Morgan Hill Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62583003873",
    },
    {
        "school": "Jackson Academy of Music and Math (JAMM)",
        "district": "Morgan Hill Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583003876",
    },
    {
        "school": "Live Oak High",
        "district": "Morgan Hill Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583003877",
    },
    {
        "school": "Los Paseos Elementary",
        "district": "Morgan Hill Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583003878",
    },
    {
        "school": "Martin Murphy Middle",
        "district": "Morgan Hill Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583003880",
    },
    {
        "school": "Nordstrom Elementary",
        "district": "Morgan Hill Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583003881",
    },
    {
        "school": "Paradise Valley Engineering Academy",
        "district": "Morgan Hill Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583003882",
    },
    {
        "school": "San Martin Gwinn Environmental Science Academy",
        "district": "Morgan Hill Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583003883",
    },
    {
        "school": "P. A. Walsh STEAM Academy",
        "district": "Morgan Hill Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583003884",
    },
    {
        "school": "El Toro Health Science Academy",
        "district": "Morgan Hill Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583009937",
    },
    {
        "school": "Barrett Elementary",
        "district": "Morgan Hill Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62583010404",
    },
    {
        "school": "Benjamin Bubb Elementary",
        "district": "Mountain View Whisman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628003922",
    },
    {
        "school": "Mariano Castro Elementary",
        "district": "Mountain View Whisman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628003923",
    },
    {
        "school": "Isaac Newton Graham Middle",
        "district": "Mountain View Whisman",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628003924",
    },
    {
        "school": "Edith Landels Elementary",
        "district": "Mountain View Whisman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628003926",
    },
    {
        "school": "Crittenden Middle",
        "district": "Mountain View Whisman",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628006931",
    },
    {
        "school": "Monta Loma Elementary",
        "district": "Mountain View Whisman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628006932",
    },
    {
        "school": "Theuerkauf Elementary",
        "district": "Mountain View Whisman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628006933",
    },
    {
        "school": "Frank L. Huff Elementary",
        "district": "Mountain View Whisman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628007791",
    },
    {
        "school": "Los Altos High",
        "district": "Mountain View-Los Altos Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62631003929",
    },
    {
        "school": "Mountain View High",
        "district": "Mountain View-Los Altos Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62631003930",
    },
    {
        "school": "Alta Vista High",
        "district": "Mountain View-Los Altos Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62631003931",
    },
    {
        "school": "Ida Jew Academies",
        "district": "Mount Pleasant Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62640001486",
    },
    {
        "school": "August Boeger Middle",
        "district": "Mount Pleasant Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62640003987",
    },
    {
        "school": "Mt. Pleasant Elementary",
        "district": "Mount Pleasant Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62640003989",
    },
    {
        "school": "Robert Sanders Elementary",
        "district": "Mount Pleasant Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62640003990",
    },
    {
        "school": "Valle Vista Elementary",
        "district": "Mount Pleasant Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62640003991",
    },
    {
        "school": "Baldwin (Julia) Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004204",
    },
    {
        "school": "Bernal Intermediate",
        "district": "Oak Grove Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004205",
    },
    {
        "school": "Christopher Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004208",
    },
    {
        "school": "Davis (Caroline) Intermediate",
        "district": "Oak Grove Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004209",
    },
    {
        "school": "Del Roble Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004210",
    },
    {
        "school": "Edenvale Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004212",
    },
    {
        "school": "Frost (Earl) Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004213",
    },
    {
        "school": "Hayes Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004215",
    },
    {
        "school": "Herman (Leonard) Intermediate",
        "district": "Oak Grove Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004216",
    },
    {
        "school": "Oak Ridge Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004218",
    },
    {
        "school": "Parkview Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004219",
    },
    {
        "school": "Sakamoto Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004220",
    },
    {
        "school": "Stipe (Samuel) Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004221",
    },
    {
        "school": "Santa Teresa Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004223",
    },
    {
        "school": "Taylor (Bertha) Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781004224",
    },
    {
        "school": "Ledesma (Rita) Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781008358",
    },
    {
        "school": "The Academy",
        "district": "Oak Grove Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62781008359",
    },
    {
        "school": "Anderson (Alex) Elementary",
        "district": "Oak Grove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62781009413",
    },
    {
        "school": "Orchard Elementary",
        "district": "Orchard Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62868004460",
    },
    {
        "school": "Addison Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004579",
    },
    {
        "school": "Herbert Hoover Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004581",
    },
    {
        "school": "El Carmelo Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004583",
    },
    {
        "school": "Escondido Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004584",
    },
    {
        "school": "Fairmeadow Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004585",
    },
    {
        "school": "Duveneck Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004586",
    },
    {
        "school": "Henry M. Gunn High",
        "district": "Palo Alto Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004587",
    },
    {
        "school": "Walter Hays Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004588",
    },
    {
        "school": "Juana Briones Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004591",
    },
    {
        "school": "Ohlone Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004592",
    },
    {
        "school": "Lucille M. Nixon Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004594",
    },
    {
        "school": "Palo Alto High",
        "district": "Palo Alto Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004596",
    },
    {
        "school": "Palo Verde Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004597",
    },
    {
        "school": "Jane Lathrop Stanford Middle",
        "district": "Palo Alto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961004598",
    },
    {
        "school": "Greendell",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961007797",
    },
    {
        "school": "Barron Park Elementary",
        "district": "Palo Alto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961007802",
    },
    {
        "school": "Packard Children's Hospital/Stanford",
        "district": "Palo Alto Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62961007813",
    },
    {
        "school": "Frank S. Greene Jr. Middle",
        "district": "Palo Alto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62961010323",
    },
    {
        "school": "Williams Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459001538",
    },
    {
        "school": "River Glen",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459004084",
    },
    {
        "school": "Abraham Lincoln High",
        "district": "San Jose Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005696",
    },
    {
        "school": "Allen at Steinbeck",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005697",
    },
    {
        "school": "Almaden Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005698",
    },
    {
        "school": "Anne Darling Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005699",
    },
    {
        "school": "Walter L. Bachrodt Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005700",
    },
    {
        "school": "Booksin Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005702",
    },
    {
        "school": "Bret Harte Middle",
        "district": "San Jose Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005703",
    },
    {
        "school": "Rachel Carson Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005706",
    },
    {
        "school": "Castillero Middle",
        "district": "San Jose Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005707",
    },
    {
        "school": "Broadway High",
        "district": "San Jose Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63459005709",
    },
    {
        "school": "Willow Glen Middle",
        "district": "San Jose Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005710",
    },
    {
        "school": "Empire Gardens Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005711",
    },
    {
        "school": "Gardner Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005713",
    },
    {
        "school": "Grant Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005714",
    },
    {
        "school": "Graystone Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005715",
    },
    {
        "school": "Gunderson High",
        "district": "San Jose Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005716",
    },
    {
        "school": "Herbert Hoover Middle",
        "district": "San Jose Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005720",
    },
    {
        "school": "Horace Mann Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005722",
    },
    {
        "school": "John Muir Middle",
        "district": "San Jose Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005723",
    },
    {
        "school": "Leland High",
        "district": "San Jose Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005725",
    },
    {
        "school": "Los Alamitos Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005727",
    },
    {
        "school": "Lowell Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005728",
    },
    {
        "school": "Selma Olinder Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005730",
    },
    {
        "school": "Muwekma Ohlone Middle",
        "district": "San Jose Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005731",
    },
    {
        "school": "Pioneer High",
        "district": "San Jose Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005732",
    },
    {
        "school": "Reed Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005734",
    },
    {
        "school": "San Jose High",
        "district": "San Jose Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005736",
    },
    {
        "school": "Schallenberger Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005737",
    },
    {
        "school": "Simonds Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005738",
    },
    {
        "school": "Terrell Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005740",
    },
    {
        "school": "Merritt Trace Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005741",
    },
    {
        "school": "Hacienda Science/Environmental Magnet",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005742",
    },
    {
        "school": "Washington Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005743",
    },
    {
        "school": "Willow Glen Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005745",
    },
    {
        "school": "Willow Glen High",
        "district": "San Jose Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459005746",
    },
    {
        "school": "Liberty (Alternative)",
        "district": "San Jose Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63459006645",
    },
    {
        "school": "Hammer Montessori at Galarza Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459007429",
    },
    {
        "school": "Middle College High",
        "district": "San Jose Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459008633",
    },
    {
        "school": "Canoas Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459008634",
    },
    {
        "school": "Ernesto Galarza Elementary",
        "district": "San Jose Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63459010411",
    },
    {
        "school": "Braly Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543001588",
    },
    {
        "school": "Juan Cabrillo Middle",
        "district": "Santa Clara Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543001599",
    },
    {
        "school": "Bowers Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006033",
    },
    {
        "school": "Bracher Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006034",
    },
    {
        "school": "Briarwood Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006036",
    },
    {
        "school": "C. W. Haman Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006040",
    },
    {
        "school": "Kathryn Hughes Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006041",
    },
    {
        "school": "Laurelwood Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006042",
    },
    {
        "school": "George Mayne Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006043",
    },
    {
        "school": "Millikin Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006044",
    },
    {
        "school": "Montague Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006045",
    },
    {
        "school": "Pomeroy Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006048",
    },
    {
        "school": "Ponderosa Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006049",
    },
    {
        "school": "Scott Lane Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006051",
    },
    {
        "school": "Sutter Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006052",
    },
    {
        "school": "New Valley Continuation High",
        "district": "Santa Clara Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63543006053",
    },
    {
        "school": "Westwood Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006054",
    },
    {
        "school": "Adrian Wilcox High",
        "district": "Santa Clara Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006055",
    },
    {
        "school": "Washington Open Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543006650",
    },
    {
        "school": "Buchser Middle",
        "district": "Santa Clara Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543007866",
    },
    {
        "school": "Marian A. Peterson Middle",
        "district": "Santa Clara Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543007867",
    },
    {
        "school": "Santa Clara High",
        "district": "Santa Clara Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543007868",
    },
    {
        "school": "Wilson Alternative",
        "district": "Santa Clara Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63543008984",
    },
    {
        "school": "Argonaut Elementary",
        "district": "Saratoga Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63591006147",
    },
    {
        "school": "Foothill Elementary",
        "district": "Saratoga Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63591006149",
    },
    {
        "school": "Redwood Middle",
        "district": "Saratoga Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63591006150",
    },
    {
        "school": "Saratoga Elementary",
        "district": "Saratoga Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63591006151",
    },
    {
        "school": "Vargas Elementary",
        "district": "Sunnyvale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63846002796",
    },
    {
        "school": "San Miguel Elementary",
        "district": "Sunnyvale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63846004088",
    },
    {
        "school": "Bishop Elementary",
        "district": "Sunnyvale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63846006456",
    },
    {
        "school": "Cherry Chase Elementary",
        "district": "Sunnyvale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63846006458",
    },
    {
        "school": "Cumberland Elementary",
        "district": "Sunnyvale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63846006459",
    },
    {
        "school": "Ellis Elementary",
        "district": "Sunnyvale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63846006460",
    },
    {
        "school": "Lakewood Elementary",
        "district": "Sunnyvale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63846006463",
    },
    {
        "school": "Columbia Middle",
        "district": "Sunnyvale",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63846006464",
    },
    {
        "school": "Sunnyvale Middle",
        "district": "Sunnyvale",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63846006465",
    },
    {
        "school": "Fairwood Elementary",
        "district": "Sunnyvale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63846007433",
    },
    {
        "school": "Alta Vista Elementary",
        "district": "Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64032006667",
    },
    {
        "school": "Carlton Elementary",
        "district": "Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64032006669",
    },
    {
        "school": "Dartmouth Middle",
        "district": "Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64032006671",
    },
    {
        "school": "Guadalupe Elementary",
        "district": "Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64032006672",
    },
    {
        "school": "Lietz Elementary",
        "district": "Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64032006674",
    },
    {
        "school": "Noddin Elementary",
        "district": "Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64032006677",
    },
    {
        "school": "Oster Elementary",
        "district": "Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64032006678",
    },
    {
        "school": "Union Middle",
        "district": "Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64032006680",
    },
    {
        "school": "Santa Clara County Community",
        "district": "Santa Clara County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103507782",
    },
    {
        "school": "Santa Clara County Court",
        "district": "Santa Clara County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103509045",
    },
    {
        "school": "Santa Clara County Special Education",
        "district": "Santa Clara County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69103509250",
    },
    {
        "school": "Nipomo High",
        "district": "Lucia Mar Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308010656",
    },
    {
        "school": "Cappy Culver Elementary",
        "district": "San Miguel Joint Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63501011786",
    },
    {
        "school": "San Luis Obispo County Community",
        "district": "San Luis Obispo County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103210655",
    },
    {
        "school": "Grizzly ChalleNGe Charter",
        "district": "San Luis Obispo County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69103211281",
    },
    {
        "school": "Parkfield Elementary",
        "district": "Shandon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63645006201",
    },
    {
        "school": "Paso Robles High",
        "district": "Paso Robles Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004807404",
    },
    {
        "school": "Liberty High (Continuation)",
        "district": "Paso Robles Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004807405",
    },
    {
        "school": "Georgia Brown Dual Immersion Magnet Elementary",
        "district": "Paso Robles Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004807406",
    },
    {
        "school": "Arts Academy at Bauer Speck Elementary",
        "district": "Paso Robles Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004807407",
    },
    {
        "school": "Winifred Pifer Elementary",
        "district": "Paso Robles Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004807408",
    },
    {
        "school": "George H. Flamson Middle",
        "district": "Paso Robles Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004807409",
    },
    {
        "school": "Virginia Peterson Elementary",
        "district": "Paso Robles Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004807410",
    },
    {
        "school": "Pat Butler Elementary",
        "district": "Paso Robles Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004807411",
    },
    {
        "school": "Daniel Lewis Middle",
        "district": "Paso Robles Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004807412",
    },
    {
        "school": "Paso Robles Independent Study Center",
        "district": "Paso Robles Joint Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004810395",
    },
    {
        "school": "Kermit King Elementary",
        "district": "Paso Robles Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004810396",
    },
    {
        "school": "Leffingwell High (Continuation)",
        "district": "Coast Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004907413",
    },
    {
        "school": "Coast Union High",
        "district": "Coast Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004907414",
    },
    {
        "school": "Cambria Grammar",
        "district": "Coast Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004907415",
    },
    {
        "school": "Santa Lucia Middle",
        "district": "Coast Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004907416",
    },
    {
        "school": "Atascadero High",
        "district": "Atascadero Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60330000247",
    },
    {
        "school": "Atascadero Middle",
        "district": "Atascadero Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60330000248",
    },
    {
        "school": "Carrisa Plains Elementary",
        "district": "Atascadero Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60330000249",
    },
    {
        "school": "Creston Elementary",
        "district": "Atascadero Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60330000250",
    },
    {
        "school": "Monterey Road Elementary",
        "district": "Atascadero Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60330000252",
    },
    {
        "school": "Santa Margarita Elementary",
        "district": "Atascadero Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60330000254",
    },
    {
        "school": "Santa Rosa Road Academic Academy",
        "district": "Atascadero Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60330000255",
    },
    {
        "school": "San Benito Elementary",
        "district": "Atascadero Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60330001384",
    },
    {
        "school": "Paloma Creek High",
        "district": "Atascadero Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60330006562",
    },
    {
        "school": "Fine Arts Academy",
        "district": "Atascadero Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60330008624",
    },
    {
        "school": "San Gabriel Elementary",
        "district": "Atascadero Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60330009303",
    },
    {
        "school": "Atascadero Choices in Education Academy (ACE)",
        "district": "Atascadero Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60330010317",
    },
    {
        "school": "Cayucos Elementary",
        "district": "Cayucos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60784007271",
    },
    {
        "school": "Arroyo Grande High",
        "district": "Lucia Mar Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003516",
    },
    {
        "school": "Branch Elementary",
        "district": "Lucia Mar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003517",
    },
    {
        "school": "Dana Elementary",
        "district": "Lucia Mar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003518",
    },
    {
        "school": "Grover Beach Elementary",
        "district": "Lucia Mar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003519",
    },
    {
        "school": "Grover Heights Elementary",
        "district": "Lucia Mar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003520",
    },
    {
        "school": "Harloe Elementary",
        "district": "Lucia Mar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003521",
    },
    {
        "school": "Judkins Middle",
        "district": "Lucia Mar Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003522",
    },
    {
        "school": "Lopez Continuation High",
        "district": "Lucia Mar Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62308003523",
    },
    {
        "school": "Nipomo Elementary",
        "district": "Lucia Mar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003524",
    },
    {
        "school": "Fairgrove Elementary",
        "district": "Lucia Mar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003525",
    },
    {
        "school": "Ocean View Elementary",
        "district": "Lucia Mar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003526",
    },
    {
        "school": "Oceano Elementary",
        "district": "Lucia Mar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003527",
    },
    {
        "school": "Paulding Middle",
        "district": "Lucia Mar Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003528",
    },
    {
        "school": "Shell Beach Elementary",
        "district": "Lucia Mar Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308003529",
    },
    {
        "school": "Mesa Middle",
        "district": "Lucia Mar Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308009910",
    },
    {
        "school": "Pleasant Valley Elementary",
        "district": "Pleasant Valley Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63102004808",
    },
    {
        "school": "Monarch Grove Elementary",
        "district": "San Luis Coastal Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480001393",
    },
    {
        "school": "Baywood Elementary",
        "district": "San Luis Coastal Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480005867",
    },
    {
        "school": "Bishop's Peak Elementary",
        "district": "San Luis Coastal Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480005869",
    },
    {
        "school": "Hawthorne Elementary",
        "district": "San Luis Coastal Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480005871",
    },
    {
        "school": "Laguna Middle",
        "district": "San Luis Coastal Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480005872",
    },
    {
        "school": "Los Osos Middle",
        "district": "San Luis Coastal Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480005873",
    },
    {
        "school": "Los Ranchos Elementary",
        "district": "San Luis Coastal Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480005874",
    },
    {
        "school": "Morro Bay High",
        "district": "San Luis Coastal Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480005875",
    },
    {
        "school": "Pacheco Elementary",
        "district": "San Luis Coastal Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480005877",
    },
    {
        "school": "Pacific Beach High",
        "district": "San Luis Coastal Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63480005878",
    },
    {
        "school": "San Luis Obispo High",
        "district": "San Luis Coastal Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480005880",
    },
    {
        "school": "Sinsheimer Elementary",
        "district": "San Luis Coastal Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480005881",
    },
    {
        "school": "C L Smith Elementary",
        "district": "San Luis Coastal Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480005882",
    },
    {
        "school": "Teach Elementary",
        "district": "San Luis Coastal Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480009192",
    },
    {
        "school": "Del Mar Elementary",
        "district": "San Luis Coastal Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63480010066",
    },
    {
        "school": "Lillian Larsen Elementary",
        "district": "San Miguel Joint Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63501005927",
    },
    {
        "school": "Shandon Elementary",
        "district": "Shandon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63645006202",
    },
    {
        "school": "Shandon High",
        "district": "Shandon Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63645006203",
    },
    {
        "school": "Eagle Canyon High",
        "district": "Templeton Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63900002780",
    },
    {
        "school": "Vineyard Elementary",
        "district": "Templeton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63900004016",
    },
    {
        "school": "Templeton Elementary",
        "district": "Templeton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63900006541",
    },
    {
        "school": "Templeton High",
        "district": "Templeton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63900006542",
    },
    {
        "school": "Templeton Independent Study High",
        "district": "Templeton Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63900007776",
    },
    {
        "school": "Templeton Home",
        "district": "Templeton Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63900008622",
    },
    {
        "school": "Templeton Middle",
        "district": "Templeton Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63900008996",
    },
    {
        "school": "San Luis Obispo County Juvenile Court",
        "district": "San Luis Obispo County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103209246",
    },
    {
        "school": "San Luis County Special Education",
        "district": "San Luis Obispo County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69103209247",
    },
    {
        "school": "Santa Barbara County ROP-South",
        "district": "Santa Barbara County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60013311439",
    },
    {
        "school": "Santa Barbara County ROP-North",
        "district": "Santa Barbara County ROP",
        "level": "Adult Education",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60013311440",
    },
    {
        "school": "Taylor (Ida Redmond) Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558010659",
    },
    {
        "school": "Arellanes Junior High",
        "district": "Santa Maria-Bonita",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558010660",
    },
    {
        "school": "Sanchez (David J.) Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558011435",
    },
    {
        "school": "Kunst (Tommie) Junior High",
        "district": "Santa Maria-Bonita",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558011436",
    },
    {
        "school": "Liberty Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558011437",
    },
    {
        "school": "Oak Valley Elementary",
        "district": "Buellton Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60633010661",
    },
    {
        "school": "Carpinteria Family",
        "district": "Carpinteria Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60756011345",
    },
    {
        "school": "Mission Valley",
        "district": "Lompoc Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62241011344",
    },
    {
        "school": "Pioneer Valley High",
        "district": "Santa Maria Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63567011438",
    },
    {
        "school": "Santa Barbara County Community",
        "district": "Santa Barbara County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103410658",
    },
    {
        "school": "Sierra Madre High (Continuation)",
        "district": "Cuyama Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60000901478",
    },
    {
        "school": "Cuyama Valley High",
        "district": "Cuyama Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60000908779",
    },
    {
        "school": "Cuyama Elementary",
        "district": "Cuyama Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60000908780",
    },
    {
        "school": "Ballard Elementary",
        "district": "Ballard Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60372000343",
    },
    {
        "school": "Benjamin Foxen Elementary",
        "district": "Blochman Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60528000498",
    },
    {
        "school": "Bonita Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558000502",
    },
    {
        "school": "Adam (William Laird) Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009312",
    },
    {
        "school": "Alvin Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009313",
    },
    {
        "school": "Arellanes (Don Juan Bautista) Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009314",
    },
    {
        "school": "El Camino Junior High",
        "district": "Santa Maria-Bonita",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009315",
    },
    {
        "school": "Fairlawn Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009316",
    },
    {
        "school": "Fesler (Isaac) Junior High",
        "district": "Santa Maria-Bonita",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009317",
    },
    {
        "school": "Tunnell (Martin Luther) Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009318",
    },
    {
        "school": "Miller (Isaac) Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009319",
    },
    {
        "school": "Oakley (Calvin C.) Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009320",
    },
    {
        "school": "Rice (William) Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009321",
    },
    {
        "school": "Bruce (Robert) Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009322",
    },
    {
        "school": "Battles (Washington) Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009323",
    },
    {
        "school": "Ontiveros (Juan Pacifico) Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558009727",
    },
    {
        "school": "Jonata Middle",
        "district": "Buellton Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60633000551",
    },
    {
        "school": "Aliso Elementary",
        "district": "Carpinteria Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60756000724",
    },
    {
        "school": "Canalino Elementary",
        "district": "Carpinteria Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60756000725",
    },
    {
        "school": "Carpinteria Middle",
        "district": "Carpinteria Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60756000726",
    },
    {
        "school": "Carpinteria Senior High",
        "district": "Carpinteria Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60756000727",
    },
    {
        "school": "Summerland Elementary",
        "district": "Carpinteria Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60756000729",
    },
    {
        "school": "Rincon High (Continuation)",
        "district": "Carpinteria Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60756001445",
    },
    {
        "school": "Foothill Alternative High",
        "district": "Carpinteria Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60756006574",
    },
    {
        "school": "Cold Spring Elementary",
        "district": "Cold Spring Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60927000939",
    },
    {
        "school": "Santa Ynez Elementary",
        "district": "College Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60933000942",
    },
    {
        "school": "College Elementary",
        "district": "College Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60933007425",
    },
    {
        "school": "Ellwood Elementary",
        "district": "Goleta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61551001969",
    },
    {
        "school": "Foothill Elementary",
        "district": "Goleta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61551001970",
    },
    {
        "school": "Hollister Elementary",
        "district": "Goleta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61551001971",
    },
    {
        "school": "Isla Vista Elementary",
        "district": "Goleta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61551001972",
    },
    {
        "school": "Kellogg Elementary",
        "district": "Goleta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61551001973",
    },
    {
        "school": "La Patera Elementary",
        "district": "Goleta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61551001974",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Goleta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61551001975",
    },
    {
        "school": "Brandon Elementary",
        "district": "Goleta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61551006622",
    },
    {
        "school": "El Camino Elementary",
        "district": "Goleta Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61551008345",
    },
    {
        "school": "Mary Buren Elementary",
        "district": "Guadalupe Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61626002029",
    },
    {
        "school": "Kermit McKenzie Intermediate",
        "district": "Guadalupe Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61626002030",
    },
    {
        "school": "Monte Vista Elementary",
        "district": "Hope Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61749002189",
    },
    {
        "school": "Vieja Valley Elementary",
        "district": "Hope Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61749002190",
    },
    {
        "school": "Hope Elementary",
        "district": "Hope Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61749007426",
    },
    {
        "school": "Buena Vista Elementary",
        "district": "Lompoc Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241002676",
    },
    {
        "school": "Cabrillo High",
        "district": "Lompoc Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241002677",
    },
    {
        "school": "Crestview Elementary",
        "district": "Lompoc Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241002678",
    },
    {
        "school": "Leonora Fillmore Elementary",
        "district": "Lompoc Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241002680",
    },
    {
        "school": "Arthur Hapgood Elementary",
        "district": "Lompoc Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241002681",
    },
    {
        "school": "La Canada Elementary",
        "district": "Lompoc Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241002682",
    },
    {
        "school": "Lompoc Valley Middle",
        "district": "Lompoc Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241002683",
    },
    {
        "school": "Lompoc High",
        "district": "Lompoc Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241002684",
    },
    {
        "school": "Los Berros Visual and Performing Arts Academy",
        "district": "Lompoc Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241002685",
    },
    {
        "school": "Maple High",
        "district": "Lompoc Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62241002687",
    },
    {
        "school": "Clarence Ruth Elementary",
        "district": "Lompoc Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241002689",
    },
    {
        "school": "Vandenberg Middle",
        "district": "Lompoc Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241002690",
    },
    {
        "school": "La Honda STEAM Academy",
        "district": "Lompoc Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241007298",
    },
    {
        "school": "Miguelito Elementary",
        "district": "Lompoc Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62241008882",
    },
    {
        "school": "Los Olivos Elementary",
        "district": "Los Olivos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62292003504",
    },
    {
        "school": "Montecito Union",
        "district": "Montecito Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62550003815",
    },
    {
        "school": "Ralph Dunlap Elementary",
        "district": "Orcutt Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62871004461",
    },
    {
        "school": "Lakeview Junior High",
        "district": "Orcutt Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62871004463",
    },
    {
        "school": "Joe Nightingale Elementary",
        "district": "Orcutt Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62871004464",
    },
    {
        "school": "Orcutt Junior High",
        "district": "Orcutt Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62871004465",
    },
    {
        "school": "Patterson Road Elementary",
        "district": "Orcutt Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62871004466",
    },
    {
        "school": "Pine Grove Elementary",
        "district": "Orcutt Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62871004467",
    },
    {
        "school": "Alice Shaw Elementary",
        "district": "Orcutt Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62871004468",
    },
    {
        "school": "Delta High",
        "district": "Santa Maria Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63567006082",
    },
    {
        "school": "Ernest Righetti High",
        "district": "Santa Maria Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63567006083",
    },
    {
        "school": "Santa Maria High",
        "district": "Santa Maria Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63567006084",
    },
    {
        "school": "Santa Ynez Valley Union High",
        "district": "Santa Ynez Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63585006136",
    },
    {
        "school": "Refugio High",
        "district": "Santa Ynez Valley Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63585007361",
    },
    {
        "school": "Solvang Elementary",
        "district": "Solvang Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63711006295",
    },
    {
        "school": "Vista de Las Cruces",
        "district": "Vista del Mar Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64122006826",
    },
    {
        "school": "Santa Barbara County Special Education",
        "district": "Santa Barbara County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69103407192",
    },
    {
        "school": "Santa Barbara County Juvenile Court",
        "district": "Santa Barbara County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103409249",
    },
    {
        "school": "Santa Cruz County ROP",
        "district": "Santa Cruz County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60014311465",
    },
    {
        "school": "Tierra Pacifica Charter",
        "district": "Live Oak Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62199011260",
    },
    {
        "school": "Radcliff Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949011460",
    },
    {
        "school": "Landmark Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949011461",
    },
    {
        "school": "Pajaro Valley High",
        "district": "Pajaro Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949011462",
    },
    {
        "school": "Cesar E. Chavez Middle",
        "district": "Pajaro Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949011463",
    },
    {
        "school": "Santa Cruz County Community",
        "district": "Santa Cruz County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103610668",
    },
    {
        "school": "Hall District Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004543",
    },
    {
        "school": "Pajaro Middle",
        "district": "Pajaro Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004547",
    },
    {
        "school": "Ohlone Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949009600",
    },
    {
        "school": "Brook Knoll Elementary",
        "district": "Scotts Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004306172",
    },
    {
        "school": "Scotts Valley Middle",
        "district": "Scotts Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004306173",
    },
    {
        "school": "Vine Hill Elementary",
        "district": "Scotts Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004306174",
    },
    {
        "school": "Scotts Valley High",
        "district": "Scotts Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004308369",
    },
    {
        "school": "Bonny Doon Elementary",
        "district": "Bonny Doon Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60564000515",
    },
    {
        "school": "Happy Valley Elementary",
        "district": "Happy Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61656002088",
    },
    {
        "school": "Green Acres Elementary",
        "district": "Live Oak Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62199002611",
    },
    {
        "school": "Live Oak Elementary",
        "district": "Live Oak Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62199002612",
    },
    {
        "school": "Shoreline Middle",
        "district": "Live Oak Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62199007434",
    },
    {
        "school": "Del Mar Elementary",
        "district": "Live Oak Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62199007435",
    },
    {
        "school": "Ocean Alternative Education Center",
        "district": "Live Oak Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62199010412",
    },
    {
        "school": "Mountain Elementary",
        "district": "Mountain Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62607009166",
    },
    {
        "school": "Pacific Elementary",
        "district": "Pacific Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62934004525",
    },
    {
        "school": "Amesti Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004534",
    },
    {
        "school": "Aptos High",
        "district": "Pajaro Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004535",
    },
    {
        "school": "Aptos Junior High",
        "district": "Pajaro Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004536",
    },
    {
        "school": "Bradley Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004538",
    },
    {
        "school": "Calabasas Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004539",
    },
    {
        "school": "E. A. Hall Middle",
        "district": "Pajaro Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004540",
    },
    {
        "school": "Freedom Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004541",
    },
    {
        "school": "H. A. Hyde Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004542",
    },
    {
        "school": "Mar Vista Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004545",
    },
    {
        "school": "Mintie White Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004546",
    },
    {
        "school": "Renaissance High Continuation",
        "district": "Pajaro Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62949004548",
    },
    {
        "school": "Rio del Mar Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004549",
    },
    {
        "school": "Rolling Hills Middle",
        "district": "Pajaro Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004550",
    },
    {
        "school": "T. S. MacQuiddy Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004552",
    },
    {
        "school": "Valencia Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004553",
    },
    {
        "school": "Alianza Charter",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004554",
    },
    {
        "school": "Watsonville High",
        "district": "Pajaro Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949004555",
    },
    {
        "school": "Lakeview Middle",
        "district": "Pajaro Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949006662",
    },
    {
        "school": "New School Community Day",
        "district": "Pajaro Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62949007436",
    },
    {
        "school": "Pacific Coast Charter",
        "district": "Pajaro Valley Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949008364",
    },
    {
        "school": "Diamond Technology Institute",
        "district": "Pajaro Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949008366",
    },
    {
        "school": "Ann Soldo Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949008368",
    },
    {
        "school": "Linscott Charter",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949009599",
    },
    {
        "school": "Starlight Elementary",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949009601",
    },
    {
        "school": "Watsonville Charter School of the Arts",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949010413",
    },
    {
        "school": "SLVUSD Charter",
        "district": "San Lorenzo Valley Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63474002797",
    },
    {
        "school": "Boulder Creek Elementary",
        "district": "San Lorenzo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63474005861",
    },
    {
        "school": "San Lorenzo Valley Elementary",
        "district": "San Lorenzo Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63474005863",
    },
    {
        "school": "San Lorenzo Valley Middle",
        "district": "San Lorenzo Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63474005864",
    },
    {
        "school": "San Lorenzo Valley High",
        "district": "San Lorenzo Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63474005865",
    },
    {
        "school": "Bay View Elementary",
        "district": "Santa Cruz City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63559006058",
    },
    {
        "school": "De Laveaga Elementary",
        "district": "Santa Cruz City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63559006061",
    },
    {
        "school": "Gault Elementary",
        "district": "Santa Cruz City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63559006062",
    },
    {
        "school": "Westlake Elementary",
        "district": "Santa Cruz City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63559006069",
    },
    {
        "school": "Santa Cruz City Elementary Alternative Education-Monarch",
        "district": "Santa Cruz City Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63559010080",
    },
    {
        "school": "Branciforte Middle",
        "district": "Santa Cruz City High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63560006060",
    },
    {
        "school": "Harbor High",
        "district": "Santa Cruz City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63560006063",
    },
    {
        "school": "Costanoa Continuation High",
        "district": "Santa Cruz City High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63560006064",
    },
    {
        "school": "Mission Hill Middle",
        "district": "Santa Cruz City High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63560006065",
    },
    {
        "school": "Santa Cruz High",
        "district": "Santa Cruz City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63560006067",
    },
    {
        "school": "Soquel High",
        "district": "Santa Cruz City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63560006068",
    },
    {
        "school": "Delta Charter",
        "district": "Santa Cruz City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63560006664",
    },
    {
        "school": "Alternative Family Education",
        "district": "Santa Cruz City High",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63560007437",
    },
    {
        "school": "Ark Independent Studies",
        "district": "Santa Cruz City High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63560007869",
    },
    {
        "school": "Main Street Elementary",
        "district": "Soquel Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63729002798",
    },
    {
        "school": "New Brighton Middle",
        "district": "Soquel Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63729006309",
    },
    {
        "school": "Santa Cruz Gardens Elementary",
        "district": "Soquel Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63729006310",
    },
    {
        "school": "Soquel Elementary",
        "district": "Soquel Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63729006311",
    },
    {
        "school": "Santa Cruz County Special Education",
        "district": "Santa Cruz County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69103608020",
    },
    {
        "school": "Santa Cruz County Court",
        "district": "Santa Cruz County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103609251",
    },
    {
        "school": "Sonoma County ROP",
        "district": "Sonoma County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60012911485",
    },
    {
        "school": "Eagle Creek",
        "district": "Cloverdale Unified",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60897011806",
    },
    {
        "school": "Technology High",
        "district": "Cotati-Rohnert Park Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60994010688",
    },
    {
        "school": "Gravenstein Community Day",
        "district": "Gravenstein Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61584010684",
    },
    {
        "school": "Mark West Charter",
        "district": "Mark West Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62400011479",
    },
    {
        "school": "Mary Collins Charter School at Cherry Valley",
        "district": "Petaluma Joint Union High",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63025004716",
    },
    {
        "school": "Jack London Elementary",
        "district": "Piner-Olivet Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63045011180",
    },
    {
        "school": "Rincon Valley Charter",
        "district": "Rincon Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63264011481",
    },
    {
        "school": "Santa Rosa Accelerated Charter",
        "district": "Santa Rosa High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63583011482",
    },
    {
        "school": "Sunridge Charter",
        "district": "Twin Hills Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64023010687",
    },
    {
        "school": "Sonoma County Alternative Education Programs",
        "district": "Sonoma County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104010682",
    },
    {
        "school": "Laguna Elementary",
        "district": "Laguna Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62043002457",
    },
    {
        "school": "Lincoln Union Elementary",
        "district": "Lincoln Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62166002574",
    },
    {
        "school": "Mattie Washburn Elementary",
        "district": "Windsor Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003401797",
    },
    {
        "school": "Windsor High",
        "district": "Windsor Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003405470",
    },
    {
        "school": "Windsor Middle",
        "district": "Windsor Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003406982",
    },
    {
        "school": "Cali Calmecac Language Academy",
        "district": "Windsor Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003406983",
    },
    {
        "school": "Windsor Oaks Academy",
        "district": "Windsor Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60003408652",
    },
    {
        "school": "Brooks Elementary",
        "district": "Windsor Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003409465",
    },
    {
        "school": "Healdsburg Elementary",
        "district": "Healdsburg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004402139",
    },
    {
        "school": "Healdsburg High",
        "district": "Healdsburg Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004402140",
    },
    {
        "school": "Healdsburg Junior High",
        "district": "Healdsburg Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004402141",
    },
    {
        "school": "Marce Becerra Academy",
        "district": "Healdsburg Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004406727",
    },
    {
        "school": "Alexander Valley Elementary",
        "district": "Alexander Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60189000064",
    },
    {
        "school": "Analy High",
        "district": "West Sonoma County Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60267000193",
    },
    {
        "school": "El Molino High",
        "district": "West Sonoma County Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60267000194",
    },
    {
        "school": "Laguna High",
        "district": "West Sonoma County Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60267000195",
    },
    {
        "school": "Bellevue Elementary",
        "district": "Bellevue Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60438000393",
    },
    {
        "school": "Kawana Springs Elementary",
        "district": "Bellevue Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60438000394",
    },
    {
        "school": "Meadow View Elementary",
        "district": "Bellevue Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60438007865",
    },
    {
        "school": "Strawberry Elementary",
        "district": "Bennett Valley Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60465000429",
    },
    {
        "school": "Yulupa Elementary",
        "district": "Bennett Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60465000430",
    },
    {
        "school": "Cinnabar Charter",
        "district": "Cinnabar Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60870000884",
    },
    {
        "school": "Cloverdale High",
        "district": "Cloverdale Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60897000899",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Cloverdale Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60897000900",
    },
    {
        "school": "Johanna Echols-Hansen High (Continuation)",
        "district": "Cloverdale Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60897000901",
    },
    {
        "school": "Washington",
        "district": "Cloverdale Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60897000902",
    },
    {
        "school": "El Camino High",
        "district": "Cotati-Rohnert Park Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60994001076",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Cotati-Rohnert Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60994001077",
    },
    {
        "school": "Marguerite Hahn Elementary",
        "district": "Cotati-Rohnert Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60994001078",
    },
    {
        "school": "John Reed Primary",
        "district": "Cotati-Rohnert Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60994001079",
    },
    {
        "school": "Rancho Cotate High",
        "district": "Cotati-Rohnert Park Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60994001081",
    },
    {
        "school": "Thomas Page Academy",
        "district": "Cotati-Rohnert Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60994001083",
    },
    {
        "school": "Lawrence E. Jones Middle",
        "district": "Cotati-Rohnert Park Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60994005461",
    },
    {
        "school": "Monte Vista Elementary",
        "district": "Cotati-Rohnert Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60994009772",
    },
    {
        "school": "Dunham Elementary",
        "district": "Dunham Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61161001291",
    },
    {
        "school": "Forestville Elementary",
        "district": "Forestville Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61401001606",
    },
    {
        "school": "Fort Ross Elementary",
        "district": "Fort Ross Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61413001616",
    },
    {
        "school": "Geyserville Elementary",
        "district": "Geyserville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61515001907",
    },
    {
        "school": "Buena Vista High",
        "district": "Geyserville Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61515007726",
    },
    {
        "school": "Gravenstein Elementary",
        "district": "Gravenstein Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61584002000",
    },
    {
        "school": "Hillcrest Middle",
        "district": "Gravenstein Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61584002001",
    },
    {
        "school": "Guerneville Elementary (Charter)",
        "district": "Guerneville Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632002031",
    },
    {
        "school": "Salmon Creek School - A Charter",
        "district": "Harmony Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61662001736",
    },
    {
        "school": "Harmony Elementary",
        "district": "Harmony Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61662002091",
    },
    {
        "school": "Horicon Elementary",
        "district": "Horicon Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61758002192",
    },
    {
        "school": "Kenwood Elementary",
        "district": "Kenwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61941002330",
    },
    {
        "school": "Liberty Elementary",
        "district": "Liberty Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62154002570",
    },
    {
        "school": "John B. Riebli Elementary",
        "district": "Mark West Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62400001766",
    },
    {
        "school": "Mark West Elementary",
        "district": "Mark West Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62400003610",
    },
    {
        "school": "San Miguel Elementary",
        "district": "Mark West Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62400003611",
    },
    {
        "school": "Monte Rio Elementary",
        "district": "Monte Rio Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62541003786",
    },
    {
        "school": "Montgomery Elementary",
        "district": "Montgomery Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62565003845",
    },
    {
        "school": "Oak Grove Elementary",
        "district": "Oak Grove Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62784004225",
    },
    {
        "school": "Oak Grove Elementary/Willowside Middle",
        "district": "Oak Grove Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62784004226",
    },
    {
        "school": "La Tercera Elementary",
        "district": "Old Adobe Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62832004384",
    },
    {
        "school": "Miwok Valley Elementary Charter",
        "district": "Old Adobe Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62832004385",
    },
    {
        "school": "Old Adobe Elementary Charter",
        "district": "Old Adobe Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62832004386",
    },
    {
        "school": "Sonoma Mountain Elementary",
        "district": "Old Adobe Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62832007455",
    },
    {
        "school": "Grant Elementary",
        "district": "Petaluma City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63023004717",
    },
    {
        "school": "McDowell Elementary",
        "district": "Petaluma City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63023004719",
    },
    {
        "school": "McKinley Elementary",
        "district": "Petaluma City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63023004720",
    },
    {
        "school": "McNear Elementary",
        "district": "Petaluma City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63023004721",
    },
    {
        "school": "Penngrove Elementary",
        "district": "Petaluma City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63023004722",
    },
    {
        "school": "Valley Vista Elementary",
        "district": "Petaluma City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63023004726",
    },
    {
        "school": "Valley Oaks Elementary (Alternative)",
        "district": "Petaluma City Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63023005436",
    },
    {
        "school": "Carpe Diem High (Continuation)",
        "district": "Petaluma Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63025001786",
    },
    {
        "school": "Sonoma Mountain High (Continuation)",
        "district": "Petaluma Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63025001788",
    },
    {
        "school": "Casa Grande High",
        "district": "Petaluma Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63025004715",
    },
    {
        "school": "Kenilworth Junior High",
        "district": "Petaluma Joint Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63025004718",
    },
    {
        "school": "Petaluma High",
        "district": "Petaluma Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63025004723",
    },
    {
        "school": "Petaluma Junior High",
        "district": "Petaluma Joint Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63025004724",
    },
    {
        "school": "San Antonio High (Continuation)",
        "district": "Petaluma Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63025004725",
    },
    {
        "school": "Valley Oaks High (Alternative)",
        "district": "Petaluma Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63025005439",
    },
    {
        "school": "RISE Academy",
        "district": "Petaluma Joint Union High",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63025008645",
    },
    {
        "school": "Kashia Elementary",
        "district": "Kashia Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63234004985",
    },
    {
        "school": "Binkley Elementary Charter",
        "district": "Rincon Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63264005077",
    },
    {
        "school": "Madrone Elementary",
        "district": "Rincon Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63264005078",
    },
    {
        "school": "Spring Creek Matanzas Charter",
        "district": "Rincon Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63264005079",
    },
    {
        "school": "Whited Elementary Charter",
        "district": "Rincon Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63264005080",
    },
    {
        "school": "Sequoia Elementary",
        "district": "Rincon Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63264005081",
    },
    {
        "school": "Village Elementary Charter",
        "district": "Rincon Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63264005083",
    },
    {
        "school": "Austin Creek Elementary",
        "district": "Rincon Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63264008646",
    },
    {
        "school": "Roseland Elementary",
        "district": "Roseland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63351005176",
    },
    {
        "school": "Sheppard Elementary",
        "district": "Roseland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63351005177",
    },
    {
        "school": "Brook Hill Elementary",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581006117",
    },
    {
        "school": "Luther Burbank Elementary",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581006118",
    },
    {
        "school": "Santa Rosa French-American Charter (SRFACS)",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581006119",
    },
    {
        "school": "Helen M. Lehman Elementary",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581006120",
    },
    {
        "school": "Hidden Valley Elementary",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581006122",
    },
    {
        "school": "Abraham Lincoln Elementary",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581006125",
    },
    {
        "school": "James Monroe Elementary",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581006126",
    },
    {
        "school": "Proctor Terrace Elementary",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581006129",
    },
    {
        "school": "Steele Lane Elementary",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581006135",
    },
    {
        "school": "Albert F. Biella Elementary",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581009635",
    },
    {
        "school": "Elsie Allen High",
        "district": "Santa Rosa High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63583004108",
    },
    {
        "school": "Herbert Slater Middle",
        "district": "Santa Rosa High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63583006121",
    },
    {
        "school": "Hilliard Comstock Middle",
        "district": "Santa Rosa High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63583006123",
    },
    {
        "school": "Lawrence Cook Middle",
        "district": "Santa Rosa High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63583006124",
    },
    {
        "school": "Montgomery High",
        "district": "Santa Rosa High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63583006127",
    },
    {
        "school": "Piner High",
        "district": "Santa Rosa High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63583006128",
    },
    {
        "school": "Ridgway High (Continuation)",
        "district": "Santa Rosa High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63583006130",
    },
    {
        "school": "Rincon Valley Middle",
        "district": "Santa Rosa High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63583006131",
    },
    {
        "school": "Santa Rosa High",
        "district": "Santa Rosa High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63583006132",
    },
    {
        "school": "Santa Rosa Middle",
        "district": "Santa Rosa High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63583006133",
    },
    {
        "school": "Maria Carrillo High",
        "district": "Santa Rosa High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63583006679",
    },
    {
        "school": "Brook Haven Middle",
        "district": "Sebastopol Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63618006177",
    },
    {
        "school": "Park Side Elementary",
        "district": "Sebastopol Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63618006178",
    },
    {
        "school": "Creekside High",
        "district": "Sonoma Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63720002851",
    },
    {
        "school": "Altimira Middle",
        "district": "Sonoma Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63720006298",
    },
    {
        "school": "Dunbar Elementary",
        "district": "Sonoma Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63720006299",
    },
    {
        "school": "El Verano Elementary",
        "district": "Sonoma Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63720006300",
    },
    {
        "school": "Flowery Elementary",
        "district": "Sonoma Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63720006301",
    },
    {
        "school": "Prestwood Elementary",
        "district": "Sonoma Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63720006302",
    },
    {
        "school": "Sassarini Elementary",
        "district": "Sonoma Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63720006303",
    },
    {
        "school": "Sonoma Valley High",
        "district": "Sonoma Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63720006304",
    },
    {
        "school": "Adele Harrison Middle",
        "district": "Sonoma Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63720010436",
    },
    {
        "school": "Apple Blossom",
        "district": "Twin Hills Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64023006652",
    },
    {
        "school": "Twin Hills Charter Middle",
        "district": "Twin Hills Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64023006653",
    },
    {
        "school": "Orchard View",
        "district": "Twin Hills Union Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64023008651",
    },
    {
        "school": "Two Rock Elementary",
        "district": "Two Rock Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64026006654",
    },
    {
        "school": "Corona Creek Elementary",
        "district": "Waugh Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64179007457",
    },
    {
        "school": "Meadow Elementary",
        "district": "Waugh Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64179010332",
    },
    {
        "school": "West Side Elementary",
        "district": "West Side Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64227006921",
    },
    {
        "school": "Wilson Elementary",
        "district": "Wilmar Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64275006980",
    },
    {
        "school": "Robert L. Stevens Elementary",
        "district": "Wright Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64320004118",
    },
    {
        "school": "J. X. Wilson Elementary",
        "district": "Wright Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64320007015",
    },
    {
        "school": "Wright Charter",
        "district": "Wright Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64320007016",
    },
    {
        "school": "Sonoma County Special Education",
        "district": "Sonoma County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104007225",
    },
    {
        "school": "Sonoma County Court",
        "district": "Sonoma County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104009253",
    },
    {
        "school": "George Kelly Elementary",
        "district": "Tracy Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004711784",
    },
    {
        "school": "San Joaquin County ROCP",
        "district": "San Joaquin County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60014011424",
    },
    {
        "school": "Anthony C. Traina Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61884011411",
    },
    {
        "school": "Julia Morgan Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223010652",
    },
    {
        "school": "Clyde W. Needham Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223011322",
    },
    {
        "school": "Lois E. Borchardt Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223011356",
    },
    {
        "school": "Ansel Adams",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223011413",
    },
    {
        "school": "Millswood Middle",
        "district": "Lodi Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223011414",
    },
    {
        "school": "Christa McAuliffe Middle",
        "district": "Lodi Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223011415",
    },
    {
        "school": "Ellerth E. Larson Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223011416",
    },
    {
        "school": "Manlio Silva Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223011417",
    },
    {
        "school": "Ronald E. McNair High",
        "district": "Lodi Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223011418",
    },
    {
        "school": "George Y. Komure Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361010653",
    },
    {
        "school": "Weston Ranch High",
        "district": "Manteca Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361011321",
    },
    {
        "school": "Walter Woodward Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361011419",
    },
    {
        "school": "Veritas Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361011420",
    },
    {
        "school": "Park View Elementary",
        "district": "Ripon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63288011421",
    },
    {
        "school": "George W. Bush Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801011302",
    },
    {
        "school": "Cesar Chavez High",
        "district": "Stockton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801011422",
    },
    {
        "school": "San Joaquin County Community",
        "district": "San Joaquin County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103110650",
    },
    {
        "school": "Merrill F. West High",
        "district": "Tracy Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707371",
    },
    {
        "school": "Duncan-Russell Continuation",
        "district": "Tracy Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004707379",
    },
    {
        "school": "Tracy High",
        "district": "Tracy Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707380",
    },
    {
        "school": "Central Elementary",
        "district": "Tracy Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707383",
    },
    {
        "school": "Monte Vista Middle",
        "district": "Tracy Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707384",
    },
    {
        "school": "McKinley Elementary",
        "district": "Tracy Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707387",
    },
    {
        "school": "North Elementary",
        "district": "Tracy Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707390",
    },
    {
        "school": "South/West Park Elementary",
        "district": "Tracy Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707393",
    },
    {
        "school": "Louis J. Villalovoz Elementary",
        "district": "Tracy Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707396",
    },
    {
        "school": "Melville S. Jacobson Elementary",
        "district": "Tracy Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707397",
    },
    {
        "school": "Gladys Poet-Christian Elementary",
        "district": "Tracy Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707398",
    },
    {
        "school": "Earle E. Williams Middle",
        "district": "Tracy Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707399",
    },
    {
        "school": "Louis A. Bohn Elementary",
        "district": "Tracy Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707400",
    },
    {
        "school": "Wanda Hirsch Elementary",
        "district": "Tracy Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004707401",
    },
    {
        "school": "Willow Community Day",
        "district": "Tracy Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004708341",
    },
    {
        "school": "Art Freiler",
        "district": "Tracy Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004710394",
    },
    {
        "school": "Banta Elementary",
        "district": "Banta Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60387000354",
    },
    {
        "school": "Dent Elementary",
        "district": "Escalon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61284001446",
    },
    {
        "school": "El Portal Middle",
        "district": "Escalon Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61284001447",
    },
    {
        "school": "Escalon High",
        "district": "Escalon Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61284001448",
    },
    {
        "school": "Farmington Elementary",
        "district": "Escalon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61284001449",
    },
    {
        "school": "Van Allen Elementary",
        "district": "Escalon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61284001450",
    },
    {
        "school": "Vista High (Continuation)",
        "district": "Escalon Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61284008831",
    },
    {
        "school": "Collegeville Elementary",
        "district": "Escalon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61284009364",
    },
    {
        "school": "Monticello Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61884001330",
    },
    {
        "school": "Jefferson",
        "district": "Jefferson Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61884002277",
    },
    {
        "school": "Tom Hawkins Elementary",
        "district": "Jefferson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61884008615",
    },
    {
        "school": "Colonial Heights",
        "district": "Lincoln Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169002575",
    },
    {
        "school": "John R. Williams",
        "district": "Lincoln Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169002577",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Lincoln Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169002578",
    },
    {
        "school": "Lincoln High",
        "district": "Lincoln Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169002579",
    },
    {
        "school": "Mable Barron",
        "district": "Lincoln Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169002580",
    },
    {
        "school": "Sierra Middle",
        "district": "Lincoln Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169002581",
    },
    {
        "school": "Village Oaks High",
        "district": "Lincoln Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62169002582",
    },
    {
        "school": "Tully C. Knoles",
        "district": "Lincoln Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169002583",
    },
    {
        "school": "Brookside",
        "district": "Lincoln Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169002775",
    },
    {
        "school": "Claudia Landeen",
        "district": "Lincoln Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169008875",
    },
    {
        "school": "Don Riggio",
        "district": "Lincoln Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169008876",
    },
    {
        "school": "Glenwood Elementary",
        "district": "Linden Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62181002586",
    },
    {
        "school": "Linden Elementary",
        "district": "Linden Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62181002588",
    },
    {
        "school": "Linden High",
        "district": "Linden Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62181002589",
    },
    {
        "school": "Waterloo Elementary",
        "district": "Linden Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62181002590",
    },
    {
        "school": "Waverly Elementary",
        "district": "Linden Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62181002591",
    },
    {
        "school": "Sutherland Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223001341",
    },
    {
        "school": "Davis Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002642",
    },
    {
        "school": "Oakwood Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002643",
    },
    {
        "school": "Erma B. Reese Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002646",
    },
    {
        "school": "George Washington Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002647",
    },
    {
        "school": "Heritage Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002649",
    },
    {
        "school": "Houston",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002650",
    },
    {
        "school": "Lakewood Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002652",
    },
    {
        "school": "Lawrence Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002653",
    },
    {
        "school": "Leroy Nichols Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002654",
    },
    {
        "school": "Liberty High",
        "district": "Lodi Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62223002655",
    },
    {
        "school": "Live Oak Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002656",
    },
    {
        "school": "Lockeford Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002657",
    },
    {
        "school": "Lodi High",
        "district": "Lodi Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002658",
    },
    {
        "school": "Morada Middle",
        "district": "Lodi Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002659",
    },
    {
        "school": "Lodi Middle",
        "district": "Lodi Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002663",
    },
    {
        "school": "Tokay High",
        "district": "Lodi Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002665",
    },
    {
        "school": "Victor Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002668",
    },
    {
        "school": "Vinewood Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223002669",
    },
    {
        "school": "Plaza Robles Continuation High",
        "district": "Lodi Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62223002776",
    },
    {
        "school": "John Muir Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223003998",
    },
    {
        "school": "Elkhorn",
        "district": "Lodi Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223007743",
    },
    {
        "school": "Clairmont Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223008152",
    },
    {
        "school": "Independence",
        "district": "Lodi Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62223008320",
    },
    {
        "school": "Henderson",
        "district": "Lodi Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62223008321",
    },
    {
        "school": "Middle College High",
        "district": "Lodi Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223008616",
    },
    {
        "school": "Joe Serna Jr. Charter",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223008617",
    },
    {
        "school": "Parklane Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223008878",
    },
    {
        "school": "Creekside Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223008879",
    },
    {
        "school": "Delta Sierra Middle",
        "district": "Lodi Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223009391",
    },
    {
        "school": "Wagner-Holt Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223009895",
    },
    {
        "school": "Beckman Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223009896",
    },
    {
        "school": "Bear Creek High",
        "district": "Lodi Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223010314",
    },
    {
        "school": "Westwood Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223010315",
    },
    {
        "school": "August Knodt Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361001374",
    },
    {
        "school": "East Union High",
        "district": "Manteca Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361003577",
    },
    {
        "school": "French Camp Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361003578",
    },
    {
        "school": "Golden West Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361003579",
    },
    {
        "school": "Lathrop Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361003580",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361003581",
    },
    {
        "school": "Manteca High",
        "district": "Manteca Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361003583",
    },
    {
        "school": "New Haven Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361003584",
    },
    {
        "school": "Nile Garden Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361003585",
    },
    {
        "school": "Sequoia Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361003587",
    },
    {
        "school": "Shasta Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361003588",
    },
    {
        "school": "Sierra High",
        "district": "Manteca Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361004002",
    },
    {
        "school": "Joshua Cowell Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361004004",
    },
    {
        "school": "Manteca Community Day (7-12)",
        "district": "Manteca Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62361006561",
    },
    {
        "school": "Manteca Community Day (K-6)",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62361007364",
    },
    {
        "school": "Great Valley Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361007749",
    },
    {
        "school": "Calla High",
        "district": "Manteca Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62361007775",
    },
    {
        "school": "Neil Hafley Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361008160",
    },
    {
        "school": "George McParland Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361009398",
    },
    {
        "school": "Brock Elliott Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361009575",
    },
    {
        "school": "Stella Brockman Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361009916",
    },
    {
        "school": "Joseph Widmer Jr. Elementary",
        "district": "Manteca Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361010390",
    },
    {
        "school": "New Hope Elementary",
        "district": "New Hope Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62697004075",
    },
    {
        "school": "New Jerusalem Elementary",
        "district": "New Jerusalem Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62703004076",
    },
    {
        "school": "Delta Charter",
        "district": "New Jerusalem Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62703010391",
    },
    {
        "school": "Oak View Elementary",
        "district": "Oak View Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62793004229",
    },
    {
        "school": "Ripon Elementary",
        "district": "Ripon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63288005111",
    },
    {
        "school": "Ripon High",
        "district": "Ripon Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63288005112",
    },
    {
        "school": "Ripona Elementary",
        "district": "Ripon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63288005113",
    },
    {
        "school": "Weston Elementary",
        "district": "Ripon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63288008953",
    },
    {
        "school": "Colony Oak Elementary",
        "district": "Ripon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63288010027",
    },
    {
        "school": "Taft Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801001375",
    },
    {
        "school": "Adams Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006398",
    },
    {
        "school": "August Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006399",
    },
    {
        "school": "Cleveland Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006400",
    },
    {
        "school": "Commodore Stockton Skills",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006401",
    },
    {
        "school": "Edison High",
        "district": "Stockton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006403",
    },
    {
        "school": "El Dorado Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006404",
    },
    {
        "school": "Elmwood Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006405",
    },
    {
        "school": "Fillmore Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006406",
    },
    {
        "school": "Franklin High",
        "district": "Stockton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006407",
    },
    {
        "school": "Grunsky Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006413",
    },
    {
        "school": "Harrison Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006415",
    },
    {
        "school": "Hazelton Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006416",
    },
    {
        "school": "Kohl Open Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006417",
    },
    {
        "school": "Hoover Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006418",
    },
    {
        "school": "Kennedy Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006420",
    },
    {
        "school": "King Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006421",
    },
    {
        "school": "Madison Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006422",
    },
    {
        "school": "McKinley Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006424",
    },
    {
        "school": "Monroe Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006425",
    },
    {
        "school": "Montezuma Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006426",
    },
    {
        "school": "Nightingale Charter",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006427",
    },
    {
        "school": "Pulliam Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006429",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006431",
    },
    {
        "school": "Stagg Senior High",
        "district": "Stockton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006432",
    },
    {
        "school": "Taylor Leadership Academy",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006434",
    },
    {
        "school": "Tyler Skills Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006435",
    },
    {
        "school": "Van Buren Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006436",
    },
    {
        "school": "Victory Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801006437",
    },
    {
        "school": "Rio Calaveras Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801007754",
    },
    {
        "school": "Walton Development Center",
        "district": "Stockton Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63801007882",
    },
    {
        "school": "San Joaquin Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801008340",
    },
    {
        "school": "Weber Institute",
        "district": "Stockton Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63801008619",
    },
    {
        "school": "District Special Education",
        "district": "Stockton Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63801008991",
    },
    {
        "school": "Jane Frederick High",
        "district": "Stockton Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63801009446",
    },
    {
        "school": "George Washington Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801009447",
    },
    {
        "school": "Wilson Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801010316",
    },
    {
        "school": "Dolores Huerta Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801010392",
    },
    {
        "school": "San Joaquin County Special Education",
        "district": "San Joaquin County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69103107179",
    },
    {
        "school": "John F. Cruikshank Jr.",
        "district": "San Joaquin County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103107355",
    },
    {
        "school": "Alder Creek Middle",
        "district": "Tahoe-Truckee Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63877011005",
    },
    {
        "school": "Chicago Park Elementary",
        "district": "Chicago Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60834000811",
    },
    {
        "school": "Clear Creek Elementary",
        "district": "Clear Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60888000898",
    },
    {
        "school": "Lyman Gilmore Middle",
        "district": "Grass Valley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61578001997",
    },
    {
        "school": "Grass Valley Charter",
        "district": "Grass Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61578002267",
    },
    {
        "school": "Margaret G. Scotten Elementary",
        "district": "Grass Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61578008851",
    },
    {
        "school": "Deer Creek Elementary",
        "district": "Nevada City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62682004060",
    },
    {
        "school": "Seven Hills Intermediate",
        "district": "Nevada City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62682004062",
    },
    {
        "school": "Nevada Union High",
        "district": "Nevada Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62688004064",
    },
    {
        "school": "North Point Academy",
        "district": "Nevada Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62688007794",
    },
    {
        "school": "Bear River High",
        "district": "Nevada Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62688008918",
    },
    {
        "school": "Silver Springs High (Continuation)",
        "district": "Nevada Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62688009953",
    },
    {
        "school": "NU Tech High",
        "district": "Nevada Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62688010261",
    },
    {
        "school": "Magnolia Intermediate",
        "district": "Pleasant Ridge Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63093004792",
    },
    {
        "school": "Cottage Hill Elementary",
        "district": "Pleasant Ridge Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63093007330",
    },
    {
        "school": "Alta Sierra Elementary",
        "district": "Pleasant Ridge Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63093008942",
    },
    {
        "school": "Union Hill Elementary",
        "district": "Union Hill Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64038006681",
    },
    {
        "school": "Washington Elementary",
        "district": "Twin Ridges Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001206852",
    },
    {
        "school": "Grizzly Hill",
        "district": "Twin Ridges Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001209206",
    },
    {
        "school": "Glenshire Elementary",
        "district": "Tahoe-Truckee Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63877004954",
    },
    {
        "school": "Cold Stream Alternative",
        "district": "Tahoe-Truckee Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63877006175",
    },
    {
        "school": "Donner Trail Elementary",
        "district": "Tahoe-Truckee Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63877006512",
    },
    {
        "school": "Sierra High (Continuation)",
        "district": "Tahoe-Truckee Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63877006517",
    },
    {
        "school": "Tahoe Truckee High",
        "district": "Tahoe-Truckee Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63877006520",
    },
    {
        "school": "Truckee Elementary",
        "district": "Tahoe-Truckee Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63877006521",
    },
    {
        "school": "Nevada County Special Education",
        "district": "Nevada County Office of Education",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69102307155",
    },
    {
        "school": "Kings Beach Elementary",
        "district": "Tahoe-Truckee Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63877006513",
    },
    {
        "school": "North Tahoe High",
        "district": "Tahoe-Truckee Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63877006514",
    },
    {
        "school": "North Tahoe",
        "district": "Tahoe-Truckee Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63877006515",
    },
    {
        "school": "Tahoe Lake Elementary",
        "district": "Tahoe-Truckee Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63877006519",
    },
    {
        "school": "Mendocino County ROP",
        "district": "Mendocino County ROC/ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60011810959",
    },
    {
        "school": "Potter Valley Junior High",
        "district": "Potter Valley Community Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63140010958",
    },
    {
        "school": "Grace Hudson Elementary",
        "district": "Ukiah Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64030010957",
    },
    {
        "school": "Mendocino County Community",
        "district": "Mendocino County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101910551",
    },
    {
        "school": "Orr Creek",
        "district": "Mendocino County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101911685",
    },
    {
        "school": "Anderson Valley Elementary",
        "district": "Anderson Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60273000198",
    },
    {
        "school": "Anderson Valley Junior-Senior High",
        "district": "Anderson Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60273000199",
    },
    {
        "school": "Rancheria Continuation",
        "district": "Anderson Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60273000200",
    },
    {
        "school": "Arena Elementary",
        "district": "Arena Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60309000242",
    },
    {
        "school": "Whale Gulch Elementary",
        "district": "Leggett Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60966500669",
    },
    {
        "school": "Leggett Valley High",
        "district": "Leggett Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60966509665",
    },
    {
        "school": "Leggett Valley Elementary",
        "district": "Leggett Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60966509671",
    },
    {
        "school": "Whale Gulch High",
        "district": "Leggett Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60966510258",
    },
    {
        "school": "Noyo High (Continuation)",
        "district": "Fort Bragg Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61407000660",
    },
    {
        "school": "Dana Gray Elementary",
        "district": "Fort Bragg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61407001608",
    },
    {
        "school": "Fort Bragg Middle",
        "district": "Fort Bragg Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61407001609",
    },
    {
        "school": "Fort Bragg High",
        "district": "Fort Bragg Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61407001610",
    },
    {
        "school": "Redwood Elementary",
        "district": "Fort Bragg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61407001614",
    },
    {
        "school": "Lighthouse Community Day",
        "district": "Fort Bragg Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61407008163",
    },
    {
        "school": "Shelter Cove",
        "district": "Fort Bragg Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61407008734",
    },
    {
        "school": "Manchester Elementary",
        "district": "Manchester Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62355003569",
    },
    {
        "school": "Comptche Elementary",
        "district": "Mendocino Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62448003656",
    },
    {
        "school": "Mendocino Sunrise High",
        "district": "Mendocino Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62448003658",
    },
    {
        "school": "Mendocino K-8",
        "district": "Mendocino Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62448003659",
    },
    {
        "school": "Mendocino High",
        "district": "Mendocino Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62448003660",
    },
    {
        "school": "Mendocino Alternative",
        "district": "Mendocino Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62448004624",
    },
    {
        "school": "Albion Elementary",
        "district": "Mendocino Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62448008196",
    },
    {
        "school": "Point Arena High",
        "district": "Point Arena Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63123004831",
    },
    {
        "school": "South Coast Continuation",
        "district": "Point Arena Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63123007331",
    },
    {
        "school": "Potter Valley Elementary",
        "district": "Potter Valley Community Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63140004867",
    },
    {
        "school": "Potter Valley High",
        "district": "Potter Valley Community Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63140004868",
    },
    {
        "school": "Centerville High (Continuation)",
        "district": "Potter Valley Community Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63140007333",
    },
    {
        "school": "Round Valley Elementary",
        "district": "Round Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63372005194",
    },
    {
        "school": "Round Valley High",
        "district": "Round Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63372005195",
    },
    {
        "school": "Round Valley Continuation",
        "district": "Round Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63372010257",
    },
    {
        "school": "Calpella Elementary",
        "district": "Ukiah Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64030006655",
    },
    {
        "school": "Frank Zeek Elementary",
        "district": "Ukiah Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64030006656",
    },
    {
        "school": "Nokomis Elementary",
        "district": "Ukiah Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64030006658",
    },
    {
        "school": "Oak Manor Elementary",
        "district": "Ukiah Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64030006659",
    },
    {
        "school": "Pomolita Middle",
        "district": "Ukiah Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64030006660",
    },
    {
        "school": "South Valley High (Continuation)",
        "district": "Ukiah Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64030006663",
    },
    {
        "school": "Ukiah High",
        "district": "Ukiah Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64030006665",
    },
    {
        "school": "Yokayo Elementary",
        "district": "Ukiah Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64030006666",
    },
    {
        "school": "Eagle Peak Middle",
        "district": "Ukiah Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64030007172",
    },
    {
        "school": "Baechtel Grove Middle",
        "district": "Willits Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64256006966",
    },
    {
        "school": "Brookside Elementary",
        "district": "Willits Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64256006967",
    },
    {
        "school": "Willits High",
        "district": "Willits Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64256006972",
    },
    {
        "school": "Sherwood",
        "district": "Willits Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64256008208",
    },
    {
        "school": "Blosser Lane Elementary",
        "district": "Willits Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64256009658",
    },
    {
        "school": "Laytonville Continuation High",
        "district": "Laytonville Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64258000666",
    },
    {
        "school": "Laytonville Elementary",
        "district": "Laytonville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64258007899",
    },
    {
        "school": "Laytonville High",
        "district": "Laytonville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64258007900",
    },
    {
        "school": "Spy Rock Elementary",
        "district": "Laytonville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64258009464",
    },
    {
        "school": "West Hills Juvenile Hall Court",
        "district": "Mendocino County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101909023",
    },
    {
        "school": "River Delta Community Day",
        "district": "River Delta Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63311011075",
    },
    {
        "school": "Gretchen Higgins Elementary",
        "district": "Dixon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61128010679",
    },
    {
        "school": "Dixon Community Day",
        "district": "Dixon Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61128011236",
    },
    {
        "school": "Farragut Academy",
        "district": "Vallejo City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64074011224",
    },
    {
        "school": "Solano County Community",
        "district": "Solano County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69112210678",
    },
    {
        "school": "Mokelumne High (Continuation)",
        "district": "River Delta Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63311002535",
    },
    {
        "school": "Bates Elementary",
        "district": "River Delta Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63311005121",
    },
    {
        "school": "Isleton Elementary",
        "district": "River Delta Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63311005124",
    },
    {
        "school": "Walnut Grove Elementary",
        "district": "River Delta Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63311005127",
    },
    {
        "school": "Rio Vista High",
        "district": "River Delta Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63311005125",
    },
    {
        "school": "Riverview Middle",
        "district": "River Delta Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63311005126",
    },
    {
        "school": "D. H. White Elementary",
        "district": "River Delta Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63311005128",
    },
    {
        "school": "River Delta High/Elementary (Alternative)",
        "district": "River Delta Joint Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63311009429",
    },
    {
        "school": "Delta High",
        "district": "River Delta Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63311005123",
    },
    {
        "school": "Benicia High",
        "district": "Benicia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60462000422",
    },
    {
        "school": "Benicia Middle",
        "district": "Benicia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60462000423",
    },
    {
        "school": "Mary Farmar Elementary",
        "district": "Benicia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60462000424",
    },
    {
        "school": "Liberty High",
        "district": "Benicia Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60462000425",
    },
    {
        "school": "Robert Semple Elementary",
        "district": "Benicia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60462000427",
    },
    {
        "school": "Matthew Turner Elementary",
        "district": "Benicia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60462002832",
    },
    {
        "school": "Joe Henderson Elementary",
        "district": "Benicia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60462009116",
    },
    {
        "school": "C. A. Jacobs Intermediate",
        "district": "Dixon Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61128001250",
    },
    {
        "school": "Dixon High",
        "district": "Dixon Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61128001251",
    },
    {
        "school": "Maine Prairie High (Continuation)",
        "district": "Dixon Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61128001253",
    },
    {
        "school": "Anderson (Linford L.) Elementary",
        "district": "Dixon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61128001254",
    },
    {
        "school": "Tremont Elementary",
        "district": "Dixon Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61128010328",
    },
    {
        "school": "Armijo High",
        "district": "Fairfield-Suisun Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001510",
    },
    {
        "school": "Crescent Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001514",
    },
    {
        "school": "Fairfield High",
        "district": "Fairfield-Suisun Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001516",
    },
    {
        "school": "Fairview Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001518",
    },
    {
        "school": "Cleo Gordon Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001520",
    },
    {
        "school": "Grange Middle",
        "district": "Fairfield-Suisun Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001521",
    },
    {
        "school": "Green Valley Middle",
        "district": "Fairfield-Suisun Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001522",
    },
    {
        "school": "K. I. Jones Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001523",
    },
    {
        "school": "Anna Kyle Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001524",
    },
    {
        "school": "Sem Yeto Continuation High",
        "district": "Fairfield-Suisun Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61336001526",
    },
    {
        "school": "E. Ruth Sheldon Academy of Innovative Learning",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001527",
    },
    {
        "school": "Suisun Valley Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001528",
    },
    {
        "school": "Tolenas Academy of Music and Media",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336001530",
    },
    {
        "school": "Laurel Creek Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336002835",
    },
    {
        "school": "Crystal Middle",
        "district": "Fairfield-Suisun Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336007282",
    },
    {
        "school": "Suisun Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336007283",
    },
    {
        "school": "Nelda Mundy Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336007857",
    },
    {
        "school": "Oakbrook Academy of the Arts",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336008837",
    },
    {
        "school": "Dan O. Root Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336009814",
    },
    {
        "school": "B. Gale Wilson Elementary",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336009815",
    },
    {
        "school": "Angelo Rodriguez High",
        "district": "Fairfield-Suisun Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336010429",
    },
    {
        "school": "Foxboro Elementary",
        "district": "Travis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63963002845",
    },
    {
        "school": "Travis Elementary",
        "district": "Travis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63963005418",
    },
    {
        "school": "Center Elementary",
        "district": "Travis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63963006595",
    },
    {
        "school": "Golden West Middle",
        "district": "Travis Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63963006596",
    },
    {
        "school": "Travis Education Center",
        "district": "Travis Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63963006597",
    },
    {
        "school": "Scandia Elementary",
        "district": "Travis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63963006598",
    },
    {
        "school": "Vanden High",
        "district": "Travis Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63963006600",
    },
    {
        "school": "Travis Community Day",
        "district": "Travis Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63963008641",
    },
    {
        "school": "Travis Independent Study",
        "district": "Travis Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63963008642",
    },
    {
        "school": "Cambridge Elementary",
        "district": "Travis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63963008998",
    },
    {
        "school": "Elise P. Buckingham Charter Magnet High",
        "district": "Vacaville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059002846",
    },
    {
        "school": "Alamo Elementary",
        "district": "Vacaville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059006697",
    },
    {
        "school": "Country High",
        "district": "Vacaville Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64059006698",
    },
    {
        "school": "Fairmont Charter Elementary",
        "district": "Vacaville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059006701",
    },
    {
        "school": "Hemlock Elementary",
        "district": "Vacaville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059006702",
    },
    {
        "school": "Willis Jepson Middle",
        "district": "Vacaville Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059006703",
    },
    {
        "school": "Edwin Markham Elementary",
        "district": "Vacaville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059006704",
    },
    {
        "school": "Orchard Elementary",
        "district": "Vacaville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059006705",
    },
    {
        "school": "Eugene Padan Elementary",
        "district": "Vacaville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059006706",
    },
    {
        "school": "Vacaville High",
        "district": "Vacaville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059006709",
    },
    {
        "school": "Vaca Pena Middle",
        "district": "Vacaville Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059009002",
    },
    {
        "school": "Will C. Wood High",
        "district": "Vacaville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059009648",
    },
    {
        "school": "Jean Callison Elementary",
        "district": "Vacaville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059010123",
    },
    {
        "school": "Browns Valley Elementary",
        "district": "Vacaville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059010329",
    },
    {
        "school": "Cooper Elementary",
        "district": "Vacaville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059010330",
    },
    {
        "school": "Annie Pennycook Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006718",
    },
    {
        "school": "Beverly Hills Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006719",
    },
    {
        "school": "Johnston Cooper Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006720",
    },
    {
        "school": "Dan Mini Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006721",
    },
    {
        "school": "Cave Language Academy",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006722",
    },
    {
        "school": "Elsa Widenmann Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006723",
    },
    {
        "school": "Mare Island Health and Fitness Academy",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006724",
    },
    {
        "school": "Federal Terrace Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006725",
    },
    {
        "school": "Franklin Middle",
        "district": "Vallejo City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006726",
    },
    {
        "school": "Highland Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006728",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006731",
    },
    {
        "school": "Loma Vista Environmental Science Academy",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006732",
    },
    {
        "school": "John Finney High (Continuation)",
        "district": "Vallejo City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64074006734",
    },
    {
        "school": "Solano Middle",
        "district": "Vallejo City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006735",
    },
    {
        "school": "Hogan Middle",
        "district": "Vallejo City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006736",
    },
    {
        "school": "Steffan Manor Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006737",
    },
    {
        "school": "Vallejo High",
        "district": "Vallejo City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074006739",
    },
    {
        "school": "Grace Patterson Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074007368",
    },
    {
        "school": "Jesse M. Bethel High",
        "district": "Vallejo City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074007861",
    },
    {
        "school": "Vallejo Adult Transition",
        "district": "Vallejo City Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "64074007889",
    },
    {
        "school": "Glen Cove Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074009455",
    },
    {
        "school": "Joseph H. Wardlaw Elementary",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074010331",
    },
    {
        "school": "Solano County Special Education",
        "district": "Solano County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69112206289",
    },
    {
        "school": "Solano Co Juve Detention Facility - Evergreen Acad",
        "district": "Solano County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69112209271",
    },
    {
        "school": "Freedom Elementary",
        "district": "Farmersville Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003511532",
    },
    {
        "school": "Santa Fe Elementary",
        "district": "Porterville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006411533",
    },
    {
        "school": "Strathmore High",
        "district": "Porterville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006411535",
    },
    {
        "school": "Ronald Reagan Academy",
        "district": "Dinuba Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006511370",
    },
    {
        "school": "John F. Kennedy Elementary",
        "district": "Dinuba Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006511536",
    },
    {
        "school": "Jim Maples Academy",
        "district": "Burton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60657010701",
    },
    {
        "school": "Summit Charter Academy",
        "district": "Burton Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60657011526",
    },
    {
        "school": "Earlimart Community Day",
        "district": "Earlimart Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61176011367",
    },
    {
        "school": "Richgrove Elementary",
        "district": "Richgrove Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63243011376",
    },
    {
        "school": "Strathmore Community Day",
        "district": "Strathmore Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63813010702",
    },
    {
        "school": "Los Tules Middle",
        "district": "Tulare City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987011371",
    },
    {
        "school": "Countryside Community Day",
        "district": "Tulare Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63993011528",
    },
    {
        "school": "El Diamante High",
        "district": "Visalia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116010703",
    },
    {
        "school": "Oak Grove Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116011529",
    },
    {
        "school": "Four Creeks Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116011530",
    },
    {
        "school": "Visalia Charter Independent Study",
        "district": "Visalia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116011823",
    },
    {
        "school": "Tulare County Community",
        "district": "Tulare County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104510700",
    },
    {
        "school": "Farmersville Junior High",
        "district": "Farmersville Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003501547",
    },
    {
        "school": "J. E. Hester Elementary",
        "district": "Farmersville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003501548",
    },
    {
        "school": "George L. Snowden Elementary",
        "district": "Farmersville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003501549",
    },
    {
        "school": "Farmersville High",
        "district": "Farmersville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003507903",
    },
    {
        "school": "Deep Creek Academy",
        "district": "Farmersville Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60003508425",
    },
    {
        "school": "Bartlett Middle",
        "district": "Porterville Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006404869",
    },
    {
        "school": "Belleview Elementary",
        "district": "Porterville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006404870",
    },
    {
        "school": "John J. Doyle Elementary",
        "district": "Porterville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006404871",
    },
    {
        "school": "Olive Street Elementary",
        "district": "Porterville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006404872",
    },
    {
        "school": "Pioneer Middle",
        "district": "Porterville Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006404873",
    },
    {
        "school": "Roche Elementary",
        "district": "Porterville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006404874",
    },
    {
        "school": "Vandalia Elementary",
        "district": "Porterville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006404875",
    },
    {
        "school": "West Putnam Elementary",
        "district": "Porterville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006404876",
    },
    {
        "school": "Westfield Elementary",
        "district": "Porterville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006404877",
    },
    {
        "school": "Citrus High",
        "district": "Porterville Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006404878",
    },
    {
        "school": "Monache High",
        "district": "Porterville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006404879",
    },
    {
        "school": "Porterville High",
        "district": "Porterville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006404880",
    },
    {
        "school": "Monte Vista Elementary",
        "district": "Porterville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006407467",
    },
    {
        "school": "Vine Street Community Day",
        "district": "Porterville Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006407905",
    },
    {
        "school": "Granite Hills High",
        "district": "Porterville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006408426",
    },
    {
        "school": "Los Robles Elementary",
        "district": "Porterville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006409424",
    },
    {
        "school": "Grand View Elementary",
        "district": "Dinuba Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006501237",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Dinuba Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006501238",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Dinuba Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006501239",
    },
    {
        "school": "Washington Intermediate",
        "district": "Dinuba Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006501240",
    },
    {
        "school": "Wilson Elementary",
        "district": "Dinuba Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006501241",
    },
    {
        "school": "Dinuba High",
        "district": "Dinuba Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006501242",
    },
    {
        "school": "Sierra Vista High (Continuation)",
        "district": "Dinuba Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006501243",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Dinuba Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006509359",
    },
    {
        "school": "Allensworth Elementary",
        "district": "Allensworth Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60198000086",
    },
    {
        "school": "Alpaugh Elementary",
        "district": "Alpaugh Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60201000087",
    },
    {
        "school": "Alpaugh -Senior High",
        "district": "Alpaugh Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60201000088",
    },
    {
        "school": "Tule Continuation High",
        "district": "Alpaugh Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60201001837",
    },
    {
        "school": "Alta Vista Elementary",
        "district": "Alta Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60222000098",
    },
    {
        "school": "Buena Vista Elementary",
        "district": "Buena Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60642000562",
    },
    {
        "school": "Burton Elementary",
        "district": "Burton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60657000589",
    },
    {
        "school": "William R. Buckley Elementary",
        "district": "Burton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60657007898",
    },
    {
        "school": "Burton Middle",
        "district": "Burton Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60657008800",
    },
    {
        "school": "Oak Grove Elementary",
        "district": "Burton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60657008801",
    },
    {
        "school": "Columbine Elementary",
        "district": "Columbine Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60951000965",
    },
    {
        "school": "Cutler Elementary",
        "district": "Cutler-Orosi Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61035001156",
    },
    {
        "school": "Lovell High",
        "district": "Cutler-Orosi Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61035001158",
    },
    {
        "school": "Orosi High",
        "district": "Cutler-Orosi Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61035001159",
    },
    {
        "school": "Palm Elementary",
        "district": "Cutler-Orosi Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61035001160",
    },
    {
        "school": "Golden Valley Elementary",
        "district": "Cutler-Orosi Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61035005511",
    },
    {
        "school": "Cutler-Orosi Community Day",
        "district": "Cutler-Orosi Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61035008419",
    },
    {
        "school": "El Monte Middle",
        "district": "Cutler-Orosi Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61035008661",
    },
    {
        "school": "Esperanza High",
        "district": "Cutler-Orosi Joint Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61035009776",
    },
    {
        "school": "Ducor Union Elementary",
        "district": "Ducor Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61155001290",
    },
    {
        "school": "Earlimart Elementary",
        "district": "Earlimart Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61176001297",
    },
    {
        "school": "Earlimart Middle",
        "district": "Earlimart Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61176001298",
    },
    {
        "school": "Alila",
        "district": "Earlimart Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61176010446",
    },
    {
        "school": "Hope Elementary",
        "district": "Hope Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61752002191",
    },
    {
        "school": "Hot Springs Elementary",
        "district": "Hot Springs Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61764002194",
    },
    {
        "school": "Kings River Elementary",
        "district": "Kings River Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61974002378",
    },
    {
        "school": "Liberty Elementary",
        "district": "Liberty Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62157002571",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Lindsay Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62187002594",
    },
    {
        "school": "Lindsay Senior High",
        "district": "Lindsay Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62187002595",
    },
    {
        "school": "Washington Elementary",
        "district": "Lindsay Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62187002596",
    },
    {
        "school": "John J. Cairns Continuation",
        "district": "Lindsay Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62187005524",
    },
    {
        "school": "Lindsay Community Day",
        "district": "Lindsay Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62187008420",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Lindsay Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62187009389",
    },
    {
        "school": "Monson-Sultana Elementary",
        "district": "Monson-Sultana Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62535003784",
    },
    {
        "school": "Oak Valley Elementary",
        "district": "Oak Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62790004228",
    },
    {
        "school": "Outside Creek Elementary",
        "district": "Outside Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62916004498",
    },
    {
        "school": "Palo Verde Elementary",
        "district": "Palo Verde Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62967004605",
    },
    {
        "school": "Pixley Elementary",
        "district": "Pixley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63063004754",
    },
    {
        "school": "Pleasant View Elementary",
        "district": "Pleasant View Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63105004809",
    },
    {
        "school": "Rockford Elementary",
        "district": "Rockford Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63327005168",
    },
    {
        "school": "Saucelito Elementary",
        "district": "Saucelito Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63594006152",
    },
    {
        "school": "Sequoia Elementary Charter",
        "district": "Sequoia Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63636006193",
    },
    {
        "school": "Springville Elementary",
        "district": "Springville Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63777006383",
    },
    {
        "school": "Stone Corral Elementary",
        "district": "Stone Corral Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63804006439",
    },
    {
        "school": "Sundale Elementary",
        "district": "Sundale Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63834006453",
    },
    {
        "school": "Sunnyside Elementary",
        "district": "Sunnyside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63843006455",
    },
    {
        "school": "Carl Smith Middle",
        "district": "Terra Bella Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63906004200",
    },
    {
        "school": "Terra Bella Elementary",
        "district": "Terra Bella Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63906006543",
    },
    {
        "school": "Three Rivers Elementary",
        "district": "Three Rivers Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63921006547",
    },
    {
        "school": "Tipton Elementary",
        "district": "Tipton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63930006548",
    },
    {
        "school": "Traver Elementary",
        "district": "Traver Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63960006594",
    },
    {
        "school": "Cherry Avenue Middle",
        "district": "Tulare City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987006611",
    },
    {
        "school": "Garden Elementary",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987006612",
    },
    {
        "school": "Frank Kohn Elementary",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987006613",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987006614",
    },
    {
        "school": "Maple Elementary",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987006615",
    },
    {
        "school": "Mulcahy Middle",
        "district": "Tulare City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987006616",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987006617",
    },
    {
        "school": "Wilson Elementary",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987006618",
    },
    {
        "school": "Heritage Elementary",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987007469",
    },
    {
        "school": "Tulare City Community Day",
        "district": "Tulare City",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63987008422",
    },
    {
        "school": "Cypress Elementary",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987008999",
    },
    {
        "school": "Pleasant Elementary",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987009201",
    },
    {
        "school": "Live Oak Middle",
        "district": "Tulare City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987009647",
    },
    {
        "school": "Tulare Technical Preparatory High",
        "district": "Tulare Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63993002852",
    },
    {
        "school": "Sierra Vista Charter High",
        "district": "Tulare Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63993004203",
    },
    {
        "school": "Tulare Union High",
        "district": "Tulare Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63993006619",
    },
    {
        "school": "Tulare Western High",
        "district": "Tulare Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63993006620",
    },
    {
        "school": "Hurley Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116001847",
    },
    {
        "school": "La Joya Middle",
        "district": "Visalia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116004211",
    },
    {
        "school": "Conyer Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006785",
    },
    {
        "school": "Crestwood Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006786",
    },
    {
        "school": "Crowley Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006787",
    },
    {
        "school": "Divisadero Middle",
        "district": "Visalia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006788",
    },
    {
        "school": "Elbow Creek Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006789",
    },
    {
        "school": "Riverway Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006791",
    },
    {
        "school": "Golden West High",
        "district": "Visalia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006792",
    },
    {
        "school": "Goshen Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006793",
    },
    {
        "school": "Green Acres Middle",
        "district": "Visalia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006794",
    },
    {
        "school": "Highland Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006795",
    },
    {
        "school": "Houston Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006796",
    },
    {
        "school": "Ivanhoe Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006797",
    },
    {
        "school": "Linwood Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006798",
    },
    {
        "school": "Mineral King Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006799",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006800",
    },
    {
        "school": "Mt. Whitney High",
        "district": "Visalia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006801",
    },
    {
        "school": "Redwood High",
        "district": "Visalia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006803",
    },
    {
        "school": "Royal Oaks Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006805",
    },
    {
        "school": "Sequoia High",
        "district": "Visalia Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64116006806",
    },
    {
        "school": "Annie R. Mitchell",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006807",
    },
    {
        "school": "Valley Oak Middle",
        "district": "Visalia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006808",
    },
    {
        "school": "Veva Blunt Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006809",
    },
    {
        "school": "Washington Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006810",
    },
    {
        "school": "Willow Glen Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116006811",
    },
    {
        "school": "River Bend",
        "district": "Visalia Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "64116007892",
    },
    {
        "school": "Charter Home School Academy",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116008424",
    },
    {
        "school": "Golden Oak Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116009007",
    },
    {
        "school": "Pinkham Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116009457",
    },
    {
        "school": "Waukena Joint Union Elementary",
        "district": "Waukena Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64182006870",
    },
    {
        "school": "Woodville Elementary",
        "district": "Woodville Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64317007014",
    },
    {
        "school": "La Sierra High",
        "district": "Tulare County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69104508660",
    },
    {
        "school": "Tulare County Court",
        "district": "Tulare County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104509053",
    },
    {
        "school": "Special Education",
        "district": "Tulare County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104509257",
    },
    {
        "school": "Tri-County ROP",
        "district": "Tri-County ROP",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60014511522",
    },
    {
        "school": "Robbins Elementary",
        "district": "Winship-Robbins",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64290011818",
    },
    {
        "school": "Andros Karperos",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347011377",
    },
    {
        "school": "River Valley High",
        "district": "Yuba City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347011520",
    },
    {
        "school": "Rio Del Oro Elementary",
        "district": "Plumas Lake Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63118011547",
    },
    {
        "school": "Wheatland Charter Academy",
        "district": "Wheatland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64233011548",
    },
    {
        "school": "Brittan Elementary",
        "district": "Brittan Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60609000544",
    },
    {
        "school": "Browns Elementary",
        "district": "Browns Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60610000545",
    },
    {
        "school": "East Nicolaus High",
        "district": "East Nicolaus Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61178001299",
    },
    {
        "school": "Franklin Elementary",
        "district": "Franklin Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61434001642",
    },
    {
        "school": "Encinal Elementary",
        "district": "Live Oak Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62205002613",
    },
    {
        "school": "Live Oak Middle",
        "district": "Live Oak Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62205002614",
    },
    {
        "school": "Live Oak High",
        "district": "Live Oak Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62205002615",
    },
    {
        "school": "Luther Elementary",
        "district": "Live Oak Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62205002616",
    },
    {
        "school": "Valley Oak Continuation High",
        "district": "Live Oak Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62205009390",
    },
    {
        "school": "Live Oak Alternative",
        "district": "Live Oak Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62205009891",
    },
    {
        "school": "Marcum-Illinois Union Elementary",
        "district": "Marcum-Illinois Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62380003595",
    },
    {
        "school": "Meridian Elementary",
        "district": "Meridian Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62469003704",
    },
    {
        "school": "Nuestro Elementary",
        "district": "Nuestro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62775004201",
    },
    {
        "school": "Pleasant Grove",
        "district": "Pleasant Grove Joint Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63090004791",
    },
    {
        "school": "Sutter High",
        "district": "Sutter Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63861006473",
    },
    {
        "school": "Butte View High",
        "district": "Sutter Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63861009449",
    },
    {
        "school": "Butte Vista Elementary",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347004175",
    },
    {
        "school": "Albert Powell Continuation",
        "district": "Yuba City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64347007028",
    },
    {
        "school": "April Lane Elementary",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347007029",
    },
    {
        "school": "Barry Elementary",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347007030",
    },
    {
        "school": "Bridge Street Elementary",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347007031",
    },
    {
        "school": "Central Gaither Elementary",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347007032",
    },
    {
        "school": "Gray Avenue Middle",
        "district": "Yuba City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347007033",
    },
    {
        "school": "King Avenue Elementary",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347007034",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347007035",
    },
    {
        "school": "Lincrest Elementary",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347007036",
    },
    {
        "school": "Park Avenue Elementary",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347007037",
    },
    {
        "school": "Tierra Buena Elementary",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347007039",
    },
    {
        "school": "Yuba City High",
        "district": "Yuba City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347007041",
    },
    {
        "school": "Yuba City Independence Academy",
        "district": "Yuba City Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64347010154",
    },
    {
        "school": "Sutter County Special Education",
        "district": "Sutter County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104207231",
    },
    {
        "school": "Camptonville Elementary",
        "district": "Camptonville Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60726000678",
    },
    {
        "school": "South Lindhurst Continuation High",
        "district": "Marysville Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62409002879",
    },
    {
        "school": "Anna McKenney Intermediate",
        "district": "Marysville Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003620",
    },
    {
        "school": "Arboga Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003621",
    },
    {
        "school": "Browns Valley Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003622",
    },
    {
        "school": "Cedar Lane Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003623",
    },
    {
        "school": "Cordua Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003624",
    },
    {
        "school": "Dobbins Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003625",
    },
    {
        "school": "Ella Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003626",
    },
    {
        "school": "Foothill Intermediate",
        "district": "Marysville Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003627",
    },
    {
        "school": "Johnson Park Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003628",
    },
    {
        "school": "Linda Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003629",
    },
    {
        "school": "Lindhurst High",
        "district": "Marysville Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003630",
    },
    {
        "school": "Loma Rica Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003631",
    },
    {
        "school": "Covillaud Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003632",
    },
    {
        "school": "Marysville High",
        "district": "Marysville Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003633",
    },
    {
        "school": "Olivehurst Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003634",
    },
    {
        "school": "Kynoch Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003637",
    },
    {
        "school": "Yuba Feather Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003638",
    },
    {
        "school": "Yuba Gardens Intermediate",
        "district": "Marysville Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409003639",
    },
    {
        "school": "Marysville Charter Academy for the Arts",
        "district": "Marysville Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409008671",
    },
    {
        "school": "Bear River",
        "district": "Wheatland",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64233006925",
    },
    {
        "school": "Lone Tree Elementary",
        "district": "Wheatland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64233006927",
    },
    {
        "school": "Wheatland Elementary",
        "district": "Wheatland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64233006928",
    },
    {
        "school": "Wheatland Union High",
        "district": "Wheatland Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64235006930",
    },
    {
        "school": "Yuba County Career Preparatory Charter",
        "district": "Yuba County Office of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69104805572",
    },
    {
        "school": "Harry P B Carden",
        "district": "Yuba County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104809261",
    },
    {
        "school": "Yuba County Special Education",
        "district": "Yuba County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104809262",
    },
    {
        "school": "THE PINNACLE CHARTER SCHOOL",
        "district": "State Charter School Institute",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002001915",
    },
    {
        "school": "PRAIRIE VIEW HIGH SCHOOL",
        "district": "School District 27J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258002003",
    },
    {
        "school": "ADVENTURE ELEMENTARY",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555001932",
    },
    {
        "school": "WELBY COMMUNITY SCHOOL",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555001997",
    },
    {
        "school": "ACHIEVE ACADEMY",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555002004",
    },
    {
        "school": "EXPLORE ELEMENTARY",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555002007",
    },
    {
        "school": "CLAYTON PARTNERSHIP SCHOOL",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555002016",
    },
    {
        "school": "YORK INTERNATIONAL",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555002017",
    },
    {
        "school": "MONTEREY COMMUNITY SCHOOL",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555002021",
    },
    {
        "school": "MEADOW COMMUNITY SCHOOL",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555002031",
    },
    {
        "school": "MOUNTAIN RANGE HIGH SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001996",
    },
    {
        "school": "SILVER CREEK ELEMENTARY",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690002028",
    },
    {
        "school": "HIGH POINT ACADEMY",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002002033",
    },
    {
        "school": "LOTUS SCHOOL FOR EXCELLENCE",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001916",
    },
    {
        "school": "PEORIA ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001927",
    },
    {
        "school": "AURORA FRONTIER K-8",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234002009",
    },
    {
        "school": "COYOTE HILLS ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291002032",
    },
    {
        "school": "JUSTICE HIGH CHARTER SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80249002013",
    },
    {
        "school": "GEORGETOWN COMMUNITY SCHOOL",
        "district": "Clear Creek School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80300001999",
    },
    {
        "school": "DELTA ACADEMY OF APPLIED LEARNING",
        "district": "Delta County Joint District No. 50",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80333002001",
    },
    {
        "school": "VISION CHARTER ACADEMY",
        "district": "Delta County Joint District No. 50",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80333002024",
    },
    {
        "school": "DENVER CENTER FOR INTERNATIONAL STUDIES",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001917",
    },
    {
        "school": "FARRELL B. HOWELL ECE-8 SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001928",
    },
    {
        "school": "FLORIDA PITT-WALLER ECE-8 SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001933",
    },
    {
        "school": "STRIVE PREP - FEDERAL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336002012",
    },
    {
        "school": "CASTLE VIEW HIGH SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001918",
    },
    {
        "school": "NORTH STAR ACADEMY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345002011",
    },
    {
        "school": "STONE CREEK SCHOOL",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002002018",
    },
    {
        "school": "THE CLASSICAL ACADEMY MIDDLE SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001931",
    },
    {
        "school": "THE CLASSICAL ACADEMY HIGH SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001943",
    },
    {
        "school": "ROCKY MOUNTAIN CLASSICAL ACADEMY",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387002000",
    },
    {
        "school": "BANNING LEWIS RANCH ACADEMY",
        "district": "El Paso County Colorado School District 49",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387002027",
    },
    {
        "school": "ODYSSEY ELEMENTARY SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387002035",
    },
    {
        "school": "MEIKLEJOHN ELEMENTARY",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001923",
    },
    {
        "school": "NEW AMERICA SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80480002014",
    },
    {
        "school": "WAYNE CARLE MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480002036",
    },
    {
        "school": "ACADEMY OF ARTS AND KNOWLEDGE ELEMENTARY",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002001998",
    },
    {
        "school": "NEW VISION CHARTER SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540002006",
    },
    {
        "school": "PEAR PARK ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435001992",
    },
    {
        "school": "FRUITA 8/9 SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435002020",
    },
    {
        "school": "RIM ROCK ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435002030",
    },
    {
        "school": "SARGENT JUNIOR HIGH SCHOOL",
        "district": "Sargent School District No. Re-33J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80645002015",
    },
    {
        "school": "PRITCHETT MIDDLE SCHOOL",
        "district": "Pritchett School District No. Re-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80609001952",
    },
    {
        "school": "BACKPACK EARLY LEARNING ACADEMY",
        "district": "Delta County Joint District No. 50",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333001893",
    },
    {
        "school": "GRAND MESA CHOICE ACADEMY",
        "district": "Delta County Joint District No. 50",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80333001953",
    },
    {
        "school": "GRAND VALLEY CENTER FOR FAMILY LEARNING",
        "district": "Grand Valley School District No. 16 in the county of Garfi",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80438001909",
    },
    {
        "school": "COAL RIDGE HIGH SCHOOL",
        "district": "Garfield School District No. Re-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80624001906",
    },
    {
        "school": "HIGHLAND ELEMENTARY SCHOOL",
        "district": "Garfield School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80624001967",
    },
    {
        "school": "GUNNISON ELEMENTARY SCHOOL",
        "district": "Gunnison Watershed School District Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80447001968",
    },
    {
        "school": "LAKE CITY COMMUNITY SCHOOL",
        "district": "Hinsdale County School District No. Re-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80462001969",
    },
    {
        "school": "PEAKVIEW SCHOOL",
        "district": "Huerfano School District Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80708001845",
    },
    {
        "school": "FISHER'S PEAK ELEMENTARY SCHOOL",
        "district": "Trinidad School District 1 in the county of Las Animas and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80696001946",
    },
    {
        "school": "FOWLER ELEMENTARY SCHOOL",
        "district": "Fowler School District No. R4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80411001981",
    },
    {
        "school": "LA JUNTA INTERMEDIATE SCHOOL",
        "district": "East Otero School District No. R1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80513001974",
    },
    {
        "school": "LA JUNTA PRIMARY SCHOOL",
        "district": "East Otero School District No. R1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80513001975",
    },
    {
        "school": "Aspen Preschool",
        "district": "Aspen School District No. 1 in the county of Pitkin and Sta",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80228001982",
    },
    {
        "school": "MELVIN HENDRICKSON DEVELOPMENT CENTER",
        "district": "Lamar School District No. Re-2",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80522001983",
    },
    {
        "school": "SOROCO PRESCHOOL AT YAMPA",
        "district": "South Routt School District No. Re 3",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80591001910",
    },
    {
        "school": "THE ACADEMIC RECOVERY CENTER OF SAN LUIS VALLEY",
        "district": "Center Consolidated School District No. 26 Jt. of the count",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80285002008",
    },
    {
        "school": "SILVERTON MIDDLE SCHOOL",
        "district": "Silverton School District No. 1 in the county of San Juan",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80657001985",
    },
    {
        "school": "ORTEGA MIDDLE SCHOOL",
        "district": "Alamosa School District No. Re-11J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80207000026",
    },
    {
        "school": "ALAMOSA HIGH SCHOOL",
        "district": "Alamosa School District No. Re-11J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80207000027",
    },
    {
        "school": "SANGRE DE CRISTO ELEMENTARY SCHOOL",
        "district": "Sangre de Cristo School District No. Re-22J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80642001115",
    },
    {
        "school": "SANGRE DE CRISTO UNDIVIDED HIGH SCHOOL",
        "district": "Sangre de Cristo School District No. Re-22J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80642001116",
    },
    {
        "school": "PAGOSA SPRINGS ELEMENTARY SCHOOL",
        "district": "Archuleta County School District No. 50 Jt",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80219000038",
    },
    {
        "school": "PAGOSA SPRINGS HIGH SCHOOL",
        "district": "Archuleta County School District No. 50 Jt",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80219000039",
    },
    {
        "school": "PAGOSA SPRINGS MIDDLE SCHOOL",
        "district": "Archuleta County School District No. 50 Jt",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80219000040",
    },
    {
        "school": "CAMPO ELEMENTARY SCHOOL",
        "district": "Campo School District No. Re-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80276000169",
    },
    {
        "school": "CAMPO UNDIVIDED HIGH SCHOOL",
        "district": "Campo School District No. Re-6",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80276000170",
    },
    {
        "school": "PRITCHETT ELEMENTARY SCHOOL",
        "district": "Pritchett School District No. Re-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80609001026",
    },
    {
        "school": "PRITCHETT HIGH SCHOOL",
        "district": "Pritchett School District No. Re-3",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80609001027",
    },
    {
        "school": "SPRINGFIELD ELEMENTARY SCHOOL",
        "district": "Springfield School District No. Re-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80663001141",
    },
    {
        "school": "SPRINGFIELD JUNIOR/SENIOR HIGH SCHOOL",
        "district": "Springfield School District No. Re-4",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80663001142",
    },
    {
        "school": "VILAS ELEMENTARY SCHOOL",
        "district": "Vilas School District Re-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80699001206",
    },
    {
        "school": "VILAS UNDIVIDED HIGH SCHOOL",
        "district": "Vilas School District Re-5",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80699001207",
    },
    {
        "school": "WALSH ELEMENTARY SCHOOL",
        "district": "Walsh School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80711001215",
    },
    {
        "school": "WALSH HIGH SCHOOL",
        "district": "Walsh School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80711001216",
    },
    {
        "school": "LAS ANIMAS ELEMENTARY SCHOOL",
        "district": "Las Animas School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80525000866",
    },
    {
        "school": "LAS ANIMAS JUNIOR HIGH SCHOOL",
        "district": "Las Animas School District No. Re-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80525000867",
    },
    {
        "school": "LAS ANIMAS HIGH SCHOOL",
        "district": "Las Animas School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80525000868",
    },
    {
        "school": "JUMP START LEARNING CENTER",
        "district": "Las Animas School District No. Re-1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80525001782",
    },
    {
        "school": "McClave Elementary School",
        "district": "McClave School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80558000962",
    },
    {
        "school": "McClave Undivided High School",
        "district": "McClave School District No. Re-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80558000963",
    },
    {
        "school": "BUENA VISTA HIGH SCHOOL",
        "district": "Buena Vista School District No. R-31",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80264000157",
    },
    {
        "school": "Harry L McGinnis Middle School",
        "district": "Buena Vista School District No. R-31",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80264000158",
    },
    {
        "school": "AVERY/PARSONS ELEMENTARY SCHOOL",
        "district": "Buena Vista School District No. R-31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80264000159",
    },
    {
        "school": "CHAFFEE COUNTY HIGH SCHOOL",
        "district": "Buena Vista School District No. R-31",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80264006155",
    },
    {
        "school": "SALIDA MIDDLE SCHOOL",
        "district": "Salida School District No. R-32",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80633001107",
    },
    {
        "school": "LONGFELLOW ELEMENTARY SCHOOL",
        "district": "Salida School District No. R-32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80633001108",
    },
    {
        "school": "SALIDA HIGH SCHOOL",
        "district": "Salida School District No. R-32",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80633001109",
    },
    {
        "school": "CHEYENNE WELLS ELEMENTARY SCHOOL",
        "district": "Cheyenne County School District No. Re-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80000100214",
    },
    {
        "school": "CHEYENNE WELLS JUNIOR/HIGH SCHOOL",
        "district": "Cheyenne County School District No. Re-5",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80000100215",
    },
    {
        "school": "KIT CARSON JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Kit Carson School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80504000826",
    },
    {
        "school": "KIT CARSON ELEMENTARY SCHOOL",
        "district": "Kit Carson School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80504000827",
    },
    {
        "school": "GUADALUPE ELEMENTARY SCHOOL",
        "district": "South Conejos School District No. Re10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80213000033",
    },
    {
        "school": "ANTONITO HIGH SCHOOL",
        "district": "South Conejos School District No. Re10",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80213000035",
    },
    {
        "school": "ANTONITO MIDDLE SCHOOL",
        "district": "South Conejos School District No. Re10",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80213001464",
    },
    {
        "school": "CENTAURI MIDDLE SCHOOL",
        "district": "North Conejos School District No. Re1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80510000842",
    },
    {
        "school": "CENTAURI HIGH SCHOOL",
        "district": "North Conejos School District No. Re1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80510000843",
    },
    {
        "school": "LA JARA ELEMENTARY SCHOOL",
        "district": "North Conejos School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80510000844",
    },
    {
        "school": "MANASSA ELEMENTARY SCHOOL",
        "district": "North Conejos School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80510000845",
    },
    {
        "school": "CENTENNIAL SCHOOL",
        "district": "Centennial School District No. R-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80636001416",
    },
    {
        "school": "SANFORD ELEMENTARY SCHOOL",
        "district": "Sanford School District No. 6 in the county of Conejos and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80639001113",
    },
    {
        "school": "SANFORD JUNIOR/SENIOR HIGH SCHOOL",
        "district": "Sanford School District No. 6 in the county of Conejos and",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80639001114",
    },
    {
        "school": "SIERRA GRANDE K-12 SCHOOL",
        "district": "Sierra Grande School District No. R-30",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80414000572",
    },
    {
        "school": "CROWLEY COUNTY JUNIOR AND SENIOR HIGH SCHOOL",
        "district": "Crowley County School District No. Re-1-J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80321000282",
    },
    {
        "school": "CROWLEY COUNTY ELEMENTARY K-6",
        "district": "Crowley County School District No. Re-1-J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80321001519",
    },
    {
        "school": "CUSTER COUNTY HIGH SCHOOL",
        "district": "Custer County School District Consolidate 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80720001225",
    },
    {
        "school": "CUSTER COUNTY ELEMENTARY SCHOOL",
        "district": "Custer County School District Consolidate 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80720001226",
    },
    {
        "school": "CUSTER MIDDLE SCHOOL",
        "district": "Custer County School District Consolidate 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80720001732",
    },
    {
        "school": "CEDAREDGE ELEMENTARY SCHOOL",
        "district": "Delta County Joint District No. 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333000293",
    },
    {
        "school": "NORTH FORK MONTESSORI @ CRAWFORD",
        "district": "Delta County Joint District No. 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333000295",
    },
    {
        "school": "DELTA MIDDLE SCHOOL",
        "district": "Delta County Joint District No. 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333000296",
    },
    {
        "school": "DELTA HIGH SCHOOL",
        "district": "Delta County Joint District No. 50",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333000297",
    },
    {
        "school": "GARNET MESA ELEMENTARY SCHOOL",
        "district": "Delta County Joint District No. 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333000298",
    },
    {
        "school": "HOTCHKISS ELEMENTARY SCHOOL",
        "district": "Delta County Joint District No. 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333000299",
    },
    {
        "school": "HOTCHKISS HIGH SCHOOL",
        "district": "Delta County Joint District No. 50",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333000300",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "Delta County Joint District No. 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333000301",
    },
    {
        "school": "PAONIA HIGH SCHOOL",
        "district": "Delta County Joint District No. 50",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333000304",
    },
    {
        "school": "CEDAREDGE MIDDLE SCHOOL",
        "district": "Delta County Joint District No. 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333001334",
    },
    {
        "school": "CEDAREDGE HIGH SCHOOL",
        "district": "Delta County Joint District No. 50",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333001335",
    },
    {
        "school": "PAONIA ELEMENTARY SCHOOL",
        "district": "Delta County Joint District No. 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333001337",
    },
    {
        "school": "DOVE CREEK HIGH SCHOOL",
        "district": "Dolores County School District RE-2J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80342000429",
    },
    {
        "school": "SEVENTH STREET ELEMENTARY SCHOOL",
        "district": "Dolores County School District RE-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80342000435",
    },
    {
        "school": "BASALT MIDDLE SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426000133",
    },
    {
        "school": "BASALT ELEMENTARY SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426000582",
    },
    {
        "school": "BASALT HIGH SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426000584",
    },
    {
        "school": "CARBONDALE MIDDLE SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426000586",
    },
    {
        "school": "GLENWOOD SPRINGS MIDDLE SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426000587",
    },
    {
        "school": "GLENWOOD SPRINGS HIGH SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426000588",
    },
    {
        "school": "GLENWOOD SPRINGS ELEMENTARY SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426000589",
    },
    {
        "school": "ROARING FORK HIGH SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426000590",
    },
    {
        "school": "CARBONDALE COMMUNITY CHARTER SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426001505",
    },
    {
        "school": "CRYSTAL RIVER ELEMENTARY SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426001540",
    },
    {
        "school": "BRIDGES",
        "district": "Roaring Fork School District No. Re-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80426001596",
    },
    {
        "school": "SOPRIS ELEMENTARY SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426001597",
    },
    {
        "school": "BEA UNDERWOOD ELEMENTARY SCHOOL",
        "district": "Grand Valley School District No. 16 in the county of Garfi",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80438000630",
    },
    {
        "school": "GRAND VALLEY HIGH SCHOOL",
        "district": "Grand Valley School District No. 16 in the county of Garfi",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80438000631",
    },
    {
        "school": "GRAND VALLEY MIDDLE SCHOOL",
        "district": "Grand Valley School District No. 16 in the county of Garfi",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80438001368",
    },
    {
        "school": "RIFLE MIDDLE SCHOOL",
        "district": "Garfield School District No. Re-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80624001096",
    },
    {
        "school": "RIFLE HIGH SCHOOL",
        "district": "Garfield School District No. Re-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80624001097",
    },
    {
        "school": "RIVERSIDE SCHOOL",
        "district": "Garfield School District No. Re-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80624001098",
    },
    {
        "school": "CACTUS VALLEY ELEMENTARY SCHOOL",
        "district": "Garfield School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80624001099",
    },
    {
        "school": "WAMSLEY ELEMENTARY SCHOOL",
        "district": "Garfield School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80624001358",
    },
    {
        "school": "KATHRYN SENOR ELEMENTARY SCHOOL",
        "district": "Garfield School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80624001598",
    },
    {
        "school": "FRASER VALLEY ELEMENTARY SCHOOL",
        "district": "East Grand School District No. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80432000594",
    },
    {
        "school": "GRANBY ELEMENTARY SCHOOL",
        "district": "East Grand School District No. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80432000595",
    },
    {
        "school": "MIDDLE PARK HIGH SCHOOL",
        "district": "East Grand School District No. 2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80432000596",
    },
    {
        "school": "EAST GRAND MIDDLE SCHOOL",
        "district": "East Grand School District No. 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80432001343",
    },
    {
        "school": "West Grand Elementary and Middle School",
        "district": "West Grand School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80507000829",
    },
    {
        "school": "WEST GRAND HIGH SCHOOL",
        "district": "West Grand School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80507000830",
    },
    {
        "school": "CRESTED BUTTE SECONDARY SCHOOL",
        "district": "Gunnison Watershed School District Re1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80447000655",
    },
    {
        "school": "GUNNISON HIGH SCHOOL",
        "district": "Gunnison Watershed School District Re1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80447000656",
    },
    {
        "school": "MARBLE CHARTER SCHOOL",
        "district": "Gunnison Watershed School District Re1J",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80447001507",
    },
    {
        "school": "GUNNISON MIDDLE SCHOOL",
        "district": "Gunnison Watershed School District Re1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80447001600",
    },
    {
        "school": "LAKE PRESCHOOL",
        "district": "Gunnison Watershed School District Re1J",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80447001689",
    },
    {
        "school": "LA VETA ELEMENTARY SCHOOL",
        "district": "La Veta School District Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80516000853",
    },
    {
        "school": "LA VETA JUNIOR-SENIOR HIGH SCHOOL",
        "district": "La Veta School District Re-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80516000854",
    },
    {
        "school": "GARDNER ELEMENTARY SCHOOL",
        "district": "Huerfano School District Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80708001211",
    },
    {
        "school": "JOHN MALL HIGH SCHOOL",
        "district": "Huerfano School District Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80708001212",
    },
    {
        "school": "NORTH PARK SCHOOL",
        "district": "North Park School District R-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80705001209",
    },
    {
        "school": "EADS ELEMENTARY SCHOOL",
        "district": "Kiowa County School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80351000458",
    },
    {
        "school": "EADS HIGH SCHOOL",
        "district": "Kiowa County School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80351000459",
    },
    {
        "school": "EADS MIDDLE SCHOOL",
        "district": "Kiowa County School District No. Re-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80351001277",
    },
    {
        "school": "PLAINVIEW ELEMENTARY SCHOOL",
        "district": "Kiowa County School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80693001198",
    },
    {
        "school": "PLAINVIEW JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Kiowa County School District No. Re-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80693001199",
    },
    {
        "school": "FLAGLER PUBLIC SCHOOL",
        "district": "Arriba-Flagler Consolidated School District No. 20",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80226000509",
    },
    {
        "school": "BETHUNE PUBLIC SCHOOLS",
        "district": "Bethune School District No. R- 5",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80246000095",
    },
    {
        "school": "BURLINGTON ELEMENTARY SCHOOL",
        "district": "Burlington Public School District No. RE-6J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80267000160",
    },
    {
        "school": "BURLINGTON MIDDLE SCHOOL",
        "district": "Burlington Public School District No. RE-6J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80267000161",
    },
    {
        "school": "BURLINGTON HIGH SCHOOL",
        "district": "Burlington Public School District No. RE-6J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80267000162",
    },
    {
        "school": "HI-PLAINS SCHOOL DISTRICT R-23",
        "district": "Hi-Plains R-23",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80651001130",
    },
    {
        "school": "STRATTON MIDDLE SCHOOL",
        "district": "School District No. R-4 in the county of Kit Carson and Stat",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80678000138",
    },
    {
        "school": "STRATTON ELEMENTARY SCHOOL",
        "district": "School District No. R-4 in the county of Kit Carson and Stat",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80678001162",
    },
    {
        "school": "STRATTON SENIOR HIGH SCHOOL",
        "district": "School District No. R-4 in the county of Kit Carson and Stat",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80678001163",
    },
    {
        "school": "AGUILAR ELEMENTARY SCHOOL",
        "district": "Aguilar Reorganized School District No. 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80201000022",
    },
    {
        "school": "AGUILAR JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Aguilar Reorganized School District No. 6",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80201000023",
    },
    {
        "school": "BRANSON SCHOOL",
        "district": "Branson Reorganized School District No. 82",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80252000141",
    },
    {
        "school": "BRANSON SCHOOL ONLINE",
        "district": "Branson Reorganized School District No. 82",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80252001728",
    },
    {
        "school": "HOEHNE SCHOOLS",
        "district": "Hoehne Reorganized School District No. 3",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80465000680",
    },
    {
        "school": "KIM ELEMENTARY SCHOOL",
        "district": "Kim Reorganized School District No. 88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80498000822",
    },
    {
        "school": "KIM UNDIVIDED HIGH SCHOOL",
        "district": "Kim Reorganized School District No. 88",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80498000823",
    },
    {
        "school": "ECKHART ELEMENTARY SCHOOL",
        "district": "Trinidad School District 1 in the county of Las Animas and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80696001201",
    },
    {
        "school": "TRINIDAD MIDDLE SCHOOL",
        "district": "Trinidad School District 1 in the county of Las Animas and",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80696001204",
    },
    {
        "school": "TRINIDAD HIGH SCHOOL",
        "district": "Trinidad School District 1 in the county of Las Animas and",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80696001205",
    },
    {
        "school": "PRIMERO JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Primero Reorganized School District No. 2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80726001255",
    },
    {
        "school": "PRIMERO ELEMENTARY SCHOOL",
        "district": "Primero Reorganized School District No. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80726001256",
    },
    {
        "school": "GENOA-HUGO SCHOOL",
        "district": "Genoa-Hugo School District No. C-113",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80474000686",
    },
    {
        "school": "KARVAL ELEMENTARY SCHOOL",
        "district": "Karval School District No. Re 23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80489000814",
    },
    {
        "school": "KARVAL JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Karval School District No. Re 23",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80489000815",
    },
    {
        "school": "LIMON ELEMENTARY SCHOOL",
        "district": "Limon School District No. Re 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80528000870",
    },
    {
        "school": "LIMON JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Limon School District No. Re 4J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80528000871",
    },
    {
        "school": "CREEDE SCHOOL",
        "district": "Creede School District",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80315000279",
    },
    {
        "school": "CRAIG MIDDLE SCHOOL",
        "district": "Moffat County School District RE: No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80573000977",
    },
    {
        "school": "MAYBELL SCHOOL",
        "district": "Moffat County School District RE: No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80573000980",
    },
    {
        "school": "MOFFAT COUNTY HIGH SCHOOL",
        "district": "Moffat County School District RE: No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80573000981",
    },
    {
        "school": "SUNSET ELEMENTARY SCHOOL",
        "district": "Moffat County School District RE: No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80573000983",
    },
    {
        "school": "RIDGEVIEW ELEMENTARY SCHOOL",
        "district": "Moffat County School District RE: No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80573001355",
    },
    {
        "school": "SANDROCK ELEMENTARY",
        "district": "Moffat County School District RE: No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80573001553",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "Moffat County School District RE: No. 1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80573001659",
    },
    {
        "school": "BEECH STREET PRESCHOOL",
        "district": "Montezuma-Cortez School District No. Re-1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80309000235",
    },
    {
        "school": "MONTEZUMA-CORTEZ MIDDLE SCHOOL",
        "district": "Montezuma-Cortez School District No. Re-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80309000833",
    },
    {
        "school": "KEMPER ELEMENTARY SCHOOL",
        "district": "Montezuma-Cortez School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80309000835",
    },
    {
        "school": "LEWIS-ARRIOLA ELEMENTARY SCHOOL",
        "district": "Montezuma-Cortez School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80309000837",
    },
    {
        "school": "MANAUGH ELEMENTARY SCHOOL",
        "district": "Montezuma-Cortez School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80309000838",
    },
    {
        "school": "MESA ELEMENTARY SCHOOL",
        "district": "Montezuma-Cortez School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80309000839",
    },
    {
        "school": "MONTEZUMA-CORTEZ HIGH SCHOOL",
        "district": "Montezuma-Cortez School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80309000840",
    },
    {
        "school": "PLEASANT VIEW ELEMENTARY SCHOOL",
        "district": "Montezuma-Cortez School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80309000841",
    },
    {
        "school": "BATTLE ROCK CHARTER SCHOOL",
        "district": "Montezuma-Cortez School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80309001093",
    },
    {
        "school": "SOUTHWEST OPEN CHARTER SCHOOL",
        "district": "Montezuma-Cortez School District No. Re-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80309001692",
    },
    {
        "school": "TEDDY BEAR PRESCHOOL",
        "district": "Dolores School District No. Re-4A",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80339000237",
    },
    {
        "school": "DOLORES ELEMENTARY SCHOOL",
        "district": "Dolores School District No. Re-4A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80339000430",
    },
    {
        "school": "DOLORES SECONDARY SCHOOL",
        "district": "Dolores School District No. Re-4A",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80339000432",
    },
    {
        "school": "MANCOS ELEMENTARY SCHOOL",
        "district": "Mancos School District Re-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80546000943",
    },
    {
        "school": "MANCOS HIGH SCHOOL",
        "district": "Mancos School District Re-6",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80546000944",
    },
    {
        "school": "MANCOS MIDDLE SCHOOL",
        "district": "Mancos School District Re-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80546001287",
    },
    {
        "school": "CHERAW SCHOOL",
        "district": "Cheraw School District No. 31 in the county of Otero and S",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80288000182",
    },
    {
        "school": "FOWLER JUNIOR HIGH SCHOOL",
        "district": "Fowler School District No. R4J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80411000567",
    },
    {
        "school": "FOWLER HIGH SCHOOL",
        "district": "Fowler School District No. R4J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80411000568",
    },
    {
        "school": "MANZANOLA ELEMENTARY SCHOOL",
        "district": "Manzanola Joint District No. 3J of the counties of Otero a",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80552000949",
    },
    {
        "school": "MANZANOLA JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Manzanola Joint District No. 3J of the counties of Otero a",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80552001375",
    },
    {
        "school": "JEFFERSON INTERMEDIATE SCHOOL",
        "district": "Rocky Ford School District No. R2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80627001101",
    },
    {
        "school": "ROCKY FORD JUNIOR/SENIOR HIGH SCHOOL",
        "district": "Rocky Ford School District No. R2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80627001103",
    },
    {
        "school": "WASHINGTON PRIMARY SCHOOL",
        "district": "Rocky Ford School District No. R2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80627001104",
    },
    {
        "school": "SWINK ELEMENTARY SCHOOL",
        "district": "Swink School District No. 33 in the county of Otero and St",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80684001168",
    },
    {
        "school": "SWINK JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Swink School District No. 33 in the county of Otero and St",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80684001169",
    },
    {
        "school": "OURAY ELEMENTARY SCHOOL",
        "district": "Ouray School District No. R-1 of  the county of Ouray and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80597001018",
    },
    {
        "school": "OURAY SENIOR HIGH SCHOOL",
        "district": "Ouray School District No. R-1 of  the county of Ouray and",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80597001019",
    },
    {
        "school": "OURAY MIDDLE SCHOOL",
        "district": "Ouray School District No. R-1 of  the county of Ouray and",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80597001662",
    },
    {
        "school": "RIDGWAY ELEMENTARY SCHOOL",
        "district": "Ridgway School District No. R-2  of  the county of Ouray a",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80621001089",
    },
    {
        "school": "RIDGWAY HIGH SCHOOL",
        "district": "Ridgway School District No. R-2  of  the county of Ouray a",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80621001090",
    },
    {
        "school": "RIDGWAY MIDDLE SCHOOL",
        "district": "Ridgway School District No. R-2  of  the county of Ouray a",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80621006166",
    },
    {
        "school": "HAXTUN ELEMENTARY SCHOOL",
        "district": "Haxtun School District No. Re-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80456000673",
    },
    {
        "school": "HAXTUN HIGH SCHOOL",
        "district": "Haxtun School District No. Re-2J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80456000674",
    },
    {
        "school": "HOLYOKE ELEMENTARY SCHOOL",
        "district": "Holyoke School District No. Re-1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80471000683",
    },
    {
        "school": "HOLYOKE SENIOR HIGH SCHOOL",
        "district": "Holyoke School District No. Re-1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80471000684",
    },
    {
        "school": "ASPEN ELEMENTARY SCHOOL",
        "district": "Aspen School District No. 1 in the county of Pitkin and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80228000045",
    },
    {
        "school": "ASPEN MIDDLE SCHOOL",
        "district": "Aspen School District No. 1 in the county of Pitkin and Sta",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80228000046",
    },
    {
        "school": "ASPEN HIGH SCHOOL",
        "district": "Aspen School District No. 1 in the county of Pitkin and Sta",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80228000047",
    },
    {
        "school": "ASPEN COMMUNITY CHARTER SCHOOL",
        "district": "Aspen School District No. 1 in the county of Pitkin and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80228001703",
    },
    {
        "school": "GRANADA ELEMENTARY SCHOOL",
        "district": "Granada School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80429000592",
    },
    {
        "school": "GRANADA UNDIVIDED HIGH SCHOOL",
        "district": "Granada School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80429000593",
    },
    {
        "school": "Holly School",
        "district": "Holly School District No. Re-3",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80468000681",
    },
    {
        "school": "ALTA VISTA CHARTER SCHOOL",
        "district": "Lamar School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80522000860",
    },
    {
        "school": "LAMAR MIDDLE SCHOOL",
        "district": "Lamar School District No. Re-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80522000861",
    },
    {
        "school": "LAMAR HIGH SCHOOL",
        "district": "Lamar School District No. Re-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80522000862",
    },
    {
        "school": "PARKVIEW ELEMENTARY SCHOOL",
        "district": "Lamar School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80522000864",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "Lamar School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80522000865",
    },
    {
        "school": "WILEY ELEMENTARY SCHOOL",
        "district": "Wiley School District No. Re-13 Jt",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80732001260",
    },
    {
        "school": "WILEY JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Wiley School District No. Re-13 Jt",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80732001261",
    },
    {
        "school": "MEEKER ELEMENTARY SCHOOL",
        "district": "Meeker School District Re1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80561000965",
    },
    {
        "school": "BARONE MIDDLE SCHOOL",
        "district": "Meeker School District Re1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80561000966",
    },
    {
        "school": "MEEKER HIGH SCHOOL",
        "district": "Meeker School District Re1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80561000967",
    },
    {
        "school": "PARKVIEW ELEMENTARY SCHOOL",
        "district": "Rangely School District RE4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80618001086",
    },
    {
        "school": "RANGELY JUNIOR/SENIOR HIGH SCHOOL",
        "district": "Rangely School District RE4",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80618001088",
    },
    {
        "school": "DEL NORTE ELEMENTARY SCHOOL",
        "district": "Upper Rio Grande School District C-7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80330000289",
    },
    {
        "school": "DEL NORTE HIGH JR./SR. HIGH SCHOOL",
        "district": "Upper Rio Grande School District C-7",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80330000290",
    },
    {
        "school": "BYRON SYRING DELTA CENTER",
        "district": "Monte Vista School District No. C-8",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80576000984",
    },
    {
        "school": "BILL METZ ELEMENTARY SCHOOL",
        "district": "Monte Vista School District No. C-8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80576000985",
    },
    {
        "school": "MONTE VISTA MIDDLE SCHOOL",
        "district": "Monte Vista School District No. C-8",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80576000986",
    },
    {
        "school": "MARSH ELEMENTARY SCHOOL",
        "district": "Monte Vista School District No. C-8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80576001110",
    },
    {
        "school": "MONTE VISTA SENIOR HIGH SCHOOL",
        "district": "Monte Vista School District No. C-8",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80576001356",
    },
    {
        "school": "MONTE VISTA ON-LINE ACADEMY",
        "district": "Monte Vista School District No. C-8",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80576001560",
    },
    {
        "school": "SARGENT ELEMENTARY SCHOOL",
        "district": "Sargent School District No. Re-33J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80645001117",
    },
    {
        "school": "SARGENT SENIOR HIGH SCHOOL",
        "district": "Sargent School District No. Re-33J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80645001118",
    },
    {
        "school": "HAYDEN VALLEY ELEMENTARY SCHOOL",
        "district": "Hayden School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80459000675",
    },
    {
        "school": "HAYDEN MIDDLE SCHOOL",
        "district": "Hayden School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80459000676",
    },
    {
        "school": "HAYDEN HIGH SCHOOL",
        "district": "Hayden School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80459001348",
    },
    {
        "school": "SOROCO MIDDLE SCHOOL",
        "district": "South Routt School District No. Re 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80591001013",
    },
    {
        "school": "SOROCO HIGH SCHOOL",
        "district": "South Routt School District No. Re 3",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80591001014",
    },
    {
        "school": "SOUTH ROUTT ELEMENTARY SCHOOL",
        "district": "South Routt School District No. Re 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80591001015",
    },
    {
        "school": "STEAMBOAT SPRINGS HIGH SCHOOL",
        "district": "Steamboat Springs School District No. Re 2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80666001144",
    },
    {
        "school": "SODA CREEK ELEMENTARY SCHOOL",
        "district": "Steamboat Springs School District No. Re 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80666001145",
    },
    {
        "school": "STEAMBOAT SPRINGS MIDDLE SCHOOL",
        "district": "Steamboat Springs School District No. Re 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80666001146",
    },
    {
        "school": "STRAWBERRY PARK ELEMENTARY SCHOOL",
        "district": "Steamboat Springs School District No. Re 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80666001360",
    },
    {
        "school": "NORTH ROUTT CHARTER SCHOOL",
        "district": "Steamboat Springs School District No. Re 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80666001749",
    },
    {
        "school": "HASKIN ELEMENTARY SCHOOL",
        "district": "Center Consolidated School District No. 26 Jt. of the count",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80285000177",
    },
    {
        "school": "SKOGLUND MIDDLE SCHOOL",
        "district": "Center Consolidated School District No. 26 Jt. of the count",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80285000178",
    },
    {
        "school": "CENTER HIGH SCHOOL",
        "district": "Center Consolidated School District No. 26 Jt. of the count",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80285000179",
    },
    {
        "school": "MOFFAT PREK-12 SCHOOL",
        "district": "Moffat School District No. 2 in the county of Saguache and",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80570000974",
    },
    {
        "school": "CRESTONE CHARTER SCHOOL",
        "district": "Moffat School District No. 2 in the county of Saguache and",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80570001511",
    },
    {
        "school": "MOUNTAIN VALLEY SCHOOL",
        "district": "Mountain Valley School District No. Re 1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80630001415",
    },
    {
        "school": "SILVERTON ELEMENTARY SCHOOL",
        "district": "Silverton School District No. 1 in the county of San Juan",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80657001136",
    },
    {
        "school": "SILVERTON HIGH SCHOOL",
        "district": "Silverton School District No. 1 in the county of San Juan",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80657001137",
    },
    {
        "school": "NORWOOD PUBLIC SCHOOLS",
        "district": "Norwood School District No. R-2J",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80588001012",
    },
    {
        "school": "TELLURIDE INTERMEDIATE SCHOOL",
        "district": "Telluride School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80687001170",
    },
    {
        "school": "TELLURIDE HIGH SCHOOL",
        "district": "Telluride School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80687001171",
    },
    {
        "school": "TELLURIDE MIDDLE SCHOOL",
        "district": "Telluride School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80687001304",
    },
    {
        "school": "JULESBURG ELEMENTARY SCHOOL",
        "district": "Julesburg School District No. Re1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80486000811",
    },
    {
        "school": "JULESBURG HIGH SCHOOL",
        "district": "Julesburg School District No. Re1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80486000813",
    },
    {
        "school": "REVERE ELEMENTARY",
        "district": "Revere School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80600001020",
    },
    {
        "school": "REVERE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Revere School District",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80600001021",
    },
    {
        "school": "AKRON ELEMENTARY SCHOOL",
        "district": "Akron School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80204000024",
    },
    {
        "school": "AKRON HIGH SCHOOL",
        "district": "Akron School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80204000025",
    },
    {
        "school": "ARICKAREE ELEMENTARY SCHOOL",
        "district": "Arickaree School District No. R-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80222000041",
    },
    {
        "school": "ARICKAREE UNDIVIDED HIGH SCHOOL",
        "district": "Arickaree School District No. R-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80222000042",
    },
    {
        "school": "LONE STAR ELEMENTARY SCHOOL",
        "district": "Lone Star School District No. 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80534000894",
    },
    {
        "school": "LONE STAR UNDIVIDED HIGH SCHOOL",
        "district": "Lone Star School District No. 101",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80534000895",
    },
    {
        "school": "OTIS ELEMENTARY SCHOOL",
        "district": "Otis School District No. R-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80594001016",
    },
    {
        "school": "OTIS JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Otis School District No. R-3",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80594001017",
    },
    {
        "school": "WOODLIN ELEMENTARY SCHOOL",
        "district": "Woodlin School District No. R-104",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80741001270",
    },
    {
        "school": "WOODLIN UNDIVIDED HIGH SCHOOL",
        "district": "Woodlin School District No. R-104",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80741001271",
    },
    {
        "school": "LITTLE INDIANS PRESCHOOL",
        "district": "Yuma 1 School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80001601745",
    },
    {
        "school": "YUMA MIDDLE SCHOOL",
        "district": "Yuma 1 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80001601819",
    },
    {
        "school": "KENNETH P MORRIS ELEMENTARY SCHOOL",
        "district": "Yuma 1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80001601820",
    },
    {
        "school": "YUMA HIGH SCHOOL",
        "district": "Yuma 1 School District",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80001601821",
    },
    {
        "school": "WRAY ELEMENTARY SCHOOL",
        "district": "Wray RD-2 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80001701816",
    },
    {
        "school": "BUCHANAN MIDDLE SCHOOL",
        "district": "Wray RD-2 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80001701817",
    },
    {
        "school": "WRAY HIGH SCHOOL",
        "district": "Wray RD-2 School District",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80001701818",
    },
    {
        "school": "IDALIA ELEMENTARY SCHOOL",
        "district": "Idalia RJ-3 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80001801741",
    },
    {
        "school": "IDALIA JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Idalia RJ-3 School District",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80001801742",
    },
    {
        "school": "LIBERTY SCHOOL",
        "district": "Liberty J-4 School District",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "CO",
        "nces_id": "80001901744",
    },
    {
        "school": "ALPINE ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001832",
    },
    {
        "school": "ALTONA MIDDLE SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001886",
    },
    {
        "school": "FLAGSTAFF CHARTER ACADEMY",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001890",
    },
    {
        "school": "TRAIL RIDGE MIDDLE SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001891",
    },
    {
        "school": "LEGACY ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001830",
    },
    {
        "school": "CARBON VALLEY ACADEMY",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001887",
    },
    {
        "school": "ERIE HIGH SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001889",
    },
    {
        "school": "BEAR CREEK ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000099",
    },
    {
        "school": "BOULDER HIGH SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000101",
    },
    {
        "school": "MANHATTAN MIDDLE SCHOOL OF THE ARTS AND ACADEMICS",
        "district": "Boulder Valley School District No. Re2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000104",
    },
    {
        "school": "CASEY MIDDLE SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000106",
    },
    {
        "school": "CENTAURUS HIGH SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000107",
    },
    {
        "school": "CENTENNIAL MIDDLE SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000108",
    },
    {
        "school": "COLUMBINE ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000109",
    },
    {
        "school": "CREST VIEW ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000110",
    },
    {
        "school": "DOUGLASS ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000111",
    },
    {
        "school": "EISENHOWER ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000112",
    },
    {
        "school": "FAIRVIEW HIGH SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000114",
    },
    {
        "school": "FLATIRONS ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000115",
    },
    {
        "school": "FOOTHILL ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000116",
    },
    {
        "school": "GOLD HILL ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000117",
    },
    {
        "school": "HEATHERWOOD ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000118",
    },
    {
        "school": "JAMESTOWN ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000119",
    },
    {
        "school": "LAFAYETTE ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000121",
    },
    {
        "school": "ANGEVINE MIDDLE SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000122",
    },
    {
        "school": "LOUISVILLE ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000124",
    },
    {
        "school": "LOUISVILLE MIDDLE SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000125",
    },
    {
        "school": "CREEKSIDE ELEMENTARY SCHOOL AT MARTIN PARK",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000128",
    },
    {
        "school": "MESA ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000129",
    },
    {
        "school": "NEDERLAND ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000130",
    },
    {
        "school": "NEDERLAND MIDDLE-SENIOR HIGH SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000131",
    },
    {
        "school": "NEVIN PLATT MIDDLE SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000132",
    },
    {
        "school": "SOUTHERN HILLS MIDDLE SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000134",
    },
    {
        "school": "UNIVERSITY HILL ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000135",
    },
    {
        "school": "WHITTIER ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000139",
    },
    {
        "school": "NEW VISTA HIGH SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000465",
    },
    {
        "school": "ARAPAHOE RIDGE HIGH SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80249001219",
    },
    {
        "school": "COMMUNITY MONTESSORI SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001227",
    },
    {
        "school": "HIGH PEAKS ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001243",
    },
    {
        "school": "RYAN ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001365",
    },
    {
        "school": "COAL CREEK ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001376",
    },
    {
        "school": "ALICIA SANCHEZ INTERNATIONAL SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001403",
    },
    {
        "school": "SUMMIT MIDDLE CHARTER SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001517",
    },
    {
        "school": "SUPERIOR ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001518",
    },
    {
        "school": "MONARCH K-8 SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001573",
    },
    {
        "school": "BOULDER COMMUNITY SCHOOL/INTEGRATED STUDIES",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001630",
    },
    {
        "school": "BOULDER PREP CHARTER HIGH SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80249001631",
    },
    {
        "school": "MONARCH HIGH SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001632",
    },
    {
        "school": "ELDORADO K-8 SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001771",
    },
    {
        "school": "PEAK TO PEAK CHARTER SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001792",
    },
    {
        "school": "FIRESIDE ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249006154",
    },
    {
        "school": "HORIZONS K-8 SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80249006199",
    },
    {
        "school": "PIONEER BILINGUAL ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249006200",
    },
    {
        "school": "BURLINGTON ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000896",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000897",
    },
    {
        "school": "ERIE ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000899",
    },
    {
        "school": "HYGIENE ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000903",
    },
    {
        "school": "INDIAN PEAKS ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000904",
    },
    {
        "school": "LONGMONT ESTATES ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000907",
    },
    {
        "school": "SUNSET MIDDLE SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000908",
    },
    {
        "school": "LONGMONT HIGH SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000909",
    },
    {
        "school": "LONGS PEAK MIDDLE SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000910",
    },
    {
        "school": "LYONS ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000911",
    },
    {
        "school": "LYONS MIDDLE/SENIOR HIGH SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000912",
    },
    {
        "school": "MOUNTAIN VIEW ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000916",
    },
    {
        "school": "NIWOT ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000917",
    },
    {
        "school": "NIWOT HIGH SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000918",
    },
    {
        "school": "NORTHRIDGE ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000920",
    },
    {
        "school": "ROCKY MOUNTAIN ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000921",
    },
    {
        "school": "SKYLINE HIGH SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001284",
    },
    {
        "school": "COLUMBINE ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001373",
    },
    {
        "school": "OLDE COLUMBINE HIGH SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80537001374",
    },
    {
        "school": "SANBORN ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001396",
    },
    {
        "school": "TWIN PEAKS CHARTER ACADEMY",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001572",
    },
    {
        "school": "EAGLE CREST ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001675",
    },
    {
        "school": "FALL RIVER ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001737",
    },
    {
        "school": "SILVER CREEK HIGH SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001814",
    },
    {
        "school": "WESTVIEW MIDDLE SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006198",
    },
    {
        "school": "BIRCH ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000100",
    },
    {
        "school": "BROOMFIELD HEIGHTS MIDDLE SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000102",
    },
    {
        "school": "BROOMFIELD HIGH SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000103",
    },
    {
        "school": "EMERALD ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000113",
    },
    {
        "school": "KOHL ELEMENTARY SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249000120",
    },
    {
        "school": "ASPEN CREEK K-8 SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249001758",
    },
    {
        "school": "ERIE MIDDLE SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000900",
    },
    {
        "school": "THUNDER VALLEY PK-8",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000901",
    },
    {
        "school": "FREDERICK SENIOR HIGH SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000902",
    },
    {
        "school": "MEAD ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000914",
    },
    {
        "school": "MEAD MIDDLE SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537000915",
    },
    {
        "school": "COAL RIDGE MIDDLE SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001774",
    },
    {
        "school": "PRAIRIE RIDGE ELEMENTARY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537001794",
    },
    {
        "school": "CANON CITY MIDDLE SCHOOL",
        "district": "Fremont Re-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80279000171",
    },
    {
        "school": "CANON CITY HIGH SCHOOL",
        "district": "Fremont Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80279000172",
    },
    {
        "school": "HARRISON SCHOOL",
        "district": "Fremont Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80279000173",
    },
    {
        "school": "LINCOLN SCHOOL OF SCIENCE AND TECHNOLOGY",
        "district": "Fremont Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80279000174",
    },
    {
        "school": "MCKINLEY ELEMENTARY SCHOOL",
        "district": "Fremont Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80279000175",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "Fremont Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80279000176",
    },
    {
        "school": "CANON EXPLORATORY SCHOOL",
        "district": "Fremont Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80279001433",
    },
    {
        "school": "MOUNT VIEW CORE KNOWLEDGE CHARTER SCHOOL",
        "district": "Fremont Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80279001538",
    },
    {
        "school": "COTOPAXI ELEMENTARY SCHOOL",
        "district": "Fremont Re-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80312000276",
    },
    {
        "school": "COTOPAXI JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Fremont Re-3",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80312000277",
    },
    {
        "school": "Florence Jr./Sr. High School",
        "district": "Fremont Re-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80396000514",
    },
    {
        "school": "FREMONT ELEMENTARY SCHOOL",
        "district": "Fremont Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80396000515",
    },
    {
        "school": "PENROSE ELEMENTARY SCHOOL",
        "district": "Fremont Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80396000516",
    },
    {
        "school": "THE DA VINCI ACADEMY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001842",
    },
    {
        "school": "DISCOVERY CANYON CAMPUS HIGH SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001905",
    },
    {
        "school": "EASTLAKE HIGH SCHOOL OF COLORADO SPRINGS",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80306001841",
    },
    {
        "school": "THE BIJOU SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80306001888",
    },
    {
        "school": "MERIDIAN RANCH ELEMENTARY SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387001843",
    },
    {
        "school": "PIKES PEAK SCHOOL EXPEDITIONARY LEARNING",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387001844",
    },
    {
        "school": "RIDGEVIEW ELEMENTARY SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387001898",
    },
    {
        "school": "SPRINGS RANCH ELEMENTARY SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387001899",
    },
    {
        "school": "JAMES IRWIN CHARTER ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001902",
    },
    {
        "school": "MOUNTAIN VISTA COMMUNITY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001903",
    },
    {
        "school": "JAMES IRWIN CHARTER MIDDLE SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001964",
    },
    {
        "school": "SOARING EAGLES ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001965",
    },
    {
        "school": "JAMES MADISON CHARTER ACADEMY SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001885",
    },
    {
        "school": "CRESSON ELEMENTARY SCHOOL",
        "district": "Cripple Creek-Victor School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80318000280",
    },
    {
        "school": "CRIPPLE CREEK-VICTOR JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Cripple Creek-Victor School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80318000281",
    },
    {
        "school": "SUMMIT ELEMENTARY SCHOOL",
        "district": "Woodland Park School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80738000643",
    },
    {
        "school": "GATEWAY ELEMENTARY SCHOOL",
        "district": "Woodland Park School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80738001266",
    },
    {
        "school": "WOODLAND PARK HIGH SCHOOL",
        "district": "Woodland Park School District No. Re-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80738001267",
    },
    {
        "school": "WOODLAND PARK MIDDLE SCHOOL",
        "district": "Woodland Park School District No. Re-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80738001268",
    },
    {
        "school": "COLUMBINE ELEMENTARY SCHOOL",
        "district": "Woodland Park School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80738001269",
    },
    {
        "school": "CHALLENGER MIDDLE SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192000001",
    },
    {
        "school": "AIR ACADEMY HIGH SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192000002",
    },
    {
        "school": "DOUGLASS VALLEY ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192000003",
    },
    {
        "school": "EDITH WOLFORD ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192000004",
    },
    {
        "school": "MOUNTAIN VIEW ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192000005",
    },
    {
        "school": "ROCKRIMMON ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192000007",
    },
    {
        "school": "WOODMEN-ROBERTS ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192000008",
    },
    {
        "school": "ANTELOPE TRAILS ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192000123",
    },
    {
        "school": "PRAIRIE HILLS ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192000531",
    },
    {
        "school": "ASPEN VALLEY CAMPUS",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80192000858",
    },
    {
        "school": "FOOTHILLS ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001319",
    },
    {
        "school": "HIGH PLAINS ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001320",
    },
    {
        "school": "RAMPART HIGH SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001321",
    },
    {
        "school": "FRONTIER ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001387",
    },
    {
        "school": "EAGLEVIEW MIDDLE SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001402",
    },
    {
        "school": "LIBERTY HIGH SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001429",
    },
    {
        "school": "PIONEER ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001430",
    },
    {
        "school": "TIMBERVIEW MIDDLE SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001462",
    },
    {
        "school": "EXPLORER ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001496",
    },
    {
        "school": "THE CLASSICAL ACADEMY CHARTER",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001592",
    },
    {
        "school": "MOUNTAIN RIDGE MIDDLE SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001593",
    },
    {
        "school": "ACADEMY ENDEAVOUR ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001643",
    },
    {
        "school": "ACADEMY INTERNATIONAL ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001644",
    },
    {
        "school": "PINE CREEK HIGH SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192001645",
    },
    {
        "school": "CALHAN ELEMENTARY SCHOOL",
        "district": "Calhan District No. RJ1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80273000167",
    },
    {
        "school": "Calhan Secondary School",
        "district": "Calhan District No. RJ1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80273000168",
    },
    {
        "school": "CALHAN MIDDLE SCHOOL",
        "district": "Calhan District No. RJ1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80273000510",
    },
    {
        "school": "CHEYENNE MOUNTAIN JUNIOR HIGH SCHOOL",
        "district": "Cheyenne Mountain School District No. 12 in the county of E",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80294000209",
    },
    {
        "school": "SKYWAY PARK ELEMENTARY SCHOOL",
        "district": "Cheyenne Mountain School District No. 12 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80294000210",
    },
    {
        "school": "CHEYENNE MOUNTAIN HIGH SCHOOL",
        "district": "Cheyenne Mountain School District No. 12 in the county of E",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80294000211",
    },
    {
        "school": "BROADMOOR ELEMENTARY SCHOOL",
        "district": "Cheyenne Mountain School District No. 12 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80294000212",
    },
    {
        "school": "CANON ELEMENTARY SCHOOL",
        "district": "Cheyenne Mountain School District No. 12 in the county of E",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80294000213",
    },
    {
        "school": "THE VANGUARD SCHOOL (ELEMENTARY)",
        "district": "Cheyenne Mountain School District No. 12 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80294001326",
    },
    {
        "school": "CHEYENNE MOUNTAIN ELEMENTARY SCHOOL",
        "district": "Cheyenne Mountain School District No. 12 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80294001391",
    },
    {
        "school": "PINON VALLEY ELEMENTARY SCHOOL",
        "district": "Cheyenne Mountain School District No. 12 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80294001535",
    },
    {
        "school": "GOLD CAMP ELEMENTARY SCHOOL",
        "district": "Cheyenne Mountain School District No. 12 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80294001591",
    },
    {
        "school": "AUDUBON ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000222",
    },
    {
        "school": "BRISTOL ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000224",
    },
    {
        "school": "BUENA VISTA ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000225",
    },
    {
        "school": "CARVER ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000226",
    },
    {
        "school": "COLUMBIA ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000227",
    },
    {
        "school": "CORONADO HIGH SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000228",
    },
    {
        "school": "EDISON ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000231",
    },
    {
        "school": "NIKOLA TESLA EDUCATION OPPORTUNITY CENTER",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80306000232",
    },
    {
        "school": "SABIN MIDDLE SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000234",
    },
    {
        "school": "FREMONT ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000236",
    },
    {
        "school": "GRANT ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000238",
    },
    {
        "school": "ADAMS ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000239",
    },
    {
        "school": "HENRY ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000240",
    },
    {
        "school": "HOLMES MIDDLE SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000241",
    },
    {
        "school": "MANN MIDDLE SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000242",
    },
    {
        "school": "HOWBERT ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000243",
    },
    {
        "school": "JACKSON ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000245",
    },
    {
        "school": "KELLER ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000247",
    },
    {
        "school": "MADISON ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000251",
    },
    {
        "school": "TWAIN ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000252",
    },
    {
        "school": "MIDLAND ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000253",
    },
    {
        "school": "MITCHELL HIGH SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000254",
    },
    {
        "school": "MONROE ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000255",
    },
    {
        "school": "NORTH MIDDLE SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000256",
    },
    {
        "school": "PALMER HIGH SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000257",
    },
    {
        "school": "PENROSE ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000258",
    },
    {
        "school": "QUEEN PALMER ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000260",
    },
    {
        "school": "ROOSEVELT CHARTER ACADEMY",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000262",
    },
    {
        "school": "RUSSELL MIDDLE SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000263",
    },
    {
        "school": "STEELE ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000265",
    },
    {
        "school": "STRATTON ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000266",
    },
    {
        "school": "TAYLOR ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000267",
    },
    {
        "school": "DOHERTY HIGH SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000268",
    },
    {
        "school": "WEST MIDDLE SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000272",
    },
    {
        "school": "ROGERS ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000274",
    },
    {
        "school": "WILSON ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306000275",
    },
    {
        "school": "RUDY ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306001274",
    },
    {
        "school": "COMMUNITY PREP CHARTER SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80306001299",
    },
    {
        "school": "GLOBE CHARTER SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306001318",
    },
    {
        "school": "KING ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306001379",
    },
    {
        "school": "CHIPETA ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306001435",
    },
    {
        "school": "MARTINEZ ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306001470",
    },
    {
        "school": "CIVA CHARTER ACADEMY",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306001589",
    },
    {
        "school": "SCOTT ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306001641",
    },
    {
        "school": "TRAILBLAZER ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306001642",
    },
    {
        "school": "JENKINS MIDDLE SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306001683",
    },
    {
        "school": "EDISON ELEMENTARY SCHOOL",
        "district": "Edison Joint District No. 54 of the counties of El Paso and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80363000478",
    },
    {
        "school": "EDISON JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Edison Joint District No. 54 of the counties of El Paso and",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80363001278",
    },
    {
        "school": "ELLICOTT ELEMENTARY SCHOOL",
        "district": "Ellicott School District No. 22 in the county of El Paso a",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80375000484",
    },
    {
        "school": "ELLICOTT SENIOR HIGH SCHOOL",
        "district": "Ellicott School District No. 22 in the county of El Paso a",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80375000485",
    },
    {
        "school": "ELLICOTT MIDDLE SCHOOL",
        "district": "Ellicott School District No. 22 in the county of El Paso a",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80375001735",
    },
    {
        "school": "EVANS INTERNATIONAL ELEMENTARY SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387000504",
    },
    {
        "school": "FALCON ELEMENTARY SCHOOL OF TECHNOLOGY",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387000505",
    },
    {
        "school": "FALCON MIDDLE SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387000506",
    },
    {
        "school": "FALCON HIGH SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387000507",
    },
    {
        "school": "HORIZON MIDDLE SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387001393",
    },
    {
        "school": "STETSON ELEMENTARY SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387001438",
    },
    {
        "school": "REMINGTON ELEMENTARY SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387001537",
    },
    {
        "school": "SAND CREEK HIGH SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387001594",
    },
    {
        "school": "WOODMEN HILLS ELEMENTARY SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387001686",
    },
    {
        "school": "SKYVIEW MIDDLE SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387001799",
    },
    {
        "school": "WELTE EDUCATION CENTER",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80408000096",
    },
    {
        "school": "ABRAMS ELEMENTARY SCHOOL",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80408000560",
    },
    {
        "school": "CARSON MIDDLE SCHOOL",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80408000561",
    },
    {
        "school": "FOUNTAIN-FORT CARSON HIGH SCHOOL",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80408000562",
    },
    {
        "school": "FOUNTAIN MIDDLE SCHOOL",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80408000563",
    },
    {
        "school": "MESA ELEMENTARY SCHOOL",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80408000564",
    },
    {
        "school": "PATRIOT ELEMENTARY SCHOOL",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80408000565",
    },
    {
        "school": "ARAGON ELEMENTARY SCHOOL",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80408000566",
    },
    {
        "school": "MOUNTAINSIDE ELEMENTARY SCHOOL",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80408000856",
    },
    {
        "school": "JORDAHL ELEMENTARY SCHOOL",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80408001481",
    },
    {
        "school": "HANOVER JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Hanover School District No. 28 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80450000661",
    },
    {
        "school": "CARMEL MIDDLE SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453000662",
    },
    {
        "school": "CENTENNIAL ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453000663",
    },
    {
        "school": "GIBERSON ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453000665",
    },
    {
        "school": "FOX MEADOW MIDDLE SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453000666",
    },
    {
        "school": "HARRISON HIGH SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453000667",
    },
    {
        "school": "MONTEREY ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453000668",
    },
    {
        "school": "PANORAMA MIDDLE SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453000669",
    },
    {
        "school": "PIKES PEAK ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453000670",
    },
    {
        "school": "STRATMOOR HILLS ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453000671",
    },
    {
        "school": "STRATTON MEADOWS ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453000672",
    },
    {
        "school": "BRICKER ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001314",
    },
    {
        "school": "OAK CREEK ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001369",
    },
    {
        "school": "WILDFLOWER ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001370",
    },
    {
        "school": "SIERRA HIGH SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001382",
    },
    {
        "school": "TURMAN ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001443",
    },
    {
        "school": "OTERO ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001484",
    },
    {
        "school": "SAND CREEK INTERNATIONAL ELEMENTARY SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001533",
    },
    {
        "school": "JAMES IRWIN CHARTER HIGH SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453001781",
    },
    {
        "school": "MANITOU SPRINGS MIDDLE SCHOOL",
        "district": "Manitou Springs School District No. 14 in the county of El",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80549000945",
    },
    {
        "school": "MANITOU SPRINGS HIGH SCHOOL",
        "district": "Manitou Springs School District No. 14 in the county of El",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80549000946",
    },
    {
        "school": "MANITOU SPRINGS ELEMENTARY SCHOOL",
        "district": "Manitou Springs School District No. 14 in the county of El",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80549000947",
    },
    {
        "school": "UTE PASS ELEMENTARY SCHOOL",
        "district": "Manitou Springs School District No. 14 in the county of El",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80549000948",
    },
    {
        "school": "MIAMI/YODER ELEMENTARY SCHOOL",
        "district": "Miami-Yoder Joint District No. 60 of the counties of El Pas",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80567000971",
    },
    {
        "school": "MIAMI-YODER MIDDLE/HIGH SCHOOL",
        "district": "Miami-Yoder Joint District No. 60 of the counties of El Pas",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80567000972",
    },
    {
        "school": "LEWIS-PALMER MIDDLE SCHOOL",
        "district": "Lewis-Palmer Consolidated School District No. 38 in the co",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80582001002",
    },
    {
        "school": "LEWIS-PALMER HIGH SCHOOL",
        "district": "Lewis-Palmer Consolidated School District No. 38 in the co",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80582001003",
    },
    {
        "school": "LEWIS-PALMER ELEMENTARY SCHOOL",
        "district": "Lewis-Palmer Consolidated School District No. 38 in the co",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80582001004",
    },
    {
        "school": "BEAR CREEK ELEMENTARY SCHOOL",
        "district": "Lewis-Palmer Consolidated School District No. 38 in the co",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80582001371",
    },
    {
        "school": "PALMER LAKE ELEMENTARY SCHOOL",
        "district": "Lewis-Palmer Consolidated School District No. 38 in the co",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80582001397",
    },
    {
        "school": "RAY E KILMER ELEMENTARY SCHOOL",
        "district": "Lewis-Palmer Consolidated School District No. 38 in the co",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80582001489",
    },
    {
        "school": "MONUMENT CHARTER ACADEMY",
        "district": "Lewis-Palmer Consolidated School District No. 38 in the co",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80582001536",
    },
    {
        "school": "PRAIRIE WINDS ELEMENTARY SCHOOL",
        "district": "Lewis-Palmer Consolidated School District No. 38 in the co",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80582001810",
    },
    {
        "school": "PEYTON ELEMENTARY SCHOOL",
        "district": "Peyton School District No. 23 in the county of El Paso and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80606001024",
    },
    {
        "school": "PEYTON SENIOR HIGH SCHOOL",
        "district": "Peyton School District No. 23 in the county of El Paso and",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80606001025",
    },
    {
        "school": "PEYTON JUNIOR HIGH SCHOOL",
        "district": "Peyton School District No. 23 in the county of El Paso and",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80606001399",
    },
    {
        "school": "DISCOVERY HIGH SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80648000051",
    },
    {
        "school": "TALBOTT STEAM INNOVATION SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001119",
    },
    {
        "school": "JANITELL JUNIOR HIGH SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001120",
    },
    {
        "school": "MARTIN LUTHER KING JR ELEMENTARY SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001121",
    },
    {
        "school": "PINELLO ELEMENTARY SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001123",
    },
    {
        "school": "VENETUCCI ELEMENTARY SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001124",
    },
    {
        "school": "SPROUL JUNIOR HIGH SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001125",
    },
    {
        "school": "WATSON JUNIOR HIGH SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001126",
    },
    {
        "school": "WEBSTER ELEMENTARY SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001127",
    },
    {
        "school": "Widefield Elementary School of the Arts",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001128",
    },
    {
        "school": "WIDEFIELD HIGH SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001129",
    },
    {
        "school": "WIDEFIELD DISTRICT 3 PRESCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001359",
    },
    {
        "school": "SUNRISE ELEMENTARY SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001418",
    },
    {
        "school": "FRENCH ELEMENTARY SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001458",
    },
    {
        "school": "MESA RIDGE HIGH SCHOOL",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648001588",
    },
    {
        "school": "STARS EARLY LEARNING CENTER",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195001947",
    },
    {
        "school": "JOHN W THIMMIG ELEMENTARY SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258001822",
    },
    {
        "school": "BELLE CREEK CHARTER SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258001948",
    },
    {
        "school": "MARY E PENNOCK ELEMENTARY SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258001949",
    },
    {
        "school": "SECOND CREEK ELEMENTARY SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258001950",
    },
    {
        "school": "MAPLETON EXPEDITIONARY SCHOOL OF THE ARTS",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555001857",
    },
    {
        "school": "MAPLETON EARLY COLLEGE HIGH SCHOOL",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555001858",
    },
    {
        "school": "GLOBAL LEADERSHIP ACADEMY",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555001860",
    },
    {
        "school": "ACADEMY HIGH SCHOOL",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555001872",
    },
    {
        "school": "ROCKY TOP MIDDLE SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001726",
    },
    {
        "school": "PRAIRIE HILLS ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001945",
    },
    {
        "school": "HIDDEN LAKE HIGH SCHOOL",
        "district": "Westminster Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CO",
        "nces_id": "80723001877",
    },
    {
        "school": "MURPHY CREEK K-8 SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001881",
    },
    {
        "school": "CANYON CREEK ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001831",
    },
    {
        "school": "SKY VISTA MIDDLE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001878",
    },
    {
        "school": "ASPEN CROSSING ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001879",
    },
    {
        "school": "RED HAWK RIDGE ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001880",
    },
    {
        "school": "CHEROKEE TRAIL HIGH SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001951",
    },
    {
        "school": "MERIDIAN ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001733",
    },
    {
        "school": "DSST: Montview High School",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001833",
    },
    {
        "school": "HIGHLINE ACADEMY SOUTHEAST",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001835",
    },
    {
        "school": "OMAR D BLAIR CHARTER SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001838",
    },
    {
        "school": "EARLY COLLEGE OF DENVER",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001839",
    },
    {
        "school": "COLORADO HIGH SCHOOL CHARTER",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336001862",
    },
    {
        "school": "LENA ARCHULETA ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001864",
    },
    {
        "school": "KIPP SUNSHINE PEAK ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001865",
    },
    {
        "school": "LOWRY ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001867",
    },
    {
        "school": "BRUCE RANDOLPH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001869",
    },
    {
        "school": "ACADEMY OF URBAN LEARNING",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336001894",
    },
    {
        "school": "DENVER ONLINE HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001955",
    },
    {
        "school": "WESTERLY CREEK ELEMENTARY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001957",
    },
    {
        "school": "SOARING HAWK ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001840",
    },
    {
        "school": "CHALLENGE TO EXCELLENCE CHARTER SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001874",
    },
    {
        "school": "FRONTIER VALLEY ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001875",
    },
    {
        "school": "AMERICAN ACADEMY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001896",
    },
    {
        "school": "COPPER MESA ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001897",
    },
    {
        "school": "REDSTONE ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001900",
    },
    {
        "school": "FLAGSTONE ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001959",
    },
    {
        "school": "LEGACY POINT ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001960",
    },
    {
        "school": "ROCK CANYON HIGH SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001961",
    },
    {
        "school": "ROCKY HEIGHTS MIDDLE SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001962",
    },
    {
        "school": "TIMBER TRAIL ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001963",
    },
    {
        "school": "COLORADO SPRINGS CHARTER ACADEMY",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002001912",
    },
    {
        "school": "ROSS MONTESSORI SCHOOL",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002001913",
    },
    {
        "school": "BRADY EXPLORATION SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80480001907",
    },
    {
        "school": "BLUE HERON ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001919",
    },
    {
        "school": "FREE HORIZON MONTESSORI",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001920",
    },
    {
        "school": "JEFFERSON ACADEMY",
        "district": "Jefferson County School District No. R-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001921",
    },
    {
        "school": "JEFFERSON ACADEMY HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001922",
    },
    {
        "school": "FALCON BLUFFS MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001970",
    },
    {
        "school": "CLEAR CREEK HIGH SCHOOL",
        "district": "Clear Creek School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80300000217",
    },
    {
        "school": "CARLSON ELEMENTARY SCHOOL",
        "district": "Clear Creek School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80300000218",
    },
    {
        "school": "KING-MURPHY ELEMENTARY SCHOOL",
        "district": "Clear Creek School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80300001332",
    },
    {
        "school": "CLEAR CREEK MIDDLE SCHOOL",
        "district": "Clear Creek School District No. Re-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80300006157",
    },
    {
        "school": "AGATE ELEMENTARY SCHOOL",
        "district": "Agate School District No. 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80198000020",
    },
    {
        "school": "AGATE JUNIOR SENIOR HIGH SCHOOL",
        "district": "Agate School District No. 300",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80198000021",
    },
    {
        "school": "ELBERT ELEMENTARY SCHOOL",
        "district": "Elbert School District No. 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80369000480",
    },
    {
        "school": "ELBERT JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Elbert School District No. 200",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80369000481",
    },
    {
        "school": "ELIZABETH RUNNING CREEK PRESCHOOL",
        "district": "ELIZABETH SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80372000048",
    },
    {
        "school": "ELIZABETH MIDDLE SCHOOL",
        "district": "ELIZABETH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80372000482",
    },
    {
        "school": "ELIZABETH HIGH SCHOOL",
        "district": "ELIZABETH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80372000483",
    },
    {
        "school": "RUNNING CREEK ELEMENTARY SCHOOL",
        "district": "ELIZABETH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80372001479",
    },
    {
        "school": "SINGING HILLS ELEMENTARY SCHOOL",
        "district": "ELIZABETH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80372001532",
    },
    {
        "school": "LEGACY ACADEMY",
        "district": "ELIZABETH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80372001586",
    },
    {
        "school": "FRONTIER HIGH SCHOOL",
        "district": "ELIZABETH SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80372001775",
    },
    {
        "school": "SINGING HILLS PRESCHOOL",
        "district": "ELIZABETH SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80372001798",
    },
    {
        "school": "KIOWA ELEMENTARY SCHOOL",
        "district": "School District No. C-2 in the county of Elbert and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80501000824",
    },
    {
        "school": "KIOWA HIGH SCHOOL",
        "district": "School District No. C-2 in the county of Elbert and State of",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80501000825",
    },
    {
        "school": "KIOWA MIDDLE SCHOOL",
        "district": "School District No. C-2 in the county of Elbert and State of",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80501001587",
    },
    {
        "school": "SIMLA ELEMENTARY SCHOOL",
        "district": "Big Sandy School District No. 100J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80660001138",
    },
    {
        "school": "SIMLA HIGH SCHOOL",
        "district": "Big Sandy School District No. 100J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80660001139",
    },
    {
        "school": "SIMLA JUNIOR HIGH SCHOOL",
        "district": "Big Sandy School District No. 100J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80660001140",
    },
    {
        "school": "GILPIN COUNTY ELEMENTARY SCHOOL",
        "district": "Gilpin County School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80423000581",
    },
    {
        "school": "GILPIN COUNTY UNDIVIDED HIGH SCHOOL",
        "district": "Gilpin County School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80423001298",
    },
    {
        "school": "DEER CREEK ELEMENTARY SCHOOL",
        "district": "Platte Canyon School District No. 1 of  the county of Park",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80237000086",
    },
    {
        "school": "PLATTE CANYON HIGH SCHOOL",
        "district": "Platte Canyon School District No. 1 of  the county of Park",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80237000087",
    },
    {
        "school": "FITZSIMMONS MIDDLE SCHOOL",
        "district": "Platte Canyon School District No. 1 of  the county of Park",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80237001325",
    },
    {
        "school": "LAKE GEORGE CHARTER SCHOOL",
        "district": "Park County School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80384000501",
    },
    {
        "school": "EDITH TETER ELEMENTARY SCHOOL",
        "district": "Park County School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80384000502",
    },
    {
        "school": "SOUTH PARK HIGH SCHOOL",
        "district": "Park County School District No. Re-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80384000503",
    },
    {
        "school": "SOUTH PARK MIDDLE SCHOOL",
        "district": "Park County School District No. Re-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80384000622",
    },
    {
        "school": "GUFFEY CHARTER SCHOOL",
        "district": "Park County School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80384001695",
    },
    {
        "school": "ADAMS CITY MIDDLE SCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195000009",
    },
    {
        "school": "ADAMS CITY HIGH SCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195000010",
    },
    {
        "school": "ALSUP ELEMENTARY SCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195000011",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195000012",
    },
    {
        "school": "DUPONT ELEMENTARY SCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195000013",
    },
    {
        "school": "KEARNEY MIDDLE SCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195000015",
    },
    {
        "school": "KEMP ELEMENTARY SCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195000016",
    },
    {
        "school": "MONACO ELEMENTARY SCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195000017",
    },
    {
        "school": "HANSON ELEMENTARY SCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195000018",
    },
    {
        "school": "ROSE HILL ELEMENTARY SCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195000019",
    },
    {
        "school": "MILDRED L SANVILLE PRESCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80195000404",
    },
    {
        "school": "LESTER R ARNOLD HIGH SCHOOL",
        "district": "School District N. 14 in the county of Adams & State of Colo",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80195001307",
    },
    {
        "school": "ALTURA ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000052",
    },
    {
        "school": "CLYDE MILLER K-8",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000057",
    },
    {
        "school": "CRAWFORD ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000058",
    },
    {
        "school": "MONTVIEW MATH & HEALTH SCIENCES ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000072",
    },
    {
        "school": "NORTH MIDDLE SCHOOL HEALTH SCIENCES AND TECHNOLOGY",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000074",
    },
    {
        "school": "PARIS ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000075",
    },
    {
        "school": "PARK LANE ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000076",
    },
    {
        "school": "SABLE ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000077",
    },
    {
        "school": "LAREDO CHILD DEVELOPMENT CENTER",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001627",
    },
    {
        "school": "OPTIONS SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001789",
    },
    {
        "school": "BENNETT ELEMENTARY SCHOOL",
        "district": "Bennett School District No. 29J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80243000091",
    },
    {
        "school": "BENNETT HIGH SCHOOL",
        "district": "Bennett School District No. 29J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80243000092",
    },
    {
        "school": "BENNETT MIDDLE SCHOOL",
        "district": "Bennett School District No. 29J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80243000093",
    },
    {
        "school": "BENNETT PRESCHOOL",
        "district": "Bennett School District No. 29J",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80243001751",
    },
    {
        "school": "BRIGHTON HIGH SCHOOL",
        "district": "School District 27J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258000144",
    },
    {
        "school": "HENDERSON ELEMENTARY SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258000146",
    },
    {
        "school": "NORTH ELEMENTARY SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258000148",
    },
    {
        "school": "NORTHEAST ELEMENTARY SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258000149",
    },
    {
        "school": "SOUTH ELEMENTARY SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258000150",
    },
    {
        "school": "SOUTHEAST ELEMENTARY SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258000151",
    },
    {
        "school": "VIKAN MIDDLE SCHOOL",
        "district": "School District 27J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258000152",
    },
    {
        "school": "Innovations & Options",
        "district": "School District 27J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80258000729",
    },
    {
        "school": "OVERLAND TRAIL MIDDLE SCHOOL",
        "district": "School District 27J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258001377",
    },
    {
        "school": "BROMLEY EAST CHARTER SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258001729",
    },
    {
        "school": "VALLEY VIEW K-8",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555000959",
    },
    {
        "school": "STRASBURG ELEMENTARY SCHOOL",
        "district": "Strasburg School District 31J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80675001159",
    },
    {
        "school": "HEMPHILL MIDDLE SCHOOL",
        "district": "Strasburg School District 31J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80675001160",
    },
    {
        "school": "STRASBURG HIGH SCHOOL",
        "district": "Strasburg School District 31J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80675001161",
    },
    {
        "school": "PRAIRIE CREEK HIGH SCHOOL",
        "district": "Strasburg School District 31J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80675001669",
    },
    {
        "school": "STARGATE CHARTER SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690000728",
    },
    {
        "school": "VANTAGE POINT",
        "district": "Adams 12 Five Star Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80690001172",
    },
    {
        "school": "CORONADO HILLS ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001174",
    },
    {
        "school": "TARVER ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001175",
    },
    {
        "school": "FEDERAL HEIGHTS ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001176",
    },
    {
        "school": "HILLCREST ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001177",
    },
    {
        "school": "HULSTROM OPTIONS K-8 SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001178",
    },
    {
        "school": "SILVER HILLS MIDDLE SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001179",
    },
    {
        "school": "MALLEY DRIVE ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001181",
    },
    {
        "school": "McElwain Elementary School",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001182",
    },
    {
        "school": "THE INTERNATIONAL SCHOOL AT THORNTON MIDDLE",
        "district": "Adams 12 Five Star Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001183",
    },
    {
        "school": "NORTH MOR ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001184",
    },
    {
        "school": "NORTH STAR ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001185",
    },
    {
        "school": "SHADOW RIDGE MIDDLE SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001186",
    },
    {
        "school": "NORTHGLENN MIDDLE SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001187",
    },
    {
        "school": "NORTHGLENN HIGH SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001188",
    },
    {
        "school": "STUKEY ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001190",
    },
    {
        "school": "THORNTON ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001191",
    },
    {
        "school": "THORNTON HIGH SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001192",
    },
    {
        "school": "WESTVIEW ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001195",
    },
    {
        "school": "WOODGLEN ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001196",
    },
    {
        "school": "CHERRY DRIVE ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001290",
    },
    {
        "school": "COTTON CREEK ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001305",
    },
    {
        "school": "LEROY DRIVE ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001306",
    },
    {
        "school": "SKYVIEW ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001401",
    },
    {
        "school": "HUNTERS GLEN ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001419",
    },
    {
        "school": "ROCKY MOUNTAIN ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001460",
    },
    {
        "school": "RIVERDALE ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001461",
    },
    {
        "school": "HORIZON HIGH SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001491",
    },
    {
        "school": "ARAPAHOE RIDGE ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001619",
    },
    {
        "school": "CENTURY MIDDLE SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001620",
    },
    {
        "school": "EAGLEVIEW ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001622",
    },
    {
        "school": "GLACIER PEAK ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001709",
    },
    {
        "school": "Metropolitan Arts Academy",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001232",
    },
    {
        "school": "FAIRVIEW ELEMENTARY SCHOOL",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001235",
    },
    {
        "school": "FRANCIS M. DAY ELEMENTARY SCHOOL",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001236",
    },
    {
        "school": "HARRIS PARK ELEMENTARY SCHOOL",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001238",
    },
    {
        "school": "M. SCOTT CARPENTER MIDDLE SCHOOL",
        "district": "Westminster Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001241",
    },
    {
        "school": "MESA ELEMENTARY SCHOOL",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001242",
    },
    {
        "school": "SHAW HEIGHTS MIDDLE SCHOOL",
        "district": "Westminster Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001244",
    },
    {
        "school": "SHERRELWOOD ELEMENTARY SCHOOL",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001246",
    },
    {
        "school": "SKYLINE VISTA ELEMENTARY SCHOOL",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001247",
    },
    {
        "school": "SUNSET RIDGE ELEMENTARY SCHOOL",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001248",
    },
    {
        "school": "TENNYSON KNOLLS ELEMENTARY SCHOOL",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001249",
    },
    {
        "school": "WESTMINSTER HIGH SCHOOL",
        "district": "Westminster Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001254",
    },
    {
        "school": "JOHN E. FLYNN A MARZANO ACADEMY",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723001363",
    },
    {
        "school": "GREGORY HILL PRESCHOOL",
        "district": "Westminster Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723006175",
    },
    {
        "school": "AURORA HILLS MIDDLE SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000054",
    },
    {
        "school": "BOSTON K-8 SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000055",
    },
    {
        "school": "AURORA CENTRAL HIGH SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000056",
    },
    {
        "school": "DARTMOUTH ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000059",
    },
    {
        "school": "EAST MIDDLE SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000060",
    },
    {
        "school": "ELKHART ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000061",
    },
    {
        "school": "FULTON ACADEMY OF EXCELLENCE",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000062",
    },
    {
        "school": "GATEWAY HIGH SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000063",
    },
    {
        "school": "HINKLEY HIGH SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000064",
    },
    {
        "school": "JEWELL ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000066",
    },
    {
        "school": "KENTON ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000067",
    },
    {
        "school": "LANSING ELEMENTARY COMMUNITY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000068",
    },
    {
        "school": "LAREDO ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000069",
    },
    {
        "school": "LYN KNOLL ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000070",
    },
    {
        "school": "MRACHEK MIDDLE SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000073",
    },
    {
        "school": "SIXTH AVENUE ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000078",
    },
    {
        "school": "SOUTH MIDDLE SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000079",
    },
    {
        "school": "VAUGHN ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000080",
    },
    {
        "school": "VIRGINIA COURT ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000081",
    },
    {
        "school": "AURORA WEST COLLEGE PREPARATORY ACADEMY",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000082",
    },
    {
        "school": "WHEELING ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000083",
    },
    {
        "school": "WILLIAM SMITH HIGH SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000084",
    },
    {
        "school": "YALE ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234000085",
    },
    {
        "school": "VASSAR ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001294",
    },
    {
        "school": "DALTON ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001295",
    },
    {
        "school": "ARKANSAS ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001296",
    },
    {
        "school": "COLUMBIA MIDDLE SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001322",
    },
    {
        "school": "IOWA ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001323",
    },
    {
        "school": "TOLLGATE ELEMENTARY SCHOOL OF EXPEDITIONARY LEARNI",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001324",
    },
    {
        "school": "CENTURY ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001388",
    },
    {
        "school": "RANGEVIEW HIGH SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001389",
    },
    {
        "school": "SIDE CREEK ELEMENTARY SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001432",
    },
    {
        "school": "AURORA QUEST K-8",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001674",
    },
    {
        "school": "AURORA ACADEMY CHARTER SCHOOL",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234001759",
    },
    {
        "school": "BYERS ELEMENTARY SCHOOL",
        "district": "Byers School District No. 32J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80270000163",
    },
    {
        "school": "BYERS JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Byers School District No. 32J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80270000164",
    },
    {
        "school": "THUNDER RIDGE MIDDLE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000034",
    },
    {
        "school": "ARROWHEAD ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000183",
    },
    {
        "school": "BELLEVIEW ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000184",
    },
    {
        "school": "CAMPUS MIDDLE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000185",
    },
    {
        "school": "CHERRY CREEK HIGH SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000186",
    },
    {
        "school": "CHERRY HILLS VILLAGE ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000187",
    },
    {
        "school": "COTTONWOOD CREEK ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000188",
    },
    {
        "school": "DRY CREEK ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000190",
    },
    {
        "school": "EASTRIDGE COMMUNITY ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000191",
    },
    {
        "school": "GREENWOOD ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000192",
    },
    {
        "school": "HERITAGE ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000193",
    },
    {
        "school": "HOLLY HILLS ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000194",
    },
    {
        "school": "HOMESTEAD ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000195",
    },
    {
        "school": "INDEPENDENCE ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000196",
    },
    {
        "school": "LAREDO MIDDLE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000197",
    },
    {
        "school": "MISSION VIEJO ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000198",
    },
    {
        "school": "POLTON COMMUNITY ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000199",
    },
    {
        "school": "PONDEROSA ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000200",
    },
    {
        "school": "PRAIRIE MIDDLE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000201",
    },
    {
        "school": "SAGEBRUSH ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000202",
    },
    {
        "school": "SMOKY HILL HIGH SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000203",
    },
    {
        "school": "VILLAGE EAST COMMUNITY ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000204",
    },
    {
        "school": "WALNUT HILLS COMMUNITY ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000206",
    },
    {
        "school": "WEST MIDDLE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000207",
    },
    {
        "school": "WILLOW CREEK ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000208",
    },
    {
        "school": "CHALLENGE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291000763",
    },
    {
        "school": "CHERRY CREEK CHARTER ACADEMY",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001152",
    },
    {
        "school": "OVERLAND HIGH SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001272",
    },
    {
        "school": "HIGH PLAINS ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001273",
    },
    {
        "school": "CIMARRON ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001297",
    },
    {
        "school": "HORIZON MIDDLE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001328",
    },
    {
        "school": "MEADOW POINT ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001329",
    },
    {
        "school": "TRAILS WEST ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001330",
    },
    {
        "school": "SUNRISE ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001378",
    },
    {
        "school": "INDIAN RIDGE ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001390",
    },
    {
        "school": "CREEKSIDE ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001404",
    },
    {
        "school": "TIMBERLINE ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001405",
    },
    {
        "school": "SUMMIT ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001468",
    },
    {
        "school": "ROLLING HILLS ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001514",
    },
    {
        "school": "GRANDVIEW HIGH SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001625",
    },
    {
        "school": "ANTELOPE RIDGE ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001670",
    },
    {
        "school": "DAKOTA VALLEY ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001671",
    },
    {
        "school": "FALCON CREEK MIDDLE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001672",
    },
    {
        "school": "FOX HOLLOW ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001710",
    },
    {
        "school": "LIBERTY MIDDLE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291001711",
    },
    {
        "school": "EAGLECREST HIGH SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006156",
    },
    {
        "school": "HIGHLINE COMMUNITY ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006182",
    },
    {
        "school": "PEAKVIEW ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006183",
    },
    {
        "school": "DEER TRAIL ELEMENTARY SCHOOL",
        "district": "Deer Trail School District No. 26J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80327000287",
    },
    {
        "school": "DEER TRAIL JUNIOR-SENIOR HIGH SCHOOL",
        "district": "Deer Trail School District No. 26J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80327000288",
    },
    {
        "school": "RIDGE VIEW ACADEMY CHARTER SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336001724",
    },
    {
        "school": "ENGLEWOOD EARLY CHILDHOOD EDUCATION CENTER AT MADD",
        "district": "Englewood School District No. 1 in the county of Arapahoe",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80378000029",
    },
    {
        "school": "CHARLES HAY WORLD SCHOOL",
        "district": "Englewood School District No. 1 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80378000486",
    },
    {
        "school": "CHERRELYN ELEMENTARY SCHOOL",
        "district": "Englewood School District No. 1 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80378000488",
    },
    {
        "school": "CLAYTON ELEMENTARY SCHOOL",
        "district": "Englewood School District No. 1 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80378000489",
    },
    {
        "school": "ENGLEWOOD HIGH SCHOOL",
        "district": "Englewood School District No. 1 in the county of Arapahoe",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80378000491",
    },
    {
        "school": "WM E BISHOP ELEMENTARY SCHOOL",
        "district": "Englewood School District No. 1 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80378000497",
    },
    {
        "school": "COLORADO'S FINEST HIGH SCHOOL OF CHOICE",
        "district": "Englewood School District No. 1 in the county of Arapahoe",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80378001310",
    },
    {
        "school": "ENGLEWOOD LEADERSHIP ACADEMY",
        "district": "Englewood School District No. 1 in the county of Arapahoe",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80378001772",
    },
    {
        "school": "VILLAGE AT NORTH",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000764",
    },
    {
        "school": "ARAPAHOE HIGH SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000873",
    },
    {
        "school": "CENTENNIAL ACADEMY OF FINE ARTS EDUCATION",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000874",
    },
    {
        "school": "EAST ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000875",
    },
    {
        "school": "EUCLID MIDDLE SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000876",
    },
    {
        "school": "FIELD ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000877",
    },
    {
        "school": "FRANKLIN ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000878",
    },
    {
        "school": "GODDARD MIDDLE SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000879",
    },
    {
        "school": "HERITAGE HIGH SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000881",
    },
    {
        "school": "HIGHLAND ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000882",
    },
    {
        "school": "HOPKINS ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000883",
    },
    {
        "school": "LITTLETON HIGH SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000884",
    },
    {
        "school": "NEWTON MIDDLE SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000885",
    },
    {
        "school": "PEABODY ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000887",
    },
    {
        "school": "RUNYON ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000888",
    },
    {
        "school": "SANDBURG ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000889",
    },
    {
        "school": "MOODY ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000890",
    },
    {
        "school": "TWAIN ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000891",
    },
    {
        "school": "WILDER ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531000893",
    },
    {
        "school": "LOIS LENSKI ELEMENTARY SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531001300",
    },
    {
        "school": "JOHN WESLEY POWELL MIDDLE SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531001351",
    },
    {
        "school": "LITTLETON ACADEMY",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531001515",
    },
    {
        "school": "LITTLETON PREP CHARTER SCHOOL",
        "district": "Littleton School District No. 6 in the county of Arapahoe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80531001626",
    },
    {
        "school": "ALICE TERRY ELEMENTARY SCHOOL",
        "district": "Sheridan School District No. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80654001132",
    },
    {
        "school": "SHERIDAN HIGH SCHOOL",
        "district": "Sheridan School District No. 2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80654001134",
    },
    {
        "school": "FORT LOGAN NORTHGATE",
        "district": "Sheridan School District No. 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80654001135",
    },
    {
        "school": "CENTENNIAL ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001173",
    },
    {
        "school": "WESTLAKE MIDDLE SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001194",
    },
    {
        "school": "MOUNTAIN VIEW ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001362",
    },
    {
        "school": "COYOTE RIDGE ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001668",
    },
    {
        "school": "LEGACY HIGH SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690001784",
    },
    {
        "school": "ROCKY MOUNTAIN SCHOOL OF EXPEDITIONARY LEARNING",
        "district": "DENVER 1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80000400709",
    },
    {
        "school": "ABRAHAM LINCOLN HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000305",
    },
    {
        "school": "JOHN H. AMESSE ELEMENTARY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000306",
    },
    {
        "school": "ASBURY ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000307",
    },
    {
        "school": "ASHLEY ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000309",
    },
    {
        "school": "BARNUM ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000311",
    },
    {
        "school": "BEACH COURT ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000313",
    },
    {
        "school": "BRADLEY INTERNATIONAL SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000317",
    },
    {
        "school": "BROMWELL ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000318",
    },
    {
        "school": "BROWN INTERNATIONAL ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000319",
    },
    {
        "school": "BRYANT WEBSTER DUAL LANGUAGE ECE-8 SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000320",
    },
    {
        "school": "CAREER EDUCATION CENTER EARLY COLLEGE",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CO",
        "nces_id": "80336000322",
    },
    {
        "school": "CARSON ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000323",
    },
    {
        "school": "CENTENNIAL A SCHOOL FOR EXPEDITIONARY LEARNING",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000324",
    },
    {
        "school": "CHELTENHAM ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000325",
    },
    {
        "school": "COLFAX ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000327",
    },
    {
        "school": "COLLEGE VIEW ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000328",
    },
    {
        "school": "COLUMBIAN ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000329",
    },
    {
        "school": "COLUMBINE ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000330",
    },
    {
        "school": "CORY ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000331",
    },
    {
        "school": "COWELL ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000332",
    },
    {
        "school": "DOULL ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000336",
    },
    {
        "school": "EAGLETON ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000337",
    },
    {
        "school": "EAST HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000338",
    },
    {
        "school": "EDISON ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000340",
    },
    {
        "school": "ELLIS ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000341",
    },
    {
        "school": "EMILY GRIFFITH HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336000345",
    },
    {
        "school": "FAIRVIEW ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000347",
    },
    {
        "school": "FORCE ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000349",
    },
    {
        "school": "GARDEN PLACE ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000351",
    },
    {
        "school": "GEORGE WASHINGTON HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000352",
    },
    {
        "school": "GODSMAN ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000354",
    },
    {
        "school": "GOLDRICK ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000355",
    },
    {
        "school": "GRANT BEACON MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000357",
    },
    {
        "school": "GUST ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000359",
    },
    {
        "school": "HAMILTON MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000361",
    },
    {
        "school": "INTERNATIONAL ACADEMY OF DENVER AT HARRINGTON",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000362",
    },
    {
        "school": "HILL CAMPUS OF ARTS AND SCIENCES",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000364",
    },
    {
        "school": "HOLM ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000365",
    },
    {
        "school": "JOHN F KENNEDY HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000367",
    },
    {
        "school": "JOHNSON ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000368",
    },
    {
        "school": "KAISER ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000369",
    },
    {
        "school": "KNAPP ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000371",
    },
    {
        "school": "HALLETT ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000372",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000375",
    },
    {
        "school": "MCKINLEY-THATCHER ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000377",
    },
    {
        "school": "MCMEEN ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000378",
    },
    {
        "school": "MERRILL MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000379",
    },
    {
        "school": "CONTEMPORARY LEARNING ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336000380",
    },
    {
        "school": "MONTCLAIR SCHOOL OF ACADEMICS AND ENRICHMENT",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000384",
    },
    {
        "school": "DORA MOORE ECE-8 SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000385",
    },
    {
        "school": "MOREY MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000386",
    },
    {
        "school": "MUNROE ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000387",
    },
    {
        "school": "NEWLON ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000388",
    },
    {
        "school": "NORTH HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000389",
    },
    {
        "school": "PALMER ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000390",
    },
    {
        "school": "PARK HILL SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000391",
    },
    {
        "school": "SABIN WORLD SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000398",
    },
    {
        "school": "SAMUELS ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000399",
    },
    {
        "school": "CHARLES M. SCHENCK (CMS) COMMUNITY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000400",
    },
    {
        "school": "SCHMITT ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000401",
    },
    {
        "school": "SKINNER MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000403",
    },
    {
        "school": "SMITH ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000407",
    },
    {
        "school": "SOUTH HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000408",
    },
    {
        "school": "STECK ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000410",
    },
    {
        "school": "STEDMAN ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000411",
    },
    {
        "school": "STEELE ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000412",
    },
    {
        "school": "SWANSEA ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000414",
    },
    {
        "school": "TELLER ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000415",
    },
    {
        "school": "THOMAS JEFFERSON HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000417",
    },
    {
        "school": "TRAYLOR ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000418",
    },
    {
        "school": "UNIVERSITY PARK ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000419",
    },
    {
        "school": "VALDEZ ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000420",
    },
    {
        "school": "VALVERDE ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000421",
    },
    {
        "school": "CASTRO ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000424",
    },
    {
        "school": "WHITTIER ECE-8 SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336000426",
    },
    {
        "school": "MCGLONE ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001276",
    },
    {
        "school": "MARRAMA ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001380",
    },
    {
        "school": "DR. MARTIN LUTHER KING JR. EARLY COLLEGE",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001406",
    },
    {
        "school": "DENISON MONTESSORI SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001522",
    },
    {
        "school": "SLAVENS K-8 SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001524",
    },
    {
        "school": "DENVER SCHOOL OF THE ARTS",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001574",
    },
    {
        "school": "FLORENCE CRITTENTON HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336001575",
    },
    {
        "school": "UNIVERSITY PREP - STEELE ST.",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001576",
    },
    {
        "school": "MAXWELL ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001635",
    },
    {
        "school": "ODYSSEY SCHOOL OF DENVER",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001636",
    },
    {
        "school": "WYATT ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001637",
    },
    {
        "school": "SOUTHMOOR ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001679",
    },
    {
        "school": "GRANT RANCH ECE-8 SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001738",
    },
    {
        "school": "MARIE L. GREENWOOD ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001739",
    },
    {
        "school": "ACADEMIA ANA MARIE SANDOVAL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001750",
    },
    {
        "school": "POLARIS ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001767",
    },
    {
        "school": "GREEN VALLEY ELEMENTARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336001776",
    },
    {
        "school": "PREP ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336001795",
    },
    {
        "school": "EARLY CHILDHOOD EDUCATION CENTER",
        "district": "Sheridan School District No. 2",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80654000032",
    },
    {
        "school": "SUMMIT VIEW ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000044",
    },
    {
        "school": "ACRES GREEN ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000436",
    },
    {
        "school": "CASTLE ROCK ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000437",
    },
    {
        "school": "CASTLE ROCK MIDDLE SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000438",
    },
    {
        "school": "CHERRY VALLEY ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000439",
    },
    {
        "school": "DOUGLAS COUNTY HIGH SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000440",
    },
    {
        "school": "LARKSPUR ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000441",
    },
    {
        "school": "NORTHEAST ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000442",
    },
    {
        "school": "SAGEWOOD MIDDLE SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000443",
    },
    {
        "school": "PINE LANE ELEMENTARY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000444",
    },
    {
        "school": "ROXBOROUGH ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000445",
    },
    {
        "school": "SEDALIA ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000446",
    },
    {
        "school": "SOUTH RIDGE ELEMENTARY AN IB WORLD SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000447",
    },
    {
        "school": "ACADEMY CHARTER SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000492",
    },
    {
        "school": "PARKER CORE KNOWLEDGE CHARTER SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345000812",
    },
    {
        "school": "COYOTE CREEK ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001250",
    },
    {
        "school": "FOX CREEK ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001275",
    },
    {
        "school": "PINE GROVE ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001279",
    },
    {
        "school": "RENAISSANCE EXPEDITION LEARN OUTWARD BOUND SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001288",
    },
    {
        "school": "NORTHRIDGE ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001339",
    },
    {
        "school": "PONDEROSA HIGH SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001341",
    },
    {
        "school": "SAND CREEK ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001407",
    },
    {
        "school": "HIGHLANDS RANCH HIGH SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001437",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "Douglas County School District No. Re 1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001474",
    },
    {
        "school": "ROCK RIDGE ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001475",
    },
    {
        "school": "EAGLE RIDGE ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001476",
    },
    {
        "school": "CHEROKEE TRAIL ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001497",
    },
    {
        "school": "COUGAR RUN ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001526",
    },
    {
        "school": "EAGLE ACADEMY",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80345001527",
    },
    {
        "school": "RANCH VIEW MIDDLE SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001528",
    },
    {
        "school": "THUNDERRIDGE HIGH SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001529",
    },
    {
        "school": "BUFFALO RIDGE ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001577",
    },
    {
        "school": "CHAPARRAL HIGH SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001578",
    },
    {
        "school": "DC MONTESSORI CHARTER SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001581",
    },
    {
        "school": "SIERRA MIDDLE SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001582",
    },
    {
        "school": "PIONEER ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001583",
    },
    {
        "school": "PLATTE RIVER CHARTER ACADEMY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001584",
    },
    {
        "school": "TRAILBLAZER ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001585",
    },
    {
        "school": "IRON HORSE ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001638",
    },
    {
        "school": "WILDCAT MOUNTAIN ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001639",
    },
    {
        "school": "SADDLE RANCH ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001680",
    },
    {
        "school": "ELDORADO ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001736",
    },
    {
        "school": "HERITAGE ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001740",
    },
    {
        "school": "MOUNTAIN RIDGE MIDDLE SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001747",
    },
    {
        "school": "MOUNTAIN VISTA HIGH SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001748",
    },
    {
        "school": "ARROWWOOD ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001757",
    },
    {
        "school": "MEADOW VIEW ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001785",
    },
    {
        "school": "PRAIRIE CROSSING ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345001809",
    },
    {
        "school": "FRANKTOWN ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345003172",
    },
    {
        "school": "MOUNTAIN VIEW ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006152",
    },
    {
        "school": "BEAR CANYON ELEMENTARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006159",
    },
    {
        "school": "DANIEL C OAKES HIGH SCHOOL--CASTLE ROCK",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80345006218",
    },
    {
        "school": "CRESTHILL MIDDLE SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006219",
    },
    {
        "school": "ALAMEDA INTERNATIONAL JUNIOR/SENIOR HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000691",
    },
    {
        "school": "ALLENDALE ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000692",
    },
    {
        "school": "ARVADA HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000694",
    },
    {
        "school": "ARVADA WEST HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000695",
    },
    {
        "school": "BEAR CREEK K-8 SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000696",
    },
    {
        "school": "BEAR CREEK HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000697",
    },
    {
        "school": "BELL MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000698",
    },
    {
        "school": "Belmar School of Integrated Arts",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000699",
    },
    {
        "school": "BERGEN MEADOW PRIMARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000701",
    },
    {
        "school": "CAMPBELL ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000702",
    },
    {
        "school": "CARMODY MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000703",
    },
    {
        "school": "COAL CREEK CANYON K-8 ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000704",
    },
    {
        "school": "COLOROW ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000705",
    },
    {
        "school": "COLUMBINE HILLS ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000706",
    },
    {
        "school": "COLUMBINE HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000707",
    },
    {
        "school": "CREIGHTON MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000708",
    },
    {
        "school": "DENNISON ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000710",
    },
    {
        "school": "DEVINNY ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000711",
    },
    {
        "school": "DRAKE JUNIOR HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000712",
    },
    {
        "school": "DUNSTAN MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000713",
    },
    {
        "school": "DUTCH CREEK ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000714",
    },
    {
        "school": "EDGEWATER ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000716",
    },
    {
        "school": "EIBER ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000717",
    },
    {
        "school": "EVERGREEN MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000718",
    },
    {
        "school": "EVERGREEN HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000719",
    },
    {
        "school": "EVERITT MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000720",
    },
    {
        "school": "FAIRMOUNT ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000721",
    },
    {
        "school": "FITZMORRIS ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000722",
    },
    {
        "school": "FOOTHILLS ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000724",
    },
    {
        "school": "Foster K-8",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000725",
    },
    {
        "school": "FREMONT ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000726",
    },
    {
        "school": "GLENNON HEIGHTS ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000731",
    },
    {
        "school": "GOLDEN HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000733",
    },
    {
        "school": "GREEN GABLES ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000734",
    },
    {
        "school": "GREEN MOUNTAIN ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000735",
    },
    {
        "school": "GREEN MOUNTAIN HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000736",
    },
    {
        "school": "HACKBERRY HILL ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000737",
    },
    {
        "school": "HUTCHINSON ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000738",
    },
    {
        "school": "JEFFERSON JUNIOR/SENIOR HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000739",
    },
    {
        "school": "SHERIDAN GREEN ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000741",
    },
    {
        "school": "KEN CARYL MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000742",
    },
    {
        "school": "KENDRICK LAKES ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000743",
    },
    {
        "school": "KULLERSTRAND ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000744",
    },
    {
        "school": "KYFFIN ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000745",
    },
    {
        "school": "LAKEWOOD HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000747",
    },
    {
        "school": "LASLEY ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000748",
    },
    {
        "school": "LAWRENCE ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000749",
    },
    {
        "school": "LEAWOOD ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000750",
    },
    {
        "school": "LITTLE ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000751",
    },
    {
        "school": "LUMBERG ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000752",
    },
    {
        "school": "MAPLE GROVE ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000754",
    },
    {
        "school": "MILLER SPECIAL EDUCATION",
        "district": "Jefferson County School District No. R-1",
        "level": "Other",
        "type": "Special education school",
        "state": "CO",
        "nces_id": "80480000756",
    },
    {
        "school": "MITCHELL ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000757",
    },
    {
        "school": "MOLHOLM ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000758",
    },
    {
        "school": "NORMANDY ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000759",
    },
    {
        "school": "NORTH ARVADA MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000760",
    },
    {
        "school": "JEFFERSON COUNTY OPEN SECONDARY",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000765",
    },
    {
        "school": "PARMALEE ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000768",
    },
    {
        "school": "PARR ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000769",
    },
    {
        "school": "PATTERSON INTERNATIONAL SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000770",
    },
    {
        "school": "PECK ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000771",
    },
    {
        "school": "PEIFFER ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000772",
    },
    {
        "school": "PEAK EXPEDITIONARY - PENNINGTON",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000773",
    },
    {
        "school": "POMONA HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000775",
    },
    {
        "school": "PROSPECT VALLEY ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000776",
    },
    {
        "school": "RALSTON ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000777",
    },
    {
        "school": "RED ROCKS ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000778",
    },
    {
        "school": "SECREST ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000780",
    },
    {
        "school": "SIERRA ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000781",
    },
    {
        "school": "SLATER ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000782",
    },
    {
        "school": "DEANE ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000783",
    },
    {
        "school": "SOUTH LAKEWOOD ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000784",
    },
    {
        "school": "EMORY ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000785",
    },
    {
        "school": "STOBER ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000787",
    },
    {
        "school": "STOTT ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000788",
    },
    {
        "school": "SWANSON ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000790",
    },
    {
        "school": "JOHN AND KAREN LITZ PRESCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000791",
    },
    {
        "school": "THOMSON ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000792",
    },
    {
        "school": "VANDERHOOF ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000793",
    },
    {
        "school": "VIVIAN ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000794",
    },
    {
        "school": "WEST JEFFERSON MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000795",
    },
    {
        "school": "WARDER ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000796",
    },
    {
        "school": "WARREN TECH CENTRAL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CO",
        "nces_id": "80480000797",
    },
    {
        "school": "WEBER ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000798",
    },
    {
        "school": "WELCHESTER ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000799",
    },
    {
        "school": "WEST JEFFERSON ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000800",
    },
    {
        "school": "WESTGATE ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000801",
    },
    {
        "school": "WHEAT RIDGE HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000803",
    },
    {
        "school": "WILMORE DAVIS ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000804",
    },
    {
        "school": "WILMOT ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000805",
    },
    {
        "school": "BRADFORD K8 NORTH",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000913",
    },
    {
        "school": "D'EVELYN JUNIOR/SENIOR HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000964",
    },
    {
        "school": "JEFFERSON ACADEMY ELEMENTARY",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000975",
    },
    {
        "school": "LONGVIEW HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80480000988",
    },
    {
        "school": "MORTENSEN ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480000991",
    },
    {
        "school": "POWDERHORN ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001006",
    },
    {
        "school": "ROONEY RANCH ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001009",
    },
    {
        "school": "RYAN ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001028",
    },
    {
        "school": "COLLEGIATE ACADEMY OF COLORADO",
        "district": "Jefferson County School District No. R-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001036",
    },
    {
        "school": "SHELTON ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001044",
    },
    {
        "school": "SUMMIT RIDGE MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001054",
    },
    {
        "school": "VAN ARSDALE ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001056",
    },
    {
        "school": "OBERON JUNIOR HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001283",
    },
    {
        "school": "DEER CREEK MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001315",
    },
    {
        "school": "MARSHDALE ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001316",
    },
    {
        "school": "MOORE MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001317",
    },
    {
        "school": "WITT ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001350",
    },
    {
        "school": "KENDALLVUE ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001372",
    },
    {
        "school": "CHATFIELD HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001383",
    },
    {
        "school": "MANDALAY MIDDLE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001384",
    },
    {
        "school": "STONY CREEK ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001385",
    },
    {
        "school": "SHAFFER ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001395",
    },
    {
        "school": "ADAMS ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001446",
    },
    {
        "school": "CORONADO ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001447",
    },
    {
        "school": "GOVERNOR'S RANCH ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001448",
    },
    {
        "school": "UTE MEADOWS ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001450",
    },
    {
        "school": "WESTRIDGE ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001451",
    },
    {
        "school": "LUKAS ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001486",
    },
    {
        "school": "STANDLEY LAKE HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001487",
    },
    {
        "school": "ELK CREEK ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001500",
    },
    {
        "school": "EXCEL ACADEMY CHARTER SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001508",
    },
    {
        "school": "CONIFER SENIOR HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001542",
    },
    {
        "school": "DAKOTA RIDGE SENIOR HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001543",
    },
    {
        "school": "MOUNT CARBON ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001546",
    },
    {
        "school": "SEMPER ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001548",
    },
    {
        "school": "WEST WOODS ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001549",
    },
    {
        "school": "BERGEN VALLEY INTERMEDIATE SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001603",
    },
    {
        "school": "LINCOLN CHARTER ACADEMY",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001605",
    },
    {
        "school": "ROCKY MOUNTAIN DEAF SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Other",
        "type": "Special education school",
        "state": "CO",
        "nces_id": "80480001606",
    },
    {
        "school": "MONTESSORI PEAKS CHARTER ACADEMY",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001607",
    },
    {
        "school": "COMPASS MONTESSORI - WHEAT RIDGE CHARTER SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001649",
    },
    {
        "school": "MANNING OPTIONS SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001746",
    },
    {
        "school": "COMPASS MONTESSORI - GOLDEN CHARTER SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001766",
    },
    {
        "school": "RALSTON VALLEY SENIOR HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001797",
    },
    {
        "school": "WOODROW WILSON CHARTER ACADEMY",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001807",
    },
    {
        "school": "ROCKY MOUNTAIN ACADEMY OF EVERGREEN",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480001812",
    },
    {
        "school": "MCLAIN COMMUNITY HIGH SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80480006163",
    },
    {
        "school": "BRADFORD K8 SOUTH",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006164",
    },
    {
        "school": "NORMA ANDERSON PRESCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006255",
    },
    {
        "school": "JEFFERSON COUNTY OPEN ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006256",
    },
    {
        "school": "BAYFIELD INTERMEDIATE SCHOOL",
        "district": "Bayfield School District No. 10Jt-R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80240000088",
    },
    {
        "school": "BAYFIELD MIDDLE SCHOOL",
        "district": "Bayfield School District No. 10Jt-R",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80240000089",
    },
    {
        "school": "BAYFIELD HIGH SCHOOL",
        "district": "Bayfield School District No. 10Jt-R",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80240000090",
    },
    {
        "school": "DURANGO HIGH SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348000448",
    },
    {
        "school": "FLORIDA MESA ELEMENTARY SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348000449",
    },
    {
        "school": "FORT LEWIS MESA ELEMENTARY SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348000450",
    },
    {
        "school": "MILLER MIDDLE SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348000452",
    },
    {
        "school": "NEEDHAM ELEMENTARY SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348000453",
    },
    {
        "school": "PARK ELEMENTARY SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348000454",
    },
    {
        "school": "RIVERVIEW ELEMENTARY SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348000455",
    },
    {
        "school": "ESCALANTE MIDDLE SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348000456",
    },
    {
        "school": "SUNNYSIDE ELEMENTARY SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348000457",
    },
    {
        "school": "ANIMAS VALLEY ELEMENTARY SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348001066",
    },
    {
        "school": "IGNACIO MIDDLE SCHOOL",
        "district": "Ignacio School District No. 11Jt",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80477000688",
    },
    {
        "school": "IGNACIO HIGH SCHOOL",
        "district": "Ignacio School District No. 11Jt",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80477000689",
    },
    {
        "school": "IGNACIO ELEMENTARY SCHOOL",
        "district": "Ignacio School District No. 11Jt",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80477001444",
    },
    {
        "school": "BATTLE MOUNTAIN HIGH SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354000461",
    },
    {
        "school": "EAGLE VALLEY ELEMENTARY SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354000462",
    },
    {
        "school": "EAGLE VALLEY HIGH SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354000463",
    },
    {
        "school": "RED SANDSTONE ELEMENTARY SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354000468",
    },
    {
        "school": "EAGLE COUNTY CHARTER ACADEMY",
        "district": "Eagle County School District No. Re 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354000851",
    },
    {
        "school": "EAGLE VALLEY MIDDLE SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354001309",
    },
    {
        "school": "HOMESTAKE PEAK SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354001478",
    },
    {
        "school": "AVON ELEMENTARY SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354001530",
    },
    {
        "school": "BERRY CREEK MIDDLE SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354001531",
    },
    {
        "school": "RED HILL ELEMENTARY SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354001721",
    },
    {
        "school": "BRUSH CREEK ELEMENTARY SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354001722",
    },
    {
        "school": "GYPSUM CREEK MIDDLE SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354001723",
    },
    {
        "school": "RED CANYON HIGH SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80354001756",
    },
    {
        "school": "EDWARDS ELEMENTARY SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354006221",
    },
    {
        "school": "GYPSUM ELEMENTARY SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354006222",
    },
    {
        "school": "LAKE COUNTY INTERMEDIATE SCHOOL",
        "district": "Lake County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80519000855",
    },
    {
        "school": "LAKE COUNTY HIGH SCHOOL",
        "district": "Lake County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80519000857",
    },
    {
        "school": "WESTPARK ELEMENTARY SCHOOL",
        "district": "Lake County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80519000859",
    },
    {
        "school": "PITTS ELEMENTARY SCHOOL",
        "district": "Lake County School District No. R-1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80519001550",
    },
    {
        "school": "FOSSIL RIDGE HIGH SCHOOL",
        "district": "Poudre School District R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001848",
    },
    {
        "school": "KINARD CORE KNOWLEDGE MIDDLE SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001849",
    },
    {
        "school": "POUDRE COMMUNITY ACADEMY",
        "district": "Poudre School District R-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80399001938",
    },
    {
        "school": "BACON ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001973",
    },
    {
        "school": "THOMPSON INTEGRATED EARLY CHILDHOOD",
        "district": "Thompson School District R-2J",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540001977",
    },
    {
        "school": "ESTES PARK K-5 SCHOOL",
        "district": "Estes Park School District R-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80381000498",
    },
    {
        "school": "ESTES PARK MIDDLE SCHOOL",
        "district": "Estes Park School District R-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80381000499",
    },
    {
        "school": "ESTES PARK HIGH SCHOOL",
        "district": "Estes Park School District R-3",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80381000500",
    },
    {
        "school": "KRUSE ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000147",
    },
    {
        "school": "MCGRAW ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000165",
    },
    {
        "school": "CENTENNIAL HIGH SCHOOL",
        "district": "Poudre School District R-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80399000517",
    },
    {
        "school": "BAUDER ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000519",
    },
    {
        "school": "BEATTIE ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000520",
    },
    {
        "school": "BENNETT ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000521",
    },
    {
        "school": "BLEVINS MIDDLE SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000522",
    },
    {
        "school": "BOLTZ MIDDLE SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000523",
    },
    {
        "school": "CACHE LA POUDRE MIDDLE SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000524",
    },
    {
        "school": "CACHE LA POUDRE ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000525",
    },
    {
        "school": "DUNN ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000526",
    },
    {
        "school": "EYESTONE ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000527",
    },
    {
        "school": "FORT COLLINS HIGH SCHOOL",
        "district": "Poudre School District R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000528",
    },
    {
        "school": "IRISH ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000533",
    },
    {
        "school": "LINCOLN MIDDLE SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000536",
    },
    {
        "school": "O'DEA ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000539",
    },
    {
        "school": "POUDRE HIGH SCHOOL",
        "district": "Poudre School District R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000541",
    },
    {
        "school": "PUTNAM ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000542",
    },
    {
        "school": "RIFFENBURGH ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000544",
    },
    {
        "school": "ROCKY MOUNTAIN HIGH SCHOOL",
        "district": "Poudre School District R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000545",
    },
    {
        "school": "TAVELLI ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000547",
    },
    {
        "school": "TIMNATH ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000548",
    },
    {
        "school": "WELLINGTON MIDDLE SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000551",
    },
    {
        "school": "HARRIS BILINGUAL ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000573",
    },
    {
        "school": "LAUREL ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000583",
    },
    {
        "school": "TRAUT CORE ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399000606",
    },
    {
        "school": "PRESTON MIDDLE SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001091",
    },
    {
        "school": "SHEPARDSON ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001280",
    },
    {
        "school": "LESHER MIDDLE SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001408",
    },
    {
        "school": "LOPEZ ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001409",
    },
    {
        "school": "WERNER ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001440",
    },
    {
        "school": "JOHNSON ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001480",
    },
    {
        "school": "LINTON ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001498",
    },
    {
        "school": "LIBERTY COMMON CHARTER SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001608",
    },
    {
        "school": "RIDGEVIEW CLASSICAL CHARTER SCHOOLS",
        "district": "Poudre School District R-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001717",
    },
    {
        "school": "ZACH ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399001727",
    },
    {
        "school": "OLANDER ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399006161",
    },
    {
        "school": "WEBBER MIDDLE SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399006162",
    },
    {
        "school": "COTTONWOOD PLAINS ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000607",
    },
    {
        "school": "B F KITCHEN ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000924",
    },
    {
        "school": "CONRAD BALL MIDDLE SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000925",
    },
    {
        "school": "BERTHOUD ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000926",
    },
    {
        "school": "BERTHOUD HIGH SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000927",
    },
    {
        "school": "BIG THOMPSON ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000928",
    },
    {
        "school": "BILL REED MIDDLE SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000929",
    },
    {
        "school": "MARY BLAIR ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000930",
    },
    {
        "school": "CENTENNIAL ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000931",
    },
    {
        "school": "GARFIELD ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000932",
    },
    {
        "school": "IVY STOCKWELL ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000933",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000934",
    },
    {
        "school": "LOVELAND HIGH SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000935",
    },
    {
        "school": "MONROE ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000936",
    },
    {
        "school": "NAMAQUA ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000937",
    },
    {
        "school": "THOMPSON VALLEY HIGH SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000938",
    },
    {
        "school": "TRUSCOTT ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000939",
    },
    {
        "school": "HAROLD FERGUSON HIGH SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80540000941",
    },
    {
        "school": "WINONA ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540000942",
    },
    {
        "school": "SARAH MILNER ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540001285",
    },
    {
        "school": "WALT CLARK MIDDLE SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540001286",
    },
    {
        "school": "LAURENE EDMONDSON ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540001301",
    },
    {
        "school": "CARRIE MARTIN ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540001352",
    },
    {
        "school": "TURNER MIDDLE SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540001354",
    },
    {
        "school": "LUCILE ERWIN MIDDLE SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540001655",
    },
    {
        "school": "MOUNTAIN VIEW HIGH SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540001786",
    },
    {
        "school": "BRUSH MIDDLE SCHOOL",
        "district": "School District No. Re-2 Brush",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80261000153",
    },
    {
        "school": "BRUSH HIGH SCHOOL",
        "district": "School District No. Re-2 Brush",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80261000154",
    },
    {
        "school": "BEAVER VALLEY ELEMENTARY SCHOOL",
        "district": "School District No. Re-2 Brush",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80261000155",
    },
    {
        "school": "THOMSON PRIMARY SCHOOL",
        "district": "School District No. Re-2 Brush",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80261000156",
    },
    {
        "school": "COLUMBINE ELEMENTARY SCHOOL",
        "district": "School District No. Re-3 Fort Morgan",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80405000556",
    },
    {
        "school": "FORT MORGAN HIGH SCHOOL",
        "district": "School District No. Re-3 Fort Morgan",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80405000557",
    },
    {
        "school": "GREEN ACRES ELEMENTARY SCHOOL",
        "district": "School District No. Re-3 Fort Morgan",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80405000558",
    },
    {
        "school": "SHERMAN EARLY CHILDHOOD CENTER",
        "district": "School District No. Re-3 Fort Morgan",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80405000559",
    },
    {
        "school": "FORT MORGAN MIDDLE SCHOOL",
        "district": "School District No. Re-3 Fort Morgan",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80405001281",
    },
    {
        "school": "LINCOLN HIGH SCHOOL",
        "district": "School District No. Re-3 Fort Morgan",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80405001611",
    },
    {
        "school": "PIONEER ELEMENTARY SCHOOL",
        "district": "School District No. Re-3 Fort Morgan",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80405006298",
    },
    {
        "school": "WELDON VALLEY ELEMENTARY SCHOOL",
        "district": "School District No. Re-20 Weldon Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80714001217",
    },
    {
        "school": "WELDON VALLEY JR/SR HIGH SCHOOL",
        "district": "School District No. Re-20 Weldon Valley",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80714001218",
    },
    {
        "school": "WIGGINS ELEMENTARY SCHOOL",
        "district": "School District No. Re-50 Wiggins",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80729001257",
    },
    {
        "school": "WIGGINS HIGH SCHOOL",
        "district": "School District No. Re-50 Wiggins",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80729001258",
    },
    {
        "school": "DUAL IMMERSION ACADEMY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80435001850",
    },
    {
        "school": "INDEPENDENCE ACADEMY",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435001980",
    },
    {
        "school": "PLATEAU VALLEY ELEMENTARY SCHOOL",
        "district": "Plateau Valley School District No. 50 in the county of Mesa",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80303000219",
    },
    {
        "school": "PLATEAU VALLEY HIGH SCHOOL",
        "district": "Plateau Valley School District No. 50 in the county of Mesa",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80303000220",
    },
    {
        "school": "GRAND MESA HIGH SCHOOL",
        "district": "Plateau Valley School District No. 50 in the county of Mesa",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80303001434",
    },
    {
        "school": "PLATEAU VALLEY MIDDLE SCHOOL",
        "district": "Plateau Valley School District No. 50 in the county of Mesa",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80303006288",
    },
    {
        "school": "DE BEQUE PK-12 SCHOOL DISTRICT 49JT",
        "district": "De Beque Joint District No. 49 of the counties of Mesa and",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80324000286",
    },
    {
        "school": "REDLANDS MIDDLE SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000205",
    },
    {
        "school": "APPLETON ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000597",
    },
    {
        "school": "BOOKCLIFF MIDDLE SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000598",
    },
    {
        "school": "BROADWAY ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000599",
    },
    {
        "school": "CENTRAL HIGH SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000600",
    },
    {
        "school": "CHATFIELD ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000601",
    },
    {
        "school": "CLIFTON ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000602",
    },
    {
        "school": "EAST MIDDLE SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000605",
    },
    {
        "school": "FRUITA MIDDLE SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000608",
    },
    {
        "school": "FRUITA MONUMENT HIGH SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000609",
    },
    {
        "school": "FRUITVALE ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000610",
    },
    {
        "school": "GATEWAY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000611",
    },
    {
        "school": "GRAND JUNCTION HIGH SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000612",
    },
    {
        "school": "LINCOLN ORCHARD MESA ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000613",
    },
    {
        "school": "LOMA ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000615",
    },
    {
        "school": "NISLEY ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000616",
    },
    {
        "school": "ORCHARD AVENUE ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000618",
    },
    {
        "school": "ORCHARD MESA MIDDLE SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000619",
    },
    {
        "school": "PALISADE HIGH SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000620",
    },
    {
        "school": "POMONA ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000621",
    },
    {
        "school": "R-5 HIGH SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80435000623",
    },
    {
        "school": "SCENIC ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000624",
    },
    {
        "school": "SHELLEDY ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000625",
    },
    {
        "school": "TAYLOR ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000626",
    },
    {
        "school": "TOPE ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000627",
    },
    {
        "school": "WEST MIDDLE SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435000629",
    },
    {
        "school": "MESA VIEW ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435001344",
    },
    {
        "school": "MOUNT GARFIELD MIDDLE SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435001345",
    },
    {
        "school": "THUNDER MOUNTAIN ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435001346",
    },
    {
        "school": "WINGATE ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435001347",
    },
    {
        "school": "NEW EMERSON SCHOOL AT COLUMBUS",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435001552",
    },
    {
        "school": "GRAND MESA MIDDLE SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435001656",
    },
    {
        "school": "ROCKY MOUNTAIN ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435001657",
    },
    {
        "school": "DOS RIOS ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435001691",
    },
    {
        "school": "BENJAMIN EATON ELEMENTARY SCHOOL",
        "district": "Weld County School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80360001986",
    },
    {
        "school": "HEIMAN ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441001988",
    },
    {
        "school": "WINOGRAD K-8 ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441001989",
    },
    {
        "school": "BELLA ROMERO ACADEMY OF APPLIED TECHNOLOGY",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441001990",
    },
    {
        "school": "PIONEER RIDGE ELEMENTARY SCHOOL",
        "district": "Weld County School District No. Re-5J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80483001911",
    },
    {
        "school": "KNOWLEDGE QUEST ACADEMY",
        "district": "Weld County School District No. Re-5J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80483002029",
    },
    {
        "school": "LOCHBUIE ELEMENTARY SCHOOL",
        "district": "Weld County School District RE-3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80492002025",
    },
    {
        "school": "WELD CENTRAL MIDDLE SCHOOL",
        "district": "Weld County School District RE-3J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80492002026",
    },
    {
        "school": "GRANDVIEW ELEMENTARY SCHOOL",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735001987",
    },
    {
        "school": "HIGHLAND ELEMENTARY SCHOOL",
        "district": "Weld County School District No. Re-9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80231000049",
    },
    {
        "school": "HIGHLAND HIGH SCHOOL",
        "district": "Weld County School District No. Re-9",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80231000050",
    },
    {
        "school": "HIGHLAND MIDDLE SCHOOL",
        "district": "Weld County School District No. Re-9",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80231001466",
    },
    {
        "school": "BRIGGSDALE ELEMENTARY SCHOOL",
        "district": "School District No. Re-10 in the county of Weld and State o",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80255000142",
    },
    {
        "school": "BRIGGSDALE UNDIVIDED HIGH SCHOOL",
        "district": "School District No. Re-10 in the county of Weld and State o",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80255000143",
    },
    {
        "school": "EATON ELEMENTARY SCHOOL",
        "district": "Weld County School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80360000474",
    },
    {
        "school": "EATON MIDDLE SCHOOL",
        "district": "Weld County School District No. Re-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80360000475",
    },
    {
        "school": "EATON HIGH SCHOOL",
        "district": "Weld County School District No. Re-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80360000476",
    },
    {
        "school": "GALETON ELEMENTARY SCHOOL",
        "district": "Weld County School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80360000477",
    },
    {
        "school": "FORT LUPTON HIGH SCHOOL",
        "district": "Weld re-8 schools",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80402000552",
    },
    {
        "school": "FORT LUPTON MIDDLE SCHOOL",
        "district": "Weld re-8 schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80402000553",
    },
    {
        "school": "LEO WILLIAM BUTLER ELEMENTARY SCHOOL",
        "district": "Weld re-8 schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80402000554",
    },
    {
        "school": "TWOMBLY ELEMENTARY SCHOOL",
        "district": "Weld re-8 schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80402001366",
    },
    {
        "school": "GILCREST ELEMENTARY SCHOOL",
        "district": "Weld County Reorganized School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80420000575",
    },
    {
        "school": "PETE MIRICH ELEMENTARY SCHOOL",
        "district": "Weld County Reorganized School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80420000576",
    },
    {
        "school": "NORTH VALLEY MIDDLE SCHOOL",
        "district": "Weld County Reorganized School District No. Re-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80420000577",
    },
    {
        "school": "PLATTEVILLE ELEMENTARY SCHOOL",
        "district": "Weld County Reorganized School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80420000578",
    },
    {
        "school": "SOUTH VALLEY MIDDLE SCHOOL",
        "district": "Weld County Reorganized School District No. Re-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80420000579",
    },
    {
        "school": "VALLEY HIGH SCHOOL",
        "district": "Weld County Reorganized School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80420000580",
    },
    {
        "school": "MARTINEZ ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000633",
    },
    {
        "school": "BRENTWOOD MIDDLE SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000634",
    },
    {
        "school": "CENTENNIAL ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000636",
    },
    {
        "school": "CHAPPELOW K-8 MAGNET SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000637",
    },
    {
        "school": "FRANKLIN MIDDLE SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000639",
    },
    {
        "school": "GREELEY WEST HIGH SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000640",
    },
    {
        "school": "GREELEY CENTRAL HIGH SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000641",
    },
    {
        "school": "HEATH MIDDLE SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000642",
    },
    {
        "school": "PRAIRIE HEIGHTS MIDDLE SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000645",
    },
    {
        "school": "MADISON ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000646",
    },
    {
        "school": "MEEKER ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000648",
    },
    {
        "school": "SCOTT ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000649",
    },
    {
        "school": "SHAWSHEEN ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441000650",
    },
    {
        "school": "JACKSON ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441001291",
    },
    {
        "school": "MONFORT ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441001312",
    },
    {
        "school": "DOS RIOS ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441001482",
    },
    {
        "school": "S. CHRISTA MCAULIFFE STEM ACADEMY",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441001483",
    },
    {
        "school": "FRONTIER CHARTER ACADEMY",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441001614",
    },
    {
        "school": "Union Colony Schools",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441001615",
    },
    {
        "school": "UNIVERSITY SCHOOLS",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441001696",
    },
    {
        "school": "NORTHRIDGE HIGH SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441001788",
    },
    {
        "school": "PAWNEE SCHOOL PK-12",
        "district": "School District No. Re-12 in the county of Weld and State of",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80444000653",
    },
    {
        "school": "LETFORD ELEMENTARY SCHOOL",
        "district": "Weld County School District No. Re-5J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80483000807",
    },
    {
        "school": "MILLIKEN ELEMENTARY SCHOOL",
        "district": "Weld County School District No. Re-5J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80483000808",
    },
    {
        "school": "MILLIKEN MIDDLE SCHOOL",
        "district": "Weld County School District No. Re-5J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80483000809",
    },
    {
        "school": "ROOSEVELT HIGH SCHOOL",
        "district": "Weld County School District No. Re-5J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80483000810",
    },
    {
        "school": "HUDSON ELEMENTARY SCHOOL",
        "district": "Weld County School District RE-3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80492000816",
    },
    {
        "school": "HOFF ELEMENTARY SCHOOL",
        "district": "Weld County School District RE-3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80492000817",
    },
    {
        "school": "WELD CENTRAL SENIOR HIGH SCHOOL",
        "district": "Weld County School District RE-3J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80492000819",
    },
    {
        "school": "CARDINAL COMMUNITY ACADEMY CHARTER SCHOOL",
        "district": "Weld County School District RE-3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80492001760",
    },
    {
        "school": "PLATTE VALLEY ELEMENTARY SCHOOL",
        "district": "Weld County School District No. Re-7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80495000820",
    },
    {
        "school": "PLATTE VALLEY HIGH SCHOOL",
        "district": "Weld County School District No. Re-7",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80495000821",
    },
    {
        "school": "PLATTE VALLEY MIDDLE SCHOOL",
        "district": "Weld County School District No. Re-7",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80495001697",
    },
    {
        "school": "PRAIRIE ELEMENTARY SCHOOL",
        "district": "School District No. Re-11 in the county of Weld and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80672001157",
    },
    {
        "school": "PRAIRIE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "School District No. Re-11 in the county of Weld and State of",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80672001158",
    },
    {
        "school": "MOUNTAIN VIEW ELEMENTARY SCHOOL",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735001262",
    },
    {
        "school": "TOZER ELEMENTARY SCHOOL",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735001263",
    },
    {
        "school": "WINDSOR HIGH SCHOOL",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735001264",
    },
    {
        "school": "WINDSOR MIDDLE SCHOOL",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735001265",
    },
    {
        "school": "SKYVIEW ELEMENTARY SCHOOL",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735001364",
    },
    {
        "school": "WINDSOR CHARTER ACADEMY ELEMENTARY SCHOOL",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735001815",
    },
    {
        "school": "VISTA CHARTER SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80579001852",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "Montrose County School District Re-1J",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579000250",
    },
    {
        "school": "CENTENNIAL MIDDLE SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579000987",
    },
    {
        "school": "COLUMBINE MIDDLE SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579000989",
    },
    {
        "school": "JOHNSON ELEMENTARY SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579000990",
    },
    {
        "school": "MONTROSE HIGH SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579000992",
    },
    {
        "school": "NORTHSIDE ELEMENTARY SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579000994",
    },
    {
        "school": "OAK GROVE ELEMENTARY SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579000995",
    },
    {
        "school": "OLATHE ELEMENTARY SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579000996",
    },
    {
        "school": "OLATHE MIDDLE SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579000997",
    },
    {
        "school": "OLATHE HIGH SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579000998",
    },
    {
        "school": "POMONA ELEMENTARY SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579000999",
    },
    {
        "school": "COTTONWOOD ELEMENTARY SCHOOL",
        "district": "Montrose County School District Re-1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579001554",
    },
    {
        "school": "NUCLA HIGH SCHOOL",
        "district": "West End School District No. Re-2",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80585001007",
    },
    {
        "school": "NATURITA ELEMENTARY SCHOOL",
        "district": "West End School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80585001398",
    },
    {
        "school": "PARADOX VALLEY CHARTER SCHOOL",
        "district": "West End School District No. Re-2",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80585001693",
    },
    {
        "school": "CEDAR RIDGE ELEMENTARY SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001854",
    },
    {
        "school": "PRAIRIE WINDS ELEMENTARY SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001855",
    },
    {
        "school": "HERITAGE ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612000261",
    },
    {
        "school": "BELMONT ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001029",
    },
    {
        "school": "FRANKLIN SCHOOL OF INNOVATION",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001030",
    },
    {
        "school": "BESSEMER ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001031",
    },
    {
        "school": "BEULAH HEIGHTS ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001032",
    },
    {
        "school": "BRADFORD ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001033",
    },
    {
        "school": "CARLILE ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001034",
    },
    {
        "school": "CENTENNIAL HIGH SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001035",
    },
    {
        "school": "CENTRAL HIGH SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001037",
    },
    {
        "school": "COLUMBIAN ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001038",
    },
    {
        "school": "EAST HIGH SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001040",
    },
    {
        "school": "EVA R BACA ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001041",
    },
    {
        "school": "GOODNIGHT ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001046",
    },
    {
        "school": "HAAFF ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001047",
    },
    {
        "school": "HIGHLAND PARK ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001048",
    },
    {
        "school": "IRVING ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001050",
    },
    {
        "school": "RISLEY INTERNATIONAL ACADEMY OF INNOVATION",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001051",
    },
    {
        "school": "PUEBLO ACADEMY OF ARTS",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001055",
    },
    {
        "school": "MINNEQUA ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001057",
    },
    {
        "school": "MORTON ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001058",
    },
    {
        "school": "PARK VIEW ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001060",
    },
    {
        "school": "RONCALLI STEM ACADEMY",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001061",
    },
    {
        "school": "SOUTH PARK ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001063",
    },
    {
        "school": "SOUTH HIGH SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001064",
    },
    {
        "school": "SUNSET PARK ELEMENTARY SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001065",
    },
    {
        "school": "W H HEATON MIDDLE SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001067",
    },
    {
        "school": "PUEBLO CHARTER SCHOOL FOR THE ARTS & SCIENCES",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001106",
    },
    {
        "school": "CHAVEZ/HUERTA K-12 PREPARATORY ACADEMY",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612001730",
    },
    {
        "school": "THE CONNECT CHARTER SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615000632",
    },
    {
        "school": "AVONDALE ELEMENTARY SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001069",
    },
    {
        "school": "BEULAH ELEMENTARY SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001071",
    },
    {
        "school": "BEULAH MIDDLE SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001072",
    },
    {
        "school": "CRAVER MIDDLE SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001074",
    },
    {
        "school": "NORTH MESA ELEMENTARY SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001076",
    },
    {
        "school": "PLEASANT VIEW MIDDLE SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001078",
    },
    {
        "school": "PUEBLO COUNTY HIGH SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001079",
    },
    {
        "school": "LIBERTY POINT ELEMENTARY SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001080",
    },
    {
        "school": "RYE ELEMENTARY SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001081",
    },
    {
        "school": "RYE HIGH SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001082",
    },
    {
        "school": "SOUTH MESA ELEMENTARY SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001083",
    },
    {
        "school": "VINELAND ELEMENTARY SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001084",
    },
    {
        "school": "VINELAND MIDDLE SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001085",
    },
    {
        "school": "LIBERTY POINT INTERNATIONAL SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001357",
    },
    {
        "school": "SIERRA VISTA ELEMENTARY SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001558",
    },
    {
        "school": "SWALLOWS CHARTER ACADEMY",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001559",
    },
    {
        "school": "PUEBLO WEST HIGH SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001613",
    },
    {
        "school": "SKY VIEW MIDDLE SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001714",
    },
    {
        "school": "DESERT SAGE ELEMENTARY SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615001718",
    },
    {
        "school": "SUMMIT HIGH SCHOOL",
        "district": "Summit School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80681001164",
    },
    {
        "school": "FRISCO ELEMENTARY SCHOOL",
        "district": "Summit School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80681001165",
    },
    {
        "school": "BRECKENRIDGE ELEMENTARY SCHOOL",
        "district": "Summit School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80681001166",
    },
    {
        "school": "SILVERTHORNE ELEMENTARY SCHOOL",
        "district": "Summit School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80681001167",
    },
    {
        "school": "DILLON VALLEY ELEMENTARY SCHOOL",
        "district": "Summit School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80681001303",
    },
    {
        "school": "SUMMIT MIDDLE SCHOOL",
        "district": "Summit School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80681001400",
    },
    {
        "school": "SUMMIT COVE ELEMENTARY SCHOOL",
        "district": "Summit School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80681001563",
    },
    {
        "school": "UPPER BLUE ELEMENTARY SCHOOL",
        "district": "Summit School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80681001564",
    },
    {
        "school": "FLEMING ELEMENTARY SCHOOL",
        "district": "School District No. Re-3 Frenchman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80393000511",
    },
    {
        "school": "FLEMING HIGH SCHOOL",
        "district": "School District No. Re-3 Frenchman",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80393000512",
    },
    {
        "school": "MERINO ELEMENTARY SCHOOL",
        "district": "School District No. Re-4 Buffalo",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80564000969",
    },
    {
        "school": "MERINO JUNIOR SENIOR HIGH SCHOOL",
        "district": "School District No. Re-4 Buffalo",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80564000970",
    },
    {
        "school": "PEETZ ELEMENTARY SCHOOL",
        "district": "School District No. Re-5 Plateau",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80603001022",
    },
    {
        "school": "PEETZ JUNIOR-SENIOR HIGH SCHOOL",
        "district": "School District No. Re-5 Plateau",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80603001023",
    },
    {
        "school": "CALICHE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "School District No. Re-1 Valley",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80669001147",
    },
    {
        "school": "HAGEN EARLY EDUCATION CENTER",
        "district": "School District No. Re-1 Valley",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80669001151",
    },
    {
        "school": "STERLING MIDDLE SCHOOL",
        "district": "School District No. Re-1 Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80669001154",
    },
    {
        "school": "STERLING HIGH SCHOOL",
        "district": "School District No. Re-1 Valley",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80669001155",
    },
    {
        "school": "CALICHE ELEMENTARY SCHOOL",
        "district": "School District No. Re-1 Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80669001361",
    },
    {
        "school": "Park City Prep Charter School",
        "district": "Park City Prep Charter School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90003301449",
    },
    {
        "school": "Western CT Academy of International Studies Elementary Magne",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102001438",
    },
    {
        "school": "House of Arts Letters and Science (HALS)  Academy",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267001445",
    },
    {
        "school": "John C. Daniels",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001443",
    },
    {
        "school": "Colchester Elementary School",
        "district": "COLCHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90084001444",
    },
    {
        "school": "Bunnell High School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000885",
    },
    {
        "school": "Chapel School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000887",
    },
    {
        "school": "Harry B. Flood Middle School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000888",
    },
    {
        "school": "Franklin School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000889",
    },
    {
        "school": "Stratford Academy - Johnson House",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000892",
    },
    {
        "school": "Lordship School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000893",
    },
    {
        "school": "Nichols School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000894",
    },
    {
        "school": "Second Hill Lane School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000895",
    },
    {
        "school": "Stratford High School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000897",
    },
    {
        "school": "Eli Whitney School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000898",
    },
    {
        "school": "Wilcoxson School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000899",
    },
    {
        "school": "David Wooster Middle School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444000900",
    },
    {
        "school": "Connecticut IB Academy",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126001477",
    },
    {
        "school": "Nayaug Elementary School",
        "district": "GLASTONBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90162001447",
    },
    {
        "school": "Bristow Middle School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001419",
    },
    {
        "school": "Anna E. Norris School",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126000191",
    },
    {
        "school": "Dr. Franklin H. Mayberry School",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126000194",
    },
    {
        "school": "Dr. John A. Langford School",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126000195",
    },
    {
        "school": "Dr. Thomas S. O'Connell School",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126000196",
    },
    {
        "school": "East Hartford Middle School",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126000197",
    },
    {
        "school": "East Hartford High School",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126000200",
    },
    {
        "school": "Governor William Pitkin School",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126000201",
    },
    {
        "school": "Joseph O. Goodwin School",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126000204",
    },
    {
        "school": "Robert J. O'Brien School",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126000206",
    },
    {
        "school": "Silver Lane School",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126000208",
    },
    {
        "school": "Sunset Ridge Middle School",
        "district": "EAST HARTFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90126001275",
    },
    {
        "school": "Aiken School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492000004",
    },
    {
        "school": "Braeburn School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001009",
    },
    {
        "school": "Bugbee School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001011",
    },
    {
        "school": "Charter Oak International Academy",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001012",
    },
    {
        "school": "Conard High School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001013",
    },
    {
        "school": "Duffy School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001014",
    },
    {
        "school": "Hall High School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001015",
    },
    {
        "school": "King Philip Middle School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001017",
    },
    {
        "school": "Morley School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001018",
    },
    {
        "school": "Norfeldt School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001019",
    },
    {
        "school": "Sedgwick Middle School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001021",
    },
    {
        "school": "Webster Hill School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001024",
    },
    {
        "school": "Whiting Lane School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001025",
    },
    {
        "school": "Wolcott School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001026",
    },
    {
        "school": "Smith School",
        "district": "WEST HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90492001217",
    },
    {
        "school": "Forbes School",
        "district": "TORRINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90459000917",
    },
    {
        "school": "Southwest School",
        "district": "TORRINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90459000922",
    },
    {
        "school": "Torringford School",
        "district": "TORRINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90459000923",
    },
    {
        "school": "Torrington High School",
        "district": "TORRINGTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90459000924",
    },
    {
        "school": "Torrington Middle School",
        "district": "TORRINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90459000925",
    },
    {
        "school": "Vogel-Wetmore School",
        "district": "TORRINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90459001211",
    },
    {
        "school": "Windham Middle School",
        "district": "WINDHAM SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90519001081",
    },
    {
        "school": "Natchaug School",
        "district": "WINDHAM SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90519001083",
    },
    {
        "school": "W. B. Sweeney School",
        "district": "WINDHAM SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90519001084",
    },
    {
        "school": "Windham Center School",
        "district": "WINDHAM SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90519001085",
    },
    {
        "school": "Windham High School",
        "district": "WINDHAM SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90519001086",
    },
    {
        "school": "North Windham School",
        "district": "WINDHAM SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90519001214",
    },
    {
        "school": "New Beginnings Inc Family Academy",
        "district": "New Beginnings Inc Family Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90002801366",
    },
    {
        "school": "Stamford Academy",
        "district": "Stamford Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90003101405",
    },
    {
        "school": "Burr Elementary School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153001378",
    },
    {
        "school": "Fairfield Ludlowe High School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153001379",
    },
    {
        "school": "Reed Intermediate School",
        "district": "NEWTOWN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90291001487",
    },
    {
        "school": "Scotts Ridge Middle School",
        "district": "RIDGEFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90381001361",
    },
    {
        "school": "Barlow Mountain Elementary School",
        "district": "RIDGEFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90381001467",
    },
    {
        "school": "The Academy of Information Technology & Engineering",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432001468",
    },
    {
        "school": "Frenchtown Elementary School",
        "district": "TRUMBULL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90462001469",
    },
    {
        "school": "Weston Intermediate School",
        "district": "WESTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90501001428",
    },
    {
        "school": "Saugatuck Elementary School",
        "district": "WESTPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90504001363",
    },
    {
        "school": "The Bridge Academy",
        "district": "THE BRIDGE ACADEMY DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90001500809",
    },
    {
        "school": "Luis Munoz Marin School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000001",
    },
    {
        "school": "Barnum School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000049",
    },
    {
        "school": "Bassick High School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000050",
    },
    {
        "school": "Beardsley School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000051",
    },
    {
        "school": "Black Rock School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000052",
    },
    {
        "school": "Blackham School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000053",
    },
    {
        "school": "Bryant School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000054",
    },
    {
        "school": "Central High School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000056",
    },
    {
        "school": "Columbus School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000058",
    },
    {
        "school": "Wilbur Cross School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000059",
    },
    {
        "school": "Edison School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000060",
    },
    {
        "school": "Hall School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000065",
    },
    {
        "school": "Hallen School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000066",
    },
    {
        "school": "Warren Harding High School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000067",
    },
    {
        "school": "Thomas Hooker School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000069",
    },
    {
        "school": "Cesar Batalla School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000070",
    },
    {
        "school": "Park City Magnet School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000071",
    },
    {
        "school": "Madison School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000074",
    },
    {
        "school": "Classical Studies Academy",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000075",
    },
    {
        "school": "Jettie S. Tisdale School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000076",
    },
    {
        "school": "Read School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000080",
    },
    {
        "school": "Roosevelt School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000081",
    },
    {
        "school": "A.B. Skane Center",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000085",
    },
    {
        "school": "Waltersville School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000086",
    },
    {
        "school": "Geraldine Johnson School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000087",
    },
    {
        "school": "John Winthrop School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045000090",
    },
    {
        "school": "Multicultural Magnet School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045001127",
    },
    {
        "school": "Paul Laurence Dunbar School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045001161",
    },
    {
        "school": "James J. Curiale School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045001162",
    },
    {
        "school": "High Horizons Magnet School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045001163",
    },
    {
        "school": "Six-Six Magnet School",
        "district": "Cooperative Educational Services",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90091000340",
    },
    {
        "school": "Helen Keller Middle School",
        "district": "EASTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90141000233",
    },
    {
        "school": "Samuel Staples Elementary School",
        "district": "EASTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90141000234",
    },
    {
        "school": "Fairfield Warde High School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000256",
    },
    {
        "school": "Dwight Elementary School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000257",
    },
    {
        "school": "Fairfield Woods Middle School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000258",
    },
    {
        "school": "Holland Hill School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000260",
    },
    {
        "school": "Jennings School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000261",
    },
    {
        "school": "McKinley School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000262",
    },
    {
        "school": "Mill Hill School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000263",
    },
    {
        "school": "North Stratfield School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000264",
    },
    {
        "school": "Riverfield School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000267",
    },
    {
        "school": "Sherman School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000269",
    },
    {
        "school": "Stratfield School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000270",
    },
    {
        "school": "Tomlinson Middle School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000271",
    },
    {
        "school": "Osborn Hill School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000609",
    },
    {
        "school": "Roger Ludlowe Middle School",
        "district": "FAIRFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90153000919",
    },
    {
        "school": "Fawn Hollow Elementary School",
        "district": "MONROE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90255000488",
    },
    {
        "school": "Masuk High School",
        "district": "MONROE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90255000489",
    },
    {
        "school": "Monroe Elementary School",
        "district": "MONROE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90255000490",
    },
    {
        "school": "Stepney Elementary School",
        "district": "MONROE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90255000491",
    },
    {
        "school": "Jockey Hollow School",
        "district": "MONROE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90255000920",
    },
    {
        "school": "John Read Middle School",
        "district": "REDDING SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90351000721",
    },
    {
        "school": "Redding Elementary School",
        "district": "REDDING SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90351000722",
    },
    {
        "school": "Joel Barlow High School",
        "district": "REGIONAL SCHOOL DISTRICT 09",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90378000773",
    },
    {
        "school": "Sunnyside School",
        "district": "SHELTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90405000003",
    },
    {
        "school": "Booth Hill School",
        "district": "SHELTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90405000796",
    },
    {
        "school": "Elizabeth Shelton School",
        "district": "SHELTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90405000798",
    },
    {
        "school": "Intermediate School",
        "district": "SHELTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90405000801",
    },
    {
        "school": "Long Hill School",
        "district": "SHELTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90405000803",
    },
    {
        "school": "Mohegan School",
        "district": "SHELTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90405000804",
    },
    {
        "school": "Shelton High School",
        "district": "SHELTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90405000806",
    },
    {
        "school": "Booth Hill School",
        "district": "TRUMBULL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90462000927",
    },
    {
        "school": "Daniels Farm School",
        "district": "TRUMBULL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90462000929",
    },
    {
        "school": "Hillcrest Middle School",
        "district": "TRUMBULL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90462000930",
    },
    {
        "school": "Jane Ryan School",
        "district": "TRUMBULL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90462000931",
    },
    {
        "school": "Madison Middle School",
        "district": "TRUMBULL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90462000933",
    },
    {
        "school": "Middlebrook School",
        "district": "TRUMBULL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90462000934",
    },
    {
        "school": "Tashua School",
        "district": "TRUMBULL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90462000936",
    },
    {
        "school": "Trumbull High School",
        "district": "TRUMBULL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90462000937",
    },
    {
        "school": "Mead School",
        "district": "ANSONIA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90006000005",
    },
    {
        "school": "Prendergast School",
        "district": "ANSONIA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90006001020",
    },
    {
        "school": "Bradley School",
        "district": "DERBY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90111000174",
    },
    {
        "school": "Derby High School",
        "district": "DERBY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90111000175",
    },
    {
        "school": "Irving School",
        "district": "DERBY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90111000178",
    },
    {
        "school": "Calf Pen Meadow School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000467",
    },
    {
        "school": "Harborside Middle School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000468",
    },
    {
        "school": "J. F. Kennedy School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000471",
    },
    {
        "school": "Jonathan Law High School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000472",
    },
    {
        "school": "Joseph A. Foran High School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000473",
    },
    {
        "school": "West Shore Middle School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000474",
    },
    {
        "school": "Live Oaks School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000476",
    },
    {
        "school": "Mathewson School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000477",
    },
    {
        "school": "Meadowside School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000478",
    },
    {
        "school": "Orange Avenue School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000480",
    },
    {
        "school": "Orchard Hills School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000481",
    },
    {
        "school": "Pumpkin Delight School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000483",
    },
    {
        "school": "East Shore Middle School",
        "district": "MILFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90252000484",
    },
    {
        "school": "Bungay School",
        "district": "SEYMOUR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90399000790",
    },
    {
        "school": "Seymour High School",
        "district": "SEYMOUR SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90399000793",
    },
    {
        "school": "Seymour Middle School",
        "district": "SEYMOUR SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90399000794",
    },
    {
        "school": "Hawley Elementary School",
        "district": "NEWTOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90291000613",
    },
    {
        "school": "Middle Gate Elementary School",
        "district": "NEWTOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90291000614",
    },
    {
        "school": "Newtown High School",
        "district": "NEWTOWN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90291000615",
    },
    {
        "school": "Newtown Middle School",
        "district": "NEWTOWN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90291000616",
    },
    {
        "school": "Sandy Hook Elementary School",
        "district": "NEWTOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90291000617",
    },
    {
        "school": "Head O'Meadow Elementary School",
        "district": "NEWTOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90291001121",
    },
    {
        "school": "Branchville Elementary School",
        "district": "RIDGEFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90381000525",
    },
    {
        "school": "East Ridge Middle School",
        "district": "RIDGEFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90381000776",
    },
    {
        "school": "Farmingville Elementary School",
        "district": "RIDGEFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90381000777",
    },
    {
        "school": "Ridgebury Elementary School",
        "district": "RIDGEFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90381000778",
    },
    {
        "school": "Ridgefield High School",
        "district": "RIDGEFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90381000779",
    },
    {
        "school": "Scotland Elementary School",
        "district": "RIDGEFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90381000780",
    },
    {
        "school": "Veterans Park Elementary School",
        "district": "RIDGEFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90381000781",
    },
    {
        "school": "Sherman School",
        "district": "SHERMAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90408000808",
    },
    {
        "school": "Side By Side Charter School",
        "district": "Side By Side Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90001600823",
    },
    {
        "school": "Darien High School",
        "district": "DARIEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90105000164",
    },
    {
        "school": "Hindley Elementary School",
        "district": "DARIEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90105000165",
    },
    {
        "school": "Middlesex Middle School",
        "district": "DARIEN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90105000169",
    },
    {
        "school": "Ox Ridge Elementary School",
        "district": "DARIEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90105000170",
    },
    {
        "school": "Royle Elementary School",
        "district": "DARIEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90105000171",
    },
    {
        "school": "Tokeneke Elementary School",
        "district": "DARIEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90105000172",
    },
    {
        "school": "Holmes Elementary School",
        "district": "DARIEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90105000498",
    },
    {
        "school": "Parkway School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000107",
    },
    {
        "school": "Central Middle School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000295",
    },
    {
        "school": "Cos Cob School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000296",
    },
    {
        "school": "Eastern Middle School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000298",
    },
    {
        "school": "Glenville School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000299",
    },
    {
        "school": "Greenwich High School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000300",
    },
    {
        "school": "Hamilton Avenue School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000301",
    },
    {
        "school": "Julian Curtiss School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000302",
    },
    {
        "school": "New Lebanon School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000303",
    },
    {
        "school": "North Mianus School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000304",
    },
    {
        "school": "North Street School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000305",
    },
    {
        "school": "Old Greenwich School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000306",
    },
    {
        "school": "Riverside School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000308",
    },
    {
        "school": "Western Middle School",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171000309",
    },
    {
        "school": "International School At Dundee",
        "district": "GREENWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90171001288",
    },
    {
        "school": "East School",
        "district": "NEW CANAAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90270000530",
    },
    {
        "school": "New Canaan High School",
        "district": "NEW CANAAN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90270000531",
    },
    {
        "school": "Saxe Middle School",
        "district": "NEW CANAAN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90270000532",
    },
    {
        "school": "South School",
        "district": "NEW CANAAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90270000533",
    },
    {
        "school": "West School",
        "district": "NEW CANAAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90270000534",
    },
    {
        "school": "Brien McMahon High School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000638",
    },
    {
        "school": "Brookside Elementary School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000640",
    },
    {
        "school": "Columbus Magnet School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000642",
    },
    {
        "school": "Cranbury Elementary School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000643",
    },
    {
        "school": "Fox Run Elementary School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000645",
    },
    {
        "school": "Jefferson Magnet School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000648",
    },
    {
        "school": "Kendall Elementary School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000649",
    },
    {
        "school": "Marvin Elementary School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000651",
    },
    {
        "school": "Naramake Elementary School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000652",
    },
    {
        "school": "Nathan Hale Middle School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000653",
    },
    {
        "school": "Norwalk High School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000655",
    },
    {
        "school": "Ponus Ridge Middle School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000656",
    },
    {
        "school": "Roton Middle School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000657",
    },
    {
        "school": "Rowayton School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000658",
    },
    {
        "school": "Silvermine Dual Language Magnet School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000659",
    },
    {
        "school": "Tracey Magnet School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000660",
    },
    {
        "school": "West Rocks Middle School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000661",
    },
    {
        "school": "Wolfpit School",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309000662",
    },
    {
        "school": "Toquam Magnet School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000008",
    },
    {
        "school": "Scofield Middle School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000009",
    },
    {
        "school": "Hart School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000167",
    },
    {
        "school": "Cloonan School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000851",
    },
    {
        "school": "Davenport Ridge School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000852",
    },
    {
        "school": "Dolan School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000853",
    },
    {
        "school": "Julia A. Stark School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000858",
    },
    {
        "school": "K. T. Murphy School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000859",
    },
    {
        "school": "Newfield School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000860",
    },
    {
        "school": "Northeast School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000861",
    },
    {
        "school": "Rogers International School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000864",
    },
    {
        "school": "Roxbury School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000865",
    },
    {
        "school": "Springdale School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000866",
    },
    {
        "school": "Stamford High School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000867",
    },
    {
        "school": "Stillmeadow School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000868",
    },
    {
        "school": "Turn of River School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000870",
    },
    {
        "school": "Westhill High School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000871",
    },
    {
        "school": "Westover School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432000872",
    },
    {
        "school": "Rippowam Middle School",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432001353",
    },
    {
        "school": "Hurlbutt Elementary School",
        "district": "WESTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90501001045",
    },
    {
        "school": "Weston High School",
        "district": "WESTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90501001046",
    },
    {
        "school": "Weston Middle School",
        "district": "WESTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90501001047",
    },
    {
        "school": "Green's Farms School",
        "district": "WESTPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90504000960",
    },
    {
        "school": "Bedford Middle School",
        "district": "WESTPORT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90504001048",
    },
    {
        "school": "Coleytown Elementary School",
        "district": "WESTPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90504001051",
    },
    {
        "school": "King's Highway Elementary School",
        "district": "WESTPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90504001055",
    },
    {
        "school": "Long Lots School",
        "district": "WESTPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90504001056",
    },
    {
        "school": "Staples High School",
        "district": "WESTPORT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90504001058",
    },
    {
        "school": "Cider Mill School",
        "district": "WILTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90513001071",
    },
    {
        "school": "Middlebrook School",
        "district": "WILTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90513001073",
    },
    {
        "school": "Miller-Driscoll School",
        "district": "WILTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90513001075",
    },
    {
        "school": "Wilton High School",
        "district": "WILTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90513001076",
    },
    {
        "school": "Sarah Noble Intermediate School",
        "district": "NEW MILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90285001372",
    },
    {
        "school": "Anna H. Rockwell School",
        "district": "BETHEL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90027000023",
    },
    {
        "school": "Bethel High School",
        "district": "BETHEL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90027000024",
    },
    {
        "school": "Bethel Middle School",
        "district": "BETHEL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90027000025",
    },
    {
        "school": "Frank A. Berry School",
        "district": "BETHEL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90027000027",
    },
    {
        "school": "Ralph M. T. Johnson School",
        "district": "BETHEL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90027001118",
    },
    {
        "school": "Brookfield High School",
        "district": "BROOKFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90054000109",
    },
    {
        "school": "Center Elementary School",
        "district": "BROOKFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90054000110",
    },
    {
        "school": "Whisconier Middle School",
        "district": "BROOKFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90054000112",
    },
    {
        "school": "Huckleberry Hill Elementary School",
        "district": "BROOKFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90054001186",
    },
    {
        "school": "Broadview Middle School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000149",
    },
    {
        "school": "Danbury High School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000150",
    },
    {
        "school": "Great Plain School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000151",
    },
    {
        "school": "Hayestown Avenue School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000152",
    },
    {
        "school": "King Street Primary School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000153",
    },
    {
        "school": "Mill Ridge Primary School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000154",
    },
    {
        "school": "Morris Street School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000156",
    },
    {
        "school": "Park Avenue School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000157",
    },
    {
        "school": "Pembroke School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000158",
    },
    {
        "school": "Ellsworth Avenue School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000159",
    },
    {
        "school": "Rogers Park Middle School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000160",
    },
    {
        "school": "Shelter Rock School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000161",
    },
    {
        "school": "South Street School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000162",
    },
    {
        "school": "Stadley Rough School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102000163",
    },
    {
        "school": "King Street Intermediate School",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102001166",
    },
    {
        "school": "Consolidated School",
        "district": "NEW FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90273000535",
    },
    {
        "school": "New Fairfield High School",
        "district": "NEW FAIRFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90273000537",
    },
    {
        "school": "Meeting House Hill School",
        "district": "NEW FAIRFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90273001195",
    },
    {
        "school": "New Fairfield Middle School",
        "district": "NEW FAIRFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90273001224",
    },
    {
        "school": "Hill And Plain School",
        "district": "NEW MILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90285000599",
    },
    {
        "school": "New Milford High School",
        "district": "NEW MILFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90285000602",
    },
    {
        "school": "Schaghticoke Middle School",
        "district": "NEW MILFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90285000603",
    },
    {
        "school": "Northville Elementary School",
        "district": "NEW MILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90285001168",
    },
    {
        "school": "Killingly Central School",
        "district": "KILLINGLY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90207000391",
    },
    {
        "school": "Killingly High School",
        "district": "KILLINGLY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90207000392",
    },
    {
        "school": "Killingly Intermediate School",
        "district": "KILLINGLY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90207000393",
    },
    {
        "school": "Killingly Memorial School",
        "district": "KILLINGLY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90207000394",
    },
    {
        "school": "Shepard Hill Elementary School",
        "district": "PLAINFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90327000047",
    },
    {
        "school": "Moosup Elementary School",
        "district": "PLAINFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90327000692",
    },
    {
        "school": "Plainfield Central School",
        "district": "PLAINFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90327000693",
    },
    {
        "school": "Plainfield High School",
        "district": "PLAINFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90327000695",
    },
    {
        "school": "Plainfield Memorial School",
        "district": "PLAINFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90327000696",
    },
    {
        "school": "Thompson Brook School",
        "district": "AVON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90012001367",
    },
    {
        "school": "Carmen Arace Intermediate School",
        "district": "BLOOMFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90033001375",
    },
    {
        "school": "Canton Middle School",
        "district": "CANTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90069001376",
    },
    {
        "school": "Two Rivers Magnet Middle School",
        "district": "Capitol Region Education Council",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001364",
    },
    {
        "school": "West Woods Upper Elementary School",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90156001368",
    },
    {
        "school": "Breakthrough Magnet School South",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001369",
    },
    {
        "school": "Sport and Medical Sciences Academy",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001370",
    },
    {
        "school": "University High School of Science and Engineering",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001381",
    },
    {
        "school": "Capital Preparatory Magnet School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001435",
    },
    {
        "school": "Classical Magnet School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001478",
    },
    {
        "school": "Pathways Academy of Technology and Design",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001479",
    },
    {
        "school": "Woodside Intermediate School",
        "district": "CROMWELL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90099001432",
    },
    {
        "school": "Bullard-Havens Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201137",
    },
    {
        "school": "Henry Abbott Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201144",
    },
    {
        "school": "A. I. Prince Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201136",
    },
    {
        "school": "E. C. Goodwin Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201138",
    },
    {
        "school": "Howell Cheney Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201145",
    },
    {
        "school": "Jumoke Academy",
        "district": "JUMOKE ACADEMY DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90000700747",
    },
    {
        "school": "Odyssey Community School",
        "district": "Odyssey Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90000900774",
    },
    {
        "school": "Avon High School",
        "district": "AVON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90012000011",
    },
    {
        "school": "Avon Middle School",
        "district": "AVON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90012000012",
    },
    {
        "school": "Roaring Brook School",
        "district": "AVON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90012000013",
    },
    {
        "school": "Berlin High School",
        "district": "BERLIN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90021000016",
    },
    {
        "school": "Catherine M. McGee Middle School",
        "district": "BERLIN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90021000017",
    },
    {
        "school": "Emma Hart Willard School",
        "district": "BERLIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90021000018",
    },
    {
        "school": "Mary E. Griswold School",
        "district": "BERLIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90021000020",
    },
    {
        "school": "Richard D. Hubbard School",
        "district": "BERLIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90021000021",
    },
    {
        "school": "Bloomfield High School",
        "district": "BLOOMFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90033000029",
    },
    {
        "school": "Laurel School",
        "district": "BLOOMFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90033000032",
    },
    {
        "school": "Metacomet School",
        "district": "BLOOMFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90033000033",
    },
    {
        "school": "Carmen Arace Middle School",
        "district": "BLOOMFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90033000034",
    },
    {
        "school": "Chippens Hill Middle School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051000089",
    },
    {
        "school": "Bristol Central High School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051000092",
    },
    {
        "school": "Bristol Eastern High School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051000093",
    },
    {
        "school": "Edgewood School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051000096",
    },
    {
        "school": "Ellen P. Hubbell School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051000097",
    },
    {
        "school": "Greene-Hills School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051000098",
    },
    {
        "school": "Ivy Drive School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051000099",
    },
    {
        "school": "Mountain View School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051000103",
    },
    {
        "school": "Northeast Middle School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051000104",
    },
    {
        "school": "South Side School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051000105",
    },
    {
        "school": "Stafford School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051000106",
    },
    {
        "school": "Canton High School",
        "district": "CANTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90069000118",
    },
    {
        "school": "Canton Intermediate School",
        "district": "CANTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90069000119",
    },
    {
        "school": "Cherry Brook Primary School",
        "district": "CANTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90069000120",
    },
    {
        "school": "Glastonbury/East Hartford Magnet School",
        "district": "Capitol Region Education Council",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070000072",
    },
    {
        "school": "Montessori Magnet School",
        "district": "Capitol Region Education Council",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070000210",
    },
    {
        "school": "Metropolitan Learning Center for Global and International St",
        "district": "Capitol Region Education Council",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070000880",
    },
    {
        "school": "University of Hartford Magnet School",
        "district": "Capitol Region Education Council",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001357",
    },
    {
        "school": "Allgrove School",
        "district": "EAST GRANBY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90117000180",
    },
    {
        "school": "East Granby High School",
        "district": "EAST GRANBY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90117000181",
    },
    {
        "school": "East Granby Middle School",
        "district": "EAST GRANBY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90117000182",
    },
    {
        "school": "R. Dudley Seymour School",
        "district": "EAST GRANBY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90117000183",
    },
    {
        "school": "Broad Brook Elementary School",
        "district": "EAST WINDSOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90135000228",
    },
    {
        "school": "East Windsor High School",
        "district": "EAST WINDSOR SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90135000229",
    },
    {
        "school": "East Windsor Middle School",
        "district": "EAST WINDSOR SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90135000230",
    },
    {
        "school": "Farmington High School",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90156000273",
    },
    {
        "school": "Irving A. Robbins Middle School",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90156000274",
    },
    {
        "school": "Noah Wallace School",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90156000275",
    },
    {
        "school": "Union School",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90156000276",
    },
    {
        "school": "West District School",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90156000277",
    },
    {
        "school": "East Farms School",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90156001206",
    },
    {
        "school": "Gideon Welles School",
        "district": "GLASTONBURY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90162000279",
    },
    {
        "school": "Buttonball Lane School",
        "district": "GLASTONBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90162000280",
    },
    {
        "school": "Smith Middle School",
        "district": "GLASTONBURY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90162000282",
    },
    {
        "school": "Glastonbury High School",
        "district": "GLASTONBURY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90162000283",
    },
    {
        "school": "Hebron Avenue School",
        "district": "GLASTONBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90162000284",
    },
    {
        "school": "Hopewell School",
        "district": "GLASTONBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90162000286",
    },
    {
        "school": "Naubuc School",
        "district": "GLASTONBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90162000287",
    },
    {
        "school": "Granby Memorial High School",
        "district": "GRANBY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90168000289",
    },
    {
        "school": "Kelly Lane Primary School",
        "district": "GRANBY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90168000290",
    },
    {
        "school": "Granby Memorial Middle School",
        "district": "GRANBY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90168000291",
    },
    {
        "school": "Wells Road Intermediate School",
        "district": "GRANBY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90168000293",
    },
    {
        "school": "Sanchez School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000026",
    },
    {
        "school": "Burns Latino Studies Academy",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000357",
    },
    {
        "school": "Burr School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000358",
    },
    {
        "school": "Bellizzi School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000360",
    },
    {
        "school": "STEM Magnet at Annie Fisher School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000362",
    },
    {
        "school": "M. D. Fox School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000364",
    },
    {
        "school": "Environmental Sciences Magnet at Hooker School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000366",
    },
    {
        "school": "Kennelly School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000368",
    },
    {
        "school": "M. L. King Jr. Middle School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000369",
    },
    {
        "school": "Kinsella Magnet School of Performing Arts",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000370",
    },
    {
        "school": "McDonough Middle School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000371",
    },
    {
        "school": "Naylor/CCSU Leadership Academy",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000372",
    },
    {
        "school": "Parkville Community School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000373",
    },
    {
        "school": "Rawson School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000376",
    },
    {
        "school": "SAND School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000377",
    },
    {
        "school": "Milner Middle School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000381",
    },
    {
        "school": "Webster Micro Society Magnet School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000383",
    },
    {
        "school": "West Middle School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000384",
    },
    {
        "school": "Wish Museum School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000385",
    },
    {
        "school": "Expeditionary Learning Academy at Moylan School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192000636",
    },
    {
        "school": "Betances Learning Lab Magnet School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001192",
    },
    {
        "school": "Hartford Magnet Trinity College Academy",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001295",
    },
    {
        "school": "Hartland School",
        "district": "HARTLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90195000386",
    },
    {
        "school": "Bowers School",
        "district": "MANCHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90231000417",
    },
    {
        "school": "Buckley School",
        "district": "MANCHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90231000418",
    },
    {
        "school": "Highland Park School",
        "district": "MANCHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90231000420",
    },
    {
        "school": "Illing Middle School",
        "district": "MANCHESTER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90231000421",
    },
    {
        "school": "Keeney School",
        "district": "MANCHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90231000422",
    },
    {
        "school": "Manchester High School",
        "district": "MANCHESTER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90231000424",
    },
    {
        "school": "Martin School",
        "district": "MANCHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90231000425",
    },
    {
        "school": "Verplanck School",
        "district": "MANCHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90231000429",
    },
    {
        "school": "Waddell School",
        "district": "MANCHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90231000430",
    },
    {
        "school": "Elmer Thienes-Mary Hall Elementary School",
        "district": "MARLBOROUGH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90237000437",
    },
    {
        "school": "Chamberlain  Elementary School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000509",
    },
    {
        "school": "DiLoreto Elementary & Middle School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000510",
    },
    {
        "school": "Gaffney Elementary School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000512",
    },
    {
        "school": "Holmes Elementary School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000513",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000514",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000515",
    },
    {
        "school": "Northend Elementary School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000517",
    },
    {
        "school": "Pulaski Middle School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000518",
    },
    {
        "school": "New Britain High School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000521",
    },
    {
        "school": "Slade Middle School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000522",
    },
    {
        "school": "Smalley Elementary School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000523",
    },
    {
        "school": "Smith Elementary School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000524",
    },
    {
        "school": "Vance Elementary School",
        "district": "NEW BRITAIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90267000527",
    },
    {
        "school": "Elizabeth Green School",
        "district": "NEWINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90288000604",
    },
    {
        "school": "John Paterson School",
        "district": "NEWINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90288000606",
    },
    {
        "school": "Martin Kellogg Middle School",
        "district": "NEWINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90288000608",
    },
    {
        "school": "Newington High School",
        "district": "NEWINGTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90288000610",
    },
    {
        "school": "Anna Reynolds School",
        "district": "NEWINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90288000611",
    },
    {
        "school": "Ruth Chaffee School",
        "district": "NEWINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90288000612",
    },
    {
        "school": "John Wallace Middle School",
        "district": "NEWINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90288001120",
    },
    {
        "school": "Middle School of Plainville",
        "district": "PLAINVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90330000048",
    },
    {
        "school": "Frank T. Wheeler School",
        "district": "PLAINVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90330000699",
    },
    {
        "school": "Linden Street School",
        "district": "PLAINVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90330000701",
    },
    {
        "school": "Louis Toffolon School",
        "district": "PLAINVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90330000702",
    },
    {
        "school": "Plainville High School",
        "district": "PLAINVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90330000703",
    },
    {
        "school": "Har-Bur Middle School",
        "district": "REGIONAL SCHOOL DISTRICT 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90352000727",
    },
    {
        "school": "Lake Garda Elementary School",
        "district": "REGIONAL SCHOOL DISTRICT 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90352000729",
    },
    {
        "school": "Lewis S. Mills High School",
        "district": "REGIONAL SCHOOL DISTRICT 10",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90352000730",
    },
    {
        "school": "Albert D. Griswold Middle School",
        "district": "ROCKY HILL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90384000782",
    },
    {
        "school": "Myrtle H. Stevens School",
        "district": "ROCKY HILL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90384000784",
    },
    {
        "school": "Rocky Hill High School",
        "district": "ROCKY HILL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90384000785",
    },
    {
        "school": "West Hill School",
        "district": "ROCKY HILL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90384000786",
    },
    {
        "school": "Central School",
        "district": "SIMSBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90411000810",
    },
    {
        "school": "Henry James Memorial School",
        "district": "SIMSBURY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90411000811",
    },
    {
        "school": "Latimer Lane School",
        "district": "SIMSBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90411000812",
    },
    {
        "school": "Simsbury High School",
        "district": "SIMSBURY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90411000813",
    },
    {
        "school": "Squadron Line School",
        "district": "SIMSBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90411000814",
    },
    {
        "school": "Tariffville School",
        "district": "SIMSBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90411000815",
    },
    {
        "school": "Tootin' Hills School",
        "district": "SIMSBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90411000816",
    },
    {
        "school": "Philip R. Smith School",
        "district": "SOUTH WINDSOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90417000821",
    },
    {
        "school": "Eli Terry School",
        "district": "SOUTH WINDSOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90417000822",
    },
    {
        "school": "Orchard Hill School",
        "district": "SOUTH WINDSOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90417000824",
    },
    {
        "school": "Pleasant Valley School",
        "district": "SOUTH WINDSOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90417000825",
    },
    {
        "school": "South Windsor High School",
        "district": "SOUTH WINDSOR SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90417000826",
    },
    {
        "school": "Timothy Edwards School",
        "district": "SOUTH WINDSOR SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90417000827",
    },
    {
        "school": "Derynoski Elementary School",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423000829",
    },
    {
        "school": "Flanders Elementary School",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423000830",
    },
    {
        "school": "Hatton Elementary School",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423000831",
    },
    {
        "school": "John F. Kennedy Middle School",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423000832",
    },
    {
        "school": "Joseph A. Depaolo Middle School",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423000833",
    },
    {
        "school": "Oshana Elementary School",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423000836",
    },
    {
        "school": "South End Elementary School",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423000837",
    },
    {
        "school": "Southington High School",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423000838",
    },
    {
        "school": "Strong Elementary School",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423000839",
    },
    {
        "school": "Thalberg Elementary School",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423000840",
    },
    {
        "school": "Urbin T. Kelley School",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423000841",
    },
    {
        "school": "Alfred W. Hanmer School",
        "district": "WETHERSFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90507001059",
    },
    {
        "school": "Charles Wright School",
        "district": "WETHERSFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90507001060",
    },
    {
        "school": "Emerson-Williams School",
        "district": "WETHERSFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90507001061",
    },
    {
        "school": "Highcrest School",
        "district": "WETHERSFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90507001064",
    },
    {
        "school": "Samuel B. Webb Elementary School",
        "district": "WETHERSFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90507001065",
    },
    {
        "school": "Silas Deane Middle School",
        "district": "WETHERSFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90507001066",
    },
    {
        "school": "Wethersfield High School",
        "district": "WETHERSFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90507001068",
    },
    {
        "school": "Clover Street School",
        "district": "WINDSOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90522001087",
    },
    {
        "school": "John F. Kennedy School",
        "district": "WINDSOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90522001089",
    },
    {
        "school": "Oliver Ellsworth School",
        "district": "WINDSOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90522001092",
    },
    {
        "school": "Poquonock Elementary School",
        "district": "WINDSOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90522001093",
    },
    {
        "school": "Sage Park Middle School",
        "district": "WINDSOR SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90522001095",
    },
    {
        "school": "Windsor High School",
        "district": "WINDSOR SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90522001096",
    },
    {
        "school": "Oliver Wolcott Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201148",
    },
    {
        "school": "Ann Antolini School",
        "district": "NEW HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90276000538",
    },
    {
        "school": "Bakerville Consolidated School",
        "district": "NEW HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90276000539",
    },
    {
        "school": "New Hartford Elementary School",
        "district": "NEW HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90276000540",
    },
    {
        "school": "Harwinton Consolidated School",
        "district": "REGIONAL SCHOOL DISTRICT 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90352000728",
    },
    {
        "school": "Vinal Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201150",
    },
    {
        "school": "Cromwell High School",
        "district": "CROMWELL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90099000145",
    },
    {
        "school": "Edna C. Stevens School",
        "district": "CROMWELL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90099000146",
    },
    {
        "school": "Cromwell Middle School",
        "district": "CROMWELL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90099000147",
    },
    {
        "school": "Center School",
        "district": "EAST HAMPTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90123000186",
    },
    {
        "school": "East Hampton High School",
        "district": "EAST HAMPTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90123000187",
    },
    {
        "school": "East Hampton Middle School",
        "district": "EAST HAMPTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90123000188",
    },
    {
        "school": "Memorial School",
        "district": "EAST HAMPTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90123000189",
    },
    {
        "school": "Bielefield School",
        "district": "MIDDLETOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90249000453",
    },
    {
        "school": "Farm Hill School",
        "district": "MIDDLETOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90249000455",
    },
    {
        "school": "Keigwin Middle School",
        "district": "MIDDLETOWN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90249000456",
    },
    {
        "school": "Lawrence School",
        "district": "MIDDLETOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90249000457",
    },
    {
        "school": "MacDonough School",
        "district": "MIDDLETOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90249000458",
    },
    {
        "school": "Woodrow Wilson Middle School",
        "district": "MIDDLETOWN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90249000459",
    },
    {
        "school": "Moody School",
        "district": "MIDDLETOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90249000460",
    },
    {
        "school": "Snow School",
        "district": "MIDDLETOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90249000461",
    },
    {
        "school": "Spencer School",
        "district": "MIDDLETOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90249000462",
    },
    {
        "school": "Wesley School",
        "district": "MIDDLETOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90249000464",
    },
    {
        "school": "Middletown High School",
        "district": "MIDDLETOWN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90249000465",
    },
    {
        "school": "Eli Whitney Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201140",
    },
    {
        "school": "Emmett O'Brien Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201141",
    },
    {
        "school": "H. C. Wilcox Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201142",
    },
    {
        "school": "Platt Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201149",
    },
    {
        "school": "W. F. Kaynor Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201151",
    },
    {
        "school": "Ella T. Grasso Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201139",
    },
    {
        "school": "Norwich Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201147",
    },
    {
        "school": "Bacon Academy",
        "district": "COLCHESTER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90084000135",
    },
    {
        "school": "William J. Johnston Middle School",
        "district": "COLCHESTER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90084000136",
    },
    {
        "school": "Jack Jackter Intermediate School",
        "district": "COLCHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90084000137",
    },
    {
        "school": "E. O. Smith High School",
        "district": "REGIONAL SCHOOL DISTRICT 19",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90000501215",
    },
    {
        "school": "Bolton Center School",
        "district": "BOLTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90036000036",
    },
    {
        "school": "Bolton High School",
        "district": "BOLTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90036000037",
    },
    {
        "school": "Horace W. Porter School",
        "district": "COLUMBIA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90090000139",
    },
    {
        "school": "Capt. Nathan Hale School",
        "district": "COVENTRY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90096000141",
    },
    {
        "school": "Coventry Grammar School",
        "district": "COVENTRY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90096000142",
    },
    {
        "school": "Coventry High School",
        "district": "COVENTRY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90096000143",
    },
    {
        "school": "George Hersey Robertson School",
        "district": "COVENTRY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90096000144",
    },
    {
        "school": "Center School",
        "district": "ELLINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90144000235",
    },
    {
        "school": "Crystal Lake School",
        "district": "ELLINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90144000236",
    },
    {
        "school": "Ellington High School",
        "district": "ELLINGTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90144000237",
    },
    {
        "school": "Ellington Middle School",
        "district": "ELLINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90144000238",
    },
    {
        "school": "Windermere School",
        "district": "ELLINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90144000239",
    },
    {
        "school": "Gilead Hill School",
        "district": "HEBRON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90201000387",
    },
    {
        "school": "Hebron Elementary School",
        "district": "HEBRON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90201000388",
    },
    {
        "school": "Annie E. Vinton School",
        "district": "MANSFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90234000432",
    },
    {
        "school": "Mansfield Middle School",
        "district": "MANSFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90234000433",
    },
    {
        "school": "Dorothy C. Goodwin School",
        "district": "MANSFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90234000434",
    },
    {
        "school": "Southeast Elementary School",
        "district": "MANSFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90234000435",
    },
    {
        "school": "RHAM High School",
        "district": "REGIONAL SCHOOL DISTRICT 08",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90375000772",
    },
    {
        "school": "RHAM Middle School",
        "district": "REGIONAL SCHOOL DISTRICT 08",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90375001210",
    },
    {
        "school": "Stafford Middle School",
        "district": "STAFFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90429000061",
    },
    {
        "school": "Stafford High School",
        "district": "STAFFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90429000845",
    },
    {
        "school": "Staffordville School",
        "district": "STAFFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90429000847",
    },
    {
        "school": "West Stafford School",
        "district": "STAFFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90429000848",
    },
    {
        "school": "Tolland Intermediate School",
        "district": "TOLLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90456000913",
    },
    {
        "school": "Tolland High School",
        "district": "TOLLAND SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90456000914",
    },
    {
        "school": "Tolland Middle School",
        "district": "TOLLAND SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90456000915",
    },
    {
        "school": "Birch Grove Primary School",
        "district": "TOLLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90456000948",
    },
    {
        "school": "Union Elementary School",
        "district": "UNION SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90465000938",
    },
    {
        "school": "Center Road School",
        "district": "VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90468000939",
    },
    {
        "school": "Lake Street School",
        "district": "VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90468000940",
    },
    {
        "school": "Maple Street School",
        "district": "VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90468000941",
    },
    {
        "school": "Northeast School",
        "district": "VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90468000942",
    },
    {
        "school": "Rockville High School",
        "district": "VERNON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90468000943",
    },
    {
        "school": "Skinner Road School",
        "district": "VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90468000944",
    },
    {
        "school": "Vernon Center Middle School",
        "district": "VERNON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90468000947",
    },
    {
        "school": "Center School",
        "district": "WILLINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90510001069",
    },
    {
        "school": "Hall Memorial School",
        "district": "WILLINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90510001070",
    },
    {
        "school": "H. H. Ellis Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201143",
    },
    {
        "school": "Windham Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201152",
    },
    {
        "school": "Explorations",
        "district": "EXPLORATIONS DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90001800834",
    },
    {
        "school": "Barkhamsted Elementary School",
        "district": "BARKHAMSTED SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90015000015",
    },
    {
        "school": "Lee H. Kellogg School",
        "district": "CANAAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90063000115",
    },
    {
        "school": "Colebrook Consolidated School",
        "district": "COLEBROOK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90087000138",
    },
    {
        "school": "Cornwall Consolidated School",
        "district": "CORNWALL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90093000140",
    },
    {
        "school": "Kent Center School",
        "district": "KENT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90204000389",
    },
    {
        "school": "Center School",
        "district": "LITCHFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90222000405",
    },
    {
        "school": "Litchfield High School",
        "district": "LITCHFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90222000406",
    },
    {
        "school": "Litchfield Intermediate School",
        "district": "LITCHFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90222000407",
    },
    {
        "school": "Botelle Elementary School",
        "district": "NORFOLK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90294000618",
    },
    {
        "school": "North Canaan Elementary School",
        "district": "NORTH CANAAN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90300000626",
    },
    {
        "school": "Eli Terry Jr. Middle School",
        "district": "PLYMOUTH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90333000705",
    },
    {
        "school": "Plymouth Center School",
        "district": "PLYMOUTH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90333000706",
    },
    {
        "school": "Terryville High School",
        "district": "PLYMOUTH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90333001199",
    },
    {
        "school": "Goshen Center School",
        "district": "REGIONAL SCHOOL DISTRICT 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90351500723",
    },
    {
        "school": "James Morris School",
        "district": "REGIONAL SCHOOL DISTRICT 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90351500724",
    },
    {
        "school": "Wamogo Regional High School",
        "district": "REGIONAL SCHOOL DISTRICT 06",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90351500725",
    },
    {
        "school": "Warren Elementary School",
        "district": "REGIONAL SCHOOL DISTRICT 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90351500726",
    },
    {
        "school": "Booth Free School",
        "district": "REGIONAL SCHOOL DISTRICT 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353000731",
    },
    {
        "school": "The Burnham School",
        "district": "REGIONAL SCHOOL DISTRICT 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353000734",
    },
    {
        "school": "Washington Primary School",
        "district": "REGIONAL SCHOOL DISTRICT 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353000735",
    },
    {
        "school": "Housatonic Valley Regional High School",
        "district": "REGIONAL SCHOOL DISTRICT 01",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90360000766",
    },
    {
        "school": "Northwestern Regional High School",
        "district": "REGIONAL SCHOOL DISTRICT 07",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90372000771",
    },
    {
        "school": "Northwestern Regional Middle School",
        "district": "REGIONAL SCHOOL DISTRICT 07",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90372001226",
    },
    {
        "school": "Salisbury Central School",
        "district": "SALISBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90393000788",
    },
    {
        "school": "Sharon Center School",
        "district": "SHARON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90402000795",
    },
    {
        "school": "Batcheller Early Education Center",
        "district": "WINCHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90516001077",
    },
    {
        "school": "Pearson School",
        "district": "WINCHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90516001080",
    },
    {
        "school": "The Gilbert School",
        "district": "The Gilbert School District",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90537201222",
    },
    {
        "school": "Bethlehem Elementary School",
        "district": "REGIONAL SCHOOL DISTRICT 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353600743",
    },
    {
        "school": "Mitchell Elementary School",
        "district": "REGIONAL SCHOOL DISTRICT 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353600744",
    },
    {
        "school": "Nonnewaug High School",
        "district": "REGIONAL SCHOOL DISTRICT 14",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353600745",
    },
    {
        "school": "Woodbury Middle School",
        "district": "REGIONAL SCHOOL DISTRICT 14",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353600746",
    },
    {
        "school": "Black Rock School",
        "district": "THOMASTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90450000906",
    },
    {
        "school": "Thomaston High School",
        "district": "THOMASTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90450000908",
    },
    {
        "school": "Thomaston Center School",
        "district": "THOMASTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90450001117",
    },
    {
        "school": "Brownstone Intermediate School",
        "district": "PORTLAND SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90339001393",
    },
    {
        "school": "Dr. Robert H. Brown Intermediate School",
        "district": "MADISON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90228001382",
    },
    {
        "school": "Walter C. Polson Middle School",
        "district": "MADISON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90228001480",
    },
    {
        "school": "John S. Martinez Sea and Sky STEM School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001386",
    },
    {
        "school": "Ross/Woodward School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001387",
    },
    {
        "school": "King/Robinson Magnet School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001388",
    },
    {
        "school": "Roberto Clemente Leadership Academy for Global Awareness",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001483",
    },
    {
        "school": "Celentano BioTech Health and Medical Magnet School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001484",
    },
    {
        "school": "Metropolitan Business Academy",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001485",
    },
    {
        "school": "Gildersleeve School",
        "district": "PORTLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90339000711",
    },
    {
        "school": "Portland High School",
        "district": "PORTLAND SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90339000712",
    },
    {
        "school": "Portland Middle School",
        "district": "PORTLAND SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90339000713",
    },
    {
        "school": "Valley View School",
        "district": "PORTLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90339000714",
    },
    {
        "school": "Coginchaug Regional High School",
        "district": "REGIONAL SCHOOL DISTRICT 13",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353500737",
    },
    {
        "school": "Frank Ward Strong School",
        "district": "REGIONAL SCHOOL DISTRICT 13",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353500739",
    },
    {
        "school": "Frederick Brewster School",
        "district": "REGIONAL SCHOOL DISTRICT 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353500740",
    },
    {
        "school": "John Lyman School",
        "district": "REGIONAL SCHOOL DISTRICT 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353500741",
    },
    {
        "school": "Middlefield Memorial School",
        "district": "REGIONAL SCHOOL DISTRICT 13",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353500742",
    },
    {
        "school": "Old Saybrook Middle School",
        "district": "OLD SAYBROOK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90318000007",
    },
    {
        "school": "Kathleen E. Goodwin School",
        "district": "OLD SAYBROOK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90318000681",
    },
    {
        "school": "Old Saybrook Senior High School",
        "district": "OLD SAYBROOK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90318000684",
    },
    {
        "school": "Chester Elementary School",
        "district": "CHESTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90078000130",
    },
    {
        "school": "Lewin G. Joel Jr. School",
        "district": "CLINTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90081000132",
    },
    {
        "school": "Jared Eliot School",
        "district": "CLINTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90081000133",
    },
    {
        "school": "The Morgan School",
        "district": "CLINTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90081000134",
    },
    {
        "school": "Deep River Elementary School",
        "district": "DEEP RIVER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90108000173",
    },
    {
        "school": "East Haddam Elementary School",
        "district": "EAST HADDAM SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90120000184",
    },
    {
        "school": "Nathan Hale-Ray High School",
        "district": "EAST HADDAM SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90120000185",
    },
    {
        "school": "Nathan Hale-Ray Middle School",
        "district": "EAST HADDAM SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90120000198",
    },
    {
        "school": "Essex Elementary School",
        "district": "ESSEX SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90150000255",
    },
    {
        "school": "Burr District Elementary School",
        "district": "REGIONAL SCHOOL DISTRICT 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353900757",
    },
    {
        "school": "Haddam-Killingworth High School",
        "district": "REGIONAL SCHOOL DISTRICT 17",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353900759",
    },
    {
        "school": "Killingworth Elementary School",
        "district": "REGIONAL SCHOOL DISTRICT 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353900760",
    },
    {
        "school": "Haddam-Killingworth Middle School",
        "district": "REGIONAL SCHOOL DISTRICT 17",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353901201",
    },
    {
        "school": "John Winthrop Middle School",
        "district": "REGIONAL SCHOOL DISTRICT 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90363000767",
    },
    {
        "school": "Valley Regional High School",
        "district": "REGIONAL SCHOOL DISTRICT 04",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90363000768",
    },
    {
        "school": "Daisy Ingraham School",
        "district": "WESTBROOK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90498001042",
    },
    {
        "school": "Westbrook Middle School",
        "district": "WESTBROOK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90498001043",
    },
    {
        "school": "Westbrook High School",
        "district": "WESTBROOK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90498001044",
    },
    {
        "school": "Common Ground High School",
        "district": "Common Ground High School District",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90001400807",
    },
    {
        "school": "Amistad Academy",
        "district": "AMISTAD ACADEMY DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90002400981",
    },
    {
        "school": "Wintergreen Interdistrict  Magnet School",
        "district": "Area Cooperative Educational Services",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90007000884",
    },
    {
        "school": "Thomas Edison Magnet Middle School",
        "district": "Area Cooperative Educational Services",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90007001358",
    },
    {
        "school": "Branford High School",
        "district": "BRANFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90042000039",
    },
    {
        "school": "Francis Walsh Intermediate School",
        "district": "BRANFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90042000041",
    },
    {
        "school": "Mary T. Murphy School",
        "district": "BRANFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90042000042",
    },
    {
        "school": "Mary R. Tisko School",
        "district": "BRANFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90042000043",
    },
    {
        "school": "John B. Sliney School",
        "district": "BRANFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90042001119",
    },
    {
        "school": "Chapman School",
        "district": "CHESHIRE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90075000122",
    },
    {
        "school": "Cheshire High School",
        "district": "CHESHIRE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90075000123",
    },
    {
        "school": "Dodd Middle School",
        "district": "CHESHIRE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90075000125",
    },
    {
        "school": "Doolittle School",
        "district": "CHESHIRE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90075000126",
    },
    {
        "school": "Highland School",
        "district": "CHESHIRE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90075000127",
    },
    {
        "school": "Norton School",
        "district": "CHESHIRE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90075000129",
    },
    {
        "school": "Deer Run School",
        "district": "EAST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90129000214",
    },
    {
        "school": "Dominick H. Ferrara School",
        "district": "EAST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90129000215",
    },
    {
        "school": "East Haven High School",
        "district": "EAST HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90129000216",
    },
    {
        "school": "Joseph Melillo Middle School",
        "district": "EAST HAVEN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90129000217",
    },
    {
        "school": "Grove J. Tuttle School",
        "district": "EAST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90129000218",
    },
    {
        "school": "Momauguin School",
        "district": "EAST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90129000219",
    },
    {
        "school": "Carbone School/East Haven Academy",
        "district": "EAST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90129000605",
    },
    {
        "school": "Overbrook Early Learning Center",
        "district": "EAST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90129001350",
    },
    {
        "school": "A. Baldwin Middle School",
        "district": "GUILFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90180000328",
    },
    {
        "school": "A. W. Cox School",
        "district": "GUILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90180000329",
    },
    {
        "school": "Calvin Leete School",
        "district": "GUILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90180000330",
    },
    {
        "school": "E. C. Adams Middle School",
        "district": "GUILFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90180000331",
    },
    {
        "school": "Guilford High School",
        "district": "GUILFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90180000332",
    },
    {
        "school": "Guilford Lakes School",
        "district": "GUILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90180000333",
    },
    {
        "school": "Melissa Jones School",
        "district": "GUILFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90180000334",
    },
    {
        "school": "Bear Path School",
        "district": "HAMDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90186000336",
    },
    {
        "school": "Church Street School",
        "district": "HAMDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90186000337",
    },
    {
        "school": "Dunbar Hill School",
        "district": "HAMDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90186000338",
    },
    {
        "school": "Hamden High School",
        "district": "HAMDEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90186000339",
    },
    {
        "school": "Helen Street School",
        "district": "HAMDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90186000341",
    },
    {
        "school": "Hamden Middle School",
        "district": "HAMDEN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90186000342",
    },
    {
        "school": "Ridge Hill School",
        "district": "HAMDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90186000345",
    },
    {
        "school": "Shepherd Glen School",
        "district": "HAMDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90186000346",
    },
    {
        "school": "Spring Glen School",
        "district": "HAMDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90186000348",
    },
    {
        "school": "West Woods School",
        "district": "HAMDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90186000349",
    },
    {
        "school": "J. Milton Jeffrey Elementary School",
        "district": "MADISON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90228000410",
    },
    {
        "school": "Daniel Hand High School",
        "district": "MADISON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90228000411",
    },
    {
        "school": "Kathleen H. Ryerson Elementary School",
        "district": "MADISON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90228000413",
    },
    {
        "school": "Benjamin Franklin School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240000439",
    },
    {
        "school": "Casimir Pulaski School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240000440",
    },
    {
        "school": "Francis T. Maloney High School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240000441",
    },
    {
        "school": "Hanover School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240000442",
    },
    {
        "school": "Israel Putnam School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240000443",
    },
    {
        "school": "John Barry School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240000445",
    },
    {
        "school": "Lincoln Middle School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240000447",
    },
    {
        "school": "Nathan Hale School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240000448",
    },
    {
        "school": "Orville H. Platt High School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240000449",
    },
    {
        "school": "Roger Sherman School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240000450",
    },
    {
        "school": "Thomas Hooker School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240000451",
    },
    {
        "school": "Washington Middle School",
        "district": "MERIDEN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90240001194",
    },
    {
        "school": "Barnard Environmental Magnet School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000542",
    },
    {
        "school": "Beecher School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000543",
    },
    {
        "school": "Benjamin Jepson Magnet School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000544",
    },
    {
        "school": "Betsy Ross Arts Magnet School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000545",
    },
    {
        "school": "Bishop Woods Architecture and Design Magnet School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000546",
    },
    {
        "school": "New Haven Academy",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000547",
    },
    {
        "school": "Columbus Family Academy",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000549",
    },
    {
        "school": "Clinton Avenue School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000550",
    },
    {
        "school": "Davis Academy for Arts & Design Innovation",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000551",
    },
    {
        "school": "East Rock Community Magnet School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000552",
    },
    {
        "school": "Edgewood School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000553",
    },
    {
        "school": "Fair Haven School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000554",
    },
    {
        "school": "Hill Regional Career High School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000556",
    },
    {
        "school": "High School In The Community",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000558",
    },
    {
        "school": "Hill Central Music Academy",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000559",
    },
    {
        "school": "James Hillhouse High School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000563",
    },
    {
        "school": "Lincoln-Bassett School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000566",
    },
    {
        "school": "Nathan Hale School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000568",
    },
    {
        "school": "Augusta Lewis Troup School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000580",
    },
    {
        "school": "Truman School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000581",
    },
    {
        "school": "Conte/West Hills Magnet School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000584",
    },
    {
        "school": "Wilbur Cross High School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000585",
    },
    {
        "school": "Wexler/Grant Community School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000586",
    },
    {
        "school": "Worthington Hooker School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000588",
    },
    {
        "school": "West Rock Authors Academy",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279000647",
    },
    {
        "school": "Cooperative High School - Inter-District Magnet",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001207",
    },
    {
        "school": "Sound School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001216",
    },
    {
        "school": "Jerome Harrison School",
        "district": "North Branford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90297000620",
    },
    {
        "school": "North Branford High School",
        "district": "North Branford School District",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90297000621",
    },
    {
        "school": "North Branford Intermediate School",
        "district": "North Branford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90297000622",
    },
    {
        "school": "Totoket Valley Elementary School",
        "district": "North Branford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90297000623",
    },
    {
        "school": "Clintonville Elementary School",
        "district": "NORTH HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90303000627",
    },
    {
        "school": "Green Acres Elementary School",
        "district": "NORTH HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90303000628",
    },
    {
        "school": "Montowese Elementary School",
        "district": "NORTH HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90303000630",
    },
    {
        "school": "North Haven High School",
        "district": "NORTH HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90303000631",
    },
    {
        "school": "North Haven Middle School",
        "district": "NORTH HAVEN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90303000632",
    },
    {
        "school": "Ridge Road Elementary School",
        "district": "NORTH HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90303000633",
    },
    {
        "school": "Peck Place School",
        "district": "ORANGE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90321000687",
    },
    {
        "school": "Race Brook School",
        "district": "ORANGE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90321000688",
    },
    {
        "school": "Turkey Hill School",
        "district": "ORANGE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90321000689",
    },
    {
        "school": "Mary L. Tracy School",
        "district": "ORANGE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90321001225",
    },
    {
        "school": "Mary G. Fritz Elementary School of Yalesville",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474000536",
    },
    {
        "school": "Cook Hill School",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474000950",
    },
    {
        "school": "Dag Hammarskjold Middle School",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474000951",
    },
    {
        "school": "Evarts C. Stevens School",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474000952",
    },
    {
        "school": "Highland School",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474000953",
    },
    {
        "school": "James H. Moran Middle School",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474000954",
    },
    {
        "school": "Lyman Hall High School",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474000955",
    },
    {
        "school": "Mark T. Sheehan High School",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474000956",
    },
    {
        "school": "Moses Y. Beach School",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474000957",
    },
    {
        "school": "Pond Hill School",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474000959",
    },
    {
        "school": "Rock Hill School",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474000961",
    },
    {
        "school": "Parker Farms School",
        "district": "WALLINGFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90474001213",
    },
    {
        "school": "Alma E. Pagels School",
        "district": "WEST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90495001027",
    },
    {
        "school": "Edith E. Mackrille School",
        "district": "WEST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90495001033",
    },
    {
        "school": "Forest School",
        "district": "WEST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90495001035",
    },
    {
        "school": "Harry M. Bailey Middle School",
        "district": "WEST HAVEN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90495001036",
    },
    {
        "school": "Carrigan 5/6 Intermediate School",
        "district": "WEST HAVEN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90495001037",
    },
    {
        "school": "Savin Rock Community School",
        "district": "WEST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90495001038",
    },
    {
        "school": "Seth G. Haley School",
        "district": "WEST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90495001039",
    },
    {
        "school": "Washington School",
        "district": "WEST HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90495001040",
    },
    {
        "school": "West Haven High School",
        "district": "WEST HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90495001041",
    },
    {
        "school": "Preston Veterans' Memorial School",
        "district": "PRESTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90342001466",
    },
    {
        "school": "The Friendship School",
        "district": "LEARN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90345001430",
    },
    {
        "school": "Lebanon Middle School",
        "district": "LEBANON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90213000028",
    },
    {
        "school": "Lebanon Elementary School",
        "district": "LEBANON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90213000395",
    },
    {
        "school": "Lyman Memorial High School",
        "district": "LEBANON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90213000396",
    },
    {
        "school": "Voluntown Elementary School",
        "district": "VOLUNTOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90471000949",
    },
    {
        "school": "Integrated Day Charter School",
        "district": "Integrated Day Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90001000775",
    },
    {
        "school": "Interdistrict School For Arts And Communication",
        "district": "Interdistrict School for Arts and Comm District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90001100797",
    },
    {
        "school": "Fields Memorial School",
        "district": "BOZRAH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90039000038",
    },
    {
        "school": "East Lyme High School",
        "district": "EAST LYME SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90132000223",
    },
    {
        "school": "East Lyme Middle School",
        "district": "EAST LYME SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90132000224",
    },
    {
        "school": "Flanders School",
        "district": "EAST LYME SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90132000225",
    },
    {
        "school": "Lillie B. Haynes School",
        "district": "EAST LYME SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90132000226",
    },
    {
        "school": "Niantic Center School",
        "district": "EAST LYME SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90132000227",
    },
    {
        "school": "Franklin Elementary School",
        "district": "FRANKLIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90159000278",
    },
    {
        "school": "Griswold Middle School",
        "district": "GRISWOLD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90174000019",
    },
    {
        "school": "Griswold Elementary School",
        "district": "GRISWOLD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90174000310",
    },
    {
        "school": "Griswold High School",
        "district": "GRISWOLD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90174000311",
    },
    {
        "school": "Carl C. Cutler Middle School",
        "district": "GROTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90177000312",
    },
    {
        "school": "Charles Barnum School",
        "district": "GROTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90177000313",
    },
    {
        "school": "Claude Chester School",
        "district": "GROTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90177000314",
    },
    {
        "school": "Robert E. Fitch High School",
        "district": "GROTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90177000318",
    },
    {
        "school": "Mary Morrisson School",
        "district": "GROTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90177000321",
    },
    {
        "school": "S. B. Butler School",
        "district": "GROTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90177000325",
    },
    {
        "school": "West Side Middle School",
        "district": "GROTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90177000326",
    },
    {
        "school": "Gales Ferry School",
        "district": "LEDYARD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90216000397",
    },
    {
        "school": "Gallup Hill School",
        "district": "LEDYARD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90216000398",
    },
    {
        "school": "Juliet W. Long School",
        "district": "LEDYARD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90216000399",
    },
    {
        "school": "Ledyard High School",
        "district": "LEDYARD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90216000401",
    },
    {
        "school": "Ledyard Middle School",
        "district": "LEDYARD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90216000402",
    },
    {
        "school": "Lisbon Central School",
        "district": "LISBON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90219000403",
    },
    {
        "school": "Leonard J. Tyl Middle School",
        "district": "MONTVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90258000035",
    },
    {
        "school": "Dr. Charles E. Murphy School",
        "district": "MONTVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90258000492",
    },
    {
        "school": "Mohegan School",
        "district": "MONTVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90258000494",
    },
    {
        "school": "Montville High School",
        "district": "MONTVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90258000495",
    },
    {
        "school": "Oakdale School",
        "district": "MONTVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90258000496",
    },
    {
        "school": "C.B. Jennings International Elementary Magnet",
        "district": "NEW LONDON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90282000591",
    },
    {
        "school": "Nathan Hale Arts Magnet School",
        "district": "NEW LONDON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90282000594",
    },
    {
        "school": "New London High School",
        "district": "NEW LONDON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90282000595",
    },
    {
        "school": "Bennie Dover Jackson Middle School",
        "district": "NEW LONDON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90282000596",
    },
    {
        "school": "Winthrop STEM Elementary Magnet School",
        "district": "NEW LONDON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90282000597",
    },
    {
        "school": "North Stonington Elementary School",
        "district": "North Stonington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90306000634",
    },
    {
        "school": "Wheeler High School",
        "district": "North Stonington School District",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90306000635",
    },
    {
        "school": "Bishop School Early Learning Center",
        "district": "NORWICH SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90312000663",
    },
    {
        "school": "John B. Stanton School",
        "district": "NORWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90312000667",
    },
    {
        "school": "Moriarty Magnet School",
        "district": "NORWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90312000668",
    },
    {
        "school": "Kelly STEAM Magnet Middle School",
        "district": "NORWICH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90312000670",
    },
    {
        "school": "Samuel Huntington School",
        "district": "NORWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90312000672",
    },
    {
        "school": "Teachers' Memorial Global Studies Magnet Middle School",
        "district": "NORWICH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90312000674",
    },
    {
        "school": "Thomas W. Mahan School",
        "district": "NORWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90312000675",
    },
    {
        "school": "Uncas Elementary School",
        "district": "NORWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90312000676",
    },
    {
        "school": "Veterans' Memorial School",
        "district": "NORWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90312000677",
    },
    {
        "school": "Wequonnoc Magnet School",
        "district": "NORWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90312000678",
    },
    {
        "school": "Preston Plains School",
        "district": "PRESTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90342000717",
    },
    {
        "school": "Regional Multicultural Magnet School",
        "district": "LEARN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90345000079",
    },
    {
        "school": "Center School",
        "district": "REGIONAL SCHOOL DISTRICT 18",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "CT",
        "nces_id": "90354000761",
    },
    {
        "school": "Lyme Consolidated School",
        "district": "REGIONAL SCHOOL DISTRICT 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90354000762",
    },
    {
        "school": "Lyme-Old Lyme High School",
        "district": "REGIONAL SCHOOL DISTRICT 18",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90354000763",
    },
    {
        "school": "Mile Creek School",
        "district": "REGIONAL SCHOOL DISTRICT 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90354000764",
    },
    {
        "school": "Lyme-Old Lyme Middle School",
        "district": "REGIONAL SCHOOL DISTRICT 18",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90354001123",
    },
    {
        "school": "Salem Elementary School",
        "district": "SALEM SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90390000787",
    },
    {
        "school": "Sayles School",
        "district": "SPRAGUE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90426000842",
    },
    {
        "school": "Deans Mill School",
        "district": "STONINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90438000876",
    },
    {
        "school": "Stonington Middle School",
        "district": "STONINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90438000877",
    },
    {
        "school": "Stonington High School",
        "district": "STONINGTON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90438000881",
    },
    {
        "school": "West Vine Street School",
        "district": "STONINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90438000883",
    },
    {
        "school": "Clark Lane Middle School",
        "district": "WATERFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90486000994",
    },
    {
        "school": "Oswegatchie Elementary School",
        "district": "WATERFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90486000998",
    },
    {
        "school": "Waterford High School",
        "district": "WATERFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90486001001",
    },
    {
        "school": "Norwich Free Academy",
        "district": "Norwich Free Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90537101221",
    },
    {
        "school": "McAlister Intermediate School",
        "district": "SUFFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90447001394",
    },
    {
        "school": "Edgar H. Parkman School",
        "district": "ENFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90147000241",
    },
    {
        "school": "Eli Whitney School",
        "district": "ENFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90147000242",
    },
    {
        "school": "Enfield High School",
        "district": "ENFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90147000243",
    },
    {
        "school": "Enfield Street School",
        "district": "ENFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90147000244",
    },
    {
        "school": "Hazardville Memorial School",
        "district": "ENFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90147000247",
    },
    {
        "school": "Henry Barnard School",
        "district": "ENFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90147000248",
    },
    {
        "school": "John F. Kennedy Middle School",
        "district": "ENFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90147000249",
    },
    {
        "school": "Prudence Crandall School",
        "district": "ENFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90147000254",
    },
    {
        "school": "Suffield Middle School",
        "district": "SUFFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90447000902",
    },
    {
        "school": "A. Ward Spaulding School",
        "district": "SUFFIELD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90447000903",
    },
    {
        "school": "Suffield High School",
        "district": "SUFFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90447000904",
    },
    {
        "school": "North Street School",
        "district": "WINDSOR LOCKS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90525001097",
    },
    {
        "school": "South Elementary School",
        "district": "WINDSOR LOCKS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90525001098",
    },
    {
        "school": "Windsor Locks High School",
        "district": "WINDSOR LOCKS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90525001100",
    },
    {
        "school": "Windsor Locks Middle School",
        "district": "WINDSOR LOCKS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90525001101",
    },
    {
        "school": "Somers Elementary School",
        "district": "SOMERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90414000526",
    },
    {
        "school": "Mabelle B. Avery Middle School",
        "district": "SOMERS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90414000818",
    },
    {
        "school": "Somers High School",
        "district": "SOMERS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90414000819",
    },
    {
        "school": "Waterbury Arts Magnet School (Middle)",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483001395",
    },
    {
        "school": "Waterbury Arts Magnet School (High)",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483001396",
    },
    {
        "school": "Quaker Farms School",
        "district": "OXFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90324000002",
    },
    {
        "school": "Great Oak Middle School",
        "district": "OXFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90324000690",
    },
    {
        "school": "Oxford Center School",
        "district": "OXFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90324000691",
    },
    {
        "school": "Bethany Community School",
        "district": "BETHANY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90024000022",
    },
    {
        "school": "Amity Middle School: Orange",
        "district": "REGIONAL SCHOOL DISTRICT 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90366000769",
    },
    {
        "school": "Amity Regional High School",
        "district": "REGIONAL SCHOOL DISTRICT 05",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90366000770",
    },
    {
        "school": "Amity Middle School: Bethany",
        "district": "REGIONAL SCHOOL DISTRICT 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90366001114",
    },
    {
        "school": "Fletcher W. Judson School",
        "district": "WATERTOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90489001003",
    },
    {
        "school": "Polk School",
        "district": "WATERTOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90489001005",
    },
    {
        "school": "Swift Middle School",
        "district": "WATERTOWN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90489001007",
    },
    {
        "school": "Watertown High School",
        "district": "WATERTOWN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90489001008",
    },
    {
        "school": "John Trumbull Primary School",
        "district": "WATERTOWN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90489001135",
    },
    {
        "school": "Andrew Avenue School",
        "district": "NAUGATUCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90264000499",
    },
    {
        "school": "City Hill Middle School",
        "district": "NAUGATUCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90264000501",
    },
    {
        "school": "Cross Street Intermediate School",
        "district": "NAUGATUCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90264000502",
    },
    {
        "school": "Hillside Intermediate School",
        "district": "NAUGATUCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90264000504",
    },
    {
        "school": "Naugatuck High School",
        "district": "NAUGATUCK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90264000505",
    },
    {
        "school": "Hop Brook Elementary School",
        "district": "NAUGATUCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90264000506",
    },
    {
        "school": "Salem School",
        "district": "NAUGATUCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90264000507",
    },
    {
        "school": "Western School",
        "district": "NAUGATUCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90264000508",
    },
    {
        "school": "Maple Hill School",
        "district": "NAUGATUCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90264001223",
    },
    {
        "school": "Long Meadow Elementary School",
        "district": "REGIONAL SCHOOL DISTRICT 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353700708",
    },
    {
        "school": "Memorial Middle School",
        "district": "REGIONAL SCHOOL DISTRICT 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353700748",
    },
    {
        "school": "Pomperaug Regional High School",
        "district": "REGIONAL SCHOOL DISTRICT 15",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353700749",
    },
    {
        "school": "Pomperaug School",
        "district": "REGIONAL SCHOOL DISTRICT 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353700750",
    },
    {
        "school": "Rochambeau Middle School",
        "district": "REGIONAL SCHOOL DISTRICT 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353700751",
    },
    {
        "school": "Gainfield Elementary School",
        "district": "REGIONAL SCHOOL DISTRICT 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353701116",
    },
    {
        "school": "Middlebury Elementary School",
        "district": "REGIONAL SCHOOL DISTRICT 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353701200",
    },
    {
        "school": "Laurel Ledge School",
        "district": "REGIONAL SCHOOL DISTRICT 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353800755",
    },
    {
        "school": "Long River Middle School",
        "district": "REGIONAL SCHOOL DISTRICT 16",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353800756",
    },
    {
        "school": "Woodland Regional High School",
        "district": "REGIONAL SCHOOL DISTRICT 16",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353801356",
    },
    {
        "school": "Maloney Interdistrict Magnet School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000541",
    },
    {
        "school": "Woodrow Wilson School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000685",
    },
    {
        "school": "B. W. Tinker School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000966",
    },
    {
        "school": "Bucks Hill School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000968",
    },
    {
        "school": "Bunker Hill School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000969",
    },
    {
        "school": "Carrington School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000970",
    },
    {
        "school": "Crosby High School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000971",
    },
    {
        "school": "Driggs School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000972",
    },
    {
        "school": "Margaret M. Generali Elementary School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000974",
    },
    {
        "school": "F. J. Kingsbury School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000975",
    },
    {
        "school": "Gilmartin School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000976",
    },
    {
        "school": "H. S. Chase School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000977",
    },
    {
        "school": "Hopeville School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000978",
    },
    {
        "school": "John F. Kennedy High School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000979",
    },
    {
        "school": "Michael F. Wallace Middle School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000983",
    },
    {
        "school": "Regan School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000984",
    },
    {
        "school": "Sprague School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000986",
    },
    {
        "school": "Walsh School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000987",
    },
    {
        "school": "Washington School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000988",
    },
    {
        "school": "Wendell L. Cross School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000990",
    },
    {
        "school": "West Side Middle School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000991",
    },
    {
        "school": "Wilby High School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483000992",
    },
    {
        "school": "North End Middle School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483001115",
    },
    {
        "school": "Rotella Interdistrict Magnet School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483001131",
    },
    {
        "school": "Tyrrell Middle School",
        "district": "WOLCOTT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90528001102",
    },
    {
        "school": "Frisbie School",
        "district": "WOLCOTT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90528001103",
    },
    {
        "school": "Alcott School",
        "district": "WOLCOTT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90528001105",
    },
    {
        "school": "Wakelee School",
        "district": "WOLCOTT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90528001106",
    },
    {
        "school": "Wolcott High School",
        "district": "WOLCOTT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90528001107",
    },
    {
        "school": "Ashford School",
        "district": "ASHFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90009000010",
    },
    {
        "school": "Chaplin Elementary School",
        "district": "CHAPLIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90072000121",
    },
    {
        "school": "Hampton Elementary School",
        "district": "HAMPTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90189000351",
    },
    {
        "school": "Parish Hill High School",
        "district": "REGIONAL SCHOOL DISTRICT 11",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90357000765",
    },
    {
        "school": "Scotland Elementary School",
        "district": "SCOTLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90396000789",
    },
    {
        "school": "Dr. Helen Baldwin Middle School",
        "district": "CANTERBURY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90066001187",
    },
    {
        "school": "Canterbury Elementary School",
        "district": "CANTERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90066001188",
    },
    {
        "school": "Brooklyn Elementary School",
        "district": "BROOKLYN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90057000113",
    },
    {
        "school": "Brooklyn Middle School",
        "district": "BROOKLYN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90057000114",
    },
    {
        "school": "Eastford Elementary School",
        "district": "EASTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90138000232",
    },
    {
        "school": "Pomfret Community School",
        "district": "POMFRET SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90336000709",
    },
    {
        "school": "Putnam Elementary School",
        "district": "PUTNAM SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90348000718",
    },
    {
        "school": "Putnam High School",
        "district": "PUTNAM SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90348000719",
    },
    {
        "school": "Putnam Middle School",
        "district": "PUTNAM SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90348000720",
    },
    {
        "school": "Mary R. Fisher Elementary School",
        "district": "THOMPSON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90453000909",
    },
    {
        "school": "Thompson Middle School",
        "district": "THOMPSON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90453000910",
    },
    {
        "school": "Tourtellotte Memorial High School",
        "district": "THOMPSON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90453000911",
    },
    {
        "school": "Woodstock Middle School",
        "district": "WOODSTOCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90537000573",
    },
    {
        "school": "Woodstock Elementary School",
        "district": "WOODSTOCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90537001110",
    },
    {
        "school": "Cesar Chavez PCS for Public Policy - Parkside MS",
        "district": "Cesar Chavez PCS for Public Policy",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000500328",
    },
    {
        "school": "Friendship PCS - Collegiate Academy",
        "district": "Friendship PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800338",
    },
    {
        "school": "Washington Latin PCS - MS",
        "district": "Washington Latin PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110001900324",
    },
    {
        "school": "St. Coletta Special Education PCS",
        "district": "St. Coletta Special Education PCS",
        "level": "Other",
        "type": "Special education school",
        "state": "DC",
        "nces_id": "110006400367",
    },
    {
        "school": "Cedar Tree Academy PCS",
        "district": "Cedar Tree Academy PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110002900245",
    },
    {
        "school": "Roosevelt STAY HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "DC",
        "nces_id": "110003000264",
    },
    {
        "school": "McKinley Technology HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000267",
    },
    {
        "school": "Kelly Miller MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000272",
    },
    {
        "school": "KIPP DC - KEY Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100246",
    },
    {
        "school": "Latin American Montessori Bilingual PCS",
        "district": "Latin American Montessori Bilingual PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003200247",
    },
    {
        "school": "Thurgood Marshall Academy PCS",
        "district": "Thurgood Marshall Academy PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003400249",
    },
    {
        "school": "DC Bilingual PCS",
        "district": "DC Bilingual PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004200273",
    },
    {
        "school": "E.L. Haynes PCS - MS",
        "district": "E.L. Haynes PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004300274",
    },
    {
        "school": "Mary McLeod Bethune Day Academy PCS",
        "district": "Mary McLeod Bethune Day Academy PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004400275",
    },
    {
        "school": "Two Rivers PCS - 4th St",
        "district": "Two Rivers PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004500279",
    },
    {
        "school": "DC Prep PCS - Edgewood MS",
        "district": "DC Prep PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004800277",
    },
    {
        "school": "Eagle Academy PCS - Congress Heights",
        "district": "Eagle Academy PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004900278",
    },
    {
        "school": "Hope Community PCS - Lamond",
        "district": "Hope Community PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110005100301",
    },
    {
        "school": "AppleTree Early Learning Center PCS - Columbia Heights",
        "district": "AppleTree Early Learning PCS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110005400304",
    },
    {
        "school": "Bridges PCS",
        "district": "Bridges PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110005500305",
    },
    {
        "school": "Howard University MS of Mathematics and Science PCS",
        "district": "Howard University Middle School of Math and Science PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110005800308",
    },
    {
        "school": "Elsie Whitlow Stokes Community Freedom PCS - Brookland",
        "district": "Elsie Whitlow Stokes Community Freedom PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000900223",
    },
    {
        "school": "Perry Street Preparatory PCS",
        "district": "Perry Street Preparatory PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110001100225",
    },
    {
        "school": "IDEA PCS",
        "district": "IDEA PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110001300227",
    },
    {
        "school": "Meridian PCS",
        "district": "Meridian PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110001500229",
    },
    {
        "school": "Roots PCS",
        "district": "Roots PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110002000234",
    },
    {
        "school": "SEED PCS of Washington DC",
        "district": "SEED PCS of Washington DC",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110002200236",
    },
    {
        "school": "Murch ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000001",
    },
    {
        "school": "Moten ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000002",
    },
    {
        "school": "Miner ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000004",
    },
    {
        "school": "Roosevelt HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000008",
    },
    {
        "school": "Takoma Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000011",
    },
    {
        "school": "Stanton ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000013",
    },
    {
        "school": "Duke Ellington School of the Arts",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000016",
    },
    {
        "school": "Sousa MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000019",
    },
    {
        "school": "Seaton ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000024",
    },
    {
        "school": "Savoy ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000025",
    },
    {
        "school": "Ross ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000027",
    },
    {
        "school": "Randle Highlands ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000029",
    },
    {
        "school": "Shepherd ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000030",
    },
    {
        "school": "Marie Reed ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000032",
    },
    {
        "school": "Raymond Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000033",
    },
    {
        "school": "Maury ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000034",
    },
    {
        "school": "Mann ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000035",
    },
    {
        "school": "Malcolm X ES at Green",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000036",
    },
    {
        "school": "Ludlow-Taylor ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000037",
    },
    {
        "school": "Leckie Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000041",
    },
    {
        "school": "LaSalle-Backus Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000042",
    },
    {
        "school": "Langdon ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000044",
    },
    {
        "school": "Lafayette ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000045",
    },
    {
        "school": "Watkins ES (Capitol Hill Cluster)",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000048",
    },
    {
        "school": "Thomas ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000049",
    },
    {
        "school": "Stoddert ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000050",
    },
    {
        "school": "Simon ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000054",
    },
    {
        "school": "H.D. Woodson HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000055",
    },
    {
        "school": "J.O. Wilson ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000062",
    },
    {
        "school": "Smothers ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000064",
    },
    {
        "school": "Whittier Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000065",
    },
    {
        "school": "West Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000067",
    },
    {
        "school": "Wheatley Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000068",
    },
    {
        "school": "Walker-Jones Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000070",
    },
    {
        "school": "Tyler ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000072",
    },
    {
        "school": "Turner ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000073",
    },
    {
        "school": "Tubman ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000074",
    },
    {
        "school": "Truesdell Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000075",
    },
    {
        "school": "Thomson ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000076",
    },
    {
        "school": "Eastern HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000078",
    },
    {
        "school": "Dunbar HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000079",
    },
    {
        "school": "Coolidge HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000081",
    },
    {
        "school": "Cardozo Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000082",
    },
    {
        "school": "Ballou HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000084",
    },
    {
        "school": "Anacostia HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000085",
    },
    {
        "school": "Eaton ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000096",
    },
    {
        "school": "Drew ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000097",
    },
    {
        "school": "H.D. Cooke ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000100",
    },
    {
        "school": "King ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000102",
    },
    {
        "school": "Cleveland ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000103",
    },
    {
        "school": "Burrville ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000106",
    },
    {
        "school": "Burroughs ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000107",
    },
    {
        "school": "Bruce-Monroe ES at Park View",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000110",
    },
    {
        "school": "Bunker Hill ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000111",
    },
    {
        "school": "Brightwood Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000112",
    },
    {
        "school": "Brent ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000113",
    },
    {
        "school": "Beers ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000118",
    },
    {
        "school": "Barnard ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000119",
    },
    {
        "school": "Bancroft ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000120",
    },
    {
        "school": "Amidon-Bowen ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000121",
    },
    {
        "school": "Aiton ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000122",
    },
    {
        "school": "Powell ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000125",
    },
    {
        "school": "Plummer ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000126",
    },
    {
        "school": "School Without Walls HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000131",
    },
    {
        "school": "Woodrow Wilson HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000133",
    },
    {
        "school": "Hart MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000135",
    },
    {
        "school": "Deal MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000138",
    },
    {
        "school": "Kramer MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000143",
    },
    {
        "school": "Johnson MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000144",
    },
    {
        "school": "School Without Walls at Francis-Stevens",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000149",
    },
    {
        "school": "Eliot-Hine MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000151",
    },
    {
        "school": "Browne Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000152",
    },
    {
        "school": "Benjamin Banneker HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000153",
    },
    {
        "school": "Peabody ES (Capitol Hill Cluster)",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000156",
    },
    {
        "school": "Payne ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000157",
    },
    {
        "school": "Patterson ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000158",
    },
    {
        "school": "Oyster-Adams Bilingual School",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000160",
    },
    {
        "school": "Lawrence E. Boone ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000161",
    },
    {
        "school": "Nalle ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000163",
    },
    {
        "school": "Noyes ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000164",
    },
    {
        "school": "Garfield ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000165",
    },
    {
        "school": "Garrison ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000171",
    },
    {
        "school": "Kimball ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000173",
    },
    {
        "school": "Key ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000174",
    },
    {
        "school": "Ketcham ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000176",
    },
    {
        "school": "Janney ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000179",
    },
    {
        "school": "Hyde-Addison ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000180",
    },
    {
        "school": "Houston ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000181",
    },
    {
        "school": "Hendley ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000182",
    },
    {
        "school": "Hearst ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000183",
    },
    {
        "school": "C.W. Harris ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000185",
    },
    {
        "school": "Hardy MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000186",
    },
    {
        "school": "Stuart-Hobson MS (Capitol Hill Cluster)",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000191",
    },
    {
        "school": "Luke C. Moore HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "DC",
        "nces_id": "110003000198",
    },
    {
        "school": "Ballou STAY HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "DC",
        "nces_id": "110003000207",
    },
    {
        "school": "Capital City PCS - Lower School",
        "district": "Capital City PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003500253",
    },
    {
        "school": "Paul PCS - MS",
        "district": "Paul PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003900257",
    },
    {
        "school": "Charter School of New Castle",
        "district": "Charter School of New Castle",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100002400256",
    },
    {
        "school": "Odyssey Charter School",
        "district": "Odyssey Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100002600259",
    },
    {
        "school": "Academy Of Dover Charter School",
        "district": "Academy of Dover Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100001700144",
    },
    {
        "school": "Providence Creek Academy Charter School",
        "district": "Providence Creek Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100001800122",
    },
    {
        "school": "Kent County Secondary ILC",
        "district": "Capital School District",
        "level": "High",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100019000328",
    },
    {
        "school": "Smyrna Middle School",
        "district": "Smyrna School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100162000141",
    },
    {
        "school": "Sunnyside Elementary School",
        "district": "Smyrna School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100162000216",
    },
    {
        "school": "Positive Outcomes Charter School",
        "district": "Positive Outcomes Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100000500013",
    },
    {
        "school": "Campus Community School",
        "district": "Campus Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100000700070",
    },
    {
        "school": "Kent Elementary Intensive Learning Center",
        "district": "Caesar Rodney School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100018000018",
    },
    {
        "school": "Allen Frear Elementary School",
        "district": "Caesar Rodney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100018000038",
    },
    {
        "school": "Caesar Rodney High School",
        "district": "Caesar Rodney School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100018000040",
    },
    {
        "school": "Dover Air Force Base Middle School",
        "district": "Caesar Rodney School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100018000041",
    },
    {
        "school": "John S. Charlton School",
        "district": "Caesar Rodney School District",
        "level": "Other",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100018000043",
    },
    {
        "school": "Major George S. Welch Elementary School",
        "district": "Caesar Rodney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100018000044",
    },
    {
        "school": "Nellie Hughes Stokes Elementary School",
        "district": "Caesar Rodney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100018000045",
    },
    {
        "school": "Star Hill Elementary School",
        "district": "Caesar Rodney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100018000046",
    },
    {
        "school": "W. B. Simpson Elementary School",
        "district": "Caesar Rodney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100018000047",
    },
    {
        "school": "W. Reily Brown Elementary School",
        "district": "Caesar Rodney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100018000048",
    },
    {
        "school": "F. Niel Postlethwait Middle School",
        "district": "Caesar Rodney School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100018000071",
    },
    {
        "school": "Fred Fifer III Middle School",
        "district": "Caesar Rodney School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100018000072",
    },
    {
        "school": "J. Ralph McIlvaine Early Childhood Center",
        "district": "Caesar Rodney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100018000309",
    },
    {
        "school": "North Dover Elementary School",
        "district": "Capital School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100019000011",
    },
    {
        "school": "Central Middle School",
        "district": "Capital School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100019000049",
    },
    {
        "school": "Dover High School",
        "district": "Capital School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100019000050",
    },
    {
        "school": "East Dover Elementary School",
        "district": "Capital School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100019000051",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Capital School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100019000052",
    },
    {
        "school": "Hartly Elementary School",
        "district": "Capital School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100019000053",
    },
    {
        "school": "Kent County Community School",
        "district": "Capital School District",
        "level": "Other",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100019000054",
    },
    {
        "school": "South Dover Elementary School",
        "district": "Capital School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100019000055",
    },
    {
        "school": "Towne Point Elementary School",
        "district": "Capital School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100019000056",
    },
    {
        "school": "Booker T. Washington Elementary School",
        "district": "Capital School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100019000057",
    },
    {
        "school": "William Henry Middle School",
        "district": "Capital School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100019000058",
    },
    {
        "school": "POLYTECH High School",
        "district": "POLYTECH School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "DE",
        "nces_id": "100075000092",
    },
    {
        "school": "Lake Forest Central Elementary School",
        "district": "Lake Forest School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100079000077",
    },
    {
        "school": "Lake Forest East Elementary School",
        "district": "Lake Forest School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100079000094",
    },
    {
        "school": "Lake Forest High School",
        "district": "Lake Forest School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100079000095",
    },
    {
        "school": "Lake Forest North Elementary School",
        "district": "Lake Forest School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100079000096",
    },
    {
        "school": "Lake Forest South Elementary School",
        "district": "Lake Forest School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100079000097",
    },
    {
        "school": "Chipman (W.T.) Middle School",
        "district": "Lake Forest School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100079000098",
    },
    {
        "school": "Banneker (Benjamin) Elementary School",
        "district": "Milford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100108000107",
    },
    {
        "school": "Milford Senior High School",
        "district": "Milford School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100108000111",
    },
    {
        "school": "Smyrna Elementary School",
        "district": "Smyrna School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100162000298",
    },
    {
        "school": "Smyrna High School",
        "district": "Smyrna School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100162000299",
    },
    {
        "school": "Moore (John Bassett) School",
        "district": "Smyrna School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100162000300",
    },
    {
        "school": "North Smyrna Elementary School",
        "district": "Smyrna School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100162000301",
    },
    {
        "school": "Clayton Elementary School",
        "district": "Smyrna School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100162000302",
    },
    {
        "school": "Morris (Evelyn I.) Early Childhood",
        "district": "Milford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100108000002",
    },
    {
        "school": "Ross (Lulu M.) Elementary School",
        "district": "Milford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100108000109",
    },
    {
        "school": "Delaware Military Academy",
        "district": "Delaware Military Academy",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100001600143",
    },
    {
        "school": "MOT Charter School",
        "district": "MOT Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100001900123",
    },
    {
        "school": "Loss (Olive B.) Elementary School",
        "district": "Appoquinimink School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000121",
    },
    {
        "school": "Brick Mill Elementary School",
        "district": "Appoquinimink School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000142",
    },
    {
        "school": "Cedar Lane Early Childhood Center",
        "district": "Appoquinimink School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000178",
    },
    {
        "school": "Waters (Alfred G.) Middle School",
        "district": "Appoquinimink School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000222",
    },
    {
        "school": "Appoquinimink High School",
        "district": "Appoquinimink School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000225",
    },
    {
        "school": "Wilbur (Kathleen H.) Elementary",
        "district": "Colonial School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000237",
    },
    {
        "school": "McCullough (Calvin R. ) Middle School",
        "district": "Colonial School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000271",
    },
    {
        "school": "St. Georges Technical High School",
        "district": "New Castle County Vocational-Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "DE",
        "nces_id": "100128000181",
    },
    {
        "school": "North Star Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000179",
    },
    {
        "school": "Pyle (Sarah) Academy",
        "district": "Christina School District",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "DE",
        "nces_id": "100020000227",
    },
    {
        "school": "Charter School of Wilmington",
        "district": "Charter School of Wilmington",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100000400012",
    },
    {
        "school": "East Side Charter School",
        "district": "East Side Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100000600017",
    },
    {
        "school": "Edison (Thomas A.) Charter School",
        "district": "Edison (Thomas A.) Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100001000079",
    },
    {
        "school": "Kuumba Academy Charter School",
        "district": "Kuumba Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100001400106",
    },
    {
        "school": "Newark Charter School",
        "district": "Newark Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100001500112",
    },
    {
        "school": "Meredith (Everett) Middle School",
        "district": "Appoquinimink School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000014",
    },
    {
        "school": "Middletown High School",
        "district": "Appoquinimink School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000024",
    },
    {
        "school": "Redding (Louis L.) Middle School",
        "district": "Appoquinimink School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000026",
    },
    {
        "school": "Silver Lake Elementary School",
        "district": "Appoquinimink School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000027",
    },
    {
        "school": "Townsend Elementary School",
        "district": "Appoquinimink School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000028",
    },
    {
        "school": "Appoquinimink PreSchool Center",
        "district": "Appoquinimink School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100008000103",
    },
    {
        "school": "Cedar Lane Elementary School",
        "district": "Appoquinimink School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000332",
    },
    {
        "school": "Marshall (Thurgood) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000005",
    },
    {
        "school": "Douglass School",
        "district": "Christina School District",
        "level": "Other",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100020000010",
    },
    {
        "school": "Keene (William B.) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000117",
    },
    {
        "school": "Delaware School for the Deaf",
        "district": "Christina School District",
        "level": "Other",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100020000210",
    },
    {
        "school": "Wilson (Etta J.) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000214",
    },
    {
        "school": "Stubbs Early Education Center",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000217",
    },
    {
        "school": "Smith (Jennie E.) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000218",
    },
    {
        "school": "McVey (Joseph M.) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000221",
    },
    {
        "school": "Maclary (R. Elisabeth) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000223",
    },
    {
        "school": "Leasure (May B.) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000224",
    },
    {
        "school": "Downes (John R.) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000228",
    },
    {
        "school": "Jones (Albert H.) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000229",
    },
    {
        "school": "Brookside Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000231",
    },
    {
        "school": "The Bayard School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000232",
    },
    {
        "school": "The Bancroft School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000233",
    },
    {
        "school": "Shue-Medill Middle School",
        "district": "Christina School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000234",
    },
    {
        "school": "Kirk (George V.) Middle School",
        "district": "Christina School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000235",
    },
    {
        "school": "Gauger-Cobbs Middle School",
        "district": "Christina School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000236",
    },
    {
        "school": "Newark High School",
        "district": "Christina School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000238",
    },
    {
        "school": "Glasgow High School",
        "district": "Christina School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000239",
    },
    {
        "school": "Christiana High School",
        "district": "Christina School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000240",
    },
    {
        "school": "Brennen School (The)",
        "district": "Christina School District",
        "level": "Other",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100020000305",
    },
    {
        "school": "Gallaher (Robert S.) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000312",
    },
    {
        "school": "West Park Place Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000316",
    },
    {
        "school": "Brader (Henry M.) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000323",
    },
    {
        "school": "Southern Elementary School",
        "district": "Colonial School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000118",
    },
    {
        "school": "Leach (John G.) School",
        "district": "Colonial School District",
        "level": "Other",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100023000196",
    },
    {
        "school": "Wilmington Manor Elementary School",
        "district": "Colonial School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000197",
    },
    {
        "school": "Pleasantville Elementary School",
        "district": "Colonial School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000198",
    },
    {
        "school": "Eisenberg (Harry O.) Elementary School",
        "district": "Colonial School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000200",
    },
    {
        "school": "The Colwyck Center",
        "district": "Colonial School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000203",
    },
    {
        "school": "Castle Hills Elementary School",
        "district": "Colonial School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000204",
    },
    {
        "school": "Downie (Carrie) Elementary School",
        "district": "Colonial School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000205",
    },
    {
        "school": "Read (George) Middle School",
        "district": "Colonial School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000206",
    },
    {
        "school": "Bedford (Gunning) Middle School",
        "district": "Colonial School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000208",
    },
    {
        "school": "Penn (William) High School",
        "district": "Colonial School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000209",
    },
    {
        "school": "Springer Middle School",
        "district": "Brandywine School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000009",
    },
    {
        "school": "Claymont Elementary School",
        "district": "Brandywine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000062",
    },
    {
        "school": "Brandywine High School",
        "district": "Brandywine School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000242",
    },
    {
        "school": "duPont (Pierre S.) Middle School",
        "district": "Brandywine School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000243",
    },
    {
        "school": "Mount Pleasant High School",
        "district": "Brandywine School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000246",
    },
    {
        "school": "Concord High School",
        "district": "Brandywine School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000247",
    },
    {
        "school": "Bush (Charles W.) Pre-School",
        "district": "Brandywine School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100124000277",
    },
    {
        "school": "Maple Lane Elementary School",
        "district": "Brandywine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000281",
    },
    {
        "school": "Lombardy Elementary School",
        "district": "Brandywine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000282",
    },
    {
        "school": "Lancashire Elementary School",
        "district": "Brandywine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000283",
    },
    {
        "school": "Harlan (David W. ) Elementary School",
        "district": "Brandywine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000285",
    },
    {
        "school": "Forwood Elementary School",
        "district": "Brandywine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000288",
    },
    {
        "school": "Carrcroft Elementary School",
        "district": "Brandywine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000291",
    },
    {
        "school": "Hanby Elementary School",
        "district": "Brandywine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000293",
    },
    {
        "school": "Talley Middle School",
        "district": "Brandywine School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000294",
    },
    {
        "school": "Mount Pleasant Elementary School",
        "district": "Brandywine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000318",
    },
    {
        "school": "Delcastle Technical High School",
        "district": "New Castle County Vocational-Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "DE",
        "nces_id": "100128000154",
    },
    {
        "school": "Hodgson (Paul M.) Vocational Technical High School",
        "district": "New Castle County Vocational-Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "DE",
        "nces_id": "100128000296",
    },
    {
        "school": "Howard High School of Technology",
        "district": "New Castle County Vocational-Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "DE",
        "nces_id": "100128000297",
    },
    {
        "school": "Calloway (Cab) School of the Arts",
        "district": "Red Clay Consolidated School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000004",
    },
    {
        "school": "Brandywine Springs School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000104",
    },
    {
        "school": "First State School",
        "district": "Red Clay Consolidated School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "DE",
        "nces_id": "100130000116",
    },
    {
        "school": "Shortlidge (Evan G.) Academy",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000219",
    },
    {
        "school": "Richardson Park Learning Center",
        "district": "Red Clay Consolidated School District",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100130000248",
    },
    {
        "school": "Meadowood Program",
        "district": "Red Clay Consolidated School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "DE",
        "nces_id": "100130000249",
    },
    {
        "school": "Warner Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000250",
    },
    {
        "school": "Richardson Park Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000252",
    },
    {
        "school": "Mote (Anna P.) Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000254",
    },
    {
        "school": "Marbrook Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000255",
    },
    {
        "school": "Lewis (William C.) Dual Language Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000258",
    },
    {
        "school": "Highlands Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000261",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000262",
    },
    {
        "school": "Baltz (Austin D.) Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000264",
    },
    {
        "school": "Forest Oak Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000265",
    },
    {
        "school": "Stanton Middle School",
        "district": "Red Clay Consolidated School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000266",
    },
    {
        "school": "Skyline Middle School",
        "district": "Red Clay Consolidated School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000267",
    },
    {
        "school": "duPont (H.B.) Middle School",
        "district": "Red Clay Consolidated School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000269",
    },
    {
        "school": "Conrad Schools of Science",
        "district": "Red Clay Consolidated School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000270",
    },
    {
        "school": "duPont (Alexis I.) Middle School",
        "district": "Red Clay Consolidated School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000272",
    },
    {
        "school": "McKean (Thomas) High School",
        "district": "Red Clay Consolidated School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000274",
    },
    {
        "school": "Dickinson (John) School",
        "district": "Red Clay Consolidated School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000275",
    },
    {
        "school": "duPont (Alexis I.) High School",
        "district": "Red Clay Consolidated School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000276",
    },
    {
        "school": "Richey Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000315",
    },
    {
        "school": "Linden Hill Elementary School",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000334",
    },
    {
        "school": "Milton Elementary School",
        "district": "Cape Henlopen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100017000140",
    },
    {
        "school": "Sussex Academy of Arts and Sciences",
        "district": "Sussex Academy",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100001100091",
    },
    {
        "school": "Cape Henlopen High School",
        "district": "Cape Henlopen School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100017000029",
    },
    {
        "school": "H. O. Brittingham Elementary School",
        "district": "Cape Henlopen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100017000030",
    },
    {
        "school": "Mariner Middle School",
        "district": "Cape Henlopen School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100017000033",
    },
    {
        "school": "Rehoboth Elementary School",
        "district": "Cape Henlopen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100017000035",
    },
    {
        "school": "Shields (Richard A.) Elementary School",
        "district": "Cape Henlopen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100017000036",
    },
    {
        "school": "Beacon Middle School",
        "district": "Cape Henlopen School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100017000037",
    },
    {
        "school": "Sussex Consortium",
        "district": "Cape Henlopen School District",
        "level": "Other",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100017000304",
    },
    {
        "school": "Delmar Middle School",
        "district": "Delmar School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100027000078",
    },
    {
        "school": "Delmar High School",
        "district": "Delmar School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100027000080",
    },
    {
        "school": "Carver (G.W.) Educational Center",
        "district": "Indian River School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "DE",
        "nces_id": "100068000065",
    },
    {
        "school": "North Georgetown Elementary School",
        "district": "Indian River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000067",
    },
    {
        "school": "Long Neck Elementary School",
        "district": "Indian River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000074",
    },
    {
        "school": "Southern Delaware School of the Arts",
        "district": "Indian River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000075",
    },
    {
        "school": "East Millsboro Elementary School",
        "district": "Indian River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000081",
    },
    {
        "school": "Clayton (John M.) Elementary School",
        "district": "Indian River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000082",
    },
    {
        "school": "Georgetown Elementary School",
        "district": "Indian River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000083",
    },
    {
        "school": "Ennis (Howard T.) School",
        "district": "Indian River School District",
        "level": "Other",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100068000084",
    },
    {
        "school": "Indian River High School",
        "district": "Indian River School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000085",
    },
    {
        "school": "Lord Baltimore Elementary School",
        "district": "Indian River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000086",
    },
    {
        "school": "Selbyville Middle School",
        "district": "Indian River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000087",
    },
    {
        "school": "Showell (Phillip C.) Elementary School",
        "district": "Indian River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000088",
    },
    {
        "school": "Sussex Central High School",
        "district": "Indian River School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000090",
    },
    {
        "school": "Laurel Senior High School",
        "district": "Laurel School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100081000100",
    },
    {
        "school": "North Laurel Early Learning Academy",
        "district": "Laurel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100081000101",
    },
    {
        "school": "Blades Elementary School",
        "district": "Seaford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100153000020",
    },
    {
        "school": "Seaford Central Elementary School",
        "district": "Seaford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100153000155",
    },
    {
        "school": "Seaford Middle School",
        "district": "Seaford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100153000156",
    },
    {
        "school": "Frederick Douglass Elementary School",
        "district": "Seaford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100153000157",
    },
    {
        "school": "Seaford Senior High School",
        "district": "Seaford School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100153000158",
    },
    {
        "school": "West Seaford Elementary School",
        "district": "Seaford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100153000160",
    },
    {
        "school": "Sussex Orthopedic Program",
        "district": "Seaford School District",
        "level": "Other",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100153000322",
    },
    {
        "school": "Sussex Technical High School",
        "district": "Sussex Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "DE",
        "nces_id": "100168000170",
    },
    {
        "school": "Woodbridge Middle School",
        "district": "Woodbridge School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100185000073",
    },
    {
        "school": "Woodbridge Early Childhood Education Center",
        "district": "Woodbridge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100185000193",
    },
    {
        "school": "Woodbridge High School",
        "district": "Woodbridge School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100185000194",
    },
    {
        "school": "ALACHUA COUNTY JAIL",
        "district": "ALACHUA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120003007045",
    },
    {
        "school": "VIERA HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015004244",
    },
    {
        "school": "SUNRISE ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015004246",
    },
    {
        "school": "TREASURE COAST ELEMENTARY SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093004903",
    },
    {
        "school": "EXCELSIOR CHARTER OF BROWARD",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004460",
    },
    {
        "school": "SOMERSET ARTS CONSERVATORY",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004463",
    },
    {
        "school": "SUNSHINE ELEMENTARY CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004467",
    },
    {
        "school": "SOMERSET ACADEMY ELEMENTARY (MIRAMAR CAMPUS)",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004471",
    },
    {
        "school": "SOMERSET ACADEMY MIDDLE (MIRAMAR CAMPUS)",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004472",
    },
    {
        "school": "OAKLEAF JUNIOR HIGH",
        "district": "CLAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030007174",
    },
    {
        "school": "LORENZO WALKER TECHNICAL HIGH SCHOOL",
        "district": "COLLIER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120033004488",
    },
    {
        "school": "LORENZO WALKER TECHNICAL COLLEGE",
        "district": "COLLIER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120033007143",
    },
    {
        "school": "NEW BERLIN ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048004820",
    },
    {
        "school": "RYMFIRE ELEMENTARY SCHOOL",
        "district": "FLAGLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054004841",
    },
    {
        "school": "PEMAYETV EMAHAKV CHARTER OUR WAY SCHOOL",
        "district": "GLADES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120066004849",
    },
    {
        "school": "HILLTOP ELEMENTARY SCHOOL",
        "district": "HARDEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120075004853",
    },
    {
        "school": "DOBY ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004871",
    },
    {
        "school": "LENNARD HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004872",
    },
    {
        "school": "DEER PARK ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004883",
    },
    {
        "school": "HILLSBOROUGH VIRTUAL FRANCHISE HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007146",
    },
    {
        "school": "DELIA SANCHEZ FULL SERVICE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007201",
    },
    {
        "school": "THE DOVE (DEVELOPING OPPORTUNITIES THRU VOC. ED.)",
        "district": "JACKSON",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120096007112",
    },
    {
        "school": "JACKSON ALTERNATIVE SCHOOL",
        "district": "JACKSON",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120096007169",
    },
    {
        "school": "RIVER HALL ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108004918",
    },
    {
        "school": "CHALLENGER MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108004919",
    },
    {
        "school": "CHRISTA MCAULIFFE CHARTER ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108004926",
    },
    {
        "school": "OASIS CHARTER MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108004929",
    },
    {
        "school": "BOND ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111004945",
    },
    {
        "school": "LEON COUNTY JAIL",
        "district": "LEON",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120111007180",
    },
    {
        "school": "NATURE COAST MIDDLE SCHOOL",
        "district": "LEVY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114004951",
    },
    {
        "school": "IMAGINE CHARTER SCHOOL AT NORTH MANATEE",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123007153",
    },
    {
        "school": "OASIS MIDDLE SCHOOL",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123007193",
    },
    {
        "school": "HAMMETT BOWEN JR. ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126004985",
    },
    {
        "school": "MARION VIRTUAL FRANCHISE",
        "district": "MARION",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126007050",
    },
    {
        "school": "DR. DAVID L. ANDERSON MIDDLE SCHOOL",
        "district": "MARTIN",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129004989",
    },
    {
        "school": "DAVID LAWRENCE JR. K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004654",
    },
    {
        "school": "RONALD W. REAGAN/DORAL SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004726",
    },
    {
        "school": "COUNTRY CLUB MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039005913",
    },
    {
        "school": "MATER GARDENS ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039006019",
    },
    {
        "school": "PINECREST ACADEMY (SOUTH CAMPUS)",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039006171",
    },
    {
        "school": "MATER ACADEMY LAKES MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039006173",
    },
    {
        "school": "NORMA BUTLER BOSSARD ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039006302",
    },
    {
        "school": "YOUNG WOMENS PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007016",
    },
    {
        "school": "MATER ACADEMY LAKES HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007077",
    },
    {
        "school": "PREK INTERVENTION",
        "district": "MIAMI-DADE",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120039007084",
    },
    {
        "school": "MIAMI LAKES EDUCATIONAL CENTER AND TECHNICAL COLLEGE",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120039007197",
    },
    {
        "school": "DISTRICT INSTRUCTIONAL CENTER (DIC)",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007215",
    },
    {
        "school": "YULEE HIGH SCHOOL",
        "district": "NASSAU",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135004995",
    },
    {
        "school": "OKALOOSA VIRTUAL FRANCHISE",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138007168",
    },
    {
        "school": "CASTLE CREEK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005022",
    },
    {
        "school": "WOLF LAKE MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005024",
    },
    {
        "school": "SOUTH CREEK MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005025",
    },
    {
        "school": "SAND LAKE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005026",
    },
    {
        "school": "WYNDHAM LAKES ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005027",
    },
    {
        "school": "WOLF LAKE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005028",
    },
    {
        "school": "VISTA LAKES ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005029",
    },
    {
        "school": "AVALON MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005032",
    },
    {
        "school": "STONE LAKES ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005033",
    },
    {
        "school": "OSCEOLA VIRTUAL FRANCHISE (SECONDARY)",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147005802",
    },
    {
        "school": "OSCEOLA TECHNICAL COLLEGE KISSIMMEE CAMPUS",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120147007148",
    },
    {
        "school": "LAKE MARION CREEK MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159005346",
    },
    {
        "school": "PALM BEACH JUVENILE CORRECTIONAL FACILITY",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150005793",
    },
    {
        "school": "BELIEVERS ACADEMY",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150006206",
    },
    {
        "school": "RIVIERA BEACH PREPARATORY & ACHIEVEMENT ACADEMY",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150006502",
    },
    {
        "school": "TURNING POINTS ACADEMY",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150007154",
    },
    {
        "school": "RIVER RIDGE MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153005308",
    },
    {
        "school": "GULF HIGHLANDS ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153006288",
    },
    {
        "school": "WIREGRASS RANCH HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153006440",
    },
    {
        "school": "PAUL R. SMITH MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153006504",
    },
    {
        "school": "OAKSTEAD ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153006561",
    },
    {
        "school": "TRINITY OAKS ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153006755",
    },
    {
        "school": "DR. JOHN LONG MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153006898",
    },
    {
        "school": "ATHENIAN ACADEMY OF TECHNOLOGY AND THE ARTS",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007177",
    },
    {
        "school": "SOUTH MCKEEL ACADEMY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159005341",
    },
    {
        "school": "CHAIN OF LAKES COLLEGIATE HIGH",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159005349",
    },
    {
        "school": "VICTORY RIDGE ACADEMY",
        "district": "POLK",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120159005350",
    },
    {
        "school": "LAKE ALFRED POLYTECH ACADEMY",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159007029",
    },
    {
        "school": "CITY OF PALMS CHARTER HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108004933",
    },
    {
        "school": "WEST GATE K-8 SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177005371",
    },
    {
        "school": "HOLLEY-NAVARRE PRIMARY",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165005375",
    },
    {
        "school": "LAMARQUE ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168005389",
    },
    {
        "school": "MARKHAM WOODS MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171005390",
    },
    {
        "school": "CRYSTAL LAKE ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171005391",
    },
    {
        "school": "SUWANNEE ELEMENTARY SCHOOL",
        "district": "SUWANNEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120183005396",
    },
    {
        "school": "MANATEE COVE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192007034",
    },
    {
        "school": "AMIKIDS VOLUSIA",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120192007093",
    },
    {
        "school": "MKY- HEAD START /DPP PK SCHOOL",
        "district": "ST. JOHNS",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174003498",
    },
    {
        "school": "HEAD START PROGRAM",
        "district": "GADSDEN",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060003709",
    },
    {
        "school": "WEST GLADES SCHOOL",
        "district": "GLADES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120066004187",
    },
    {
        "school": "APALACHICOLA FOREST YOUTH ACADEMY",
        "district": "LIBERTY",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120117004171",
    },
    {
        "school": "SOUTH WALTON HIGH SCHOOL",
        "district": "WALTON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198003941",
    },
    {
        "school": "DUNE LAKES ELEMENTARY SCHOOL",
        "district": "WALTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198004144",
    },
    {
        "school": "EMERALD COAST MIDDLE SCHOOL",
        "district": "WALTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198004175",
    },
    {
        "school": "BRADFORD HIGH SCHOOL",
        "district": "BRADFORD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120012000070",
    },
    {
        "school": "STARKE ELEMENTARY SCHOOL",
        "district": "BRADFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120012000071",
    },
    {
        "school": "SOUTHSIDE ELEMENTARY SCHOOL",
        "district": "BRADFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120012000072",
    },
    {
        "school": "LAWTEY ELEMENTARY SCHOOL",
        "district": "BRADFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120012000073",
    },
    {
        "school": "BROOKER ELEMENTARY SCHOOL",
        "district": "BRADFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120012000074",
    },
    {
        "school": "NORTH FLORIDA TECHNICAL COLLEGE",
        "district": "BRADFORD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120012000075",
    },
    {
        "school": "BRADFORD MIDDLE SCHOOL",
        "district": "BRADFORD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120012000076",
    },
    {
        "school": "HAMPTON ELEMENTARY SCHOOL",
        "district": "BRADFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120012000077",
    },
    {
        "school": "RAINBOW CENTER",
        "district": "BRADFORD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120012003677",
    },
    {
        "school": "BLOUNTSTOWN HIGH SCHOOL",
        "district": "CALHOUN",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120021000290",
    },
    {
        "school": "CARR ELEMENTARY & MIDDLE SCHOOL",
        "district": "CALHOUN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120021000292",
    },
    {
        "school": "ALTHA PUBLIC SCHOOL",
        "district": "CALHOUN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120021000293",
    },
    {
        "school": "BLOUNTSTOWN ELEMENTARY SCHOOL",
        "district": "CALHOUN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120021000294",
    },
    {
        "school": "DIXIE COUNTY HIGH SCHOOL",
        "district": "DIXIE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120045000626",
    },
    {
        "school": "OLD TOWN ELEMENTARY SCHOOL",
        "district": "DIXIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120045000627",
    },
    {
        "school": "JAMES M. ANDERSON ELEMENTARY SCHOOL",
        "district": "DIXIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120045000628",
    },
    {
        "school": "RUTH RAINS MIDDLE SCHOOL",
        "district": "DIXIE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120045002154",
    },
    {
        "school": "FRANKLIN COUNTY SCHOOL",
        "district": "FRANKLIN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120057000845",
    },
    {
        "school": "FRANKLIN COUNTY LEARNING CENTER",
        "district": "FRANKLIN",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120057000846",
    },
    {
        "school": "APALACHICOLA BAY CHARTER SCHOOL",
        "district": "FRANKLIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120057003708",
    },
    {
        "school": "MOORE HAVEN MIDDLE HIGH SCHOOL.",
        "district": "GLADES",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120066000864",
    },
    {
        "school": "MOORE HAVEN ELEMENTARY SCHOOL",
        "district": "GLADES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120066002174",
    },
    {
        "school": "RCMA-BOOKER T. WASHINGTON",
        "district": "GLADES",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120066002185",
    },
    {
        "school": "PORT ST. JOE ELEMENTARY SCHOOL",
        "district": "GULF",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120069000867",
    },
    {
        "school": "PORT ST. JOE HIGH SCHOOL",
        "district": "GULF",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120069000868",
    },
    {
        "school": "WEWAHITCHKA HIGH SCHOOL",
        "district": "GULF",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120069000870",
    },
    {
        "school": "WEWAHITCHKA ELEMENTARY SCHOOL",
        "district": "GULF",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120069002176",
    },
    {
        "school": "HAMILTON COUNTY HIGH SCHOOL",
        "district": "HAMILTON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120072000872",
    },
    {
        "school": "HAMILTON COUNTY ELEMENTARY SCHOOL",
        "district": "HAMILTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120072000873",
    },
    {
        "school": "OAK GROVE ACADEMY",
        "district": "HAMILTON",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120072002235",
    },
    {
        "school": "HOLMES COUNTY HIGH SCHOOL",
        "district": "HOLMES",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120090001044",
    },
    {
        "school": "POPLAR SPRINGS HIGH SCHOOL",
        "district": "HOLMES",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120090001046",
    },
    {
        "school": "BETHLEHEM HIGH SCHOOL",
        "district": "HOLMES",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120090001047",
    },
    {
        "school": "PONCE DE LEON HIGH SCHOOL",
        "district": "HOLMES",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120090001049",
    },
    {
        "school": "PONCE DE LEON ELEMENTARY SCHOOL",
        "district": "HOLMES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120090002071",
    },
    {
        "school": "MARIANNA HIGH SCHOOL",
        "district": "JACKSON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001065",
    },
    {
        "school": "FRANK M. GOLSON ELEMENTARY SCHOOL",
        "district": "JACKSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001066",
    },
    {
        "school": "RIVERSIDE ELEMENTARY SCHOOL",
        "district": "JACKSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001067",
    },
    {
        "school": "MARIANNA MIDDLE SCHOOL",
        "district": "JACKSON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001068",
    },
    {
        "school": "MALONE HIGH SCHOOL",
        "district": "JACKSON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001069",
    },
    {
        "school": "SNEADS HIGH SCHOOL",
        "district": "JACKSON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001070",
    },
    {
        "school": "SNEADS ELEMENTARY SCHOOL",
        "district": "JACKSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001071",
    },
    {
        "school": "GRAND RIDGE SCHOOL",
        "district": "JACKSON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001072",
    },
    {
        "school": "HOPE SCHOOL",
        "district": "JACKSON",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120096001073",
    },
    {
        "school": "COTTONDALE HIGH SCHOOL",
        "district": "JACKSON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001075",
    },
    {
        "school": "COTTONDALE ELEMENTARY SCHOOL",
        "district": "JACKSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001076",
    },
    {
        "school": "GRACEVILLE ELEMENTARY SCHOOL",
        "district": "JACKSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001077",
    },
    {
        "school": "GRACEVILLE HIGH SCHOOL",
        "district": "JACKSON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096001078",
    },
    {
        "school": "DIST WIDE HOMEBOUND PROGRAM",
        "district": "JACKSON",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120096001080",
    },
    {
        "school": "JACKSON COUNTY EARLY CHILDHOOD CENTER",
        "district": "JACKSON",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096003192",
    },
    {
        "school": "LAFAYETTE HIGH SCHOOL",
        "district": "LAFAYETTE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120102001085",
    },
    {
        "school": "LAFAYETTE ELEMENTARY SCHOOL",
        "district": "LAFAYETTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120102002329",
    },
    {
        "school": "WILLISTON ELEMENTARY SCHOOL",
        "district": "LEVY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114000791",
    },
    {
        "school": "CHIEFLAND ELEMENTARY SCHOOL",
        "district": "LEVY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114000798",
    },
    {
        "school": "BRONSON ELEMENTARY SCHOOL",
        "district": "LEVY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114000799",
    },
    {
        "school": "BRONSON MIDDLE/HIGH SCHOOL",
        "district": "LEVY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114001197",
    },
    {
        "school": "CEDAR KEY HIGH SCHOOL",
        "district": "LEVY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114001198",
    },
    {
        "school": "CHIEFLAND MIDDLE HIGH SCHOOL",
        "district": "LEVY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114001199",
    },
    {
        "school": "WILLISTON MIDDLE HIGH SCHOOL",
        "district": "LEVY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114001201",
    },
    {
        "school": "JOYCE M. BULLOCK ELEMENTARY SCHOOL",
        "district": "LEVY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114001202",
    },
    {
        "school": "YANKEETOWN SCHOOL",
        "district": "LEVY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114001204",
    },
    {
        "school": "WHISPERING WINDS CHARTER SCHOOL",
        "district": "LEVY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114003606",
    },
    {
        "school": "LIBERTY COUNTY HIGH SCHOOL",
        "district": "LIBERTY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120117001205",
    },
    {
        "school": "W. R. TOLAR K-8 SCHOOL",
        "district": "LIBERTY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120117001206",
    },
    {
        "school": "HOSFORD ELEMENTARY JUNIOR HIGH SCHOOL",
        "district": "LIBERTY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120117001207",
    },
    {
        "school": "LIBERTY WILDERNESS CROSSROADS",
        "district": "LIBERTY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120117003423",
    },
    {
        "school": "LIBERTY EARLY LEARNING CENTER",
        "district": "LIBERTY",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120117003730",
    },
    {
        "school": "GREENVILLE ELEMENTARY SCHOOL",
        "district": "MADISON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120120001214",
    },
    {
        "school": "LEE ELEMENTARY SCHOOL",
        "district": "MADISON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120120001215",
    },
    {
        "school": "PINETTA ELEMENTARY SCHOOL",
        "district": "MADISON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120120001216",
    },
    {
        "school": "MADISON COUNTY HIGH SCHOOL",
        "district": "MADISON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120120002212",
    },
    {
        "school": "JOANN BRIDGES ACADEMY",
        "district": "MADISON",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120120003608",
    },
    {
        "school": "MADISON COUNTY CENTRAL SCHOOL",
        "district": "MADISON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120120003731",
    },
    {
        "school": "SUWANNEE PRIMARY SCHOOL",
        "district": "SUWANNEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120183001943",
    },
    {
        "school": "RIVEROAK TECHNICAL COLLEGE",
        "district": "SUWANNEE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120183001944",
    },
    {
        "school": "SUWANNEE INTERMEDIATE SCHOOL",
        "district": "SUWANNEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120183001945",
    },
    {
        "school": "SUWANNEE HIGH SCHOOL",
        "district": "SUWANNEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120183001946",
    },
    {
        "school": "SUWANNEE MIDDLE SCHOOL",
        "district": "SUWANNEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120183001947",
    },
    {
        "school": "BRANFORD HIGH SCHOOL",
        "district": "SUWANNEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120183001948",
    },
    {
        "school": "DONALD RALPH COOKE SCHOOL",
        "district": "SUWANNEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120183003806",
    },
    {
        "school": "BRANFORD ELEMENTARY SCHOOL",
        "district": "SUWANNEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120183004454",
    },
    {
        "school": "TAYLOR COUNTY MIDDLE SCHOOL",
        "district": "TAYLOR",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120186001949",
    },
    {
        "school": "TAYLOR COUNTY ELEMENTARY SCHOOL",
        "district": "TAYLOR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120186001951",
    },
    {
        "school": "STEINHATCHEE SCHOOL",
        "district": "TAYLOR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120186001952",
    },
    {
        "school": "BIG BEND TECHNICAL COLLEGE",
        "district": "TAYLOR",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120186001954",
    },
    {
        "school": "TAYLOR COUNTY PRIMARY SCHOOL",
        "district": "TAYLOR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120186001955",
    },
    {
        "school": "TAYLOR COUNTY HIGH SCHOOL",
        "district": "TAYLOR",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120186002002",
    },
    {
        "school": "TAYLOR COUNTY PRE-K",
        "district": "TAYLOR",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120186003274",
    },
    {
        "school": "UNION COUNTY HIGH SCHOOL",
        "district": "UNION",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120189001956",
    },
    {
        "school": "LAKE BUTLER MIDDLE SCHOOL",
        "district": "UNION",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120189001957",
    },
    {
        "school": "LAKE BUTLER ELEMENTARY SCHOOL",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120189001958",
    },
    {
        "school": "UNION JUVENILE RESIDENTIAL FACILITY",
        "district": "UNION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120189002967",
    },
    {
        "school": "WEST DEFUNIAK ELEMENTARY SCHOOL",
        "district": "WALTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198002018",
    },
    {
        "school": "PAXTON SCHOOL",
        "district": "WALTON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198002020",
    },
    {
        "school": "FREEPORT SENIOR HIGH SCHOOL",
        "district": "WALTON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198002022",
    },
    {
        "school": "VAN R. BUTLER ELEMENTARY SCHOOL",
        "district": "WALTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198002023",
    },
    {
        "school": "WALTON MIDDLE SCHOOL",
        "district": "WALTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198002024",
    },
    {
        "school": "WALTON HIGH SCHOOL",
        "district": "WALTON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198002025",
    },
    {
        "school": "MAUDE SAUNDERS ELEMENTARY SCHOOL",
        "district": "WALTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198002026",
    },
    {
        "school": "FREEPORT ELEMENTARY SCHOOL",
        "district": "WALTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198002541",
    },
    {
        "school": "EMERALD COAST TECHNICAL COLLEGE",
        "district": "WALTON",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120198002644",
    },
    {
        "school": "SEASIDE NEIGHBORHOOD SCHOOL",
        "district": "WALTON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198003138",
    },
    {
        "school": "FREEPORT MIDDLE SCHOOL",
        "district": "WALTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198003524",
    },
    {
        "school": "WALTON LEARNING CENTER",
        "district": "WALTON",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120198003527",
    },
    {
        "school": "WALTON ACADEMY INC.",
        "district": "WALTON",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120198004458",
    },
    {
        "school": "CHIPLEY HIGH SCHOOL",
        "district": "WASHINGTON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201002027",
    },
    {
        "school": "KATE M. SMITH ELEMENTARY SCHOOL",
        "district": "WASHINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201002028",
    },
    {
        "school": "VERNON HIGH SCHOOL",
        "district": "WASHINGTON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201002029",
    },
    {
        "school": "ROULHAC MIDDLE SCHOOL",
        "district": "WASHINGTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201002031",
    },
    {
        "school": "VERNON ELEMENTARY SCHOOL",
        "district": "WASHINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201002033",
    },
    {
        "school": "VERNON MIDDLE SCHOOL",
        "district": "WASHINGTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201002587",
    },
    {
        "school": "DESOTO COUNTY HIGH SCHOOL",
        "district": "DESOTO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120042000620",
    },
    {
        "school": "WEST ELEMENTARY SCHOOL",
        "district": "DESOTO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120042000621",
    },
    {
        "school": "MEMORIAL ELEMENTARY SCHOOL",
        "district": "DESOTO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120042000622",
    },
    {
        "school": "DESOTO MIDDLE SCHOOL",
        "district": "DESOTO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120042000624",
    },
    {
        "school": "NOCATEE ELEMENTARY SCHOOL",
        "district": "DESOTO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120042000625",
    },
    {
        "school": "HOSPITAL AND HOMEBOUND",
        "district": "DESOTO",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120042003350",
    },
    {
        "school": "REDUCED SERVICES",
        "district": "DESOTO",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120042003702",
    },
    {
        "school": "BONITA SPRINGS CHARTER SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003870",
    },
    {
        "school": "HECTOR A. CAFFERATA JR ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003947",
    },
    {
        "school": "RAYMA C. PAGE ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003948",
    },
    {
        "school": "RAY V. POTTORF ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003949",
    },
    {
        "school": "VETERANS PARK ACADEMY FOR THE ARTS",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003950",
    },
    {
        "school": "SOUTH FORT MYERS HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003952",
    },
    {
        "school": "HARNS MARSH ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003953",
    },
    {
        "school": "GATEWAY CHARTER HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003955",
    },
    {
        "school": "OASIS CHARTER ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003956",
    },
    {
        "school": "LEXINGTON MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003964",
    },
    {
        "school": "IDA S. BAKER HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003965",
    },
    {
        "school": "EAST LEE COUNTY HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003966",
    },
    {
        "school": "VARSITY LAKES MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003967",
    },
    {
        "school": "CAPE CORAL CHARTER SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003968",
    },
    {
        "school": "MARINER MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108004107",
    },
    {
        "school": "TRAFALGAR ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108004108",
    },
    {
        "school": "GATEWAY CHARTER ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108004109",
    },
    {
        "school": "MANATEE ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108004924",
    },
    {
        "school": "SIX MILE CHARTER ACADEMY",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108005603",
    },
    {
        "school": "PACE SCHOOL FOR GIRLS",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108005778",
    },
    {
        "school": "DR CARRIE D ROBINSON LITTLETON ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108000779",
    },
    {
        "school": "GATEWAY ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108000783",
    },
    {
        "school": "ALLEN PARK ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001122",
    },
    {
        "school": "THE ALVA SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001123",
    },
    {
        "school": "BONITA SPRINGS ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001125",
    },
    {
        "school": "CAPE ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001126",
    },
    {
        "school": "CYPRESS LAKE MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001127",
    },
    {
        "school": "PAUL LAURENCE DUNBAR MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001128",
    },
    {
        "school": "EDGEWOOD ACADEMY",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001129",
    },
    {
        "school": "EDISON PARK CREATIVE AND EXPRESSIVE ARTS SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001130",
    },
    {
        "school": "FORT MYERS BEACH ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001131",
    },
    {
        "school": "FORT MYERS MIDDLE ACADEMY",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001132",
    },
    {
        "school": "FORT MYERS HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001133",
    },
    {
        "school": "FRANKLIN PARK ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001135",
    },
    {
        "school": "J. COLIN ENGLISH ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001136",
    },
    {
        "school": "LEHIGH ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001138",
    },
    {
        "school": "NORTH FORT MYERS HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001139",
    },
    {
        "school": "ORANGE RIVER ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001140",
    },
    {
        "school": "ORANGEWOOD ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001141",
    },
    {
        "school": "PINE ISLAND ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001142",
    },
    {
        "school": "THE SANIBEL SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001143",
    },
    {
        "school": "TICE ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001144",
    },
    {
        "school": "TROPIC ISLES ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001145",
    },
    {
        "school": "VILLAS ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001146",
    },
    {
        "school": "HEIGHTS ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001148",
    },
    {
        "school": "BAYSHORE ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001149",
    },
    {
        "school": "CYPRESS LAKE HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001150",
    },
    {
        "school": "TANGLEWOOD ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001153",
    },
    {
        "school": "CALOOSA ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001155",
    },
    {
        "school": "CALOOSA MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001156",
    },
    {
        "school": "RIVERDALE HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001157",
    },
    {
        "school": "NORTH FORT MYERS ACADEMY FOR THE ARTS",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001158",
    },
    {
        "school": "BONITA SPRINGS MIDDLE CENTER FOR THE ARTS",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001160",
    },
    {
        "school": "COUNTY WIDE EXCEPTIONAL CHILD PROGRAMS",
        "district": "LEE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120108001161",
    },
    {
        "school": "CAPE CORAL TECHNICAL COLLEGE",
        "district": "LEE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120108001751",
    },
    {
        "school": "HANCOCK CREEK ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001758",
    },
    {
        "school": "THREE OAKS MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001798",
    },
    {
        "school": "EARLY CHILDHOOD LEARNING SERVICES",
        "district": "LEE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108001818",
    },
    {
        "school": "CAPE CORAL HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002075",
    },
    {
        "school": "PELICAN ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002076",
    },
    {
        "school": "SAN CARLOS PARK ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002078",
    },
    {
        "school": "LEE ADOLESCENT MOTHERS PROGRAM",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108002200",
    },
    {
        "school": "FORT MYERS TECHNICAL COLLEGE",
        "district": "LEE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120108002201",
    },
    {
        "school": "GULF ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002332",
    },
    {
        "school": "GULF MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002333",
    },
    {
        "school": "SOUTHWEST FLORIDA JUVENILE DETENTION CENTER",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108002334",
    },
    {
        "school": "LEHIGH ACRES MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002335",
    },
    {
        "school": "SPRING CREEK ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002337",
    },
    {
        "school": "ROYAL PALM EXCEPTIONAL SCHOOL CENTER",
        "district": "LEE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120108002338",
    },
    {
        "school": "LEHIGH SENIOR HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002398",
    },
    {
        "school": "PINEWOODS ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002399",
    },
    {
        "school": "BUCKINGHAM EXCEPTIONAL STUDENT CENTER",
        "district": "LEE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120108002471",
    },
    {
        "school": "SUNSHINE ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002472",
    },
    {
        "school": "MARINER HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002565",
    },
    {
        "school": "ESTERO HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002566",
    },
    {
        "school": "THREE OAKS ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002613",
    },
    {
        "school": "SKYLINE ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002614",
    },
    {
        "school": "TRAFALGAR MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002683",
    },
    {
        "school": "DIPLOMAT ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002833",
    },
    {
        "school": "COLONIAL ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108002834",
    },
    {
        "school": "SUCCESS ACADEMY",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108003077",
    },
    {
        "school": "MIRROR LAKES ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003197",
    },
    {
        "school": "DIPLOMAT MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003417",
    },
    {
        "school": "LEE COUNTY JAIL",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108003724",
    },
    {
        "school": "THE ISLAND SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108003725",
    },
    {
        "school": "DUNBAR HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108004368",
    },
    {
        "school": "EDWARD A. UPTHEGROVE ELEMENTARY",
        "district": "HENDRY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078003852",
    },
    {
        "school": "CLEWISTON MIDDLE SCHOOL",
        "district": "HENDRY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078000884",
    },
    {
        "school": "LABELLE ELEMENTARY SCHOOL",
        "district": "HENDRY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078000885",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "HENDRY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078000886",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "HENDRY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078000887",
    },
    {
        "school": "LABELLE HIGH SCHOOL",
        "district": "HENDRY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078000888",
    },
    {
        "school": "COUNTRY OAKS ELEMENTARY SCHOOL",
        "district": "HENDRY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078002432",
    },
    {
        "school": "COUNTY WIDE EXCEPTIONAL STUDENT EDUCATION",
        "district": "HENDRY",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120078002502",
    },
    {
        "school": "EASTSIDE ELEMENTARY SCHOOL",
        "district": "HENDRY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078002559",
    },
    {
        "school": "CLEWISTON HIGH SCHOOL",
        "district": "HENDRY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078002663",
    },
    {
        "school": "CLEWISTON YOUTH DEVELOPMENTAL ACADEMY",
        "district": "HENDRY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120078003067",
    },
    {
        "school": "LABELLE YOUTH DEVELOPMENTAL ACADEMY",
        "district": "HENDRY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120078003174",
    },
    {
        "school": "LABELLE MIDDLE SCHOOL",
        "district": "HENDRY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078004349",
    },
    {
        "school": "THE CHILES ACADEMY",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120192003939",
    },
    {
        "school": "DEPT. OF CORRECTIONS EDUCATIONAL PROGRAM",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120192003940",
    },
    {
        "school": "EASTER SEALS CHILD DEVELOPMENT CENTER DAYTONA BEACH",
        "district": "VOLUSIA",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120192003988",
    },
    {
        "school": "SPIRIT ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192003990",
    },
    {
        "school": "CYPRESS CREEK ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192005404",
    },
    {
        "school": "DAVID C. HINSON SR. MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192005747",
    },
    {
        "school": "RICHARD MILBURN ACADEMY",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120192005749",
    },
    {
        "school": "PALM TERRACE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001196",
    },
    {
        "school": "SUNRISE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001208",
    },
    {
        "school": "TOMOKA ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001962",
    },
    {
        "school": "CAMPBELL MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001963",
    },
    {
        "school": "ORMOND BEACH ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001966",
    },
    {
        "school": "CORONADO BEACH ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001967",
    },
    {
        "school": "DELAND HIGH SCHOOL",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001969",
    },
    {
        "school": "WOODWARD AVENUE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001970",
    },
    {
        "school": "LOUISE S. MCINNIS ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001971",
    },
    {
        "school": "DELTONA MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001972",
    },
    {
        "school": "ENTERPRISE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001973",
    },
    {
        "school": "CHAMPION ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001979",
    },
    {
        "school": "R. J. LONGSTREET ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001983",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001984",
    },
    {
        "school": "MAINLAND HIGH SCHOOL",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001986",
    },
    {
        "school": "GEORGE W. MARKS ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001987",
    },
    {
        "school": "EDGEWATER PUBLIC SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001988",
    },
    {
        "school": "NEW SMYRNA BEACH HIGH SCHOOL",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001990",
    },
    {
        "school": "ORANGE CITY ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001992",
    },
    {
        "school": "ORMOND BEACH MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001993",
    },
    {
        "school": "ORTONA ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001994",
    },
    {
        "school": "SPRUCE CREEK HIGH SCHOOL",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001995",
    },
    {
        "school": "OSCEOLA ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001996",
    },
    {
        "school": "PIERSON ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001998",
    },
    {
        "school": "PORT ORANGE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192001999",
    },
    {
        "school": "READ-PATTILLO ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002000",
    },
    {
        "school": "FRIENDSHIP ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002004",
    },
    {
        "school": "SEABREEZE HIGH SCHOOL",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002005",
    },
    {
        "school": "TURIE T. SMALL ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002007",
    },
    {
        "school": "SOUTH DAYTONA ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002008",
    },
    {
        "school": "SOUTHWESTERN MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002009",
    },
    {
        "school": "EDITH I. STARKE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002010",
    },
    {
        "school": "T. DEWITT TAYLOR MIDDLE-HIGH SCHOOL",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002011",
    },
    {
        "school": "VOLUSIA REGIONAL JUVENILE DETENTION CENTER",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120192002013",
    },
    {
        "school": "SPRUCE CREEK ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002105",
    },
    {
        "school": "OSTEEN ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002267",
    },
    {
        "school": "HOLLY HILL SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002268",
    },
    {
        "school": "PINE TRAIL ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002269",
    },
    {
        "school": "RIVERVIEW LEARNING CENTER",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120192002270",
    },
    {
        "school": "SUGAR MILL ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002271",
    },
    {
        "school": "BLUE LAKE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002415",
    },
    {
        "school": "DELTONA LAKES ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002416",
    },
    {
        "school": "SILVER SANDS MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002417",
    },
    {
        "school": "DELAND MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002418",
    },
    {
        "school": "NEW SMYRNA BEACH MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002419",
    },
    {
        "school": "HIGHBANKS LEARNING CENTER",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120192002482",
    },
    {
        "school": "CHISHOLM ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002538",
    },
    {
        "school": "DISCOVERY ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002640",
    },
    {
        "school": "DELTONA HIGH SCHOOL",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002641",
    },
    {
        "school": "HORIZON ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002709",
    },
    {
        "school": "STEWART TREATMENT CENTER",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120192002717",
    },
    {
        "school": "INDIAN RIVER ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002795",
    },
    {
        "school": "TIMBERCREST ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002796",
    },
    {
        "school": "GALAXY MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002797",
    },
    {
        "school": "ATLANTIC HIGH SCHOOL",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002968",
    },
    {
        "school": "SWEETWATER ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002969",
    },
    {
        "school": "PINE RIDGE HIGH SCHOOL",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192002970",
    },
    {
        "school": "HALIFAX BEHAVIORAL SERVICES",
        "district": "VOLUSIA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120192002972",
    },
    {
        "school": "VOLUSIA PINES ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192003128",
    },
    {
        "school": "FOREST LAKE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192003129",
    },
    {
        "school": "DEBARY ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192003130",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120192003134",
    },
    {
        "school": "PATHWAYS ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192003275",
    },
    {
        "school": "THE READING EDGE ACADEMY",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192003515",
    },
    {
        "school": "HERITAGE MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192003670",
    },
    {
        "school": "DAYTONA JUVENILE RESIDENTIAL FACILITY",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120192003672",
    },
    {
        "school": "CREEKSIDE MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192003808",
    },
    {
        "school": "FREEDOM ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192004455",
    },
    {
        "school": "NORTHWEST FLORIDA BALLET ACADEMIE",
        "district": "OKALOOSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138003880",
    },
    {
        "school": "ADJUDICATED YOUTH FACILITY",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120138003881",
    },
    {
        "school": "EMERALD COAST CAREER INSTITUTE N",
        "district": "OKALOOSA",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120138005628",
    },
    {
        "school": "ANNETTE P. EDWINS ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001320",
    },
    {
        "school": "BAKER SCHOOL",
        "district": "OKALOOSA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001321",
    },
    {
        "school": "BOB SIKES ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001322",
    },
    {
        "school": "CLIFFORD MEIGS MIDDLE SCHOOL",
        "district": "OKALOOSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001324",
    },
    {
        "school": "SHOAL RIVER MIDDLE SCHOOL",
        "district": "OKALOOSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001325",
    },
    {
        "school": "C. W. RUCKEL MIDDLE SCHOOL",
        "district": "OKALOOSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001327",
    },
    {
        "school": "DESTIN ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001328",
    },
    {
        "school": "LULA J. EDGE ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001329",
    },
    {
        "school": "EGLIN ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001330",
    },
    {
        "school": "LAUREL HILL SCHOOL",
        "district": "OKALOOSA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001332",
    },
    {
        "school": "NICEVILLE SENIOR HIGH SCHOOL",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001333",
    },
    {
        "school": "NORTHWOOD ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001334",
    },
    {
        "school": "SILVER SANDS-EXCEP. CHILDREN",
        "district": "OKALOOSA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120138001336",
    },
    {
        "school": "RIVERSIDE ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001337",
    },
    {
        "school": "W. C. PRYOR MIDDLE SCHOOL",
        "district": "OKALOOSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001339",
    },
    {
        "school": "WRIGHT ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001340",
    },
    {
        "school": "SHALIMAR ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001341",
    },
    {
        "school": "ELLIOTT POINT ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001343",
    },
    {
        "school": "MARY ESTHER ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001345",
    },
    {
        "school": "JAMES E PLEW ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001346",
    },
    {
        "school": "CHOCTAWHATCHEE SENIOR HIGH SCHOOL",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001347",
    },
    {
        "school": "CRESTVIEW HIGH SCHOOL",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001348",
    },
    {
        "school": "KENWOOD ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001349",
    },
    {
        "school": "FLOROSA ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001350",
    },
    {
        "school": "FORT WALTON BEACH HIGH SCHOOL",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001351",
    },
    {
        "school": "MAX BRUNER JUNIOR MIDDLE SCHOOL",
        "district": "OKALOOSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001352",
    },
    {
        "school": "ADDIE R. LEWIS SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001353",
    },
    {
        "school": "LONGWOOD ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138001354",
    },
    {
        "school": "OKALOOSA TECHNICAL COLLEGE AND CHOICE HIGH SCHOOL",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120138002443",
    },
    {
        "school": "WALKER ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138002682",
    },
    {
        "school": "BLUEWATER ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138002774",
    },
    {
        "school": "OKALOOSA ACADEMY",
        "district": "OKALOOSA",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120138003088",
    },
    {
        "school": "ANTIOCH ELEMENTARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138003209",
    },
    {
        "school": "DAVIDSON MIDDLE SCHOOL",
        "district": "OKALOOSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138003210",
    },
    {
        "school": "DESTIN MIDDLE SCHOOL",
        "district": "OKALOOSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138003211",
    },
    {
        "school": "CRESTVIEW YOUTH ACADEMY",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120138003446",
    },
    {
        "school": "OKALOOSA YOUTH ACADEMY",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120138003447",
    },
    {
        "school": "OKALOOSA REGIONAL DETENTION",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120138003621",
    },
    {
        "school": "LIZA JACKSON PREPARATORY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138003735",
    },
    {
        "school": "COLLEGIATE HIGH SCHOOL AT NORTHWEST FLORIDA STATE COLLEGE",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138004392",
    },
    {
        "school": "MICANOPY  ACADEMY",
        "district": "ALACHUA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003003811",
    },
    {
        "school": "HEALTHY LEARNING ACADEMY CHARTER SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003003981",
    },
    {
        "school": "HIGH SPRINGS COMMUNITY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003003989",
    },
    {
        "school": "SIATECH AT GAINESVILLE",
        "district": "ALACHUA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120003004047",
    },
    {
        "school": "TRENTON HIGH SCHOOL",
        "district": "GILCHRIST",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120063000862",
    },
    {
        "school": "BELL HIGH SCHOOL",
        "district": "GILCHRIST",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120063000863",
    },
    {
        "school": "BELL ELEMENTARY SCHOOL",
        "district": "GILCHRIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120063002181",
    },
    {
        "school": "TRENTON ELEMENTARY SCHOOL",
        "district": "GILCHRIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120063002748",
    },
    {
        "school": "J. J. FINLEY ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000002",
    },
    {
        "school": "STEPHEN FOSTER ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000003",
    },
    {
        "school": "A.QUINN JONES CENTER",
        "district": "ALACHUA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120003000004",
    },
    {
        "school": "LAKE FOREST ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000005",
    },
    {
        "school": "SIDNEY LANIER CENTER",
        "district": "ALACHUA",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120003000006",
    },
    {
        "school": "LITTLEWOOD ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000007",
    },
    {
        "school": "W. A. METCALFE ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000008",
    },
    {
        "school": "JOSEPH WILLIAMS ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000009",
    },
    {
        "school": "ABRAHAM LINCOLN MIDDLE SCHOOL",
        "district": "ALACHUA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000010",
    },
    {
        "school": "HOWARD W. BISHOP MIDDLE SCHOOL",
        "district": "ALACHUA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000011",
    },
    {
        "school": "WESTWOOD MIDDLE SCHOOL",
        "district": "ALACHUA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000012",
    },
    {
        "school": "GAINESVILLE HIGH SCHOOL",
        "district": "ALACHUA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000013",
    },
    {
        "school": "ALACHUA ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000014",
    },
    {
        "school": "ARCHER ELEMENTARY",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000015",
    },
    {
        "school": "HAWTHORNE MIDDLE/HIGH SCHOOL",
        "district": "ALACHUA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000016",
    },
    {
        "school": "C. W. NORTON ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000017",
    },
    {
        "school": "A. L. MEBANE MIDDLE SCHOOL",
        "district": "ALACHUA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000018",
    },
    {
        "school": "NEWBERRY HIGH SCHOOL",
        "district": "ALACHUA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000019",
    },
    {
        "school": "SANTA FE HIGH SCHOOL",
        "district": "ALACHUA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000020",
    },
    {
        "school": "CHESTER SHELL ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000021",
    },
    {
        "school": "MYRA TERWILLIGER ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000023",
    },
    {
        "school": "IDYLWILD ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000024",
    },
    {
        "school": "GLEN SPRINGS ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000025",
    },
    {
        "school": "MARJORIE KINNAN RAWLINGS ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000026",
    },
    {
        "school": "PROFESSIONAL ACADEMY MAGNET AT LOFTEN HIGH SCHOOL",
        "district": "ALACHUA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000027",
    },
    {
        "school": "EASTSIDE HIGH SCHOOL",
        "district": "ALACHUA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000028",
    },
    {
        "school": "F. W. BUCHHOLZ HIGH SCHOOL",
        "district": "ALACHUA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000029",
    },
    {
        "school": "FORT CLARKE MIDDLE SCHOOL",
        "district": "ALACHUA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000032",
    },
    {
        "school": "NEWBERRY ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000033",
    },
    {
        "school": "W. W. IRBY ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000034",
    },
    {
        "school": "OAK VIEW MIDDLE SCHOOL",
        "district": "ALACHUA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003000619",
    },
    {
        "school": "ALACHUA REGIONAL JUVENILE DETENTION CENTER",
        "district": "ALACHUA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120003002107",
    },
    {
        "school": "KIMBALL WILES ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003002465",
    },
    {
        "school": "WILLIAM S. TALBOT ELEM SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003002466",
    },
    {
        "school": "HIDDEN OAK ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003002588",
    },
    {
        "school": "FEARNSIDE FAMILY SERVICES CENTER",
        "district": "ALACHUA",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003002975",
    },
    {
        "school": "KANAPAHA MIDDLE SCHOOL",
        "district": "ALACHUA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003003022",
    },
    {
        "school": "HOSPITAL HOMEBOUND",
        "district": "ALACHUA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120003003141",
    },
    {
        "school": "WILES HEAD START",
        "district": "ALACHUA",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003003143",
    },
    {
        "school": "THE ONE ROOM SCHOOL HOUSE PROJECT",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003003144",
    },
    {
        "school": "MICANOPY AREA COOPERATIVE SCHOOL INC.",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003003145",
    },
    {
        "school": "ALACHUA ACADEMY",
        "district": "ALACHUA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120003003281",
    },
    {
        "school": "AMIKIDS",
        "district": "ALACHUA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120003003282",
    },
    {
        "school": "PACE",
        "district": "ALACHUA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120003003283",
    },
    {
        "school": "CARING & SHARING LEARNING SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003003285",
    },
    {
        "school": "LAWTON M. CHILES ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003003530",
    },
    {
        "school": "THE EINSTEIN SCHOOL INC.",
        "district": "ALACHUA",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120003003532",
    },
    {
        "school": "EXPRESSIONS LEARNING ARTS ACADEMY",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003003533",
    },
    {
        "school": "ALACHUA LEARNING ACADEMY ELEMENTARY",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003003534",
    },
    {
        "school": "GENESIS PREPARATORY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003004302",
    },
    {
        "school": "P.K. YONGE DEVELOPMENTAL RESEARCH SCHOOL",
        "district": "UF LAB SCH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201502912",
    },
    {
        "school": "CITRUS HIGH SCHOOL",
        "district": "CITRUS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027000305",
    },
    {
        "school": "INVERNESS PRIMARY SCHOOL",
        "district": "CITRUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027000306",
    },
    {
        "school": "INVERNESS MIDDLE SCHOOL",
        "district": "CITRUS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027000307",
    },
    {
        "school": "FLORAL CITY ELEMENTARY SCHOOL",
        "district": "CITRUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027000309",
    },
    {
        "school": "HOMOSASSA ELEMENTARY SCHOOL",
        "district": "CITRUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027000310",
    },
    {
        "school": "CRYSTAL RIVER MIDDLE SCHOOL",
        "district": "CITRUS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027000312",
    },
    {
        "school": "CRYSTAL RIVER PRIMARY SCHOOL",
        "district": "CITRUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027000313",
    },
    {
        "school": "CRYSTAL RIVER HIGH SCHOOL",
        "district": "CITRUS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027000314",
    },
    {
        "school": "WITHLACOOCHEE TECHNICAL COLLEGE",
        "district": "CITRUS",
        "level": "Middle",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120027000315",
    },
    {
        "school": "CREST SCHOOL",
        "district": "CITRUS",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120027002088",
    },
    {
        "school": "CITRUS SPRINGS MIDDLE SCHOOL",
        "district": "CITRUS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027002089",
    },
    {
        "school": "LECANTO MIDDLE SCHOOL",
        "district": "CITRUS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027002123",
    },
    {
        "school": "LECANTO PRIMARY SCHOOL",
        "district": "CITRUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027002424",
    },
    {
        "school": "LECANTO HIGH SCHOOL",
        "district": "CITRUS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027002425",
    },
    {
        "school": "HERNANDO ELEMENTARY SCHOOL",
        "district": "CITRUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027002426",
    },
    {
        "school": "CITRUS SPRINGS ELEMENTARY SCHOOL",
        "district": "CITRUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027002493",
    },
    {
        "school": "PLEASANT GROVE ELEMENTARY SCHOOL",
        "district": "CITRUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027002595",
    },
    {
        "school": "ROCK CRUSHER ELEMENTARY SCHOOL",
        "district": "CITRUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027002727",
    },
    {
        "school": "CYPRESS CREEK ACADEMY",
        "district": "CITRUS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120027003035",
    },
    {
        "school": "CITRUS COUNTY RENAISSANCE CENTER",
        "district": "CITRUS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120027003158",
    },
    {
        "school": "FOREST RIDGE ELEMENTARY SCHOOL",
        "district": "CITRUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027004325",
    },
    {
        "school": "ACADEMY OF ENVIRONMENTAL SCIENCE",
        "district": "CITRUS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027004326",
    },
    {
        "school": "COPPERGATE ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030005773",
    },
    {
        "school": "PREK/KINDERGARTEN CENTER",
        "district": "BAKER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120006005427",
    },
    {
        "school": "FLEMING ISLAND HIGH SCHOOL",
        "district": "CLAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030004062",
    },
    {
        "school": "SWIMMING PEN CREEK ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030004190",
    },
    {
        "school": "LAKE ASBURY JUNIOR HIGH SCHOOL",
        "district": "CLAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030005468",
    },
    {
        "school": "ARGYLE ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030005469",
    },
    {
        "school": "DON BREWER ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048003843",
    },
    {
        "school": "KERNAN TRAIL ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048003844",
    },
    {
        "school": "OCEANWAY ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048003845",
    },
    {
        "school": "KERNAN MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048003846",
    },
    {
        "school": "BISCAYNE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048004079",
    },
    {
        "school": "SCHOOL FOR ACCELERATED LEARNING AND TECHNOLOGIES INC",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048004191",
    },
    {
        "school": "OCEANWAY SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048004193",
    },
    {
        "school": "J. ALLEN AXSON ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048004197",
    },
    {
        "school": "YULEE MIDDLE SCHOOL",
        "district": "NASSAU",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135004113",
    },
    {
        "school": "ST. JOHNS COUNTY JAIL (DJJ)",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120174003931",
    },
    {
        "school": "DURBIN CREEK ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174004141",
    },
    {
        "school": "ST. JOHNS TECHNICAL HIGH SCHOOL",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120174004194",
    },
    {
        "school": "ST JOHNS COUNTY JUVENILE RESIDENTIAL",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120174004195",
    },
    {
        "school": "TIMBERLIN CREEK ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174005723",
    },
    {
        "school": "SOUTH WOODS ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174005724",
    },
    {
        "school": "HICKORY CREEK ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174005725",
    },
    {
        "school": "BAKER COUNTY SENIOR HIGH SCHOOL",
        "district": "BAKER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120006000035",
    },
    {
        "school": "MACCLENNY ELEMENTARY SCHOOL",
        "district": "BAKER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120006000036",
    },
    {
        "school": "BAKER COUNTY MIDDLE SCHOOL",
        "district": "BAKER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120006000037",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "BAKER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120006000038",
    },
    {
        "school": "J FRANKLYN KELLER INTERMEDIATE SCHOOL",
        "district": "BAKER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120006002647",
    },
    {
        "school": "FLORIDA YOUTH CHALLENGE ACADEMY",
        "district": "CLAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030003690",
    },
    {
        "school": "ROBERT M. PATERSON ELEMENTARY",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000203",
    },
    {
        "school": "GREEN COVE SPRINGS JUNIOR HIGH SCHOOL",
        "district": "CLAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000317",
    },
    {
        "school": "CHARLES E. BENNETT ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000319",
    },
    {
        "school": "ORANGE PARK ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000320",
    },
    {
        "school": "GROVE PARK ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000321",
    },
    {
        "school": "W E CHERRY ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000322",
    },
    {
        "school": "ORANGE PARK HIGH SCHOOL",
        "district": "CLAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000323",
    },
    {
        "school": "DOCTORS INLET ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000325",
    },
    {
        "school": "MIDDLEBURG ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000326",
    },
    {
        "school": "KEYSTONE HEIGHTS ELEMENTARY",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000327",
    },
    {
        "school": "KEYSTONE HEIGHTS JUNIOR/SENIOR HIGH",
        "district": "CLAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000328",
    },
    {
        "school": "S BRYAN JENNINGS ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000329",
    },
    {
        "school": "CLAY HIGH SCHOOL",
        "district": "CLAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000330",
    },
    {
        "school": "LAKESIDE JUNIOR HIGH SCHOOL",
        "district": "CLAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000331",
    },
    {
        "school": "LAKESIDE ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000332",
    },
    {
        "school": "ORANGE PARK JUNIOR HIGH SCHOOL",
        "district": "CLAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000333",
    },
    {
        "school": "WILKINSON JUNIOR HIGH SCHOOL",
        "district": "CLAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000334",
    },
    {
        "school": "MONTCLAIR ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030000335",
    },
    {
        "school": "MIDDLEBURG HIGH SCHOOL",
        "district": "CLAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030002053",
    },
    {
        "school": "TYNES ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030002092",
    },
    {
        "school": "RIDGEVIEW ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030002287",
    },
    {
        "school": "CLAY HILL ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030002427",
    },
    {
        "school": "RIDGEVIEW HIGH SCHOOL",
        "district": "CLAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030002494",
    },
    {
        "school": "LAKE ASBURY ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030002550",
    },
    {
        "school": "R. C. BANNERMAN LEARNING CENTER",
        "district": "CLAY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120030002728",
    },
    {
        "school": "J.L. WILKINSON ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030002729",
    },
    {
        "school": "MCRAE ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030003036",
    },
    {
        "school": "FLEMING ISLAND ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030003037",
    },
    {
        "school": "RIDEOUT ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030003691",
    },
    {
        "school": "THUNDERBOLT ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030004328",
    },
    {
        "school": "AMIKIDS JACKSONVILLE",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048000425",
    },
    {
        "school": "MATTIE V RUTHERFORD ALT ED CENTER",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048000629",
    },
    {
        "school": "WEST RIVERSIDE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000633",
    },
    {
        "school": "GRAND PARK CAREER CENTER",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048000635",
    },
    {
        "school": "BRENTWOOD ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000636",
    },
    {
        "school": "ORTEGA ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000637",
    },
    {
        "school": "CENTRAL RIVERSIDE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000638",
    },
    {
        "school": "RUTH N. UPSON ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000639",
    },
    {
        "school": "FISHWEIR ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000640",
    },
    {
        "school": "ANNIE R. MORGAN ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000641",
    },
    {
        "school": "KIRBY-SMITH MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000645",
    },
    {
        "school": "LORETTO ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000646",
    },
    {
        "school": "JULIA LANDON COLLEGE PREPARATORY & LEADERSHIP DEVELOPMENT SC",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000647",
    },
    {
        "school": "ROBERT E. LEE HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000648",
    },
    {
        "school": "ANDREW JACKSON HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000649",
    },
    {
        "school": "HENRY F. KITE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000650",
    },
    {
        "school": "BALDWIN MIDDLE-SENIOR HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000651",
    },
    {
        "school": "DINSMORE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000652",
    },
    {
        "school": "ARLINGTON ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000653",
    },
    {
        "school": "THOMAS JEFFERSON ELEMENTARY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000654",
    },
    {
        "school": "WHITEHOUSE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000655",
    },
    {
        "school": "GARDEN CITY ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000657",
    },
    {
        "school": "DUNCAN U. FLETCHER MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000660",
    },
    {
        "school": "HOGAN-SPRING GLEN ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000661",
    },
    {
        "school": "ATLANTIC BEACH ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000662",
    },
    {
        "school": "ALFRED I. DUPONT MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000663",
    },
    {
        "school": "VENETIA ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000664",
    },
    {
        "school": "LAKE SHORE MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000665",
    },
    {
        "school": "NORTH SHORE ELEMENTARY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000666",
    },
    {
        "school": "HENDRICKS AVENUE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000667",
    },
    {
        "school": "SPRING PARK ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000668",
    },
    {
        "school": "JOHN LOVE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000669",
    },
    {
        "school": "PAXON SCHOOL/ADVANCED STUDIES",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000671",
    },
    {
        "school": "SOUTHSIDE ESTATES ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000672",
    },
    {
        "school": "HYDE PARK ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000673",
    },
    {
        "school": "BILTMORE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000674",
    },
    {
        "school": "RAMONA BOULEVARD ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000675",
    },
    {
        "school": "SAN PABLO ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000676",
    },
    {
        "school": "LOVE GROVE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000677",
    },
    {
        "school": "SAN JOSE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000678",
    },
    {
        "school": "BAYVIEW ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000679",
    },
    {
        "school": "LAKE LUCINA ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000680",
    },
    {
        "school": "TERRY PARKER HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000681",
    },
    {
        "school": "ENGLEWOOD ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000682",
    },
    {
        "school": "JOHN STOCKTON ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000683",
    },
    {
        "school": "WOODLAND ACRES ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000684",
    },
    {
        "school": "ENGLEWOOD HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000685",
    },
    {
        "school": "SALLYE B. MATHIS ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000686",
    },
    {
        "school": "PINEDALE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000688",
    },
    {
        "school": "WINDY HILL ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000689",
    },
    {
        "school": "RUTLEDGE H. PEARSON ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000690",
    },
    {
        "school": "JEAN RIBAULT HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000691",
    },
    {
        "school": "CEDAR HILLS ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000692",
    },
    {
        "school": "TIMUCUAN ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000693",
    },
    {
        "school": "HIGHLANDS ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000694",
    },
    {
        "school": "LONG BRANCH ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000695",
    },
    {
        "school": "SADIE T. TILLIS ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000697",
    },
    {
        "school": "SAINT CLAIR EVANS ACADEMY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000698",
    },
    {
        "school": "SUSIE E. TOLBERT ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000699",
    },
    {
        "school": "JACKSONVILLE BEACH ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000701",
    },
    {
        "school": "MATTHEW W. GILBERT MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000702",
    },
    {
        "school": "SMART POPE LIVINGSTON ELEMENTARY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000704",
    },
    {
        "school": "JAMES WELDON JOHNSON COLLEGE PREPARTORY MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000705",
    },
    {
        "school": "STANTON COLLEGE PREPARATORY",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000706",
    },
    {
        "school": "JOHN E. FORD K-8 SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000707",
    },
    {
        "school": "NORTHWESTERN MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000708",
    },
    {
        "school": "GEORGE WASHINGTON CARVER ELEMENTARY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000710",
    },
    {
        "school": "PINE FOREST ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000711",
    },
    {
        "school": "R. V. DANIELS ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000712",
    },
    {
        "school": "RUFUS E. PAYNE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000713",
    },
    {
        "school": "WILLIAM M. RAINES HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000714",
    },
    {
        "school": "CARTER G. WOODSON ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000715",
    },
    {
        "school": "S. A. HULL ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000717",
    },
    {
        "school": "PALM AVENUE EXCEP. STUDENT CENTER",
        "district": "DUVAL",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120048000718",
    },
    {
        "school": "HOSPITAL AND HOMEBOUND",
        "district": "DUVAL",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120048000720",
    },
    {
        "school": "YOUTH DEVELOPMENT CENTER",
        "district": "DUVAL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048000721",
    },
    {
        "school": "REYNOLDS LANE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000728",
    },
    {
        "school": "KINGS TRAIL ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000729",
    },
    {
        "school": "PICKETT ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000731",
    },
    {
        "school": "BROOKVIEW ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000732",
    },
    {
        "school": "J. E. B. STUART MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000733",
    },
    {
        "school": "PARKWOOD HEIGHTS ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000734",
    },
    {
        "school": "HOLIDAY HILL ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000735",
    },
    {
        "school": "SOUTHSIDE MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000737",
    },
    {
        "school": "JEAN RIBAULT MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000738",
    },
    {
        "school": "ARLINGTON MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000739",
    },
    {
        "school": "HYDE GROVE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000740",
    },
    {
        "school": "JEFFERSON DAVIS MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000742",
    },
    {
        "school": "SAN MATEO ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000743",
    },
    {
        "school": "JOSEPH STILWELL MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000744",
    },
    {
        "school": "MARTIN LUTHER KING JR ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000745",
    },
    {
        "school": "NORMANDY VILLAGE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000746",
    },
    {
        "school": "GREENFIELD ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000747",
    },
    {
        "school": "DUNCAN U. FLETCHER HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000748",
    },
    {
        "school": "SAMUEL W. WOLFSON HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000749",
    },
    {
        "school": "SEABREEZE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000750",
    },
    {
        "school": "MAYPORT ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000751",
    },
    {
        "school": "MERRILL ROAD ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000752",
    },
    {
        "school": "JACKSONVILLE HEIGHTS ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000753",
    },
    {
        "school": "BEAUCLERC ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000754",
    },
    {
        "school": "LONE STAR ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000755",
    },
    {
        "school": "STONEWALL JACKSON ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000756",
    },
    {
        "school": "FORT CAROLINE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000757",
    },
    {
        "school": "MAMIE AGNES JONES ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000758",
    },
    {
        "school": "SANDALWOOD HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000759",
    },
    {
        "school": "FORT CAROLINE MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000760",
    },
    {
        "school": "ARLINGTON HEIGHTS ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000761",
    },
    {
        "school": "WESTSIDE HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000762",
    },
    {
        "school": "LOUIS S. SHEFFIELD ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000763",
    },
    {
        "school": "GREGORY DRIVE ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000764",
    },
    {
        "school": "HIGHLANDS MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000765",
    },
    {
        "school": "JOSEPH FINEGAN ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000766",
    },
    {
        "school": "EDWARD H. WHITE HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000767",
    },
    {
        "school": "PINE ESTATES ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000768",
    },
    {
        "school": "ALDEN ROAD EXCEP. STUDENT CENTER",
        "district": "DUVAL",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120048000769",
    },
    {
        "school": "MAYPORT MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000770",
    },
    {
        "school": "FRANK H. PETERSON ACADEMIES",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000772",
    },
    {
        "school": "A. PHILIP RANDOLPH ACADEMIES",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048000773",
    },
    {
        "school": "PRETRIAL DETENTION FACILITY",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048001571",
    },
    {
        "school": "CROWN POINT ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002159",
    },
    {
        "school": "TEEN PARENT SERVICE CENTER",
        "district": "DUVAL",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002161",
    },
    {
        "school": "MARINE SCIENCE EDUCATION CENTER",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048002162",
    },
    {
        "school": "NEPTUNE BEACH ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002163",
    },
    {
        "school": "DOUGLAS ANDERSON SCHOOL OF THE ARTS",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002469",
    },
    {
        "school": "CRYSTAL SPRINGS ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002556",
    },
    {
        "school": "MANDARIN OAKS ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002700",
    },
    {
        "school": "CHIMNEY LAKES ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002739",
    },
    {
        "school": "SABAL PALM ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002740",
    },
    {
        "school": "LANDMARK MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002741",
    },
    {
        "school": "ALIMACANI ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002742",
    },
    {
        "school": "MANDARIN MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002743",
    },
    {
        "school": "MANDARIN HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002744",
    },
    {
        "school": "FIRST COAST HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002745",
    },
    {
        "school": "DARNELL COOKMAN MIDDLE/HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002816",
    },
    {
        "school": "GREENLAND PINES ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002817",
    },
    {
        "school": "ANDREW A. ROBINSON ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048002818",
    },
    {
        "school": "MT. HERMAN ESE CENTER",
        "district": "DUVAL",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120048003053",
    },
    {
        "school": "GATEWAY COMMUNITY SERVICES",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048003167",
    },
    {
        "school": "PACE CENTER FOR GIRLS-JAX",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048003169",
    },
    {
        "school": "SCHOOL OF SUCCESS ACADEMY-SOS",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048003172",
    },
    {
        "school": "ABESS PARK ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048003173",
    },
    {
        "school": "DUVAL ACADEMY",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048003352",
    },
    {
        "school": "IMPACT HALFWAY HOUSE",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048003354",
    },
    {
        "school": "DUVAL REGIONAL JUVENILE DETENTION CENTER",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048003356",
    },
    {
        "school": "TWIN LAKES ACADEMY ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048003360",
    },
    {
        "school": "TWIN LAKES ACADEMY MIDDLE SCHOOL",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048003361",
    },
    {
        "school": "ENTERPRISE LEARNING ACADEMY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048003362",
    },
    {
        "school": "CHET'S CREEK ELEMENTARY SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048003363",
    },
    {
        "school": "WAYMAN ACADEMY OF THE ARTS",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048004343",
    },
    {
        "school": "LAVILLA SCHOOL OF THE ARTS",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048004344",
    },
    {
        "school": "FERNANDINA BEACH MIDDLE SCHOOL",
        "district": "NASSAU",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135001307",
    },
    {
        "school": "SOUTHSIDE ELEMENTARY SCHOOL",
        "district": "NASSAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135001309",
    },
    {
        "school": "EMMA LOVE HARDEE ELEMENTARY",
        "district": "NASSAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135001310",
    },
    {
        "school": "YULEE ELEMENTARY SCHOOL",
        "district": "NASSAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135001311",
    },
    {
        "school": "CALLAHAN ELEMENTARY SCHOOL",
        "district": "NASSAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135001313",
    },
    {
        "school": "CALLAHAN MIDDLE SCHOOL",
        "district": "NASSAU",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135001314",
    },
    {
        "school": "HILLIARD MIDDLE-SENIOR HIGH",
        "district": "NASSAU",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135001315",
    },
    {
        "school": "BRYCEVILLE ELEMENTARY SCHOOL",
        "district": "NASSAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135001316",
    },
    {
        "school": "WEST NASSAU COUNTY HIGH SCHOOL",
        "district": "NASSAU",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135001317",
    },
    {
        "school": "HILLIARD ELEMENTARY SCHOOL",
        "district": "NASSAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135001318",
    },
    {
        "school": "CALLAHAN INTERMEDIATE SCHOOL",
        "district": "NASSAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135001319",
    },
    {
        "school": "YULEE PRIMARY SCHOOL",
        "district": "NASSAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135002520",
    },
    {
        "school": "FERNANDINA BEACH HIGH SCHOOL",
        "district": "NASSAU",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135002851",
    },
    {
        "school": "PONTE VEDRA PALM VALLEY- RAWLINGS ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174001057",
    },
    {
        "school": "OTIS A. MASON ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174001060",
    },
    {
        "school": "CROOKSHANK ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174001905",
    },
    {
        "school": "KETTERLINUS ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174001909",
    },
    {
        "school": "R. B. HUNT ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174001914",
    },
    {
        "school": "R J MURRAY MIDDLE SCHOOL",
        "district": "ST. JOHNS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174001915",
    },
    {
        "school": "ST. AUGUSTINE HIGH SCHOOL",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174001916",
    },
    {
        "school": "THE WEBSTER SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174001918",
    },
    {
        "school": "FIRST COAST TECHNICAL COLLEGE",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120174001919",
    },
    {
        "school": "JULINGTON CREEK ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174001920",
    },
    {
        "school": "ALLEN D NEASE SENIOR HIGH SCHOOL",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174002262",
    },
    {
        "school": "W. DOUGLAS HARTLEY ELEMENTARY",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174002263",
    },
    {
        "school": "SEBASTIAN MIDDLE SCHOOL",
        "district": "ST. JOHNS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174002896",
    },
    {
        "school": "ALICE B. LANDRUM MIDDLE SCHOOL",
        "district": "ST. JOHNS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174002897",
    },
    {
        "school": "SWITZERLAND POINT MIDDLE SCHOOL",
        "district": "ST. JOHNS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174002898",
    },
    {
        "school": "OSCEOLA ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174002899",
    },
    {
        "school": "MILL CREEK ACADEMY",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174002900",
    },
    {
        "school": "GAMBLE ROGERS MIDDLE SCHOOL",
        "district": "ST. JOHNS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174002956",
    },
    {
        "school": "GAINES ALTERNATIVE AT HAMBLEN",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120174003017",
    },
    {
        "school": "CUNNINGHAM CREEK ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174003018",
    },
    {
        "school": "OCEAN PALMS ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174003120",
    },
    {
        "school": "HASTINGS JUVENILE CORRECTIONAL",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120174003660",
    },
    {
        "school": "THERAPEUTIC LEARNING CENTER",
        "district": "ST. JOHNS",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120174003792",
    },
    {
        "school": "FRUIT COVE MIDDLE SCHOOL",
        "district": "ST. JOHNS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174003794",
    },
    {
        "school": "ST JOHNS COUNTY TRANSITION PROGRAM",
        "district": "ST. JOHNS",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120174004443",
    },
    {
        "school": "PEDRO MENENDEZ HIGH SCHOOL",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174004444",
    },
    {
        "school": "BARTRAM TRAIL HIGH SCHOOL",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174004445",
    },
    {
        "school": "DEAF ELEMENTARY SCHOOL (FSDB)",
        "district": "DEAF/BLIND",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120201601212",
    },
    {
        "school": "DEAF MIDDLE SCHOOL (FSDB)",
        "district": "DEAF/BLIND",
        "level": "Middle",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120201601246",
    },
    {
        "school": "DEAF HIGH SCHOOL (FSDB)",
        "district": "DEAF/BLIND",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120201601247",
    },
    {
        "school": "BLIND PK-8 SCHOOL (FSDB)",
        "district": "DEAF/BLIND",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120201601257",
    },
    {
        "school": "BLIND HIGH SCHOOL (FSDB)",
        "district": "DEAF/BLIND",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120201601265",
    },
    {
        "school": "BIG PINE ACADEMY",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132003875",
    },
    {
        "school": "MONROE JUVENILE DETENTION CENTER",
        "district": "MONROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120132005622",
    },
    {
        "school": "CORAL SHORES HIGH SCHOOL",
        "district": "MONROE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132001292",
    },
    {
        "school": "KEY WEST HIGH SCHOOL",
        "district": "MONROE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132001294",
    },
    {
        "school": "HORACE O'BRYANT SCHOOL",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132001295",
    },
    {
        "school": "MARATHON SCHOOL",
        "district": "MONROE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132001296",
    },
    {
        "school": "POINCIANA ELEMENTARY SCHOOL",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132001299",
    },
    {
        "school": "SUGARLOAF SCHOOL",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132001301",
    },
    {
        "school": "STANLEY SWITLIK ELEMENTARY SCHOOL",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132001303",
    },
    {
        "school": "KEY LARGO SCHOOL",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132001304",
    },
    {
        "school": "GERALD ADAMS ELEMENTARY SCHOOL",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132001305",
    },
    {
        "school": "PLANTATION KEY SCHOOL",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132001306",
    },
    {
        "school": "MAY SANDS MONTESSORI SCHOOL",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132003440",
    },
    {
        "school": "TREASURE VILLAGE MONTESSORI CHARTER SCHOOL",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132003619",
    },
    {
        "school": "COLUMBIA HIGH SCHOOL",
        "district": "COLUMBIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036000358",
    },
    {
        "school": "RICHARDSON SIXTH GRADE ACADEMY",
        "district": "COLUMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036000359",
    },
    {
        "school": "MELROSE PARK ELEMENTARY SCHOOL",
        "district": "COLUMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036000360",
    },
    {
        "school": "EASTSIDE ELEMENTARY SCHOOL",
        "district": "COLUMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036000361",
    },
    {
        "school": "FIVE POINTS ELEMENTARY SCHOOL",
        "district": "COLUMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036000362",
    },
    {
        "school": "FORT WHITE ELEMENTARY SCHOOL",
        "district": "COLUMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036000363",
    },
    {
        "school": "SUMMERS ELEMENTARY SCHOOL",
        "district": "COLUMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036000364",
    },
    {
        "school": "NIBLACK ELEMENTARY SCHOOL",
        "district": "COLUMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036000365",
    },
    {
        "school": "PATHWAYS ACADEMY",
        "district": "COLUMBIA",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120036000366",
    },
    {
        "school": "COLUMBIA CITY ELEMENTARY SCHOOL",
        "district": "COLUMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036002102",
    },
    {
        "school": "LAKE CITY MIDDLE SCHOOL",
        "district": "COLUMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036002732",
    },
    {
        "school": "FORT WHITE HIGH SCHOOL",
        "district": "COLUMBIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036004331",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "COLUMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036004332",
    },
    {
        "school": "PALMETTO ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159005342",
    },
    {
        "school": "R. BRUCE WAGNER ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159003923",
    },
    {
        "school": "COMPASS MIDDLE CHARTER SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159003925",
    },
    {
        "school": "DR. NE ROBERTS ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159003926",
    },
    {
        "school": "ROSABELLE W. BLAKE ACADEMY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159003927",
    },
    {
        "school": "POLK COUNTY SHERIFF'S CENTRAL CENTER",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159003929",
    },
    {
        "school": "MCKEEL ELEMENTARY ACADEMY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004137",
    },
    {
        "school": "LAKELAND MONTESSORI SCHOOL HOUSE",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004178",
    },
    {
        "school": "RIDGE COMMUNITY HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004179",
    },
    {
        "school": "POLK VIRTUAL FRANCHISE",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004180",
    },
    {
        "school": "HOSPITAL HOMEBOUND",
        "district": "POLK",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120159004185",
    },
    {
        "school": "POLK STATE COLLEGE COLLEGIATE HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004186",
    },
    {
        "school": "BERKLEY ACCELERATED MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004188",
    },
    {
        "school": "SLEEPY HILL ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159005337",
    },
    {
        "school": "HIGHLANDS GROVE ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159005338",
    },
    {
        "school": "CHAIN OF LAKES ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159005714",
    },
    {
        "school": "HIGHLANDS YOUTH ACADEMY",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159003495",
    },
    {
        "school": "LOUGHMAN OAKS ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001043",
    },
    {
        "school": "LAKELAND SENIOR HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001703",
    },
    {
        "school": "SOUTHWEST MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001705",
    },
    {
        "school": "CARLTON PALMORE ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001706",
    },
    {
        "school": "CLEVELAND COURT ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001708",
    },
    {
        "school": "COMBEE ACADEMY OF DESIGN AND ENGINEERING",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001709",
    },
    {
        "school": "CRYSTAL LAKE ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001710",
    },
    {
        "school": "DIXIELAND ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001712",
    },
    {
        "school": "PHILIP O'BRIEN ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001713",
    },
    {
        "school": "MEDULLA ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001715",
    },
    {
        "school": "NORTH LAKELAND ELEMENTARY SCHOOL OF CHOICE",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001716",
    },
    {
        "school": "SOUTHWEST ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001717",
    },
    {
        "school": "LINCOLN AVENUE ACADEMY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001718",
    },
    {
        "school": "ROCHELLE SCHOOL OF THE ARTS",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001719",
    },
    {
        "school": "SHELLEY S. BOONE MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001721",
    },
    {
        "school": "ALTA VISTA ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001722",
    },
    {
        "school": "EASTSIDE ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001723",
    },
    {
        "school": "BETHUNE ACADEMY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001724",
    },
    {
        "school": "DAVENPORT SCHOOL OF THE ARTS",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001725",
    },
    {
        "school": "WINTER HAVEN SENIOR HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001726",
    },
    {
        "school": "DENISON MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001727",
    },
    {
        "school": "FRANK E. BRIGHAM ACADEMY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001728",
    },
    {
        "school": "WESTWOOD MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001729",
    },
    {
        "school": "ELBERT ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001730",
    },
    {
        "school": "FRED G. GARNER ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001731",
    },
    {
        "school": "INWOOD ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001732",
    },
    {
        "school": "LAKE SHIPP ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001733",
    },
    {
        "school": "JOHN SNIVELY ELEMENTARY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001734",
    },
    {
        "school": "LAKE ALFRED ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001735",
    },
    {
        "school": "KAREN M. SIEGEL ACADEMY",
        "district": "POLK",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120159001736",
    },
    {
        "school": "WAHNETA ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001737",
    },
    {
        "school": "JEWETT MIDDLE ACADEMY MAGNET",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001739",
    },
    {
        "school": "JEWETT SCHOOL OF THE ARTS",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001740",
    },
    {
        "school": "FORT MEADE MIDDLE/SENIOR HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001743",
    },
    {
        "school": "AUBURNDALE SENIOR HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001745",
    },
    {
        "school": "LENA VISTA ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001748",
    },
    {
        "school": "AUBURNDALE CENTRAL ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001749",
    },
    {
        "school": "WALTER CALDWELL ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001750",
    },
    {
        "school": "POLK CITY ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001752",
    },
    {
        "school": "BARTOW SENIOR HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001753",
    },
    {
        "school": "BARTOW MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001754",
    },
    {
        "school": "BARTOW ELEMENTARY ACADEMY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001755",
    },
    {
        "school": "FLORAL AVENUE ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001756",
    },
    {
        "school": "JEAN O'DELL LEARNING CENTER",
        "district": "POLK",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120159001757",
    },
    {
        "school": "ALTURAS ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001760",
    },
    {
        "school": "HIGHLAND CITY ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001761",
    },
    {
        "school": "MULBERRY SENIOR HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001762",
    },
    {
        "school": "PURCELL ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001763",
    },
    {
        "school": "KINGSFORD ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001764",
    },
    {
        "school": "MULBERRY MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001765",
    },
    {
        "school": "KATHLEEN SENIOR HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001766",
    },
    {
        "school": "KATHLEEN MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001767",
    },
    {
        "school": "KATHLEEN ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001768",
    },
    {
        "school": "GRIFFIN ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001769",
    },
    {
        "school": "JESSE KEEN ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001770",
    },
    {
        "school": "WINSTON ACADEMY OF ENGINEERING",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001771",
    },
    {
        "school": "FROSTPROOF ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001772",
    },
    {
        "school": "MCLAUGHLIN MIDDLE SCHOOL AND FINE ARTS ACADEMY",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001773",
    },
    {
        "school": "POLK AVENUE ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001774",
    },
    {
        "school": "HILLCREST ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001775",
    },
    {
        "school": "SPOOK HILL ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001776",
    },
    {
        "school": "ROOSEVELT ACADEMY",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159001777",
    },
    {
        "school": "JANIE HOWARD WILSON SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001778",
    },
    {
        "school": "DALE R FAIR BABSON PARK ELEMENTARY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001779",
    },
    {
        "school": "EDGAR L. PADGETT ELEMENTARY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001780",
    },
    {
        "school": "GAUSE ACADEMY OF LEADERSHIP",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159001781",
    },
    {
        "school": "CRYSTAL LAKE MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001782",
    },
    {
        "school": "OSCAR J. POPE ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001783",
    },
    {
        "school": "MAYNARD A TRAVISS TECHNICAL COLLEGE",
        "district": "POLK",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120159001784",
    },
    {
        "school": "MCKEEL ACADEMY OF TECHNOLOGY",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001785",
    },
    {
        "school": "SCOTT LAKE ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001786",
    },
    {
        "school": "RIDGE TECHNICAL COLLEGE",
        "district": "POLK",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120159001787",
    },
    {
        "school": "EAGLE LAKE ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001788",
    },
    {
        "school": "GARDEN GROVE ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001789",
    },
    {
        "school": "LAKE WALES SENIOR HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001790",
    },
    {
        "school": "JAMES E. STEPHENS ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001791",
    },
    {
        "school": "LAKE GIBSON MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001792",
    },
    {
        "school": "LAKELAND HIGHLANDS MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001793",
    },
    {
        "school": "DUNDEE ELEMENTARY ACADEMY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001794",
    },
    {
        "school": "HAINES CITY SENIOR HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001795",
    },
    {
        "school": "FROSTPROOF MIDDLE/SENIOR HIGH",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001796",
    },
    {
        "school": "BEN HILL GRIFFIN JR ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001982",
    },
    {
        "school": "GEORGE W. JENKINS SENIOR HIGH",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159001985",
    },
    {
        "school": "BILL DUNCAN OPPORTUNITY CENTER",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159001989",
    },
    {
        "school": "CLARENCE BOSWELL ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159002401",
    },
    {
        "school": "DORIS A. SANDERS LEARNING CENTER",
        "district": "POLK",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120159002402",
    },
    {
        "school": "JAMES W. SIKES ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159002404",
    },
    {
        "school": "LAKE GIBSON SENIOR HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159002405",
    },
    {
        "school": "JERE L. STAMBAUGH MIDDLE",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159002456",
    },
    {
        "school": "UNION ACADEMY",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159002457",
    },
    {
        "school": "R. CLEM CHURCHWELL ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159002480",
    },
    {
        "school": "WENDELL WATSON ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159002893",
    },
    {
        "school": "VALLEYVIEW ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159002894",
    },
    {
        "school": "SOCRUM ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159002895",
    },
    {
        "school": "RIDGE TEEN PARENT PROGRAM",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159002947",
    },
    {
        "school": "POLK HALFWAY HOUSE",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159002949",
    },
    {
        "school": "LAWTON CHILES MIDDLE ACADEMY",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159003015",
    },
    {
        "school": "LAKE REGION HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159003016",
    },
    {
        "school": "DISCOVERY ACADEMY OF LAKE ALFRED",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159003112",
    },
    {
        "school": "DON E WOODS OPPORTUNITY CENTER",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159003256",
    },
    {
        "school": "ACHIEVEMENT ACADEMY",
        "district": "POLK",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120159003259",
    },
    {
        "school": "SLEEPY HILL MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159003655",
    },
    {
        "school": "DUNDEE RIDGE MIDDLE ACADEMY",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159003656",
    },
    {
        "school": "HARTRIDGE ACADEMY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159003788",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159003789",
    },
    {
        "school": "DANIEL JENKINS ACADEMY OF TECHNOLOGY MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004435",
    },
    {
        "school": "SANDHILL ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004436",
    },
    {
        "school": "RIDGEVIEW GLOBAL STUDIES ACADEMY",
        "district": "POLK",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004437",
    },
    {
        "school": "LEWIS ANNA WOODBURY ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004438",
    },
    {
        "school": "PINEWOOD ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004440",
    },
    {
        "school": "BERKLEY ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159004441",
    },
    {
        "school": "HIALEAH GARDENS SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039006229",
    },
    {
        "school": "WEST HIALEAH GARDENS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039006435",
    },
    {
        "school": "ENDEAVOUR PRIMARY LEARNING CENTER",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003813",
    },
    {
        "school": "SILVER SHORES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003814",
    },
    {
        "school": "CYPRESS BAY HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003815",
    },
    {
        "school": "SUNSET LAKES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003816",
    },
    {
        "school": "PARK LAKES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003817",
    },
    {
        "school": "LIBERTY ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003818",
    },
    {
        "school": "MANATEE BAY ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003819",
    },
    {
        "school": "WESTGLADES MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003820",
    },
    {
        "school": "NEW RENAISSANCE MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003821",
    },
    {
        "school": "MILLENNIUM 6-12 COLLEGIATE ACADEMY",
        "district": "BROWARD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003822",
    },
    {
        "school": "SOMERSET ACADEMY CHARTER HIGH",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003823",
    },
    {
        "school": "CORAL GLADES HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004037",
    },
    {
        "school": "GLADES MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004038",
    },
    {
        "school": "CORAL COVE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004039",
    },
    {
        "school": "DOLPHIN BAY ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004040",
    },
    {
        "school": "MONARCH HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004050",
    },
    {
        "school": "ROCK ISLAND ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004051",
    },
    {
        "school": "EVERGLADES HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004052",
    },
    {
        "school": "SOMERSET ACADEMY DAVIE CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004054",
    },
    {
        "school": "BROWARD VIRTUAL FRANCHISE",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004058",
    },
    {
        "school": "HOLLYWOOD ACADEMY OF ARTS & SCIENCE",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004215",
    },
    {
        "school": "EAGLES NEST CHARTER ACADEMY",
        "district": "BROWARD",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018005453",
    },
    {
        "school": "EAGLES NEST MIDDLE CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018005454",
    },
    {
        "school": "CHAMPIONSHIP ACADEMY OF DISTINCTION AT HOLLYWOOD",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018005455",
    },
    {
        "school": "HOLLYWOOD ACADEMY OF ARTS AND SCIENCE MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018005456",
    },
    {
        "school": "NORTH BROWARD ACADEMY OF EXCELLENCE MIDDLE",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018005458",
    },
    {
        "school": "PARAGON ACADEMY OF TECHNOLOGY",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018005460",
    },
    {
        "school": "HENRY D PERRY EDUCATION CENTER",
        "district": "BROWARD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018005464",
    },
    {
        "school": "BOB GRAHAM EDUCATION CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003831",
    },
    {
        "school": "ARCHIMEDEAN ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003832",
    },
    {
        "school": "MATER ACADEMY EAST CHARTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003833",
    },
    {
        "school": "DOWNTOWN MIAMI CHARTER SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003834",
    },
    {
        "school": "MATER ACADEMY CHARTER HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003838",
    },
    {
        "school": "MIAMI COMMUNITY CHARTER SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003970",
    },
    {
        "school": "SOMERSET ACADEMY CHARTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003971",
    },
    {
        "school": "MIAMI CHILDREN'S MUSEUM CHARTER SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003972",
    },
    {
        "school": "SOMERSET ACADEMY CHARTER MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003974",
    },
    {
        "school": "SOMERSET ACADEMY CHARTER HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003975",
    },
    {
        "school": "INTERNATIONAL STUDIES CHARTER HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003977",
    },
    {
        "school": "AVENTURA CITY OF EXCELLENCE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004068",
    },
    {
        "school": "YOUTH CO-OP CHARTER SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004069",
    },
    {
        "school": "THEODORE R. AND THELMA A. GIBSON CHARTER SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004070",
    },
    {
        "school": "DORAL ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004071",
    },
    {
        "school": "ADA MERRITT K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004072",
    },
    {
        "school": "KEYS GATE CHARTER SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004073",
    },
    {
        "school": "MATER ACADEMY CHARTER MIDDLE",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004074",
    },
    {
        "school": "PINECREST ACADEMY CHARTER MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004075",
    },
    {
        "school": "LAMAR LOUISE CURRY MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004076",
    },
    {
        "school": "JOHN A. FERGUSON SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004077",
    },
    {
        "school": "ROBERT MORGAN EDUCATIONAL CENTER",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004078",
    },
    {
        "school": "SUMMERVILLE ADVANTAGE ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004541",
    },
    {
        "school": "THE CHARTER SCHOOL AT WATERSTONE",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039005476",
    },
    {
        "school": "EARLY BEGINNINGS ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039005477",
    },
    {
        "school": "ARCHIMEDEAN MIDDLE CONSERVATORY",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039005485",
    },
    {
        "school": "MATER EAST ACADEMY MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039005487",
    },
    {
        "school": "RENAISSANCE MIDDLE CHARTER SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039005489",
    },
    {
        "school": "DORAL PERFORMING ARTS & ENTERTAINMENT ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039005493",
    },
    {
        "school": "MATER PERFORMING ARTS & ENTERTAINMENT ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039005494",
    },
    {
        "school": "STELLAR LEADERSHIP ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039005495",
    },
    {
        "school": "SOUTH DADE MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039005838",
    },
    {
        "school": "WESTLAND HIALEAH SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039005861",
    },
    {
        "school": "DR. MANUEL C. BARREIRO ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039006617",
    },
    {
        "school": "PLEASANT CITY ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003896",
    },
    {
        "school": "INDEPENDENCE MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003897",
    },
    {
        "school": "FREEDOM SHORES ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003898",
    },
    {
        "school": "CROSSPOINTE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003899",
    },
    {
        "school": "ROYAL PALM BEACH ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003900",
    },
    {
        "school": "BENOIST FARMS ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003901",
    },
    {
        "school": "CHOLEE LAKE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003902",
    },
    {
        "school": "SEAGULL ACADEMY",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150003905",
    },
    {
        "school": "SOMERSET ACADEMY JFK CHARTER SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003907",
    },
    {
        "school": "EVERGLADES PREPARATORY ACADEMY",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150003909",
    },
    {
        "school": "SEMINOLE RIDGE COMMUNITY HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003944",
    },
    {
        "school": "HIDDEN OAKS ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003946",
    },
    {
        "school": "DON ESTRIDGE HIGH TECH MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004015",
    },
    {
        "school": "PARK VISTA COMMUNITY HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004020",
    },
    {
        "school": "TRADEWINDS MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004021",
    },
    {
        "school": "ACADEMY FOR POSITIVE LEARNING",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004022",
    },
    {
        "school": "L C SWAIN MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004024",
    },
    {
        "school": "PIERCE HAMMOCK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004025",
    },
    {
        "school": "WEST BOCA RATON HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004026",
    },
    {
        "school": "GRASSY WATERS ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004028",
    },
    {
        "school": "OSCEOLA CREEK MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004030",
    },
    {
        "school": "PALM BEACH CENTRAL HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004121",
    },
    {
        "school": "JEAGA MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004122",
    },
    {
        "school": "WESTERN ACADEMY CHARTER SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004125",
    },
    {
        "school": "PALM BEACH SCHOOL FOR AUTISM",
        "district": "PALM BEACH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150004127",
    },
    {
        "school": "DIAMOND VIEW ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004128",
    },
    {
        "school": "EQUESTRIAN TRAILS ELEMENTARY",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004129",
    },
    {
        "school": "G-STAR SCHOOL OF THE ARTS",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004131",
    },
    {
        "school": "GULFSTREAM L.I.F.E. ACADEMY",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150005683",
    },
    {
        "school": "ELBRIDGE GALE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150005687",
    },
    {
        "school": "MONTESSORI ACADEMYOF EARLY ENRICHMENT INC",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150005688",
    },
    {
        "school": "HAMMOCK POINTE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150000961",
    },
    {
        "school": "JUPITER ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001476",
    },
    {
        "school": "JUPITER HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001477",
    },
    {
        "school": "ALLAMANDA ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001479",
    },
    {
        "school": "PALM BEACH GARDENS ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001480",
    },
    {
        "school": "HOWELL L. WATKINS MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001481",
    },
    {
        "school": "THE CONSERVATORY SCHOOL AT NORTH PALM BEACH",
        "district": "PALM BEACH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001482",
    },
    {
        "school": "LAKE PARK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001483",
    },
    {
        "school": "SUNCOAST COMMUNITY HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001484",
    },
    {
        "school": "WASHINGTON ELEMENTARY MAGNET SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001485",
    },
    {
        "school": "JOHN F. KENNEDY MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001486",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001487",
    },
    {
        "school": "NORTHMORE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001490",
    },
    {
        "school": "NORTHBORO ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001491",
    },
    {
        "school": "ROOSEVELT MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001492",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001493",
    },
    {
        "school": "WESTWARD ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001494",
    },
    {
        "school": "U. B. KINSEY/PALMVIEW ELEMENTARY",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001495",
    },
    {
        "school": "PALM BEACH PUBLIC SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001497",
    },
    {
        "school": "WEST GATE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001499",
    },
    {
        "school": "BELVEDERE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001501",
    },
    {
        "school": "CONNISTON MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001502",
    },
    {
        "school": "PALMETTO ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001504",
    },
    {
        "school": "SOUTH OLIVE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001506",
    },
    {
        "school": "FOREST HILL COMMUNITY HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001507",
    },
    {
        "school": "MEADOW PARK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001508",
    },
    {
        "school": "BERKSHIRE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001509",
    },
    {
        "school": "PALM SPRINGS MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001510",
    },
    {
        "school": "FOREST HILL ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001511",
    },
    {
        "school": "GREENACRES ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001512",
    },
    {
        "school": "PALM SPRINGS ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001513",
    },
    {
        "school": "HIGHLAND ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001514",
    },
    {
        "school": "NORTH GRADE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001515",
    },
    {
        "school": "LAKE WORTH HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001516",
    },
    {
        "school": "BARTON ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001519",
    },
    {
        "school": "LANTANA ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001520",
    },
    {
        "school": "LANTANA MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001521",
    },
    {
        "school": "ROLLING GREEN ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001522",
    },
    {
        "school": "POINCIANA STEM ELEMENTARY MAGNET SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001523",
    },
    {
        "school": "GALAXY ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001525",
    },
    {
        "school": "FOREST PARK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001526",
    },
    {
        "school": "ATLANTIC HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001527",
    },
    {
        "school": "PLUMOSA SCHOOL OF THE ARTS",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001528",
    },
    {
        "school": "S. D. SPADY ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001529",
    },
    {
        "school": "PINE GROVE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001532",
    },
    {
        "school": "J. C. MITCHELL ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001533",
    },
    {
        "school": "BOCA RATON ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001534",
    },
    {
        "school": "BOCA RATON COMMUNITY HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001535",
    },
    {
        "school": "PAHOKEE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001538",
    },
    {
        "school": "GLADES CENTRAL HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001541",
    },
    {
        "school": "LAKE SHORE MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001543",
    },
    {
        "school": "GOVE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001544",
    },
    {
        "school": "GLADE VIEW ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001545",
    },
    {
        "school": "ROSENWALD ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001547",
    },
    {
        "school": "JOHN I. LEONARD HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001548",
    },
    {
        "school": "PALM BEACH GARDENS HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001549",
    },
    {
        "school": "WYNNEBROOK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001550",
    },
    {
        "school": "WEST RIVIERA ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001551",
    },
    {
        "school": "GROVE PARK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001552",
    },
    {
        "school": "HAGEN ROAD ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001553",
    },
    {
        "school": "MELALEUCA ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001555",
    },
    {
        "school": "ADDISON MIZNER ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001556",
    },
    {
        "school": "INLET GROVE COMMUNITY HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001557",
    },
    {
        "school": "BOCA RATON COMMUNITY MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001558",
    },
    {
        "school": "CLIFFORD O TAYLOR/KIRKLANE ELEMENTARY",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001559",
    },
    {
        "school": "DWIGHT D. EISENHOWER ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001560",
    },
    {
        "school": "CONGRESS COMMUNITY MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150001561",
    },
    {
        "school": "WELLINGTON ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002091",
    },
    {
        "school": "JERRY THOMAS ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002232",
    },
    {
        "school": "SANTALUCES COMMUNITY HIGH",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002233",
    },
    {
        "school": "SOUTH TECH ACADEMY",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002234",
    },
    {
        "school": "CRESTWOOD COMMUNITY MIDDLE",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002365",
    },
    {
        "school": "H. L. JOHNSON ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002370",
    },
    {
        "school": "JUPITER MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002375",
    },
    {
        "school": "LOGGERS' RUN COMMUNITY MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002378",
    },
    {
        "school": "SPANISH RIVER COMMUNITY HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002383",
    },
    {
        "school": "VERDE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002386",
    },
    {
        "school": "WHISPERING PINES ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002450",
    },
    {
        "school": "CORAL SUNSET ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002477",
    },
    {
        "school": "CHRISTA MCAULIFFE MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002523",
    },
    {
        "school": "LOXAHATCHEE GROVES ELEMENTARY",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002524",
    },
    {
        "school": "WELLINGTON LANDINGS MIDDLE",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002578",
    },
    {
        "school": "CALUSA ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002579",
    },
    {
        "school": "PAHOKEE MIDDLE-SENIOR HIGH",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002624",
    },
    {
        "school": "ROYAL PALM SCHOOL",
        "district": "PALM BEACH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150002625",
    },
    {
        "school": "K. E. CUNNINGHAM/CANAL POINT ELEMENTARY",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002626",
    },
    {
        "school": "PALM BEACH LAKES HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002627",
    },
    {
        "school": "INDIAN PINES ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002628",
    },
    {
        "school": "BANYAN CREEK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002629",
    },
    {
        "school": "NEW HORIZONS ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002630",
    },
    {
        "school": "WELLINGTON HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002631",
    },
    {
        "school": "SEMINOLE TRAILS ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002690",
    },
    {
        "school": "DEL PRADO ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002691",
    },
    {
        "school": "LIGHTHOUSE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002692",
    },
    {
        "school": "CYPRESS TRAILS ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002693",
    },
    {
        "school": "SANDPIPER SHORES ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002694",
    },
    {
        "school": "BEAR LAKES MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002695",
    },
    {
        "school": "LIMESTONE CREEK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002696",
    },
    {
        "school": "CITRUS COVE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002697",
    },
    {
        "school": "ALEXANDER W DREYFOOS JUNIOR SCHOOL OF THE ARTS",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002783",
    },
    {
        "school": "LIBERTY PARK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002784",
    },
    {
        "school": "OMNI MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002785",
    },
    {
        "school": "JUPITER FARMS ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002786",
    },
    {
        "school": "WATSON B. DUNCAN MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002870",
    },
    {
        "school": "TIMBER TRACE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002871",
    },
    {
        "school": "CRYSTAL LAKES ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002872",
    },
    {
        "school": "LAKE WORTH COMMUNITY MIDDLE",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002873",
    },
    {
        "school": "ACREAGE PINES ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002874",
    },
    {
        "school": "PANTHER RUN ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002875",
    },
    {
        "school": "OLYMPIC HEIGHTS COMMUNITY HIGH",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002876",
    },
    {
        "school": "WILLIAM T. DWYER HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002877",
    },
    {
        "school": "ESE OTHER TEACHING SERVICES",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150002878",
    },
    {
        "school": "CARVER MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002932",
    },
    {
        "school": "EGRET LAKE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002933",
    },
    {
        "school": "MANATEE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150002934",
    },
    {
        "school": "INDIAN RIDGE SCHOOL",
        "district": "PALM BEACH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150002935",
    },
    {
        "school": "STARLIGHT COVE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003009",
    },
    {
        "school": "WOODLANDS MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003010",
    },
    {
        "school": "ORCHARD VIEW ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003011",
    },
    {
        "school": "PIONEER PARK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003012",
    },
    {
        "school": "WATERS EDGE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003100",
    },
    {
        "school": "OKEEHEELEE MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003101",
    },
    {
        "school": "BELLE GLADE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003102",
    },
    {
        "school": "ROYAL PALM BEACH HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003223",
    },
    {
        "school": "GOLDEN GROVE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003224",
    },
    {
        "school": "WESTERN PINES COMMUNITY MIDDLE",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003225",
    },
    {
        "school": "BAK MIDDLE SCHOOL OF THE ARTS",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003226",
    },
    {
        "school": "PALM BEACH COUNTY JAIL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150003228",
    },
    {
        "school": "PALM BEACH REGIONAL DETENTION CENTER",
        "district": "PALM BEACH",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150003232",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150003236",
    },
    {
        "school": "HIGHRIDGE FAMILY CENTER",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150003246",
    },
    {
        "school": "MORIKAMI PARK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003468",
    },
    {
        "school": "EAGLES LANDING MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003469",
    },
    {
        "school": "ED VENTURE CHARTER SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150003470",
    },
    {
        "school": "POTENTIALS CHARTER SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150003471",
    },
    {
        "school": "BINKS FOREST ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003637",
    },
    {
        "school": "CORAL REEF ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003638",
    },
    {
        "school": "THE LEARNING CENTER AT THE ELS CENTER OF EXCELLENCE",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150003643",
    },
    {
        "school": "ALTERNATIVE PROGRAM CENTRAL",
        "district": "PALM BEACH",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150003648",
    },
    {
        "school": "TEEN PARENT PROGRAM - PK",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003649",
    },
    {
        "school": "BOYNTON BEACH COMMUNITY HIGH",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003755",
    },
    {
        "school": "BEACON COVE INTERMEDIATE SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003756",
    },
    {
        "school": "FRONTIER ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003757",
    },
    {
        "school": "SUNRISE PARK ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003759",
    },
    {
        "school": "DISCOVERY KEY ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003760",
    },
    {
        "school": "SOUTH AREA SECONDARY INTENSIVE TRANSITION PROGRAM",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150003763",
    },
    {
        "school": "IMAGINE SCHOOLS CHANCELLOR CAMPUS",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003768",
    },
    {
        "school": "GLADES ACADEMY INC",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003769",
    },
    {
        "school": "BRIGHT FUTURES ACADEMY",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150003771",
    },
    {
        "school": "TOUSSAINT L'OUVERTURE HIGH",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150003772",
    },
    {
        "school": "SOUTH GRADE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004409",
    },
    {
        "school": "DR. MARY MCLEOD BETHUNE ELEMENTARY",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004410",
    },
    {
        "school": "HERITAGE ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004411",
    },
    {
        "school": "POLO PARK MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004412",
    },
    {
        "school": "PALM BEACH MARITIME ACADEMY",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004413",
    },
    {
        "school": "VILLAGE ACADEMY ON THE ART & SARA JO KOBACKER CAMPUS",
        "district": "PALM BEACH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150004414",
    },
    {
        "school": "CROSSROADS ACADEMY",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150004420",
    },
    {
        "school": "A.D. HENDERSON UNIVERSITY SCHOOL & FAU HIGH SCHOOL",
        "district": "FAU LAB SCH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201203140",
    },
    {
        "school": "DEERFIELD BEACH ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000141",
    },
    {
        "school": "POMPANO BEACH MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000142",
    },
    {
        "school": "OAKLAND PARK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000143",
    },
    {
        "school": "NORTH SIDE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000144",
    },
    {
        "school": "WESTPINE MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000145",
    },
    {
        "school": "WELLEBY ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000146",
    },
    {
        "school": "DANIA ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000147",
    },
    {
        "school": "HOLLYWOOD HILLS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000148",
    },
    {
        "school": "HOLLYWOOD CENTRAL ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000149",
    },
    {
        "school": "GULFSTREAM ACADEMY OF HALLANDALE BEACH",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000150",
    },
    {
        "school": "RIVERLAND ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000151",
    },
    {
        "school": "WEST HOLLYWOOD ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000152",
    },
    {
        "school": "SOUTH BROWARD HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000153",
    },
    {
        "school": "EMBASSY CREEK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000154",
    },
    {
        "school": "WILTON MANORS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000155",
    },
    {
        "school": "BENNETT ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000156",
    },
    {
        "school": "STRANAHAN HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000157",
    },
    {
        "school": "CROISSANT PARK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000158",
    },
    {
        "school": "COLBERT ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000159",
    },
    {
        "school": "MCARTHUR HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000160",
    },
    {
        "school": "SUNRISE MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000161",
    },
    {
        "school": "DILLARD ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000162",
    },
    {
        "school": "WALKER ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000164",
    },
    {
        "school": "COLLINS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000165",
    },
    {
        "school": "MARY M BETHUNE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000166",
    },
    {
        "school": "ATTUCKS MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000167",
    },
    {
        "school": "BLANCHE ELY HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000168",
    },
    {
        "school": "DILLARD  6-12",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000169",
    },
    {
        "school": "DEERFIELD PARK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000170",
    },
    {
        "school": "HALLANDALE HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000171",
    },
    {
        "school": "OAKRIDGE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000175",
    },
    {
        "school": "OLSEN MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000176",
    },
    {
        "school": "MCNICOL MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000177",
    },
    {
        "school": "HARBORDALE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000178",
    },
    {
        "school": "BROWARD ESTATES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000179",
    },
    {
        "school": "WATKINS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000180",
    },
    {
        "school": "NORTH ANDREWS GARDENS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000181",
    },
    {
        "school": "MIRAMAR ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000182",
    },
    {
        "school": "PLANTATION MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000183",
    },
    {
        "school": "NORCREST ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000184",
    },
    {
        "school": "TEDDER ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000185",
    },
    {
        "school": "MARGATE MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000186",
    },
    {
        "school": "CHARLES DREW ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000187",
    },
    {
        "school": "SEAGULL SCHOOL",
        "district": "BROWARD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018000188",
    },
    {
        "school": "SUNLAND PARK ACADEMY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000189",
    },
    {
        "school": "LARKDALE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000190",
    },
    {
        "school": "WESTWOOD HEIGHTS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000191",
    },
    {
        "school": "BAYVIEW ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000192",
    },
    {
        "school": "PALM COVE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000193",
    },
    {
        "school": "SAWGRASS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000194",
    },
    {
        "school": "STIRLING ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000196",
    },
    {
        "school": "PARKWAY MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000197",
    },
    {
        "school": "ORANGE BROOK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000198",
    },
    {
        "school": "DRIFTWOOD ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000199",
    },
    {
        "school": "TROPICAL ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000200",
    },
    {
        "school": "POMPANO BEACH ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000201",
    },
    {
        "school": "MEADOWBROOK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000202",
    },
    {
        "school": "BROADVIEW ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000204",
    },
    {
        "school": "LAKE FOREST ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000205",
    },
    {
        "school": "MCNAB ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000206",
    },
    {
        "school": "FLORANADA ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000207",
    },
    {
        "school": "DRIFTWOOD MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000208",
    },
    {
        "school": "BRIGHT HORIZONS",
        "district": "BROWARD",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120018000209",
    },
    {
        "school": "NEW RIVER MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000210",
    },
    {
        "school": "SANDERS PARK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000211",
    },
    {
        "school": "CRESTHAVEN ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000212",
    },
    {
        "school": "DEERFIELD BEACH MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000213",
    },
    {
        "school": "STEPHEN FOSTER ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000214",
    },
    {
        "school": "PETERS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000215",
    },
    {
        "school": "PLANTATION ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000216",
    },
    {
        "school": "FORT LAUDERDALE HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000217",
    },
    {
        "school": "BOULEVARD HEIGHTS ELEMENTARY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000218",
    },
    {
        "school": "WINGATE OAKS CENTER",
        "district": "BROWARD",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120018000219",
    },
    {
        "school": "THE QUEST CENTER",
        "district": "BROWARD",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120018000221",
    },
    {
        "school": "WILLIAM DANDY MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000222",
    },
    {
        "school": "LLOYD ESTATES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000223",
    },
    {
        "school": "PALMVIEW ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000224",
    },
    {
        "school": "CORAL SPRINGS HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000225",
    },
    {
        "school": "MARGATE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000226",
    },
    {
        "school": "SUNSHINE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000227",
    },
    {
        "school": "NORTH FORK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000228",
    },
    {
        "school": "COOPER CITY ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000229",
    },
    {
        "school": "PEMBROKE PINES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000230",
    },
    {
        "school": "NORTHEAST HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000231",
    },
    {
        "school": "PLANTATION PARK ELEMENTARY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000232",
    },
    {
        "school": "NOVA DWIGHT D. EISENHOWER ELEM",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000233",
    },
    {
        "school": "NOVA HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000234",
    },
    {
        "school": "NOVA BLANCHE FORMAN ELEMENTARY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000235",
    },
    {
        "school": "NOVA MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000236",
    },
    {
        "school": "SHERIDAN PARK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000237",
    },
    {
        "school": "LAUDERHILL PAUL TURNER ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000238",
    },
    {
        "school": "LAUDERHILL 6-12",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000239",
    },
    {
        "school": "COCONUT CREEK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000240",
    },
    {
        "school": "PLANTATION HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000241",
    },
    {
        "school": "CASTLE HILL ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000242",
    },
    {
        "school": "DR. MARTIN LUTHER KING JR. MONTESSORI ACADEMY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000243",
    },
    {
        "school": "VILLAGE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000244",
    },
    {
        "school": "ANNABEL C. PERRY PK-8",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000245",
    },
    {
        "school": "FAIRWAY ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000246",
    },
    {
        "school": "HOLLYWOOD HILLS HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000247",
    },
    {
        "school": "ROBERT C. MARKHAM ELEMENTARY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000248",
    },
    {
        "school": "COCONUT CREEK HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000249",
    },
    {
        "school": "LAUDERDALE LAKES MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000250",
    },
    {
        "school": "DEERFIELD BEACH HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000251",
    },
    {
        "school": "BOYD H. ANDERSON HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000252",
    },
    {
        "school": "MIRAMAR HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000253",
    },
    {
        "school": "HOLLYWOOD PARK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000254",
    },
    {
        "school": "CYPRESS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000255",
    },
    {
        "school": "APOLLO MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000256",
    },
    {
        "school": "SHERIDAN HILLS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000257",
    },
    {
        "school": "ORIOLE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000258",
    },
    {
        "school": "MIRROR LAKE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000259",
    },
    {
        "school": "ROYAL PALM ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000260",
    },
    {
        "school": "CRYSTAL LAKE MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000261",
    },
    {
        "school": "PINES MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000262",
    },
    {
        "school": "SEMINOLE MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000263",
    },
    {
        "school": "PIPER HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000264",
    },
    {
        "school": "COOPER CITY HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000265",
    },
    {
        "school": "PARK RIDGE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000266",
    },
    {
        "school": "JAMES S. HUNT ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000267",
    },
    {
        "school": "PASADENA LAKES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000268",
    },
    {
        "school": "ATLANTIC TECHNICAL COLLEGE",
        "district": "BROWARD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120018000270",
    },
    {
        "school": "NORTH LAUDERDALE PK-8",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000271",
    },
    {
        "school": "SOUTH PLANTATION HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000272",
    },
    {
        "school": "ATLANTIC WEST ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000273",
    },
    {
        "school": "HORIZON ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000274",
    },
    {
        "school": "FLAMINGO ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000275",
    },
    {
        "school": "CORAL SPRINGS PK-8",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000276",
    },
    {
        "school": "CORAL SPRINGS MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000277",
    },
    {
        "school": "PIONEER MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000278",
    },
    {
        "school": "BAIR MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000279",
    },
    {
        "school": "TAMARAC ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000280",
    },
    {
        "school": "FOREST HILLS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000281",
    },
    {
        "school": "PEMBROKE LAKES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000282",
    },
    {
        "school": "NOB HILL ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000283",
    },
    {
        "school": "WESTCHESTER ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000284",
    },
    {
        "school": "MORROW ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000285",
    },
    {
        "school": "RAMBLEWOOD MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000286",
    },
    {
        "school": "RAMBLEWOOD ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018000287",
    },
    {
        "school": "PINE RIDGE ALTERNATIVE CENTER",
        "district": "BROWARD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018000908",
    },
    {
        "school": "RIVERGLADES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018001355",
    },
    {
        "school": "CROSS CREEK SCHOOL",
        "district": "BROWARD",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120018001356",
    },
    {
        "school": "BANYAN ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002039",
    },
    {
        "school": "DAVIE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002041",
    },
    {
        "school": "GRIFFIN ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002043",
    },
    {
        "school": "MAPLEWOOD ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002044",
    },
    {
        "school": "PINES LAKES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002046",
    },
    {
        "school": "PINEWOOD ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002047",
    },
    {
        "school": "SHERIDAN TECHNICAL COLLEGE",
        "district": "BROWARD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120018002048",
    },
    {
        "school": "VIRGINIA SHUMAN YOUNG ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002080",
    },
    {
        "school": "EAGLE POINT ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002081",
    },
    {
        "school": "J. P. TARAVELLA HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002117",
    },
    {
        "school": "WESTERN HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002120",
    },
    {
        "school": "SILVER LAKES MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002284",
    },
    {
        "school": "LANIER-JAMES EDUCATION CENTER",
        "district": "BROWARD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018002486",
    },
    {
        "school": "MCFATTER TECHNICAL COLLEGE",
        "district": "BROWARD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120018002488",
    },
    {
        "school": "RIVERSIDE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002491",
    },
    {
        "school": "COUNTRY ISLES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002542",
    },
    {
        "school": "CORAL PARK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002543",
    },
    {
        "school": "FOREST GLEN MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002544",
    },
    {
        "school": "SILVER RIDGE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002545",
    },
    {
        "school": "CYPRESS RUN ALTERNATIVE CENTER",
        "district": "BROWARD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018002593",
    },
    {
        "school": "SANDPIPER ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002594",
    },
    {
        "school": "CENTRAL PARK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002701",
    },
    {
        "school": "WALTER C. YOUNG MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002703",
    },
    {
        "school": "WINSTON PARK ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002705",
    },
    {
        "school": "COUNTRY HILLS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002706",
    },
    {
        "school": "HAWKES BLUFF ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002707",
    },
    {
        "school": "PARK SPRINGS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002708",
    },
    {
        "school": "SEA CASTLE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002720",
    },
    {
        "school": "MARJORY STONEMAN DOUGLAS HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002721",
    },
    {
        "school": "TEQUESTA TRACE MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002722",
    },
    {
        "school": "INDIAN TRACE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002723",
    },
    {
        "school": "WHISPERING PINES EXCEPTIONAL EDUCATION CENTER",
        "district": "BROWARD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018002801",
    },
    {
        "school": "JAMES S. RICKARDS MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002802",
    },
    {
        "school": "QUIET WATERS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002803",
    },
    {
        "school": "CHAPEL TRAIL ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002979",
    },
    {
        "school": "THURGOOD MARSHALL ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002980",
    },
    {
        "school": "SILVER TRAIL MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002981",
    },
    {
        "school": "EAGLE RIDGE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002982",
    },
    {
        "school": "INDIAN RIDGE MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002983",
    },
    {
        "school": "SILVER PALMS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018002984",
    },
    {
        "school": "WHIDDON RODGERS EDUCATION CENTER",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018003027",
    },
    {
        "school": "CHARLES W FLANAGAN HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003029",
    },
    {
        "school": "SAWGRASS SPRINGS MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003030",
    },
    {
        "school": "TRADEWINDS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003031",
    },
    {
        "school": "PANTHER RUN ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003154",
    },
    {
        "school": "SOMERSET NEIGHBORHOOD SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003155",
    },
    {
        "school": "CHARTER SCHOOL OF EXCELLENCE",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003156",
    },
    {
        "school": "CENTRAL CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003157",
    },
    {
        "school": "POMPANO BEACH HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003301",
    },
    {
        "school": "EVERGLADES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003302",
    },
    {
        "school": "SILVER LAKES ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003303",
    },
    {
        "school": "FOX TRAIL ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003304",
    },
    {
        "school": "LAKESIDE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003305",
    },
    {
        "school": "GATOR RUN ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003306",
    },
    {
        "school": "PEMBROKE PINES CHARTER ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003307",
    },
    {
        "school": "ARC BROWARD INC.",
        "district": "BROWARD",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120018003310",
    },
    {
        "school": "ANN STORCK CENTER INC.",
        "district": "BROWARD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003311",
    },
    {
        "school": "BAUDHUIN ORAL SCHOOL-NOVA UNIVERSITY",
        "district": "BROWARD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003312",
    },
    {
        "school": "BROWARD CHILDREN'S CENTER NORTH",
        "district": "BROWARD",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003313",
    },
    {
        "school": "BROWARD CHILDREN'S CENTER SOUTH",
        "district": "BROWARD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003314",
    },
    {
        "school": "UCP EARLY BEGINNINGS",
        "district": "BROWARD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003316",
    },
    {
        "school": "ALPHABET LAND-MARGATE",
        "district": "BROWARD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003318",
    },
    {
        "school": "BROWARD DETENTION CENTER",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018003320",
    },
    {
        "school": "AMIKIDS OF GREATER FORT LAUDERDALE",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018003324",
    },
    {
        "school": "DAVE THOMAS EDUCATION CENTER WEST",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018003543",
    },
    {
        "school": "CITY/PEMBROKE PINES CHARTER MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003544",
    },
    {
        "school": "CORAL SPRINGS CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003545",
    },
    {
        "school": "PACE CENTER FOR GIRLS INC.",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018003547",
    },
    {
        "school": "COCONUT PALM ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003681",
    },
    {
        "school": "CHALLENGER ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003682",
    },
    {
        "school": "PARK TRAILS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003683",
    },
    {
        "school": "COLLEGE ACADEMY AT BROWARD COLLEGE",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003684",
    },
    {
        "school": "IMAGINE CHARTER SCHOOL AT WESTON",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003685",
    },
    {
        "school": "SOMERSET ACADEMY MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003686",
    },
    {
        "school": "NORTH BROWARD ACADEMY OF EXCELLENCE",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003687",
    },
    {
        "school": "IMAGINE CHARTER SCHOOL AT NORTH LAUDERDALE ELEMENTARY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018003688",
    },
    {
        "school": "LYONS CREEK MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004314",
    },
    {
        "school": "FALCON COVE MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004316",
    },
    {
        "school": "PARKSIDE ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004317",
    },
    {
        "school": "CITY/PEMBROKE PINES CHARTER HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004318",
    },
    {
        "school": "SOMERSET ACADEMY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018004320",
    },
    {
        "school": "AIR BASE K-8 CENTER FOR INTERNATIONAL EDUCATION",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000367",
    },
    {
        "school": "LENORA BRAYNON SMITH ELEMENTARY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000368",
    },
    {
        "school": "ARCOLA LAKE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000369",
    },
    {
        "school": "AUBURNDALE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000370",
    },
    {
        "school": "AVOCADO ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000371",
    },
    {
        "school": "BANYAN ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000372",
    },
    {
        "school": "RUTH K. BROAD BAY HARBOR K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000373",
    },
    {
        "school": "BEL-AIRE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000374",
    },
    {
        "school": "BISCAYNE BEACH ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000376",
    },
    {
        "school": "BISCAYNE GARDENS ELEMENTARY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000377",
    },
    {
        "school": "VAN E. BLANTON ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000378",
    },
    {
        "school": "BLUE LAKES ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000379",
    },
    {
        "school": "BRENTWOOD ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000380",
    },
    {
        "school": "JAMES H. BRIGHT ELEMENTARY/J.W. JOHNSON ELEMENTARY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000381",
    },
    {
        "school": "BROADMOOR ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000382",
    },
    {
        "school": "W. J. BRYAN ELEMENTARY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000383",
    },
    {
        "school": "BUNCHE PARK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000385",
    },
    {
        "school": "CAMPBELL DRIVE K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000386",
    },
    {
        "school": "CARIBBEAN K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000387",
    },
    {
        "school": "CAROL CITY ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000388",
    },
    {
        "school": "GEORGE W. CARVER ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000389",
    },
    {
        "school": "MIAMI BEACH FEINBERG/FISHER K-8",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000390",
    },
    {
        "school": "DR. WILLIAM A. CHAPMAN ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000391",
    },
    {
        "school": "CITRUS GROVE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000392",
    },
    {
        "school": "COCONUT GROVE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000393",
    },
    {
        "school": "COLONIAL DRIVE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000394",
    },
    {
        "school": "COMSTOCK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000395",
    },
    {
        "school": "CORAL GABLES PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000397",
    },
    {
        "school": "CORAL PARK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000398",
    },
    {
        "school": "CORAL REEF ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000399",
    },
    {
        "school": "CORAL TERRACE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000400",
    },
    {
        "school": "CORAL WAY K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000401",
    },
    {
        "school": "CRESTVIEW ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000402",
    },
    {
        "school": "CUTLER RIDGE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000403",
    },
    {
        "school": "CYPRESS K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000404",
    },
    {
        "school": "FREDERICK R. DOUGLASS ELEMENTARY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000405",
    },
    {
        "school": "CHARLES R DREW K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000406",
    },
    {
        "school": "PAUL LAURENCE DUNBAR K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000407",
    },
    {
        "school": "JOHN G. DUPUIS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000408",
    },
    {
        "school": "AMELIA EARHART ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000409",
    },
    {
        "school": "EARLINGTON HEIGHTS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000410",
    },
    {
        "school": "EDISON PARK K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000411",
    },
    {
        "school": "EMERSON ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000412",
    },
    {
        "school": "LILLIE C. EVANS K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000413",
    },
    {
        "school": "EVERGLADES K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000414",
    },
    {
        "school": "DAVID FAIRCHILD ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000415",
    },
    {
        "school": "FAIRLAWN ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000416",
    },
    {
        "school": "FLAGAMI ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000417",
    },
    {
        "school": "HENRY M. FLAGLER ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000418",
    },
    {
        "school": "FLAMINGO ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000419",
    },
    {
        "school": "FLORIDA CITY ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000421",
    },
    {
        "school": "GLORIA FLOYD ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000422",
    },
    {
        "school": "BENJAMIN FRANKLIN K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000423",
    },
    {
        "school": "FULFORD ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000424",
    },
    {
        "school": "GOLDEN GLADES ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000426",
    },
    {
        "school": "GRATIGNY ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000428",
    },
    {
        "school": "GREENGLADE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000429",
    },
    {
        "school": "GREYNOLDS PARK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000430",
    },
    {
        "school": "GULFSTREAM ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000431",
    },
    {
        "school": "HIALEAH ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000432",
    },
    {
        "school": "HIBISCUS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000433",
    },
    {
        "school": "VIRGINIA A BOONE-HIGHLAND OAKS SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000434",
    },
    {
        "school": "HOLMES ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000435",
    },
    {
        "school": "THENA CROWDER EARLY CHILDHOOD DIAGNOSTIC SPECIAL EDUCATION C",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120039000436",
    },
    {
        "school": "HOWARD DRIVE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000437",
    },
    {
        "school": "MADIE IVES K-8 PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000438",
    },
    {
        "school": "KENDALE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000440",
    },
    {
        "school": "KENDALE LAKES ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000441",
    },
    {
        "school": "KENSINGTON PARK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000442",
    },
    {
        "school": "KENWOOD K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000443",
    },
    {
        "school": "KEY BISCAYNE K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000444",
    },
    {
        "school": "KINLOCH PARK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000446",
    },
    {
        "school": "LAKE STEVENS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000447",
    },
    {
        "school": "LAKEVIEW ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000448",
    },
    {
        "school": "LEEWOOD K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000450",
    },
    {
        "school": "LEISURE CITY K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000451",
    },
    {
        "school": "LAURA C. SAUNDERS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000452",
    },
    {
        "school": "LIBERTY CITY ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000453",
    },
    {
        "school": "JESSE J. MCCRARY JR. ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000454",
    },
    {
        "school": "LORAH PARK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000455",
    },
    {
        "school": "LUDLAM ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000456",
    },
    {
        "school": "FRANK CRAWFORD MARTIN K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000457",
    },
    {
        "school": "MEADOWLANE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000458",
    },
    {
        "school": "MELROSE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000459",
    },
    {
        "school": "MIAMI GARDENS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000461",
    },
    {
        "school": "MIAMI HEIGHTS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000462",
    },
    {
        "school": "MIAMI LAKES K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000463",
    },
    {
        "school": "MIAMI SHORES ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000465",
    },
    {
        "school": "MIAMI SPRINGS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000466",
    },
    {
        "school": "MARCUS A. MILAM K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000467",
    },
    {
        "school": "MORNINGSIDE K-8 ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000468",
    },
    {
        "school": "ROBERT RUSSA MOTON ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000469",
    },
    {
        "school": "MYRTLE GROVE K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000470",
    },
    {
        "school": "COCONUT PALM K-8 ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000471",
    },
    {
        "school": "NATURAL BRIDGE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000472",
    },
    {
        "school": "NORLAND ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000473",
    },
    {
        "school": "NORTH BEACH ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000474",
    },
    {
        "school": "BARBARA HAWKINS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000475",
    },
    {
        "school": "NORTH COUNTY K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000476",
    },
    {
        "school": "NORTH GLADE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000477",
    },
    {
        "school": "NORTH HIALEAH ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000478",
    },
    {
        "school": "NORTH MIAMI ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000479",
    },
    {
        "school": "NORTH TWIN LAKES ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000480",
    },
    {
        "school": "NORWOOD ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000481",
    },
    {
        "school": "OAK GROVE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000482",
    },
    {
        "school": "OJUS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000483",
    },
    {
        "school": "AGENORIA S PASCHAL/OLINDA ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000484",
    },
    {
        "school": "OLYMPIA HEIGHTS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000485",
    },
    {
        "school": "DR. ROBERT B. INGRAM ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000486",
    },
    {
        "school": "ORCHARD VILLA ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000487",
    },
    {
        "school": "PALMETTO ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000488",
    },
    {
        "school": "PALM LAKES ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000489",
    },
    {
        "school": "PALM SPRINGS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000490",
    },
    {
        "school": "PALM SPRINGS NORTH ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000491",
    },
    {
        "school": "PARKVIEW ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000492",
    },
    {
        "school": "PARKWAY ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000493",
    },
    {
        "school": "DR. HENRY E. PERRINE ACADEMY OF THE ARTS",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000494",
    },
    {
        "school": "KELSEY L. PHARR ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000495",
    },
    {
        "school": "PINECREST ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000496",
    },
    {
        "school": "PINE LAKE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000497",
    },
    {
        "school": "PINE VILLA ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000498",
    },
    {
        "school": "POINCIANA PARK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000499",
    },
    {
        "school": "RAINBOW PARK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000500",
    },
    {
        "school": "REDLAND ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000501",
    },
    {
        "school": "REDONDO ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000502",
    },
    {
        "school": "ETHEL F. BECKFORD/RICHMOND PRIMARY LEARNING CENTER",
        "district": "MIAMI-DADE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000503",
    },
    {
        "school": "RIVERSIDE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000504",
    },
    {
        "school": "ROCKWAY ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000505",
    },
    {
        "school": "ROYAL GREEN ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000506",
    },
    {
        "school": "ROYAL PALM ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000507",
    },
    {
        "school": "GERTRUDE K. EDELMAN/SABAL PALM",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000508",
    },
    {
        "school": "SANTA CLARA ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000509",
    },
    {
        "school": "SCOTT LAKE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000510",
    },
    {
        "school": "SEMINOLE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000511",
    },
    {
        "school": "SHADOWLAWN ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000512",
    },
    {
        "school": "SHENANDOAH ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000513",
    },
    {
        "school": "SILVER BLUFF ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000514",
    },
    {
        "school": "DR. FREDERICA S. WILSON/SKYWAY ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000515",
    },
    {
        "school": "SNAPPER CREEK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000516",
    },
    {
        "school": "SOUTH HIALEAH ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000517",
    },
    {
        "school": "SOUTH MIAMI K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000518",
    },
    {
        "school": "SOUTH MIAMI HEIGHTS ELEMENTARY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000519",
    },
    {
        "school": "SOUTHSIDE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000520",
    },
    {
        "school": "SPRINGVIEW ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000521",
    },
    {
        "school": "E.W.F. STIRRUP ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000522",
    },
    {
        "school": "SUNSET ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000523",
    },
    {
        "school": "SUNSET PARK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000524",
    },
    {
        "school": "SYLVANIA HEIGHTS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000525",
    },
    {
        "school": "TREASURE ISLAND ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000526",
    },
    {
        "school": "TROPICAL ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000527",
    },
    {
        "school": "FRANCES S. TUCKER ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000528",
    },
    {
        "school": "TWIN LAKES ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000529",
    },
    {
        "school": "VILLAGE GREEN ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000530",
    },
    {
        "school": "VINELAND K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000531",
    },
    {
        "school": "MAE M. WALTERS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000532",
    },
    {
        "school": "WEST HOMESTEAD K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000533",
    },
    {
        "school": "HENRY S. WEST LABORATORY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000534",
    },
    {
        "school": "DR. HENRY W. MACK/WEST LITTLE RIVER K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000535",
    },
    {
        "school": "CARRIE P. MEEK/WESTVIEW K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000536",
    },
    {
        "school": "PHYLLIS WHEATLEY ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000537",
    },
    {
        "school": "WHISPERING PINES ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000538",
    },
    {
        "school": "WINSTON PARK K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000539",
    },
    {
        "school": "NATHAN B. YOUNG ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000540",
    },
    {
        "school": "GEORGIA JONES AYERS MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000541",
    },
    {
        "school": "ARVIDA MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000542",
    },
    {
        "school": "BROWNSVILLE MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000543",
    },
    {
        "school": "CAROL CITY MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000544",
    },
    {
        "school": "GEORGE WASHINGTON CARVER MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000546",
    },
    {
        "school": "CUTLER BAY SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000547",
    },
    {
        "school": "CITRUS GROVE MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000548",
    },
    {
        "school": "CUTLER BAY MIDDLE",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000549",
    },
    {
        "school": "HENRY H. FILER MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000551",
    },
    {
        "school": "GLADES MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000553",
    },
    {
        "school": "HIALEAH MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000554",
    },
    {
        "school": "HIGHLAND OAKS MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000555",
    },
    {
        "school": "HOMESTEAD MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000556",
    },
    {
        "school": "THOMAS JEFFERSON MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000557",
    },
    {
        "school": "JOHN F. KENNEDY MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000558",
    },
    {
        "school": "KINLOCH PARK MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000559",
    },
    {
        "school": "LAKE STEVENS MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000560",
    },
    {
        "school": "MADISON MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000562",
    },
    {
        "school": "HORACE MANN MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000563",
    },
    {
        "school": "HOWARD D. MCMILLAN MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000565",
    },
    {
        "school": "MIAMI LAKES MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000568",
    },
    {
        "school": "MIAMI SPRINGS MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000569",
    },
    {
        "school": "MIAMI BEACH NAUTILUS MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000570",
    },
    {
        "school": "NORLAND MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000571",
    },
    {
        "school": "NORTH DADE MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000572",
    },
    {
        "school": "NORTH MIAMI MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000573",
    },
    {
        "school": "PALM SPRINGS MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000574",
    },
    {
        "school": "PALMETTO MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000575",
    },
    {
        "school": "PONCE DE LEON MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000577",
    },
    {
        "school": "REDLAND MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000578",
    },
    {
        "school": "RICHMOND HEIGHTS MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000579",
    },
    {
        "school": "RIVIERA MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000580",
    },
    {
        "school": "ROCKWAY MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000581",
    },
    {
        "school": "SHENANDOAH MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000582",
    },
    {
        "school": "SOUTHWOOD MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000583",
    },
    {
        "school": "SOUTH MIAMI MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000584",
    },
    {
        "school": "W. R. THOMAS MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000585",
    },
    {
        "school": "WEST MIAMI MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000587",
    },
    {
        "school": "AMERICAN SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000589",
    },
    {
        "school": "CORAL GABLES SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000590",
    },
    {
        "school": "HIALEAH SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000591",
    },
    {
        "school": "HIALEAH-MIAMI LAKES SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000592",
    },
    {
        "school": "HOMESTEAD SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000593",
    },
    {
        "school": "MIAMI BEACH SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000594",
    },
    {
        "school": "MIAMI CAROL CITY SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000595",
    },
    {
        "school": "MIAMI CENTRAL SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000596",
    },
    {
        "school": "MIAMI CORAL PARK SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000599",
    },
    {
        "school": "MIAMI EDISON SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000600",
    },
    {
        "school": "MIAMI JACKSON SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000601",
    },
    {
        "school": "MIAMI KILLIAN SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000602",
    },
    {
        "school": "MIAMI NORLAND SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000603",
    },
    {
        "school": "MIAMI NORTHWESTERN SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000604",
    },
    {
        "school": "MIAMI PALMETTO SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000605",
    },
    {
        "school": "MIAMI SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000606",
    },
    {
        "school": "MIAMI SPRINGS SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000607",
    },
    {
        "school": "MIAMI SUNSET SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000608",
    },
    {
        "school": "NORTH MIAMI BEACH SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000609",
    },
    {
        "school": "NORTH MIAMI SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000610",
    },
    {
        "school": "MIAMI MACARTHUR EDUCATIONAL CENTER",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039000611",
    },
    {
        "school": "SOUTH DADE SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000612",
    },
    {
        "school": "SOUTH MIAMI SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000613",
    },
    {
        "school": "MIAMI SOUTHRIDGE SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000614",
    },
    {
        "school": "SOUTHWEST MIAMI SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039000615",
    },
    {
        "school": "JANN MANN EDUCATIONAL CENTER",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039000616",
    },
    {
        "school": "COPE CENTER NORTH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039000617",
    },
    {
        "school": "PHYLLIS R. MILLER ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039001388",
    },
    {
        "school": "IRVING & BEATRICE PESKOE K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039001441",
    },
    {
        "school": "SCHOOL FOR ADVANCED STUDIES - SOUTH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039001443",
    },
    {
        "school": "WILLIAM H. TURNER TECHNICAL ARTS HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039001478",
    },
    {
        "school": "DEVON AIRE K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002054",
    },
    {
        "school": "HIALEAH GARDENS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002114",
    },
    {
        "school": "JACK DAVID GORDON ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002115",
    },
    {
        "school": "TITLE I MIGRANT EDUCATION PROGRAM",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002127",
    },
    {
        "school": "ALTERNATIVE OUTREACH PROGRAM",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039002132",
    },
    {
        "school": "BRUCIE BALL EDUCATIONAL CENTER",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120039002135",
    },
    {
        "school": "INSTRUCTIONAL CENTER SYSTEM WIDE",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002137",
    },
    {
        "school": "LINDSEY HOPKINS TECHNICAL COLLEGE",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120039002138",
    },
    {
        "school": "OLIVER HOOVER ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002147",
    },
    {
        "school": "ROBERT MORGAN EDUCATIONAL CENTER AND TECHNICAL COLLEGE",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120039002148",
    },
    {
        "school": "BENT TREE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002291",
    },
    {
        "school": "CALUSA ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002292",
    },
    {
        "school": "NEVA KING COOPER EDUCATIONAL CENTER",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120039002428",
    },
    {
        "school": "HAMMOCKS MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002429",
    },
    {
        "school": "SWEETWATER ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002468",
    },
    {
        "school": "CHARLES R HADLEY ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002498",
    },
    {
        "school": "JOE HALL ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002499",
    },
    {
        "school": "BEN SHEPPARD ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002500",
    },
    {
        "school": "JUVENILE JUSTICE CENTER ALT ED",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039002555",
    },
    {
        "school": "JOELLA GOOD ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002699",
    },
    {
        "school": "TOUSSAINT L'OUVERTURE ELEMENTARY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002704",
    },
    {
        "school": "JANE S. ROBERTS K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002711",
    },
    {
        "school": "N DADE CENTER FOR MODERN LANGUAGE",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002713",
    },
    {
        "school": "RUBEN DARIO MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002714",
    },
    {
        "school": "SCHOOL FOR ADVANCED STUDIES NORTH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002715",
    },
    {
        "school": "MARJORY STONEMAN DOUGLAS ELEM",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002733",
    },
    {
        "school": "DR. GILBERT L. PORTER ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002734",
    },
    {
        "school": "G. HOLMES BRADDOCK SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002735",
    },
    {
        "school": "DESIGN & ARCHITECTURE SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002736",
    },
    {
        "school": "BOWMAN ASHE/DOOLIN K-8 ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002805",
    },
    {
        "school": "CLAUDE PEPPER ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002806",
    },
    {
        "school": "ERNEST R. GRAHAM K-8 ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002807",
    },
    {
        "school": "MIAMI BEACH SOUTH POINTE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002808",
    },
    {
        "school": "MAST ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002809",
    },
    {
        "school": "NEW WORLD SCHOOL OF THE ARTS",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002810",
    },
    {
        "school": "TEENAGE PARENT PROGRAM",
        "district": "MIAMI-DADE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002811",
    },
    {
        "school": "DR. MARVIN DUNN ACADEMY FOR COMMUNITY EDUCATION.",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039002812",
    },
    {
        "school": "ROBERT RENICK EDUCATION CENTER",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120039002813",
    },
    {
        "school": "RUTH OWENS KRUSE EDUCATION CENTER",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120039002814",
    },
    {
        "school": "MAYA ANGELOU ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002986",
    },
    {
        "school": "WILLIAM H. LEHMAN ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002987",
    },
    {
        "school": "BARBARA GOLEMAN SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039002988",
    },
    {
        "school": "ETHEL KOGER BECKHAM K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003043",
    },
    {
        "school": "DANTE B. FASCELL ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003044",
    },
    {
        "school": "ZORA NEALE HURSTON ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003045",
    },
    {
        "school": "WESLEY MATTHEWS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003046",
    },
    {
        "school": "HENRY E.S. REEVES K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003047",
    },
    {
        "school": "JOHN I. SMITH K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003048",
    },
    {
        "school": "DR. EDWARD L. WHIGHAM ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003049",
    },
    {
        "school": "CHARLES DAVID WYCHE JR ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003050",
    },
    {
        "school": "PAUL W. BELL MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003051",
    },
    {
        "school": "CORAL REEF SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003052",
    },
    {
        "school": "ENEIDA M. HARTNER ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003162",
    },
    {
        "school": "HERBERT A. AMMONS MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003163",
    },
    {
        "school": "DOCTORS CHARTER SCHOOL OF MIAMI SHORES",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003164",
    },
    {
        "school": "CORAL REEF MONTESSORI ACADEMY CHARTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003340",
    },
    {
        "school": "MATER ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003341",
    },
    {
        "school": "LINDA LENTIN K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003343",
    },
    {
        "school": "DR. MICHAEL M. KROP SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003345",
    },
    {
        "school": "RENAISSANCE ELEMENTARY CHARTER SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003554",
    },
    {
        "school": "CHRISTINA M. EVE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003555",
    },
    {
        "school": "DORAL ACADEMY CHARTER MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003558",
    },
    {
        "school": "JOSE DE DIEGO MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003559",
    },
    {
        "school": "SCHOOL FOR ADVANCED STUDIES-WOLFSON",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003561",
    },
    {
        "school": "BOOKER T. WASHINGTON SENIOR HIGH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003562",
    },
    {
        "school": "AMIKIDS MIAMI-DADE SOUTH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039003563",
    },
    {
        "school": "AMIKIDS MIAMI-DADE NORTH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039003564",
    },
    {
        "school": "DADE JUVENILE RESIDENTIAL FACILITY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039003565",
    },
    {
        "school": "MIAMI YOUTH ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039003569",
    },
    {
        "school": "EUGENIA B. THOMAS K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003693",
    },
    {
        "school": "PINECREST PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003696",
    },
    {
        "school": "HUBERT O. SIBLEY K-8 ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003697",
    },
    {
        "school": "DORAL ACADEMY CHARTER HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039003699",
    },
    {
        "school": "DR. CARLOS J. FINLAY ELEMENTARY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004335",
    },
    {
        "school": "LAWTON CHILES MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004338",
    },
    {
        "school": "MIAMI LAKES EDUCATIONAL CENTER",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004339",
    },
    {
        "school": "FELIX VARELA SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039004340",
    },
    {
        "school": "OSCEOLA ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033003829",
    },
    {
        "school": "CALUSA PARK ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033003830",
    },
    {
        "school": "THE PHOENIX PROGRAM-IMMOKALEE",
        "district": "COLLIER",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120033003957",
    },
    {
        "school": "BEACON HIGH SCHOOL",
        "district": "COLLIER",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120033003958",
    },
    {
        "school": "GOLDEN GATE HIGH SCHOOL",
        "district": "COLLIER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033003959",
    },
    {
        "school": "PALMETTO RIDGE HIGH SCHOOL",
        "district": "COLLIER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033003960",
    },
    {
        "school": "NORTH NAPLES MIDDLE SCHOOL",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033003961",
    },
    {
        "school": "ESTATES ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033003962",
    },
    {
        "school": "SABAL PALM ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033004063",
    },
    {
        "school": "CYPRESS PALM MIDDLE SCHOOL",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033004489",
    },
    {
        "school": "VETERANS MEMORIAL ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033004490",
    },
    {
        "school": "PARKSIDE ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033004495",
    },
    {
        "school": "IMMOKALEE MIDDLE SCHOOL",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000269",
    },
    {
        "school": "EVERGLADES CITY SCHOOL",
        "district": "COLLIER",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000336",
    },
    {
        "school": "GULFVIEW MIDDLE SCHOOL",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000337",
    },
    {
        "school": "LAKE PARK ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000340",
    },
    {
        "school": "TOMMIE BARFIELD ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000341",
    },
    {
        "school": "SHADOWLAWN ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000342",
    },
    {
        "school": "NAPLES HIGH SCHOOL",
        "district": "COLLIER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000343",
    },
    {
        "school": "PINECREST ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000344",
    },
    {
        "school": "SEA GATE ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000345",
    },
    {
        "school": "HIGHLANDS ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000346",
    },
    {
        "school": "LAKE TRAFFORD ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000347",
    },
    {
        "school": "AVALON ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000348",
    },
    {
        "school": "EAST NAPLES MIDDLE SCHOOL",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000349",
    },
    {
        "school": "POINCIANA ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000350",
    },
    {
        "school": "GOLDEN GATE ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000351",
    },
    {
        "school": "NAPLES PARK ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000352",
    },
    {
        "school": "PINE RIDGE MIDDLE SCHOOL",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000353",
    },
    {
        "school": "LELY HIGH SCHOOL",
        "district": "COLLIER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000354",
    },
    {
        "school": "IMMOKALEE HIGH SCHOOL",
        "district": "COLLIER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000355",
    },
    {
        "school": "BARRON COLLIER HIGH SCHOOL",
        "district": "COLLIER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033000357",
    },
    {
        "school": "LAUREL OAK ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033001382",
    },
    {
        "school": "OAKRIDGE MIDDLE SCHOOL",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033001383",
    },
    {
        "school": "MANATEE ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033002095",
    },
    {
        "school": "NEW BEGINNINGS IMMOKALEE",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120033002099",
    },
    {
        "school": "NEW BEGINNINGS - NAPLES",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120033002101",
    },
    {
        "school": "GOLDEN GATE MIDDLE SCHOOL",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033002125",
    },
    {
        "school": "BIG CYPRESS ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033002496",
    },
    {
        "school": "VILLAGE OAKS ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033002551",
    },
    {
        "school": "GOLDEN TERRACE ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033002677",
    },
    {
        "school": "VINEYARDS ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033002730",
    },
    {
        "school": "LELY ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033002731",
    },
    {
        "school": "IMMOKALEE TEEN PARENTING PROG",
        "district": "COLLIER",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120033002804",
    },
    {
        "school": "MANATEE MIDDLE SCHOOL",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033002985",
    },
    {
        "school": "PELICAN MARSH ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033003038",
    },
    {
        "school": "NAPLES AREA TEENAGE PARENTING",
        "district": "COLLIER",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120033003039",
    },
    {
        "school": "THE PHOENIX PROGRAM NAPLES",
        "district": "COLLIER",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120033003160",
    },
    {
        "school": "GULF COAST HIGH SCHOOL",
        "district": "COLLIER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033003336",
    },
    {
        "school": "THE PACE PROGRAM",
        "district": "COLLIER",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120033003338",
    },
    {
        "school": "MARCO ISLAND CHARTER MIDDLE",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033003339",
    },
    {
        "school": "CORKSCREW ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033003551",
    },
    {
        "school": "HOSPITAL/HOMEBOUND",
        "district": "COLLIER",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120033003552",
    },
    {
        "school": "COLLIER JUVENILE DETENTION CENTER",
        "district": "COLLIER",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120033003692",
    },
    {
        "school": "CORKSCREW MIDDLE SCHOOL",
        "district": "COLLIER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033004329",
    },
    {
        "school": "IMMOKALEE COMMUNITY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033004330",
    },
    {
        "school": "MCINTOSH AREA SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126004112",
    },
    {
        "school": "MARION TECHNICAL INSTITUTE",
        "district": "MARION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120126005612",
    },
    {
        "school": "MAPLEWOOD ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126000830",
    },
    {
        "school": "ROMEO ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126000833",
    },
    {
        "school": "HOWARD MIDDLE SCHOOL",
        "district": "MARION",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001251",
    },
    {
        "school": "ANTHONY ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001252",
    },
    {
        "school": "BELLEVIEW ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001253",
    },
    {
        "school": "BELLEVIEW-SANTOS ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001254",
    },
    {
        "school": "EAST MARION ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001259",
    },
    {
        "school": "EIGHTH STREET ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001260",
    },
    {
        "school": "FESSENDEN ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001261",
    },
    {
        "school": "FORT KING MIDDLE SCHOOL",
        "district": "MARION",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001262",
    },
    {
        "school": "WARD-HIGHLANDS ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001264",
    },
    {
        "school": "LAKE WEIR MIDDLE SCHOOL",
        "district": "MARION",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001266",
    },
    {
        "school": "MADISON STREET ACADEMY OF VISUAL AND PERFORMING ARTS",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001267",
    },
    {
        "school": "DR N H JONES ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001268",
    },
    {
        "school": "NORTH MARION HIGH SCHOOL",
        "district": "MARION",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001269",
    },
    {
        "school": "OAKCREST ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001270",
    },
    {
        "school": "FOREST HIGH SCHOOL",
        "district": "MARION",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001271",
    },
    {
        "school": "OSCEOLA MIDDLE SCHOOL",
        "district": "MARION",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001272",
    },
    {
        "school": "SPARR ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001273",
    },
    {
        "school": "SOUTH OCALA ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001274",
    },
    {
        "school": "STANTON-WEIRSDALE ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001275",
    },
    {
        "school": "WYOMINA PARK ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001276",
    },
    {
        "school": "VANGUARD HIGH SCHOOL",
        "district": "MARION",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001277",
    },
    {
        "school": "HILLCREST",
        "district": "MARION",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120126001278",
    },
    {
        "school": "NORTH MARION MIDDLE SCHOOL",
        "district": "MARION",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001279",
    },
    {
        "school": "LAKE WEIR HIGH SCHOOL",
        "district": "MARION",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001280",
    },
    {
        "school": "REDDICK-COLLIER ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001865",
    },
    {
        "school": "BELLEVIEW MIDDLE SCHOOL",
        "district": "MARION",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001876",
    },
    {
        "school": "DUNNELLON ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126001878",
    },
    {
        "school": "SILVER RIVER MENTORING AND INSTRUCTION",
        "district": "MARION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120126001902",
    },
    {
        "school": "DUNNELLON HIGH SCHOOL",
        "district": "MARION",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126002442",
    },
    {
        "school": "OCALA SPRINGS ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126002517",
    },
    {
        "school": "SHADY HILL ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126002518",
    },
    {
        "school": "FORT MCCOY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126002618",
    },
    {
        "school": "EMERALD SHORES ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126002681",
    },
    {
        "school": "COLLEGE PARK ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126002760",
    },
    {
        "school": "SUNRISE ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126002765",
    },
    {
        "school": "EVERGREEN ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126002766",
    },
    {
        "school": "HARBOUR VIEW ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126002767",
    },
    {
        "school": "BELLEVIEW HIGH SCHOOL",
        "district": "MARION",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126002914",
    },
    {
        "school": "DUNNELLON MIDDLE SCHOOL",
        "district": "MARION",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126003005",
    },
    {
        "school": "MARION REG. JUVENILE DETENTION CENTER",
        "district": "MARION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120126003006",
    },
    {
        "school": "MARION YOUTH ACADEMY",
        "district": "MARION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120126003083",
    },
    {
        "school": "MCSO JUVENILES",
        "district": "MARION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120126003084",
    },
    {
        "school": "ARC BIRTH-3",
        "district": "MARION",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120126003085",
    },
    {
        "school": "GREENWAY ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126003202",
    },
    {
        "school": "OCALA CENTER FOR SUCCESS AND INDEPENDENCE",
        "district": "MARION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120126003203",
    },
    {
        "school": "NEW LEAF CENTER",
        "district": "MARION",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120126003434",
    },
    {
        "school": "ELC PK ESE SERVICES",
        "district": "MARION",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120126003436",
    },
    {
        "school": "SADDLEWOOD ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126003613",
    },
    {
        "school": "PACE CENTER FOR GIRLS INC.",
        "district": "MARION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120126003733",
    },
    {
        "school": "LIBERTY MIDDLE SCHOOL",
        "district": "MARION",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126004385",
    },
    {
        "school": "WEST PORT HIGH SCHOOL",
        "district": "MARION",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126004386",
    },
    {
        "school": "MARION CHARTER SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126004387",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "OKEECHOBEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120141001357",
    },
    {
        "school": "OKEECHOBEE HIGH SCHOOL",
        "district": "OKEECHOBEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120141001358",
    },
    {
        "school": "SOUTH ELEMENTARY SCHOOL",
        "district": "OKEECHOBEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120141001359",
    },
    {
        "school": "YEARLING MIDDLE SCHOOL",
        "district": "OKEECHOBEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120141001360",
    },
    {
        "school": "NORTH ELEMENTARY SCHOOL",
        "district": "OKEECHOBEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120141002217",
    },
    {
        "school": "EVERGLADES ELEMENTARY SCHOOL",
        "district": "OKEECHOBEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120141002571",
    },
    {
        "school": "SEMINOLE ELEMENTARY SCHOOL",
        "district": "OKEECHOBEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120141002775",
    },
    {
        "school": "OSCEOLA MIDDLE SCHOOL",
        "district": "OKEECHOBEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120141003089",
    },
    {
        "school": "STUDENT SERV./SPECIAL PROGRAMS",
        "district": "OKEECHOBEE",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120141003090",
    },
    {
        "school": "TANTIE JUVENILE RESIDENTIAL FACILITY",
        "district": "OKEECHOBEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120141003213",
    },
    {
        "school": "OKEECHOBEE ACHIEVEMENT ACADEMY",
        "district": "OKEECHOBEE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120141003624",
    },
    {
        "school": "CYPRESS JUVENILE RESIDENTIAL FACILITY",
        "district": "OKEECHOBEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120141003737",
    },
    {
        "school": "WESTBROOKE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005019",
    },
    {
        "school": "SUNSET PARK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005034",
    },
    {
        "school": "CLERMONT MIDDLE SCHOOL",
        "district": "LAKE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105003867",
    },
    {
        "school": "EAST RIDGE HIGH SCHOOL",
        "district": "LAKE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105003868",
    },
    {
        "school": "LEESBURG ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105003980",
    },
    {
        "school": "ALTOONA SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105003984",
    },
    {
        "school": "PINE RIDGE ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105004105",
    },
    {
        "school": "IMAGINE SCHOOLS AT SOUTH LAKE",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105005598",
    },
    {
        "school": "FLORIDA VIRTUAL SCHOOL FLEX 6-8",
        "district": "FL VIRTUAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120000204145",
    },
    {
        "school": "FLORIDA VIRTUAL SCHOOL FLEX 9-12",
        "district": "FL VIRTUAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120000204146",
    },
    {
        "school": "SHEELER HIGH CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144003884",
    },
    {
        "school": "CHANCERY HIGH CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144003885",
    },
    {
        "school": "THORNEBROOKE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003887",
    },
    {
        "school": "PROJECT COMPASS",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144003994",
    },
    {
        "school": "BETA",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144003995",
    },
    {
        "school": "VILLAGE",
        "district": "ORANGE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144004000",
    },
    {
        "school": "EAGLES NEST ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144004003",
    },
    {
        "school": "WEST OAKS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144004004",
    },
    {
        "school": "JUVENILE OFFENDERS PROGRAM",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144004006",
    },
    {
        "school": "WEST CREEK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144004008",
    },
    {
        "school": "WORKFORCE ADVANTAGE ACADEMY CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144004011",
    },
    {
        "school": "UCP PINE HILLS CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144004114",
    },
    {
        "school": "OAKLAND AVENUE CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144004115",
    },
    {
        "school": "FREEDOM HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144004117",
    },
    {
        "school": "WEKIVA HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005017",
    },
    {
        "school": "MILLENNIA ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005018",
    },
    {
        "school": "MOSS PARK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005021",
    },
    {
        "school": "BRIDGEWATER MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005031",
    },
    {
        "school": "LEGACY HIGH CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005634",
    },
    {
        "school": "LEGACY MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005636",
    },
    {
        "school": "FREEDOM MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005637",
    },
    {
        "school": "OCOEE HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005638",
    },
    {
        "school": "EAST LAKE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005639",
    },
    {
        "school": "ANDOVER ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005641",
    },
    {
        "school": "WHISPERING OAK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144005642",
    },
    {
        "school": "OSCEOLA REGIONAL JUVENILE COMMITMENT FACILITY",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120147003888",
    },
    {
        "school": "POINCIANA ACADEMY OF FINE ARTS",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147003889",
    },
    {
        "school": "PARTIN SETTLEMENT ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147003890",
    },
    {
        "school": "CANOE CREEK CHARTER ACADEMY",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147003892",
    },
    {
        "school": "BELLALAGO CHARTER ACADEMY",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147004012",
    },
    {
        "school": "HARMONY HIGH SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147004013",
    },
    {
        "school": "CELEBRATION HIGH SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147004118",
    },
    {
        "school": "OSCEOLA COUNTY SCHOOL FOR THE ARTS",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147004119",
    },
    {
        "school": "FLORA RIDGE ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147005055",
    },
    {
        "school": "CHESTNUT ELEMENTARY SCHOOL FOR SCIENCE AND ENGINEERING",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147005655",
    },
    {
        "school": "SUNRISE ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147005656",
    },
    {
        "school": "WALKER ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171004009",
    },
    {
        "school": "LAYER ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171004010",
    },
    {
        "school": "HAGERTY HIGH SCHOOL",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171005736",
    },
    {
        "school": "BEVERLY SHORES ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001087",
    },
    {
        "school": "CLERMONT ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001088",
    },
    {
        "school": "EUSTIS ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001090",
    },
    {
        "school": "EUSTIS HEIGHTS ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001091",
    },
    {
        "school": "EUSTIS HIGH SCHOOL",
        "district": "LAKE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001092",
    },
    {
        "school": "FRUITLAND PARK ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001093",
    },
    {
        "school": "GRAY MIDDLE SCHOOL",
        "district": "LAKE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001095",
    },
    {
        "school": "LEESBURG HIGH SCHOOL",
        "district": "LAKE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001097",
    },
    {
        "school": "MT. DORA HIGH SCHOOL",
        "district": "LAKE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001099",
    },
    {
        "school": "TAVARES HIGH SCHOOL",
        "district": "LAKE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001102",
    },
    {
        "school": "TAVARES MIDDLE SCHOOL",
        "district": "LAKE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001103",
    },
    {
        "school": "UMATILLA HIGH SCHOOL",
        "district": "LAKE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001105",
    },
    {
        "school": "TREADWAY ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001106",
    },
    {
        "school": "OAK PARK MIDDLE SCHOOL",
        "district": "LAKE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001107",
    },
    {
        "school": "MINNEOLA ELEMENTARY CONVERSION CHARTER SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001108",
    },
    {
        "school": "CARVER MIDDLE SCHOOL",
        "district": "LAKE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001109",
    },
    {
        "school": "MT. DORA MIDDLE SCHOOL",
        "district": "LAKE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001114",
    },
    {
        "school": "RIMES EARLY LEARNING & LITERACY CENTER",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001115",
    },
    {
        "school": "TRIANGLE ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001116",
    },
    {
        "school": "LAKE TECHNICAL COLLEGE",
        "district": "LAKE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120105001117",
    },
    {
        "school": "LAKE HILLS SCHOOL",
        "district": "LAKE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120105001118",
    },
    {
        "school": "MASCOTTE ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001119",
    },
    {
        "school": "TAVARES ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001120",
    },
    {
        "school": "UMATILLA MIDDLE SCHOOL",
        "district": "LAKE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001121",
    },
    {
        "school": "SPRING CREEK CHARTER SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001702",
    },
    {
        "school": "SOUTH LAKE HIGH SCHOOL",
        "district": "LAKE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105001714",
    },
    {
        "school": "GROVELAND ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105002074",
    },
    {
        "school": "NONSCHOOL EXCEPTIONAL EDUCATION",
        "district": "LAKE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120105002331",
    },
    {
        "school": "SEMINOLE SPRINGS ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105002659",
    },
    {
        "school": "LAKE ACADEMY EUSTIS",
        "district": "LAKE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120105002761",
    },
    {
        "school": "CYPRESS RIDGE ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105003074",
    },
    {
        "school": "EUSTIS MIDDLE SCHOOL",
        "district": "LAKE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105003195",
    },
    {
        "school": "LAKE ACADEMY LEESBURG",
        "district": "LAKE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120105003196",
    },
    {
        "school": "LAKE COUNTY ACER PROGRAM",
        "district": "LAKE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120105003414",
    },
    {
        "school": "THE VILLAGES ELEMENTARY OF LADY LAKE SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105003593",
    },
    {
        "school": "ASTATULA ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105003594",
    },
    {
        "school": "LOST LAKE ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105003595",
    },
    {
        "school": "WINDY HILL MIDDLE SCHOOL",
        "district": "LAKE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105003596",
    },
    {
        "school": "ALEE ACADEMY CHARTER SCHOOL",
        "district": "LAKE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120105003597",
    },
    {
        "school": "ROUND LAKE ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105004364",
    },
    {
        "school": "UMATILLA ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105004365",
    },
    {
        "school": "WILLIAM FRANGUS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144000839",
    },
    {
        "school": "SHINGLE CREEK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144000861",
    },
    {
        "school": "CYPRESS CREEK HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144000865",
    },
    {
        "school": "PIEDMONT LAKES MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144000866",
    },
    {
        "school": "WILLIAM R BOONE HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001363",
    },
    {
        "school": "EDGEWATER HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001364",
    },
    {
        "school": "HOWARD MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001365",
    },
    {
        "school": "CHEROKEE",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120144001366",
    },
    {
        "school": "MEMORIAL MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001367",
    },
    {
        "school": "HILLCREST ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001370",
    },
    {
        "school": "LAKE COMO SCHOOL",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001372",
    },
    {
        "school": "PINELOCH ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001373",
    },
    {
        "school": "PRINCETON ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001374",
    },
    {
        "school": "ORLO VISTA ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001375",
    },
    {
        "school": "APOPKA MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001376",
    },
    {
        "school": "KILLARNEY ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001378",
    },
    {
        "school": "OCOEE MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001379",
    },
    {
        "school": "LAKEVIEW MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001380",
    },
    {
        "school": "TILDENVILLE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001381",
    },
    {
        "school": "LOCKHART ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001385",
    },
    {
        "school": "UNION PARK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001386",
    },
    {
        "school": "ZELLWOOD ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001387",
    },
    {
        "school": "DILLARD STREET ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001389",
    },
    {
        "school": "LAKE SILVER ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001390",
    },
    {
        "school": "BALDWIN PARK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001391",
    },
    {
        "school": "DREAM LAKE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001392",
    },
    {
        "school": "CONWAY ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001393",
    },
    {
        "school": "LAKEMONT ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001394",
    },
    {
        "school": "GLENRIDGE MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001395",
    },
    {
        "school": "COLLEGE PARK MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001396",
    },
    {
        "school": "GATEWAY",
        "district": "ORANGE",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120144001397",
    },
    {
        "school": "AZALEA PARK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001398",
    },
    {
        "school": "PINE HILLS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001399",
    },
    {
        "school": "BLANKNER K-8",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001400",
    },
    {
        "school": "ROCK LAKE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001401",
    },
    {
        "school": "LAKE WESTON ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001402",
    },
    {
        "school": "COLONIAL HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001403",
    },
    {
        "school": "MAYNARD EVANS HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001404",
    },
    {
        "school": "ENGELWOOD ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001405",
    },
    {
        "school": "OAK RIDGE HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001406",
    },
    {
        "school": "CATALINA ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001407",
    },
    {
        "school": "CHENEY ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001408",
    },
    {
        "school": "LOCKHART MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001409",
    },
    {
        "school": "MAITLAND MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001410",
    },
    {
        "school": "SALLY RIDE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001411",
    },
    {
        "school": "BROOKSHIRE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001412",
    },
    {
        "school": "DOVER SHORES ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001413",
    },
    {
        "school": "MOLLIE RAY ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001414",
    },
    {
        "school": "TANGELO PARK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001416",
    },
    {
        "school": "LOVELL ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001417",
    },
    {
        "school": "CHICKASAW ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001418",
    },
    {
        "school": "SPRING LAKE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001419",
    },
    {
        "school": "LANCASTER ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001420",
    },
    {
        "school": "ROLLING HILLS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001421",
    },
    {
        "school": "BONNEVILLE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001422",
    },
    {
        "school": "HIAWASSEE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001423",
    },
    {
        "school": "MICHAEL MCCOY ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001424",
    },
    {
        "school": "PERSHING SCHOOL",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001425",
    },
    {
        "school": "UNION PARK MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001426",
    },
    {
        "school": "ROBINSWOOD MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001427",
    },
    {
        "school": "STONEWALL JACKSON MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001428",
    },
    {
        "school": "WESTRIDGE MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001429",
    },
    {
        "school": "JUDSON B WALKER MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001430",
    },
    {
        "school": "WINEGARD ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001431",
    },
    {
        "school": "DOMMERICH ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001432",
    },
    {
        "school": "LAKE SYBELIA ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001433",
    },
    {
        "school": "WINDERMERE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001434",
    },
    {
        "school": "MEADOWBROOK MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001435",
    },
    {
        "school": "RIVERSIDE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001436",
    },
    {
        "school": "SADLER ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001437",
    },
    {
        "school": "APOPKA ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001438",
    },
    {
        "school": "WILLIAM S MAXEY ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001439",
    },
    {
        "school": "ORANGE CENTER ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001440",
    },
    {
        "school": "HUNGERFORD ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001442",
    },
    {
        "school": "PHYLLIS WHEATLEY ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001444",
    },
    {
        "school": "CONWAY MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001445",
    },
    {
        "school": "ALOMA ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001446",
    },
    {
        "school": "WINTER PARK HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001447",
    },
    {
        "school": "IVEY LANE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001448",
    },
    {
        "school": "RIDGEWOOD PARK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001449",
    },
    {
        "school": "SHENANDOAH ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001450",
    },
    {
        "school": "COLUMBIA ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001451",
    },
    {
        "school": "PALMETTO ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001452",
    },
    {
        "school": "OAK HILL ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001453",
    },
    {
        "school": "WEST ORANGE HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001454",
    },
    {
        "school": "APOPKA HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001455",
    },
    {
        "school": "PINAR ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001456",
    },
    {
        "school": "LIBERTY MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001457",
    },
    {
        "school": "MAGNOLIA SCHOOL",
        "district": "ORANGE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120144001458",
    },
    {
        "school": "JONES HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001459",
    },
    {
        "school": "ECCLESTON ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001461",
    },
    {
        "school": "WASHINGTON SHORES ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001462",
    },
    {
        "school": "CARVER MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144001463",
    },
    {
        "school": "DEVEREUX TREATMENT PROGRAM",
        "district": "ORANGE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144001908",
    },
    {
        "school": "JUVENILE DETENTION",
        "district": "ORANGE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144002219",
    },
    {
        "school": "DR. PHILLIPS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002220",
    },
    {
        "school": "ORANGE TECHNICAL COLLEGE MID FLORIDA CAMPUS",
        "district": "ORANGE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120144002224",
    },
    {
        "school": "OCOEE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002225",
    },
    {
        "school": "ORANGE TECHNICAL COLLEGE ORLANDO CAMPUS",
        "district": "ORANGE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120144002227",
    },
    {
        "school": "ORANGE TECHNICAL COLLEGE WESTSIDE CAMPUS",
        "district": "ORANGE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120144002355",
    },
    {
        "school": "DEERWOOD ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002475",
    },
    {
        "school": "PRAIRIE LAKE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002522",
    },
    {
        "school": "DR. PHILLIPS HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002572",
    },
    {
        "school": "PALM LAKE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002573",
    },
    {
        "school": "VENTURA ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002574",
    },
    {
        "school": "ROCK SPRINGS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002620",
    },
    {
        "school": "METROWEST ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002621",
    },
    {
        "school": "HOSPITAL HOMEBOUND",
        "district": "ORANGE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120144002645",
    },
    {
        "school": "SIMON YOUTH FOUND ACAD AT OUTLET MKTPLCE",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144002650",
    },
    {
        "school": "ARBOR RIDGE K-8",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002685",
    },
    {
        "school": "MEADOW WOODS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002687",
    },
    {
        "school": "UNIVERSITY HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002779",
    },
    {
        "school": "WINDY RIDGE K-8",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002780",
    },
    {
        "school": "BAY MEADOWS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002781",
    },
    {
        "school": "JOHN YOUNG ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002782",
    },
    {
        "school": "CLAY SPRINGS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002857",
    },
    {
        "school": "SOUTHWEST MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002858",
    },
    {
        "school": "WATERBRIDGE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002859",
    },
    {
        "school": "WATERFORD ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002860",
    },
    {
        "school": "LITTLE RIVER ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002861",
    },
    {
        "school": "HIDDEN OAKS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002862",
    },
    {
        "school": "AMIKIDS ORLANDO",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144002918",
    },
    {
        "school": "CYPRESS SPRINGS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002919",
    },
    {
        "school": "HUNTERS CREEK MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002923",
    },
    {
        "school": "HUNTERS CREEK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002926",
    },
    {
        "school": "GOTHA MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144002927",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144002928",
    },
    {
        "school": "PASSPORT CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003214",
    },
    {
        "school": "DISCOVERY MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003217",
    },
    {
        "school": "ROSEMONT ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003218",
    },
    {
        "school": "SOUTHWOOD ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003219",
    },
    {
        "school": "SUNRISE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003220",
    },
    {
        "school": "LAKE WHITNEY ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003221",
    },
    {
        "school": "PRINCETON HOUSE CHARTER",
        "district": "ORANGE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120144003449",
    },
    {
        "school": "LAKE EOLA CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003450",
    },
    {
        "school": "LAKEVILLE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003451",
    },
    {
        "school": "LAKE GEM ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003452",
    },
    {
        "school": "RIVERDALE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003453",
    },
    {
        "school": "LAKE GEORGE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003454",
    },
    {
        "school": "PINEWOOD ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003455",
    },
    {
        "school": "CORNER LAKE MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003457",
    },
    {
        "school": "MEADOW WOODS MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003458",
    },
    {
        "school": "OAKSHIRE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003627",
    },
    {
        "school": "LAWTON CHILES ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003628",
    },
    {
        "school": "NORTHLAKE PARK COMMUNITY ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003629",
    },
    {
        "school": "CHAIN OF LAKES MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003630",
    },
    {
        "school": "HOPE CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003738",
    },
    {
        "school": "NAP FORD COMMUNITY CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003739",
    },
    {
        "school": "UCP DOWNTOWN CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144003741",
    },
    {
        "school": "THREE POINTS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003742",
    },
    {
        "school": "CAMELOT ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003743",
    },
    {
        "school": "AVALON ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003744",
    },
    {
        "school": "TIMBER CREEK HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003745",
    },
    {
        "school": "OLYMPIA HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003746",
    },
    {
        "school": "ODYSSEY MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144003747",
    },
    {
        "school": "ORANGE YOUTH ACADEMY",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144003748",
    },
    {
        "school": "LA AMISTAD",
        "district": "ORANGE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120144004394",
    },
    {
        "school": "ENDEAVOR ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144004396",
    },
    {
        "school": "CITRUS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144004397",
    },
    {
        "school": "CYPRESS ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147000913",
    },
    {
        "school": "ZENITH ACCELERATED ACADEMY",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120147000920",
    },
    {
        "school": "HIGHLANDS ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147001468",
    },
    {
        "school": "OSCEOLA HIGH SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147001469",
    },
    {
        "school": "DENN JOHN MIDDLE SCHOOL",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147001470",
    },
    {
        "school": "THACKER AVENUE ELEMENTARY FOR INTERNATIONAL STUDIES",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147001471",
    },
    {
        "school": "ST. CLOUD ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147001472",
    },
    {
        "school": "ST. CLOUD HIGH SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147001473",
    },
    {
        "school": "MICHIGAN AVENUE ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147001474",
    },
    {
        "school": "ST. CLOUD MIDDLE SCHOOL",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147001475",
    },
    {
        "school": "REEDY CREEK ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002231",
    },
    {
        "school": "BOGGY CREEK ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002357",
    },
    {
        "school": "HICKORY TREE ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002448",
    },
    {
        "school": "GATEWAY HIGH SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002476",
    },
    {
        "school": "MILL CREEK ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002575",
    },
    {
        "school": "LAKEVIEW ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002576",
    },
    {
        "school": "PLEASANT HILL ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002622",
    },
    {
        "school": "PARKWAY MIDDLE SCHOOL",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002623",
    },
    {
        "school": "NEPTUNE MIDDLE SCHOOL",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002672",
    },
    {
        "school": "VENTURA ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002675",
    },
    {
        "school": "DEERWOOD ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002865",
    },
    {
        "school": "POINCIANA HIGH SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147002866",
    },
    {
        "school": "HORIZON MIDDLE SCHOOL",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147003008",
    },
    {
        "school": "KISSIMMEE MIDDLE SCHOOL",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147003097",
    },
    {
        "school": "CELEBRATION SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147003098",
    },
    {
        "school": "NEW BEGINNINGS EDUCATION CENTER",
        "district": "OSCEOLA",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120147003222",
    },
    {
        "school": "NEW DIMENSIONS HIGH SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147003467",
    },
    {
        "school": "NARCOOSSEE MIDDLE SCHOOL",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147003632",
    },
    {
        "school": "DISCOVERY INTERMEDIATE SCHOOL",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147003633",
    },
    {
        "school": "PROFESSIONAL & TECHNICAL HIGH SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120147003634",
    },
    {
        "school": "CENTRAL AVENUE ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147003749",
    },
    {
        "school": "P. M. WELLS CHARTER ACADEMY",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147003750",
    },
    {
        "school": "UCP OSCEOLA CHARTER SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120147003752",
    },
    {
        "school": "HOSPITAL/HOMEBOUND PROGRAM",
        "district": "OSCEOLA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120147003754",
    },
    {
        "school": "KISSIMMEE ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147004398",
    },
    {
        "school": "KISSIMMEE CHARTER ACADEMY",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147004402",
    },
    {
        "school": "FOUR CORNERS CHARTER SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147004401",
    },
    {
        "school": "INDIAN TRAILS MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001179",
    },
    {
        "school": "BOYS TOWN",
        "district": "SEMINOLE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120171001195",
    },
    {
        "school": "BEAR LAKE ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001862",
    },
    {
        "school": "ENGLISH ESTATES ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001863",
    },
    {
        "school": "GENEVA ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001864",
    },
    {
        "school": "LAKE MARY ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001866",
    },
    {
        "school": "LONGWOOD ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001867",
    },
    {
        "school": "MILWEE MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001868",
    },
    {
        "school": "LAWTON ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001869",
    },
    {
        "school": "PINE CREST ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001870",
    },
    {
        "school": "SANFORD MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001871",
    },
    {
        "school": "SEMINOLE HIGH SCHOOL",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001872",
    },
    {
        "school": "MILLENNIUM MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001873",
    },
    {
        "school": "SOUTH SEMINOLE MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001874",
    },
    {
        "school": "CASSELBERRY ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001875",
    },
    {
        "school": "WILSON ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001877",
    },
    {
        "school": "GOLDSBORO ELEMENTARY MAGNET",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001879",
    },
    {
        "school": "JACKSON HEIGHTS MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001881",
    },
    {
        "school": "MIDWAY ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001882",
    },
    {
        "school": "ENDEAVOR SCHOOL",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120171001883",
    },
    {
        "school": "WINTER SPRINGS ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001884",
    },
    {
        "school": "SPRING LAKE ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001885",
    },
    {
        "school": "OVIEDO HIGH SCHOOL",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001886",
    },
    {
        "school": "LYMAN HIGH SCHOOL",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001887",
    },
    {
        "school": "LAKE BRANTLEY HIGH SCHOOL",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001888",
    },
    {
        "school": "TEAGUE MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001889",
    },
    {
        "school": "FOREST CITY ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001890",
    },
    {
        "school": "RED BUG ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001891",
    },
    {
        "school": "IDYLLWILDE ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001892",
    },
    {
        "school": "EASTBROOK ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001893",
    },
    {
        "school": "TUSKAWILLA MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001894",
    },
    {
        "school": "LAKE HOWELL HIGH SCHOOL",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001895",
    },
    {
        "school": "ALTAMONTE ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001896",
    },
    {
        "school": "SABAL POINT ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001897",
    },
    {
        "school": "WOODLANDS ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001898",
    },
    {
        "school": "LAKE ORIENTA ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001899",
    },
    {
        "school": "STERLING PARK ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001900",
    },
    {
        "school": "WEKIVA ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001901",
    },
    {
        "school": "RAINBOW ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171001997",
    },
    {
        "school": "ROCK LAKE MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171002103",
    },
    {
        "school": "LAKE MARY HIGH SCHOOL",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171002261",
    },
    {
        "school": "KEETH ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171002410",
    },
    {
        "school": "HAMILTON ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171002464",
    },
    {
        "school": "CROOMS ACADEMY OF INFORMATION TECHNOLOGY",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171002533",
    },
    {
        "school": "GREENWOOD LAKES MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171002534",
    },
    {
        "school": "HOSPITAL HOMEBOUND PROGRAM",
        "district": "SEMINOLE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120171002535",
    },
    {
        "school": "STENSTROM ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171002636",
    },
    {
        "school": "HEATHROW ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171002905",
    },
    {
        "school": "PARTIN ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171002906",
    },
    {
        "school": "TAPP CHILDCARE CENTER",
        "district": "SEMINOLE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171002964",
    },
    {
        "school": "HIGHLANDS ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171003125",
    },
    {
        "school": "CARILLON ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171003126",
    },
    {
        "school": "HOPPER CENTER",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120171003268",
    },
    {
        "school": "WICKLOW ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171003269",
    },
    {
        "school": "WINTER SPRINGS HIGH SCHOOL",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171003270",
    },
    {
        "school": "SCPS CONSEQUENCE UNIT",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120171003510",
    },
    {
        "school": "JOHN POLK ALTERNATIVE SCHOOL",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120171003668",
    },
    {
        "school": "BENTLEY ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171003801",
    },
    {
        "school": "UCP SEMINOLE CHILD DEVELOPMENT",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120171003802",
    },
    {
        "school": "CHOICES IN LEARNING CHARTER",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171003803",
    },
    {
        "school": "CONTRACTED SERVICES",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120171003804",
    },
    {
        "school": "EVANS ELEMENTARY SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171004449",
    },
    {
        "school": "CHILES MIDDLE SCHOOL",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171004450",
    },
    {
        "school": "THE CHILDREN'S READING CENTER",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162004139",
    },
    {
        "school": "Q.I. ROBERTS JR. - SR. HIGH SCHOOL",
        "district": "PUTNAM",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162004140",
    },
    {
        "school": "OCHWILLA ELEMENTARY SCHOOL",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001056",
    },
    {
        "school": "C. L. OVERTURF JR 6TH GRADE CENTER",
        "district": "PUTNAM",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001797",
    },
    {
        "school": "MELLON ELEMENTARY SCHOOL",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001799",
    },
    {
        "school": "KELLEY SMITH ELEMENTARY SCHOOL",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001800",
    },
    {
        "school": "INTERLACHEN HIGH SCHOOL",
        "district": "PUTNAM",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001802",
    },
    {
        "school": "C. H. PRICE MIDDLE SCHOOL",
        "district": "PUTNAM",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001803",
    },
    {
        "school": "MELROSE ELEMENTARY SCHOOL",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001804",
    },
    {
        "school": "JAMES A. LONG ELEMENTARY SCHOOL",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001805",
    },
    {
        "school": "ROBERT H. JENKINS JUNIOR MIDDLE",
        "district": "PUTNAM",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001806",
    },
    {
        "school": "GEORGE C. MILLER JR. MIDDLE SCHOOL",
        "district": "PUTNAM",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001808",
    },
    {
        "school": "MIDDLETON-BURNEY ELEMENTARY SCHOOL",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001809",
    },
    {
        "school": "CRESCENT CITY HIGH SCHOOL",
        "district": "PUTNAM",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001810",
    },
    {
        "school": "PALATKA HIGH SCHOOL",
        "district": "PUTNAM",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162001811",
    },
    {
        "school": "ELEANOR H. MILLER SCHOOL",
        "district": "PUTNAM",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120162002530",
    },
    {
        "school": "INTERLACHEN ELEMENTARY SCHOOL",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162002664",
    },
    {
        "school": "BROWNING-PEARCE ELEMENTARY SCHOOL",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162002667",
    },
    {
        "school": "WILLIAM D. MOSELEY ELEMENTARY SCHOOL",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162003791",
    },
    {
        "school": "QUEST ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015003978",
    },
    {
        "school": "IMAGINE SCHOOLS AT WEST MELBOURNE",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015003979",
    },
    {
        "school": "FIELDSTON PREPARATORY SCHOOL",
        "district": "BREVARD",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120015004059",
    },
    {
        "school": "MANATEE ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015004061",
    },
    {
        "school": "BREVARD VIRTUAL FRANCHISE",
        "district": "BREVARD",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015005441",
    },
    {
        "school": "BREVARD COUNTY JUVENILE DETENTION CENTER",
        "district": "BREVARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120015000062",
    },
    {
        "school": "TITUSVILLE HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000078",
    },
    {
        "school": "OAK PARK ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000079",
    },
    {
        "school": "JAMES MADISON MIDDLE SCHOOL",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000080",
    },
    {
        "school": "APOLLO ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000081",
    },
    {
        "school": "COQUINA ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000083",
    },
    {
        "school": "MIMS ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000084",
    },
    {
        "school": "ANDREW JACKSON MIDDLE SCHOOL",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000086",
    },
    {
        "school": "IMPERIAL ESTATES ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000087",
    },
    {
        "school": "ASTRONAUT HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000088",
    },
    {
        "school": "PINEWOOD ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000089",
    },
    {
        "school": "ROCKLEDGE SENIOR HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000090",
    },
    {
        "school": "SUNTREE ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000091",
    },
    {
        "school": "CAMBRIDGE ELEMENTARY MAGNET SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000093",
    },
    {
        "school": "ENDEAVOUR ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000094",
    },
    {
        "school": "GOLFVIEW ELEMENTARY MAGNET SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000095",
    },
    {
        "school": "RONALD MCNAIR MAGNET MIDDLE SCHOOL",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000096",
    },
    {
        "school": "FAIRGLEN ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000097",
    },
    {
        "school": "JOHN F. KENNEDY MIDDLE SCHOOL",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000098",
    },
    {
        "school": "COCOA HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000100",
    },
    {
        "school": "SATURN ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000101",
    },
    {
        "school": "HANS CHRISTIAN ANDERSEN ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000102",
    },
    {
        "school": "MELBOURNE SENIOR HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000103",
    },
    {
        "school": "PALM BAY MAGNET SENIOR HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000104",
    },
    {
        "school": "MEADOWLANE PRIMARY ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000105",
    },
    {
        "school": "UNIVERSITY PARK ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000106",
    },
    {
        "school": "STONE MAGNET MIDDLE SCHOOL",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000107",
    },
    {
        "school": "PALM BAY ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000108",
    },
    {
        "school": "EAU GALLIE HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000109",
    },
    {
        "school": "CENTRAL MIDDLE SCHOOL",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000110",
    },
    {
        "school": "LYNDON B. JOHNSON MIDDLE SCHOOL",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000111",
    },
    {
        "school": "SHERWOOD ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000112",
    },
    {
        "school": "HARBOR CITY ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000113",
    },
    {
        "school": "SABAL ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000114",
    },
    {
        "school": "CROTON ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000116",
    },
    {
        "school": "ROY ALLEN ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000117",
    },
    {
        "school": "MERRITT ISLAND HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000118",
    },
    {
        "school": "EDGEWOOD JR/SR HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000119",
    },
    {
        "school": "MILA ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000120",
    },
    {
        "school": "TROPICAL ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000121",
    },
    {
        "school": "AUDUBON ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000122",
    },
    {
        "school": "THOMAS JEFFERSON MIDDLE SCHOOL",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000125",
    },
    {
        "school": "LEWIS CARROLL ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000126",
    },
    {
        "school": "COCOA BEACH JUNIOR/SENIOR HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000127",
    },
    {
        "school": "THEODORE ROOSEVELT ELEMENTARY  SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000128",
    },
    {
        "school": "CAPE VIEW ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000130",
    },
    {
        "school": "SATELLITE SENIOR HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000131",
    },
    {
        "school": "DELAURA MIDDLE SCHOOL",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000132",
    },
    {
        "school": "SPESSARD L. HOLLAND ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000133",
    },
    {
        "school": "SEA PARK ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000134",
    },
    {
        "school": "SURFSIDE ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000135",
    },
    {
        "school": "OCEAN BREEZE ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000136",
    },
    {
        "school": "INDIALANTIC ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000137",
    },
    {
        "school": "HERBERT C. HOOVER MIDDLE SCHOOL",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000138",
    },
    {
        "school": "GEMINI ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000139",
    },
    {
        "school": "DR. W.J. CREEL ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015000140",
    },
    {
        "school": "ENTERPRISE ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002036",
    },
    {
        "school": "PORT MALABAR ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002038",
    },
    {
        "school": "NORTH/CENTRAL AREA ALTERNATIVE LEARNING CENTER",
        "district": "BREVARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120015002052",
    },
    {
        "school": "SOUTH AREA ALTERNATIVE LEARNING CENTER",
        "district": "BREVARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120015002055",
    },
    {
        "school": "LOCKMAR ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002112",
    },
    {
        "school": "JOHN F. TURNER SENIOR ELEMENTARY  SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002281",
    },
    {
        "school": "CHALLENGER 7 ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002483",
    },
    {
        "school": "COLUMBIA ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002484",
    },
    {
        "school": "CHRISTA MCAULIFFE ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002485",
    },
    {
        "school": "SOUTHWEST MIDDLE SCHOOL",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002590",
    },
    {
        "school": "DISCOVERY ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002591",
    },
    {
        "school": "ATLANTIS ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002662",
    },
    {
        "school": "RIVIERA ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002698",
    },
    {
        "school": "JUPITER ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002799",
    },
    {
        "school": "SPACE COAST JUNIOR/SENIOR HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015002977",
    },
    {
        "school": "BREVARD COUNTY JAIL COMPLEX",
        "district": "BREVARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120015003023",
    },
    {
        "school": "PRE-K ESE SERVICES",
        "district": "BREVARD",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120015003024",
    },
    {
        "school": "MELBOURNE CENTER FOR PERSONAL GROWTH",
        "district": "BREVARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120015003025",
    },
    {
        "school": "DEVEREUX HOSPITAL",
        "district": "BREVARD",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120015003026",
    },
    {
        "school": "BREVARD GROUP TREATMENT HOME",
        "district": "BREVARD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120015003150",
    },
    {
        "school": "OUTWARD BOUND",
        "district": "BREVARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120015003292",
    },
    {
        "school": "BAYSIDE HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015003293",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015003294",
    },
    {
        "school": "LONGLEAF ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015003295",
    },
    {
        "school": "WEST SHORE JUNIOR/SENIOR HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015003296",
    },
    {
        "school": "PALM BAY ACADEMY CHARTER SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015003297",
    },
    {
        "school": "RALPH M WILLIAMS JUNIOR ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015003538",
    },
    {
        "school": "ODYSSEY CHARTER SCHOOL",
        "district": "BREVARD",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015003540",
    },
    {
        "school": "SCULPTOR CHARTER SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015003541",
    },
    {
        "school": "RIVERDALE COUNTRY DAY SCHOOL",
        "district": "BREVARD",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120015003678",
    },
    {
        "school": "EDUCATIONAL HORIZONS CHARTER",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015003680",
    },
    {
        "school": "W. MELBOURNE ELEMENTARY SCHOOL FOR SCIENCE",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015004308",
    },
    {
        "school": "ROBERT L. STEVENSON ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015004310",
    },
    {
        "school": "FREEDOM 7 ELEMENTARY SCHOOL OF INTERNATIONAL STUDIES",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015004311",
    },
    {
        "school": "ROYAL PALM CHARTER SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015004313",
    },
    {
        "school": "MATANZAS HIGH SCHOOL",
        "district": "FLAGLER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054005533",
    },
    {
        "school": "BELLE TERRE ELEMENTARY SCHOOL",
        "district": "FLAGLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054005534",
    },
    {
        "school": "BUNNELL ELEMENTARY SCHOOL",
        "district": "FLAGLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054000841",
    },
    {
        "school": "FLAGLER-PALM COAST HIGH SCHOOL",
        "district": "FLAGLER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054000842",
    },
    {
        "school": "BUDDY TAYLOR MIDDLE SCHOOL",
        "district": "FLAGLER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054002170",
    },
    {
        "school": "LEWIS E. WADSWORTH ELEMENTARY",
        "district": "FLAGLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054002558",
    },
    {
        "school": "OLD KINGS ELEMENTARY SCHOOL",
        "district": "FLAGLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054002747",
    },
    {
        "school": "INDIAN TRAILS MIDDLE SCHOOL",
        "district": "FLAGLER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054003064",
    },
    {
        "school": "BAY HAVEN CHARTER MIDDLE SCHOOL",
        "district": "BAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009005429",
    },
    {
        "school": "CHAUTAUQUA CHARTER SCHOOL",
        "district": "BAY",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120009005431",
    },
    {
        "school": "BAY HIGH SCHOOL",
        "district": "BAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000039",
    },
    {
        "school": "HUTCHISON BEACH ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000040",
    },
    {
        "school": "CEDAR GROVE ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000041",
    },
    {
        "school": "CALLAWAY ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000042",
    },
    {
        "school": "MERRIAM CHERRY STREET ELEMENTARY",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000043",
    },
    {
        "school": "LUCILLE MOORE ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000045",
    },
    {
        "school": "HILAND PARK ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000047",
    },
    {
        "school": "JINKS MIDDLE SCHOOL",
        "district": "BAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000048",
    },
    {
        "school": "LYNN HAVEN ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000049",
    },
    {
        "school": "PARKER ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000052",
    },
    {
        "school": "SOUTHPORT ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000053",
    },
    {
        "school": "ST. ANDREW SCHOOL  AT OAKLAND TERRACE",
        "district": "BAY",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120009000055",
    },
    {
        "school": "WALLER ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000056",
    },
    {
        "school": "TOMMY SMITH ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000059",
    },
    {
        "school": "MOWAT MIDDLE SCHOOL",
        "district": "BAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000063",
    },
    {
        "school": "RUTHERFORD HIGH SCHOOL",
        "district": "BAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000064",
    },
    {
        "school": "NORTHSIDE ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000065",
    },
    {
        "school": "A. CRAWFORD MOSLEY HIGH SCHOOL",
        "district": "BAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000067",
    },
    {
        "school": "TYNDALL ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009000068",
    },
    {
        "school": "EXCEPTIONAL STUDENT EDUCATION",
        "district": "BAY",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120009002034",
    },
    {
        "school": "MARGARET K. LEWIS IN MILLVILLE",
        "district": "BAY",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120009002037",
    },
    {
        "school": "MERRITT BROWN MIDDLE SCHOOL",
        "district": "BAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009002589",
    },
    {
        "school": "SURFSIDE MIDDLE SCHOOL",
        "district": "BAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009002665",
    },
    {
        "school": "PATRONIS ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009002976",
    },
    {
        "school": "NEW HORIZONS LEARNING CENTER",
        "district": "BAY",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120009003147",
    },
    {
        "school": "BAY REGIONAL JUVENILE DETENTION CENTER",
        "district": "BAY",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120009003289",
    },
    {
        "school": "BAY HAVEN CHARTER ACADEMY",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009003676",
    },
    {
        "school": "DEANE BOZEMAN SCHOOL",
        "district": "BAY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009004304",
    },
    {
        "school": "J.R. ARNOLD HIGH SCHOOL",
        "district": "BAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009004305",
    },
    {
        "school": "BENNETT C RUSSELL ELEMENTARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165005376",
    },
    {
        "school": "BYRNEVILLE ELEMENTARY SCHOOL INC.",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051003847",
    },
    {
        "school": "PENSACOLA BEACH ELEMENTARY SCHOOL INC",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051003848",
    },
    {
        "school": "MOLINO PARK ELEMENTARY",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051004081",
    },
    {
        "school": "CAPSTONE ACADEMY",
        "district": "ESCAMBIA",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120051004173",
    },
    {
        "school": "R. C. LIPSCOMB ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000439",
    },
    {
        "school": "JIM ALLEN ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000774",
    },
    {
        "school": "BELLVIEW ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000776",
    },
    {
        "school": "BELLVIEW MIDDLE SCHOOL",
        "district": "ESCAMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000777",
    },
    {
        "school": "BRATT ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000780",
    },
    {
        "school": "BRENTWOOD ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000781",
    },
    {
        "school": "CORDOVA PARK ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000790",
    },
    {
        "school": "ENSLEY ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000793",
    },
    {
        "school": "ESCAMBIA HIGH SCHOOL",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000794",
    },
    {
        "school": "FERRY PASS ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000795",
    },
    {
        "school": "FERRY PASS MIDDLE SCHOOL",
        "district": "ESCAMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000796",
    },
    {
        "school": "MONTCLAIR ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000801",
    },
    {
        "school": "MYRTLE GROVE ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000802",
    },
    {
        "school": "NAVY POINT ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000803",
    },
    {
        "school": "OAKCREST ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000804",
    },
    {
        "school": "PENSACOLA HIGH SCHOOL",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000805",
    },
    {
        "school": "PINE MEADOW ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000806",
    },
    {
        "school": "PLEASANT GROVE ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000807",
    },
    {
        "school": "SCENIC HEIGHTS ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000808",
    },
    {
        "school": "O. J. SEMMES ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000809",
    },
    {
        "school": "SHERWOOD ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000810",
    },
    {
        "school": "A. K. SUTER ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000811",
    },
    {
        "school": "J. M. TATE SENIOR HIGH SCHOOL",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000812",
    },
    {
        "school": "ERNEST WARD MIDDLE SCHOOL",
        "district": "ESCAMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000813",
    },
    {
        "school": "WARRINGTON ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000814",
    },
    {
        "school": "WARRINGTON MIDDLE SCHOOL",
        "district": "ESCAMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000815",
    },
    {
        "school": "WEST PENSACOLA ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000817",
    },
    {
        "school": "J. H. WORKMAN MIDDLE SCHOOL",
        "district": "ESCAMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000819",
    },
    {
        "school": "REINHARDT HOLM ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000820",
    },
    {
        "school": "BROWN BARGE MIDDLE SCHOOL",
        "district": "ESCAMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000824",
    },
    {
        "school": "GEORGE STONE TECHNICAL COLLEGE",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120051000836",
    },
    {
        "school": "PINE FOREST HIGH SCHOOL",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000837",
    },
    {
        "school": "LONGLEAF ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000838",
    },
    {
        "school": "L. D. MCARTHUR ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051000840",
    },
    {
        "school": "LINCOLN PARK ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051002063",
    },
    {
        "school": "BEULAH ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051002164",
    },
    {
        "school": "WASHINGTON SENIOR HIGH SCHOOL",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051002169",
    },
    {
        "school": "ESCAMBIA JUVENILE DETENTION",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120051002304",
    },
    {
        "school": "HOSPITAL & HOMEBOUND",
        "district": "ESCAMBIA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120051002305",
    },
    {
        "school": "LAKEVIEW SPECIAL EDUCATION",
        "district": "ESCAMBIA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120051002306",
    },
    {
        "school": "ESCAMBIA WESTGATE CENTER",
        "district": "ESCAMBIA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120051002431",
    },
    {
        "school": "SUCCESS ACADEMY",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120051002557",
    },
    {
        "school": "RANSOM MIDDLE SCHOOL",
        "district": "ESCAMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051002600",
    },
    {
        "school": "ESCAMBIA BOYS' BASE",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120051002601",
    },
    {
        "school": "COUNTY ADMINISTRATIVE ANNEX",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120051002602",
    },
    {
        "school": "HELLEN CARO ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051002746",
    },
    {
        "school": "C. A. WEIS ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051002819",
    },
    {
        "school": "JIM C. BAILEY MIDDLE SCHOOL",
        "district": "ESCAMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051002994",
    },
    {
        "school": "NORTHVIEW HIGH SCHOOL",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051002995",
    },
    {
        "school": "PACE PROGRAM",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120051003057",
    },
    {
        "school": "BEULAH ACADEMY OF SCIENCE",
        "district": "ESCAMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051003366",
    },
    {
        "school": "N. B. COOK ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051003581",
    },
    {
        "school": "WEST FLORIDA HIGH SCHOOL/TECHNICAL",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051003703",
    },
    {
        "school": "ESCAMBIA SCH. DIST. JAIL PROG.",
        "district": "ESCAMBIA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120051003704",
    },
    {
        "school": "JACKIE HARRIS PREPARATORY ACADEMY",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120051003705",
    },
    {
        "school": "CAMELOT ACADEMY OF ESCAMBIA COUNTY",
        "district": "ESCAMBIA",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120051004345",
    },
    {
        "school": "BLUE ANGELS ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051004346",
    },
    {
        "school": "CENTRAL SCHOOL",
        "district": "SANTA ROSA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001813",
    },
    {
        "school": "BERRYHILL ELEMENTARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001814",
    },
    {
        "school": "BAGDAD ELEMENTARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001815",
    },
    {
        "school": "CHUMUCKLA ELEMENTARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001816",
    },
    {
        "school": "EAST MILTON ELEMENTARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001817",
    },
    {
        "school": "GULF BREEZE ELEMENTARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001819",
    },
    {
        "school": "GULF BREEZE MIDDLE SCHOOL",
        "district": "SANTA ROSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001820",
    },
    {
        "school": "GULF BREEZE HIGH SCHOOL",
        "district": "SANTA ROSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001821",
    },
    {
        "school": "T. R. JACKSON PREK CENTER",
        "district": "SANTA ROSA",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001822",
    },
    {
        "school": "JAY HIGH SCHOOL",
        "district": "SANTA ROSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001823",
    },
    {
        "school": "JAY ELEMENTARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001824",
    },
    {
        "school": "MILTON HIGH SCHOOL",
        "district": "SANTA ROSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001826",
    },
    {
        "school": "S. S. DIXON PRIMARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001828",
    },
    {
        "school": "PACE HIGH SCHOOL",
        "district": "SANTA ROSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001830",
    },
    {
        "school": "HOBBS MIDDLE SCHOOL",
        "district": "SANTA ROSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001832",
    },
    {
        "school": "MARTIN LUTHER KING MIDDLE SCHOOL",
        "district": "SANTA ROSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001833",
    },
    {
        "school": "HOLLEY-NAVARRE INTERMEDIATE",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165001834",
    },
    {
        "school": "PEA RIDGE ELEMENTARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165002097",
    },
    {
        "school": "W. H. RHODES ELEMENTARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165002098",
    },
    {
        "school": "RADFORD M LOCKLIN TECHNICAL COLLEGE",
        "district": "SANTA ROSA",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120165002257",
    },
    {
        "school": "ORIOLE BEACH ELEMENTARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165002258",
    },
    {
        "school": "SANTA ROSA ADULT SCHOOL",
        "district": "SANTA ROSA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120165002408",
    },
    {
        "school": "HOLLEY-NAVARRE MIDDLE SCHOOL",
        "district": "SANTA ROSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165002670",
    },
    {
        "school": "S. S. DIXON INTERMEDIATE SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165002959",
    },
    {
        "school": "WEST NAVARRE PRIMARY SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165002960",
    },
    {
        "school": "NAVARRE HIGH SCHOOL",
        "district": "SANTA ROSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165003122",
    },
    {
        "school": "THOMAS L SIMS MIDDLE SCHOOL",
        "district": "SANTA ROSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165003504",
    },
    {
        "school": "LEARNING ACADEMY OF SANTA ROSA",
        "district": "SANTA ROSA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120165003505",
    },
    {
        "school": "AVALON MIDDLE SCHOOL",
        "district": "SANTA ROSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165003664",
    },
    {
        "school": "WEST NAVARRE INTERMEDIATE SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165003665",
    },
    {
        "school": "SAIL",
        "district": "SANTA ROSA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120165003666",
    },
    {
        "school": "WOODLAWN BEACH MIDDLE SCHOOL",
        "district": "SANTA ROSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165004446",
    },
    {
        "school": "PK EARLY INTERVENTION",
        "district": "MARTIN",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129003874",
    },
    {
        "school": "JENSEN BEACH HIGH SCHOOL",
        "district": "MARTIN",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129004042",
    },
    {
        "school": "THE HOPE CHARTER CENTER FOR AUTISM",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120129004043",
    },
    {
        "school": "CLARK ADVANCED LEARNING CENTER",
        "district": "MARTIN",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129004044",
    },
    {
        "school": "ST. LUCIE COUNTY SCHOOL BOARD-JAIL PROGRAM-ESE",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120177003932",
    },
    {
        "school": "OAK HAMMOCK K-8 SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177003943",
    },
    {
        "school": "TREASURE COAST HIGH SCHOOL",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177004148",
    },
    {
        "school": "DALE CASSENS EDUCATION COMPLEX",
        "district": "ST. LUCIE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120177004149",
    },
    {
        "school": "HIDDEN OAKS MIDDLE SCHOOL",
        "district": "MARTIN",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129000834",
    },
    {
        "school": "STUART MIDDLE SCHOOL",
        "district": "MARTIN",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129001281",
    },
    {
        "school": "MARTIN COUNTY HIGH SCHOOL",
        "district": "MARTIN",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129001282",
    },
    {
        "school": "J. D. PARKER SCHOOL OF TECHNOLOGY",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129001284",
    },
    {
        "school": "PALM CITY ELEMENTARY SCHOOL",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129001285",
    },
    {
        "school": "MURRAY MIDDLE SCHOOL",
        "district": "MARTIN",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129001286",
    },
    {
        "school": "PORT SALERNO ELEMENTARY SCHOOL",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129001287",
    },
    {
        "school": "HOBE SOUND ELEMENTARY SCHOOL",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129001288",
    },
    {
        "school": "WARFIELD ELEMENTARY SCHOOL",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129001289",
    },
    {
        "school": "JENSEN BEACH ELEMENTARY SCHOOL",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129001290",
    },
    {
        "school": "INDIANTOWN MIDDLE SCHOOL",
        "district": "MARTIN",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129001291",
    },
    {
        "school": "ESE HOMEBOUND",
        "district": "MARTIN",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120129002214",
    },
    {
        "school": "SOUTH FORK HIGH SCHOOL",
        "district": "MARTIN",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129002344",
    },
    {
        "school": "PINEWOOD ELEMENTARY SCHOOL",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129002619",
    },
    {
        "school": "SPECTRUM ACADEMY",
        "district": "MARTIN",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120129002655",
    },
    {
        "school": "CRYSTAL LAKE ELEMENTARY SCHOOL",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129002770",
    },
    {
        "school": "WILLOUGHBY LEARNING CENTER",
        "district": "MARTIN",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120129002848",
    },
    {
        "school": "FELIX A WILLIAMS ELEMENTARY SCHOOL",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129002915",
    },
    {
        "school": "SEA WIND ELEMENTARY SCHOOL",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129003007",
    },
    {
        "school": "TEEN PARENT INDIANTOWN",
        "district": "MARTIN",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129003086",
    },
    {
        "school": "BESSEY CREEK ELEMENTARY SCHOOL",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129003087",
    },
    {
        "school": "PORT SALERNO LEARNING CENTER",
        "district": "MARTIN",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120129003614",
    },
    {
        "school": "RIVERBEND ACADEMY",
        "district": "MARTIN",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120129003615",
    },
    {
        "school": "PREKINDERGARTEN PROGRAMS",
        "district": "MARTIN",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129003617",
    },
    {
        "school": "MARTIN COUNTY JAIL",
        "district": "MARTIN",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120129004390",
    },
    {
        "school": "PERFORMANCE BASED PREPARATORY ACADEMY",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120177001079",
    },
    {
        "school": "MARIPOSA ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177001081",
    },
    {
        "school": "MANATEE ACADEMY K-8",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177001111",
    },
    {
        "school": "WHITE CITY ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177001922",
    },
    {
        "school": "FAIRLAWN ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177001923",
    },
    {
        "school": "LAWNWOOD ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177001925",
    },
    {
        "school": "ST. LUCIE ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177001926",
    },
    {
        "school": "DAN MCCARTY MIDDLE SCHOOL",
        "district": "ST. LUCIE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177001927",
    },
    {
        "school": "FRANCES K. SWEET ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177001928",
    },
    {
        "school": "CHESTER A. MOORE ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177001931",
    },
    {
        "school": "LINCOLN PARK ACADEMY",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177001932",
    },
    {
        "school": "FORT PIERCE CENTRAL HIGH SCHOOL",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177001933",
    },
    {
        "school": "FORT PIERCE WESTWOOD ACADEMY THE W.E.S.T. PREP MAGNET",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002104",
    },
    {
        "school": "FLORESTA ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002264",
    },
    {
        "school": "LAKEWOOD PARK ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002265",
    },
    {
        "school": "MORNINGSIDE ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002266",
    },
    {
        "school": "NORTHPORT K-8 SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002481",
    },
    {
        "school": "WINDMILL POINT ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002536",
    },
    {
        "school": "VILLAGE GREEN ENVIRONMENTAL STUDIES SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002537",
    },
    {
        "school": "BAYSHORE ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002638",
    },
    {
        "school": "PORT ST. LUCIE HIGH SCHOOL",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002671",
    },
    {
        "school": "PARKWAY ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002673",
    },
    {
        "school": "SOUTHPORT MIDDLE SCHOOL",
        "district": "ST. LUCIE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002901",
    },
    {
        "school": "FOREST GROVE MIDDLE SCHOOL",
        "district": "ST. LUCIE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177002902",
    },
    {
        "school": "ST. LUCIE DETENTION CENTER",
        "district": "ST. LUCIE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120177002903",
    },
    {
        "school": "HOMEBOUND PROGRAM",
        "district": "ST. LUCIE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120177002957",
    },
    {
        "school": "RIVERS EDGE ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177003019",
    },
    {
        "school": "SOUTHERN OAKS MIDDLE SCHOOL",
        "district": "ST. LUCIE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177003020",
    },
    {
        "school": "WEATHERBEE ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177003121",
    },
    {
        "school": "CREATIVE ARTS ACADEMY OF ST. LUCIE",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177003500",
    },
    {
        "school": "SAVANNA RIDGE ELEMENTARY SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177003501",
    },
    {
        "school": "ST. LUCIE WEST K-8 SCHOOL",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177003502",
    },
    {
        "school": "ST. LUCIE WEST CENTENNIAL HIGH",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177003503",
    },
    {
        "school": "PACE CENTER FOR GIRLS TREASURE COAST",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120177003661",
    },
    {
        "school": "DATA HOUSE",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120177003796",
    },
    {
        "school": "SALLIE JONES ELEMENTARY SCHOOL",
        "district": "CHARLOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024000295",
    },
    {
        "school": "CHARLOTTE HIGH SCHOOL",
        "district": "CHARLOTTE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024000296",
    },
    {
        "school": "PEACE RIVER ELEMENTARY SCHOOL",
        "district": "CHARLOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024000297",
    },
    {
        "school": "LEMON BAY HIGH SCHOOL",
        "district": "CHARLOTTE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024000298",
    },
    {
        "school": "BAKER/HEAD START",
        "district": "CHARLOTTE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024000299",
    },
    {
        "school": "EAST ELEMENTARY SCHOOL",
        "district": "CHARLOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024000300",
    },
    {
        "school": "NEIL ARMSTRONG ELEMENTARY SCHOOL",
        "district": "CHARLOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024000301",
    },
    {
        "school": "PUNTA GORDA MIDDLE SCHOOL",
        "district": "CHARLOTTE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024000302",
    },
    {
        "school": "PORT CHARLOTTE MIDDLE SCHOOL",
        "district": "CHARLOTTE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024000303",
    },
    {
        "school": "MEADOW PARK ELEMENTARY SCHOOL",
        "district": "CHARLOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024000304",
    },
    {
        "school": "CHARLOTTE HARBOR SCHOOL",
        "district": "CHARLOTTE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120024002050",
    },
    {
        "school": "CHARLOTTE TECHNICAL COLLEGE",
        "district": "CHARLOTTE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120024002051",
    },
    {
        "school": "PORT CHARLOTTE HIGH SCHOOL",
        "district": "CHARLOTTE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024002122",
    },
    {
        "school": "L. A. AINGER MIDDLE SCHOOL",
        "district": "CHARLOTTE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024002422",
    },
    {
        "school": "VINELAND ELEMENTARY SCHOOL",
        "district": "CHARLOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024002548",
    },
    {
        "school": "LIBERTY ELEMENTARY SCHOOL",
        "district": "CHARLOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024002549",
    },
    {
        "school": "MURDOCK MIDDLE SCHOOL",
        "district": "CHARLOTTE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024002668",
    },
    {
        "school": "MYAKKA RIVER ELEMENTARY SCHOOL",
        "district": "CHARLOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024002724",
    },
    {
        "school": "DEEP CREEK ELEMENTARY SCHOOL",
        "district": "CHARLOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024002725",
    },
    {
        "school": "KINGSWAY ELEMENTARY SCHOOL",
        "district": "CHARLOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024003333",
    },
    {
        "school": "PINNACLE ACADEMY INC.",
        "district": "MANATEE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120123003871",
    },
    {
        "school": "GILBERT W MCNEAL ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123004110",
    },
    {
        "school": "FREEDOM ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123004111",
    },
    {
        "school": "VIRGIL MILLS ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123004204",
    },
    {
        "school": "R. DAN NOLAN MIDDLE SCHOOL",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123004205",
    },
    {
        "school": "BRADEN RIVER HIGH SCHOOL",
        "district": "MANATEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123005608",
    },
    {
        "school": "ROBERT WILLIS ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123005609",
    },
    {
        "school": "SARASOTA MILITARY ACADEMY",
        "district": "SARASOTA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168003933",
    },
    {
        "school": "HERON CREEK MIDDLE SCHOOL",
        "district": "SARASOTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168003935",
    },
    {
        "school": "CRANBERRY ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168004142",
    },
    {
        "school": "SARASOTA SUNCOAST ACADEMY",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168004199",
    },
    {
        "school": "THE FLORIDA CENTER FOR CHILD AND FAMILY DEVELOPMENT",
        "district": "SARASOTA",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120168004201",
    },
    {
        "school": "STUDENT LEADERSHIP ACADEMY",
        "district": "SARASOTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168004203",
    },
    {
        "school": "PINNACLE ACADEMY INC.",
        "district": "SARASOTA",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120168004206",
    },
    {
        "school": "CHILDREN FIRST",
        "district": "SARASOTA",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120168004208",
    },
    {
        "school": "TATUM RIDGE ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168005734",
    },
    {
        "school": "TARA ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123000822",
    },
    {
        "school": "ANNA MARIA ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001217",
    },
    {
        "school": "BALLARD ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001218",
    },
    {
        "school": "BAYSHORE ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001219",
    },
    {
        "school": "BAYSHORE HIGH SCHOOL",
        "district": "MANATEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001220",
    },
    {
        "school": "MANATEE ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001222",
    },
    {
        "school": "MANATEE HIGH SCHOOL",
        "district": "MANATEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001223",
    },
    {
        "school": "MANATEE TECHNICAL COLLEGE",
        "district": "MANATEE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120123001224",
    },
    {
        "school": "JESSIE P. MILLER ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001225",
    },
    {
        "school": "MYAKKA CITY ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001226",
    },
    {
        "school": "ONECO ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001227",
    },
    {
        "school": "G D ROGERS GARDEN- BULLOCK ELEMENTARY",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001228",
    },
    {
        "school": "PALM VIEW K-8 SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001229",
    },
    {
        "school": "PALMA SOLA ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001230",
    },
    {
        "school": "PALMETTO ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001231",
    },
    {
        "school": "PALMETTO HIGH SCHOOL",
        "district": "MANATEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001232",
    },
    {
        "school": "ROBERT H. PRINE ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001233",
    },
    {
        "school": "BLANCHE H. DAUGHTREY ELEMENTARY",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001234",
    },
    {
        "school": "SAMOSET ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001235",
    },
    {
        "school": "SOUTHEAST HIGH SCHOOL",
        "district": "MANATEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001236",
    },
    {
        "school": "JAMES TILLMAN ELEMENTARY MAGNET SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001239",
    },
    {
        "school": "BLACKBURN ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001240",
    },
    {
        "school": "FRANCES WAKELAND ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001241",
    },
    {
        "school": "W. D. SUGG MIDDLE SCHOOL",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001242",
    },
    {
        "school": "H. S. MOODY ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001244",
    },
    {
        "school": "MARTHA B. KING MIDDLE SCHOOL",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123001245",
    },
    {
        "school": "HOSPITAL HOMEBOUND INSTRUCTION",
        "district": "MANATEE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120123001249",
    },
    {
        "school": "JUST FOR GIRLS MIDDLE SCHOOL",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120123001839",
    },
    {
        "school": "FLORINE J ABEL ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123002082",
    },
    {
        "school": "IDA M. STEWART ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123002083",
    },
    {
        "school": "JUVENILE DETENTION CENTER",
        "district": "MANATEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120123002084",
    },
    {
        "school": "WILLIAM H. BASHAW ELEMENTARY",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123002474",
    },
    {
        "school": "LOUISE R JOHNSON K-8 SCHOOL OF INTERNATIONAL STUDIES",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123002585",
    },
    {
        "school": "BRADEN RIVER ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123002615",
    },
    {
        "school": "PALMSHORES BEHAVIOR HEALTH CENTER",
        "district": "MANATEE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120123002716",
    },
    {
        "school": "GENE WITT ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123002757",
    },
    {
        "school": "BRADEN RIVER MIDDLE SCHOOL",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123002838",
    },
    {
        "school": "SEA BREEZE ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123002839",
    },
    {
        "school": "EASTER SEALS",
        "district": "MANATEE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120123002842",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "MANATEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120123002844",
    },
    {
        "school": "CARLOS E. HAILE MIDDLE SCHOOL",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123003198",
    },
    {
        "school": "MANATEE SCHOOL OF ARTS/SCIENCES",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123003199",
    },
    {
        "school": "TEAM SUCCESS A SCHOOL OF EXCELLENCE",
        "district": "MANATEE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123003200",
    },
    {
        "school": "LAKEWOOD RANCH HIGH SCHOOL",
        "district": "MANATEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123003425",
    },
    {
        "school": "MANATEE SCHOOL FOR THE ARTS",
        "district": "MANATEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123003429",
    },
    {
        "school": "HORIZONS ACADEMY",
        "district": "MANATEE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120123003610",
    },
    {
        "school": "MARJORIE G. KINNAN ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123004374",
    },
    {
        "school": "WILLIAM MONROE ROWLETT ACADEMY FOR ARTS AND COMMUNICATION",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123004375",
    },
    {
        "school": "ELECTA LEE MAGNET MIDDLE SCHOOL",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123004376",
    },
    {
        "school": "ACCESS TO EDUCATION",
        "district": "MANATEE",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120123004377",
    },
    {
        "school": "MANATEE COMMUNITY ACTION AGENCY-HEAD START",
        "district": "MANATEE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123004381",
    },
    {
        "school": "LAUREL NOKOMIS SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001154",
    },
    {
        "school": "TOLEDO BLADE ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001175",
    },
    {
        "school": "ALTA VISTA ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001835",
    },
    {
        "school": "PINE VIEW SCHOOL",
        "district": "SARASOTA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001836",
    },
    {
        "school": "SARASOTA MIDDLE SCHOOL",
        "district": "SARASOTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001837",
    },
    {
        "school": "SARASOTA HIGH SCHOOL",
        "district": "SARASOTA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001838",
    },
    {
        "school": "BRENTWOOD ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001840",
    },
    {
        "school": "BROOKSIDE MIDDLE SCHOOL",
        "district": "SARASOTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001841",
    },
    {
        "school": "ENGLEWOOD ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001842",
    },
    {
        "school": "FRUITVILLE ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001843",
    },
    {
        "school": "MCINTOSH MIDDLE SCHOOL",
        "district": "SARASOTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001844",
    },
    {
        "school": "PHILLIPPI SHORES ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001846",
    },
    {
        "school": "RIVERVIEW HIGH SCHOOL",
        "district": "SARASOTA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001847",
    },
    {
        "school": "SOUTHSIDE ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001848",
    },
    {
        "school": "TUTTLE ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001849",
    },
    {
        "school": "VENICE ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001850",
    },
    {
        "school": "VENICE SENIOR HIGH SCHOOL",
        "district": "SARASOTA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001851",
    },
    {
        "school": "GOCIO ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001853",
    },
    {
        "school": "GULF GATE ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001854",
    },
    {
        "school": "WILKINSON ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001855",
    },
    {
        "school": "ESE SPECIAL PROGRAMS",
        "district": "SARASOTA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120168001856",
    },
    {
        "school": "OAK PARK SCHOOL",
        "district": "SARASOTA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120168001857",
    },
    {
        "school": "ASHTON ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001859",
    },
    {
        "school": "GARDEN ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168001860",
    },
    {
        "school": "SUNCOAST TECHNICAL COLLEGE",
        "district": "SARASOTA",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120168001861",
    },
    {
        "school": "BAY HAVEN SCHOOL OF BASICS PLUS",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168002458",
    },
    {
        "school": "BOOKER MIDDLE SCHOOL",
        "district": "SARASOTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168002460",
    },
    {
        "school": "BOOKER HIGH SCHOOL",
        "district": "SARASOTA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168002461",
    },
    {
        "school": "VENICE MIDDLE SCHOOL",
        "district": "SARASOTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168002462",
    },
    {
        "school": "GLENALLEN ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168002463",
    },
    {
        "school": "LAKEVIEW ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168002583",
    },
    {
        "school": "TAYLOR RANCH ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168002792",
    },
    {
        "school": "EMMA E. BOOKER ELEMENTARY SCHOOL",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168002904",
    },
    {
        "school": "TRIAD",
        "district": "SARASOTA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120168003123",
    },
    {
        "school": "SARASOTA SCHOOL OF ARTS/SCIENCES",
        "district": "SARASOTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168003265",
    },
    {
        "school": "SUNCOAST SCHOOL FOR INNOVATIVE STUDIES",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168003508",
    },
    {
        "school": "ISLAND VILLAGE MONTESSORI SCHOOL",
        "district": "SARASOTA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168003799",
    },
    {
        "school": "NORTH PORT HIGH SCHOOL",
        "district": "SARASOTA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168003800",
    },
    {
        "school": "THE ACADEMY AT YOUTH CARE LANE",
        "district": "HIGHLANDS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120084003853",
    },
    {
        "school": "SEBRING MIDDLE SCHOOL",
        "district": "HIGHLANDS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084000898",
    },
    {
        "school": "WOODLAWN ELEMENTARY SCHOOL",
        "district": "HIGHLANDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084000899",
    },
    {
        "school": "FRED WILD ELEMENTARY SCHOOL",
        "district": "HIGHLANDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084000900",
    },
    {
        "school": "AVON ELEMENTARY SCHOOL",
        "district": "HIGHLANDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084000901",
    },
    {
        "school": "AVON PARK MIDDLE SCHOOL",
        "district": "HIGHLANDS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084000902",
    },
    {
        "school": "LAKE PLACID ELEMENTARY SCHOOL",
        "district": "HIGHLANDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084000904",
    },
    {
        "school": "SEBRING HIGH SCHOOL",
        "district": "HIGHLANDS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084000905",
    },
    {
        "school": "AVON PARK HIGH SCHOOL",
        "district": "HIGHLANDS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084000906",
    },
    {
        "school": "LAKE PLACID HIGH SCHOOL",
        "district": "HIGHLANDS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084000907",
    },
    {
        "school": "SUN 'N LAKE ELEMENTARY SCHOOL",
        "district": "HIGHLANDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084002504",
    },
    {
        "school": "LAKE COUNTRY ELEMENTARY SCHOOL",
        "district": "HIGHLANDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084002606",
    },
    {
        "school": "LAKE PLACID MIDDLE SCHOOL",
        "district": "HIGHLANDS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084002651",
    },
    {
        "school": "PARK ELEMENTARY SCHOOL",
        "district": "HIGHLANDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084002754",
    },
    {
        "school": "CRACKER TRAIL ELEMENTARY SCHOOL",
        "district": "HIGHLANDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084002824",
    },
    {
        "school": "HILL-GUSTAT MIDDLE SCHOOL",
        "district": "HIGHLANDS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084003069",
    },
    {
        "school": "THE PEMBROKE PINES FLORIDA",
        "district": "FSU LAB SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201304147",
    },
    {
        "school": "JEFFERSON COUNTY MIDDLE A SOMERSET CHARTER SCHOOL",
        "district": "JEFFERSON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120099001082",
    },
    {
        "school": "JEFFERSON COUNTY ELEMENTARY A SOMERSET CHARTER SCHOOL",
        "district": "JEFFERSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120099001084",
    },
    {
        "school": "CRAWFORDVILLE ELEMENTARY SCHOOL",
        "district": "WAKULLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195002015",
    },
    {
        "school": "WAKULLA HIGH SCHOOL",
        "district": "WAKULLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195002017",
    },
    {
        "school": "DISTRICT PRE-K PROGRAMS",
        "district": "WAKULLA",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195002272",
    },
    {
        "school": "WAKULLA MIDDLE SCHOOL",
        "district": "WAKULLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195002273",
    },
    {
        "school": "SHADEVILLE ELEMENTARY SCHOOL",
        "district": "WAKULLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195002657",
    },
    {
        "school": "MEDART ELEMENTARY SCHOOL",
        "district": "WAKULLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195003137",
    },
    {
        "school": "WAKULLA INSTITUTE",
        "district": "WAKULLA",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120195003280",
    },
    {
        "school": "WAKULLA COAST CHARTER SCHOOL OF ARTS SCIENCE & TECHNOLOGY",
        "district": "WAKULLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195003673",
    },
    {
        "school": "ALTERNATIVE HIGH SCHOOL PROGRAM",
        "district": "WAKULLA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120195003810",
    },
    {
        "school": "RIVERSPRINGS MIDDLE SCHOOL",
        "district": "WAKULLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195004457",
    },
    {
        "school": "GEORGE W. MUNROE ELEMENTARY SCHOOL",
        "district": "GADSDEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060000848",
    },
    {
        "school": "GADSDEN COUNTY HIGH SCHOOL",
        "district": "GADSDEN",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060000849",
    },
    {
        "school": "HAVANA MAGNET SCHOOL",
        "district": "GADSDEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060000852",
    },
    {
        "school": "GADSDEN ELEMENTARY MAGNET SCHOOL",
        "district": "GADSDEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060000853",
    },
    {
        "school": "GREENSBORO ELEMENTARY SCHOOL",
        "district": "GADSDEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060000854",
    },
    {
        "school": "CHATTAHOOCHEE ELEMENTARY SCHOOL",
        "district": "GADSDEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060000855",
    },
    {
        "school": "STEWART STREET ELEMENTARY SCHOOL",
        "district": "GADSDEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060000858",
    },
    {
        "school": "JAMES A. SHANKS MIDDLE SCHOOL",
        "district": "GADSDEN",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060000859",
    },
    {
        "school": "CARTER PARRAMORE ACADEMY",
        "district": "GADSDEN",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120060000860",
    },
    {
        "school": "GADSDEN TECHNICAL INSTITUTE",
        "district": "GADSDEN",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120060002166",
    },
    {
        "school": "FLORIDA STATE HOSPITAL",
        "district": "GADSDEN",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120060002172",
    },
    {
        "school": "BOLD STEP INFANT CARE",
        "district": "GADSDEN",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060002822",
    },
    {
        "school": "CROSSROAD ACADEMY",
        "district": "GADSDEN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060003066",
    },
    {
        "school": "GADSDEN CENTRAL ACADEMY",
        "district": "GADSDEN",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120060003584",
    },
    {
        "school": "SECOND CHANCE AT GHAZVINI LEARNING CENTER",
        "district": "LEON",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120111000788",
    },
    {
        "school": "LEON HIGH SCHOOL",
        "district": "LEON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001162",
    },
    {
        "school": "KATE SULLIVAN ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001163",
    },
    {
        "school": "ELIZABETH COBB MIDDLE SCHOOL",
        "district": "LEON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001164",
    },
    {
        "school": "FRANK HARTSFIELD ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001165",
    },
    {
        "school": "JAMES RICKARDS HIGH SCHOOL",
        "district": "LEON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001166",
    },
    {
        "school": "SABAL PALM ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001168",
    },
    {
        "school": "RUEDIGER ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001170",
    },
    {
        "school": "RAA MIDDLE SCHOOL",
        "district": "LEON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001171",
    },
    {
        "school": "WOODVILLE SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001173",
    },
    {
        "school": "AMOS P. GODBY HIGH SCHOOL",
        "district": "LEON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001176",
    },
    {
        "school": "OAK RIDGE ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001177",
    },
    {
        "school": "SAIL",
        "district": "LEON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001178",
    },
    {
        "school": "GRIFFIN MIDDLE SCHOOL",
        "district": "LEON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001180",
    },
    {
        "school": "JOHN G RILEY ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001181",
    },
    {
        "school": "R. FRANK NIMS MIDDLE SCHOOL",
        "district": "LEON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001182",
    },
    {
        "school": "PINEVIEW ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001184",
    },
    {
        "school": "LIVELY TECHNICAL COLLEGE",
        "district": "LEON",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120111001185",
    },
    {
        "school": "GILCHRIST ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001186",
    },
    {
        "school": "ASTORIA PARK ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001188",
    },
    {
        "school": "GRETCHEN EVERHART SCHOOL",
        "district": "LEON",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120111001189",
    },
    {
        "school": "W T MOORE ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001190",
    },
    {
        "school": "SEALEY ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001191",
    },
    {
        "school": "APALACHEE ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001192",
    },
    {
        "school": "FAIRVIEW MIDDLE SCHOOL",
        "district": "LEON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001193",
    },
    {
        "school": "LINCOLN HIGH SCHOOL",
        "district": "LEON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001194",
    },
    {
        "school": "FORT BRADEN SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111001825",
    },
    {
        "school": "HOSPITAL HOMEBOUND",
        "district": "LEON",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120111002079",
    },
    {
        "school": "HERITAGE TRAILS COMMUNITY SCHOOL",
        "district": "LEON",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120111002207",
    },
    {
        "school": "PREK",
        "district": "LEON",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120111002339",
    },
    {
        "school": "KILLEARN LAKES ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111002473",
    },
    {
        "school": "CHAIRES ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111002567",
    },
    {
        "school": "SPRINGWOOD ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111002568",
    },
    {
        "school": "DESOTO TRAIL ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111002679",
    },
    {
        "school": "BUCK LAKE ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111002680",
    },
    {
        "school": "DEERLAKE MIDDLE SCHOOL",
        "district": "LEON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111002763",
    },
    {
        "school": "HAWKS RISE ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111002999",
    },
    {
        "school": "SWIFT CREEK MIDDLE SCHOOL",
        "district": "LEON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111003000",
    },
    {
        "school": "CANOPY OAKS ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111003419",
    },
    {
        "school": "LAWTON CHILES HIGH SCHOOL",
        "district": "LEON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111003598",
    },
    {
        "school": "THE SCHOOL OF ARTS AND SCIENCES  ON THOMASVILLE",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111003599",
    },
    {
        "school": "LEON CO JUVENILE DETENTION CENTER",
        "district": "LEON",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120111003601",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "LEON",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120111003602",
    },
    {
        "school": "ROBERTS ELEMENTARY SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111003727",
    },
    {
        "school": "FLORIDA STATE UNIVERSITY SCHOOL",
        "district": "FSU LAB SCH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201303021",
    },
    {
        "school": "FLORIDA A&M UNIVERSITY DEVELOPMENTAL RESEARCH SCHOOL",
        "district": "FAMU LAB SCH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201402974",
    },
    {
        "school": "DOUBLE BRANCH ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153006976",
    },
    {
        "school": "NATURE COAST TECHNICAL HIGH",
        "district": "HERNANDO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081004083",
    },
    {
        "school": "GULF COAST ACADEMY OF SCIENCE AND TECHNOLOGY",
        "district": "HERNANDO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081004084",
    },
    {
        "school": "CHALLENGER K-8 SCHOOL OF SCIENCE AND MATH",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081005548",
    },
    {
        "school": "BRYANT ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003854",
    },
    {
        "school": "BURNEY ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003855",
    },
    {
        "school": "CIMINO ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003856",
    },
    {
        "school": "FARNELL MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003857",
    },
    {
        "school": "FREEDOM HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003858",
    },
    {
        "school": "IPPOLITO ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003859",
    },
    {
        "school": "LIBERTY MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003860",
    },
    {
        "school": "MARTINEZ MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003861",
    },
    {
        "school": "MIDDLETON HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003862",
    },
    {
        "school": "SOUTH COUNTY CAREER CENTER",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087003863",
    },
    {
        "school": "ESE BIRTH THRU AGE 5",
        "district": "HILLSBOROUGH",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087003942",
    },
    {
        "school": "LOCKHART ELEMENTARY MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004086",
    },
    {
        "school": "HERITAGE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004087",
    },
    {
        "school": "JENNINGS MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004088",
    },
    {
        "school": "MULRENNAN MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004089",
    },
    {
        "school": "NELSON ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004090",
    },
    {
        "school": "NEWSOME HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004091",
    },
    {
        "school": "MULLER ELEMENTARY MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004092",
    },
    {
        "school": "SCHMIDT ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004093",
    },
    {
        "school": "SESSUMS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004094",
    },
    {
        "school": "MACFARLANE PARK ELEMENTARY MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004096",
    },
    {
        "school": "NORTH TAMPA EPIC 3 CENTER",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087004097",
    },
    {
        "school": "BRANDON EPIC 3 CENTER",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087004098",
    },
    {
        "school": "HORIZON CHARTER SCHOOL OF TAMPA",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004101",
    },
    {
        "school": "LEGACY PREPARATORY ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004102",
    },
    {
        "school": "WALTON ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004151",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004152",
    },
    {
        "school": "SHEEHY ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004153",
    },
    {
        "school": "HOSPITAL/HOMEBOUND/HOMEBASED PROGRAMS",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087004154",
    },
    {
        "school": "BOWERS-WHITLEY CAREER CENTER",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087004155",
    },
    {
        "school": "SHIELDS MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004156",
    },
    {
        "school": "CORR ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004157",
    },
    {
        "school": "COLLINS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004158",
    },
    {
        "school": "GIUNTA MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004162",
    },
    {
        "school": "FROST ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004163",
    },
    {
        "school": "COLUMBUS RESIDENTIAL JUVENILE FACILITY",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087004164",
    },
    {
        "school": "DAVIS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004166",
    },
    {
        "school": "TRINITY SCHOOL FOR CHILDREN",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004167",
    },
    {
        "school": "TURNER-BARTELS K-8 SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004168",
    },
    {
        "school": "SPOTO HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004169",
    },
    {
        "school": "FISHHAWK CREEK ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004170",
    },
    {
        "school": "SUMMERFIELD CROSSINGS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004875",
    },
    {
        "school": "HAMMOND ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004884",
    },
    {
        "school": "LITERACY/LEADERSHIP/TECHNOLOGY ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087005577",
    },
    {
        "school": "KIDS COMMUNITY COLLEGE RIVERVIEW SOUTH",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087005578",
    },
    {
        "school": "TRINITY ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003911",
    },
    {
        "school": "WESLEY CHAPEL ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003912",
    },
    {
        "school": "ACADEMY AT THE FARM",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003913",
    },
    {
        "school": "COUNTRYSIDE MONTESSORI ACADEMY",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003916",
    },
    {
        "school": "PINE VIEW ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153004132",
    },
    {
        "school": "LONGLEAF ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153005692",
    },
    {
        "school": "SEVEN OAKS ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153005693",
    },
    {
        "school": "PINELLAS PREPARATORY ACADEMY",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156003917",
    },
    {
        "school": "ST. PETERSBURG COLLEGIATE HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156004033",
    },
    {
        "school": "BAYSIDE HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156004035",
    },
    {
        "school": "PLATO ACADEMY CLEARWATER",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156004036",
    },
    {
        "school": "DOUGLAS L. JAMERSON JR. ELEMENTARY",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156004133",
    },
    {
        "school": "JAMES B. SANDERLIN K-8",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156004134",
    },
    {
        "school": "THURGOOD MARSHALL FUNDAMENTAL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156004135",
    },
    {
        "school": "BROOKSVILLE ELEMENTARY SCHOOL",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081000449",
    },
    {
        "school": "HERNANDO HIGH SCHOOL",
        "district": "HERNANDO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081000890",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081000894",
    },
    {
        "school": "EASTSIDE ELEMENTARY SCHOOL",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081000895",
    },
    {
        "school": "FRANK W. SPRINGSTEAD HIGH SCHOOL",
        "district": "HERNANDO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081000896",
    },
    {
        "school": "WEST HERNANDO MIDDLE SCHOOL",
        "district": "HERNANDO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081001609",
    },
    {
        "school": "FOX CHAPEL MIDDLE SCHOOL",
        "district": "HERNANDO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081002067",
    },
    {
        "school": "SUNCOAST ELEMENTARY SCHOOL",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081002250",
    },
    {
        "school": "SPRING HILL ELEMENTARY SCHOOL",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081002433",
    },
    {
        "school": "POWELL MIDDLE SCHOOL",
        "district": "HERNANDO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081002434",
    },
    {
        "school": "JOHN D. FLOYD ELEMENTARY SCHOOL",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081002503",
    },
    {
        "school": "D. S. PARROTT MIDDLE SCHOOL",
        "district": "HERNANDO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081002603",
    },
    {
        "school": "CENTRAL HIGH SCHOOL",
        "district": "HERNANDO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081002604",
    },
    {
        "school": "DELTONA ELEMENTARY SCHOOL",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081002605",
    },
    {
        "school": "PINE GROVE ELEMENTARY SCHOOL",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081002669",
    },
    {
        "school": "MOTON ELEMENTARY SCHOOL",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081002753",
    },
    {
        "school": "ENDEAVOR ACADEMY",
        "district": "HERNANDO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120081003068",
    },
    {
        "school": "CHOCACHATTI ELEMENTARY SCHOOL",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081003585",
    },
    {
        "school": "BOYETTE SPRINGS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000552",
    },
    {
        "school": "CANNELLA ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000566",
    },
    {
        "school": "COLSON ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000597",
    },
    {
        "school": "FOLSOM ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000618",
    },
    {
        "school": "HUNTER'S GREEN ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000623",
    },
    {
        "school": "LITHIA SPRINGS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000696",
    },
    {
        "school": "LOWRY ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000723",
    },
    {
        "school": "SCHWARZKOPF ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000724",
    },
    {
        "school": "ADAMS MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000909",
    },
    {
        "school": "FOREST HILLS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000910",
    },
    {
        "school": "ALEXANDER ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000911",
    },
    {
        "school": "PIERCE MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000912",
    },
    {
        "school": "BALLAST POINT ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000914",
    },
    {
        "school": "BAY CREST ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000915",
    },
    {
        "school": "JUST ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000916",
    },
    {
        "school": "STEWART MIDDLE MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000917",
    },
    {
        "school": "BRANDON HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000918",
    },
    {
        "school": "MCLANE MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000919",
    },
    {
        "school": "BROOKER ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000921",
    },
    {
        "school": "BROWARD ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000922",
    },
    {
        "school": "BRYAN ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000924",
    },
    {
        "school": "BUCHANAN MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000925",
    },
    {
        "school": "DR CARTER G WOODSON K-8 SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000928",
    },
    {
        "school": "CARROLLWOOD ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000929",
    },
    {
        "school": "CHAMBERLAIN HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000930",
    },
    {
        "school": "CHIARAMONTE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000931",
    },
    {
        "school": "CITRUS PARK ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000932",
    },
    {
        "school": "CLAIR-MEL ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000933",
    },
    {
        "school": "DOWDELL MIDDLE MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000934",
    },
    {
        "school": "CLEVELAND ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000935",
    },
    {
        "school": "COLEMAN MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000936",
    },
    {
        "school": "CORK ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000938",
    },
    {
        "school": "CRESTWOOD ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000939",
    },
    {
        "school": "DESOTO ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000941",
    },
    {
        "school": "DICKENSON ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000942",
    },
    {
        "school": "DOVER ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000943",
    },
    {
        "school": "DUNBAR ELEMENTARY MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000944",
    },
    {
        "school": "EAST BAY HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000945",
    },
    {
        "school": "EISENHOWER MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000946",
    },
    {
        "school": "EDISON ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000947",
    },
    {
        "school": "EGYPT LAKE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000948",
    },
    {
        "school": "FOSTER ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000949",
    },
    {
        "school": "SLIGH MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000950",
    },
    {
        "school": "GIBSONTON ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000953",
    },
    {
        "school": "GORRIE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000955",
    },
    {
        "school": "GRADY ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000956",
    },
    {
        "school": "GRAHAM ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000957",
    },
    {
        "school": "BELLAMY ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000958",
    },
    {
        "school": "GRECO MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000959",
    },
    {
        "school": "HILLSBOROUGH HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000960",
    },
    {
        "school": "JACKSON ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000962",
    },
    {
        "school": "KENLY ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000964",
    },
    {
        "school": "KING HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000965",
    },
    {
        "school": "KINGSWOOD ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000966",
    },
    {
        "school": "KNIGHTS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000967",
    },
    {
        "school": "LAKE MAGDALENE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000968",
    },
    {
        "school": "LANIER ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000969",
    },
    {
        "school": "MONROE MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000970",
    },
    {
        "school": "TAMPA HEIGHTS ELEMENTARY MAGNET",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000971",
    },
    {
        "school": "LETO HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000972",
    },
    {
        "school": "LIMONA ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000973",
    },
    {
        "school": "LINCOLN ELEMENTARY MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000974",
    },
    {
        "school": "LUTZ K-8 SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000976",
    },
    {
        "school": "MABRY ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000977",
    },
    {
        "school": "MADISON MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000979",
    },
    {
        "school": "MANGO ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000980",
    },
    {
        "school": "MANN MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000982",
    },
    {
        "school": "MARSHALL MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000983",
    },
    {
        "school": "MCDONALD ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000985",
    },
    {
        "school": "MENDENHALL ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000987",
    },
    {
        "school": "MILES ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000989",
    },
    {
        "school": "MITCHELL ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000990",
    },
    {
        "school": "MORGAN WOODS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000991",
    },
    {
        "school": "MORT ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000992",
    },
    {
        "school": "OAK GROVE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000993",
    },
    {
        "school": "OAK PARK ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000994",
    },
    {
        "school": "PALM RIVER ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000997",
    },
    {
        "school": "PINECREST ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000998",
    },
    {
        "school": "PLANT HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087000999",
    },
    {
        "school": "PLANT CITY HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001000",
    },
    {
        "school": "TOMLIN MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001001",
    },
    {
        "school": "POTTER ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001002",
    },
    {
        "school": "PROGRESS VILLAGE MIDDLE MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001003",
    },
    {
        "school": "RIVERVIEW ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001005",
    },
    {
        "school": "ROBINSON ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001006",
    },
    {
        "school": "ROBINSON HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001007",
    },
    {
        "school": "ROBLES ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001008",
    },
    {
        "school": "LAVOY EXCEPTIONAL CENTER",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087001010",
    },
    {
        "school": "JEFFERSON HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001011",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001012",
    },
    {
        "school": "RUSKIN ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001013",
    },
    {
        "school": "SEFFNER ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001014",
    },
    {
        "school": "SEMINOLE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001015",
    },
    {
        "school": "SHAW ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001016",
    },
    {
        "school": "SHORE ELEMENTARY MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001017",
    },
    {
        "school": "SPRINGHEAD ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001019",
    },
    {
        "school": "SULPHUR SPRINGS K-8 SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001020",
    },
    {
        "school": "TAMPA BAY BOULEVARD ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001022",
    },
    {
        "school": "TEMPLE TERRACE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001023",
    },
    {
        "school": "DOROTHY THOMAS CENTER",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087001024",
    },
    {
        "school": "THONOTOSASSA ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001025",
    },
    {
        "school": "TINKER K-8 SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001026",
    },
    {
        "school": "TOWN & COUNTRY ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001027",
    },
    {
        "school": "WEBB MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001028",
    },
    {
        "school": "TRAPNELL ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001029",
    },
    {
        "school": "TURKEY CREEK MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001030",
    },
    {
        "school": "TWIN LAKES ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001031",
    },
    {
        "school": "WESTSHORE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001033",
    },
    {
        "school": "WILLIAMS MIDDLE MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001035",
    },
    {
        "school": "WILSON MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001036",
    },
    {
        "school": "WILSON ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001037",
    },
    {
        "school": "WIMAUMA ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001038",
    },
    {
        "school": "WITTER ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001039",
    },
    {
        "school": "WOODBRIDGE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001040",
    },
    {
        "school": "YATES ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001041",
    },
    {
        "school": "YOUNG MIDDLE MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087001042",
    },
    {
        "school": "BUCKHORN ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002069",
    },
    {
        "school": "ANDERSON ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002183",
    },
    {
        "school": "APOLLO BEACH ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002184",
    },
    {
        "school": "CLAYWELL ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002187",
    },
    {
        "school": "TAMPA BAY TECH HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002325",
    },
    {
        "school": "GAITHER HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002437",
    },
    {
        "school": "LOPEZ ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002439",
    },
    {
        "school": "ARMWOOD HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002505",
    },
    {
        "school": "BURNS MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002506",
    },
    {
        "school": "ESSRIG ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002507",
    },
    {
        "school": "HILL MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002508",
    },
    {
        "school": "LEWIS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002509",
    },
    {
        "school": "NORTHWEST ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002510",
    },
    {
        "school": "SIMMONS EXCEPTIONAL CENTER",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087002511",
    },
    {
        "school": "CAMINITI EXCEPTIONAL CENTER",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087002512",
    },
    {
        "school": "WEST TAMPA ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002513",
    },
    {
        "school": "ALAFIA ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002561",
    },
    {
        "school": "BLOOMINGDALE HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002562",
    },
    {
        "school": "MANISCALCO K-8 SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002702",
    },
    {
        "school": "TAMPA PALMS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002710",
    },
    {
        "school": "MENDEZ EXCEPTIONAL CENTER",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087002756",
    },
    {
        "school": "BING ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002826",
    },
    {
        "school": "CYPRESS CREEK ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002827",
    },
    {
        "school": "MINTZ ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002828",
    },
    {
        "school": "SUMMERFIELD ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002829",
    },
    {
        "school": "WALDEN LAKE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002830",
    },
    {
        "school": "DURANT HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087002997",
    },
    {
        "school": "BURNETT MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003071",
    },
    {
        "school": "VALRICO ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003072",
    },
    {
        "school": "CARVER EXCEPTIONAL CENTER",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087003177",
    },
    {
        "school": "BENITO MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003178",
    },
    {
        "school": "BLAKE HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003179",
    },
    {
        "school": "SICKLES HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003181",
    },
    {
        "school": "WHARTON HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003185",
    },
    {
        "school": "JAMES ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003186",
    },
    {
        "school": "CLARK ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003375",
    },
    {
        "school": "LOMAX MAGNET ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003376",
    },
    {
        "school": "ORANGE GROVE MIDDLE MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003377",
    },
    {
        "school": "RIVERVIEW HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003379",
    },
    {
        "school": "PIZZO K-8 SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003380",
    },
    {
        "school": "RODGERS MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003381",
    },
    {
        "school": "RAMPELLO K-8 MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003382",
    },
    {
        "school": "THE SPRING",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087003383",
    },
    {
        "school": "WESTCHASE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003387",
    },
    {
        "school": "HILLSBOROUGH GIRLS ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087003388",
    },
    {
        "school": "DETENTION CENTER WEST",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087003390",
    },
    {
        "school": "LES PETERS ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087003394",
    },
    {
        "school": "AMI KIDS YES",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087003397",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087003399",
    },
    {
        "school": "TERRACE COMMUNITY MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003404",
    },
    {
        "school": "WATERS CAREER CENTER",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087003586",
    },
    {
        "school": "TAMPA RESIDENTIAL FACILITY",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087003588",
    },
    {
        "school": "PEPIN ACADEMIES",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087003589",
    },
    {
        "school": "ALONSO HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003711",
    },
    {
        "school": "SIMMONS CAREER CENTER",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087003712",
    },
    {
        "school": "CHILES ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003713",
    },
    {
        "school": "MCKITRICK ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003714",
    },
    {
        "school": "SYMMES ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087003715",
    },
    {
        "school": "FALKENBURG ROAD JAIL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087003716",
    },
    {
        "school": "BEVIS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004350",
    },
    {
        "school": "DAVIDSEN MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004351",
    },
    {
        "school": "MEMORIAL MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004352",
    },
    {
        "school": "PRIDE ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004353",
    },
    {
        "school": "RANDALL MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004354",
    },
    {
        "school": "VILLAGE OF EXCELLENCE ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004356",
    },
    {
        "school": "LEARNING GATE COMMUNITY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004358",
    },
    {
        "school": "RCMA WIMAUMA ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087004359",
    },
    {
        "school": "RODNEY B. COX ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001562",
    },
    {
        "school": "PASCO HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001563",
    },
    {
        "school": "PASCO ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001564",
    },
    {
        "school": "PASCO MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001565",
    },
    {
        "school": "WEST ZEPHYRHILLS ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001567",
    },
    {
        "school": "RAYMOND B. STEWART MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001568",
    },
    {
        "school": "ZEPHYRHILLS HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001569",
    },
    {
        "school": "WOODLAND ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001570",
    },
    {
        "school": "CONNERTON ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001572",
    },
    {
        "school": "MITTYE P. LOCKE ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001573",
    },
    {
        "school": "GULF MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001574",
    },
    {
        "school": "RICHEY ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001575",
    },
    {
        "school": "HUDSON ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001576",
    },
    {
        "school": "LACOOCHEE ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001577",
    },
    {
        "school": "GULF HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001578",
    },
    {
        "school": "SCHRADER ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001579",
    },
    {
        "school": "BAYONET POINT MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001580",
    },
    {
        "school": "NORTHWEST ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001582",
    },
    {
        "school": "HUDSON HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001583",
    },
    {
        "school": "CYPRESS ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001585",
    },
    {
        "school": "LAND O' LAKES HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001586",
    },
    {
        "school": "ANCLOTE ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001587",
    },
    {
        "school": "GULFSIDE ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001588",
    },
    {
        "school": "PINE VIEW MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153001589",
    },
    {
        "school": "SCHWETTMAN EDUCATION CENTER",
        "district": "PASCO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120153002237",
    },
    {
        "school": "CALUSA ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002239",
    },
    {
        "school": "MOON LAKE ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002240",
    },
    {
        "school": "SAN ANTONIO ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002241",
    },
    {
        "school": "HUDSON MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002391",
    },
    {
        "school": "LAKE MYRTLE ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002451",
    },
    {
        "school": "FRED K. MARCHMAN TECHNICAL COLLEGE",
        "district": "PASCO",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120153002452",
    },
    {
        "school": "CENTENNIAL ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002580",
    },
    {
        "school": "SEVEN SPRINGS ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002632",
    },
    {
        "school": "DEER PARK ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002678",
    },
    {
        "school": "DR. MARY GIELLA ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002787",
    },
    {
        "school": "FOX HOLLOW ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002880",
    },
    {
        "school": "THOMAS E. WEIGHTMAN MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002881",
    },
    {
        "school": "RIVER RIDGE HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002882",
    },
    {
        "school": "COTEE RIVER ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153002937",
    },
    {
        "school": "DENHAM OAKS ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003013",
    },
    {
        "school": "SEVEN SPRINGS MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003106",
    },
    {
        "school": "JAMES IRVIN EDUCATION CENTER",
        "district": "PASCO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120153003107",
    },
    {
        "school": "CHESTER W. TAYLOR JR. ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003251",
    },
    {
        "school": "SAND PINE ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003476",
    },
    {
        "school": "WESLEY CHAPEL HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003650",
    },
    {
        "school": "JAMES M. MARLOWE ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003651",
    },
    {
        "school": "CHASCO MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003775",
    },
    {
        "school": "CENTENNIAL MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153003776",
    },
    {
        "school": "SHERIFF'S DETENTION CENTER",
        "district": "PASCO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120153003778",
    },
    {
        "school": "JUVENILE DETENTION CENTER",
        "district": "PASCO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120153003779",
    },
    {
        "school": "CHASCO ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153004421",
    },
    {
        "school": "SUNRAY ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153004422",
    },
    {
        "school": "JAMES W. MITCHELL HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153004423",
    },
    {
        "school": "CENTRAL PASCO GIRLS ACADEMY",
        "district": "PASCO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120153004424",
    },
    {
        "school": "DAYSPRING ACADEMY",
        "district": "PASCO",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153004426",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "PASCO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120153004427",
    },
    {
        "school": "MARJORIE KINNAN RAWLINGS ELEM",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156000984",
    },
    {
        "school": "ANONA ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001592",
    },
    {
        "school": "AZALEA ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001593",
    },
    {
        "school": "AZALEA MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001594",
    },
    {
        "school": "BARDMOOR ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001595",
    },
    {
        "school": "LARGO MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001596",
    },
    {
        "school": "BAUDER ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001597",
    },
    {
        "school": "BAY POINT ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001598",
    },
    {
        "school": "BAY POINT MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001599",
    },
    {
        "school": "BAY VISTA FUNDAMENTAL ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001600",
    },
    {
        "school": "BEAR CREEK ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001601",
    },
    {
        "school": "BELCHER ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001602",
    },
    {
        "school": "BELLEAIR ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001603",
    },
    {
        "school": "BLANTON ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001604",
    },
    {
        "school": "BOCA CIEGA HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001605",
    },
    {
        "school": "CAMPBELL PARK ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001606",
    },
    {
        "school": "CLEARWATER HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001610",
    },
    {
        "school": "CROSS BAYOU ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001612",
    },
    {
        "school": "DIXIE M. HOLLINS HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001614",
    },
    {
        "school": "DUNEDIN ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001615",
    },
    {
        "school": "DUNEDIN HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001616",
    },
    {
        "school": "DUNEDIN HIGHLAND MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001617",
    },
    {
        "school": "EISENHOWER ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001618",
    },
    {
        "school": "FAIRMOUNT PARK ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001619",
    },
    {
        "school": "FITZGERALD MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001620",
    },
    {
        "school": "FUGUITT ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001621",
    },
    {
        "school": "LYNCH ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001622",
    },
    {
        "school": "PERKINS ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001623",
    },
    {
        "school": "GIBBS HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001624",
    },
    {
        "school": "GULFPORT MONTESSORI ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001626",
    },
    {
        "school": "HIGH POINT ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001627",
    },
    {
        "school": "LAKEVIEW FUNDAMENTAL ELEMENTARY",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001631",
    },
    {
        "school": "LAKEWOOD ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001632",
    },
    {
        "school": "LAKEWOOD HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001633",
    },
    {
        "school": "LARGO HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001635",
    },
    {
        "school": "LEALMAN AVENUE ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001636",
    },
    {
        "school": "LEALMAN INNOVATION ACADEMY",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156001637",
    },
    {
        "school": "MADEIRA BEACH FUNDAMENTAL K-8",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001640",
    },
    {
        "school": "MAXIMO ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001641",
    },
    {
        "school": "MEADOWLAWN MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001642",
    },
    {
        "school": "MELROSE ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001643",
    },
    {
        "school": "MILDRED HELMS ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001644",
    },
    {
        "school": "MOUNT VERNON ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001645",
    },
    {
        "school": "NINA HARRIS ESE CENTER",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120156001646",
    },
    {
        "school": "NORTHEAST HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001647",
    },
    {
        "school": "NORTH SHORE ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001648",
    },
    {
        "school": "NORTHWEST ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001651",
    },
    {
        "school": "OAK GROVE MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001653",
    },
    {
        "school": "OAKHURST ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001654",
    },
    {
        "school": "OLDSMAR ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001655",
    },
    {
        "school": "ORANGE GROVE ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001656",
    },
    {
        "school": "OZONA ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001657",
    },
    {
        "school": "CURTIS FUNDAMENTAL ELEMENTARY",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001658",
    },
    {
        "school": "RICHARD L. SANDERS SCHOOL",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120156001660",
    },
    {
        "school": "PASADENA FUNDAMENTAL ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001661",
    },
    {
        "school": "CLEARWATER INTERMEDIATE",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156001662",
    },
    {
        "school": "PINELLAS CENTRAL ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001663",
    },
    {
        "school": "RICHARD O JACOBSON TECHNICAL HIGH SCHOOL AT SEMINOLE",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001664",
    },
    {
        "school": "PINELLAS PARK ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001665",
    },
    {
        "school": "PINELLAS PARK MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001666",
    },
    {
        "school": "PINELLAS PARK HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001667",
    },
    {
        "school": "PLUMB ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001668",
    },
    {
        "school": "PONCE DE LEON ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001669",
    },
    {
        "school": "RIDGECREST ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001670",
    },
    {
        "school": "SAFETY HARBOR ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001673",
    },
    {
        "school": "SAFETY HARBOR MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001674",
    },
    {
        "school": "ST. PETERSBURG HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001675",
    },
    {
        "school": "SAN JOSE ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001677",
    },
    {
        "school": "SANDY LANE ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001678",
    },
    {
        "school": "SEMINOLE ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001679",
    },
    {
        "school": "SEMINOLE HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001680",
    },
    {
        "school": "SEMINOLE MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001681",
    },
    {
        "school": "SEVENTY-FOURTH ST. ELEMENTARY",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001682",
    },
    {
        "school": "SHORE ACRES ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001683",
    },
    {
        "school": "JOHN HOPKINS MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001684",
    },
    {
        "school": "SKYCREST ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001685",
    },
    {
        "school": "SKYVIEW ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001686",
    },
    {
        "school": "STARKEY ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001689",
    },
    {
        "school": "SUNSET HILLS ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001690",
    },
    {
        "school": "TARPON SPRINGS ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001691",
    },
    {
        "school": "TARPON SPRINGS HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001693",
    },
    {
        "school": "NEW HEIGHTS ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001695",
    },
    {
        "school": "TYRONE MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001696",
    },
    {
        "school": "TARPON SPRINGS FUNDAMENTAL ELE",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001697",
    },
    {
        "school": "WALSINGHAM ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001698",
    },
    {
        "school": "WESTGATE ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001699",
    },
    {
        "school": "WOODLAWN ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001700",
    },
    {
        "school": "JOSEPH L. CARWISE MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156001978",
    },
    {
        "school": "COUNTRYSIDE HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002242",
    },
    {
        "school": "LEILA DAVIS ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002244",
    },
    {
        "school": "PAUL B. STEPHENS ESE CENTER",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120156002246",
    },
    {
        "school": "CURLEW CREEK ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002393",
    },
    {
        "school": "OSCEOLA FUNDAMENTAL HIGH",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002397",
    },
    {
        "school": "TARPON SPRINGS MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002400",
    },
    {
        "school": "PALM HARBOR MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002453",
    },
    {
        "school": "OSCEOLA MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002478",
    },
    {
        "school": "CYPRESS WOODS ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002479",
    },
    {
        "school": "SUTHERLAND ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002528",
    },
    {
        "school": "SOUTHERN OAK ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002582",
    },
    {
        "school": "LAKE ST. GEORGE ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002633",
    },
    {
        "school": "DISSTON ACADEMY",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156002788",
    },
    {
        "school": "GARRISON-JONES ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002789",
    },
    {
        "school": "CALVIN A. HUNSINGER SCHOOL",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120156002791",
    },
    {
        "school": "ESE COUNTYWIDE",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120156002883",
    },
    {
        "school": "HIGHLAND LAKES ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002884",
    },
    {
        "school": "SAWGRASS LAKE ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002886",
    },
    {
        "school": "DROPOUT PREVENTION SCHOOL",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156002889",
    },
    {
        "school": "HOSPITAL/HOMEBOUND",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120156002890",
    },
    {
        "school": "FOREST LAKES ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002938",
    },
    {
        "school": "FRONTIER ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156002939",
    },
    {
        "school": "PALM HARBOR UNIVERSITY HIGH",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156003014",
    },
    {
        "school": "CLEARWATER FUNDAMENTAL MIDDLE SCHOOL",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156003108",
    },
    {
        "school": "EAST LAKE HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156003110",
    },
    {
        "school": "BROOKER CREEK ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156003252",
    },
    {
        "school": "JOHN M. SEXTON ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156003253",
    },
    {
        "school": "MCMULLEN-BOOTH ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156003254",
    },
    {
        "school": "ACADEMIE DA VINCI CHARTER SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156003255",
    },
    {
        "school": "CHARLES BRITT ACADEMY",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156003480",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156003486",
    },
    {
        "school": "PINELLAS JUVENILE DET CENTER",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156003488",
    },
    {
        "school": "CHI CHI RODRIQUEZ ACADEMY",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156003780",
    },
    {
        "school": "PINELLAS SECONDARY SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156004431",
    },
    {
        "school": "ATHENIAN ACADEMY",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156004433",
    },
    {
        "school": "BUSHNELL ELEMENTARY SCHOOL",
        "district": "SUMTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120180001935",
    },
    {
        "school": "SOUTH SUMTER MIDDLE SCHOOL",
        "district": "SUMTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120180001936",
    },
    {
        "school": "WEBSTER ELEMENTARY SCHOOL",
        "district": "SUMTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120180001937",
    },
    {
        "school": "WILDWOOD ELEMENTARY SCHOOL",
        "district": "SUMTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120180001940",
    },
    {
        "school": "WILDWOOD MIDDLE/ HIGH SCHOOL",
        "district": "SUMTER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120180001941",
    },
    {
        "school": "SOUTH SUMTER HIGH SCHOOL",
        "district": "SUMTER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120180001942",
    },
    {
        "school": "LAKE PANASOFFKEE ELEMENTARY SCHOOL",
        "district": "SUMTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120180002639",
    },
    {
        "school": "VILLAGES CHARTER SCHOOL",
        "district": "SUMTER",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120180004452",
    },
    {
        "school": "SUMTER PREP ACADEMY",
        "district": "SUMTER",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120180004453",
    },
    {
        "school": "LIBERTY MAGNET SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093003866",
    },
    {
        "school": "WABASSO SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120093002073",
    },
    {
        "school": "VERO BEACH HIGH SCHOOL",
        "district": "INDIAN RIVER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093001052",
    },
    {
        "school": "ROSEWOOD MAGNET SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093001053",
    },
    {
        "school": "OSCEOLA MAGNET SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093001054",
    },
    {
        "school": "BEACHLAND ELEMENTARY SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093001055",
    },
    {
        "school": "FELLSMERE ELEMENTARY SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093001058",
    },
    {
        "school": "PELICAN ISLAND ELEMENTARY SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093001059",
    },
    {
        "school": "CITRUS ELEMENTARY SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093001061",
    },
    {
        "school": "DODGERTOWN ELEMENTARY SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093001062",
    },
    {
        "school": "VERO BEACH ELEMENTARY SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093001063",
    },
    {
        "school": "SEBASTIAN RIVER MIDDLE SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093001064",
    },
    {
        "school": "GIFFORD MIDDLE SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093002193",
    },
    {
        "school": "SEBASTIAN RIVER HIGH SCHOOL",
        "district": "INDIAN RIVER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093002283",
    },
    {
        "school": "SEBASTIAN ELEMENTARY SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093002470",
    },
    {
        "school": "GLENDALE ELEMENTARY SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093002563",
    },
    {
        "school": "INDIAN RIVER ACADEMY",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093002564",
    },
    {
        "school": "EXCEPTIONAL STUDENT EDUCATION",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120093002831",
    },
    {
        "school": "OSLO MIDDLE SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093002998",
    },
    {
        "school": "ALTERNATIVE CENTER FOR EDUCATION",
        "district": "INDIAN RIVER",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120093003190",
    },
    {
        "school": "INDIAN RIVER CHARTER HIGH SCHOOL",
        "district": "INDIAN RIVER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093003408",
    },
    {
        "school": "ST. PETER'S ACADEMY",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093003409",
    },
    {
        "school": "NORTH COUNTY CHARTER SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093003410",
    },
    {
        "school": "SEBASTIAN CHARTER JUNIOR HIGH SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093004361",
    },
    {
        "school": "HARDEE SENIOR HIGH SCHOOL",
        "district": "HARDEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120075000877",
    },
    {
        "school": "HARDEE JUNIOR HIGH SCHOOL",
        "district": "HARDEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120075000878",
    },
    {
        "school": "BOWLING GREEN ELEMENTARY SCHOOL",
        "district": "HARDEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120075000879",
    },
    {
        "school": "ZOLFO SPRINGS ELEMENTARY SCHOOL",
        "district": "HARDEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120075000880",
    },
    {
        "school": "WAUCHULA ELEMENTARY SCHOOL",
        "district": "HARDEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120075000881",
    },
    {
        "school": "NORTH WAUCHULA ELEMENTARY SCHOOL",
        "district": "HARDEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120075000882",
    },
    {
        "school": "PIONEER CAREER ACADEMY",
        "district": "HARDEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120075002245",
    },
    {
        "school": "Jefferson Academy",
        "district": "Jefferson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130303003671",
    },
    {
        "school": "Banks County Elementary School",
        "district": "Banks County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024003545",
    },
    {
        "school": "Price Academy",
        "district": "Bibb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042003621",
    },
    {
        "school": "UHS of Savannah Coastal Harbor Treatment Center",
        "district": "Savannah-Chatham County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102003610",
    },
    {
        "school": "Unidos Dual Language School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123003687",
    },
    {
        "school": "Lovinggood Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129003622",
    },
    {
        "school": "McClure Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129003632",
    },
    {
        "school": "Hillgrove High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129003649",
    },
    {
        "school": "Devereux Ackerman Academy",
        "district": "Cobb County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129003679",
    },
    {
        "school": "George W. Hartmann Center",
        "district": "Marietta City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351003700",
    },
    {
        "school": "Twiggs Middle School",
        "district": "Twiggs County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130522003611",
    },
    {
        "school": "Welch Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150003637",
    },
    {
        "school": "UHS of Laurel Heights",
        "district": "DeKalb County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003613",
    },
    {
        "school": "The Champion Middle Theme School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003643",
    },
    {
        "school": "Dekalb Early College Academy",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003708",
    },
    {
        "school": "Brighten Academy",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186003670",
    },
    {
        "school": "Youth Villages at Inner Harbour",
        "district": "Douglas County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186003689",
    },
    {
        "school": "Department of Corrections",
        "district": "Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002503648",
    },
    {
        "school": "Department of Human Resources",
        "district": "Department of Human Resources",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002703682",
    },
    {
        "school": "Hillside Conant School",
        "district": "Atlanta Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003660",
    },
    {
        "school": "Georgia Baptist Children's Home and Family Ministries",
        "district": "Fulton County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003651",
    },
    {
        "school": "Morningstar Treatment Services- Inc. Youth Estate",
        "district": "Glynn County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240003697",
    },
    {
        "school": "Gwinnett Intervention Education Center (GIVE) West",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003690",
    },
    {
        "school": "Commerce Primary",
        "district": "Commerce City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130144003617",
    },
    {
        "school": "Good Sheperd Therapeutic Center",
        "district": "Meriwether County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130363003633",
    },
    {
        "school": "Muscogee Youth Development Center",
        "district": "Department of Juvenile Justice",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603650",
    },
    {
        "school": "North Columbus Elementary",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387003656",
    },
    {
        "school": "Harpst Academy",
        "district": "Polk County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130420003614",
    },
    {
        "school": "Lighthouse Care Center of Augusta",
        "district": "Richmond County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438003486",
    },
    {
        "school": "Deer Chase Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438003662",
    },
    {
        "school": "Diamond Lakes Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438003701",
    },
    {
        "school": "Georgia Center",
        "district": "Taylor County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130480003673",
    },
    {
        "school": "Bradfield Center - Ault Academy",
        "district": "Troup County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000103620",
    },
    {
        "school": "Jeffersonville Elementary",
        "district": "Twiggs County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130522003707",
    },
    {
        "school": "Beaverdale Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570003684",
    },
    {
        "school": "Berrien Academy Performance Learning Center",
        "district": "Berrien County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130039003523",
    },
    {
        "school": "Clay County Middle School",
        "district": "Clay County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130120002833",
    },
    {
        "school": "Clay County Elementary",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130120002834",
    },
    {
        "school": "Cook Elementary School",
        "district": "Cook County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130147003327",
    },
    {
        "school": "Dodge County High School",
        "district": "Dodge County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130177003340",
    },
    {
        "school": "Dooly County Elementary School",
        "district": "Dooly County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130180002862",
    },
    {
        "school": "Elbert County Middle School",
        "district": "Elbert County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130201002871",
    },
    {
        "school": "Franklin County Middle School",
        "district": "Franklin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130225003358",
    },
    {
        "school": "Carnesville Elementary Intermediate School",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130225003359",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Gilmer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130234002565",
    },
    {
        "school": "Clear Creek Middle School",
        "district": "Gilmer County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130234003371",
    },
    {
        "school": "North Hart Elementary School",
        "district": "Hart County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130273002572",
    },
    {
        "school": "South Hart Elementary School",
        "district": "Hart County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130273002573",
    },
    {
        "school": "East Jackson Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130294002924",
    },
    {
        "school": "East Jackson Comprehensive High School",
        "district": "Jackson County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130294003421",
    },
    {
        "school": "Blackburn Elementary School",
        "district": "Lumpkin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130342002581",
    },
    {
        "school": "Montgomery County Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130375003432",
    },
    {
        "school": "Taylor County Primary School",
        "district": "Taylor County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130480003451",
    },
    {
        "school": "Telfair County Elementary",
        "district": "Telfair County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130483002986",
    },
    {
        "school": "Toombs County Middle School",
        "district": "Toombs County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130504002993",
    },
    {
        "school": "Lyons Primary School",
        "district": "Toombs County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130504002994",
    },
    {
        "school": "Lyons Upper Elementary",
        "district": "Toombs County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130504002995",
    },
    {
        "school": "Towns County Elementary School",
        "district": "Towns County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130507002997",
    },
    {
        "school": "Towns County Middle School",
        "district": "Towns County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130507002998",
    },
    {
        "school": "Towns County High School",
        "district": "Towns County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130507002999",
    },
    {
        "school": "Union County Elementary School",
        "district": "Union County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130525002605",
    },
    {
        "school": "Union County Middle School",
        "district": "Union County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130525003456",
    },
    {
        "school": "Warren County Middle School",
        "district": "Warren County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130546003462",
    },
    {
        "school": "Webster County Elementary/Middle School",
        "district": "Webster County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130558003015",
    },
    {
        "school": "Mount Yonah Elementary School",
        "district": "White County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130567003018",
    },
    {
        "school": "Appling County Primary School",
        "district": "Appling County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130006000006",
    },
    {
        "school": "Appling County Elementary School",
        "district": "Appling County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130006000007",
    },
    {
        "school": "Fourth District Elementary School",
        "district": "Appling County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130006000008",
    },
    {
        "school": "Appling County Middle School",
        "district": "Appling County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130006000009",
    },
    {
        "school": "Appling County High School",
        "district": "Appling County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130006000010",
    },
    {
        "school": "Altamaha Elementary School",
        "district": "Appling County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130006000011",
    },
    {
        "school": "Bacon County Elementary School",
        "district": "Bacon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130015000151",
    },
    {
        "school": "Bacon County Primary School",
        "district": "Bacon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130015000153",
    },
    {
        "school": "Bacon County Middle School",
        "district": "Bacon County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130015002349",
    },
    {
        "school": "Bacon County High School",
        "district": "Bacon County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130015002357",
    },
    {
        "school": "Banks County High School",
        "district": "Banks County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024000169",
    },
    {
        "school": "Banks County Primary School",
        "district": "Banks County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024000170",
    },
    {
        "school": "Banks County Middle School",
        "district": "Banks County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024002015",
    },
    {
        "school": "Berrien High School",
        "district": "Berrien County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130039000192",
    },
    {
        "school": "Berrien Primary School",
        "district": "Berrien County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130039000195",
    },
    {
        "school": "Berrien Middle School",
        "district": "Berrien County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130039000228",
    },
    {
        "school": "Berrien Elementary School",
        "district": "Berrien County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130039000787",
    },
    {
        "school": "Bleckley County High School",
        "district": "Bleckley County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130044000253",
    },
    {
        "school": "Bleckley Middle School",
        "district": "Bleckley County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130044000254",
    },
    {
        "school": "Bleckley County Primary School",
        "district": "Bleckley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130044000256",
    },
    {
        "school": "Bleckley County Elementary School",
        "district": "Bleckley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130044001920",
    },
    {
        "school": "Calhoun County Elementary School",
        "district": "Calhoun County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130075000311",
    },
    {
        "school": "Metter Elementary School",
        "district": "Candler County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130081000316",
    },
    {
        "school": "Metter High School",
        "district": "Candler County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130081000317",
    },
    {
        "school": "Metter Middle School",
        "district": "Candler County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130081000318",
    },
    {
        "school": "Charlton County High School",
        "district": "Charlton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130099000358",
    },
    {
        "school": "St. George Elementary School",
        "district": "Charlton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130099000359",
    },
    {
        "school": "Folkston Elementary School",
        "district": "Charlton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130099002241",
    },
    {
        "school": "Clinch County High School",
        "district": "Clinch County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130126000504",
    },
    {
        "school": "Clinch County Middle School",
        "district": "Clinch County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130126002106",
    },
    {
        "school": "Clinch County Elementary School",
        "district": "Clinch County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130126002362",
    },
    {
        "school": "Cook County Middle School",
        "district": "Cook County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130147000628",
    },
    {
        "school": "Cook Primary School",
        "district": "Cook County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130147001107",
    },
    {
        "school": "Dodge County Middle School",
        "district": "Dodge County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130177000803",
    },
    {
        "school": "South Dodge Elementary School",
        "district": "Dodge County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130177002113",
    },
    {
        "school": "North Dodge Elementary School",
        "district": "Dodge County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130177002114",
    },
    {
        "school": "Dooly County High School",
        "district": "Dooly County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130180001889",
    },
    {
        "school": "Dooly County Middle School",
        "district": "Dooly County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130180002075",
    },
    {
        "school": "Early County Elementary School",
        "district": "Early County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130192000252",
    },
    {
        "school": "Early County High School",
        "district": "Early County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130192000884",
    },
    {
        "school": "Early County Middle School",
        "district": "Early County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130192002163",
    },
    {
        "school": "Elbert County High School",
        "district": "Elbert County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130201000894",
    },
    {
        "school": "Emanuel County Institute",
        "district": "Emanuel County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130204000905",
    },
    {
        "school": "Swainsboro Primary School",
        "district": "Emanuel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130204000906",
    },
    {
        "school": "Twin City Elementary School",
        "district": "Emanuel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130204000908",
    },
    {
        "school": "Swainsboro High School",
        "district": "Emanuel County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130204002033",
    },
    {
        "school": "Swainsboro Middle School",
        "district": "Emanuel County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130204002034",
    },
    {
        "school": "Swainsboro Elementary School",
        "district": "Emanuel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130204002164",
    },
    {
        "school": "Claxton High School",
        "district": "Evans County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130207000909",
    },
    {
        "school": "Claxton Middle School",
        "district": "Evans County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130207000911",
    },
    {
        "school": "Claxton Elementary School",
        "district": "Evans County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130207002257",
    },
    {
        "school": "Fannin County Middle School",
        "district": "Fannin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130210000067",
    },
    {
        "school": "West Fannin Elementary School",
        "district": "Fannin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130210000156",
    },
    {
        "school": "East Fannin Elementary School",
        "district": "Fannin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130210000255",
    },
    {
        "school": "Fannin County High School",
        "district": "Fannin County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130210000912",
    },
    {
        "school": "Blue Ridge Elementary School",
        "district": "Fannin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130210000916",
    },
    {
        "school": "Franklin County High School",
        "district": "Franklin County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130225000961",
    },
    {
        "school": "Carnesville Elementary Primary School",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130225000962",
    },
    {
        "school": "Royston Elementary School",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130225000963",
    },
    {
        "school": "Lavonia Elementary School",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130225000964",
    },
    {
        "school": "Gilmer High School",
        "district": "Gilmer County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130234001053",
    },
    {
        "school": "Ellijay Elementary School",
        "district": "Gilmer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130234001054",
    },
    {
        "school": "Glascock County Middle/High School",
        "district": "Glascock County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130237001055",
    },
    {
        "school": "Shiver Elementary School",
        "district": "Grady County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130246001079",
    },
    {
        "school": "Southside Elementary School",
        "district": "Grady County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130246001080",
    },
    {
        "school": "Northside Elementary School",
        "district": "Grady County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130246001081",
    },
    {
        "school": "Whigham Elementary School",
        "district": "Grady County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130246001082",
    },
    {
        "school": "Cairo High School",
        "district": "Grady County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130246001083",
    },
    {
        "school": "Washington Middle School",
        "district": "Grady County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130246001084",
    },
    {
        "school": "Eastside Elementary School",
        "district": "Grady County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130246001936",
    },
    {
        "school": "Anita White Carson Middle School",
        "district": "Greene County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130249002383",
    },
    {
        "school": "Greene County Primary School",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130249002384",
    },
    {
        "school": "Greene County High School",
        "district": "Greene County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130249002386",
    },
    {
        "school": "Hart County High School",
        "district": "Hart County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130273001193",
    },
    {
        "school": "Hartwell Elementary School",
        "district": "Hart County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130273001197",
    },
    {
        "school": "Hart County Middle School",
        "district": "Hart County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130273002127",
    },
    {
        "school": "Commerce Elementary School",
        "district": "Commerce City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130144000621",
    },
    {
        "school": "Commerce High School",
        "district": "Commerce City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130144000622",
    },
    {
        "school": "Commerce Middle School",
        "district": "Commerce City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130144000623",
    },
    {
        "school": "South Jackson Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130294001251",
    },
    {
        "school": "North Jackson Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130294001252",
    },
    {
        "school": "Maysville Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130294001253",
    },
    {
        "school": "East Jackson Middle School",
        "district": "Jackson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130294001683",
    },
    {
        "school": "West Jackson Middle School",
        "district": "Jackson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130294001696",
    },
    {
        "school": "Jackson County Comprehensive High School",
        "district": "Jackson County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130294002134",
    },
    {
        "school": "West Jackson Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130294002499",
    },
    {
        "school": "Jefferson High School",
        "district": "Jefferson City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130303001260",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Jefferson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130303001261",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Jefferson City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130303002346",
    },
    {
        "school": "Jeff Davis Middle School",
        "district": "Jeff Davis County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130300001256",
    },
    {
        "school": "Jeff Davis Elementary School",
        "district": "Jeff Davis County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130300001257",
    },
    {
        "school": "Jeff Davis Primary School",
        "district": "Jeff Davis County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130300001258",
    },
    {
        "school": "Jeff Davis High School",
        "district": "Jeff Davis County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130300001259",
    },
    {
        "school": "Carver Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130306001263",
    },
    {
        "school": "Louisville Academy",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130306001264",
    },
    {
        "school": "Wrens Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130306001267",
    },
    {
        "school": "Jefferson County High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130306001291",
    },
    {
        "school": "Jenkins County High School",
        "district": "Jenkins County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130309001270",
    },
    {
        "school": "Jenkins County Elementary School",
        "district": "Jenkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130309001271",
    },
    {
        "school": "Jenkins County Middle School",
        "district": "Jenkins County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130309002398",
    },
    {
        "school": "Lincoln County Elementary School",
        "district": "Lincoln County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130333001308",
    },
    {
        "school": "Lincoln County Middle School",
        "district": "Lincoln County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130333002407",
    },
    {
        "school": "Lincoln County High School",
        "district": "Lincoln County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130333002408",
    },
    {
        "school": "Lumpkin County Middle School",
        "district": "Lumpkin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130342001319",
    },
    {
        "school": "Lumpkin County Elementary School",
        "district": "Lumpkin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130342001321",
    },
    {
        "school": "Long Branch Elementary School",
        "district": "Lumpkin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130342002139",
    },
    {
        "school": "Lumpkin County High School",
        "district": "Lumpkin County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130342002505",
    },
    {
        "school": "Macon County High School",
        "district": "Macon County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130345001322",
    },
    {
        "school": "Macon County Middle School",
        "district": "Macon County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130345001329",
    },
    {
        "school": "Macon County Elementary School",
        "district": "Macon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130345002218",
    },
    {
        "school": "Miller County Elementary School",
        "district": "Miller County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130366001368",
    },
    {
        "school": "Miller County Middle School",
        "district": "Miller County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130366002414",
    },
    {
        "school": "Miller County High School",
        "district": "Miller County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130366002415",
    },
    {
        "school": "Mitchell County Middle School",
        "district": "Mitchell County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130369001744",
    },
    {
        "school": "Mitchell County High School",
        "district": "Mitchell County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130369001912",
    },
    {
        "school": "Mitchell County Primary School",
        "district": "Mitchell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130369002220",
    },
    {
        "school": "Pelham Elementary School",
        "district": "Pelham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130408001485",
    },
    {
        "school": "Pelham High School",
        "district": "Pelham City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130408002461",
    },
    {
        "school": "Pelham City Middle School",
        "district": "Pelham City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130408002462",
    },
    {
        "school": "Montgomery County Middle School",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130375002417",
    },
    {
        "school": "Montgomery County High School",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130375002418",
    },
    {
        "school": "Morgan County High School",
        "district": "Morgan County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130378001378",
    },
    {
        "school": "Morgan County Middle School",
        "district": "Morgan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130378001379",
    },
    {
        "school": "Morgan County Primary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130378001380",
    },
    {
        "school": "Morgan County Elementary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130378002141",
    },
    {
        "school": "Pulaski County Middle School",
        "district": "Pulaski County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130422001045",
    },
    {
        "school": "Pulaski County Elementary School",
        "district": "Pulaski County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130422001513",
    },
    {
        "school": "Hawkinsville High School",
        "district": "Pulaski County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130422001514",
    },
    {
        "school": "Quitman County Elementary",
        "district": "Quitman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130429001518",
    },
    {
        "school": "Rabun County Elementary School",
        "district": "Rabun County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130432001519",
    },
    {
        "school": "Rabun County High School",
        "district": "Rabun County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130432001520",
    },
    {
        "school": "Rabun County Middle School",
        "district": "Rabun County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130432002425",
    },
    {
        "school": "Randolph County Elementary School",
        "district": "Randolph County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130435001524",
    },
    {
        "school": "Randolph Clay Middle School",
        "district": "Randolph County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130435002426",
    },
    {
        "school": "Randolph Clay High School",
        "district": "Randolph County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130435002427",
    },
    {
        "school": "Screven County High School",
        "district": "Screven County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130450001611",
    },
    {
        "school": "Screven County Elementary School",
        "district": "Screven County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130450002145",
    },
    {
        "school": "Screven County Middle School",
        "district": "Screven County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130450002231",
    },
    {
        "school": "Seminole County Middle/High School",
        "district": "Seminole County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130453001391",
    },
    {
        "school": "Seminole County Elementary School",
        "district": "Seminole County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130453001392",
    },
    {
        "school": "Stewart County Elementary School",
        "district": "Stewart County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130459002195",
    },
    {
        "school": "Stewart County Middle School",
        "district": "Stewart County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130459002431",
    },
    {
        "school": "Stewart County High School",
        "district": "Stewart County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130459002432",
    },
    {
        "school": "Central Elementary/High School",
        "district": "Talbot County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130465001637",
    },
    {
        "school": "Taliaferro County School",
        "district": "Taliaferro County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130468002514",
    },
    {
        "school": "Tattnall County High School",
        "district": "Tattnall County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130477000780",
    },
    {
        "school": "North Tattnall Middle School",
        "district": "Tattnall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130477002433",
    },
    {
        "school": "South Tattnall Middle School",
        "district": "Tattnall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130477002434",
    },
    {
        "school": "Collins Elementary School",
        "district": "Tattnall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130477002435",
    },
    {
        "school": "Glennville Elementary School",
        "district": "Tattnall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130477002437",
    },
    {
        "school": "Reidsville Elementary School",
        "district": "Tattnall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130477002438",
    },
    {
        "school": "Taylor County Upper Elementary",
        "district": "Taylor County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130480001649",
    },
    {
        "school": "Taylor County Middle School",
        "district": "Taylor County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130480002439",
    },
    {
        "school": "Taylor County High School",
        "district": "Taylor County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130480002440",
    },
    {
        "school": "Telfair County Middle School",
        "district": "Telfair County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130483002441",
    },
    {
        "school": "Telfair County High School",
        "district": "Telfair County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130483002442",
    },
    {
        "school": "Toombs Central Elementary School",
        "district": "Toombs County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130504001692",
    },
    {
        "school": "Toombs County High School",
        "district": "Toombs County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130504001693",
    },
    {
        "school": "Sally Dailey Meadows Elementary School",
        "district": "Vidalia City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130534001737",
    },
    {
        "school": "J. D. Dickerson Primary School",
        "district": "Vidalia City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130534001738",
    },
    {
        "school": "Vidalia Comprehensive High School",
        "district": "Vidalia City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130534001739",
    },
    {
        "school": "J. R. Trippe Middle School",
        "district": "Vidalia City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130534001740",
    },
    {
        "school": "Treutlen Middle/High School",
        "district": "Treutlen County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130510001699",
    },
    {
        "school": "Treutlen Elementary School",
        "district": "Treutlen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130510001700",
    },
    {
        "school": "Turner County Middle School",
        "district": "Turner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130519000657",
    },
    {
        "school": "Turner County High School",
        "district": "Turner County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130519001712",
    },
    {
        "school": "Turner County Elementary School",
        "district": "Turner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130519001859",
    },
    {
        "school": "Union County Primary School",
        "district": "Union County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130525001719",
    },
    {
        "school": "Union County High School",
        "district": "Union County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130525001720",
    },
    {
        "school": "Woody Gap High/Elementary School",
        "district": "Union County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130525001721",
    },
    {
        "school": "Warren County High School",
        "district": "Warren County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130546001782",
    },
    {
        "school": "Freeman Elementary School",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130546001783",
    },
    {
        "school": "Ridge Road Primary School",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130549001787",
    },
    {
        "school": "Washington County High School",
        "district": "Washington County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130549001788",
    },
    {
        "school": "Ridge Road Elementary School",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130549001789",
    },
    {
        "school": "T. J. Elder Middle School",
        "district": "Washington County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130549002289",
    },
    {
        "school": "Wheeler County High School",
        "district": "Wheeler County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130564001811",
    },
    {
        "school": "Wheeler County Elementary School",
        "district": "Wheeler County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130564001812",
    },
    {
        "school": "White County Middle School",
        "district": "White County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130567001813",
    },
    {
        "school": "White County High School",
        "district": "White County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130567001870",
    },
    {
        "school": "Tesnatee Gap Elementary (Old White Co. Intermediate)",
        "district": "White County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130567002447",
    },
    {
        "school": "Jack P Nix Elementary School",
        "district": "White County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130567002448",
    },
    {
        "school": "Wilcox County Elementary School",
        "district": "Wilcox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130573001836",
    },
    {
        "school": "Wilcox County High School",
        "district": "Wilcox County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130573002232",
    },
    {
        "school": "Wilcox County Middle School",
        "district": "Wilcox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130573002451",
    },
    {
        "school": "Washington-Wilkes Primary School",
        "district": "Wilkes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130576001839",
    },
    {
        "school": "Washington-Wilkes Elementary School",
        "district": "Wilkes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130576001840",
    },
    {
        "school": "Wilkinson County High School",
        "district": "Wilkinson County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130579001841",
    },
    {
        "school": "Wilkinson County Primary School",
        "district": "Wilkinson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130579001842",
    },
    {
        "school": "Wilkinson County Middle School",
        "district": "Wilkinson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130579001843",
    },
    {
        "school": "Wilkinson County Elementary School",
        "district": "Wilkinson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130579001844",
    },
    {
        "school": "Robert A. Cross Middle Magnet",
        "district": "Dougherty County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183002546",
    },
    {
        "school": "Live Oak Elementary School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183003341",
    },
    {
        "school": "Robert H Harvey Elementary School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183003342",
    },
    {
        "school": "Radium Springs Middle School",
        "district": "Dougherty County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183003343",
    },
    {
        "school": "Lincoln Elementary Magnet School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183003344",
    },
    {
        "school": "Baker County K12 School",
        "district": "Baker County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130018001867",
    },
    {
        "school": "Terrell High School",
        "district": "Terrell County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130486001658",
    },
    {
        "school": "Cooper-Carver Elementary School",
        "district": "Terrell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130486001660",
    },
    {
        "school": "Worth County Middle School",
        "district": "Worth County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130585000733",
    },
    {
        "school": "Worth County Primary School",
        "district": "Worth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130585001409",
    },
    {
        "school": "Worth County High School",
        "district": "Worth County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130585001849",
    },
    {
        "school": "Worth County Elementary School",
        "district": "Worth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130585001854",
    },
    {
        "school": "Monroe High School",
        "district": "Dougherty County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000824",
    },
    {
        "school": "Morningside Elementary School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000829",
    },
    {
        "school": "Dougherty Comprehensive High School",
        "district": "Dougherty County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000832",
    },
    {
        "school": "Albany Middle School",
        "district": "Dougherty County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000833",
    },
    {
        "school": "West Town Elementary School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000834",
    },
    {
        "school": "Radium Springs Elementary School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000836",
    },
    {
        "school": "International Studies Elementary Charter School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000837",
    },
    {
        "school": "Westover High School",
        "district": "Dougherty County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000839",
    },
    {
        "school": "Sherwood Acres Elementary School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000840",
    },
    {
        "school": "Merry Acres Middle School",
        "district": "Dougherty County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000842",
    },
    {
        "school": "Lake Park Elementary School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000843",
    },
    {
        "school": "Turner Elementary School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000846",
    },
    {
        "school": "Northside Elementary School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183000848",
    },
    {
        "school": "Lamar Reese School of the Arts",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183002314",
    },
    {
        "school": "Alice Coachman Elementary School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183002315",
    },
    {
        "school": "Martin Luther King- Jr. Elementary School",
        "district": "Dougherty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130183002316",
    },
    {
        "school": "Lee County High School",
        "district": "Lee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130327000057",
    },
    {
        "school": "Lee County Middle School West",
        "district": "Lee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130327000146",
    },
    {
        "school": "Twin Oaks Elementary",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130327000206",
    },
    {
        "school": "Lee County Elementary School",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130327001298",
    },
    {
        "school": "Kinchafoonee Primary School",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130327001731",
    },
    {
        "school": "Lee County Primary School",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130327001982",
    },
    {
        "school": "Schley County Elementary School",
        "district": "Schley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130447002230",
    },
    {
        "school": "Schley Middle High School",
        "district": "Schley County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130447002428",
    },
    {
        "school": "Americus Sumter High School (Old Americus-Sumter HS S)",
        "district": "Sumter County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130462000001",
    },
    {
        "school": "Sumter County Intermediate School",
        "district": "Sumter County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130462000004",
    },
    {
        "school": "Americus Sumter 9th Grade Academy",
        "district": "Sumter County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130462001629",
    },
    {
        "school": "Sumter County Elementary School",
        "district": "Sumter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130462001630",
    },
    {
        "school": "Sumter County Middle School",
        "district": "Sumter County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130462002090",
    },
    {
        "school": "Sumter County Primary School",
        "district": "Sumter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130462002341",
    },
    {
        "school": "Classic City High School",
        "district": "Clarke County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117002831",
    },
    {
        "school": "Oglethorpe County Middle School",
        "district": "Oglethorpe County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130399001467",
    },
    {
        "school": "Oglethorpe County High School",
        "district": "Oglethorpe County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130399001468",
    },
    {
        "school": "Oglethorpe County Elementary School",
        "district": "Oglethorpe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130399002226",
    },
    {
        "school": "Oglethorpe County Primary School",
        "district": "Oglethorpe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130399002227",
    },
    {
        "school": "Clarke Middle School",
        "district": "Clarke County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000443",
    },
    {
        "school": "Timothy Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000444",
    },
    {
        "school": "Winterville Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000445",
    },
    {
        "school": "Barnett Shoals Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000446",
    },
    {
        "school": "Whitehead Road Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000447",
    },
    {
        "school": "Clarke Central High School",
        "district": "Clarke County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000449",
    },
    {
        "school": "Hilsman Middle School",
        "district": "Clarke County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000450",
    },
    {
        "school": "Chase Street Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000451",
    },
    {
        "school": "Alps Road Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000452",
    },
    {
        "school": "Cedar Shoals High School",
        "district": "Clarke County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000453",
    },
    {
        "school": "Oglethorpe Avenue Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000454",
    },
    {
        "school": "Gaines Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000455",
    },
    {
        "school": "Burney-Harris-Lyons Middle School",
        "district": "Clarke County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000456",
    },
    {
        "school": "Fowler Drive Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000457",
    },
    {
        "school": "Barrow Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117000458",
    },
    {
        "school": "Coile Middle School",
        "district": "Clarke County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117001106",
    },
    {
        "school": "Cleveland Road Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117002102",
    },
    {
        "school": "Howard B. Stroud Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117002103",
    },
    {
        "school": "Whit Davis Road Elementary School",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117002104",
    },
    {
        "school": "Colbert Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130348001330",
    },
    {
        "school": "Comer Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130348001331",
    },
    {
        "school": "Madison County Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130348001332",
    },
    {
        "school": "Madison County High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130348001333",
    },
    {
        "school": "Ila Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130348001334",
    },
    {
        "school": "Danielsville Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130348001335",
    },
    {
        "school": "Hull-Sanford Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130348002411",
    },
    {
        "school": "Haymon-Morris Middle School",
        "district": "Barrow County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029003285",
    },
    {
        "school": "Euharlee Elementary School",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033002464",
    },
    {
        "school": "Clear Creek Elementary School",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033003287",
    },
    {
        "school": "Macon Youth Development Campus",
        "district": "Department of Juvenile Justice",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603490",
    },
    {
        "school": "Macon Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603509",
    },
    {
        "school": "Hampton L. Daughtry Elementary School",
        "district": "Butts County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130069002819",
    },
    {
        "school": "Villa Rica Middle",
        "district": "Carroll County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084003301",
    },
    {
        "school": "Ithica Elementary",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084003302",
    },
    {
        "school": "Glanton-Hindsman Elementary",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084003303",
    },
    {
        "school": "Carrollton Upper Elementary School",
        "district": "Carrollton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130087003474",
    },
    {
        "school": "Savannah Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603513",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111002521",
    },
    {
        "school": "Creekview High School",
        "district": "Cherokee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111003308",
    },
    {
        "school": "Avery Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111003309",
    },
    {
        "school": "Freedom Middle School",
        "district": "Cherokee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111003310",
    },
    {
        "school": "Creekland Middle School",
        "district": "Cherokee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111003312",
    },
    {
        "school": "William G. Hasty- Sr. Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111003526",
    },
    {
        "school": "Martha K. Glaze Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603500",
    },
    {
        "school": "Mundy's Mill High School",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002523",
    },
    {
        "school": "Harper Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002524",
    },
    {
        "school": "Martin Luther King- Jr. Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002836",
    },
    {
        "school": "James Jackson Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002837",
    },
    {
        "school": "Thurgood Marshall Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123003316",
    },
    {
        "school": "Sequoyah Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123003317",
    },
    {
        "school": "Kemp Primary",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123003318",
    },
    {
        "school": "Rex Mill Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123003319",
    },
    {
        "school": "Marietta Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603510",
    },
    {
        "school": "Kell High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002526",
    },
    {
        "school": "Kemp Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002527",
    },
    {
        "school": "Bullard Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002840",
    },
    {
        "school": "Pitner Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002841",
    },
    {
        "school": "Kennesaw Charter School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002842",
    },
    {
        "school": "McCall Primary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129003528",
    },
    {
        "school": "Austell Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129003529",
    },
    {
        "school": "Riverside Primary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129003530",
    },
    {
        "school": "Barber Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129003531",
    },
    {
        "school": "Marietta Sixth Grade Academy",
        "district": "Marietta City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351002621",
    },
    {
        "school": "Sawyer Road Elementary School",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351003479",
    },
    {
        "school": "Marietta Center for Advanced Academics",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351003480",
    },
    {
        "school": "Odyssey Charter School",
        "district": "State Charter Schools- Odyssey School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130002303482",
    },
    {
        "school": "Willis Road Elementary",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150002531",
    },
    {
        "school": "Lee Middle School",
        "district": "Coweta County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150003328",
    },
    {
        "school": "Glanton Elementary",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150003329",
    },
    {
        "school": "Crisp RYDC",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603487",
    },
    {
        "school": "Kilough Elementary School",
        "district": "Dawson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130165002536",
    },
    {
        "school": "Dawson County Junior High",
        "district": "Dawson County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130165003623",
    },
    {
        "school": "DeKalb Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603504",
    },
    {
        "school": "Metro Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603517",
    },
    {
        "school": "Burgess-Peterson Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003471",
    },
    {
        "school": "Oakhurst Elementary School",
        "district": "City Schools of Decatur",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130168002618",
    },
    {
        "school": "Lithonia High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002537",
    },
    {
        "school": "International Community School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002538",
    },
    {
        "school": "East DeKalb Special Education Center",
        "district": "DeKalb County",
        "level": "Other",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130174002642",
    },
    {
        "school": "Lithonia Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002858",
    },
    {
        "school": "Redan Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002859",
    },
    {
        "school": "Miller Grove High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003332",
    },
    {
        "school": "Oakview Elementary",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003334",
    },
    {
        "school": "Chamblee Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003336",
    },
    {
        "school": "Stone Mountain Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003337",
    },
    {
        "school": "Tucker Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003338",
    },
    {
        "school": "DeKalb PATH Academy Charter School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003339",
    },
    {
        "school": "Flat Rock Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003634",
    },
    {
        "school": "Princeton Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003665",
    },
    {
        "school": "Eastman Youth Development Campus",
        "district": "Department of Juvenile Justice",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603492",
    },
    {
        "school": "Yeager Middle School",
        "district": "Douglas County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186002547",
    },
    {
        "school": "New Manchester Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186002548",
    },
    {
        "school": "Mirror Lake Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186002549",
    },
    {
        "school": "North Douglas Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186003345",
    },
    {
        "school": "Bill Arp Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186003346",
    },
    {
        "school": "Chapel Hill Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186003628",
    },
    {
        "school": "Claxton Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603501",
    },
    {
        "school": "Cleveland Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002554",
    },
    {
        "school": "Sara Harp Minter Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002555",
    },
    {
        "school": "Crabapple Lane Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002876",
    },
    {
        "school": "Whitewater High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002877",
    },
    {
        "school": "Bennett's Mill Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213003638",
    },
    {
        "school": "Bob Richards Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603511",
    },
    {
        "school": "Liberty Middle School",
        "district": "Forsyth County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222002559",
    },
    {
        "school": "Sharon Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222002880",
    },
    {
        "school": "Chestatee Elementary",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222002881",
    },
    {
        "school": "Riverwatch Middle School",
        "district": "Forsyth County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003352",
    },
    {
        "school": "Shiloh Point Elementary",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003353",
    },
    {
        "school": "West Forsyth High School",
        "district": "Forsyth County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003354",
    },
    {
        "school": "Little Mill Middle School",
        "district": "Forsyth County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003355",
    },
    {
        "school": "Silver City Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003356",
    },
    {
        "school": "Piney Grove Middle School",
        "district": "Forsyth County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003357",
    },
    {
        "school": "Johns Creek Elementary",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003685",
    },
    {
        "school": "Heritage Academy Elementary",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012002613",
    },
    {
        "school": "Atlanta Neighborhood Charter - Elementary",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012002615",
    },
    {
        "school": "APS-Forrest Hills Academy",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130012002798",
    },
    {
        "school": "Dobbs Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003025",
    },
    {
        "school": "Bolton Academy",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003028",
    },
    {
        "school": "Bazoline E. Usher/Collier Heights Elmentary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003030",
    },
    {
        "school": "KIPP West Atlanta Young Scholars Academy",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003031",
    },
    {
        "school": "Finch Elementary",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003468",
    },
    {
        "school": "Deerwood Academy School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003470",
    },
    {
        "school": "Early College High School at Carver",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003540",
    },
    {
        "school": "Atlanta Neighborhood Charter - Middle",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003541",
    },
    {
        "school": "Northview High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002560",
    },
    {
        "school": "Liberty Point Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002561",
    },
    {
        "school": "Paul D. West Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002564",
    },
    {
        "school": "KIPP South Fulton Academy School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002885",
    },
    {
        "school": "Autrey Mill Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002886",
    },
    {
        "school": "Hamilton E. Holmes Elementary",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002887",
    },
    {
        "school": "Hopewell Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003360",
    },
    {
        "school": "Renaissance ES",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003363",
    },
    {
        "school": "Alpharetta High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003364",
    },
    {
        "school": "Cogburn Woods Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003365",
    },
    {
        "school": "Wilson Creek Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003367",
    },
    {
        "school": "Sandtown Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003368",
    },
    {
        "school": "Hapeville Charter Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003369",
    },
    {
        "school": "Amana Academy School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003535",
    },
    {
        "school": "Corley Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002898",
    },
    {
        "school": "Ivy Creek Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002899",
    },
    {
        "school": "Sycamore Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002900",
    },
    {
        "school": "Cooper Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002901",
    },
    {
        "school": "Parsons Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002902",
    },
    {
        "school": "Peachtree Ridge High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002903",
    },
    {
        "school": "Alford Elementary",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002904",
    },
    {
        "school": "Duncan Creek Elementary",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002905",
    },
    {
        "school": "Mill Creek High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003376",
    },
    {
        "school": "Osborne Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003380",
    },
    {
        "school": "Mulberry Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003381",
    },
    {
        "school": "Lovin Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003382",
    },
    {
        "school": "Berkmar Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003385",
    },
    {
        "school": "Jones Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003388",
    },
    {
        "school": "Patrick Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003393",
    },
    {
        "school": "Alcova Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003395",
    },
    {
        "school": "Winn Holt Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003396",
    },
    {
        "school": "Level Creek Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003397",
    },
    {
        "school": "Radloff Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003398",
    },
    {
        "school": "Chesney Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003399",
    },
    {
        "school": "Oakland Meadow School",
        "district": "Gwinnett County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003627",
    },
    {
        "school": "Gainesville Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603506",
    },
    {
        "school": "Heard County Middle School",
        "district": "Heard County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130279002574",
    },
    {
        "school": "Unity Grove Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002575",
    },
    {
        "school": "Luella High School",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002916",
    },
    {
        "school": "Flippen Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002918",
    },
    {
        "school": "Dutchtown High",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003407",
    },
    {
        "school": "Luella Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003408",
    },
    {
        "school": "Dutchtown Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003409",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003410",
    },
    {
        "school": "Dutchtown Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003411",
    },
    {
        "school": "Timber Ridge Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003412",
    },
    {
        "school": "Walnut Creek Elementary",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003413",
    },
    {
        "school": "Ola High School",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003414",
    },
    {
        "school": "Woodland Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003415",
    },
    {
        "school": "Red Oak Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003416",
    },
    {
        "school": "New Hope Elementary",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003417",
    },
    {
        "school": "Woodland High School",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003418",
    },
    {
        "school": "Ola Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003419",
    },
    {
        "school": "Jasper County High School",
        "district": "Jasper County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130297003423",
    },
    {
        "school": "Lamar County Elementary School",
        "district": "Lamar County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130321003425",
    },
    {
        "school": "George E. Washington Elementary School (PK-5)",
        "district": "Meriwether County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130363002582",
    },
    {
        "school": "Rocky Plains Elementary School",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393003435",
    },
    {
        "school": "Alcovy High School",
        "district": "Newton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393003436",
    },
    {
        "school": "Bessie L. Baggett Elementary",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402002588",
    },
    {
        "school": "Lillian C. Poole Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402002958",
    },
    {
        "school": "Roland W. Russom Elementary",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402002959",
    },
    {
        "school": "South Paulding High School",
        "district": "Paulding County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402003438",
    },
    {
        "school": "Connie Dugan Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402003439",
    },
    {
        "school": "Irma C. Austin Middle School",
        "district": "Paulding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402003440",
    },
    {
        "school": "North Paulding High School",
        "district": "Paulding County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402003625",
    },
    {
        "school": "Burnt Hickory Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402003655",
    },
    {
        "school": "Sammy McClure Sr. Middle School",
        "district": "Paulding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402003693",
    },
    {
        "school": "Hill City Elementary School",
        "district": "Pickens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130411002589",
    },
    {
        "school": "Jasper Middle School",
        "district": "Pickens County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130411002590",
    },
    {
        "school": "Tate Elementary School",
        "district": "Pickens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130411002591",
    },
    {
        "school": "Harmony Elementary School",
        "district": "Pickens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130411003441",
    },
    {
        "school": "Augusta Youth Development Campus",
        "district": "Department of Juvenile Justice",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603488",
    },
    {
        "school": "Augusta Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603498",
    },
    {
        "school": "General Ray Davis Middle School",
        "district": "Rockdale County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441003446",
    },
    {
        "school": "Moreland Road Elementary",
        "district": "Griffin-Spalding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252003447",
    },
    {
        "school": "Carver Road Middle School",
        "district": "Griffin-Spalding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252003448",
    },
    {
        "school": "Kennedy Road Middle School",
        "district": "Griffin-Spalding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252003449",
    },
    {
        "school": "Sumter Youth Development Campus",
        "district": "Department of Juvenile Justice",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603518",
    },
    {
        "school": "T J Loftiss II Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603514",
    },
    {
        "school": "Social Circle Primary School",
        "district": "Social Circle City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130454002622",
    },
    {
        "school": "Youth Elementary School",
        "district": "Walton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539002607",
    },
    {
        "school": "Youth Middle School",
        "district": "Walton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539003459",
    },
    {
        "school": "Sharon Elementary School",
        "district": "Walton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539003668",
    },
    {
        "school": "Waycross Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603515",
    },
    {
        "school": "Elbert Shaw Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603503",
    },
    {
        "school": "Jackson High School",
        "district": "Butts County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130069000301",
    },
    {
        "school": "Henderson Middle School",
        "district": "Butts County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130069002353",
    },
    {
        "school": "Dawson County Middle School",
        "district": "Dawson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130165001952",
    },
    {
        "school": "Robinson Elementary School",
        "district": "Dawson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130165002030",
    },
    {
        "school": "Dawson County High School",
        "district": "Dawson County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130165002253",
    },
    {
        "school": "Black's Mill Elementary School",
        "district": "Dawson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130165002254",
    },
    {
        "school": "Jones Elementary School",
        "district": "Bremen City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130051000260",
    },
    {
        "school": "Bremen High School",
        "district": "Bremen City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130051002455",
    },
    {
        "school": "Buchanan Elementary School",
        "district": "Haralson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130267001180",
    },
    {
        "school": "Tallapoosa Primary School",
        "district": "Haralson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130267001181",
    },
    {
        "school": "West Haralson Elementary School",
        "district": "Haralson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130267001182",
    },
    {
        "school": "Haralson County High School",
        "district": "Haralson County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130267001183",
    },
    {
        "school": "Buchanan Primary School",
        "district": "Haralson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130267001184",
    },
    {
        "school": "Haralson County Middle School",
        "district": "Haralson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130267001639",
    },
    {
        "school": "Ephesus Elementary School",
        "district": "Heard County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130279001199",
    },
    {
        "school": "Centralhatchee Elementary School",
        "district": "Heard County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130279001200",
    },
    {
        "school": "Heard County High School",
        "district": "Heard County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130279001201",
    },
    {
        "school": "Heard Elementary School",
        "district": "Heard County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130279001202",
    },
    {
        "school": "Jasper County Primary School",
        "district": "Jasper County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130297001004",
    },
    {
        "school": "Washington Park Elementary School",
        "district": "Jasper County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130297001255",
    },
    {
        "school": "Jasper County Middle School",
        "district": "Jasper County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130297002397",
    },
    {
        "school": "Lamar County High School",
        "district": "Lamar County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130321001294",
    },
    {
        "school": "Lamar County Primary School",
        "district": "Lamar County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130321002084",
    },
    {
        "school": "Lamar County Middle School",
        "district": "Lamar County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130321002273",
    },
    {
        "school": "Manchester Middle School",
        "district": "Meriwether County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130363001361",
    },
    {
        "school": "Manchester High School",
        "district": "Meriwether County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130363001362",
    },
    {
        "school": "Greenville High School",
        "district": "Meriwether County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130363001364",
    },
    {
        "school": "Unity Elementary School (PK-5)",
        "district": "Meriwether County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130363002334",
    },
    {
        "school": "Mountain View Elementary School",
        "district": "Meriwether County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130363002335",
    },
    {
        "school": "Pike County High School",
        "district": "Pike County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130417000546",
    },
    {
        "school": "Pike County Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130417001042",
    },
    {
        "school": "Pike County Primary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130417001495",
    },
    {
        "school": "Pike County Middle School",
        "district": "Pike County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130417001496",
    },
    {
        "school": "Bramlett Elementary School",
        "district": "Barrow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029000134",
    },
    {
        "school": "Statham Elementary School",
        "district": "Barrow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029000171",
    },
    {
        "school": "Holsenbeck Elementary School",
        "district": "Barrow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029000172",
    },
    {
        "school": "Winder-Barrow High School",
        "district": "Barrow County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029000173",
    },
    {
        "school": "County Line Elementary School",
        "district": "Barrow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029000174",
    },
    {
        "school": "Bear Creek Middle School",
        "district": "Barrow County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029000175",
    },
    {
        "school": "Bethlehem Elementary School",
        "district": "Barrow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029000176",
    },
    {
        "school": "Auburn Elementary School",
        "district": "Barrow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029000178",
    },
    {
        "school": "Westside Middle School",
        "district": "Barrow County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029001913",
    },
    {
        "school": "Kennedy Elementary School",
        "district": "Barrow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029002016",
    },
    {
        "school": "Russell Middle School",
        "district": "Barrow County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029002017",
    },
    {
        "school": "Yargo Elementary School",
        "district": "Barrow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029002293",
    },
    {
        "school": "Apalachee High School",
        "district": "Barrow County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029002350",
    },
    {
        "school": "Emerson Elementary School",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033000179",
    },
    {
        "school": "Cloverleaf Elementary",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033000180",
    },
    {
        "school": "Cass High School",
        "district": "Bartow County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033000181",
    },
    {
        "school": "Hamilton Crossing Elementary School",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033000183",
    },
    {
        "school": "Adairsville Elementary School",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033000185",
    },
    {
        "school": "White Elementary School",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033000186",
    },
    {
        "school": "Taylorsville Elementary School",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033000187",
    },
    {
        "school": "Kingston Elementary School",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033000189",
    },
    {
        "school": "Allatoona Elementary School",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033001078",
    },
    {
        "school": "Cass Middle School",
        "district": "Bartow County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033001868",
    },
    {
        "school": "Woodland High School",
        "district": "Bartow County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033001914",
    },
    {
        "school": "Mission Road Elementary School",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033001940",
    },
    {
        "school": "Red Top Middle School",
        "district": "Bartow County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033002060",
    },
    {
        "school": "Woodland Middle School at Euharlee",
        "district": "Bartow County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033002294",
    },
    {
        "school": "Adairsville Middle School",
        "district": "Bartow County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033002351",
    },
    {
        "school": "Adairsville High School",
        "district": "Bartow County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033002352",
    },
    {
        "school": "Cartersville High School",
        "district": "Cartersville City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130090000341",
    },
    {
        "school": "Cartersville Middle School",
        "district": "Cartersville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130090000342",
    },
    {
        "school": "Cartersville Primary School",
        "district": "Cartersville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130090000343",
    },
    {
        "school": "Cartersville Elementary School",
        "district": "Cartersville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130090002098",
    },
    {
        "school": "Mount Zion Elementary School",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084000319",
    },
    {
        "school": "Temple Elementary School",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084000320",
    },
    {
        "school": "Central Middle School",
        "district": "Carroll County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084000321",
    },
    {
        "school": "Villa Rica High School",
        "district": "Carroll County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084000324",
    },
    {
        "school": "Sand Hill Elementary School",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084000325",
    },
    {
        "school": "Central Elementary School",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084000326",
    },
    {
        "school": "Roopville Elementary School",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084000328",
    },
    {
        "school": "Bowdon High School",
        "district": "Carroll County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084000330",
    },
    {
        "school": "Central High School",
        "district": "Carroll County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084000331",
    },
    {
        "school": "Bowdon Elementary School",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084000332",
    },
    {
        "school": "Whitesburg Elementary School",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084000333",
    },
    {
        "school": "Temple High School",
        "district": "Carroll County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084002097",
    },
    {
        "school": "Bay Springs Middle School",
        "district": "Carroll County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084002239",
    },
    {
        "school": "Villa Rica Elementary School",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084002240",
    },
    {
        "school": "Sharp Creek Elementary School",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084002299",
    },
    {
        "school": "Bowdon Middle School",
        "district": "Carroll County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084002356",
    },
    {
        "school": "Temple Middle School",
        "district": "Carroll County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084002452",
    },
    {
        "school": "Carrollton Elementary School",
        "district": "Carrollton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130087000088",
    },
    {
        "school": "Carrollton High School",
        "district": "Carrollton City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130087000334",
    },
    {
        "school": "Carrollton Jr. High School",
        "district": "Carrollton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130087000336",
    },
    {
        "school": "Sixes Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111000114",
    },
    {
        "school": "Etowah High School",
        "district": "Cherokee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111000425",
    },
    {
        "school": "Clayton Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111000428",
    },
    {
        "school": "Ball Ground Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111000429",
    },
    {
        "school": "Macedonia Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111000431",
    },
    {
        "school": "Cherokee High School",
        "district": "Cherokee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111000432",
    },
    {
        "school": "Woodstock Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111000434",
    },
    {
        "school": "Hickory Flat Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111000435",
    },
    {
        "school": "Oak Grove Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111000437",
    },
    {
        "school": "Free Home Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111000438",
    },
    {
        "school": "Bascomb Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111001105",
    },
    {
        "school": "Woodstock High School",
        "district": "Cherokee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111001428",
    },
    {
        "school": "Woodstock Middle School",
        "district": "Cherokee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111001438",
    },
    {
        "school": "Arnold Mill Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111001443",
    },
    {
        "school": "E. T. Booth Middle School",
        "district": "Cherokee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111001860",
    },
    {
        "school": "Johnston Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111001878",
    },
    {
        "school": "Dean Rusk Middle School",
        "district": "Cherokee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111001970",
    },
    {
        "school": "Teasley Middle School",
        "district": "Cherokee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111001971",
    },
    {
        "school": "Boston Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111002020",
    },
    {
        "school": "R. M. Moore Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111002055",
    },
    {
        "school": "Mountain Road Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111002066",
    },
    {
        "school": "Sequoyah High School",
        "district": "Cherokee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111002100",
    },
    {
        "school": "Carmel Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111002359",
    },
    {
        "school": "Holly Springs Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111002360",
    },
    {
        "school": "Mount Zion Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000461",
    },
    {
        "school": "Brown Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000462",
    },
    {
        "school": "Mundys Mill Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000463",
    },
    {
        "school": "Kilpatrick Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000464",
    },
    {
        "school": "Jonesboro Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000465",
    },
    {
        "school": "Forest Park Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000466",
    },
    {
        "school": "North Clayton High School",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000467",
    },
    {
        "school": "Arnold Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000469",
    },
    {
        "school": "Tara Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000470",
    },
    {
        "school": "Northcutt Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000471",
    },
    {
        "school": "Lee Street Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000472",
    },
    {
        "school": "Jonesboro High School",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000473",
    },
    {
        "school": "Forest Park High School",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000474",
    },
    {
        "school": "East Clayton Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000475",
    },
    {
        "school": "Anderson Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000476",
    },
    {
        "school": "Riverdale High School",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000477",
    },
    {
        "school": "Pointe South Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000478",
    },
    {
        "school": "Oliver Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000479",
    },
    {
        "school": "Adamson Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000480",
    },
    {
        "school": "Swint Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000481",
    },
    {
        "school": "William M. McGarrah Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000483",
    },
    {
        "school": "Huie Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000484",
    },
    {
        "school": "Edmonds Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000485",
    },
    {
        "school": "Suder Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000486",
    },
    {
        "school": "Morrow High School",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000487",
    },
    {
        "school": "Lake City Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000488",
    },
    {
        "school": "Church Street Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000490",
    },
    {
        "school": "Riverdale Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000491",
    },
    {
        "school": "Morrow Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000492",
    },
    {
        "school": "Haynie Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000494",
    },
    {
        "school": "North Clayton Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000495",
    },
    {
        "school": "Babb Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000496",
    },
    {
        "school": "Fountain Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000497",
    },
    {
        "school": "West Clayton Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000498",
    },
    {
        "school": "Riverdale Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000499",
    },
    {
        "school": "Morrow Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000500",
    },
    {
        "school": "River's Edge Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000811",
    },
    {
        "school": "Lake Ridge Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123000812",
    },
    {
        "school": "Pointe South Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123001861",
    },
    {
        "school": "Kemp Elem School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123001925",
    },
    {
        "school": "Kendrick Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002057",
    },
    {
        "school": "Lovejoy High School",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002067",
    },
    {
        "school": "Mount Zion High School",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002068",
    },
    {
        "school": "Lovejoy Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002105",
    },
    {
        "school": "Hawthorne Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002246",
    },
    {
        "school": "M. D. Roberts Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002304",
    },
    {
        "school": "Roberta T. Smith Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002305",
    },
    {
        "school": "Callaway Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123002470",
    },
    {
        "school": "Hayes Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000240",
    },
    {
        "school": "Smitha Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000242",
    },
    {
        "school": "Hightower Trail Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000244",
    },
    {
        "school": "Mount Bethel Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000507",
    },
    {
        "school": "Dodgen Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000508",
    },
    {
        "school": "Kincaid Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000509",
    },
    {
        "school": "Still Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000510",
    },
    {
        "school": "Pine Mountain Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000511",
    },
    {
        "school": "Mabry Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000512",
    },
    {
        "school": "Walton High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000513",
    },
    {
        "school": "Birney Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000514",
    },
    {
        "school": "Clay Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000515",
    },
    {
        "school": "Hendricks Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000517",
    },
    {
        "school": "Griffin Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000518",
    },
    {
        "school": "Riverside Intermediate School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000520",
    },
    {
        "school": "Osborne High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000521",
    },
    {
        "school": "King Springs Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000523",
    },
    {
        "school": "North Cobb High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000525",
    },
    {
        "school": "Clarkdale Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000526",
    },
    {
        "school": "Big Shanty Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000527",
    },
    {
        "school": "Argyle Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000528",
    },
    {
        "school": "Wheeler High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000529",
    },
    {
        "school": "Powers Ferry Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000531",
    },
    {
        "school": "Norton Park Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000532",
    },
    {
        "school": "McEachern High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000533",
    },
    {
        "school": "Garrett Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000534",
    },
    {
        "school": "East Side Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000535",
    },
    {
        "school": "East Cobb Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000536",
    },
    {
        "school": "Campbell High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000537",
    },
    {
        "school": "Belmont Hills Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000538",
    },
    {
        "school": "Acworth Intermediate School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000539",
    },
    {
        "school": "Sope Creek Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000540",
    },
    {
        "school": "Tapp Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000541",
    },
    {
        "school": "Rocky Mount Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000543",
    },
    {
        "school": "Murdock Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000544",
    },
    {
        "school": "Sprayberry High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000545",
    },
    {
        "school": "Eastvalley Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000547",
    },
    {
        "school": "Sedalia Park Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000548",
    },
    {
        "school": "Mableton Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000551",
    },
    {
        "school": "Kennesaw Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000552",
    },
    {
        "school": "Floyd Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000553",
    },
    {
        "school": "Due West Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000554",
    },
    {
        "school": "Brumby Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000555",
    },
    {
        "school": "Bells Ferry Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000556",
    },
    {
        "school": "Hollydale Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000557",
    },
    {
        "school": "Teasley Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000558",
    },
    {
        "school": "Pebblebrook High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000559",
    },
    {
        "school": "Mountain View Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000560",
    },
    {
        "school": "Lindley Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000561",
    },
    {
        "school": "Daniell Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000564",
    },
    {
        "school": "Awtrey Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000566",
    },
    {
        "school": "Compton Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000567",
    },
    {
        "school": "Russell Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000568",
    },
    {
        "school": "LaBelle Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000571",
    },
    {
        "school": "Harmony-Leland Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000572",
    },
    {
        "school": "Fair Oaks Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000573",
    },
    {
        "school": "South Cobb High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129000574",
    },
    {
        "school": "Vaughan Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001479",
    },
    {
        "school": "Frey Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001490",
    },
    {
        "school": "Green Acres Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001491",
    },
    {
        "school": "Dickerson Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001880",
    },
    {
        "school": "Lassiter High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001881",
    },
    {
        "school": "Tritt Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001882",
    },
    {
        "school": "McCleskey Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001926",
    },
    {
        "school": "Garrison Mill Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001935",
    },
    {
        "school": "Keheley Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001972",
    },
    {
        "school": "Lewis Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001973",
    },
    {
        "school": "Milford Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001974",
    },
    {
        "school": "Pope High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001994",
    },
    {
        "school": "Davis Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129001995",
    },
    {
        "school": "Baker Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002021",
    },
    {
        "school": "Addison Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002022",
    },
    {
        "school": "Simpson Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002023",
    },
    {
        "school": "Powder Springs Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002024",
    },
    {
        "school": "Chalker Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002058",
    },
    {
        "school": "Dowell Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002069",
    },
    {
        "school": "Campbell Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002070",
    },
    {
        "school": "Varner Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002107",
    },
    {
        "school": "Shallowford Falls Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002108",
    },
    {
        "school": "Nicholson Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002109",
    },
    {
        "school": "Timber Ridge Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002110",
    },
    {
        "school": "Cheatham Hill Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002138",
    },
    {
        "school": "Sanders Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002150",
    },
    {
        "school": "Harrison High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002153",
    },
    {
        "school": "Ford Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002154",
    },
    {
        "school": "Bryant Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002158",
    },
    {
        "school": "Nickajack Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002247",
    },
    {
        "school": "Durham Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002248",
    },
    {
        "school": "Blackwell Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002249",
    },
    {
        "school": "Lost Mountain Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002250",
    },
    {
        "school": "Kennesaw Mountain High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002365",
    },
    {
        "school": "Cooper Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002475",
    },
    {
        "school": "Palmer Middle School",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129002476",
    },
    {
        "school": "Dunleith Elementary School",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351000763",
    },
    {
        "school": "Lockheed Elementary School",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351000767",
    },
    {
        "school": "Park Street Elementary School",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351001337",
    },
    {
        "school": "A.L. Burruss Elementary School",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351001338",
    },
    {
        "school": "Marietta Middle School",
        "district": "Marietta City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351001339",
    },
    {
        "school": "West Side Elementary School",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351001341",
    },
    {
        "school": "Marietta High School",
        "district": "Marietta City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351001342",
    },
    {
        "school": "Hickory Hills Elementary School",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351001345",
    },
    {
        "school": "Canongate Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000208",
    },
    {
        "school": "Eastside Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000747",
    },
    {
        "school": "Atkinson Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000748",
    },
    {
        "school": "Evans Middle School",
        "district": "Coweta County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000750",
    },
    {
        "school": "Ruth Hill Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000751",
    },
    {
        "school": "Arnco-Sargent Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000753",
    },
    {
        "school": "Newnan High School",
        "district": "Coweta County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000754",
    },
    {
        "school": "Western Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000755",
    },
    {
        "school": "Moreland Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000760",
    },
    {
        "school": "Northside Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000761",
    },
    {
        "school": "Elm Street Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000762",
    },
    {
        "school": "Jefferson Parkway Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000816",
    },
    {
        "school": "Thomas Crossroads Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000818",
    },
    {
        "school": "Arnall Middle School",
        "district": "Coweta County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150000825",
    },
    {
        "school": "Northgate High School",
        "district": "Coweta County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150001108",
    },
    {
        "school": "White Oak Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150002026",
    },
    {
        "school": "East Coweta Middle School",
        "district": "Coweta County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150002027",
    },
    {
        "school": "East Coweta High School",
        "district": "Coweta County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150002028",
    },
    {
        "school": "Newnan Crossing Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150002162",
    },
    {
        "school": "Poplar Road Elementary School",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150002251",
    },
    {
        "school": "Madras Middle School",
        "district": "Coweta County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150002252",
    },
    {
        "school": "Arbor Springs Elementary",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150002307",
    },
    {
        "school": "Smokey Road Middle School",
        "district": "Coweta County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150002367",
    },
    {
        "school": "Toomer Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000052",
    },
    {
        "school": "Crim High School",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130012000120",
    },
    {
        "school": "Lin Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000136",
    },
    {
        "school": "Charles R. Drew Charter School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012002453",
    },
    {
        "school": "Fifth Avenue Elementary",
        "district": "City Schools of Decatur",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130168000795",
    },
    {
        "school": "Renfroe Middle School",
        "district": "City Schools of Decatur",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130168000796",
    },
    {
        "school": "Clairemont Elementary School",
        "district": "City Schools of Decatur",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130168000798",
    },
    {
        "school": "Winnona Park Elementary School",
        "district": "City Schools of Decatur",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130168000799",
    },
    {
        "school": "Decatur High School",
        "district": "City Schools of Decatur",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130168000802",
    },
    {
        "school": "Chapel Hill Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000083",
    },
    {
        "school": "Shadow Rock Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000162",
    },
    {
        "school": "Salem Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000222",
    },
    {
        "school": "Coralwood Education Center",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000635",
    },
    {
        "school": "Redan High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000636",
    },
    {
        "school": "Austin Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000637",
    },
    {
        "school": "Vanderlyn Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000638",
    },
    {
        "school": "Cedar Grove High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000639",
    },
    {
        "school": "Bob Mathis Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000640",
    },
    {
        "school": "Fairington Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000642",
    },
    {
        "school": "Stone Mountain High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000644",
    },
    {
        "school": "Cedar Grove Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000645",
    },
    {
        "school": "Rockbridge Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000646",
    },
    {
        "school": "McNair Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000649",
    },
    {
        "school": "Evansdale Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000650",
    },
    {
        "school": "Dresden Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000651",
    },
    {
        "school": "Columbia Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000652",
    },
    {
        "school": "Chapel Hill Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000653",
    },
    {
        "school": "Brockett Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000654",
    },
    {
        "school": "DeKalb Elementary School of the Arts",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000656",
    },
    {
        "school": "Woodridge Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000660",
    },
    {
        "school": "Stone Mill Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000662",
    },
    {
        "school": "Fernbank Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000664",
    },
    {
        "school": "Druid Hills High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000665",
    },
    {
        "school": "Columbia High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000666",
    },
    {
        "school": "Allgood Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000667",
    },
    {
        "school": "Woodward Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000668",
    },
    {
        "school": "Tucker High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000669",
    },
    {
        "school": "Sequoyah Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000672",
    },
    {
        "school": "Livsey Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000677",
    },
    {
        "school": "Idlewood Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000678",
    },
    {
        "school": "Southwest DeKalb High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000679",
    },
    {
        "school": "Sagamore Hills Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000680",
    },
    {
        "school": "Redan Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000681",
    },
    {
        "school": "Montgomery Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000682",
    },
    {
        "school": "Kingsley Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000684",
    },
    {
        "school": "Towers High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000686",
    },
    {
        "school": "Huntley Hills Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000687",
    },
    {
        "school": "Hawthorne Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000688",
    },
    {
        "school": "Dunwoody High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000690",
    },
    {
        "school": "Chamblee Charter High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000692",
    },
    {
        "school": "Avondale Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000694",
    },
    {
        "school": "Stoneview Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000695",
    },
    {
        "school": "Snapfinger Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000696",
    },
    {
        "school": "Rowland Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000698",
    },
    {
        "school": "Rainbow Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000699",
    },
    {
        "school": "Laurel Ridge Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000700",
    },
    {
        "school": "Oakcliff Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000701",
    },
    {
        "school": "Montclair Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000702",
    },
    {
        "school": "Kelley Lake Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000703",
    },
    {
        "school": "Hightower Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000704",
    },
    {
        "school": "Cross Keys High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000707",
    },
    {
        "school": "Clarkston High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000708",
    },
    {
        "school": "Murphey Candler Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000709",
    },
    {
        "school": "Briar Vista Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000710",
    },
    {
        "school": "McNair High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000712",
    },
    {
        "school": "Toney Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000713",
    },
    {
        "school": "Oak Grove Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000714",
    },
    {
        "school": "Smoke Rise Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000715",
    },
    {
        "school": "Rock Chapel Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000717",
    },
    {
        "school": "Pleasantdale Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000718",
    },
    {
        "school": "Lakeside High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000721",
    },
    {
        "school": "Jolly Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000722",
    },
    {
        "school": "Hambrick Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000723",
    },
    {
        "school": "Chesnut Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000724",
    },
    {
        "school": "Flat Shoals Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000725",
    },
    {
        "school": "Dunaire Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000726",
    },
    {
        "school": "Canby Lane Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000727",
    },
    {
        "school": "Briarlake Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000728",
    },
    {
        "school": "Ashford Park Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000729",
    },
    {
        "school": "Stone Mountain Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000732",
    },
    {
        "school": "Cary Reynolds Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000734",
    },
    {
        "school": "Midvale Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000737",
    },
    {
        "school": "McLendon Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000738",
    },
    {
        "school": "Indian Creek Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000740",
    },
    {
        "school": "Henderson Mill Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174000741",
    },
    {
        "school": "Marbut Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174001521",
    },
    {
        "school": "Edward L. Bouie- Sr. Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174001531",
    },
    {
        "school": "Stephenson Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174001547",
    },
    {
        "school": "Stephenson High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174001553",
    },
    {
        "school": "Miller Grove Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174001568",
    },
    {
        "school": "Henderson Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174001586",
    },
    {
        "school": "Druid Hills Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174001589",
    },
    {
        "school": "Eldridge L. Miller Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174001862",
    },
    {
        "school": "Panola Way Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174001998",
    },
    {
        "school": "Kittredge Magnet School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174001999",
    },
    {
        "school": "Peachtree Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002031",
    },
    {
        "school": "Pine Ridge Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002074",
    },
    {
        "school": "Browns Mill Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002112",
    },
    {
        "school": "Robert Shaw Theme School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002256",
    },
    {
        "school": "Narvie Harris Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002308",
    },
    {
        "school": "Cedar Grove Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002310",
    },
    {
        "school": "DeKalb Alternative School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130174002313",
    },
    {
        "school": "Freedom Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002370",
    },
    {
        "school": "Wynbrooke Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002478",
    },
    {
        "school": "Martin Luther King- Jr. High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002479",
    },
    {
        "school": "Columbia Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002480",
    },
    {
        "school": "Mary McLeod Bethune Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174002482",
    },
    {
        "school": "South Douglas Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000062",
    },
    {
        "school": "Fairplay Middle School",
        "district": "Douglas County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000851",
    },
    {
        "school": "Lithia Springs Comprehensive High School",
        "district": "Douglas County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000853",
    },
    {
        "school": "Arbor Station Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000855",
    },
    {
        "school": "Turner Middle School",
        "district": "Douglas County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000856",
    },
    {
        "school": "Beulah Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000858",
    },
    {
        "school": "Winston Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000859",
    },
    {
        "school": "Annette Winn Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000860",
    },
    {
        "school": "Stewart Middle School",
        "district": "Douglas County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000861",
    },
    {
        "school": "Mount Carmel Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000863",
    },
    {
        "school": "Douglas County High School",
        "district": "Douglas County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000864",
    },
    {
        "school": "Chapel Hill Middle School",
        "district": "Douglas County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000865",
    },
    {
        "school": "Lithia Springs Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186000866",
    },
    {
        "school": "Dorsett Shoals Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186001927",
    },
    {
        "school": "Alexander High School",
        "district": "Douglas County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186001976",
    },
    {
        "school": "Chestnut Log Middle School",
        "district": "Douglas County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186002000",
    },
    {
        "school": "Factory Shoals Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186002032",
    },
    {
        "school": "Bright Star Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186002156",
    },
    {
        "school": "Sweetwater Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186002157",
    },
    {
        "school": "Burnett Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186002159",
    },
    {
        "school": "Eastside Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186002160",
    },
    {
        "school": "Chapel Hill High School",
        "district": "Douglas County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186002317",
    },
    {
        "school": "Holly Springs Elementary",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186002318",
    },
    {
        "school": "Huddleston Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213000920",
    },
    {
        "school": "Peachtree City Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213000923",
    },
    {
        "school": "Booth Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213000925",
    },
    {
        "school": "Kedron Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213001174",
    },
    {
        "school": "Spring Hill Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213001235",
    },
    {
        "school": "McIntosh High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213001892",
    },
    {
        "school": "North Fayette Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213001893",
    },
    {
        "school": "Oak Grove Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213001955",
    },
    {
        "school": "Braelinn Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002115",
    },
    {
        "school": "Robert J. Burch Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002116",
    },
    {
        "school": "Whitewater Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002117",
    },
    {
        "school": "Flat Rock Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002118",
    },
    {
        "school": "Starrs Mill High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002165",
    },
    {
        "school": "Rising Starr Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002166",
    },
    {
        "school": "Sandy Creek High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002167",
    },
    {
        "school": "Fayette County High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002168",
    },
    {
        "school": "Peeples Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002258",
    },
    {
        "school": "Fayetteville Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213002485",
    },
    {
        "school": "Chattahoochee Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222000268",
    },
    {
        "school": "North Forsyth High School",
        "district": "Forsyth County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222000893",
    },
    {
        "school": "Otwell Middle School",
        "district": "Forsyth County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222000951",
    },
    {
        "school": "Midway Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222000953",
    },
    {
        "school": "Big Creek Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222000954",
    },
    {
        "school": "Mashburn Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222000955",
    },
    {
        "school": "Forsyth Central High School",
        "district": "Forsyth County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222000956",
    },
    {
        "school": "Cumming Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222000957",
    },
    {
        "school": "Daves Creek Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222001610",
    },
    {
        "school": "Coal Mountain Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222001895",
    },
    {
        "school": "South Forsyth High School",
        "district": "Forsyth County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222001897",
    },
    {
        "school": "Vickery Creek Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222002169",
    },
    {
        "school": "Sawnee Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222002173",
    },
    {
        "school": "North Forsyth Middle School",
        "district": "Forsyth County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222002178",
    },
    {
        "school": "Vickery Creek Middle School",
        "district": "Forsyth County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222002261",
    },
    {
        "school": "South Forsyth Middle School",
        "district": "Forsyth County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222002262",
    },
    {
        "school": "Settles Bridge Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222002320",
    },
    {
        "school": "Matt Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222002487",
    },
    {
        "school": "Long Middle School",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000017",
    },
    {
        "school": "Boyd Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000022",
    },
    {
        "school": "King Middle School",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000025",
    },
    {
        "school": "Inman Middle School",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000027",
    },
    {
        "school": "Garden Hills Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000029",
    },
    {
        "school": "Rivers Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000036",
    },
    {
        "school": "Kimberly Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000038",
    },
    {
        "school": "Hutchinson Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000039",
    },
    {
        "school": "Humphries Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000043",
    },
    {
        "school": "F. L. Stanton Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000045",
    },
    {
        "school": "Dunbar Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000054",
    },
    {
        "school": "Sylvan Hills Middle School",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000058",
    },
    {
        "school": "Slater Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000059",
    },
    {
        "school": "Price Middle School",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000060",
    },
    {
        "school": "Miles Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000063",
    },
    {
        "school": "Grady High School",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000066",
    },
    {
        "school": "Thomasville Heights Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000069",
    },
    {
        "school": "Benteen Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000073",
    },
    {
        "school": "Barack and Michelle Obama Academy",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000077",
    },
    {
        "school": "M. A. Jones Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000085",
    },
    {
        "school": "Douglass High School",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000089",
    },
    {
        "school": "Cleveland Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000091",
    },
    {
        "school": "Cascade Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000092",
    },
    {
        "school": "Scott Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000099",
    },
    {
        "school": "Fickett Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000103",
    },
    {
        "school": "Peyton Forest Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000106",
    },
    {
        "school": "Sutton Middle School",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000107",
    },
    {
        "school": "Continental Colony Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000113",
    },
    {
        "school": "Beecher Hills Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000118",
    },
    {
        "school": "West Manor Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000121",
    },
    {
        "school": "Perkerson Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000122",
    },
    {
        "school": "Smith Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000124",
    },
    {
        "school": "Brandon Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000127",
    },
    {
        "school": "Morningside Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000130",
    },
    {
        "school": "Jackson Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000137",
    },
    {
        "school": "Gideons Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000139",
    },
    {
        "school": "The John Hope-Charles Walter Hill Elementary Schools",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000143",
    },
    {
        "school": "Bunche Middle School",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012000150",
    },
    {
        "school": "Mays High School",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012001865",
    },
    {
        "school": "Young Middle School",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012001866",
    },
    {
        "school": "Maynard H. Jackson- Jr. High School",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012001939",
    },
    {
        "school": "North Atlanta High School",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012002212",
    },
    {
        "school": "Centennial Academy",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012002290",
    },
    {
        "school": "Brown Middle School",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012002344",
    },
    {
        "school": "Parkside Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012002517",
    },
    {
        "school": "Crabapple Crossing Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000035",
    },
    {
        "school": "Conley Hills Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000217",
    },
    {
        "school": "New Prospect Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000927",
    },
    {
        "school": "Findley Oaks Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000948",
    },
    {
        "school": "Dolvin Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000965",
    },
    {
        "school": "Banneker High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000967",
    },
    {
        "school": "Jackson Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000968",
    },
    {
        "school": "Gullatt Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000969",
    },
    {
        "school": "Nolan Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000970",
    },
    {
        "school": "S. L. Lewis Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000971",
    },
    {
        "school": "Alpharetta Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000974",
    },
    {
        "school": "Sandy Springs Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000975",
    },
    {
        "school": "Mountain Park Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000976",
    },
    {
        "school": "Roswell North Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000978",
    },
    {
        "school": "Randolph Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000986",
    },
    {
        "school": "Riverwood International Charter School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000987",
    },
    {
        "school": "Parklane Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000988",
    },
    {
        "school": "Lee Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000991",
    },
    {
        "school": "Brookview Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000997",
    },
    {
        "school": "Campbell Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228000998",
    },
    {
        "school": "Milton High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001005",
    },
    {
        "school": "Bethune Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001006",
    },
    {
        "school": "Palmetto Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001013",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001015",
    },
    {
        "school": "North Springs High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001024",
    },
    {
        "school": "Mimosa Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001025",
    },
    {
        "school": "High Point Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001026",
    },
    {
        "school": "Westlake High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001031",
    },
    {
        "school": "Spalding Drive Elementary",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001032",
    },
    {
        "school": "Asa Hilliard Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001036",
    },
    {
        "school": "E. C. West Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001043",
    },
    {
        "school": "Northwood Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001615",
    },
    {
        "school": "State Bridge Crossing Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001620",
    },
    {
        "school": "River Eves Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001623",
    },
    {
        "school": "Webb Bridge Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001627",
    },
    {
        "school": "Northwestern Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001631",
    },
    {
        "school": "Crabapple Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001928",
    },
    {
        "school": "Haynes Bridge Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001929",
    },
    {
        "school": "Holcomb Bridge Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001930",
    },
    {
        "school": "Camp Creek Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001956",
    },
    {
        "school": "Ridgeview Charter School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001957",
    },
    {
        "school": "Independence High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130228001958",
    },
    {
        "school": "Barnwell Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228001979",
    },
    {
        "school": "Heards Ferry Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002001",
    },
    {
        "school": "McNair Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002035",
    },
    {
        "school": "Woodland Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002036",
    },
    {
        "school": "McClarin High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130228002037",
    },
    {
        "school": "Lake Windward Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002078",
    },
    {
        "school": "Roswell High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002119",
    },
    {
        "school": "Creekside High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002120",
    },
    {
        "school": "Bear Creek Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002121",
    },
    {
        "school": "Medlock Bridge Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002122",
    },
    {
        "school": "Taylor Road Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002123",
    },
    {
        "school": "Tri-Cities High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002124",
    },
    {
        "school": "Hapeville Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002170",
    },
    {
        "school": "Chattahoochee High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002172",
    },
    {
        "school": "Centennial High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002181",
    },
    {
        "school": "Sweet Apple Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002189",
    },
    {
        "school": "Shakerag Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002190",
    },
    {
        "school": "Stonewall Tell Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002264",
    },
    {
        "school": "Manning Oaks Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002265",
    },
    {
        "school": "Summit Hill Elementary",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002321",
    },
    {
        "school": "Abbotts Hill Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002378",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002379",
    },
    {
        "school": "Dunwoody Springs Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002380",
    },
    {
        "school": "Ocee Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002382",
    },
    {
        "school": "Creek View Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002489",
    },
    {
        "school": "Hembree Springs Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002490",
    },
    {
        "school": "Hillside Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002491",
    },
    {
        "school": "Elkins Pointe Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002492",
    },
    {
        "school": "River Trail Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228002493",
    },
    {
        "school": "Buford High School",
        "district": "Buford City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130060000274",
    },
    {
        "school": "Buford Elementary School",
        "district": "Buford City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130060000275",
    },
    {
        "school": "Buford Middle School",
        "district": "Buford City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130060000276",
    },
    {
        "school": "Buford Academy",
        "district": "Buford City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130060002345",
    },
    {
        "school": "Walnut Grove Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255000046",
    },
    {
        "school": "Craig Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255000272",
    },
    {
        "school": "Nesbit Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255000296",
    },
    {
        "school": "Gwinnett InterVention Education (GIVE) Center East",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130255000308",
    },
    {
        "school": "Simonton Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255000309",
    },
    {
        "school": "Simpson Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255000327",
    },
    {
        "school": "Collins Hill High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255000959",
    },
    {
        "school": "Fort Daniel Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255000972",
    },
    {
        "school": "Jackson Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255000973",
    },
    {
        "school": "Kanoheda Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255000992",
    },
    {
        "school": "Dyer Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001109",
    },
    {
        "school": "Rockbridge Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001110",
    },
    {
        "school": "Lilburn Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001111",
    },
    {
        "school": "Knight Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001112",
    },
    {
        "school": "Parkview High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001114",
    },
    {
        "school": "Trickum Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001115",
    },
    {
        "school": "Centerville Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001116",
    },
    {
        "school": "Lilburn Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001117",
    },
    {
        "school": "Duluth High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001118",
    },
    {
        "school": "Suwanee Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001119",
    },
    {
        "school": "Peachtree Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001120",
    },
    {
        "school": "Lawrenceville Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001121",
    },
    {
        "school": "Duluth Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001122",
    },
    {
        "school": "North Gwinnett High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001123",
    },
    {
        "school": "Summerour Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001124",
    },
    {
        "school": "Norcross Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001125",
    },
    {
        "school": "Dacula High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001127",
    },
    {
        "school": "Central Gwinnett High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001129",
    },
    {
        "school": "Camp Creek Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001130",
    },
    {
        "school": "Sugar Hill Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001131",
    },
    {
        "school": "Norcross High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001132",
    },
    {
        "school": "Harris Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001133",
    },
    {
        "school": "Britt Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001134",
    },
    {
        "school": "South Gwinnett High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001135",
    },
    {
        "school": "Snellville Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001136",
    },
    {
        "school": "Mountain Park Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001137",
    },
    {
        "school": "Harmony Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001138",
    },
    {
        "school": "Grayson Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001139",
    },
    {
        "school": "Bethesda Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001140",
    },
    {
        "school": "Gwin Oaks Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001142",
    },
    {
        "school": "Five Forks Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001143",
    },
    {
        "school": "Sweetwater Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001144",
    },
    {
        "school": "Harbins Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001249",
    },
    {
        "school": "Creekland Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001632",
    },
    {
        "school": "Hull Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001633",
    },
    {
        "school": "Magill Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001635",
    },
    {
        "school": "McConnell Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001638",
    },
    {
        "school": "Annistown Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001901",
    },
    {
        "school": "Arcado Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001902",
    },
    {
        "school": "Beaver Ridge Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001903",
    },
    {
        "school": "Berkmar High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001905",
    },
    {
        "school": "Brookwood High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001906",
    },
    {
        "school": "Dacula Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001907",
    },
    {
        "school": "Head Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001909",
    },
    {
        "school": "Shiloh Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001910",
    },
    {
        "school": "Berkeley Lake Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001931",
    },
    {
        "school": "Shiloh High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001937",
    },
    {
        "school": "Hopkins Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001938",
    },
    {
        "school": "Pinckneyville Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001960",
    },
    {
        "school": "Brookwood Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001961",
    },
    {
        "school": "Meadowcreek High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001980",
    },
    {
        "school": "Norton Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255001981",
    },
    {
        "school": "Richards Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002004",
    },
    {
        "school": "Minor Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002005",
    },
    {
        "school": "Phoenix High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130255002039",
    },
    {
        "school": "McKendree Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002040",
    },
    {
        "school": "Cedar Hill Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002041",
    },
    {
        "school": "Chattahoochee Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002082",
    },
    {
        "school": "Dacula Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002125",
    },
    {
        "school": "Shiloh Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002126",
    },
    {
        "school": "Pharr Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002176",
    },
    {
        "school": "Crews Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002196",
    },
    {
        "school": "Mason Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002197",
    },
    {
        "school": "Partee Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002211",
    },
    {
        "school": "Taylor Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002214",
    },
    {
        "school": "Meadowcreek Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002267",
    },
    {
        "school": "Rock Springs Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002322",
    },
    {
        "school": "Freeman's Mill Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002323",
    },
    {
        "school": "Stripling Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002324",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002325",
    },
    {
        "school": "Grayson High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255002387",
    },
    {
        "school": "Wesley Lakes Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282000367",
    },
    {
        "school": "Austin Road Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282000378",
    },
    {
        "school": "Eagle's Landing Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282000399",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001204",
    },
    {
        "school": "Stockbridge High School",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001205",
    },
    {
        "school": "McDonough Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001206",
    },
    {
        "school": "Stockbridge Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001207",
    },
    {
        "school": "McDonough High School",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001208",
    },
    {
        "school": "Smith-Barnes Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001209",
    },
    {
        "school": "Hampton Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001212",
    },
    {
        "school": "Stockbridge Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001213",
    },
    {
        "school": "Locust Grove Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001214",
    },
    {
        "school": "Pate's Creek Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001288",
    },
    {
        "school": "Pleasant Grove Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001641",
    },
    {
        "school": "Hickory Flat Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001655",
    },
    {
        "school": "Austin Road Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282001663",
    },
    {
        "school": "Cotton Indian Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002128",
    },
    {
        "school": "Oakland Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002129",
    },
    {
        "school": "Eagle's Landing High School",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002130",
    },
    {
        "school": "Ola Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002328",
    },
    {
        "school": "Mount Carmel Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002329",
    },
    {
        "school": "Union Grove High",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002391",
    },
    {
        "school": "East Lake Elementary",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002392",
    },
    {
        "school": "Luella Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002393",
    },
    {
        "school": "Union Grove Middle",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282002394",
    },
    {
        "school": "Eastside High School",
        "district": "Newton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393001023",
    },
    {
        "school": "Newton High School",
        "district": "Newton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393001454",
    },
    {
        "school": "Fairview Elementary",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393001455",
    },
    {
        "school": "East Newton Elementary School",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393001456",
    },
    {
        "school": "Cousins Middle School",
        "district": "Newton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393001457",
    },
    {
        "school": "Porterdale Elementary School",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393001459",
    },
    {
        "school": "Heard-Mixon Elementary School",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393001460",
    },
    {
        "school": "Mansfield Elementary School",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393001461",
    },
    {
        "school": "Flint Hill Elementary",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393001462",
    },
    {
        "school": "Livingston Elementary School",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393001463",
    },
    {
        "school": "Middle Ridge Elementary School",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393002222",
    },
    {
        "school": "West Newton Elementary School",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393002223",
    },
    {
        "school": "Indian Creek Middle School",
        "district": "Newton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393002224",
    },
    {
        "school": "Veterans Memorial Middle School",
        "district": "Newton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393002424",
    },
    {
        "school": "Oak Hill Elementary School",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393002507",
    },
    {
        "school": "Floyd L. Shelton Elementary School at Crossroad",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402000522",
    },
    {
        "school": "Northside Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402000524",
    },
    {
        "school": "East Paulding Middle School",
        "district": "Paulding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402000542",
    },
    {
        "school": "Dallas Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402001470",
    },
    {
        "school": "Paulding County High School",
        "district": "Paulding County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402001471",
    },
    {
        "school": "Herschel Jones Middle School",
        "district": "Paulding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402001472",
    },
    {
        "school": "New Georgia Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402001473",
    },
    {
        "school": "Hiram Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402001476",
    },
    {
        "school": "Union Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402001477",
    },
    {
        "school": "Sam D. Panter Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402001781",
    },
    {
        "school": "J. A. Dobbins Middle School",
        "district": "Paulding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402001786",
    },
    {
        "school": "McGarity Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402002009",
    },
    {
        "school": "South Paulding Middle School",
        "district": "Paulding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402002187",
    },
    {
        "school": "East Paulding High School",
        "district": "Paulding County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402002188",
    },
    {
        "school": "Nebo Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402002228",
    },
    {
        "school": "C. A. Roberts Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402002274",
    },
    {
        "school": "Allgood Elementary School",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402002275",
    },
    {
        "school": "Hiram High School",
        "district": "Paulding County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402002338",
    },
    {
        "school": "Lena Mae Moses Middle School",
        "district": "Paulding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402002508",
    },
    {
        "school": "Pickens County Junior High School",
        "district": "Pickens County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130411002048",
    },
    {
        "school": "Pickens County High School",
        "district": "Pickens County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130411002276",
    },
    {
        "school": "Shoal Creek Elementary School",
        "district": "Rockdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441000575",
    },
    {
        "school": "Memorial Middle School",
        "district": "Rockdale County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441000583",
    },
    {
        "school": "Honey Creek Elementary School",
        "district": "Rockdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441001580",
    },
    {
        "school": "House Elementary School",
        "district": "Rockdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441001581",
    },
    {
        "school": "Hicks Elementary School",
        "district": "Rockdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441001582",
    },
    {
        "school": "Rockdale County High School",
        "district": "Rockdale County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441001583",
    },
    {
        "school": "Pine Street Elementary School",
        "district": "Rockdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441001584",
    },
    {
        "school": "Flat Shoals Elementary School",
        "district": "Rockdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441001585",
    },
    {
        "school": "Edwards Middle School",
        "district": "Rockdale County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441001587",
    },
    {
        "school": "Conyers Middle School",
        "district": "Rockdale County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441001588",
    },
    {
        "school": "Barksdale Elementary School",
        "district": "Rockdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441001590",
    },
    {
        "school": "Heritage High School",
        "district": "Rockdale County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441001591",
    },
    {
        "school": "Lorraine Elementary School",
        "district": "Rockdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441001830",
    },
    {
        "school": "Sims Elementary School",
        "district": "Rockdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441002050",
    },
    {
        "school": "Hightower Trail Elementary School",
        "district": "Rockdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441002051",
    },
    {
        "school": "Salem High School",
        "district": "Rockdale County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441002193",
    },
    {
        "school": "Peek's Chapel Elementary",
        "district": "Rockdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130441002513",
    },
    {
        "school": "Jordan Hill Road Elementary School",
        "district": "Griffin-Spalding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252001049",
    },
    {
        "school": "Moore Elementary School",
        "district": "Griffin-Spalding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252001089",
    },
    {
        "school": "Griffin High School",
        "district": "Griffin-Spalding County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252001092",
    },
    {
        "school": "Orrs Elementary School",
        "district": "Griffin-Spalding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252001093",
    },
    {
        "school": "Jackson Road Elementary School",
        "district": "Griffin-Spalding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252001098",
    },
    {
        "school": "Anne Street Elementary School",
        "district": "Griffin-Spalding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252001099",
    },
    {
        "school": "Crescent Road Elementary School",
        "district": "Griffin-Spalding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252001100",
    },
    {
        "school": "Beaverbrook Elementary School",
        "district": "Griffin-Spalding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252001101",
    },
    {
        "school": "Atkinson Elementary School",
        "district": "Griffin-Spalding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252001102",
    },
    {
        "school": "Cowan Road Elementary School",
        "district": "Griffin-Spalding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252002194",
    },
    {
        "school": "Futral Road Elementary School",
        "district": "Griffin-Spalding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252002281",
    },
    {
        "school": "Spalding High School",
        "district": "Griffin-Spalding County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252002429",
    },
    {
        "school": "Cowan Road Middle School",
        "district": "Griffin-Spalding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252002430",
    },
    {
        "school": "Social Circle Elementary School",
        "district": "Social Circle City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130454001616",
    },
    {
        "school": "Social Circle High School",
        "district": "Social Circle City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130454001617",
    },
    {
        "school": "Social Circle Middle School",
        "district": "Social Circle City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130454002463",
    },
    {
        "school": "Carver Middle School",
        "district": "Walton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539000031",
    },
    {
        "school": "Walnut Grove Elementary School",
        "district": "Walton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539001057",
    },
    {
        "school": "Bay Creek Elementary School",
        "district": "Walton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539001766",
    },
    {
        "school": "Loganville Middle School",
        "district": "Walton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539001767",
    },
    {
        "school": "Walker Park Elementary School",
        "district": "Walton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539001768",
    },
    {
        "school": "Harmony Elementary School",
        "district": "Walton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539001769",
    },
    {
        "school": "Monroe Area High School",
        "district": "Walton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539001772",
    },
    {
        "school": "Loganville Elementary School",
        "district": "Walton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539002136",
    },
    {
        "school": "Loganville High School",
        "district": "Walton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539002288",
    },
    {
        "school": "Atha Road Elementary School",
        "district": "Walton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539002516",
    },
    {
        "school": "Blakeney Elementary",
        "district": "Burke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130066002817",
    },
    {
        "school": "Grovetown Middle School",
        "district": "Columbia County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141002528",
    },
    {
        "school": "Lewiston Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141002848",
    },
    {
        "school": "River Ridge Elementary",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141003325",
    },
    {
        "school": "Stallings Island Middle School",
        "district": "Columbia County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141003694",
    },
    {
        "school": "Freedom Park Elementary",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438002596",
    },
    {
        "school": "Wilkinson Gardens Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438002972",
    },
    {
        "school": "Waynesboro Primary School",
        "district": "Burke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130066000293",
    },
    {
        "school": "Burke County Middle School",
        "district": "Burke County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130066001990",
    },
    {
        "school": "Burke County High School",
        "district": "Burke County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130066001991",
    },
    {
        "school": "S G A Elementary School",
        "district": "Burke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130066001992",
    },
    {
        "school": "Riverside Middle School",
        "district": "Columbia County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141000126",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141000248",
    },
    {
        "school": "Westmont Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141000599",
    },
    {
        "school": "Evans Middle School",
        "district": "Columbia County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141000601",
    },
    {
        "school": "North Harlem Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141000602",
    },
    {
        "school": "Evans High School",
        "district": "Columbia County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141000603",
    },
    {
        "school": "North Columbia Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141000604",
    },
    {
        "school": "Martinez Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141000606",
    },
    {
        "school": "Columbia Middle School",
        "district": "Columbia County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141000607",
    },
    {
        "school": "South Columbia Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141000610",
    },
    {
        "school": "Grovetown Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141000611",
    },
    {
        "school": "Greenbrier High School",
        "district": "Columbia County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141001501",
    },
    {
        "school": "Greenbrier Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141001502",
    },
    {
        "school": "Euchee Creek Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141001506",
    },
    {
        "school": "Harlem High School",
        "district": "Columbia County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141001885",
    },
    {
        "school": "Harlem Middle School",
        "district": "Columbia County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141001886",
    },
    {
        "school": "Evans Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141001996",
    },
    {
        "school": "Blue Ridge Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141001997",
    },
    {
        "school": "Lakeside High School",
        "district": "Columbia County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141002025",
    },
    {
        "school": "Brookwood Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141002072",
    },
    {
        "school": "Lakeside Middle School",
        "district": "Columbia County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141002073",
    },
    {
        "school": "Stevens Creek Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141002161",
    },
    {
        "school": "Greenbrier Middle School",
        "district": "Columbia County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141002366",
    },
    {
        "school": "Norris Elementary School",
        "district": "McDuffie County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130357000459",
    },
    {
        "school": "Maxwell Elementary School",
        "district": "McDuffie County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130357001349",
    },
    {
        "school": "Thomson Elementary School",
        "district": "McDuffie County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130357001353",
    },
    {
        "school": "Dearing Elementary School",
        "district": "McDuffie County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130357002140",
    },
    {
        "school": "Thomson High School",
        "district": "McDuffie County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130357002183",
    },
    {
        "school": "Goshen Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438000569",
    },
    {
        "school": "Tobacco Road Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438000570",
    },
    {
        "school": "Monte Sano Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001526",
    },
    {
        "school": "Academy of Richmond County High School",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001528",
    },
    {
        "school": "Lamar - Milledge Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001529",
    },
    {
        "school": "Gracewood Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001530",
    },
    {
        "school": "Blythe Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001532",
    },
    {
        "school": "Josey High School",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001533",
    },
    {
        "school": "Johnson Magnet",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001534",
    },
    {
        "school": "Glenn Hills High School",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001536",
    },
    {
        "school": "Bayvale Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001541",
    },
    {
        "school": "Westside High School",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001542",
    },
    {
        "school": "Warren Road Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001546",
    },
    {
        "school": "Merry Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001548",
    },
    {
        "school": "Hephzibah High School",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001549",
    },
    {
        "school": "Glenn Hills Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001550",
    },
    {
        "school": "Copeland Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001551",
    },
    {
        "school": "Barton Chapel Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001552",
    },
    {
        "school": "Hephzibah Middle School",
        "district": "Richmond County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001554",
    },
    {
        "school": "Walker Traditional Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001556",
    },
    {
        "school": "Langford Middle School",
        "district": "Richmond County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001559",
    },
    {
        "school": "Hephzibah Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001560",
    },
    {
        "school": "Garrett Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001561",
    },
    {
        "school": "Butler High School",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001562",
    },
    {
        "school": "Meadowbrook Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001563",
    },
    {
        "school": "Terrace Manor Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001565",
    },
    {
        "school": "Davidson Magnet School",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001567",
    },
    {
        "school": "Dorothy Hains Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001570",
    },
    {
        "school": "Laney High School",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001573",
    },
    {
        "school": "Tutt Middle School",
        "district": "Richmond County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001574",
    },
    {
        "school": "Murphey Middle School",
        "district": "Richmond County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001579",
    },
    {
        "school": "Glenn Hills Middle School",
        "district": "Richmond County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438001817",
    },
    {
        "school": "Jamestown Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438002049",
    },
    {
        "school": "Willis Foreman Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438002088",
    },
    {
        "school": "Spirit Creek Middle School",
        "district": "Richmond County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438002089",
    },
    {
        "school": "McBean Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438002280",
    },
    {
        "school": "Cross Creek High School",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438002339",
    },
    {
        "school": "Lake Forest Hills Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438002340",
    },
    {
        "school": "Sue Reynolds Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438002511",
    },
    {
        "school": "Bainbridge High School",
        "district": "Decatur County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130171000612",
    },
    {
        "school": "Hutto Middle School",
        "district": "Decatur County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130171000613",
    },
    {
        "school": "Bainbridge Middle School",
        "district": "Decatur County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130171000614",
    },
    {
        "school": "West Bainbridge Elementary School",
        "district": "Decatur County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130171000617",
    },
    {
        "school": "Jones-Wheat Elementary School",
        "district": "Decatur County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130171000619",
    },
    {
        "school": "John Johnson Elementary School",
        "district": "Decatur County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130171000620",
    },
    {
        "school": "Potter Street Elementary School",
        "district": "Decatur County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130171002111",
    },
    {
        "school": "Sterling Elementary School",
        "district": "Glynn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240003372",
    },
    {
        "school": "Brantley County Middle School",
        "district": "Brantley County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130048000232",
    },
    {
        "school": "Nahunta Elementary School",
        "district": "Brantley County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130048000234",
    },
    {
        "school": "Hoboken Elementary School",
        "district": "Brantley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130048000257",
    },
    {
        "school": "Brantley County High School",
        "district": "Brantley County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130048000258",
    },
    {
        "school": "Nahunta Primary School",
        "district": "Brantley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130048001946",
    },
    {
        "school": "Waynesville Primary School",
        "district": "Brantley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130048002295",
    },
    {
        "school": "Oglethorpe Point Elementary School",
        "district": "Glynn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240000950",
    },
    {
        "school": "Glyndale Elementary School",
        "district": "Glynn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240001056",
    },
    {
        "school": "Jane Macon Middle",
        "district": "Glynn County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240001058",
    },
    {
        "school": "St. Simons Elementary School",
        "district": "Glynn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240001059",
    },
    {
        "school": "Altama Elementary School",
        "district": "Glynn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240001061",
    },
    {
        "school": "Goodyear Elementary School",
        "district": "Glynn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240001063",
    },
    {
        "school": "Glynn Middle",
        "district": "Glynn County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240001064",
    },
    {
        "school": "Glynn Academy",
        "district": "Glynn County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240001065",
    },
    {
        "school": "Burroughs-Molette Elementary School",
        "district": "Glynn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240001067",
    },
    {
        "school": "Brunswick High School",
        "district": "Glynn County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240001068",
    },
    {
        "school": "Golden Isles Elementary School",
        "district": "Glynn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240002080",
    },
    {
        "school": "Satilla Marsh Elementary School",
        "district": "Glynn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240002191",
    },
    {
        "school": "Greer Elementary School",
        "district": "Glynn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240002192",
    },
    {
        "school": "Needwood Middle School",
        "district": "Glynn County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240002266",
    },
    {
        "school": "Todd Grant Elementary School",
        "district": "McIntosh County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130360001356",
    },
    {
        "school": "McIntosh County Middle School",
        "district": "McIntosh County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130360002412",
    },
    {
        "school": "McIntosh Academy",
        "district": "McIntosh County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130360002413",
    },
    {
        "school": "Sonoraville High School",
        "district": "Gordon County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130243003374",
    },
    {
        "school": "Calhoun High School",
        "district": "Calhoun City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130072000305",
    },
    {
        "school": "Calhoun Middle School",
        "district": "Calhoun City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130072000307",
    },
    {
        "school": "Calhoun Elementary School",
        "district": "Calhoun City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130072002216",
    },
    {
        "school": "Fairmount Elementary School",
        "district": "Gordon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130243001071",
    },
    {
        "school": "Belwood Elementary School",
        "district": "Gordon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130243001072",
    },
    {
        "school": "Swain Elementary School",
        "district": "Gordon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130243001075",
    },
    {
        "school": "Tolbert Elementary School",
        "district": "Gordon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130243001077",
    },
    {
        "school": "Gordon Central High School",
        "district": "Gordon County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130243001959",
    },
    {
        "school": "Red Bud Elementary School",
        "district": "Gordon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130243002081",
    },
    {
        "school": "Ashworth Middle School",
        "district": "Gordon County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130243002175",
    },
    {
        "school": "Cedartown Middle School",
        "district": "Polk County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130420002594",
    },
    {
        "school": "Rockmart Middle School",
        "district": "Polk County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130420003442",
    },
    {
        "school": "Westside Elementary School",
        "district": "Polk County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130420001499",
    },
    {
        "school": "Eastside Elementary School",
        "district": "Polk County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130420001500",
    },
    {
        "school": "Rockmart High School",
        "district": "Polk County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130420001509",
    },
    {
        "school": "Cedartown High School",
        "district": "Polk County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130420001510",
    },
    {
        "school": "Cherokee Elementary School",
        "district": "Polk County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130420001916",
    },
    {
        "school": "Northside Elementary",
        "district": "Polk County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130420002010",
    },
    {
        "school": "Battlefield Primary",
        "district": "Catoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093002496",
    },
    {
        "school": "Woodstation Elementary School",
        "district": "Catoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093003304",
    },
    {
        "school": "Heritage Middle School",
        "district": "Catoosa County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093003305",
    },
    {
        "school": "Heritage High School",
        "district": "Catoosa County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093003688",
    },
    {
        "school": "Chattanooga Valley Middle School",
        "district": "Walker County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537003457",
    },
    {
        "school": "Battlefield Elementary School",
        "district": "Catoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093000346",
    },
    {
        "school": "Cloud Springs Elementary School",
        "district": "Catoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093000347",
    },
    {
        "school": "Lakeview Middle School",
        "district": "Catoosa County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093000348",
    },
    {
        "school": "West Side Elementary School",
        "district": "Catoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093000349",
    },
    {
        "school": "Lakeview-Fort Oglethorpe High School",
        "district": "Catoosa County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093000350",
    },
    {
        "school": "Ringgold Middle School",
        "district": "Catoosa County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093000351",
    },
    {
        "school": "Graysville Elementary School",
        "district": "Catoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093000352",
    },
    {
        "school": "Ringgold High School",
        "district": "Catoosa County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093000353",
    },
    {
        "school": "Ringgold Elementary School",
        "district": "Catoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093000355",
    },
    {
        "school": "Boynton Elementary School",
        "district": "Catoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093000845",
    },
    {
        "school": "Tiger Creek Elementary School",
        "district": "Catoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093001934",
    },
    {
        "school": "Ringgold Primary School",
        "district": "Catoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130093002300",
    },
    {
        "school": "Dade County High School",
        "district": "Dade County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130159000775",
    },
    {
        "school": "Dade Middle School",
        "district": "Dade County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130159000777",
    },
    {
        "school": "Davis Elementary School",
        "district": "Dade County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130159000778",
    },
    {
        "school": "Dade Elementary School",
        "district": "Dade County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130159000868",
    },
    {
        "school": "Chickamauga Elementary School",
        "district": "Chickamauga City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130114000441",
    },
    {
        "school": "Gordon Lee Middle School",
        "district": "Chickamauga City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130114002456",
    },
    {
        "school": "Gordon Lee High School",
        "district": "Chickamauga City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130114002457",
    },
    {
        "school": "Rossville Elementary School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537000661",
    },
    {
        "school": "Gilbert Elementary School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537001051",
    },
    {
        "school": "LaFayette Middle School",
        "district": "Walker County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537001741",
    },
    {
        "school": "Fairyland Elementary School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537001749",
    },
    {
        "school": "Naomi Elementary School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537001751",
    },
    {
        "school": "North LaFayette Elementary School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537001755",
    },
    {
        "school": "Chattanooga Valley Elementary School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537001760",
    },
    {
        "school": "Stone Creek Elementary School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537001762",
    },
    {
        "school": "Rock Spring Elementary School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537001764",
    },
    {
        "school": "Ridgeland High School",
        "district": "Walker County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537002093",
    },
    {
        "school": "LaFayette High School",
        "district": "Walker County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537002286",
    },
    {
        "school": "Cherokee Ridge Elementary",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537002287",
    },
    {
        "school": "Veterans Memorial Middle School",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387003680",
    },
    {
        "school": "Chattahoochee County High School",
        "district": "Chattahoochee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130105003525",
    },
    {
        "school": "Northside High School",
        "district": "Muscogee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387002583",
    },
    {
        "school": "Eagle Ridge Academy",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387003695",
    },
    {
        "school": "Marion County Middle/High School",
        "district": "Marion County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130354001346",
    },
    {
        "school": "L. K. Moss Elementary School",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130354002219",
    },
    {
        "school": "Chattahoochee County Education Center",
        "district": "Chattahoochee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130105000416",
    },
    {
        "school": "Chattahoochee County Middle School",
        "district": "Chattahoochee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130105002358",
    },
    {
        "school": "New Mountain Hill Elementary School",
        "district": "Harris County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130270001188",
    },
    {
        "school": "Park Elementary School",
        "district": "Harris County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130270002007",
    },
    {
        "school": "Pine Ridge Elementary School",
        "district": "Harris County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130270002083",
    },
    {
        "school": "Mulberry Creek Elementary School",
        "district": "Harris County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130270002269",
    },
    {
        "school": "Harris County High School",
        "district": "Harris County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130270002270",
    },
    {
        "school": "Harris County Carver Middle School",
        "district": "Harris County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130270002271",
    },
    {
        "school": "Blackmon Road Middle School",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001376",
    },
    {
        "school": "Shaw High School",
        "district": "Muscogee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001387",
    },
    {
        "school": "Downtown Elementary Magnet Academy",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001388",
    },
    {
        "school": "Fort Middle School",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001394",
    },
    {
        "school": "Hardaway High School",
        "district": "Muscogee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001397",
    },
    {
        "school": "Double Churches Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001398",
    },
    {
        "school": "Rothschild Leadership Academy School",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001399",
    },
    {
        "school": "Richards Middle School",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001400",
    },
    {
        "school": "Key Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001402",
    },
    {
        "school": "Forrest Road Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001404",
    },
    {
        "school": "Britt David Elementary Computer Magnet Academy",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001405",
    },
    {
        "school": "Columbus High School",
        "district": "Muscogee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001406",
    },
    {
        "school": "Clubview Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001411",
    },
    {
        "school": "Blanchard Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001412",
    },
    {
        "school": "Arnold Middle School",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001413",
    },
    {
        "school": "Spencer High School",
        "district": "Muscogee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001418",
    },
    {
        "school": "Reese Road Leadership Academy",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001420",
    },
    {
        "school": "Kendrick High School",
        "district": "Muscogee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001421",
    },
    {
        "school": "Georgetown Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001422",
    },
    {
        "school": "Dimon Elementary",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001425",
    },
    {
        "school": "Wesley Heights Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001427",
    },
    {
        "school": "Jordan Vocational High School",
        "district": "Muscogee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001430",
    },
    {
        "school": "Gentian Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001431",
    },
    {
        "school": "Eddy Middle School",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001432",
    },
    {
        "school": "Dawson Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001433",
    },
    {
        "school": "Waddell Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001434",
    },
    {
        "school": "St. Marys Video and Communication Technology",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001435",
    },
    {
        "school": "Rigdon Road Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001436",
    },
    {
        "school": "Carver High School",
        "district": "Muscogee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001439",
    },
    {
        "school": "Wynnton Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001441",
    },
    {
        "school": "South Columbus Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001444",
    },
    {
        "school": "River Road Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001445",
    },
    {
        "school": "Allen Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001446",
    },
    {
        "school": "Mathews Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001447",
    },
    {
        "school": "Johnson Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001448",
    },
    {
        "school": "Fox Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001449",
    },
    {
        "school": "Lonnie Jackson Academy",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001450",
    },
    {
        "school": "Davis Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387001452",
    },
    {
        "school": "Hannan Elementary",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387002142",
    },
    {
        "school": "Brewer Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387002184",
    },
    {
        "school": "Midland Middle School",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387002337",
    },
    {
        "school": "Martin Luther King- Jr. Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387002419",
    },
    {
        "school": "Baker Middle School",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387002420",
    },
    {
        "school": "East Columbus Magnet Academy",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387002421",
    },
    {
        "school": "Double Churches Middle School",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387002422",
    },
    {
        "school": "Midland Academy",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387002423",
    },
    {
        "school": "Crisp County High School",
        "district": "Crisp County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130156000769",
    },
    {
        "school": "Crisp County Elementary School",
        "district": "Crisp County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130156000771",
    },
    {
        "school": "Crisp County Pre-K",
        "district": "Crisp County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130156000772",
    },
    {
        "school": "Crisp County Middle School",
        "district": "Crisp County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130156001508",
    },
    {
        "school": "Level Grove Elementary School",
        "district": "Habersham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258003401",
    },
    {
        "school": "Habersham Ninth Grade Academy",
        "district": "Habersham County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258003402",
    },
    {
        "school": "Habersham Central High School",
        "district": "Habersham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258001145",
    },
    {
        "school": "North Habersham Middle School",
        "district": "Habersham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258001147",
    },
    {
        "school": "Baldwin Elementary School",
        "district": "Habersham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258001148",
    },
    {
        "school": "Hazel Grove Elementary School",
        "district": "Habersham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258001149",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Habersham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258001150",
    },
    {
        "school": "Demorest Elementary School",
        "district": "Habersham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258001151",
    },
    {
        "school": "Woodville Elementary School",
        "district": "Habersham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258001152",
    },
    {
        "school": "Cornelia Elementary School",
        "district": "Habersham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258001153",
    },
    {
        "school": "South Habersham Middle School",
        "district": "Habersham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258001154",
    },
    {
        "school": "Clarkesville Elementary School",
        "district": "Habersham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258002042",
    },
    {
        "school": "Woodlawn Elementary School",
        "district": "Murray County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130384003434",
    },
    {
        "school": "Blue Ridge Elementary School",
        "district": "Dalton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130162003476",
    },
    {
        "school": "New Hope Middle School",
        "district": "Whitfield County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570003465",
    },
    {
        "school": "Coker Elementary School",
        "district": "Murray County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130384001012",
    },
    {
        "school": "Murray County High School",
        "district": "Murray County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130384001381",
    },
    {
        "school": "Spring Place Elementary School",
        "district": "Murray County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130384001383",
    },
    {
        "school": "Chatsworth Elementary School",
        "district": "Murray County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130384001384",
    },
    {
        "school": "Northwest Elementary School",
        "district": "Murray County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130384001385",
    },
    {
        "school": "Gladden Middle School",
        "district": "Murray County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130384001386",
    },
    {
        "school": "Bagley Middle School",
        "district": "Murray County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130384002086",
    },
    {
        "school": "Eton Elementary School",
        "district": "Murray County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130384002221",
    },
    {
        "school": "Roan Elementary School",
        "district": "Dalton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130162000782",
    },
    {
        "school": "Brookwood Elementary School",
        "district": "Dalton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130162000783",
    },
    {
        "school": "Dalton High School",
        "district": "Dalton Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130162000786",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Dalton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130162000788",
    },
    {
        "school": "Park Creek Elementary School",
        "district": "Dalton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130162002458",
    },
    {
        "school": "Dalton Middle School",
        "district": "Dalton Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130162002459",
    },
    {
        "school": "City Park Elementary School",
        "district": "Dalton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130162002460",
    },
    {
        "school": "Phoenix High School",
        "district": "Whitfield County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001073",
    },
    {
        "school": "Eastbrook Middle School",
        "district": "Whitfield County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001816",
    },
    {
        "school": "Southeast Whitfield County High School",
        "district": "Whitfield County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001818",
    },
    {
        "school": "Northwest Whitfield County High School",
        "district": "Whitfield County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001819",
    },
    {
        "school": "Westside Middle School",
        "district": "Whitfield County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001820",
    },
    {
        "school": "Valley Point Middle School",
        "district": "Whitfield County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001821",
    },
    {
        "school": "North Whitfield Middle School",
        "district": "Whitfield County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001822",
    },
    {
        "school": "Tunnel Hill Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001823",
    },
    {
        "school": "Valley Point Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001824",
    },
    {
        "school": "Dug Gap Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001825",
    },
    {
        "school": "Dawnville Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001826",
    },
    {
        "school": "Westside Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001827",
    },
    {
        "school": "Pleasant Grove Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001828",
    },
    {
        "school": "Cohutta Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001829",
    },
    {
        "school": "Varnell Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001831",
    },
    {
        "school": "Eastside Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001832",
    },
    {
        "school": "Antioch Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570001833",
    },
    {
        "school": "New Hope Elementary School",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570002450",
    },
    {
        "school": "Coffee Middle School",
        "district": "Coffee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135003321",
    },
    {
        "school": "George Washington Carver Freshman Campus",
        "district": "Coffee County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135003323",
    },
    {
        "school": "Pearson Elementary School",
        "district": "Atkinson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130009000013",
    },
    {
        "school": "Atkinson County High School",
        "district": "Atkinson County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130009000015",
    },
    {
        "school": "Willacoochee Elementary School",
        "district": "Atkinson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130009001965",
    },
    {
        "school": "Broxton-Mary Hayes Elementary",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135000576",
    },
    {
        "school": "Nicholls Elementary School",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135000577",
    },
    {
        "school": "Ambrose Elementary School",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135000578",
    },
    {
        "school": "Westside Elementary School",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135000579",
    },
    {
        "school": "Coffee County High School",
        "district": "Coffee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135000581",
    },
    {
        "school": "West Green Elementary School",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135000582",
    },
    {
        "school": "Eastside Elementary School",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135001883",
    },
    {
        "school": "Satilla Elementary School",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135001884",
    },
    {
        "school": "Indian Creek Elementary",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135002306",
    },
    {
        "school": "East Laurens Primary School",
        "district": "Laurens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130189002934",
    },
    {
        "school": "Johnson County High School",
        "district": "Johnson County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130312000055",
    },
    {
        "school": "Johnson County Elementary School",
        "district": "Johnson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130312001697",
    },
    {
        "school": "Johnson County Middle School",
        "district": "Johnson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130312002400",
    },
    {
        "school": "Dublin Middle School",
        "district": "Dublin City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130187000869",
    },
    {
        "school": "Dublin High School",
        "district": "Dublin City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130187000873",
    },
    {
        "school": "Susie Dasher",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130187002217",
    },
    {
        "school": "Northwest Laurens Elementary",
        "district": "Laurens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130189000875",
    },
    {
        "school": "West Laurens Middle School",
        "district": "Laurens County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130189000878",
    },
    {
        "school": "Southwest Laurens Elementary",
        "district": "Laurens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130189000879",
    },
    {
        "school": "East Laurens Elementary School",
        "district": "Laurens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130189000880",
    },
    {
        "school": "East Laurens High School",
        "district": "Laurens County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130189001707",
    },
    {
        "school": "East Laurens Middle School",
        "district": "Laurens County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130189001729",
    },
    {
        "school": "Ben Hill Elementary School",
        "district": "Ben Hill County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130036000190",
    },
    {
        "school": "Fitzgerald High School",
        "district": "Ben Hill County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130036000931",
    },
    {
        "school": "Ben Hill County Primary School",
        "district": "Ben Hill County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130036002148",
    },
    {
        "school": "Ben Hill County Middle School",
        "district": "Ben Hill County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130036002149",
    },
    {
        "school": "Irwin County Middle School",
        "district": "Irwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130291001243",
    },
    {
        "school": "Irwin County Elementary School",
        "district": "Irwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130291001244",
    },
    {
        "school": "Irwin County High School",
        "district": "Irwin County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130291001246",
    },
    {
        "school": "Hunt Elementary School",
        "district": "Peach County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130405001480",
    },
    {
        "school": "Byron Elementary School",
        "district": "Peach County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130405001481",
    },
    {
        "school": "Fort Valley Middle School",
        "district": "Peach County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130405001482",
    },
    {
        "school": "Peach County High School",
        "district": "Peach County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130405001483",
    },
    {
        "school": "Byron Middle School",
        "district": "Peach County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130405001807",
    },
    {
        "school": "Kay Road Elementary",
        "district": "Peach County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130405002143",
    },
    {
        "school": "New Holland Core Knowledge Academy",
        "district": "Gainesville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130231003048",
    },
    {
        "school": "Gainesville Exploration Academy",
        "district": "Gainesville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130231003049",
    },
    {
        "school": "Chestatee High School",
        "district": "Hall County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261002569",
    },
    {
        "school": "Sugar Hill Elementary",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261002570",
    },
    {
        "school": "Flowery Branch High",
        "district": "Hall County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261002571",
    },
    {
        "school": "Lanier College and Career Academy",
        "district": "Hall County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261003403",
    },
    {
        "school": "Chicopee Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261003404",
    },
    {
        "school": "Rocky Branch Elementary School",
        "district": "Oconee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130396002587",
    },
    {
        "school": "North Oconee High School",
        "district": "Oconee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130396003437",
    },
    {
        "school": "Centennial Arts Academy",
        "district": "Gainesville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130231000037",
    },
    {
        "school": "Enota Multiple Intelligences Academy",
        "district": "Gainesville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130231001044",
    },
    {
        "school": "Fair Street International Baccalaureate World School",
        "district": "Gainesville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130231001046",
    },
    {
        "school": "Gainesville High School",
        "district": "Gainesville City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130231001048",
    },
    {
        "school": "Mount Vernon Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261000344",
    },
    {
        "school": "West Hall Middle School",
        "district": "Hall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261000357",
    },
    {
        "school": "Wauka Mountain Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001155",
    },
    {
        "school": "Myers Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001156",
    },
    {
        "school": "Riverbend Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001157",
    },
    {
        "school": "Lanier Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001158",
    },
    {
        "school": "Oakwood Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001159",
    },
    {
        "school": "Flowery Branch Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001160",
    },
    {
        "school": "North Hall High School",
        "district": "Hall County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001161",
    },
    {
        "school": "East Hall High School",
        "district": "Hall County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001162",
    },
    {
        "school": "White Sulphur Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001163",
    },
    {
        "school": "Tadmore Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001164",
    },
    {
        "school": "McEver Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001165",
    },
    {
        "school": "Lyman Hall Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001166",
    },
    {
        "school": "Johnson High School",
        "district": "Hall County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001168",
    },
    {
        "school": "South Hall Middle School",
        "district": "Hall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001169",
    },
    {
        "school": "Sardis Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001171",
    },
    {
        "school": "Lula Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001172",
    },
    {
        "school": "Chestnut Mountain Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001173",
    },
    {
        "school": "Friendship Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261001268",
    },
    {
        "school": "West Hall High School",
        "district": "Hall County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261002043",
    },
    {
        "school": "East Hall Middle School",
        "district": "Hall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261002044",
    },
    {
        "school": "North Hall Middle School",
        "district": "Hall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261002045",
    },
    {
        "school": "Spout Springs Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261002177",
    },
    {
        "school": "C. W. Davis Middle School",
        "district": "Hall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261002326",
    },
    {
        "school": "Chestatee Middle School",
        "district": "Hall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261002327",
    },
    {
        "school": "Martin Elementary School",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261002390",
    },
    {
        "school": "Oconee County High School",
        "district": "Oconee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130396000148",
    },
    {
        "school": "Oconee County Middle School",
        "district": "Oconee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130396000018",
    },
    {
        "school": "Oconee County Elementary School",
        "district": "Oconee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130396001464",
    },
    {
        "school": "Colham Ferry Elementary School",
        "district": "Oconee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130396001465",
    },
    {
        "school": "Malcom Bridge Elementary School",
        "district": "Oconee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130396001765",
    },
    {
        "school": "Oconee County Primary School",
        "district": "Oconee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130396002008",
    },
    {
        "school": "Malcom Bridge Middle School",
        "district": "Oconee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130396002225",
    },
    {
        "school": "Taylors Creek Elementary School",
        "district": "Liberty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330000436",
    },
    {
        "school": "Snelson-Golden Middle School",
        "district": "Liberty County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330001007",
    },
    {
        "school": "Button Gwinnett Elementary School",
        "district": "Liberty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330001301",
    },
    {
        "school": "Bradwell Institute",
        "district": "Liberty County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330001303",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Liberty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330001305",
    },
    {
        "school": "Frank Long Elementary School",
        "district": "Liberty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330001326",
    },
    {
        "school": "Lewis Frasier Middle School",
        "district": "Liberty County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330001736",
    },
    {
        "school": "Lyman Hall Elementary School",
        "district": "Liberty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330001911",
    },
    {
        "school": "Joseph Martin Elementary School",
        "district": "Liberty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330002046",
    },
    {
        "school": "Liberty County High School",
        "district": "Liberty County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330002182",
    },
    {
        "school": "Waldo Pafford Elementary School",
        "district": "Liberty County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330002406",
    },
    {
        "school": "Midway Middle School",
        "district": "Liberty County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130330002504",
    },
    {
        "school": "Long County High School",
        "district": "Long County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130336001371",
    },
    {
        "school": "Smiley Elementary School",
        "district": "Long County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130336002409",
    },
    {
        "school": "Martha Puckett Middle School",
        "district": "Wayne County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130555000673",
    },
    {
        "school": "Arthur Williams Middle School",
        "district": "Wayne County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130555000685",
    },
    {
        "school": "Martha Rawls Smith Elementary School",
        "district": "Wayne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130555000706",
    },
    {
        "school": "Bacon Elementary School",
        "district": "Wayne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130555000716",
    },
    {
        "school": "Jesup Elementary School",
        "district": "Wayne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130555001798",
    },
    {
        "school": "Odum Elementary School",
        "district": "Wayne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130555001799",
    },
    {
        "school": "Wayne County High School",
        "district": "Wayne County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130555001800",
    },
    {
        "school": "Screven Elementary School",
        "district": "Wayne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130555001802",
    },
    {
        "school": "Franklin Forest Elementary",
        "district": "Troup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000103455",
    },
    {
        "school": "Gardner-Newman Middle School",
        "district": "Troup County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000100593",
    },
    {
        "school": "Hollis Hand Elementary School",
        "district": "Troup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000100596",
    },
    {
        "school": "LaGrange High School",
        "district": "Troup County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000100608",
    },
    {
        "school": "Berta Weathersbee Elementary School",
        "district": "Troup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000100643",
    },
    {
        "school": "Hillcrest Elementary School",
        "district": "Troup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000101706",
    },
    {
        "school": "Rosemont Elementary School",
        "district": "Troup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000101710",
    },
    {
        "school": "Long Cane Middle School",
        "district": "Troup County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000101852",
    },
    {
        "school": "Hogansville Elementary School",
        "district": "Troup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000101853",
    },
    {
        "school": "Ethel W. Kight Elementary School",
        "district": "Troup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000101856",
    },
    {
        "school": "West Point Elementary School",
        "district": "Troup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000101962",
    },
    {
        "school": "Troup County High School",
        "district": "Troup County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000101964",
    },
    {
        "school": "Long Cane Elementary School",
        "district": "Troup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000102011",
    },
    {
        "school": "Callaway Middle School",
        "district": "Troup County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000102443",
    },
    {
        "school": "Callaway High School",
        "district": "Troup County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000102444",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042002472",
    },
    {
        "school": "Skyview Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042002473",
    },
    {
        "school": "Vineville Academy",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042002474",
    },
    {
        "school": "Burdell Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042002604",
    },
    {
        "school": "Rutland High School",
        "district": "Bibb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042002610",
    },
    {
        "school": "Rutland Middle School",
        "district": "Bibb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042002620",
    },
    {
        "school": "Howard Middle School",
        "district": "Bibb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042003290",
    },
    {
        "school": "Rosa Taylor Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042003292",
    },
    {
        "school": "Ballard Hudson Middle School",
        "district": "Bibb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042003667",
    },
    {
        "school": "Gray Station Middle School",
        "district": "Jones County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130315003424",
    },
    {
        "school": "T.G. Scott Elementary School",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130372003430",
    },
    {
        "school": "Crawford County High School",
        "district": "Crawford County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130153000080",
    },
    {
        "school": "Crawford County Elementary School",
        "district": "Crawford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130153000766",
    },
    {
        "school": "Crawford County Middle School",
        "district": "Crawford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130153002151",
    },
    {
        "school": "Mary Persons High School",
        "district": "Monroe County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130372001373",
    },
    {
        "school": "Samuel E. Hubbard Elementary School",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130372001374",
    },
    {
        "school": "Alexander II Magnet School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042000198",
    },
    {
        "school": "Bernd Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042000201",
    },
    {
        "school": "Williams Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042000203",
    },
    {
        "school": "Appling Middle School",
        "district": "Bibb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042000212",
    },
    {
        "school": "Lane Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042000218",
    },
    {
        "school": "Springdale Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042000225",
    },
    {
        "school": "Ingram/Pye Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042000226",
    },
    {
        "school": "Heard Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042000230",
    },
    {
        "school": "Hartley Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042000241",
    },
    {
        "school": "Porter Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042000247",
    },
    {
        "school": "Carter Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042000790",
    },
    {
        "school": "Weaver Middle School",
        "district": "Bibb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042001416",
    },
    {
        "school": "Union Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042001869",
    },
    {
        "school": "Westside High School",
        "district": "Bibb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042001918",
    },
    {
        "school": "Central High School",
        "district": "Bibb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042001942",
    },
    {
        "school": "Northeast High School",
        "district": "Bibb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042001943",
    },
    {
        "school": "Southwest High School",
        "district": "Bibb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042001944",
    },
    {
        "school": "Brookdale Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042002096",
    },
    {
        "school": "Miller Magnet Middle School",
        "district": "Bibb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042002234",
    },
    {
        "school": "Gray Elementary School",
        "district": "Jones County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130315001277",
    },
    {
        "school": "Jones County High School",
        "district": "Jones County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130315001279",
    },
    {
        "school": "Dames Ferry Elementary School",
        "district": "Jones County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130315002272",
    },
    {
        "school": "Clifton Ridge Middle School",
        "district": "Jones County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130315002502",
    },
    {
        "school": "Mattie Wells Elementary School",
        "district": "Jones County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130315002503",
    },
    {
        "school": "Twiggs County High School",
        "district": "Twiggs County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130522002446",
    },
    {
        "school": "Hancock Central Middle School",
        "district": "Hancock County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130264003539",
    },
    {
        "school": "Baldwin High School",
        "district": "Baldwin County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130021000158",
    },
    {
        "school": "Oak Hill MS",
        "district": "Baldwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130021002347",
    },
    {
        "school": "Hancock Central High School",
        "district": "Hancock County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130264001178",
    },
    {
        "school": "Lewis Elementary School",
        "district": "Hancock County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130264002006",
    },
    {
        "school": "Norman Park Elementary School",
        "district": "Colquitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000584",
    },
    {
        "school": "Doerun Elementary School",
        "district": "Colquitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000585",
    },
    {
        "school": "Okapilco Elementary School",
        "district": "Colquitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000586",
    },
    {
        "school": "Wright Elementary School",
        "district": "Colquitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000587",
    },
    {
        "school": "CA Gray Junior High School",
        "district": "Colquitt County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000588",
    },
    {
        "school": "Stringfellow Elementary School",
        "district": "Colquitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000589",
    },
    {
        "school": "Funston Elementary School",
        "district": "Colquitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000590",
    },
    {
        "school": "Colquitt County High School",
        "district": "Colquitt County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000591",
    },
    {
        "school": "Sunset Elementary School",
        "district": "Colquitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000594",
    },
    {
        "school": "Willie J. Williams Middle School",
        "district": "Colquitt County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000595",
    },
    {
        "school": "Hamilton Elementary School",
        "district": "Colquitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000597",
    },
    {
        "school": "Cox Elementary School",
        "district": "Colquitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138000598",
    },
    {
        "school": "Odom Elementary School",
        "district": "Colquitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130138001975",
    },
    {
        "school": "Pepperell High School",
        "district": "Floyd County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219003351",
    },
    {
        "school": "Armuchee Elementary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219000882",
    },
    {
        "school": "Pepperell Middle School",
        "district": "Floyd County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219000934",
    },
    {
        "school": "Coosa High School",
        "district": "Floyd County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219000937",
    },
    {
        "school": "Pepperell Primary",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219000938",
    },
    {
        "school": "Johnson Elementary",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219000939",
    },
    {
        "school": "Coosa Middle School",
        "district": "Floyd County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219000940",
    },
    {
        "school": "Glenwood Primary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219000941",
    },
    {
        "school": "Cave Spring Elementary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219000942",
    },
    {
        "school": "Model Elementary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219000943",
    },
    {
        "school": "Garden Lakes Elementary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219000945",
    },
    {
        "school": "Alto Park Elementary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219000949",
    },
    {
        "school": "Pepperell Elementary",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219002260",
    },
    {
        "school": "Model Middle School",
        "district": "Floyd County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219002372",
    },
    {
        "school": "Model High",
        "district": "Floyd County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219002373",
    },
    {
        "school": "Armuchee Middle School",
        "district": "Floyd County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219002374",
    },
    {
        "school": "Armuchee High School",
        "district": "Floyd County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130219002375",
    },
    {
        "school": "Rome High School",
        "district": "Rome City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130444000028",
    },
    {
        "school": "Rome Middle School",
        "district": "Rome City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130444000154",
    },
    {
        "school": "West Central Elementary School",
        "district": "Rome City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130444001595",
    },
    {
        "school": "Elm Street Elementary",
        "district": "Rome City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130444001596",
    },
    {
        "school": "East Central Elementary School",
        "district": "Rome City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130444001599",
    },
    {
        "school": "West End Elementary School",
        "district": "Rome City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130444001605",
    },
    {
        "school": "Saint Marys Middle School",
        "district": "Camden County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078003299",
    },
    {
        "school": "Woodbine Elementary School",
        "district": "Camden County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078000236",
    },
    {
        "school": "Kingsland Elementary School",
        "district": "Camden County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078000237",
    },
    {
        "school": "Saint Marys Elementary School",
        "district": "Camden County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078000313",
    },
    {
        "school": "Camden County High School",
        "district": "Camden County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078000315",
    },
    {
        "school": "David L Rainer Elementary School",
        "district": "Camden County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078000791",
    },
    {
        "school": "Mary Lee Clark Elementary School",
        "district": "Camden County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078000794",
    },
    {
        "school": "Camden Middle School",
        "district": "Camden County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078001875",
    },
    {
        "school": "Sugarmill Elementary",
        "district": "Camden County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078001941",
    },
    {
        "school": "Crooked River Elementary School",
        "district": "Camden County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078001969",
    },
    {
        "school": "Matilda Harris Elementary School",
        "district": "Camden County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078002063",
    },
    {
        "school": "Mamie Lou Gross Elementary School",
        "district": "Camden County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130078002355",
    },
    {
        "school": "Ebenezer Middle School",
        "district": "Effingham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198002550",
    },
    {
        "school": "Blandford Elementary School",
        "district": "Effingham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198003348",
    },
    {
        "school": "Richmond Hill Primary School",
        "district": "Bryan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130057000086",
    },
    {
        "school": "Lanier Primary School",
        "district": "Bryan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130057001872",
    },
    {
        "school": "Richmond Hill High School",
        "district": "Bryan County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130057001873",
    },
    {
        "school": "Bryan County Elementary School",
        "district": "Bryan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130057001948",
    },
    {
        "school": "Richmond Hill Middle School",
        "district": "Bryan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130057002235",
    },
    {
        "school": "Dr. George Washington Carver Elementary School",
        "district": "Bryan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130057002368",
    },
    {
        "school": "Richmond Hill Elementary School",
        "district": "Bryan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130057002389",
    },
    {
        "school": "Bryan County Middle School",
        "district": "Bryan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130057002395",
    },
    {
        "school": "Bryan County High School",
        "district": "Bryan County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130057002396",
    },
    {
        "school": "Georgetown School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000238",
    },
    {
        "school": "DeRenne Middle School",
        "district": "Savannah-Chatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000362",
    },
    {
        "school": "Howard Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000363",
    },
    {
        "school": "Heard Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000364",
    },
    {
        "school": "Gadsden Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000365",
    },
    {
        "school": "Otis J Brock III Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000366",
    },
    {
        "school": "Andrea B Williams Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000370",
    },
    {
        "school": "Largo-Tibet Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000373",
    },
    {
        "school": "Hubert Middle School",
        "district": "Savannah-Chatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000374",
    },
    {
        "school": "Gould Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000375",
    },
    {
        "school": "Beach High School",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000376",
    },
    {
        "school": "White Bluff Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000377",
    },
    {
        "school": "Myers Middle School",
        "district": "Savannah-Chatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000381",
    },
    {
        "school": "Johnson High School",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000382",
    },
    {
        "school": "Jacob G. Smith Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000385",
    },
    {
        "school": "Pulaski Elementary SChool",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000386",
    },
    {
        "school": "Mercer Middle School",
        "district": "Savannah-Chatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000387",
    },
    {
        "school": "Jenkins High School",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000388",
    },
    {
        "school": "Hodge Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000389",
    },
    {
        "school": "Butler Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000392",
    },
    {
        "school": "The STEM Academy at Bartlett",
        "district": "Savannah-Chatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000393",
    },
    {
        "school": "Windsor Forest Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000394",
    },
    {
        "school": "Port Wentworth Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000396",
    },
    {
        "school": "Hesse School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000400",
    },
    {
        "school": "Haven Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000401",
    },
    {
        "school": "Ellis Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000402",
    },
    {
        "school": "Bloomingdale Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000403",
    },
    {
        "school": "Pooler Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000409",
    },
    {
        "school": "Isle of Hope School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000411",
    },
    {
        "school": "Groves High School",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000413",
    },
    {
        "school": "Windsor Forest High School",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102000415",
    },
    {
        "school": "Garden City Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102001419",
    },
    {
        "school": "Coastal Middle School",
        "district": "Savannah-Chatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102002019",
    },
    {
        "school": "Marshpoint Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102002054",
    },
    {
        "school": "Esther F. Garrison School for the Arts",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102002152",
    },
    {
        "school": "West Chatham Middle School",
        "district": "Savannah-Chatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102002242",
    },
    {
        "school": "Southwest Middle School",
        "district": "Savannah-Chatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102002243",
    },
    {
        "school": "Savannah Arts Academy",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102002245",
    },
    {
        "school": "West Chatham Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102002301",
    },
    {
        "school": "Southwest Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102002302",
    },
    {
        "school": "Oglethorpe Charter School",
        "district": "Savannah-Chatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102002303",
    },
    {
        "school": "Marlow Elementary School",
        "district": "Effingham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198000887",
    },
    {
        "school": "Effingham County Middle School",
        "district": "Effingham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198000888",
    },
    {
        "school": "Guyton Elementary School",
        "district": "Effingham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198000889",
    },
    {
        "school": "Effingham County High School",
        "district": "Effingham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198000890",
    },
    {
        "school": "Springfield Elementary School",
        "district": "Effingham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198000891",
    },
    {
        "school": "Rincon Elementary School",
        "district": "Effingham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198000892",
    },
    {
        "school": "Sand Hill Elementary School",
        "district": "Effingham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198001141",
    },
    {
        "school": "Ebenezer Elementary School",
        "district": "Effingham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198001170",
    },
    {
        "school": "South Effingham High School",
        "district": "Effingham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198001594",
    },
    {
        "school": "South Effingham Middle School",
        "district": "Effingham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198001597",
    },
    {
        "school": "South Effingham Elementary School",
        "district": "Effingham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130198001954",
    },
    {
        "school": "Statesboro STEAM Academy",
        "district": "Commission Charter Schools- CCAT School",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000502626",
    },
    {
        "school": "Brooklet Elementary School",
        "district": "Bulloch County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063000277",
    },
    {
        "school": "Portal Middle/High School",
        "district": "Bulloch County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063000281",
    },
    {
        "school": "Stilson Elementary School",
        "district": "Bulloch County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063000283",
    },
    {
        "school": "Statesboro High School",
        "district": "Bulloch County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063000285",
    },
    {
        "school": "Julia P. Bryant Elementary School",
        "district": "Bulloch County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063000287",
    },
    {
        "school": "Sallie Zetterower Elementary School",
        "district": "Bulloch County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063000288",
    },
    {
        "school": "Mattie Lively Elementary School",
        "district": "Bulloch County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063000290",
    },
    {
        "school": "William James Middle School",
        "district": "Bulloch County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063002236",
    },
    {
        "school": "Langston Chapel Elementary School",
        "district": "Bulloch County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063002237",
    },
    {
        "school": "Langston Chapel Middle School",
        "district": "Bulloch County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063002238",
    },
    {
        "school": "Mill Creek Elementary School",
        "district": "Bulloch County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063002296",
    },
    {
        "school": "Southeast Bulloch Middle School",
        "district": "Bulloch County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063002297",
    },
    {
        "school": "Portal Elementary School",
        "district": "Bulloch County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063002298",
    },
    {
        "school": "Leroy Massey Elementary School",
        "district": "Chattooga County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130108003307",
    },
    {
        "school": "Lyerly Elementary School",
        "district": "Chattooga County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130108000417",
    },
    {
        "school": "Chattooga High School",
        "district": "Chattooga County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130108000418",
    },
    {
        "school": "Menlo Elementary School",
        "district": "Chattooga County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130108000421",
    },
    {
        "school": "Summerville Middle School",
        "district": "Chattooga County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130108000422",
    },
    {
        "school": "Trion Elementary School",
        "district": "Trion City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130513002465",
    },
    {
        "school": "Trion Middle School",
        "district": "Trion City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130513002466",
    },
    {
        "school": "Trion High School",
        "district": "Trion City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130513002467",
    },
    {
        "school": "Upson-Lee Middle School",
        "district": "Thomaston-Upson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130528001723",
    },
    {
        "school": "Upson-Lee High School",
        "district": "Thomaston-Upson County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130528001724",
    },
    {
        "school": "Upson-Lee Elementary School",
        "district": "Thomaston-Upson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130528002199",
    },
    {
        "school": "Upson-Lee Primary School",
        "district": "Thomaston-Upson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130528002285",
    },
    {
        "school": "Hand In Hand Primary",
        "district": "Thomas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130489003453",
    },
    {
        "school": "Cross Creek Elementary School",
        "district": "Thomas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130489000592",
    },
    {
        "school": "Garrison-Pilcher Elementary School",
        "district": "Thomas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130489001666",
    },
    {
        "school": "Thomas County Central High School",
        "district": "Thomas County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130489002146",
    },
    {
        "school": "Thomas County Middle School",
        "district": "Thomas County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130489002147",
    },
    {
        "school": "Bishop Hall Charter School",
        "district": "Thomas County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130489002342",
    },
    {
        "school": "Jerger Elementary School",
        "district": "Thomasville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130495001671",
    },
    {
        "school": "Thomasville High School",
        "district": "Thomasville City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130495001673",
    },
    {
        "school": "Harper Elementary School",
        "district": "Thomasville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130495001674",
    },
    {
        "school": "Scott Elementary School",
        "district": "Thomasville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130495001675",
    },
    {
        "school": "MacIntyre Park Middle School",
        "district": "Thomasville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130495001679",
    },
    {
        "school": "G. O. Bailey Elementary School",
        "district": "Tift County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130498001681",
    },
    {
        "school": "Annie Belle Clark Elementary School",
        "district": "Tift County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130498001682",
    },
    {
        "school": "Northside Elementary School",
        "district": "Tift County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130498001684",
    },
    {
        "school": "Len Lastinger Elementary School",
        "district": "Tift County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130498001686",
    },
    {
        "school": "J. T. Reddick Elementary School",
        "district": "Tift County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130498001687",
    },
    {
        "school": "Charles Spencer Elementary School",
        "district": "Tift County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130498001688",
    },
    {
        "school": "Matt Wilson Elementary School",
        "district": "Tift County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130498001689",
    },
    {
        "school": "Omega Elementary School",
        "district": "Tift County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130498001690",
    },
    {
        "school": "Northeast Middle School",
        "district": "Tift County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130498001691",
    },
    {
        "school": "Tift County High School",
        "district": "Tift County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130498002282",
    },
    {
        "school": "Eighth Street Middle School",
        "district": "Tift County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130498002283",
    },
    {
        "school": "Big A Elementary School",
        "district": "Stephens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130456001618",
    },
    {
        "school": "Stephens County High School",
        "district": "Stephens County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130456001619",
    },
    {
        "school": "Stephens County Middle School",
        "district": "Stephens County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130456001624",
    },
    {
        "school": "Toccoa Elementary School",
        "district": "Stephens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130456001845",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Stephens County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130456001987",
    },
    {
        "school": "Quitman Elementary School",
        "district": "Brooks County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130054000141",
    },
    {
        "school": "North Brooks Elementary School",
        "district": "Brooks County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130054000207",
    },
    {
        "school": "Brooks County High School",
        "district": "Brooks County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130054000263",
    },
    {
        "school": "Brooks County Middle School",
        "district": "Brooks County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130054001417",
    },
    {
        "school": "Echols County High School",
        "district": "Echols County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130195000886",
    },
    {
        "school": "Lanier County Primary School",
        "district": "Lanier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130324001297",
    },
    {
        "school": "Lanier County Middle School",
        "district": "Lanier County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130324002402",
    },
    {
        "school": "Lanier County High School",
        "district": "Lanier County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130324002403",
    },
    {
        "school": "Moulton-Branch Elementary School",
        "district": "Lowndes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130339001010",
    },
    {
        "school": "Lowndes High School",
        "district": "Lowndes County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130339001310",
    },
    {
        "school": "Lake Park Elementary School",
        "district": "Lowndes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130339001311",
    },
    {
        "school": "Hahira Middle School",
        "district": "Lowndes County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130339001313",
    },
    {
        "school": "Hahira Elementary School",
        "district": "Lowndes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130339001314",
    },
    {
        "school": "Lowndes Middle School",
        "district": "Lowndes County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130339001315",
    },
    {
        "school": "Clyattville Elementary School",
        "district": "Lowndes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130339001316",
    },
    {
        "school": "Pine Grove Elementary School",
        "district": "Lowndes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130339001317",
    },
    {
        "school": "Dewar Elementary",
        "district": "Lowndes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130339002410",
    },
    {
        "school": "Newbern Middle School",
        "district": "Valdosta City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130531001076",
    },
    {
        "school": "J. L. Lomax Elementary School",
        "district": "Valdosta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130531001728",
    },
    {
        "school": "W.G. Nunn Elementary",
        "district": "Valdosta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130531001730",
    },
    {
        "school": "Valdosta High School",
        "district": "Valdosta City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130531001732",
    },
    {
        "school": "Valdosta Middle School",
        "district": "Valdosta City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130531001734",
    },
    {
        "school": "Pinevale Elementary School",
        "district": "Valdosta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130531001921",
    },
    {
        "school": "Sallas Mahone Elementary",
        "district": "Valdosta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130531002468",
    },
    {
        "school": "Mossy Creek Middle School",
        "district": "Houston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288003661",
    },
    {
        "school": "Lake Joy Primary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288002920",
    },
    {
        "school": "David A. Perdue Primary",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288002921",
    },
    {
        "school": "Lake Joy Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288003618",
    },
    {
        "school": "David A. Perdue Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288000414",
    },
    {
        "school": "Quail Run Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001002",
    },
    {
        "school": "Bonaire Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001218",
    },
    {
        "school": "Thomson Middle School",
        "district": "Houston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001221",
    },
    {
        "school": "Perry High School",
        "district": "Houston County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001222",
    },
    {
        "school": "Northside Middle School",
        "district": "Houston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001223",
    },
    {
        "school": "Huntington Middle School",
        "district": "Houston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001224",
    },
    {
        "school": "Parkwood Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001225",
    },
    {
        "school": "Westside Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001227",
    },
    {
        "school": "Morningside Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001229",
    },
    {
        "school": "Northside High School",
        "district": "Houston County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001230",
    },
    {
        "school": "Centerville Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001231",
    },
    {
        "school": "Tucker Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001232",
    },
    {
        "school": "Kings Chapel Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001233",
    },
    {
        "school": "Lindsey Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001234",
    },
    {
        "school": "Warner Robins Middle School",
        "district": "Houston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001236",
    },
    {
        "school": "Shirley Hills Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001237",
    },
    {
        "school": "Perry Middle School",
        "district": "Houston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001238",
    },
    {
        "school": "Miller Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001239",
    },
    {
        "school": "Warner Robins High School",
        "district": "Houston County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001240",
    },
    {
        "school": "Russell Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001241",
    },
    {
        "school": "Feagin Mill Middle School",
        "district": "Houston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001676",
    },
    {
        "school": "Bonaire Middle School",
        "district": "Houston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288001677",
    },
    {
        "school": "Pearl Stephens Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288002131",
    },
    {
        "school": "Northside Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288002132",
    },
    {
        "school": "Houston County High School",
        "district": "Houston County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288002179",
    },
    {
        "school": "Eagle Springs Elementary",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288002330",
    },
    {
        "school": "Matthew Arthur Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288002331",
    },
    {
        "school": "C. B. Watson Primary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288002498",
    },
    {
        "school": "Patterson Elementary School",
        "district": "Pierce County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130414001494",
    },
    {
        "school": "Pierce County Middle School",
        "district": "Pierce County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130414001808",
    },
    {
        "school": "Blackshear Elementary School",
        "district": "Pierce County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130414001809",
    },
    {
        "school": "Pierce County High School",
        "district": "Pierce County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130414001915",
    },
    {
        "school": "Williams Heights Elementary School",
        "district": "Ware County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130543001393",
    },
    {
        "school": "Center Elementary School",
        "district": "Ware County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130543001395",
    },
    {
        "school": "Ruskin Elementary School",
        "district": "Ware County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130543001403",
    },
    {
        "school": "Wacona Elementary School",
        "district": "Ware County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130543001774",
    },
    {
        "school": "Waresboro Elementary School",
        "district": "Ware County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130543001775",
    },
    {
        "school": "Memorial Drive Elementary School",
        "district": "Ware County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130543001776",
    },
    {
        "school": "Ware County High School",
        "district": "Ware County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130543001777",
    },
    {
        "school": "Ware County Middle School",
        "district": "Ware County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130543001779",
    },
    {
        "school": "Waycross Middle School",
        "district": "Ware County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130543002204",
    },
    {
        "school": "Keoneula Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000291",
    },
    {
        "school": "Pomaikai Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000292",
    },
    {
        "school": "Ke Kula o Ehunuikaimalino",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000287",
    },
    {
        "school": "Kua o ka La - NCPCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000288",
    },
    {
        "school": "Mililani Ike Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000285",
    },
    {
        "school": "Ka Waihona o ka Naauao - New Century PCS",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000286",
    },
    {
        "school": "Kanuikapono Learning Center",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000289",
    },
    {
        "school": "Molokai Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000290",
    },
    {
        "school": "Ernest Bowen DeSilva Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000027",
    },
    {
        "school": "Haaheo Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000028",
    },
    {
        "school": "Hilo High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000029",
    },
    {
        "school": "Hilo Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000030",
    },
    {
        "school": "Hilo Union Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000031",
    },
    {
        "school": "Holualoa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000032",
    },
    {
        "school": "Honaunau Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000033",
    },
    {
        "school": "Honokaa High & Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000034",
    },
    {
        "school": "Hookena Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000035",
    },
    {
        "school": "Prince Jonah Kalanianaole Elementary & Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000036",
    },
    {
        "school": "Chiefess Kapiolani Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000037",
    },
    {
        "school": "Kau High & Pahala Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000038",
    },
    {
        "school": "Kaumana Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000039",
    },
    {
        "school": "Keaau Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000040",
    },
    {
        "school": "Kealakehe Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000041",
    },
    {
        "school": "Keaukaha Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000042",
    },
    {
        "school": "Kohala High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000043",
    },
    {
        "school": "Konawaena Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000044",
    },
    {
        "school": "Konawaena High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000045",
    },
    {
        "school": "Laupahoehoe Community - PCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000046",
    },
    {
        "school": "Mountain View Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000047",
    },
    {
        "school": "Naalehu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000048",
    },
    {
        "school": "Paauilo Elementary & Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000049",
    },
    {
        "school": "Pahoa High & Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000050",
    },
    {
        "school": "Waiakea Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000051",
    },
    {
        "school": "Waiakea High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000052",
    },
    {
        "school": "Waiakea Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000053",
    },
    {
        "school": "Waiakeawaena Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000054",
    },
    {
        "school": "Waimea Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000055",
    },
    {
        "school": "Kahakai Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000232",
    },
    {
        "school": "Pahoa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000234",
    },
    {
        "school": "Kealakehe Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000235",
    },
    {
        "school": "Keonepoko Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000244",
    },
    {
        "school": "Waikoloa Elementary and Middle School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000247",
    },
    {
        "school": "Honokaa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000249",
    },
    {
        "school": "Kohala Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000250",
    },
    {
        "school": "Konawaena Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000252",
    },
    {
        "school": "Kealakehe High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000254",
    },
    {
        "school": "Keaau Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000258",
    },
    {
        "school": "Keaau High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000260",
    },
    {
        "school": "Connections - New Century PCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000262",
    },
    {
        "school": "Kanu o ka Aina - New Century PCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000263",
    },
    {
        "school": "Na Wai Ola - PCS",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000264",
    },
    {
        "school": "West Hawaii Explorations Academy",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000265",
    },
    {
        "school": "Kohala Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000267",
    },
    {
        "school": "Waimea Middle - PCCS",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000268",
    },
    {
        "school": "Innovations - PCS",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000277",
    },
    {
        "school": "Ke Ana Laahana - PCS",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000278",
    },
    {
        "school": "Volcano School of Arts & Sciences - A Community PCS",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000281",
    },
    {
        "school": "Hawaii Academy of Arts & Science PCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000282",
    },
    {
        "school": "Ka Umeke Kaeo - PCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000283",
    },
    {
        "school": "Ke Kula o Nawahiokalaniopuu Iki - Laboratory PCS",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000284",
    },
    {
        "school": "Enchanted Lake Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000001",
    },
    {
        "school": "Hauula Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000002",
    },
    {
        "school": "Heeia Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000003",
    },
    {
        "school": "Kaaawa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000004",
    },
    {
        "school": "Kaelepulu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000005",
    },
    {
        "school": "Kahaluu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000006",
    },
    {
        "school": "Kahuku High & Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000007",
    },
    {
        "school": "Kailua Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000008",
    },
    {
        "school": "Kailua High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000009",
    },
    {
        "school": "Kailua Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000010",
    },
    {
        "school": "Kainalu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000011",
    },
    {
        "school": "Kalaheo High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000012",
    },
    {
        "school": "Kaneohe Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000013",
    },
    {
        "school": "Kapunahala Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000014",
    },
    {
        "school": "Keolu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000015",
    },
    {
        "school": "Governor Samuel Wilder King Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000016",
    },
    {
        "school": "Laie Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000017",
    },
    {
        "school": "Ka'ohao Public Charter School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000018",
    },
    {
        "school": "Maunawili Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000019",
    },
    {
        "school": "Mokapu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000020",
    },
    {
        "school": "Reverend Benjamin Parker Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000021",
    },
    {
        "school": "Blanche Pope Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000022",
    },
    {
        "school": "Puohala Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000023",
    },
    {
        "school": "Sunset Beach Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000024",
    },
    {
        "school": "Waiahole Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000025",
    },
    {
        "school": "Waimanalo Elementary & Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000026",
    },
    {
        "school": "Niihau High & Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000091",
    },
    {
        "school": "Waimea Canyon Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000092",
    },
    {
        "school": "Waimea High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000093",
    },
    {
        "school": "Hawaii School for the Deaf and Blind",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "HI",
        "nces_id": "150003000096",
    },
    {
        "school": "Pohukaina School",
        "district": "Hawaii Department of Education",
        "level": "Not reported",
        "type": "Special education school",
        "state": "HI",
        "nces_id": "150003000097",
    },
    {
        "school": "Olomana School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "HI",
        "nces_id": "150003000098",
    },
    {
        "school": "Mililani Mauka Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000099",
    },
    {
        "school": "Castle High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000100",
    },
    {
        "school": "Aikahi Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000101",
    },
    {
        "school": "Mililani High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000102",
    },
    {
        "school": "Moanalua High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000103",
    },
    {
        "school": "Moanalua Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000104",
    },
    {
        "school": "Mililani Waena Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000105",
    },
    {
        "school": "Mililani Uka Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000106",
    },
    {
        "school": "Makalapa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000107",
    },
    {
        "school": "Leilehua High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000108",
    },
    {
        "school": "Waiau Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000109",
    },
    {
        "school": "Waianae High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000110",
    },
    {
        "school": "Waianae Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000111",
    },
    {
        "school": "Pohakea Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000112",
    },
    {
        "school": "Pearl City Highlands School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000113",
    },
    {
        "school": "Pearl City High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000114",
    },
    {
        "school": "Pearl City Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000115",
    },
    {
        "school": "Palisades Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000116",
    },
    {
        "school": "Nanakuli High & Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000117",
    },
    {
        "school": "Nanakuli Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000118",
    },
    {
        "school": "Nanaikapono Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000119",
    },
    {
        "school": "Momilani Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000120",
    },
    {
        "school": "Mauka Lani Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000121",
    },
    {
        "school": "Manana Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000122",
    },
    {
        "school": "Makakilo Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000123",
    },
    {
        "school": "Makaha Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000124",
    },
    {
        "school": "Maili Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000125",
    },
    {
        "school": "Lehua Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000126",
    },
    {
        "school": "Kaimiloa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000127",
    },
    {
        "school": "Iroquois Point Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000128",
    },
    {
        "school": "Ilima Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000129",
    },
    {
        "school": "Honowai Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000130",
    },
    {
        "school": "Highlands Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000131",
    },
    {
        "school": "Ewa Beach Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000132",
    },
    {
        "school": "Ewa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000133",
    },
    {
        "school": "James Campbell High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000134",
    },
    {
        "school": "Barbers Point Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000135",
    },
    {
        "school": "August Ahrens Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000136",
    },
    {
        "school": "Major Sheldon Wheeler Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000137",
    },
    {
        "school": "Major Sheldon Wheeler Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000138",
    },
    {
        "school": "Gustav H Webling Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000139",
    },
    {
        "school": "Waimalu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000140",
    },
    {
        "school": "Waialua High & Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000141",
    },
    {
        "school": "Waialua Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000142",
    },
    {
        "school": "Wahiawa Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000143",
    },
    {
        "school": "Wahiawa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000144",
    },
    {
        "school": "Sergeant Samuel K Solomon Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000145",
    },
    {
        "school": "Major General William R Shafter Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000146",
    },
    {
        "school": "Alvah A Scott Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000147",
    },
    {
        "school": "Salt Lake Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000148",
    },
    {
        "school": "Red Hill Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000149",
    },
    {
        "school": "Admiral Arthur W Radford High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000150",
    },
    {
        "school": "Pearl Ridge Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000151",
    },
    {
        "school": "Pearl Harbor Kai Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000152",
    },
    {
        "school": "Pearl Harbor Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000153",
    },
    {
        "school": "Admiral Chester W Nimitz Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000154",
    },
    {
        "school": "Mokulele Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000155",
    },
    {
        "school": "Moanalua Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000156",
    },
    {
        "school": "Ahuimanu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000157",
    },
    {
        "school": "Waipahu Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000158",
    },
    {
        "school": "Waipahu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000159",
    },
    {
        "school": "Kalihi Kai Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000160",
    },
    {
        "school": "Waipahu High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000161",
    },
    {
        "school": "Kalihi Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000162",
    },
    {
        "school": "Kalani High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000163",
    },
    {
        "school": "King David Kalakaua Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000164",
    },
    {
        "school": "Princess Victoria Kaiulani Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000165",
    },
    {
        "school": "Kapolei Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000166",
    },
    {
        "school": "Kipapa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000167",
    },
    {
        "school": "Kaala Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000168",
    },
    {
        "school": "Iliahi Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000169",
    },
    {
        "school": "Lt Col Horrace Meek Hickam Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000170",
    },
    {
        "school": "Helemano Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000171",
    },
    {
        "school": "Haleiwa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000172",
    },
    {
        "school": "Daniel K Inouye Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000173",
    },
    {
        "school": "Aliamanu Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000174",
    },
    {
        "school": "Aliamanu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000175",
    },
    {
        "school": "Aiea Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000176",
    },
    {
        "school": "Aiea High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000177",
    },
    {
        "school": "Aiea Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000178",
    },
    {
        "school": "Mayor John H Wilson Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000179",
    },
    {
        "school": "President George Washington Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000180",
    },
    {
        "school": "Waikiki Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000182",
    },
    {
        "school": "Waialae Elementary - PCS",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000183",
    },
    {
        "school": "Robert Louis Stevenson Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000184",
    },
    {
        "school": "Royal Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000185",
    },
    {
        "school": "President Theodore Roosevelt High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000186",
    },
    {
        "school": "Puuhale Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000187",
    },
    {
        "school": "Pauoa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000188",
    },
    {
        "school": "Palolo Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000189",
    },
    {
        "school": "Nuuanu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000190",
    },
    {
        "school": "Noelani Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000191",
    },
    {
        "school": "Niu Valley Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000192",
    },
    {
        "school": "President William McKinley High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000193",
    },
    {
        "school": "Manoa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000194",
    },
    {
        "school": "King William Lunalilo Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000195",
    },
    {
        "school": "Maemae Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000196",
    },
    {
        "school": "President Abraham Lincoln Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000197",
    },
    {
        "school": "Linapuni Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000198",
    },
    {
        "school": "Princess Miriam K Likelike Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000200",
    },
    {
        "school": "King Liholiho Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000201",
    },
    {
        "school": "Lanakila Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000202",
    },
    {
        "school": "Prince Jonah Kuhio Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000203",
    },
    {
        "school": "Koko Head Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000204",
    },
    {
        "school": "Prince David Kawananakoa Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000205",
    },
    {
        "school": "Kauluwela Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000206",
    },
    {
        "school": "Kapalama Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000207",
    },
    {
        "school": "Kamiloiki Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000208",
    },
    {
        "school": "Kalihi Waena Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000209",
    },
    {
        "school": "Kalihi Uka Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000210",
    },
    {
        "school": "Kaimuki Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000211",
    },
    {
        "school": "Kaimuki High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000212",
    },
    {
        "school": "President Thomas Jefferson Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000213",
    },
    {
        "school": "Hokulani Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000214",
    },
    {
        "school": "Kahala Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000215",
    },
    {
        "school": "Kaewai Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000216",
    },
    {
        "school": "Queen Kaahumanu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000217",
    },
    {
        "school": "William P Jarrett Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000218",
    },
    {
        "school": "Hahaione Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000219",
    },
    {
        "school": "Mayor Joseph J Fern Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000220",
    },
    {
        "school": "Governor Wallace Rider Farrington High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000221",
    },
    {
        "school": "Governor Sanford B Dole Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000222",
    },
    {
        "school": "Central Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000223",
    },
    {
        "school": "Aliiolani Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000225",
    },
    {
        "school": "Ala Wai Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000226",
    },
    {
        "school": "Aina Haina Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000227",
    },
    {
        "school": "Henry J Kaiser High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000228",
    },
    {
        "school": "Waianae Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000229",
    },
    {
        "school": "Leihoku Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000230",
    },
    {
        "school": "Kanoelani Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000231",
    },
    {
        "school": "Kahuku Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000236",
    },
    {
        "school": "Kaleiopuu Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000239",
    },
    {
        "school": "Kamaile Academy PCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000240",
    },
    {
        "school": "Anuenue School",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000246",
    },
    {
        "school": "Holomua Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000248",
    },
    {
        "school": "Mililani Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000256",
    },
    {
        "school": "Waikele Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000257",
    },
    {
        "school": "Kapolei Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000259",
    },
    {
        "school": "Kapolei High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000261",
    },
    {
        "school": "Halau Ku Mana - A New Century PCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000270",
    },
    {
        "school": "Voyager - A Public Charter School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000271",
    },
    {
        "school": "University Laboratory School",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000273",
    },
    {
        "school": "Myron B. Thompson Academy - A New Century PCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000274",
    },
    {
        "school": "Hakipuu Learning Center",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000275",
    },
    {
        "school": "Ke Kula o Samuel M Kamakau - A Laboratory PCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000276",
    },
    {
        "school": "Eleele Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000081",
    },
    {
        "school": "Hanalei Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000082",
    },
    {
        "school": "Kalaheo Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000083",
    },
    {
        "school": "Kapaa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000084",
    },
    {
        "school": "Kapaa High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000085",
    },
    {
        "school": "Kauai High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000086",
    },
    {
        "school": "Kekaha Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000088",
    },
    {
        "school": "Kilauea Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000089",
    },
    {
        "school": "Koloa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000090",
    },
    {
        "school": "Elsie H Wilcox Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000094",
    },
    {
        "school": "King Kaumualii Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000242",
    },
    {
        "school": "Kapaa Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000255",
    },
    {
        "school": "Chiefess Kamakahelei Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000266",
    },
    {
        "school": "Kula Aupuni Niihau A Kahelelani Aloha - NCPCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000269",
    },
    {
        "school": "Ke Kula Niihau o Kekaha Learning Center - A Laboratory PCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000280",
    },
    {
        "school": "Henry Perrine Baldwin High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000056",
    },
    {
        "school": "Haiku Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000057",
    },
    {
        "school": "Hana High & Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000058",
    },
    {
        "school": "Iao Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000059",
    },
    {
        "school": "Kahului Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000060",
    },
    {
        "school": "King Kamehameha III Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000061",
    },
    {
        "school": "Kaunakakai Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000062",
    },
    {
        "school": "Kihei Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000064",
    },
    {
        "school": "Kilohana Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000065",
    },
    {
        "school": "Kualapuu School - Public Conversion Charter",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000066",
    },
    {
        "school": "Kula Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000067",
    },
    {
        "school": "Lahaina Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000068",
    },
    {
        "school": "Lahainaluna High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000069",
    },
    {
        "school": "Lanai High & Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000070",
    },
    {
        "school": "Lihikai Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000071",
    },
    {
        "school": "Makawao Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000072",
    },
    {
        "school": "Maui High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000073",
    },
    {
        "school": "Maunaloa Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000074",
    },
    {
        "school": "Molokai High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000075",
    },
    {
        "school": "Paia Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000076",
    },
    {
        "school": "Pukalani Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000077",
    },
    {
        "school": "Waihee Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000079",
    },
    {
        "school": "Wailuku Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000080",
    },
    {
        "school": "Samuel Enoka Kalama Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000233",
    },
    {
        "school": "Princess Nahienaena Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000237",
    },
    {
        "school": "Lokelani Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000238",
    },
    {
        "school": "Maui Waena Intermediate School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000241",
    },
    {
        "school": "King Kekaulike High School",
        "district": "Hawaii Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000251",
    },
    {
        "school": "Kamalii Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000253",
    },
    {
        "school": "Kihei Charter School",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000279",
    },
    {
        "school": "Eagle Grove Elementary",
        "district": "Eagle Grove Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190999001537",
    },
    {
        "school": "Early Childhood Center",
        "district": "Independence Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191458001318",
    },
    {
        "school": "McGregor Intermediate School",
        "district": "MFL MarMac Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191812001484",
    },
    {
        "school": "Prescott Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948001456",
    },
    {
        "school": "North Central Junior High School",
        "district": "Iowa City Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470001392",
    },
    {
        "school": "Grant Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654001490",
    },
    {
        "school": "Lenihan Intermediate School",
        "district": "Marshalltown Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191872001404",
    },
    {
        "school": "South Union Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897001472",
    },
    {
        "school": "Webster Elementary School",
        "district": "Urbandale Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192868001413",
    },
    {
        "school": "Gilbert Middle School",
        "district": "Gilbert Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191251001471",
    },
    {
        "school": "South Tama County Elementary School",
        "district": "South Tama County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192673001463",
    },
    {
        "school": "Carrie Lee Elementary",
        "district": "Decorah Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190873001501",
    },
    {
        "school": "Parkersburg Elementary School",
        "district": "Aplington-Parkersburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190375001336",
    },
    {
        "school": "Aplington Parkersburg High School",
        "district": "Aplington-Parkersburg Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190375001337",
    },
    {
        "school": "Clayton Ridge Middle School",
        "district": "Clayton Ridge Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191335000751",
    },
    {
        "school": "Denison Alternative High School",
        "district": "Denison Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "190891000915",
    },
    {
        "school": "North Elementary School",
        "district": "Central Decatur Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190690000816",
    },
    {
        "school": "Little Husky Learning Center",
        "district": "Oelwein Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192163000706",
    },
    {
        "school": "West Central Charter High School",
        "district": "West Central Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193087001353",
    },
    {
        "school": "Alden Elementary School",
        "district": "Alden Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190003201317",
    },
    {
        "school": "The Cougars Den",
        "district": "AGWSR Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190306001383",
    },
    {
        "school": "WisdomQuest Education Center",
        "district": "Mount Pleasant Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "191989001015",
    },
    {
        "school": "Little Rock Elementary School",
        "district": "George-Little Rock Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191248001010",
    },
    {
        "school": "George-Little Rock Middle School",
        "district": "George-Little Rock Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191248001011",
    },
    {
        "school": "Pleasantville Middle School",
        "district": "Pleasantville Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192316001403",
    },
    {
        "school": "West Monona Middle Sch",
        "district": "West Monona Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193111000738",
    },
    {
        "school": "Albia Middle School",
        "district": "Albia Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190327001406",
    },
    {
        "school": "Individualized Learning Center",
        "district": "Le Mars Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "191653001101",
    },
    {
        "school": "Creston Middle School",
        "district": "Creston Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190831001237",
    },
    {
        "school": "Creston Elementary School",
        "district": "Creston Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190831001421",
    },
    {
        "school": "Belmond-Klemme Alternative School",
        "district": "Belmond-Klemme Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "190468001436",
    },
    {
        "school": "Nodaway Valley Middle School",
        "district": "Nodaway Valley Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191311000170",
    },
    {
        "school": "Nodaway Valley Elementary School",
        "district": "Nodaway Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191311000786",
    },
    {
        "school": "Nodaway Valley High School",
        "district": "Nodaway Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191311000788",
    },
    {
        "school": "Orient Elementary School",
        "district": "Orient-Macksburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192181001298",
    },
    {
        "school": "Orient-Macksburg Senior High School",
        "district": "Orient-Macksburg Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192181001299",
    },
    {
        "school": "Corning Elementary School",
        "district": "Corning Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190813000403",
    },
    {
        "school": "Southwest Valley High school",
        "district": "Corning Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190813000404",
    },
    {
        "school": "East Campus Elementary School",
        "district": "Allamakee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190339000036",
    },
    {
        "school": "Waukon High School",
        "district": "Allamakee Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190339000038",
    },
    {
        "school": "Waukon Middle School",
        "district": "Allamakee Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190339000039",
    },
    {
        "school": "West Campus Elementary School",
        "district": "Allamakee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190339000040",
    },
    {
        "school": "Kee High School",
        "district": "Eastern Allamakee Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191041000663",
    },
    {
        "school": "Lansing Middle School",
        "district": "Eastern Allamakee Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191041000665",
    },
    {
        "school": "New Albin Elementary School",
        "district": "Eastern Allamakee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191041000666",
    },
    {
        "school": "Cora B Darling Elementary",
        "district": "Postville Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192334001377",
    },
    {
        "school": "John R Mott Jr/Hi School",
        "district": "Postville Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192334001378",
    },
    {
        "school": "Centerville High School",
        "district": "Centerville Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190675000275",
    },
    {
        "school": "Central Ward Elementary School",
        "district": "Centerville Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190675000276",
    },
    {
        "school": "Howar Middle School",
        "district": "Centerville Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190675000279",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Centerville Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190675000280",
    },
    {
        "school": "Moravia Elementary School",
        "district": "Moravia Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191971001156",
    },
    {
        "school": "Moravia High School",
        "district": "Moravia Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191971001157",
    },
    {
        "school": "Moulton Elementary School",
        "district": "Moulton-Udell Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191980001163",
    },
    {
        "school": "Moulton-Udell High School",
        "district": "Moulton-Udell Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191980001164",
    },
    {
        "school": "Audubon Elementary School",
        "district": "Audubon Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190396000095",
    },
    {
        "school": "Audubon Middle-High School",
        "district": "Audubon Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190396000096",
    },
    {
        "school": "East Buchanan Elementary School",
        "district": "East Buchanan Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191011000642",
    },
    {
        "school": "East Buchanan High School",
        "district": "East Buchanan Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191011000643",
    },
    {
        "school": "East Buchanan Middle School",
        "district": "East Buchanan Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191011000644",
    },
    {
        "school": "East Elementary School",
        "district": "Independence Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191458000865",
    },
    {
        "school": "Independence Junior Senior High School",
        "district": "Independence Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191458000866",
    },
    {
        "school": "West Elementary School",
        "district": "Independence Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191458000869",
    },
    {
        "school": "Jesup Elementary School",
        "district": "Jesup Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191533000923",
    },
    {
        "school": "Jesup High School",
        "district": "Jesup Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191533000924",
    },
    {
        "school": "Prairie Grove Elementary School",
        "district": "Jesup Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191533002016",
    },
    {
        "school": "Triumph Elementary School",
        "district": "Jesup Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191533002017",
    },
    {
        "school": "Jesup Middle School",
        "district": "Jesup Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191533002051",
    },
    {
        "school": "Perry #1 Elementary School",
        "district": "Jesup Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191533002057",
    },
    {
        "school": "North Butler Elementary",
        "district": "North Butler Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190345000042",
    },
    {
        "school": "Aplington Elementary School",
        "district": "Aplington-Parkersburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190375000081",
    },
    {
        "school": "Aplington / Parkersburg Middle School",
        "district": "Aplington-Parkersburg Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190375000082",
    },
    {
        "school": "Clarksville Elementary School",
        "district": "Clarksville Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190744000354",
    },
    {
        "school": "Clarksville High School",
        "district": "Clarksville Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190744000355",
    },
    {
        "school": "South Central Calhoun High School",
        "district": "South Central Calhoun Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002400961",
    },
    {
        "school": "Manson Northwest Webster Elementary",
        "district": "Manson Northwest Webster Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191833001052",
    },
    {
        "school": "Manson Northwest Webster Junior High/High School",
        "district": "Manson Northwest Webster Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191833001053",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Carroll Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190633000217",
    },
    {
        "school": "Carroll High School",
        "district": "Carroll Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190633000218",
    },
    {
        "school": "Adams Elementary School",
        "district": "Carroll Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190633000522",
    },
    {
        "school": "Carroll Middle School",
        "district": "Carroll Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190633001989",
    },
    {
        "school": "CR-B Elementary School",
        "district": "Coon Rapids-Bayard Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190807000401",
    },
    {
        "school": "Coon Rapids-Bayard 5-12 Attendance Center",
        "district": "Coon Rapids-Bayard Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190807000402",
    },
    {
        "school": "Glidden-Ralston Elementary School",
        "district": "Glidden-Ralston Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191275000771",
    },
    {
        "school": "Glidden-Ralston Jr-Sr High School",
        "district": "Glidden-Ralston Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191275000772",
    },
    {
        "school": "Atlantic High School",
        "district": "Atlantic Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190393000090",
    },
    {
        "school": "Atlantic Middle School",
        "district": "Atlantic Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190393000093",
    },
    {
        "school": "Washington Elementary School",
        "district": "Atlantic Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190393000094",
    },
    {
        "school": "Schuler Elementary School",
        "district": "Atlantic Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190393000412",
    },
    {
        "school": "CAM South Elementary School",
        "district": "CAM Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190594000199",
    },
    {
        "school": "CAM Middle School",
        "district": "CAM Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190594000200",
    },
    {
        "school": "Griswold Middle/High School",
        "district": "Griswold Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191323000796",
    },
    {
        "school": "Bennett Elementary School",
        "district": "Bennett Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190474000134",
    },
    {
        "school": "Durant Elementary School",
        "district": "Durant Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190960000629",
    },
    {
        "school": "Durant High School",
        "district": "Durant Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190960000630",
    },
    {
        "school": "Durant Middle School",
        "district": "Durant Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190960000631",
    },
    {
        "school": "North Cedar Mechanicsville Elem Ctr",
        "district": "North Cedar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191710001000",
    },
    {
        "school": "North Cedar Jr/Sr High School",
        "district": "North Cedar Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191710001001",
    },
    {
        "school": "North Cedar Lowden Elementary Center",
        "district": "North Cedar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191710001947",
    },
    {
        "school": "Tipton Middle School",
        "district": "Tipton Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192787000290",
    },
    {
        "school": "Tipton Elementary School",
        "district": "Tipton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192787001621",
    },
    {
        "school": "Tipton High School",
        "district": "Tipton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192787001622",
    },
    {
        "school": "Hoover Elementary School",
        "district": "West Branch Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193075001771",
    },
    {
        "school": "West Branch Middle School",
        "district": "West Branch Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193075001773",
    },
    {
        "school": "West Branch High School",
        "district": "West Branch Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193075001774",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Cherokee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190717000332",
    },
    {
        "school": "Washington High School",
        "district": "Cherokee Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190717000333",
    },
    {
        "school": "Cherokee Middle School",
        "district": "Cherokee Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190717000335",
    },
    {
        "school": "MMCRU  High School",
        "district": "Marcus-Meriden-Cleghorn Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191863001072",
    },
    {
        "school": "Nashua-Plainfield Elementary School",
        "district": "Nashua-Plainfield Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192019001196",
    },
    {
        "school": "Nashua-Plainfield Junior-SeniorHigh School",
        "district": "Nashua-Plainfield Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192019001197",
    },
    {
        "school": "New Hampton Elementary School",
        "district": "New Hampton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192034001205",
    },
    {
        "school": "New Hampton High School",
        "district": "New Hampton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192034001206",
    },
    {
        "school": "New Hampton Middle School",
        "district": "New Hampton Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192034001922",
    },
    {
        "school": "Clarke Community High School",
        "district": "Clarke Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190741000349",
    },
    {
        "school": "Clarke Middle School",
        "district": "Clarke Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190741000350",
    },
    {
        "school": "Clarke Community Elementary School",
        "district": "Clarke Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190741000351",
    },
    {
        "school": "Murray Elementary School",
        "district": "Murray Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192010001180",
    },
    {
        "school": "Murray Jr/Sr High",
        "district": "Murray Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192010001181",
    },
    {
        "school": "Central Middle School/High School",
        "district": "Central Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190684000292",
    },
    {
        "school": "Central Elementary",
        "district": "Central Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190684000293",
    },
    {
        "school": "Edgewood-Colesburg High School",
        "district": "Edgewood-Colesburg Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191050000670",
    },
    {
        "school": "Clayton Ridge High School",
        "district": "Clayton Ridge Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191335000806",
    },
    {
        "school": "Clayton Ridge Elementary School",
        "district": "Clayton Ridge Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191335000807",
    },
    {
        "school": "MFL MarMac HS",
        "district": "MFL MarMac Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191812001036",
    },
    {
        "school": "MFL MarMac Elementary School",
        "district": "MFL MarMac Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191812001038",
    },
    {
        "school": "MFL MarMac Middle School",
        "district": "MFL MarMac Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191812001068",
    },
    {
        "school": "Starmont Elementary School",
        "district": "Starmont Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192727001591",
    },
    {
        "school": "Starmont High School",
        "district": "Starmont Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192727001592",
    },
    {
        "school": "Starmont Middle School",
        "district": "Starmont Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192727001593",
    },
    {
        "school": "Westside Junior-Senior High School",
        "district": "Ar-We-Va Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190378000085",
    },
    {
        "school": "Charter Oak-Ute Junior High School",
        "district": "Charter Oak-Ute Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190711000328",
    },
    {
        "school": "Denison High School",
        "district": "Denison Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190891000508",
    },
    {
        "school": "Denison Middle School",
        "district": "Denison Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190891000509",
    },
    {
        "school": "Denison Elementary School",
        "district": "Denison Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190891000511",
    },
    {
        "school": "IKM-Manning Middle School",
        "district": "IKM-Manning Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191488000912",
    },
    {
        "school": "Schleswig Middle School",
        "district": "Schleswig Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192541001451",
    },
    {
        "school": "Schleswig Elementary School",
        "district": "Schleswig Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192541001452",
    },
    {
        "school": "Davis County Elementary",
        "district": "Davis County Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190861000059",
    },
    {
        "school": "Davis County Community High School",
        "district": "Davis County Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190861000492",
    },
    {
        "school": "Davis County Middle School",
        "district": "Davis County Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190861000493",
    },
    {
        "school": "Central Decatur MS/HS High School",
        "district": "Central Decatur Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190690000297",
    },
    {
        "school": "South Elementary School",
        "district": "Central Decatur Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190690000300",
    },
    {
        "school": "Lamoni Elementary School",
        "district": "Lamoni Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191632000974",
    },
    {
        "school": "Lamoni High School",
        "district": "Lamoni Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191632000975",
    },
    {
        "school": "Lamoni Middle School",
        "district": "Lamoni Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191632002019",
    },
    {
        "school": "Mormon Trail Jr-Sr High School",
        "district": "Mormon Trail Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191974001160",
    },
    {
        "school": "Edgewood-Colesburg Elementary School",
        "district": "Edgewood-Colesburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191050000669",
    },
    {
        "school": "Maquoketa Valley Middle School",
        "district": "Maquoketa Valley Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191854000725",
    },
    {
        "school": "Delhi Elementary School",
        "district": "Maquoketa Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191854001064",
    },
    {
        "school": "Earlville Elementary School",
        "district": "Maquoketa Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191854001065",
    },
    {
        "school": "Johnston Elementary School",
        "district": "Maquoketa Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191854001066",
    },
    {
        "school": "Maquoketa Valley Senior High School",
        "district": "Maquoketa Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191854001067",
    },
    {
        "school": "Lambert Elementary School",
        "district": "West Delaware County Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193090001782",
    },
    {
        "school": "West Delaware High School",
        "district": "West Delaware County Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193090001786",
    },
    {
        "school": "West Delaware Middle School",
        "district": "West Delaware County Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193090001787",
    },
    {
        "school": "North Union High School",
        "district": "North Union Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190385001899",
    },
    {
        "school": "Demoney Elementary",
        "district": "Estherville Lincoln Central Com Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191107000684",
    },
    {
        "school": "Estherville Lincoln Central High School",
        "district": "Estherville Lincoln Central Com Sch Dist",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191107000685",
    },
    {
        "school": "Estherville Lincoln Central Middle School",
        "district": "Estherville Lincoln Central Com Sch Dist",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191107000686",
    },
    {
        "school": "North Fayette Valley High School",
        "district": "North Fayette Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190000601232",
    },
    {
        "school": "West Union  Elementary School",
        "district": "North Fayette Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190000601234",
    },
    {
        "school": "Oelwein High School",
        "district": "Oelwein Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192163001288",
    },
    {
        "school": "Oelwein Middle School",
        "district": "Oelwein Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192163001289",
    },
    {
        "school": "Wings Park Elementary School",
        "district": "Oelwein Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192163001292",
    },
    {
        "school": "West Central PK - 8 School",
        "district": "West Central Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193087001778",
    },
    {
        "school": "Charles City High School",
        "district": "Charles City Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190708000319",
    },
    {
        "school": "Charles City MS",
        "district": "Charles City Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190708000320",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Charles City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190708000323",
    },
    {
        "school": "RRMR Elementary School",
        "district": "Rudd-Rockford-Marble Rk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192496001430",
    },
    {
        "school": "Rockford Junior-Senior Rockford Senior High",
        "district": "Rudd-Rockford-Marble Rk Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192496001431",
    },
    {
        "school": "CAL Elementary School",
        "district": "CAL Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190597000203",
    },
    {
        "school": "Hampton-Dumont High School",
        "district": "Hampton-Dumont Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191347000813",
    },
    {
        "school": "Hampton-Dumont Middle School",
        "district": "Hampton-Dumont Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191347000814",
    },
    {
        "school": "North Side Elementary School",
        "district": "Hampton-Dumont Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191347000817",
    },
    {
        "school": "South Side Elementary School",
        "district": "Hampton-Dumont Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191347000819",
    },
    {
        "school": "West Fork  Elementary Sheffield",
        "district": "West Fork Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192592001467",
    },
    {
        "school": "West Fork High School",
        "district": "West Fork Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192592001468",
    },
    {
        "school": "Fremont-Mills Middle And Senior High School",
        "district": "Fremont-Mills Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191212000745",
    },
    {
        "school": "Fremont-Mills Elementary School",
        "district": "Fremont-Mills Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191212000747",
    },
    {
        "school": "Marnie Simons Elementary School",
        "district": "Hamburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191344000812",
    },
    {
        "school": "Sidney Elementary School",
        "district": "Sidney Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192625001488",
    },
    {
        "school": "Sidney High School",
        "district": "Sidney Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192625001489",
    },
    {
        "school": "Greene County Elementary",
        "district": "Greene County Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191521000076",
    },
    {
        "school": "Greene County High School",
        "district": "Greene County Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191521000918",
    },
    {
        "school": "Greene County Middle School",
        "district": "Greene County Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191521000919",
    },
    {
        "school": "Paton-Churdan Elementary",
        "district": "Paton-Churdan Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192238001338",
    },
    {
        "school": "Paton-Churdan Jr-Sr High School",
        "district": "Paton-Churdan Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192238001339",
    },
    {
        "school": "AGWSR Middle School",
        "district": "AGWSR Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190306000634",
    },
    {
        "school": "South Hamilton Elem",
        "district": "South Hamilton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192664001547",
    },
    {
        "school": "South Hamilton Middle And High School",
        "district": "South Hamilton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192664001549",
    },
    {
        "school": "Stratford Elementary",
        "district": "Stratford Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192748001603",
    },
    {
        "school": "Pleasant View Elementary School",
        "district": "Webster City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193063001760",
    },
    {
        "school": "Sunset Heights Elementary School",
        "district": "Webster City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193063001763",
    },
    {
        "school": "Webster City High School",
        "district": "Webster City Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193063001764",
    },
    {
        "school": "Webster City Middle School",
        "district": "Webster City Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193063001765",
    },
    {
        "school": "West Hancock Elementary School",
        "district": "West Hancock Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190543000171",
    },
    {
        "school": "West Hancock High School",
        "district": "West Hancock Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190543000172",
    },
    {
        "school": "West Hancock Middle School",
        "district": "West Hancock Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190543000928",
    },
    {
        "school": "Garner-Hayfield-Ventura Elementary School",
        "district": "Garner-Hayfield-Ventura Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191233000752",
    },
    {
        "school": "Garner-Hayfield-Ventura High School",
        "district": "Garner-Hayfield-Ventura Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191233000753",
    },
    {
        "school": "AGWSR Elementary School",
        "district": "AGWSR Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190306000003",
    },
    {
        "school": "AGWSR High School",
        "district": "AGWSR Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190306000004",
    },
    {
        "school": "Eldora-New Providence Elementary School",
        "district": "Eldora-New Providence Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191069001912",
    },
    {
        "school": "South Hardin High School",
        "district": "Eldora-New Providence Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191069002048",
    },
    {
        "school": "South Hardin Middle School",
        "district": "Hubbard-Radcliffe Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191431001390",
    },
    {
        "school": "Hubbard-Radcliffe Elementary School",
        "district": "Hubbard-Radcliffe Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191431002038",
    },
    {
        "school": "Iowa Falls - Alden High School",
        "district": "Iowa Falls Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191473000904",
    },
    {
        "school": "Riverbend Middle School",
        "district": "Iowa Falls Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191473000905",
    },
    {
        "school": "Rock Run Elementary",
        "district": "Iowa Falls Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191473000907",
    },
    {
        "school": "Pineview Elementary",
        "district": "Iowa Falls Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191473000908",
    },
    {
        "school": "Harlan Elementary School",
        "district": "Mount Pleasant Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191989001169",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Mount Pleasant Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191989001170",
    },
    {
        "school": "Mount Pleasant High School",
        "district": "Mount Pleasant Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191989001172",
    },
    {
        "school": "Mount Pleasant Middle School",
        "district": "Mount Pleasant Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191989001173",
    },
    {
        "school": "Salem Elementary School",
        "district": "Mount Pleasant Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191989001175",
    },
    {
        "school": "Van Allen Elementary School",
        "district": "Mount Pleasant Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191989001177",
    },
    {
        "school": "Clark Elementary School",
        "district": "New London Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192046001209",
    },
    {
        "school": "New London Jr-Sr High School",
        "district": "New London Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192046001210",
    },
    {
        "school": "WACO High School",
        "district": "Waco Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192949001684",
    },
    {
        "school": "Winfield Elementary School",
        "district": "Winfield-Mt Union Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193183001851",
    },
    {
        "school": "Winfield-Mt Union Jr-Sr High School",
        "district": "Winfield-Mt Union Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193183001852",
    },
    {
        "school": "Crestwood Elementary School",
        "district": "Howard-Winneshiek Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191428000848",
    },
    {
        "school": "Crestwood High School",
        "district": "Howard-Winneshiek Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191428000849",
    },
    {
        "school": "Riceville Elementary School",
        "district": "Riceville Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192415001409",
    },
    {
        "school": "Riceville High School",
        "district": "Riceville Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192415001410",
    },
    {
        "school": "Gilmore City Elementary School",
        "district": "Gilmore City-Bradgate Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191260000762",
    },
    {
        "school": "Clyde D Mease Elementary School",
        "district": "Humboldt Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191437000858",
    },
    {
        "school": "Humboldt High School",
        "district": "Humboldt Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191437000859",
    },
    {
        "school": "Humboldt Middle School",
        "district": "Humboldt Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191437000860",
    },
    {
        "school": "Taft Elementary School",
        "district": "Humboldt Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191437000861",
    },
    {
        "school": "Twin Rivers Elementary School",
        "district": "Twin Rivers Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192820001644",
    },
    {
        "school": "Galva-Holstein Elementary School",
        "district": "Galva-Holstein Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191223001959",
    },
    {
        "school": "Ridge View High School",
        "district": "Galva-Holstein Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191223001960",
    },
    {
        "school": "Odebolt Arthur Battle Creek Ida Grove Middle School",
        "district": "Odebolt Arthur Battle Creek Ida Grove Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192160001285",
    },
    {
        "school": "English Valleys Jr-Sr High School",
        "district": "English Valleys Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191098000679",
    },
    {
        "school": "English Valleys Elementary School",
        "district": "English Valleys Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191098000680",
    },
    {
        "school": "H-L-V Junior-Senior High School",
        "district": "H-L-V Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191338000808",
    },
    {
        "school": "H-L-V Elementary School",
        "district": "H-L-V Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191338001993",
    },
    {
        "school": "Iowa Valley Elementary School",
        "district": "Iowa Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191485000909",
    },
    {
        "school": "Iowa Valley Jr-Sr High School",
        "district": "Iowa Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191485000910",
    },
    {
        "school": "Mary Welsh Elementary",
        "district": "Williamsburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193168000611",
    },
    {
        "school": "Williamsburg Jr-Sr High School",
        "district": "Williamsburg Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193168001845",
    },
    {
        "school": "Andrew Elementary School",
        "district": "Andrew Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190363000067",
    },
    {
        "school": "Bellevue Elementary School",
        "district": "Bellevue Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190465000128",
    },
    {
        "school": "Bellevue High School",
        "district": "Bellevue Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190465000129",
    },
    {
        "school": "Easton Valley Elementary School",
        "district": "Easton Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191013000647",
    },
    {
        "school": "Briggs Elementary School",
        "district": "Maquoketa Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191851001060",
    },
    {
        "school": "Cardinal Elementary School",
        "district": "Maquoketa Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191851001061",
    },
    {
        "school": "Maquoketa Community High School",
        "district": "Maquoketa Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191851001062",
    },
    {
        "school": "Maquoketa Middle School",
        "district": "Maquoketa Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191851001063",
    },
    {
        "school": "Fairfield High School",
        "district": "Fairfield Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191134000693",
    },
    {
        "school": "Fairfield Middle School",
        "district": "Fairfield Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191134000694",
    },
    {
        "school": "Pence Elementary",
        "district": "Fairfield Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191134000698",
    },
    {
        "school": "Washington Elementary",
        "district": "Fairfield Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191134000701",
    },
    {
        "school": "Pekin Community Junior/ Senior High School",
        "district": "Pekin Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192244001343",
    },
    {
        "school": "Pekin Elementary School",
        "district": "Pekin Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192244001345",
    },
    {
        "school": "Keota Elementary School",
        "district": "Keota Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191566000938",
    },
    {
        "school": "Keota High School",
        "district": "Keota Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191566000939",
    },
    {
        "school": "Sigourney Jr-Sr High Sch",
        "district": "Sigourney Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192628001491",
    },
    {
        "school": "Sigourney Elementary",
        "district": "Sigourney Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192628001494",
    },
    {
        "school": "Tri-County High School",
        "district": "Tri-County Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192802001634",
    },
    {
        "school": "Tri-County Junior High School",
        "district": "Tri-County Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192802001635",
    },
    {
        "school": "Tri-County Elementary School",
        "district": "Tri-County Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192802001636",
    },
    {
        "school": "Algona High School",
        "district": "Algona Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190336000030",
    },
    {
        "school": "Bertha Godfrey Elementary School",
        "district": "Algona Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190336000031",
    },
    {
        "school": "Bryant Elementary School",
        "district": "Algona Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190336000032",
    },
    {
        "school": "Lucia Wallace Elementary School",
        "district": "Algona Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190336000033",
    },
    {
        "school": "Algona Middle School",
        "district": "Algona Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190336000034",
    },
    {
        "school": "LuVerne Elementary School",
        "district": "LuVerne Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191788001026",
    },
    {
        "school": "North Kossuth Elementary School",
        "district": "North Kossuth Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192083001887",
    },
    {
        "school": "Chariton High School",
        "district": "Chariton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190705000313",
    },
    {
        "school": "Chariton Middle School",
        "district": "Chariton Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190705000314",
    },
    {
        "school": "Columbus Elementary School",
        "district": "Chariton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190705000315",
    },
    {
        "school": "Van Allen Elementary School",
        "district": "Chariton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190705000317",
    },
    {
        "school": "Central Lyon Elementary School",
        "district": "Central Lyon Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190696000306",
    },
    {
        "school": "Central Lyon Middle School",
        "district": "Central Lyon Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190696000307",
    },
    {
        "school": "Central Lyon Senior High School",
        "district": "Central Lyon Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190696000308",
    },
    {
        "school": "George Elementary School",
        "district": "George-Little Rock Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191248000757",
    },
    {
        "school": "George-Little Rock Senior High School",
        "district": "George-Little Rock Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191248000758",
    },
    {
        "school": "West Lyon Elementary School",
        "district": "West Lyon Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193102001806",
    },
    {
        "school": "West Lyon High School",
        "district": "West Lyon Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193102001807",
    },
    {
        "school": "West Lyon Junior High School",
        "district": "West Lyon Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193102001808",
    },
    {
        "school": "Knoxville High School",
        "district": "Knoxville Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191584000948",
    },
    {
        "school": "Knoxville Middle School",
        "district": "Knoxville Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191584000949",
    },
    {
        "school": "Melcher-Dallas Elem",
        "district": "Melcher-Dallas Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191896001121",
    },
    {
        "school": "Melcher-Dallas High School",
        "district": "Melcher-Dallas Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191896001122",
    },
    {
        "school": "Jefferson Intermediate",
        "district": "Pella Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192247000116",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Pella Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192247001348",
    },
    {
        "school": "Pella High School",
        "district": "Pella Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192247001350",
    },
    {
        "school": "Pella Middle School",
        "district": "Pella Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192247001351",
    },
    {
        "school": "Pleasantville Elementary",
        "district": "Pleasantville Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192316001367",
    },
    {
        "school": "Pleasantville High School",
        "district": "Pleasantville Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192316001369",
    },
    {
        "school": "Twin Cedars Elementary School",
        "district": "Twin Cedars Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192817001641",
    },
    {
        "school": "Twin Cedars Jr-Sr High School",
        "district": "Twin Cedars Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192817001642",
    },
    {
        "school": "GMG Elementary School",
        "district": "GMG Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190006000182",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Osage Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192184001301",
    },
    {
        "school": "Osage High School",
        "district": "Osage Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192184001302",
    },
    {
        "school": "Osage Middle School",
        "district": "Osage Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192184001303",
    },
    {
        "school": "St Ansgar Middle School",
        "district": "St Ansgar Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192520001440",
    },
    {
        "school": "St Ansgar Elementary School",
        "district": "St Ansgar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192520001441",
    },
    {
        "school": "St Ansgar High School",
        "district": "St Ansgar Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192520001442",
    },
    {
        "school": "Charter Oak-Ute Elementary School",
        "district": "Charter Oak-Ute Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190711000327",
    },
    {
        "school": "West Monona High School",
        "district": "West Monona Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193111001817",
    },
    {
        "school": "Whiting Elementary School",
        "district": "Whiting Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193162001841",
    },
    {
        "school": "Whiting Senior High School",
        "district": "Whiting Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193162001842",
    },
    {
        "school": "Albia High School",
        "district": "Albia Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190327000017",
    },
    {
        "school": "Lincoln Center",
        "district": "Albia Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190327000018",
    },
    {
        "school": "Grant Center",
        "district": "Albia Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190327000019",
    },
    {
        "school": "Kendall Center",
        "district": "Albia Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190327000021",
    },
    {
        "school": "Inman Elementary School",
        "district": "Red Oak Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192400001395",
    },
    {
        "school": "Red Oak Junior/Senior High School",
        "district": "Red Oak Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192400001397",
    },
    {
        "school": "Red Oak Early Childhood Center",
        "district": "Red Oak Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192400001399",
    },
    {
        "school": "Stanton Elementary School",
        "district": "Stanton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192724001588",
    },
    {
        "school": "Stanton High School",
        "district": "Stanton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192724001589",
    },
    {
        "school": "Sylvia Enarson Elementary School",
        "district": "Villisca Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192928001675",
    },
    {
        "school": "South O'Brien Elem Sch Primghar Center",
        "district": "South O'Brien Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002600618",
    },
    {
        "school": "South O'Brien Secondary School",
        "district": "South O'Brien Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002601341",
    },
    {
        "school": "Hartley-Melvin-Sanborn Elementary School",
        "district": "Hartley-Melvin-Sanborn Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191366001962",
    },
    {
        "school": "Hartley-Melvin-Sanborn High School",
        "district": "Hartley-Melvin-Sanborn Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191366001963",
    },
    {
        "school": "Hartley-Melvin-Sanborn Middle School",
        "district": "Hartley-Melvin-Sanborn Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191366002065",
    },
    {
        "school": "East Elementary School",
        "district": "Sheldon Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192598001473",
    },
    {
        "school": "Sheldon High School",
        "district": "Sheldon Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192598001474",
    },
    {
        "school": "Sheldon Middle School",
        "district": "Sheldon Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192598001475",
    },
    {
        "school": "Sibley-Ocheyedan Middle School",
        "district": "Sibley-Ocheyedan Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190001501485",
    },
    {
        "school": "Sibley Ocheyedan Elementary School",
        "district": "Sibley-Ocheyedan Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190001501486",
    },
    {
        "school": "Sibley-Ocheyedan High School",
        "district": "Sibley-Ocheyedan Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190001501487",
    },
    {
        "school": "Clarinda High School",
        "district": "Clarinda Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190735000340",
    },
    {
        "school": "Clarinda Middle School",
        "district": "Clarinda Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190735000341",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Clarinda Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190735000342",
    },
    {
        "school": "Clarinda Academy",
        "district": "Clarinda Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "190735000423",
    },
    {
        "school": "Essex Elementary School",
        "district": "Essex Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191104000682",
    },
    {
        "school": "Essex Junior-Senior High School",
        "district": "Essex Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191104000683",
    },
    {
        "school": "Shenandoah Elementary School",
        "district": "Shenandoah Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192607001478",
    },
    {
        "school": "Shenandoah High School",
        "district": "Shenandoah Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192607001482",
    },
    {
        "school": "Shenandoah Middle School",
        "district": "Shenandoah Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192607001483",
    },
    {
        "school": "South Page Elementary School",
        "district": "South Page Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192667001551",
    },
    {
        "school": "South Page Senior High School",
        "district": "South Page Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192667001552",
    },
    {
        "school": "Emmetsburg High School",
        "district": "Emmetsburg Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191095000675",
    },
    {
        "school": "Emmetsburg Middle School",
        "district": "Emmetsburg Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191095000676",
    },
    {
        "school": "West Elementary School",
        "district": "Emmetsburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191095000678",
    },
    {
        "school": "Graettinger-Terril High School",
        "district": "Graettinger-Terril Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191281000776",
    },
    {
        "school": "Ruthven-Ayrshire Elementary School",
        "district": "Ruthven-Ayrshire Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192505001966",
    },
    {
        "school": "Ruthven-Ayrshire High School",
        "district": "Ruthven-Ayrshire Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192505001967",
    },
    {
        "school": "West Bend-Mallard Elementary School",
        "district": "West Bend-Mallard Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193072001042",
    },
    {
        "school": "West Bend-Mallard Middle School",
        "district": "West Bend-Mallard Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193072001044",
    },
    {
        "school": "West Bend-Mallard High School",
        "district": "West Bend-Mallard Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193072001770",
    },
    {
        "school": "Akron Westfield Elementary School",
        "district": "Akron Westfield Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190322001937",
    },
    {
        "school": "Akron Westfield Middle School",
        "district": "Akron Westfield Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190322001938",
    },
    {
        "school": "Akron Westfield Senior High School",
        "district": "Akron Westfield Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190322001939",
    },
    {
        "school": "Hinton Elementary School",
        "district": "Hinton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191416000843",
    },
    {
        "school": "Hinton High School",
        "district": "Hinton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191416000844",
    },
    {
        "school": "Hinton Intermediate School",
        "district": "Hinton Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191416000845",
    },
    {
        "school": "Clark Elementary School",
        "district": "Le Mars Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191653000983",
    },
    {
        "school": "Le Mars Middle School",
        "district": "Le Mars Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191653000984",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Le Mars Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191653000985",
    },
    {
        "school": "Kluckhohn Elementary School",
        "district": "Le Mars Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191653000987",
    },
    {
        "school": "Le Mars High School",
        "district": "Le Mars Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191653000988",
    },
    {
        "school": "Remsen-Union Elementary School",
        "district": "Remsen-Union Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192412001405",
    },
    {
        "school": "Remsen-Union Middle School",
        "district": "Remsen-Union Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192412001995",
    },
    {
        "school": "Laurens-Marathon Elementary School",
        "district": "Laurens-Marathon Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191642000977",
    },
    {
        "school": "Laurens-Marathon Middle School",
        "district": "Laurens-Marathon Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191642000979",
    },
    {
        "school": "Pocahontas Area Regional Learning Center",
        "district": "Pocahontas Area Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "192319000377",
    },
    {
        "school": "Pocahontas Area Elementary School",
        "district": "Pocahontas Area Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192319001372",
    },
    {
        "school": "Pocahontas Area Middle/ High School",
        "district": "Pocahontas Area Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192319001373",
    },
    {
        "school": "Brooklyn-Guernsey-Malcom Elementary School",
        "district": "Brooklyn-Guernsey-Malcom Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190549000173",
    },
    {
        "school": "Brooklyn-Guernsey-Malcom Jr-Sr High School",
        "district": "Brooklyn-Guernsey-Malcom Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190549000174",
    },
    {
        "school": "Bailey Park Elementary School",
        "district": "Grinnell-Newburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191320000789",
    },
    {
        "school": "Davis Elementary School",
        "district": "Grinnell-Newburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191320000790",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Grinnell-Newburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191320000791",
    },
    {
        "school": "Grinnell Community Senior High School",
        "district": "Grinnell-Newburg Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191320000792",
    },
    {
        "school": "Grinnell Community Middle School",
        "district": "Grinnell-Newburg Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191320000793",
    },
    {
        "school": "Montezuma Elementary School",
        "district": "Montezuma Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191959001149",
    },
    {
        "school": "Montezuma High School",
        "district": "Montezuma Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191959001150",
    },
    {
        "school": "Montezuma Junior High School",
        "district": "Montezuma Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191959001151",
    },
    {
        "school": "Diagonal Elementary School",
        "district": "Diagonal Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190906000593",
    },
    {
        "school": "Diagonal Junior-Senior High School",
        "district": "Diagonal Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190906000594",
    },
    {
        "school": "Mount Ayr Elementary",
        "district": "Mount Ayr Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191986001166",
    },
    {
        "school": "Mount Ayr High School",
        "district": "Mount Ayr Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191986001167",
    },
    {
        "school": "Odebolt Arthur Battle Creek Ida Grove Elementary - Odebolt",
        "district": "Odebolt Arthur Battle Creek Ida Grove Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192160001283",
    },
    {
        "school": "Schaller-Crestland Elementary",
        "district": "Schaller-Crestland Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192538001450",
    },
    {
        "school": "East Sac County Elementary Wall Lake",
        "district": "East Sac County Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192958001686",
    },
    {
        "school": "East Sac County High School",
        "district": "East Sac County Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192958001687",
    },
    {
        "school": "Harlan High School",
        "district": "Harlan Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191350000821",
    },
    {
        "school": "Harlan Community Middle School",
        "district": "Harlan Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191350000822",
    },
    {
        "school": "Harlan Primary",
        "district": "Harlan Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191350000825",
    },
    {
        "school": "Harlan  Intermediate School",
        "district": "Harlan Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191350000826",
    },
    {
        "school": "Irwin Elementary School",
        "district": "IKM-Manning Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191488000911",
    },
    {
        "school": "Boyden-Hull Elementary School",
        "district": "Boyden-Hull Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190519000166",
    },
    {
        "school": "Boyden-Hull High School",
        "district": "Boyden-Hull Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190519000167",
    },
    {
        "school": "MOC-Floyd Valley Middle School",
        "district": "MOC-Floyd Valley Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191884000708",
    },
    {
        "school": "Orange City Elementary School",
        "district": "MOC-Floyd Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191884000710",
    },
    {
        "school": "MOC-Floyd Valley High School",
        "district": "MOC-Floyd Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191884001112",
    },
    {
        "school": "Hospers Elementary School",
        "district": "MOC-Floyd Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191884001114",
    },
    {
        "school": "Rock Valley Elementary School",
        "district": "Rock Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192466001414",
    },
    {
        "school": "Rock Valley High School",
        "district": "Rock Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192466001415",
    },
    {
        "school": "Kinsey Elementary School",
        "district": "Sioux Center Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192637001495",
    },
    {
        "school": "Sioux Center High School",
        "district": "Sioux Center Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192637001496",
    },
    {
        "school": "Sioux Center Middle School",
        "district": "Sioux Center Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192637001497",
    },
    {
        "school": "Hawarden Elementary School",
        "district": "West Sioux Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193129001819",
    },
    {
        "school": "Ireton Elementary School",
        "district": "West Sioux Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193129001820",
    },
    {
        "school": "West Sioux High School",
        "district": "West Sioux Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193129001821",
    },
    {
        "school": "West Sioux Middle School",
        "district": "West Sioux Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193129001822",
    },
    {
        "school": "GMG Secondary School",
        "district": "GMG Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190006000179",
    },
    {
        "school": "North Tama High School",
        "district": "North Tama County Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192100001258",
    },
    {
        "school": "North Tama Elementary",
        "district": "North Tama County Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192100001260",
    },
    {
        "school": "South Tama County High School",
        "district": "South Tama County",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192673001556",
    },
    {
        "school": "South Tama County Middle School",
        "district": "South Tama County",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192673001557",
    },
    {
        "school": "Bedford High School",
        "district": "Bedford Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190456000120",
    },
    {
        "school": "Bedford Elementary School",
        "district": "Bedford Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190456000122",
    },
    {
        "school": "Lenox Elementary School",
        "district": "Lenox Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191662000991",
    },
    {
        "school": "Lenox High School",
        "district": "Lenox Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191662000992",
    },
    {
        "school": "Creston High School",
        "district": "Creston Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190831000444",
    },
    {
        "school": "Creston Early Childhood Center",
        "district": "Creston Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190831000446",
    },
    {
        "school": "East Union Elementary",
        "district": "East Union Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191035000659",
    },
    {
        "school": "East Union Middle-High School",
        "district": "East Union Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191035000661",
    },
    {
        "school": "Van Buren County Community School Douds Center",
        "district": "Van Buren County Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192898001667",
    },
    {
        "school": "Van Buren County Community School Middle & High School",
        "district": "Van Buren County Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192898001670",
    },
    {
        "school": "Waco Elementary School",
        "district": "Waco Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192949001683",
    },
    {
        "school": "Mormon Trail Elementary School",
        "district": "Mormon Trail Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191974001158",
    },
    {
        "school": "Seymour Elementary School",
        "district": "Seymour Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192562001464",
    },
    {
        "school": "Seymour High School",
        "district": "Seymour Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192562001465",
    },
    {
        "school": "Wayne Elementary School",
        "district": "Wayne Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193056001754",
    },
    {
        "school": "Wayne Community Jr-Sr High School",
        "district": "Wayne Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193056001755",
    },
    {
        "school": "North Iowa Elem Buffalo Center",
        "district": "North Iowa Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190575000176",
    },
    {
        "school": "North Iowa High School",
        "district": "North Iowa Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190575000177",
    },
    {
        "school": "North Iowa Middle School",
        "district": "North Iowa Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190575001620",
    },
    {
        "school": "Forest City Elementary School",
        "district": "Forest City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191179000715",
    },
    {
        "school": "Forest City High School",
        "district": "Forest City Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191179000716",
    },
    {
        "school": "Forest City Middle School",
        "district": "Forest City Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191179000717",
    },
    {
        "school": "Lake Mills Elementary School",
        "district": "Lake Mills Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191611000963",
    },
    {
        "school": "Lake Mills Middle School",
        "district": "Lake Mills Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191611000964",
    },
    {
        "school": "Lake Mills Senior High School",
        "district": "Lake Mills Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191611000965",
    },
    {
        "school": "Decorah Middle School",
        "district": "Decorah Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190873000498",
    },
    {
        "school": "John Cline Elementary School",
        "district": "Decorah Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190873000500",
    },
    {
        "school": "Decorah High School",
        "district": "Decorah Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190873000501",
    },
    {
        "school": "West Side Elementary School",
        "district": "Decorah Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190873000502",
    },
    {
        "school": "South Winneshiek Elementary School",
        "district": "South Winneshiek Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192679001562",
    },
    {
        "school": "South Winneshiek Middle School",
        "district": "South Winneshiek Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192679001564",
    },
    {
        "school": "South Winneshiek High School",
        "district": "South Winneshiek Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192679001565",
    },
    {
        "school": "Turkey Valley Elementary School",
        "district": "Turkey Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192811001639",
    },
    {
        "school": "Turkey Valley Jr-Sr High School",
        "district": "Turkey Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192811001640",
    },
    {
        "school": "Belmond-Klemme Community Jr-Sr High School",
        "district": "Belmond-Klemme Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190468000130",
    },
    {
        "school": "Clarion-Goldfield-Dows Elementary School",
        "district": "Clarion-Goldfield-Dows Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190738000346",
    },
    {
        "school": "Clarion-Goldfield-Dows High School",
        "district": "Clarion-Goldfield-Dows Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190738000347",
    },
    {
        "school": "Clarion-Goldfield-Dows Middle School",
        "district": "Clarion-Goldfield-Dows Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190738000348",
    },
    {
        "school": "Eagle Grove High School",
        "district": "Eagle Grove Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190999000635",
    },
    {
        "school": "Robert Blue School",
        "district": "Eagle Grove Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190999000636",
    },
    {
        "school": "Maple Valley-Anthon Oto High School",
        "district": "Maple Valley-Anthon Oto Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191848001057",
    },
    {
        "school": "Mapleton Elementary School",
        "district": "Maple Valley-Anthon Oto Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191848001059",
    },
    {
        "school": "Kingsley Elementary School",
        "district": "Kingsley-Pierson Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191575000940",
    },
    {
        "school": "Kingsley-Pierson High School",
        "district": "Kingsley-Pierson Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191575000941",
    },
    {
        "school": "Pierson Elementary School",
        "district": "Kingsley-Pierson Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191575000942",
    },
    {
        "school": "Pierson Middle School",
        "district": "Kingsley-Pierson Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191575000943",
    },
    {
        "school": "Sawyer Elementary School",
        "district": "Ames Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190354000049",
    },
    {
        "school": "Ames High School",
        "district": "Ames Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190354000050",
    },
    {
        "school": "Edwards Elementary School",
        "district": "Ames Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190354000052",
    },
    {
        "school": "Fellows Elementary School",
        "district": "Ames Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190354000053",
    },
    {
        "school": "Mitchell Elementary School",
        "district": "Ames Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190354000054",
    },
    {
        "school": "Meeker Elementary School",
        "district": "Ames Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190354000056",
    },
    {
        "school": "Ames Middle School",
        "district": "Ames Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190354000060",
    },
    {
        "school": "Northwood Pre-School",
        "district": "Ames Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190354001906",
    },
    {
        "school": "Ballard High School",
        "district": "Ballard Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190420000105",
    },
    {
        "school": "Ballard Middle School",
        "district": "Ballard Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190420000106",
    },
    {
        "school": "Ballard West Elementary",
        "district": "Ballard Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190420000108",
    },
    {
        "school": "Ballard East Elementary",
        "district": "Ballard Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190420000109",
    },
    {
        "school": "Collins-Maxwell Elementary School",
        "district": "Collins-Maxwell Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190790001950",
    },
    {
        "school": "Collins-Maxwell Middle/High School",
        "district": "Collins-Maxwell Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190790001951",
    },
    {
        "school": "Colo-NESCO  Middle/High School",
        "district": "Colo-NESCO Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190792000395",
    },
    {
        "school": "Gilbert Elementary School",
        "district": "Gilbert Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191251000759",
    },
    {
        "school": "Gilbert High School",
        "district": "Gilbert Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191251000760",
    },
    {
        "school": "Central Elementary School",
        "district": "Nevada Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192025001200",
    },
    {
        "school": "Nevada High School",
        "district": "Nevada Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192025001202",
    },
    {
        "school": "Nevada Middle School",
        "district": "Nevada Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192025002072",
    },
    {
        "school": "Roland-Story Elementary School",
        "district": "Roland-Story Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192487001422",
    },
    {
        "school": "Roland-Story High School",
        "district": "Roland-Story Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192487001423",
    },
    {
        "school": "Roland-Story Middle School",
        "district": "Roland-Story Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192487001424",
    },
    {
        "school": "Boone High School",
        "district": "Boone Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190513000156",
    },
    {
        "school": "Boone Middle School",
        "district": "Boone Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190513000157",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Boone Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190513000159",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Boone Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190513000161",
    },
    {
        "school": "Page Elementary School",
        "district": "Boone Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190513000163",
    },
    {
        "school": "Madrid Elementary School",
        "district": "Madrid Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191818001039",
    },
    {
        "school": "Madrid High School",
        "district": "Madrid Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191818001040",
    },
    {
        "school": "Madrid Junior High School",
        "district": "Madrid Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191818001041",
    },
    {
        "school": "Ogden Elementary School",
        "district": "Ogden Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192166001293",
    },
    {
        "school": "Ogden Middle School",
        "district": "Ogden Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192166001294",
    },
    {
        "school": "Ogden High School",
        "district": "Ogden Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192166001295",
    },
    {
        "school": "United South",
        "district": "United Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192856001650",
    },
    {
        "school": "Black Hawk Elementary School",
        "district": "Burlington Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190579000180",
    },
    {
        "school": "Burlington Community High School",
        "district": "Burlington Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190579000181",
    },
    {
        "school": "Edward Stone Middle School",
        "district": "Burlington Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190579000186",
    },
    {
        "school": "James Wilson Grimes School",
        "district": "Burlington Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190579000187",
    },
    {
        "school": "North Hill Elementary School",
        "district": "Burlington Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190579000190",
    },
    {
        "school": "Aldo Leopold Intermediate School",
        "district": "Burlington Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190579000191",
    },
    {
        "school": "Sunnyside Elementary School",
        "district": "Burlington Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190579000194",
    },
    {
        "school": "Danville Elementary School",
        "district": "Danville Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190855000454",
    },
    {
        "school": "Danville Junior-Senior High School",
        "district": "Danville Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190855000455",
    },
    {
        "school": "Mediapolis Elementary School",
        "district": "Mediapolis Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191893001117",
    },
    {
        "school": "Mediapolis High School",
        "district": "Mediapolis Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191893001118",
    },
    {
        "school": "Middle School",
        "district": "Mediapolis Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191893001119",
    },
    {
        "school": "West Burlington Elem School",
        "district": "West Burlington Ind School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193078001775",
    },
    {
        "school": "West Burlington High School",
        "district": "West Burlington Ind School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193078001776",
    },
    {
        "school": "West Burlington Junior High School",
        "district": "West Burlington Ind School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193078001777",
    },
    {
        "school": "Tilford Elementary School",
        "district": "Vinton-Shellsburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192931001550",
    },
    {
        "school": "Midland Middle/High School",
        "district": "Midland Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191920001563",
    },
    {
        "school": "Viola Gibson Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000731",
    },
    {
        "school": "Prairie Ridge Elementary",
        "district": "College Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190786000761",
    },
    {
        "school": "Oak Ridge School",
        "district": "Linn-Mar Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191722000810",
    },
    {
        "school": "Linn Grove Elementary School",
        "district": "Linn-Mar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191722001525",
    },
    {
        "school": "Belle Plaine Jr/Sr High School",
        "district": "Belle Plaine Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190462000124",
    },
    {
        "school": "Longfellow Elementary School",
        "district": "Belle Plaine Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190462000127",
    },
    {
        "school": "Atkins Elementary School",
        "district": "Benton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190483000136",
    },
    {
        "school": "Benton Community Senior High School",
        "district": "Benton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190483000137",
    },
    {
        "school": "Benton Community Middle School",
        "district": "Benton Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190483001987",
    },
    {
        "school": "Shellsburg Elementary School",
        "district": "Vinton-Shellsburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192931001476",
    },
    {
        "school": "Vinton-Shellsburg Middle School",
        "district": "Vinton-Shellsburg Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192931001680",
    },
    {
        "school": "Vinton-Shellsburg High School",
        "district": "Vinton-Shellsburg Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192931001681",
    },
    {
        "school": "Anamosa High School",
        "district": "Anamosa Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190357000061",
    },
    {
        "school": "Anamosa Middle School",
        "district": "Anamosa Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190357000062",
    },
    {
        "school": "Strawberry Hill",
        "district": "Anamosa Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190357000064",
    },
    {
        "school": "Carpenter Elementary School",
        "district": "Monticello Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191965001152",
    },
    {
        "school": "Monticello High School",
        "district": "Monticello Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191965001153",
    },
    {
        "school": "Shannon Elementary School",
        "district": "Monticello Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191965001155",
    },
    {
        "school": "Monticello Middle School",
        "district": "Monticello Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191965002000",
    },
    {
        "school": "Olin Elementary School",
        "district": "Olin Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192172001296",
    },
    {
        "school": "Center Point-Urbana Middle School",
        "district": "Center Point-Urbana Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190666002041",
    },
    {
        "school": "Alburnett Elementary School",
        "district": "Alburnett Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190330000024",
    },
    {
        "school": "Alburnett Senior High School",
        "district": "Alburnett Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190330000025",
    },
    {
        "school": "Jackson Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000213",
    },
    {
        "school": "Arthur Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000233",
    },
    {
        "school": "Cleveland Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000234",
    },
    {
        "school": "Coolidge Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000235",
    },
    {
        "school": "Erskine Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000237",
    },
    {
        "school": "Franklin Middle School",
        "district": "Cedar Rapids Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000239",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000240",
    },
    {
        "school": "George Washington High School",
        "district": "Cedar Rapids Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000241",
    },
    {
        "school": "Grant Wood Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000243",
    },
    {
        "school": "Harding Middle School",
        "district": "Cedar Rapids Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000244",
    },
    {
        "school": "Harrison Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000245",
    },
    {
        "school": "Hiawatha Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000247",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000248",
    },
    {
        "school": "John F Kennedy High School",
        "district": "Cedar Rapids Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000250",
    },
    {
        "school": "Johnson STEAM Academy School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000251",
    },
    {
        "school": "Kenwood Leadership Academy School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000252",
    },
    {
        "school": "Madison Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000253",
    },
    {
        "school": "McKinley STEAM Academy",
        "district": "Cedar Rapids Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000254",
    },
    {
        "school": "Nixon Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000255",
    },
    {
        "school": "Pierce Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000256",
    },
    {
        "school": "Roosevelt Creative Corridor Business Academy",
        "district": "Cedar Rapids Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000258",
    },
    {
        "school": "Metro High School",
        "district": "Cedar Rapids Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "190654000259",
    },
    {
        "school": "Taft Middle School",
        "district": "Cedar Rapids Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000261",
    },
    {
        "school": "Cedar River Academy at Taylor",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000262",
    },
    {
        "school": "Thomas Jefferson High School",
        "district": "Cedar Rapids Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000263",
    },
    {
        "school": "Truman Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000264",
    },
    {
        "school": "Van Buren Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000266",
    },
    {
        "school": "Wilson Middle School",
        "district": "Cedar Rapids Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000267",
    },
    {
        "school": "Wright Elementary School",
        "district": "Cedar Rapids Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190654000268",
    },
    {
        "school": "Center Point-Urbana High School",
        "district": "Center Point-Urbana Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190666000272",
    },
    {
        "school": "Center Point-Urbana Primary School",
        "district": "Center Point-Urbana Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190666000273",
    },
    {
        "school": "Central City Elementary School",
        "district": "Central City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190678000284",
    },
    {
        "school": "Central City High School",
        "district": "Central City Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190678000285",
    },
    {
        "school": "Prairie Edge",
        "district": "College Comm School District",
        "level": "Other",
        "type": "Special education school",
        "state": "IA",
        "nces_id": "190786000104",
    },
    {
        "school": "Prairie Heights Elementary School",
        "district": "College Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190786000387",
    },
    {
        "school": "Prairie High School",
        "district": "College Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190786000388",
    },
    {
        "school": "Prairie Crest Elementary School",
        "district": "College Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190786000389",
    },
    {
        "school": "Prairie View Elementary School",
        "district": "College Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190786000391",
    },
    {
        "school": "Westfield Elementary School",
        "district": "Linn-Mar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191722000368",
    },
    {
        "school": "Bowman Woods Elementary School",
        "district": "Linn-Mar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191722001002",
    },
    {
        "school": "Indian Creek Elementary School",
        "district": "Linn-Mar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191722001003",
    },
    {
        "school": "Linn-Mar High School",
        "district": "Linn-Mar Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191722001004",
    },
    {
        "school": "Excelsior Middle School",
        "district": "Linn-Mar Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191722001005",
    },
    {
        "school": "Novak Elementary School",
        "district": "Linn-Mar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191722001006",
    },
    {
        "school": "Wilkins Elementary School",
        "district": "Linn-Mar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191722001007",
    },
    {
        "school": "Lisbon Elementary School",
        "district": "Lisbon Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191725001008",
    },
    {
        "school": "Lisbon High School",
        "district": "Lisbon Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191725001009",
    },
    {
        "school": "Lisbon Middle School",
        "district": "Lisbon Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191725001981",
    },
    {
        "school": "Francis Marion Intermediate School",
        "district": "Marion Independent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191869000437",
    },
    {
        "school": "Marion High School",
        "district": "Marion Independent School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191869001075",
    },
    {
        "school": "Starry Elementary School",
        "district": "Marion Independent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191869001077",
    },
    {
        "school": "Vernon Middle School",
        "district": "Marion Independent School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191869001078",
    },
    {
        "school": "Mount Vernon Middle School",
        "district": "Mount Vernon Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192004001178",
    },
    {
        "school": "Washington Elementary School",
        "district": "Mount Vernon Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192004001179",
    },
    {
        "school": "Mount Vernon High School",
        "district": "Mount Vernon Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192004001883",
    },
    {
        "school": "North-Linn Middle School",
        "district": "North Linn Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192082001242",
    },
    {
        "school": "North-Linn Senior High School",
        "district": "North Linn Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192082001243",
    },
    {
        "school": "North Linn Elementary",
        "district": "North Linn Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192082001244",
    },
    {
        "school": "Springville Elementary School",
        "district": "Springville Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192706001586",
    },
    {
        "school": "Springville Secondary School",
        "district": "Springville Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192706001587",
    },
    {
        "school": "Eagle Heights Elementary School",
        "district": "Clinton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190771001519",
    },
    {
        "school": "Calamus-Wheatland Elem Attendance Center",
        "district": "Calamus-Wheatland Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190600000204",
    },
    {
        "school": "Calamus-Wheatland Sec Attendance Center",
        "district": "Calamus-Wheatland Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190600002042",
    },
    {
        "school": "Camanche High School",
        "district": "Camanche Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190606000206",
    },
    {
        "school": "Camanche Middle School",
        "district": "Camanche Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190606000207",
    },
    {
        "school": "Camanche Elementary",
        "district": "Camanche Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190606000209",
    },
    {
        "school": "Central DeWitt High School",
        "district": "Central DeWitt School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190681000286",
    },
    {
        "school": "Central DeWitt Middle School",
        "district": "Central DeWitt School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190681000287",
    },
    {
        "school": "Ekstrand Elementary School",
        "district": "Central DeWitt School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190681000288",
    },
    {
        "school": "Clinton High School",
        "district": "Clinton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190771000370",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Clinton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190771000378",
    },
    {
        "school": "Whittier Elementary School",
        "district": "Clinton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190771000384",
    },
    {
        "school": "Bluff Elementary School",
        "district": "Clinton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190771000597",
    },
    {
        "school": "Delwood Elementary School",
        "district": "Delwood Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190888000505",
    },
    {
        "school": "Northeast Elementary School",
        "district": "Northeast Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192109001265",
    },
    {
        "school": "Northeast Middle-High School",
        "district": "Northeast Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192109001266",
    },
    {
        "school": "Children's Village West",
        "district": "Davenport Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858001204",
    },
    {
        "school": "Children's Village Hayes",
        "district": "Davenport Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858001416",
    },
    {
        "school": "Bettendorf High School",
        "district": "Bettendorf Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190486000142",
    },
    {
        "school": "Bettendorf Middle School",
        "district": "Bettendorf Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190486000143",
    },
    {
        "school": "Grant Wood Elementary School",
        "district": "Bettendorf Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190486000144",
    },
    {
        "school": "Herbert Hoover Elementary School",
        "district": "Bettendorf Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190486000145",
    },
    {
        "school": "Paul Norton Elementary School",
        "district": "Bettendorf Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190486000146",
    },
    {
        "school": "Mark Twain Elementary School",
        "district": "Bettendorf Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190486000149",
    },
    {
        "school": "Neil Armstrong Elementary School",
        "district": "Bettendorf Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190486000150",
    },
    {
        "school": "Adams Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000456",
    },
    {
        "school": "Blue Grass Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000457",
    },
    {
        "school": "Buchanan Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000458",
    },
    {
        "school": "Buffalo Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000459",
    },
    {
        "school": "Central High School",
        "district": "Davenport Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000461",
    },
    {
        "school": "Eisenhower Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000462",
    },
    {
        "school": "Fillmore Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000463",
    },
    {
        "school": "Frank L Smart Intermediate",
        "district": "Davenport Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000464",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000465",
    },
    {
        "school": "Harrison Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000469",
    },
    {
        "school": "Hayes Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000470",
    },
    {
        "school": "Children's Village At Hoover",
        "district": "Davenport Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000471",
    },
    {
        "school": "Jackson Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000473",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000474",
    },
    {
        "school": "Madison Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000477",
    },
    {
        "school": "McKinley Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000479",
    },
    {
        "school": "Monroe Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000480",
    },
    {
        "school": "Sudlow Intermediate",
        "district": "Davenport Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000482",
    },
    {
        "school": "Walcott Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000484",
    },
    {
        "school": "Walcott Intermediate",
        "district": "Davenport Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000485",
    },
    {
        "school": "Washington Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000486",
    },
    {
        "school": "West High School",
        "district": "Davenport Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000487",
    },
    {
        "school": "Williams Intermediate",
        "district": "Davenport Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000488",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000489",
    },
    {
        "school": "Wood Intermediate",
        "district": "Davenport Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858000490",
    },
    {
        "school": "Truman Elementary School",
        "district": "Davenport Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858001881",
    },
    {
        "school": "North High School",
        "district": "Davenport Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190858001977",
    },
    {
        "school": "Mid City High",
        "district": "Davenport Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "190858002009",
    },
    {
        "school": "Alan Shepard Elementary School",
        "district": "North Scott Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192094001251",
    },
    {
        "school": "Edward White Elementary School",
        "district": "North Scott Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192094001252",
    },
    {
        "school": "John Glenn Elementary School",
        "district": "North Scott Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192094001253",
    },
    {
        "school": "Neil Armstrong Elementary School",
        "district": "North Scott Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192094001254",
    },
    {
        "school": "North Scott Junior High School",
        "district": "North Scott Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192094001255",
    },
    {
        "school": "North Scott High School",
        "district": "North Scott Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192094001256",
    },
    {
        "school": "Virgil Grissom Elementary School",
        "district": "North Scott Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192094001257",
    },
    {
        "school": "Pleasant Valley Junior  High School",
        "district": "Pleasant Valley Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192311001361",
    },
    {
        "school": "Bridgeview Elementary School",
        "district": "Pleasant Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192311001362",
    },
    {
        "school": "Cody Elementary School",
        "district": "Pleasant Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192311001363",
    },
    {
        "school": "Pleasant Valley High School",
        "district": "Pleasant Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192311001364",
    },
    {
        "school": "Pleasant View Elementary School",
        "district": "Pleasant Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192311001365",
    },
    {
        "school": "Riverdale Heights Elem School",
        "district": "Pleasant Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192311001366",
    },
    {
        "school": "Maple Grove Elementary School",
        "district": "Waukee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051001503",
    },
    {
        "school": "Dallas Center Elementary",
        "district": "Dallas Center-Grimes Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190852000705",
    },
    {
        "school": "Prairieview School",
        "district": "Waukee Comm School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051000931",
    },
    {
        "school": "Walnut Hills Elementary School",
        "district": "Waukee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051000958",
    },
    {
        "school": "Crocker Elementary School",
        "district": "Ankeny Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369000778",
    },
    {
        "school": "Brubaker Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000746",
    },
    {
        "school": "Walnut Street School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897001143",
    },
    {
        "school": "Carver Elementary",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897001596",
    },
    {
        "school": "Summit Middle School",
        "district": "Johnston Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191545000749",
    },
    {
        "school": "Timber Ridge Elementary",
        "district": "Johnston Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191545001412",
    },
    {
        "school": "Clay Elementary",
        "district": "Southeast Polk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192682001168",
    },
    {
        "school": "Hillside Elementary School",
        "district": "West Des Moines Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093001188",
    },
    {
        "school": "Carlisle Middle School",
        "district": "Carlisle Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190627001561",
    },
    {
        "school": "Panorama Elementary",
        "district": "Panorama Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002500606",
    },
    {
        "school": "Panorama High School",
        "district": "Panorama Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002501334",
    },
    {
        "school": "Panorama Middle School",
        "district": "Panorama Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002501335",
    },
    {
        "school": "Adair-Casey Elementary School",
        "district": "Adair-Casey Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190309000006",
    },
    {
        "school": "Guthrie Center Elementary School",
        "district": "Guthrie Center Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191332000803",
    },
    {
        "school": "Guthrie Center High School",
        "district": "Guthrie Center Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191332000804",
    },
    {
        "school": "Earlham Elementary School",
        "district": "Earlham Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191005000640",
    },
    {
        "school": "Earlham Senior High School",
        "district": "Earlham Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191005000641",
    },
    {
        "school": "Earlham Middle School",
        "district": "Earlham Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191005001956",
    },
    {
        "school": "Winterset Junior High School",
        "district": "Winterset Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193186000369",
    },
    {
        "school": "Winterset Elementary School",
        "district": "Winterset Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193186001856",
    },
    {
        "school": "Winterset Middle School",
        "district": "Winterset Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193186001857",
    },
    {
        "school": "Winterset Senior High School",
        "district": "Winterset Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193186001858",
    },
    {
        "school": "Adel Elementary School",
        "district": "Adel DeSoto Minburn Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190315000008",
    },
    {
        "school": "ADM Senior High School",
        "district": "Adel DeSoto Minburn Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190315000009",
    },
    {
        "school": "DeSoto Intermediate School",
        "district": "Adel DeSoto Minburn Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190315000010",
    },
    {
        "school": "ADM Middle School",
        "district": "Adel DeSoto Minburn Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190315001986",
    },
    {
        "school": "Dallas Center-Grimes High School",
        "district": "Dallas Center-Grimes Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190852000451",
    },
    {
        "school": "Dallas Center-Grimes Middle School",
        "district": "Dallas Center-Grimes Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190852000453",
    },
    {
        "school": "Perry Elementary",
        "district": "Perry Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192253000051",
    },
    {
        "school": "Perry High School",
        "district": "Perry Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192253001355",
    },
    {
        "school": "Perry Middle School",
        "district": "Perry Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192253001356",
    },
    {
        "school": "West Central Valley Middle School",
        "district": "West Central Valley Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192750000664",
    },
    {
        "school": "Dexter Elementary School",
        "district": "West Central Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192750000671",
    },
    {
        "school": "Van Meter Elementary School",
        "district": "Van Meter Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192901001671",
    },
    {
        "school": "Van Meter High School",
        "district": "Van Meter Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192901001672",
    },
    {
        "school": "Eason Elementary School",
        "district": "Waukee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051000299",
    },
    {
        "school": "Brookview Elementary School",
        "district": "Waukee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051000699",
    },
    {
        "school": "Waukee Elementary School",
        "district": "Waukee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051001742",
    },
    {
        "school": "Waukee Middle School",
        "district": "Waukee Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051001743",
    },
    {
        "school": "Waukee High School",
        "district": "Waukee Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051001744",
    },
    {
        "school": "Woodward-Granger Middle School",
        "district": "Woodward-Granger Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193201001866",
    },
    {
        "school": "Woodward-Granger Elementary School",
        "district": "Woodward-Granger Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193201001867",
    },
    {
        "school": "Woodward-Granger High School",
        "district": "Woodward-Granger Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193201001868",
    },
    {
        "school": "Stuart Elementary School",
        "district": "West Central Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192750001605",
    },
    {
        "school": "West Central Valley High School",
        "district": "West Central Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192750001607",
    },
    {
        "school": "Interstate 35 Elementary School",
        "district": "Interstate 35 Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191467000880",
    },
    {
        "school": "Ankeny High School",
        "district": "Ankeny Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369000071",
    },
    {
        "school": "East Elementary School",
        "district": "Ankeny Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369000072",
    },
    {
        "school": "Parkview Middle School",
        "district": "Ankeny Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369000073",
    },
    {
        "school": "Northwest Elementary School",
        "district": "Ankeny Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369000074",
    },
    {
        "school": "Southeast Elementary School",
        "district": "Ankeny Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369000077",
    },
    {
        "school": "Terrace Elementary School",
        "district": "Ankeny Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369000078",
    },
    {
        "school": "Northeast Elementary",
        "district": "Ankeny Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369000148",
    },
    {
        "school": "Northview Middle School",
        "district": "Ankeny Comm School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369000380",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Ankeny Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369002026",
    },
    {
        "school": "Anderson Elementary School",
        "district": "Bondurant-Farrar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190507000153",
    },
    {
        "school": "Bondurant-Farrar High School",
        "district": "Bondurant-Farrar Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190507000154",
    },
    {
        "school": "South Prairie Elementary",
        "district": "Dallas Center-Grimes Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190852002029",
    },
    {
        "school": "Downtown School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000232",
    },
    {
        "school": "Hiatt Middle School",
        "district": "Des Moines Independent Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000516",
    },
    {
        "school": "Brody Middle School",
        "district": "Des Moines Independent Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000517",
    },
    {
        "school": "Capitol View Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000518",
    },
    {
        "school": "Callanan Middle School",
        "district": "Des Moines Independent Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000519",
    },
    {
        "school": "Cattell Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000521",
    },
    {
        "school": "East High School",
        "district": "Des Moines Independent Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000528",
    },
    {
        "school": "Edmunds Fine Arts Academy",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000529",
    },
    {
        "school": "Findley Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000531",
    },
    {
        "school": "Garton Elementary",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000534",
    },
    {
        "school": "Goodrell Middle School",
        "district": "Des Moines Independent Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000535",
    },
    {
        "school": "Scavo Alternative High School",
        "district": "Des Moines Independent Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "190897000537",
    },
    {
        "school": "Greenwood Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000538",
    },
    {
        "school": "Hanawalt Elementary",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000539",
    },
    {
        "school": "Harding Middle School",
        "district": "Des Moines Independent Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000540",
    },
    {
        "school": "Hillis Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000541",
    },
    {
        "school": "Hoover High School",
        "district": "Des Moines Independent Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000543",
    },
    {
        "school": "Howe Elementary",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000544",
    },
    {
        "school": "Hoyt Middle School",
        "district": "Des Moines Independent Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000545",
    },
    {
        "school": "Hubbell Elementary",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000546",
    },
    {
        "school": "Jackson Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000547",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000548",
    },
    {
        "school": "Lincoln High School",
        "district": "Des Moines Independent Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000550",
    },
    {
        "school": "Lovejoy Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000552",
    },
    {
        "school": "Madison Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000554",
    },
    {
        "school": "King Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000556",
    },
    {
        "school": "McCombs Middle School",
        "district": "Des Moines Independent Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000557",
    },
    {
        "school": "McKinley Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000559",
    },
    {
        "school": "Meredith Middle School",
        "district": "Des Moines Independent Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000560",
    },
    {
        "school": "Merrill Middle School",
        "district": "Des Moines Independent Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000561",
    },
    {
        "school": "Monroe Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000563",
    },
    {
        "school": "Moulton Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000565",
    },
    {
        "school": "North High School",
        "district": "Des Moines Independent Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000566",
    },
    {
        "school": "Oak Park",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000567",
    },
    {
        "school": "Orchard Place School",
        "district": "Des Moines Independent Comm School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "190897000568",
    },
    {
        "school": "Park Ave Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000569",
    },
    {
        "school": "Perkins Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000570",
    },
    {
        "school": "Phillips Elementary",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000571",
    },
    {
        "school": "Pleasant Hill Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000572",
    },
    {
        "school": "Roosevelt High School",
        "district": "Des Moines Independent Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000574",
    },
    {
        "school": "Stowe Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000577",
    },
    {
        "school": "Studebaker Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000578",
    },
    {
        "school": "Morris Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000583",
    },
    {
        "school": "Weeks Middle School",
        "district": "Des Moines Independent Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000584",
    },
    {
        "school": "Willard Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000585",
    },
    {
        "school": "Windsor Elementary",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000587",
    },
    {
        "school": "Wright Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000589",
    },
    {
        "school": "River Woods Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897000728",
    },
    {
        "school": "Cowles Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897002011",
    },
    {
        "school": "Beaver Creek Elementary School",
        "district": "Johnston Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191545000478",
    },
    {
        "school": "Lawson Elementary School",
        "district": "Johnston Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191545000532",
    },
    {
        "school": "Horizon Elementary",
        "district": "Johnston Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191545000653",
    },
    {
        "school": "Johnston Middle School",
        "district": "Johnston Comm School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191545000926",
    },
    {
        "school": "Johnston Senior High School",
        "district": "Johnston Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191545000927",
    },
    {
        "school": "Henry A Wallace Elementary School",
        "district": "Johnston Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191545002018",
    },
    {
        "school": "North Polk High School",
        "district": "North Polk Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192091001248",
    },
    {
        "school": "North Polk West Elementary School",
        "district": "North Polk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192091001249",
    },
    {
        "school": "North Polk Central Elementary School",
        "district": "North Polk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192091001923",
    },
    {
        "school": "Cornell Elementary School",
        "district": "Saydel Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192532001445",
    },
    {
        "school": "Saydel High School",
        "district": "Saydel Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192532001447",
    },
    {
        "school": "Woodside Middle School",
        "district": "Saydel Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192532001448",
    },
    {
        "school": "Altoona Elementary",
        "district": "Southeast Polk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192682001566",
    },
    {
        "school": "Centennial Elementary",
        "district": "Southeast Polk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192682001567",
    },
    {
        "school": "Delaware Elementary",
        "district": "Southeast Polk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192682001568",
    },
    {
        "school": "Four Mile Elementary",
        "district": "Southeast Polk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192682001569",
    },
    {
        "school": "Mitchellville Elementary",
        "district": "Southeast Polk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192682001570",
    },
    {
        "school": "Runnells Elementary",
        "district": "Southeast Polk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192682001571",
    },
    {
        "school": "Southeast Polk High School",
        "district": "Southeast Polk Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192682001572",
    },
    {
        "school": "Southeast Polk Junior High",
        "district": "Southeast Polk Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192682001573",
    },
    {
        "school": "Willowbrook Elementary",
        "district": "Southeast Polk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192682002068",
    },
    {
        "school": "Jensen Elementary School",
        "district": "Urbandale Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192868001655",
    },
    {
        "school": "Karen Acres Elementary School",
        "district": "Urbandale Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192868001656",
    },
    {
        "school": "Rolling Green Elementary School",
        "district": "Urbandale Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192868001658",
    },
    {
        "school": "Urbandale High School",
        "district": "Urbandale Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192868001659",
    },
    {
        "school": "Urbandale Middle School",
        "district": "Urbandale Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192868001660",
    },
    {
        "school": "Valerius Elementary School",
        "district": "Urbandale Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192868002069",
    },
    {
        "school": "Jordan Creek Elementary School",
        "district": "West Des Moines Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093000168",
    },
    {
        "school": "Walnut Creek Campus",
        "district": "West Des Moines Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "193093000393",
    },
    {
        "school": "Valley Southwoods",
        "district": "West Des Moines Comm School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093000483",
    },
    {
        "school": "Clive Learning Academy",
        "district": "West Des Moines Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093001789",
    },
    {
        "school": "Crestview School of Inquiry",
        "district": "West Des Moines Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093001790",
    },
    {
        "school": "Crossroads Park Elementary School",
        "district": "West Des Moines Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093001791",
    },
    {
        "school": "Fairmeadows Elementary School",
        "district": "West Des Moines Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093001792",
    },
    {
        "school": "Indian Hills Junior High School",
        "district": "West Des Moines Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093001793",
    },
    {
        "school": "Stilwell Junior High School",
        "district": "West Des Moines Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093001796",
    },
    {
        "school": "Valley High School",
        "district": "West Des Moines Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093001797",
    },
    {
        "school": "Western Hills Elementary School",
        "district": "West Des Moines Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093001798",
    },
    {
        "school": "Westridge Elementary",
        "district": "West Des Moines Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193093002055",
    },
    {
        "school": "Carlisle Elementary School",
        "district": "Carlisle Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190627000214",
    },
    {
        "school": "Carlisle High School",
        "district": "Carlisle Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190627000215",
    },
    {
        "school": "Hartford Upper Elementary",
        "district": "Carlisle Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190627000216",
    },
    {
        "school": "Emerson Elementary School",
        "district": "Indianola Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191464000870",
    },
    {
        "school": "Indianola High School",
        "district": "Indianola Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191464000872",
    },
    {
        "school": "Irving Elementary School",
        "district": "Indianola Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191464000874",
    },
    {
        "school": "Indianola Middle School",
        "district": "Indianola Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191464000875",
    },
    {
        "school": "Whittier Elementary School",
        "district": "Indianola Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191464000876",
    },
    {
        "school": "Martensdale Elementary School",
        "district": "Martensdale-St Marys Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191875001096",
    },
    {
        "school": "Martensdale-St Marys Jr-Sr High School",
        "district": "Martensdale-St Marys Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191875001097",
    },
    {
        "school": "Lakewood Elementary School",
        "district": "Norwalk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192124001273",
    },
    {
        "school": "Norwalk Middle School",
        "district": "Norwalk Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192124001274",
    },
    {
        "school": "Norwalk Senior High School",
        "district": "Norwalk Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192124001275",
    },
    {
        "school": "Oviatt Elementary School",
        "district": "Norwalk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192124001276",
    },
    {
        "school": "Southeast Warren Intermediate",
        "district": "Southeast Warren Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192685001574",
    },
    {
        "school": "Southeast Warren Primary",
        "district": "Southeast Warren Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192685001575",
    },
    {
        "school": "Southeast Warren Jr-Sr High School",
        "district": "Southeast Warren Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192685001576",
    },
    {
        "school": "Eleanor Roosevelt Middle School",
        "district": "Dubuque Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000976",
    },
    {
        "school": "Carver Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948001532",
    },
    {
        "school": "Peosta Elementary School",
        "district": "Western Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193135001346",
    },
    {
        "school": "Audubon Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000602",
    },
    {
        "school": "Bryant Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000603",
    },
    {
        "school": "Dubuque Senior High School",
        "district": "Dubuque Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000604",
    },
    {
        "school": "Eisenhower Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000605",
    },
    {
        "school": "Fulton Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000607",
    },
    {
        "school": "Hempstead High School",
        "district": "Dubuque Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000608",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000609",
    },
    {
        "school": "Irving Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000610",
    },
    {
        "school": "Thomas Jefferson Middle School",
        "district": "Dubuque Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000612",
    },
    {
        "school": "John Kennedy Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000613",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000614",
    },
    {
        "school": "Marshall Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000615",
    },
    {
        "school": "Sageville Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000617",
    },
    {
        "school": "Table Mound Elementary School",
        "district": "Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000619",
    },
    {
        "school": "George Washington Middle School",
        "district": "Dubuque Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190948000620",
    },
    {
        "school": "Drexler Middle- Intermediate School",
        "district": "Western Dubuque Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193135000205",
    },
    {
        "school": "Cascade Elementary School",
        "district": "Western Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193135001824",
    },
    {
        "school": "Cascade Junior-Senior High School",
        "district": "Western Dubuque Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193135001825",
    },
    {
        "school": "Dyersville Elementary School",
        "district": "Western Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193135001828",
    },
    {
        "school": "Epworth Elementary School",
        "district": "Western Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193135001829",
    },
    {
        "school": "Farley Elementary School",
        "district": "Western Dubuque Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193135001830",
    },
    {
        "school": "Western Dubuque High School",
        "district": "Western Dubuque Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193135001832",
    },
    {
        "school": "Prairie Valley Elementary School",
        "district": "Prairie Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002801381",
    },
    {
        "school": "Southeast Valley High School",
        "district": "Prairie Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002801382",
    },
    {
        "school": "Butler Elementary School",
        "district": "Fort Dodge Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191182000720",
    },
    {
        "school": "Cooper Elementary School",
        "district": "Fort Dodge Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191182000721",
    },
    {
        "school": "Duncombe Elementary School",
        "district": "Fort Dodge Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191182000722",
    },
    {
        "school": "Feelhaver Elementary School",
        "district": "Fort Dodge Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191182000723",
    },
    {
        "school": "Fort Dodge High School",
        "district": "Fort Dodge Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191182000724",
    },
    {
        "school": "Dayton Center",
        "district": "Southeast Webster Grand Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "199901902077",
    },
    {
        "school": "Elizabeth Tate Alt. High School",
        "district": "Iowa City Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "191470001030",
    },
    {
        "school": "James Van Allen Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470001034",
    },
    {
        "school": "Solon Middle School",
        "district": "Solon Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192658000707",
    },
    {
        "school": "Highland High School",
        "district": "Highland Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191401000839",
    },
    {
        "school": "Highland Middle School",
        "district": "Highland Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191401000840",
    },
    {
        "school": "Highland Elementary School",
        "district": "Highland Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191401000842",
    },
    {
        "school": "Mid-Prairie East Elem. School",
        "district": "Mid-Prairie Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191914001130",
    },
    {
        "school": "Mid-Prairie High School",
        "district": "Mid-Prairie Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191914001131",
    },
    {
        "school": "Mid-Prairie Middle School",
        "district": "Mid-Prairie Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191914001132",
    },
    {
        "school": "Mid-Prairie West Elem. School",
        "district": "Mid-Prairie Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191914001134",
    },
    {
        "school": "Lincoln Upper Elementary School",
        "district": "Washington Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193024001702",
    },
    {
        "school": "Stewart Elementary School",
        "district": "Washington Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193024001703",
    },
    {
        "school": "Washington High School",
        "district": "Washington Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193024001704",
    },
    {
        "school": "Washington Middle School",
        "district": "Washington Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193024001705",
    },
    {
        "school": "Amana Elementary School",
        "district": "Clear Creek Amana Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190759000048",
    },
    {
        "school": "Clear Creek Amana Middle School",
        "district": "Clear Creek Amana Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190759001903",
    },
    {
        "school": "Clear Creek Elementary School",
        "district": "Clear Creek Amana Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190759000359",
    },
    {
        "school": "Clear Creek Amana High School",
        "district": "Clear Creek Amana Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190759000361",
    },
    {
        "school": "Weber Elementary",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000304",
    },
    {
        "school": "Wickham Elementary",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000436",
    },
    {
        "school": "Bohumil Shimek Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000881",
    },
    {
        "school": "Central Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000883",
    },
    {
        "school": "Ernest Horn Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000885",
    },
    {
        "school": "Grant Wood Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000886",
    },
    {
        "school": "Helen Lemme Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000887",
    },
    {
        "school": "Hills Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000890",
    },
    {
        "school": "Horace Mann Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000891",
    },
    {
        "school": "Iowa City High School",
        "district": "Iowa City Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000892",
    },
    {
        "school": "Kirkwood Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000893",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000894",
    },
    {
        "school": "Longfellow Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000895",
    },
    {
        "school": "Mark Twain Elementary",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000896",
    },
    {
        "school": "Northwest Junior High School",
        "district": "Iowa City Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000897",
    },
    {
        "school": "Penn Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000898",
    },
    {
        "school": "Robert Lucas Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000899",
    },
    {
        "school": "Southeast Junior High School",
        "district": "Iowa City Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000901",
    },
    {
        "school": "West Senior High School",
        "district": "Iowa City Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470000902",
    },
    {
        "school": "Lone Tree Elementary School",
        "district": "Lone Tree Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191755001018",
    },
    {
        "school": "Lone Tree Junior-Senior High School",
        "district": "Lone Tree Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191755001019",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Solon Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192658001542",
    },
    {
        "school": "Solon High School",
        "district": "Solon Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192658001543",
    },
    {
        "school": "Central Lee High School",
        "district": "Central Lee Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190693000302",
    },
    {
        "school": "Central Lee Middle School",
        "district": "Central Lee Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190693000303",
    },
    {
        "school": "Central Lee Elementary School",
        "district": "Central Lee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190693000305",
    },
    {
        "school": "Fort Madison High School",
        "district": "Fort Madison Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191185000733",
    },
    {
        "school": "Fort Madison Middle School",
        "district": "Fort Madison Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191185000734",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Fort Madison Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191185000736",
    },
    {
        "school": "Richardson Elementary School",
        "district": "Fort Madison Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191185000737",
    },
    {
        "school": "Hawthorne Elementary School",
        "district": "Keokuk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191563000930",
    },
    {
        "school": "Keokuk High School",
        "district": "Keokuk Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191563000932",
    },
    {
        "school": "Keokuk Middle School",
        "district": "Keokuk Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191563000933",
    },
    {
        "school": "George Washington Elementary School",
        "district": "Keokuk Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191563000936",
    },
    {
        "school": "East Marshall Senior High School",
        "district": "East Marshall Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190004000117",
    },
    {
        "school": "East Marshall Middle School",
        "district": "East Marshall Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190004000121",
    },
    {
        "school": "East Marshall Elementary School",
        "district": "East Marshall Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190004000132",
    },
    {
        "school": "Franklin Elementary Sch",
        "district": "Marshalltown Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191872000372",
    },
    {
        "school": "Anson Elementary School",
        "district": "Marshalltown Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191872001082",
    },
    {
        "school": "B R Miller Middle School",
        "district": "Marshalltown Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191872001084",
    },
    {
        "school": "Fisher Elementary School",
        "district": "Marshalltown Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191872001086",
    },
    {
        "school": "J C Hoglan Elementary School",
        "district": "Marshalltown Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191872001089",
    },
    {
        "school": "Marshalltown High School",
        "district": "Marshalltown Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191872001091",
    },
    {
        "school": "Rogers Elementary School",
        "district": "Marshalltown Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191872001093",
    },
    {
        "school": "Woodbury Elementary School",
        "district": "Marshalltown Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191872001095",
    },
    {
        "school": "West Marshall Elementary School",
        "district": "West Marshall Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193108001811",
    },
    {
        "school": "West Marshall High School",
        "district": "West Marshall Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193108001812",
    },
    {
        "school": "West Marshall Middle School",
        "district": "West Marshall Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193108001813",
    },
    {
        "school": "Clear Creek Elementary School",
        "district": "Clear Lake Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190762000362",
    },
    {
        "school": "Clear Lake High School",
        "district": "Clear Lake Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190762000363",
    },
    {
        "school": "Clear Lake Middle School",
        "district": "Clear Lake Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190762000364",
    },
    {
        "school": "Alternative School",
        "district": "Mason City Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "191878001099",
    },
    {
        "school": "Harding Elementary School",
        "district": "Mason City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191878001102",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Mason City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191878001103",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Mason City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191878001104",
    },
    {
        "school": "John Adams Middle School",
        "district": "Mason City Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191878001105",
    },
    {
        "school": "Mason City High School",
        "district": "Mason City Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191878001107",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Mason City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191878001109",
    },
    {
        "school": "Central Springs Elem. Manly Campus",
        "district": "Central Springs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192076001238",
    },
    {
        "school": "Central Springs High School",
        "district": "Central Springs Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192076001239",
    },
    {
        "school": "Northwood-Kensett Elementary",
        "district": "Northwood-Kensett Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192121001270",
    },
    {
        "school": "Northwood-Kensett Jr-Sr High School",
        "district": "Northwood-Kensett Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192121001271",
    },
    {
        "school": "Early Childhood Center",
        "district": "West Liberty Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193099001408",
    },
    {
        "school": "Columbus Community High School",
        "district": "Columbus Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190798000396",
    },
    {
        "school": "Roundy Elementary School",
        "district": "Columbus Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190798000397",
    },
    {
        "school": "Columbus Community Junior High School",
        "district": "Columbus Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190798000398",
    },
    {
        "school": "Louisa-Muscatine Elementary",
        "district": "Louisa-Muscatine Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191782001023",
    },
    {
        "school": "Louisa-Muscatine High School",
        "district": "Louisa-Muscatine Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191782001025",
    },
    {
        "school": "Morning Sun Elementary School",
        "district": "Morning Sun Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191977001161",
    },
    {
        "school": "Wapello Elementary School",
        "district": "Wapello Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192973001691",
    },
    {
        "school": "Wapello Senior High School",
        "district": "Wapello Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192973001692",
    },
    {
        "school": "Wapello Junior High School",
        "district": "Wapello Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192973001927",
    },
    {
        "school": "Central Middle School",
        "district": "Muscatine Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192013001182",
    },
    {
        "school": "Muskie Early Learning Center",
        "district": "Muscatine Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192013001183",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Muscatine Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192013001184",
    },
    {
        "school": "Grant Elementary School",
        "district": "Muscatine Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192013001186",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Muscatine Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192013001187",
    },
    {
        "school": "Madison Elementary School",
        "district": "Muscatine Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192013001189",
    },
    {
        "school": "McKinley Elementary School",
        "district": "Muscatine Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192013001190",
    },
    {
        "school": "Mulberry Elementary School",
        "district": "Muscatine Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192013001192",
    },
    {
        "school": "Muscatine High School",
        "district": "Muscatine Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192013001193",
    },
    {
        "school": "West Middle School",
        "district": "Muscatine Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192013001195",
    },
    {
        "school": "West Liberty Middle School",
        "district": "West Liberty Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193099001804",
    },
    {
        "school": "West Liberty High School",
        "district": "West Liberty Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193099001805",
    },
    {
        "school": "Wilton Elementary School",
        "district": "Wilton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193180001849",
    },
    {
        "school": "Wilton Jr-Sr High School",
        "district": "Wilton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193180001850",
    },
    {
        "school": "Colfax-Mingo Elementary School",
        "district": "Colfax-Mingo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190000900385",
    },
    {
        "school": "Colfax-Mingo High School",
        "district": "Colfax-Mingo Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190000900386",
    },
    {
        "school": "Baxter Elementary School",
        "district": "Baxter Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190438000113",
    },
    {
        "school": "Baxter High School",
        "district": "Baxter Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190438000114",
    },
    {
        "school": "Lynnville-Sully High School",
        "district": "Lynnville-Sully Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191803001031",
    },
    {
        "school": "Lynnville-Sully Elementary School",
        "district": "Lynnville-Sully Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191803001964",
    },
    {
        "school": "Lynnville-Sully Middle School",
        "district": "Lynnville-Sully Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191803001994",
    },
    {
        "school": "Newton Senior High School",
        "district": "Newton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192061001226",
    },
    {
        "school": "WEST Academy Alternative School",
        "district": "Newton Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "192061002052",
    },
    {
        "school": "PCM High School",
        "district": "PCM Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "199901702060",
    },
    {
        "school": "PCM Middle School",
        "district": "PCM Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "199901702061",
    },
    {
        "school": "Prairie City Elementary School",
        "district": "PCM Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "199901702062",
    },
    {
        "school": "Monroe Elementary School",
        "district": "PCM Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "199901702063",
    },
    {
        "school": "Boyer Valley Elementary School",
        "district": "Boyer Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190957000599",
    },
    {
        "school": "Boyer Valley Middle/High School",
        "district": "Boyer Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190957000628",
    },
    {
        "school": "Logan-Magnolia Elementary School",
        "district": "Logan-Magnolia Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191746001013",
    },
    {
        "school": "Logan-Magnolia Jr-Sr High School",
        "district": "Logan-Magnolia Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191746001014",
    },
    {
        "school": "Missouri Valley Elementary",
        "district": "Missouri Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191944001145",
    },
    {
        "school": "Missouri Valley High School",
        "district": "Missouri Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191944001146",
    },
    {
        "school": "Missouri Valley Middle School",
        "district": "Missouri Valley Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191944001147",
    },
    {
        "school": "West Harrison Elementary",
        "district": "West Harrison Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193096000331",
    },
    {
        "school": "West Harrison High School West Harrison Middle Sch",
        "district": "West Harrison Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193096001801",
    },
    {
        "school": "Woodbine Elementary School",
        "district": "Woodbine Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193192001861",
    },
    {
        "school": "Woodbine High School",
        "district": "Woodbine Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193192001862",
    },
    {
        "school": "Glenwood Middle School",
        "district": "Glenwood Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191269000766",
    },
    {
        "school": "Glenwood Senior High School",
        "district": "Glenwood Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191269000767",
    },
    {
        "school": "Northeast Elementary School",
        "district": "Glenwood Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191269000768",
    },
    {
        "school": "West Elementary School",
        "district": "Glenwood Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191269000770",
    },
    {
        "school": "East Mills Jr/Sr High School",
        "district": "East Mills Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191824001046",
    },
    {
        "school": "Riverside Community Intermediate School",
        "district": "Riverside Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002700249",
    },
    {
        "school": "Riverside Community High School",
        "district": "Riverside Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002700260",
    },
    {
        "school": "AHSTW Primary School",
        "district": "AHSTW Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190408000101",
    },
    {
        "school": "AHSTW High School",
        "district": "AHSTW Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190408000102",
    },
    {
        "school": "Abraham Lincoln High School",
        "district": "Council Bluffs Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000409",
    },
    {
        "school": "Bloomer Elementary School",
        "district": "Council Bluffs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000411",
    },
    {
        "school": "Carter Lake Elementary School",
        "district": "Council Bluffs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000413",
    },
    {
        "school": "Crescent Elementary School",
        "district": "Council Bluffs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000414",
    },
    {
        "school": "Edison Elementary School",
        "district": "Council Bluffs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000416",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Council Bluffs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000418",
    },
    {
        "school": "Gerald W Kirn Middle School",
        "district": "Council Bluffs Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000419",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Council Bluffs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000422",
    },
    {
        "school": "Lewis & Clark Elementary School",
        "district": "Council Bluffs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000424",
    },
    {
        "school": "Longfellow Elementary School",
        "district": "Council Bluffs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000425",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Council Bluffs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000431",
    },
    {
        "school": "Rue Elementary School",
        "district": "Council Bluffs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000433",
    },
    {
        "school": "Thomas Jefferson High School",
        "district": "Council Bluffs Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000435",
    },
    {
        "school": "Woodrow Wilson Middle School",
        "district": "Council Bluffs Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822000440",
    },
    {
        "school": "Titan Hill Intermediate School",
        "district": "Lewis Central Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191668000994",
    },
    {
        "school": "E A Kreft Primary School",
        "district": "Lewis Central Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191668000995",
    },
    {
        "school": "Lewis Central Senior High School",
        "district": "Lewis Central Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191668000996",
    },
    {
        "school": "Lewis Central Middle School",
        "district": "Lewis Central Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191668000997",
    },
    {
        "school": "Treynor Elementary School",
        "district": "Treynor Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192796001626",
    },
    {
        "school": "Treynor High School",
        "district": "Treynor Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192796001627",
    },
    {
        "school": "Tri-Center Middle School",
        "district": "Tri-Center Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192799000309",
    },
    {
        "school": "Tri-Center Elementary School",
        "district": "Tri-Center Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192799001630",
    },
    {
        "school": "Tri-Center High School",
        "district": "Tri-Center Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192799001632",
    },
    {
        "school": "Underwood Elementary School",
        "district": "Underwood Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192823001646",
    },
    {
        "school": "Underwood High School",
        "district": "Underwood Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192823001647",
    },
    {
        "school": "Underwood Middle School",
        "district": "Underwood Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192823001892",
    },
    {
        "school": "Oskaloosa Elementary School",
        "district": "Oskaloosa Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192187001094",
    },
    {
        "school": "North Mahaska Jr-Sr High School",
        "district": "North Mahaska Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192085001245",
    },
    {
        "school": "North Mahaska Elementary School",
        "district": "North Mahaska Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192085001246",
    },
    {
        "school": "Oskaloosa High School",
        "district": "Oskaloosa Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192187001309",
    },
    {
        "school": "Oskaloosa Middle School",
        "district": "Oskaloosa Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192187001310",
    },
    {
        "school": "Blakesburg Elementary",
        "district": "Eddyville-Blakesburg- Fremont CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190495000151",
    },
    {
        "school": "Eddyville Elementary",
        "district": "Eddyville-Blakesburg- Fremont CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190495000667",
    },
    {
        "school": "Eddyville-Blakesburg- Fremont Jr/Sr High",
        "district": "Eddyville-Blakesburg- Fremont CSD",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190495000668",
    },
    {
        "school": "Cardinal High School",
        "district": "Cardinal Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190624000211",
    },
    {
        "school": "Cardinal Elementary",
        "district": "Cardinal Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190624001975",
    },
    {
        "school": "Eisenhower Elementary School",
        "district": "Ottumwa Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192211001315",
    },
    {
        "school": "Evans Middle School",
        "district": "Ottumwa Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192211001316",
    },
    {
        "school": "Horace Mann Elementary School",
        "district": "Ottumwa Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192211001319",
    },
    {
        "school": "James Elementary School",
        "district": "Ottumwa Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192211001320",
    },
    {
        "school": "Ottumwa High School",
        "district": "Ottumwa Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192211001322",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Ottumwa Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192211001328",
    },
    {
        "school": "Pickwick Early Childhood Center",
        "district": "Ottumwa Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192211002034",
    },
    {
        "school": "Madison Elementary School",
        "district": "Pella Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192247001508",
    },
    {
        "school": "North Middle School",
        "district": "Sioux City Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001287",
    },
    {
        "school": "River Valley Elementary",
        "district": "River Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191034000657",
    },
    {
        "school": "River Valley Junior- Senior High School",
        "district": "River Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191034000658",
    },
    {
        "school": "Bronson Elementary School",
        "district": "Lawton-Bronson Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191644000980",
    },
    {
        "school": "Lawton-Bronson Junior-Senior High School",
        "district": "Lawton-Bronson Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191644000981",
    },
    {
        "school": "Sergeant Bluff-Luton Elementary School",
        "district": "Sergeant Bluff-Luton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192559000726",
    },
    {
        "school": "Sergeant Bluff-Luton Senior High School",
        "district": "Sergeant Bluff-Luton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192559001460",
    },
    {
        "school": "Sergeant Bluff-Luton Primary School",
        "district": "Sergeant Bluff-Luton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192559001461",
    },
    {
        "school": "Sergeant Bluff-Luton Middle School",
        "district": "Sergeant Bluff-Luton Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192559001891",
    },
    {
        "school": "Bryant Elementary School",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001498",
    },
    {
        "school": "Clark Early Childhood Center",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001500",
    },
    {
        "school": "East High School",
        "district": "Sioux City Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001504",
    },
    {
        "school": "East Middle School",
        "district": "Sioux City Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001505",
    },
    {
        "school": "Hunt Elementary School",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001513",
    },
    {
        "school": "Irving Elementary School",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001514",
    },
    {
        "school": "Nodland Elementary School",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001521",
    },
    {
        "school": "North High School",
        "district": "Sioux City Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001522",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001526",
    },
    {
        "school": "Sunnyside Elementary School",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001530",
    },
    {
        "school": "West High School",
        "district": "Sioux City Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001533",
    },
    {
        "school": "West Middle School",
        "district": "Sioux City Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001534",
    },
    {
        "school": "Leeds Elementary School",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640001934",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Westwood Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193147001835",
    },
    {
        "school": "Westwood High School",
        "district": "Westwood Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193147001837",
    },
    {
        "school": "Moville Elementary School",
        "district": "Woodbury Central Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193195001863",
    },
    {
        "school": "Woodbury Central Middle School",
        "district": "Woodbury Central Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193195001864",
    },
    {
        "school": "Woodbury Central High School",
        "district": "Woodbury Central Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193195001865",
    },
    {
        "school": "Clay Central-Everly Elementary",
        "district": "Clay Central-Everly Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190747002027",
    },
    {
        "school": "Spencer High School",
        "district": "Spencer Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192691001582",
    },
    {
        "school": "Spencer Middle School",
        "district": "Spencer Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192691001583",
    },
    {
        "school": "Okoboji High School",
        "district": "Okoboji Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002102002",
    },
    {
        "school": "Okoboji Middle School",
        "district": "Okoboji Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002102003",
    },
    {
        "school": "Okoboji Elementary School",
        "district": "Okoboji Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002102004",
    },
    {
        "school": "Harris-Lake Park Elementary School",
        "district": "Harris-Lake Park Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191614000966",
    },
    {
        "school": "Harris-Lake Park High School",
        "district": "Harris-Lake Park Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191614000967",
    },
    {
        "school": "Spirit Lake Elementary School",
        "district": "Spirit Lake Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192700001584",
    },
    {
        "school": "Spirit Lake High School",
        "district": "Spirit Lake Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192700001585",
    },
    {
        "school": "Spirit Lake Middle School",
        "district": "Spirit Lake Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192700001905",
    },
    {
        "school": "Sioux Central Middle School",
        "district": "Sioux Central Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002300835",
    },
    {
        "school": "Albert City-Truesdale Elementary School",
        "district": "Albert City-Truesdale Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190003101300",
    },
    {
        "school": "St Lake/IA Cntrl/Buena Vista Early College HS",
        "district": "Storm Lake Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192739000847",
    },
    {
        "school": "Sioux Central Elementary School",
        "district": "Sioux Central Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002301541",
    },
    {
        "school": "Sioux Central High",
        "district": "Sioux Central Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002301896",
    },
    {
        "school": "Alta Elementary School",
        "district": "Alta-Aurelia Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190348000045",
    },
    {
        "school": "Alta-Aurelia High School",
        "district": "Alta-Aurelia Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190348000046",
    },
    {
        "school": "Newell-Fonda Elementary",
        "district": "Newell-Fonda Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192058001217",
    },
    {
        "school": "Newell-Fonda High School",
        "district": "Newell-Fonda Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192058001218",
    },
    {
        "school": "East Early Childhood Ctr",
        "district": "Storm Lake Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192739001597",
    },
    {
        "school": "Storm Lake Middle School",
        "district": "Storm Lake Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192739001600",
    },
    {
        "school": "Storm Lake High School",
        "district": "Storm Lake Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192739001601",
    },
    {
        "school": "Newell-Fonda Middle Sch.",
        "district": "Newell-Fonda Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192058000713",
    },
    {
        "school": "Lou Henry Elementary School",
        "district": "Waterloo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001165",
    },
    {
        "school": "Poyner Elementary",
        "district": "Waterloo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001546",
    },
    {
        "school": "Elk Run Early Childhood Center",
        "district": "Waterloo Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001560",
    },
    {
        "school": "K-5 Elementary School Lincoln Street Building",
        "district": "Denver Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190894000831",
    },
    {
        "school": "Greenview Alternative School",
        "district": "Waverly-Shell Rock Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "193054000832",
    },
    {
        "school": "Denver Early Elementary School",
        "district": "Denver Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190894000512",
    },
    {
        "school": "Denver Middle School",
        "district": "Denver Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190894000513",
    },
    {
        "school": "Denver Senior High School",
        "district": "Denver Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190894000514",
    },
    {
        "school": "Janesville Elementary School",
        "district": "Janesville Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191518000913",
    },
    {
        "school": "Janesville Junior-Senior High School",
        "district": "Janesville Consolidated School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191518000914",
    },
    {
        "school": "Durant Elementary School",
        "district": "Sumner-Fredericksburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192760001609",
    },
    {
        "school": "Sumner-Fredericksburg HS",
        "district": "Sumner-Fredericksburg Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192760001610",
    },
    {
        "school": "Tripoli Elementary School",
        "district": "Tripoli Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192805001637",
    },
    {
        "school": "Tripoli Middle/Sr High School",
        "district": "Tripoli Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192805001638",
    },
    {
        "school": "Readlyn Elementary School",
        "district": "Wapsie Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192976001694",
    },
    {
        "school": "Wapsie Valley High School",
        "district": "Wapsie Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192976001700",
    },
    {
        "school": "Margaretta Carey Elementary School",
        "district": "Waverly-Shell Rock Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193054001745",
    },
    {
        "school": "Southeast Elementary School",
        "district": "Waverly-Shell Rock Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193054001747",
    },
    {
        "school": "Waverly-Shell Rock Senior High School",
        "district": "Waverly-Shell Rock Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193054001749",
    },
    {
        "school": "West Cedar Elementary School",
        "district": "Waverly-Shell Rock Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193054001751",
    },
    {
        "school": "Rural Elementary School #2",
        "district": "Wapsie Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192976000520",
    },
    {
        "school": "Fairbank Elementary School",
        "district": "Wapsie Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192976001693",
    },
    {
        "school": "Rural Elementary School #1",
        "district": "Wapsie Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192976001695",
    },
    {
        "school": "Rural Elementary School #3",
        "district": "Wapsie Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192976001697",
    },
    {
        "school": "Rural Elementary School #4",
        "district": "Wapsie Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192976001698",
    },
    {
        "school": "Dike-New Hartford Junior High School",
        "district": "Dike-New Hartford Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190912001207",
    },
    {
        "school": "New Hartford Elementary School",
        "district": "Dike-New Hartford Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190912001208",
    },
    {
        "school": "Shell Rock Elementary School",
        "district": "Waverly-Shell Rock Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193054001746",
    },
    {
        "school": "BCLUW High School",
        "district": "BCLUW Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190444000118",
    },
    {
        "school": "BCLUW Elementary School",
        "district": "BCLUW Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190444000119",
    },
    {
        "school": "Dike Elementary School",
        "district": "Dike-New Hartford Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190912000595",
    },
    {
        "school": "Dike-New Hartford High School",
        "district": "Dike-New Hartford Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190912000596",
    },
    {
        "school": "Gladbrook-Reinbeck Jr. High & High School",
        "district": "Gladbrook-Reinbeck Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191266001402",
    },
    {
        "school": "Grundy Center Middle School",
        "district": "Grundy Center Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191329000415",
    },
    {
        "school": "Grundy Center Elementary School",
        "district": "Grundy Center Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191329000799",
    },
    {
        "school": "Grundy Center High School",
        "district": "Grundy Center Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191329000801",
    },
    {
        "school": "BCLUW Middle School",
        "district": "BCLUW Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190444000087",
    },
    {
        "school": "Gladbrook-Reinbeck Elementary School",
        "district": "Gladbrook-Reinbeck Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191266000764",
    },
    {
        "school": "La Porte City Elementary School",
        "district": "Union Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002200956",
    },
    {
        "school": "Union High School",
        "district": "Union Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002200957",
    },
    {
        "school": "Cedar Falls High School",
        "district": "Cedar Falls Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190651000221",
    },
    {
        "school": "Cedar Heights Elementary School",
        "district": "Cedar Falls Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190651000222",
    },
    {
        "school": "Helen A Hansen Elementary School",
        "district": "Cedar Falls Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190651000223",
    },
    {
        "school": "Holmes Junior High School",
        "district": "Cedar Falls Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190651000224",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Cedar Falls Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190651000226",
    },
    {
        "school": "North Cedar Elementary School",
        "district": "Cedar Falls Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190651000227",
    },
    {
        "school": "Orchard Hill Elementary School",
        "district": "Cedar Falls Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190651000228",
    },
    {
        "school": "Peet Junior High School",
        "district": "Cedar Falls Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190651000229",
    },
    {
        "school": "Southdale Elementary School",
        "district": "Cedar Falls Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190651000230",
    },
    {
        "school": "Dunkerton Elementary",
        "district": "Dunkerton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190954000624",
    },
    {
        "school": "Dunkerton High School",
        "district": "Dunkerton Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190954000625",
    },
    {
        "school": "Hudson Elementary School",
        "district": "Hudson Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191434000856",
    },
    {
        "school": "Hudson High School",
        "district": "Hudson Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191434000857",
    },
    {
        "school": "Bunger Middle School",
        "district": "Waterloo Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048000586",
    },
    {
        "school": "East High School",
        "district": "Waterloo Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001714",
    },
    {
        "school": "Fred Becker Elementary School",
        "district": "Waterloo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001715",
    },
    {
        "school": "Cunningham School",
        "district": "Waterloo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001719",
    },
    {
        "school": "Hoover Middle School",
        "district": "Waterloo Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001723",
    },
    {
        "school": "Irving Elementary School",
        "district": "Waterloo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001724",
    },
    {
        "school": "George Washington Carver Academy",
        "district": "Waterloo Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001725",
    },
    {
        "school": "Kingsley Elementary School",
        "district": "Waterloo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001727",
    },
    {
        "school": "Kittrell Elementary School",
        "district": "Waterloo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001728",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Waterloo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001729",
    },
    {
        "school": "Lowell Elementary School",
        "district": "Waterloo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001731",
    },
    {
        "school": "Orange Elementary School",
        "district": "Waterloo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001734",
    },
    {
        "school": "West High School",
        "district": "Waterloo Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001738",
    },
    {
        "school": "Highland Elementary School",
        "district": "Waterloo Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048001970",
    },
    {
        "school": "Central Middle School",
        "district": "Waterloo Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193048002024",
    },
    {
        "school": "Dysart-Geneseo Elementary School",
        "district": "Union Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002200632",
    },
    {
        "school": "Union Middle School",
        "district": "Union Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002202013",
    },
    {
        "school": "Robert Janss School",
        "district": "IDAHO DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160001700921",
    },
    {
        "school": "REED ELEMENTARY SCHOOL",
        "district": "KUNA JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160177000904",
    },
    {
        "school": "INDIAN CREEK ELEMENTARY",
        "district": "KUNA JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160177000913",
    },
    {
        "school": "ROSS ELEMENTARY SCHOOL",
        "district": "KUNA JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160177000915",
    },
    {
        "school": "DESERT SAGE ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000901",
    },
    {
        "school": "PROSPECT ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000902",
    },
    {
        "school": "PATHWAYS MIDDLE SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160210000931",
    },
    {
        "school": "CONNOR ACADEMY",
        "district": "THE ACADEMY INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160001400891",
    },
    {
        "school": "ALTURAS ELEMENTARY SCHOOL",
        "district": "BLAINE COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160030000908",
    },
    {
        "school": "TAYLORS CROSSING CHARTER SCHOOL",
        "district": "TAYLOR'S CROSSING PUBLIC CHARTER SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160001500892",
    },
    {
        "school": "RIMROCK ELEMENTARY",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000909",
    },
    {
        "school": "WOODLAND HILLS ELEMENTARY",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000910",
    },
    {
        "school": "JCC - NAMPA",
        "district": "IDAHO DEPARTMENT OF JUVENILE CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160001600926",
    },
    {
        "school": "VALLIVUE ACADEMY",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160060000914",
    },
    {
        "school": "COLUMBIA HIGH SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000870",
    },
    {
        "school": "JCC - ST ANTHONY",
        "district": "IDAHO DEPARTMENT OF JUVENILE CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160001600920",
    },
    {
        "school": "THE PATRIOT CENTER",
        "district": "EMMETT INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160102000923",
    },
    {
        "school": "ARTEC CHARTER SCHOOL",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160219000883",
    },
    {
        "school": "MEADOWS VALLEY SCHOOL",
        "district": "MEADOWS VALLEY DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160206000826",
    },
    {
        "school": "CLOVER CREEK HIGH SCHOOL",
        "district": "BEAR LAKE COUNTY DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160024000827",
    },
    {
        "school": "HAGERMAN SCHOOL",
        "district": "HAGERMAN JOINT DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160138000840",
    },
    {
        "school": "HIGHLAND SCHOOL",
        "district": "HIGHLAND JOINT DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160144000849",
    },
    {
        "school": "NEZPERCE SCHOOL",
        "district": "NEZPERCE JOINT DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160240000848",
    },
    {
        "school": "SHOSHONE MIDDLE SCHOOL",
        "district": "SHOSHONE JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160294000850",
    },
    {
        "school": "SHOSHONE HIGH SCHOOL",
        "district": "SHOSHONE JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160294000851",
    },
    {
        "school": "ONEIDA HIGH SCHOOL",
        "district": "ONEIDA COUNTY DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160249000856",
    },
    {
        "school": "MIDVALE SCHOOL",
        "district": "MIDVALE DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160216000857",
    },
    {
        "school": "COUNCIL ELEMENTARY SCHOOL",
        "district": "COUNCIL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160084000162",
    },
    {
        "school": "COUNCIL JR/SR HIGH SCHOOL",
        "district": "COUNCIL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160084000163",
    },
    {
        "school": "A J WINTERS ELEMENTARY SCHOOL",
        "district": "BEAR LAKE COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160024000016",
    },
    {
        "school": "BEAR LAKE MIDDLE SCHOOL",
        "district": "BEAR LAKE COUNTY DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160024000017",
    },
    {
        "school": "BEAR LAKE HIGH SCHOOL",
        "district": "BEAR LAKE COUNTY DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160024000018",
    },
    {
        "school": "PARIS ELEMENTARY SCHOOL",
        "district": "BEAR LAKE COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160024000019",
    },
    {
        "school": "GEORGETOWN ELEMENTARY SCHOOL",
        "district": "BEAR LAKE COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160024000021",
    },
    {
        "school": "LAKESIDE JR HIGH SCHOOL",
        "district": "PLUMMER-WORLEY JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160081500647",
    },
    {
        "school": "LAKESIDE HIGH SCHOOL",
        "district": "PLUMMER-WORLEY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160081500720",
    },
    {
        "school": "HEYBURN ELEMENTARY SCHOOL",
        "district": "ST MARIES JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160306000485",
    },
    {
        "school": "ST MARIES COMMUNITY EDUCATION ALTERNATIVE",
        "district": "ST MARIES JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160306000491",
    },
    {
        "school": "ST MARIES HIGH SCHOOL",
        "district": "ST MARIES JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160306000532",
    },
    {
        "school": "ST MARIES MIDDLE SCHOOL",
        "district": "ST MARIES JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160306000534",
    },
    {
        "school": "UPRIVER ELEMENTARY SCHOOL",
        "district": "ST MARIES JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160306000536",
    },
    {
        "school": "BELLEVUE ELEMENTARY SCHOOL",
        "district": "BLAINE COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160030000033",
    },
    {
        "school": "CAREY PUBLIC SCHOOL",
        "district": "BLAINE COUNTY DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160030000034",
    },
    {
        "school": "ERNEST HEMINGWAY STEAM SCHOOL",
        "district": "BLAINE COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160030000035",
    },
    {
        "school": "HAILEY ELEMENTARY SCHOOL",
        "district": "BLAINE COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160030000036",
    },
    {
        "school": "WOOD RIVER HIGH SCHOOL",
        "district": "BLAINE COUNTY DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160030000038",
    },
    {
        "school": "SILVER CREEK HIGH SCHOOL",
        "district": "BLAINE COUNTY DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160030000197",
    },
    {
        "school": "WOOD RIVER MIDDLE SCHOOL",
        "district": "BLAINE COUNTY DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160030000493",
    },
    {
        "school": "PRIEST RIVER LAMANNA HIGH",
        "district": "WEST BONNER COUNTY DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000100084",
    },
    {
        "school": "PRIEST RIVER JR HIGH SCHOOL",
        "district": "WEST BONNER COUNTY DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000100085",
    },
    {
        "school": "IDAHO HILL ELEMENTARY SCHOOL",
        "district": "WEST BONNER COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000100613",
    },
    {
        "school": "PRIEST RIVER ELEMENTARY SCHOOL",
        "district": "WEST BONNER COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000100619",
    },
    {
        "school": "PRIEST LAKE ELEMENTARY SCHOOL",
        "district": "WEST BONNER COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000100620",
    },
    {
        "school": "CLARK FORK JR/SR HIGH SCHOOL",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000200082",
    },
    {
        "school": "SANDPOINT HIGH SCHOOL",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000200087",
    },
    {
        "school": "KOOTENAI ELEMENTARY SCHOOL",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000200603",
    },
    {
        "school": "SANDPOINT JUVENILE DETENTION",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160000200604",
    },
    {
        "school": "HOPE ELEMENTARY SCHOOL",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000200614",
    },
    {
        "school": "FARMIN STIDWELL ELEMENTARY SCHOOL",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000200615",
    },
    {
        "school": "SOUTHSIDE ELEMENTARY SCHOOL",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000200616",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000200617",
    },
    {
        "school": "SAGLE ELEMENTARY SCHOOL",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000200618",
    },
    {
        "school": "NORTHSIDE ELEMENTARY SCHOOL",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000200621",
    },
    {
        "school": "LAKE PEND OREILLE HIGH SCHOOL",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160000200691",
    },
    {
        "school": "SANDPOINT MIDDLE SCHOOL",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000200724",
    },
    {
        "school": "BOUNDARY COUNTY MIDDLE SCHOOL",
        "district": "BOUNDARY COUNTY DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160042000029",
    },
    {
        "school": "BONNERS FERRY HIGH SCHOOL",
        "district": "BOUNDARY COUNTY DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160042000089",
    },
    {
        "school": "MOUNT HALL ELEMENTARY SCHOOL",
        "district": "BOUNDARY COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160042000091",
    },
    {
        "school": "NAPLES ELEMENTARY SCHOOL",
        "district": "BOUNDARY COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160042000092",
    },
    {
        "school": "VALLEY VIEW ELEMENTARY SCHOOL",
        "district": "BOUNDARY COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160042000094",
    },
    {
        "school": "ARCO ELEMENTARY SCHOOL",
        "district": "BUTTE COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160049000007",
    },
    {
        "school": "BUTTE COUNTY MIDDLE/HIGH SCHOOL",
        "district": "BUTTE COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160049000008",
    },
    {
        "school": "HOWE ELEMENTARY SCHOOL",
        "district": "BUTTE COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160049000011",
    },
    {
        "school": "CAMAS COUNTY ELEM/JR HIGH SCHOOL",
        "district": "CAMAS COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160054000110",
    },
    {
        "school": "CAMAS COUNTY HIGH SCHOOL",
        "district": "CAMAS COUNTY DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160054000111",
    },
    {
        "school": "GRACE ELEMENTARY SCHOOL",
        "district": "GRACE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160129000225",
    },
    {
        "school": "GRACE JR/SR HIGH SCHOOL",
        "district": "GRACE JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160129000742",
    },
    {
        "school": "NORTH GEM ELEMENTARY",
        "district": "NORTH GEM DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160243000427",
    },
    {
        "school": "NORTH GEM HIGH SCHOOL",
        "district": "NORTH GEM DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160243000428",
    },
    {
        "school": "HOWARD E THIRKILL PRIMARY SCHOOL",
        "district": "SODA SPRINGS JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160300000525",
    },
    {
        "school": "SODA SPRINGS HIGH SCHOOL",
        "district": "SODA SPRINGS JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160300000526",
    },
    {
        "school": "TIGERT MIDDLE SCHOOL",
        "district": "SODA SPRINGS JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160300000527",
    },
    {
        "school": "CLARK COUNTY JR/SR HIGH SCHOOL",
        "district": "CLARK COUNTY DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160075000144",
    },
    {
        "school": "LINDY ROSS ELEMENTARY SCHOOL",
        "district": "CLARK COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160075000145",
    },
    {
        "school": "CAVENDISH-TEAKEAN ELEMENTARY SCHOOL",
        "district": "OROFINO JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160252000436",
    },
    {
        "school": "OROFINO ELEMENTARY SCHOOL",
        "district": "OROFINO JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160252000439",
    },
    {
        "school": "OROFINO HIGH SCHOOL",
        "district": "OROFINO JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160252000440",
    },
    {
        "school": "TIMBERLINE HIGH SCHOOL",
        "district": "OROFINO JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160252000445",
    },
    {
        "school": "CHALLIS ELEMENTARY SCHOOL",
        "district": "CHALLIS JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160072000139",
    },
    {
        "school": "CHALLIS JR/SR HIGH SCHOOL",
        "district": "CHALLIS JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160072000140",
    },
    {
        "school": "CLAYTON ELEMENTARY SCHOOL",
        "district": "CHALLIS JOINT DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160072000141",
    },
    {
        "school": "STANLEY ELEM/JR HIGH SCHOOL",
        "district": "CHALLIS JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160072000143",
    },
    {
        "school": "MACKAY ELEMENTARY SCHOOL",
        "district": "MACKAY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160190000331",
    },
    {
        "school": "MACKAY JR/SR HIGH SCHOOL",
        "district": "MACKAY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160190000332",
    },
    {
        "school": "THATCHER ELEMENTARY SCHOOL",
        "district": "GRACE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160129000228",
    },
    {
        "school": "BLISS SCHOOL",
        "district": "BLISS JOINT DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160033000040",
    },
    {
        "school": "GOODING MIDDLE SCHOOL",
        "district": "GOODING JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160126000222",
    },
    {
        "school": "GOODING ELEMENTARY SCHOOL",
        "district": "GOODING JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160126000223",
    },
    {
        "school": "GOODING HIGH SCHOOL",
        "district": "GOODING JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160126000224",
    },
    {
        "school": "WENDELL HIGH SCHOOL",
        "district": "WENDELL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160336000271",
    },
    {
        "school": "WENDELL ELEMENTARY SCHOOL",
        "district": "WENDELL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160336000570",
    },
    {
        "school": "WENDELL MIDDLE SCHOOL",
        "district": "WENDELL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160336000571",
    },
    {
        "school": "IDAHO SCHOOL FOR THE DEAF AND THE BLIND",
        "district": "IDAHO BUREAU OF EDUCATIONAL SERVICES FOR THE DEAF AND THE BL",
        "level": "Other",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160351100685",
    },
    {
        "school": "PRAIRIE ELEMENTARY SCHOOL",
        "district": "COTTONWOOD JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160081000160",
    },
    {
        "school": "PRAIRIE JR/SR HIGH SCHOOL",
        "district": "COTTONWOOD JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160081000161",
    },
    {
        "school": "LAKESIDE ELEMENTARY SCHOOL",
        "district": "PLUMMER-WORLEY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160081500719",
    },
    {
        "school": "CANYON ELEMENTARY SCHOOL",
        "district": "KELLOGG JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160165000290",
    },
    {
        "school": "PATTERSON ELEMENTARY SCHOOL",
        "district": "CHALLIS JOINT DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160072000142",
    },
    {
        "school": "SALMON PIONEER PRIMARY SCHOOL",
        "district": "SALMON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160285000503",
    },
    {
        "school": "SALMON JR/SR HIGH SCHOOL",
        "district": "SALMON DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160285000504",
    },
    {
        "school": "SALMON ALTERNATIVE HIGH SCHOOL",
        "district": "SALMON DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160285000700",
    },
    {
        "school": "SALMON JUVENILE DETENTION CENTER",
        "district": "SALMON DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160285000750",
    },
    {
        "school": "LEADORE SCHOOL",
        "district": "SOUTH LEMHI DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160303000528",
    },
    {
        "school": "TENDOY ELEMENTARY SCHOOL",
        "district": "SOUTH LEMHI DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160303000529",
    },
    {
        "school": "KAMIAH ELEMENTARY SCHOOL",
        "district": "KAMIAH JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160162000286",
    },
    {
        "school": "KAMIAH HIGH SCHOOL",
        "district": "KAMIAH JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160162000457",
    },
    {
        "school": "DIETRICH SCHOOL",
        "district": "DIETRICH DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160090000165",
    },
    {
        "school": "RICHFIELD SCHOOL",
        "district": "RICHFIELD DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160276000497",
    },
    {
        "school": "SHOSHONE ELEMENTARY SCHOOL",
        "district": "SHOSHONE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160294000512",
    },
    {
        "school": "PECK ELEMENTARY SCHOOL",
        "district": "OROFINO JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160252000442",
    },
    {
        "school": "MALAD ELEMENTARY SCHOOL",
        "district": "ONEIDA COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160249000432",
    },
    {
        "school": "MALAD SENIOR HIGH SCHOOL",
        "district": "ONEIDA COUNTY DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160249000433",
    },
    {
        "school": "STONE ELEMENTARY SCHOOL",
        "district": "ONEIDA COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160249000434",
    },
    {
        "school": "MALAD MIDDLE SCHOOL",
        "district": "ONEIDA COUNTY DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160249000629",
    },
    {
        "school": "KELLOGG MIDDLE SCHOOL",
        "district": "KELLOGG JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160165000292",
    },
    {
        "school": "KELLOGG HIGH SCHOOL",
        "district": "KELLOGG JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160165000293",
    },
    {
        "school": "PINEHURST ELEMENTARY SCHOOL",
        "district": "KELLOGG JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160165000294",
    },
    {
        "school": "MULLAN SCHOOLS",
        "district": "MULLAN DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160228000405",
    },
    {
        "school": "SILVER HILLS ELEMENTARY SCHOOL",
        "district": "WALLACE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160330000562",
    },
    {
        "school": "WALLACE JR/SR HIGH SCHOOL",
        "district": "WALLACE DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160330000565",
    },
    {
        "school": "CASCADE ELEMENTARY SCHOOL",
        "district": "CASCADE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160063000120",
    },
    {
        "school": "CASCADE JR/SR HIGH SCHOOL",
        "district": "CASCADE DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160063000121",
    },
    {
        "school": "MCCALL-DONNELLY HIGH SCHOOL",
        "district": "MCCALL-DONNELLY JOINT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160203000354",
    },
    {
        "school": "BARBARA R MORGAN ELEMENTARY",
        "district": "MCCALL-DONNELLY JOINT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160203000356",
    },
    {
        "school": "DONNELLY ELEMENTARY",
        "district": "MCCALL-DONNELLY JOINT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160203000583",
    },
    {
        "school": "PAYETTE LAKES MIDDLE SCHOOL",
        "district": "MCCALL-DONNELLY JOINT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160203000584",
    },
    {
        "school": "HEARTLAND HIGH SCHOOL",
        "district": "MCCALL-DONNELLY JOINT SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160203000740",
    },
    {
        "school": "CAMBRIDGE ELEMENTARY SCHOOL",
        "district": "CAMBRIDGE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160057000112",
    },
    {
        "school": "CAMBRIDGE MIDDLE/HIGH SCHOOL",
        "district": "CAMBRIDGE JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160057000113",
    },
    {
        "school": "PARK INTERMEDIATE SCHOOL",
        "district": "WEISER DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160333000566",
    },
    {
        "school": "PIONEER PRIMARY SCHOOL",
        "district": "WEISER DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160333000567",
    },
    {
        "school": "WEISER HIGH SCHOOL",
        "district": "WEISER DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160333000568",
    },
    {
        "school": "WEISER MIDDLE SCHOOL",
        "district": "WEISER DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160333000569",
    },
    {
        "school": "ABERDEEN ELEMENTARY SCHOOL",
        "district": "ABERDEEN DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160003000828",
    },
    {
        "school": "ABERDEEN MIDDLE SCHOOL",
        "district": "ABERDEEN DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160003000829",
    },
    {
        "school": "ABERDEEN HIGH SCHOOL",
        "district": "ABERDEEN DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160003000002",
    },
    {
        "school": "BLACKFOOT HIGH SCHOOL",
        "district": "BLACKFOOT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160027000022",
    },
    {
        "school": "MOUNTAIN VIEW MIDDLE SCHOOL",
        "district": "BLACKFOOT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160027000023",
    },
    {
        "school": "RIDGE CREST ELEMENTARY SCHOOL",
        "district": "BLACKFOOT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160027000025",
    },
    {
        "school": "FORT HALL ELEMENTARY SCHOOL",
        "district": "BLACKFOOT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160027000026",
    },
    {
        "school": "GROVELAND ELEMENTARY SCHOOL",
        "district": "BLACKFOOT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160027000027",
    },
    {
        "school": "I T STODDARD ELEMENTARY SCHOOL",
        "district": "BLACKFOOT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160027000028",
    },
    {
        "school": "BLACKFOOT HERITAGE SIXTH GRADE",
        "district": "BLACKFOOT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160027000030",
    },
    {
        "school": "DONALD D STALKER ELEMENTARY",
        "district": "BLACKFOOT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160027000031",
    },
    {
        "school": "WAPELLO ELEMENTARY SCHOOL",
        "district": "BLACKFOOT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160027000032",
    },
    {
        "school": "VAUGHN HUGIE FAMILY ED CENTER",
        "district": "BLACKFOOT DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160027000492",
    },
    {
        "school": "INDEPENDENCE ALTERNATIVE HIGH SCHOOL",
        "district": "BLACKFOOT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160027000689",
    },
    {
        "school": "A W JOHNSON ELEMENTARY SCHOOL",
        "district": "FIRTH DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160108000196",
    },
    {
        "school": "FIRTH HIGH SCHOOL",
        "district": "FIRTH DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160108000198",
    },
    {
        "school": "FIRTH MIDDLE SCHOOL",
        "district": "FIRTH DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160108000326",
    },
    {
        "school": "SUNRISE ELEMENTARY SCHOOL",
        "district": "SHELLEY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160291000508",
    },
    {
        "school": "SHELLEY SENIOR HIGH SCHOOL",
        "district": "SHELLEY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160291000510",
    },
    {
        "school": "HAZEL STUART ELEMENTARY SCHOOL",
        "district": "SHELLEY JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160291000511",
    },
    {
        "school": "DONALD J HOBBS MIDDLE SCHOOL",
        "district": "SHELLEY JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160291000723",
    },
    {
        "school": "MORELAND ELEMENTARY SCHOOL",
        "district": "SNAKE RIVER DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160297000516",
    },
    {
        "school": "RIVERSIDE ELEMENTARY SCHOOL",
        "district": "SNAKE RIVER DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160297000518",
    },
    {
        "school": "ROCKFORD ELEMENTARY SCHOOL",
        "district": "SNAKE RIVER DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160297000519",
    },
    {
        "school": "SNAKE RIVER JR HIGH SCHOOL",
        "district": "SNAKE RIVER DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160297000520",
    },
    {
        "school": "SNAKE RIVER HIGH SCHOOL",
        "district": "SNAKE RIVER DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160297000521",
    },
    {
        "school": "SNAKE RIVER MIDDLE SCHOOL",
        "district": "SNAKE RIVER DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160297000644",
    },
    {
        "school": "ROLLING HILLS PUBLIC CHARTER",
        "district": "ROLLING HILLS PUBLIC CHARTER SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000600863",
    },
    {
        "school": "COMPASS PUBLIC CHARTER SCHOOL",
        "district": "COMPASS PUBLIC CHARTER SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000700864",
    },
    {
        "school": "FALCON RIDGE PUBLIC CHARTER",
        "district": "FALCON RIDGE PUBLIC CHARTER SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000800865",
    },
    {
        "school": "INSPIRE VIRTUAL CHARTER SCHOOL",
        "district": "INSPIRE ACADEMICS INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160001100866",
    },
    {
        "school": "DEHRYL A DENNIS PROF-TECH CENTER",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160036000817",
    },
    {
        "school": "TREASURE VALLEY MATH/SCIENCE",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000823",
    },
    {
        "school": "FREMONT H TEED MIDDLE SCHOOL",
        "district": "KUNA JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160177000805",
    },
    {
        "school": "DISCOVERY ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000801",
    },
    {
        "school": "MOUNTAIN VIEW HIGH SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000802",
    },
    {
        "school": "MERIDIAN MEDICAL ARTS CHARTER",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160210000804",
    },
    {
        "school": "PEPPER RIDGE ELEMENTARY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000818",
    },
    {
        "school": "SAWTOOTH MIDDLE SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000819",
    },
    {
        "school": "HUNTER ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000824",
    },
    {
        "school": "CENTRAL ACADEMY HIGH SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160210000903",
    },
    {
        "school": "GARDEN VALLEY SCHOOL",
        "district": "GARDEN VALLEY DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160117000830",
    },
    {
        "school": "HORSESHOE BEND MIDDLE/SR HIGH",
        "district": "HORSESHOE BEND SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160150000831",
    },
    {
        "school": "IDAHO VIRTUAL ACADEMY",
        "district": "IDAHO VIRTUAL ACADEMY INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000400859",
    },
    {
        "school": "VICTORY CHARTER SCHOOL",
        "district": "VICTORY CHARTER SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000300858",
    },
    {
        "school": "LIBERTY CHARTER SCHOOL",
        "district": "LIBERTY CHARTER SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160001200867",
    },
    {
        "school": "LEWIS AND CLARK ELEMENTARY",
        "district": "CALDWELL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160051000835",
    },
    {
        "school": "SAGE VALLEY MIDDLE SCHOOL",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060000838",
    },
    {
        "school": "THOMAS JEFFERSON CHARTER",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060000839",
    },
    {
        "school": "MELBA HIGH SCHOOL",
        "district": "MELBA JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160207000836",
    },
    {
        "school": "PURPLE SAGE ELEMENTARY",
        "district": "MIDDLETON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160213000812",
    },
    {
        "school": "EAST VALLEY MIDDLE SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000811",
    },
    {
        "school": "WILLOW CREEK ELEMENTARY",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000833",
    },
    {
        "school": "IDAHO ARTS CHARTER SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000834",
    },
    {
        "school": "BASIN ELEMENTARY SCHOOL",
        "district": "BASIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160018000334",
    },
    {
        "school": "IDAHO CITY HIGH SCHOOL",
        "district": "BASIN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160018000350",
    },
    {
        "school": "LOWMAN ELEMENTARY SCHOOL",
        "district": "GARDEN VALLEY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160117000216",
    },
    {
        "school": "HORSESHOE BEND ELEMENTARY",
        "district": "HORSESHOE BEND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160150000506",
    },
    {
        "school": "BLACK CANYON HIGH SCHOOL",
        "district": "EMMETT INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160102000095",
    },
    {
        "school": "EMMETT HIGH SCHOOL",
        "district": "EMMETT INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160102000187",
    },
    {
        "school": "OLA ELEMENTARY SCHOOL",
        "district": "EMMETT INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160102000190",
    },
    {
        "school": "EMMETT MIDDLE SCHOOL",
        "district": "EMMETT INDEPENDENT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160102000191",
    },
    {
        "school": "SWEET MONTOUR ELEMENTARY SCHOOL",
        "district": "EMMETT INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160102000192",
    },
    {
        "school": "KENNETH J CARBERRY ELEMENTARY",
        "district": "EMMETT INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160102000797",
    },
    {
        "school": "SHADOW BUTTE ELEMENTARY SCHOOL",
        "district": "EMMETT INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160102000798",
    },
    {
        "school": "BRUNEAU ELEMENTARY SCHOOL",
        "district": "BRUNEAU-GRAND VIEW JOINT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160045000098",
    },
    {
        "school": "GRAND VIEW ELEMENTARY SCHOOL",
        "district": "BRUNEAU-GRAND VIEW JOINT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160045000099",
    },
    {
        "school": "RIMROCK JR/SR HIGH SCHOOL",
        "district": "BRUNEAU-GRAND VIEW JOINT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160045000100",
    },
    {
        "school": "PLEASANT VALLEY ELEM/JR HIGH",
        "district": "PLEASANT VALLEY ELEMENTARY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160261000459",
    },
    {
        "school": "RIVERSIDE ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000004",
    },
    {
        "school": "HORIZON ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000009",
    },
    {
        "school": "ADAMS ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000042",
    },
    {
        "school": "BOISE SENIOR HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000044",
    },
    {
        "school": "BORAH SENIOR HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000045",
    },
    {
        "school": "CAPITAL SENIOR HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000047",
    },
    {
        "school": "COLLISTER ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000049",
    },
    {
        "school": "FAIRMONT JUNIOR HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000051",
    },
    {
        "school": "GARFIELD ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000053",
    },
    {
        "school": "HAWTHORNE ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000054",
    },
    {
        "school": "HIGHLANDS ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000055",
    },
    {
        "school": "HILLCREST ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000056",
    },
    {
        "school": "HILLSIDE JUNIOR HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000057",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000059",
    },
    {
        "school": "KOELSCH ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000060",
    },
    {
        "school": "LONGFELLOW ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000062",
    },
    {
        "school": "LOWELL ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000063",
    },
    {
        "school": "MADISON EARLY CHILDHOOD SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160036000064",
    },
    {
        "school": "MAPLE GROVE ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000065",
    },
    {
        "school": "MONROE ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000067",
    },
    {
        "school": "MOUNTAIN VIEW ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000068",
    },
    {
        "school": "NORTH JUNIOR HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000069",
    },
    {
        "school": "OWYHEE ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000070",
    },
    {
        "school": "PIERCE PARK ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000071",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000072",
    },
    {
        "school": "SOUTH JUNIOR HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000073",
    },
    {
        "school": "TAFT ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000074",
    },
    {
        "school": "VALLEY VIEW ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000075",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000076",
    },
    {
        "school": "WHITNEY ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000078",
    },
    {
        "school": "WHITTIER ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000079",
    },
    {
        "school": "LES BOIS JUNIOR HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000183",
    },
    {
        "school": "TRAIL WIND ELEMENTARY",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000590",
    },
    {
        "school": "SHADOW HILLS ELEMENTARY",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000591",
    },
    {
        "school": "AMITY ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000592",
    },
    {
        "school": "RIVERGLEN JR HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000632",
    },
    {
        "school": "TIMBERLINE HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000643",
    },
    {
        "school": "LIBERTY ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000650",
    },
    {
        "school": "WHITE PINE ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000706",
    },
    {
        "school": "CYNTHIA MANN ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000707",
    },
    {
        "school": "ADA COUNTY JUVENILE CENTER",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160036000708",
    },
    {
        "school": "ANSER CHARTER SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000758",
    },
    {
        "school": "KUNA MIDDLE SCHOOL",
        "district": "KUNA JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160177000306",
    },
    {
        "school": "KUNA HIGH SCHOOL",
        "district": "KUNA JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160177000307",
    },
    {
        "school": "HUBBARD ELEMENTARY SCHOOL",
        "district": "KUNA JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160177000596",
    },
    {
        "school": "PIONEER SCHOOL OF THE ARTS",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000010",
    },
    {
        "school": "EAGLE HIGH SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000318",
    },
    {
        "school": "EAGLE MIDDLE SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000319",
    },
    {
        "school": "EAGLE ELEMENTARY SCHOOL OF THE ARTS",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000362",
    },
    {
        "school": "McMillan Elementary",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000363",
    },
    {
        "school": "SUMMERWIND SCHOOL OF MATH AND SCIENCE",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000364",
    },
    {
        "school": "LAKE HAZEL ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000365",
    },
    {
        "school": "CHRISTINE DONNELL SCHOOL OF THE ARTS",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000366",
    },
    {
        "school": "LOWELL SCOTT MIDDLE SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000367",
    },
    {
        "school": "MARY MCPHERSON ELEMENTARY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000368",
    },
    {
        "school": "MERIDIAN MIDDLE SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000370",
    },
    {
        "school": "MERIDIAN ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000371",
    },
    {
        "school": "MERIDIAN HIGH SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000372",
    },
    {
        "school": "STAR ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000373",
    },
    {
        "school": "USTICK ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000374",
    },
    {
        "school": "EAGLE ACADEMY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160210000466",
    },
    {
        "school": "CECIL D ANDRUS ELEMENTARY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000593",
    },
    {
        "school": "ELIZA HART SPALDING STEM ACADEMY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000595",
    },
    {
        "school": "CHAPARRAL ELEMENTARY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000597",
    },
    {
        "school": "JOPLIN ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000598",
    },
    {
        "school": "SEVEN OAKS ELEMENTARY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000601",
    },
    {
        "school": "CROSSROADS MIDDLE SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160210000602",
    },
    {
        "school": "EAGLE HILLS ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000624",
    },
    {
        "school": "FRONTIER ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000637",
    },
    {
        "school": "LAKE HAZEL MIDDLE SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000638",
    },
    {
        "school": "BARBARA MORGAN STEM ACADEMY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000639",
    },
    {
        "school": "SILVER SAGE ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000640",
    },
    {
        "school": "CENTENNIAL HIGH SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000674",
    },
    {
        "school": "MERIDIAN ACADEMY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160210000714",
    },
    {
        "school": "CHIEF JOSEPH SCHOOL OF THE ARTS",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000717",
    },
    {
        "school": "MERIDIAN TECHNICAL CHARTER HIGH SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160210000759",
    },
    {
        "school": "PONDEROSA ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000770",
    },
    {
        "school": "ADA PROFESSIONAL-TECHNICAL CENTER",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160210000789",
    },
    {
        "school": "RIVER VALLEY ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000793",
    },
    {
        "school": "PEREGRINE ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000794",
    },
    {
        "school": "LEWIS & CLARK MIDDLE SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000795",
    },
    {
        "school": "CANYON SPRINGS HIGH SCHOOL",
        "district": "CALDWELL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160051000041",
    },
    {
        "school": "SOUTHWEST IDAHO JUVENILE DETENTION",
        "district": "CALDWELL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160051000043",
    },
    {
        "school": "CALDWELL SENIOR HIGH SCHOOL",
        "district": "CALDWELL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160051000104",
    },
    {
        "school": "JEFFERSON MIDDLE SCHOOL",
        "district": "CALDWELL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160051000105",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "CALDWELL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160051000106",
    },
    {
        "school": "VAN BUREN ELEMENTARY SCHOOL",
        "district": "CALDWELL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160051000107",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "CALDWELL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160051000108",
    },
    {
        "school": "SYRINGA MIDDLE SCHOOL",
        "district": "CALDWELL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160051000109",
    },
    {
        "school": "WILSON ELEMENTARY SCHOOL",
        "district": "CALDWELL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160051000609",
    },
    {
        "school": "SACAJAWEA ELEMENTARY SCHOOL",
        "district": "CALDWELL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160051000731",
    },
    {
        "school": "CENTRAL CANYON ELEMENTARY SCHOOL",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060000083",
    },
    {
        "school": "EAST CANYON ELEMENTARY SCHOOL",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060000115",
    },
    {
        "school": "VALLIVUE HIGH SCHOOL",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060000118",
    },
    {
        "school": "WEST CANYON ELEMENTARY SCHOOL",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060000119",
    },
    {
        "school": "VALLIVUE MIDDLE SCHOOL",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060000539",
    },
    {
        "school": "BIRCH ELEMENTARY SCHOOL",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060000778",
    },
    {
        "school": "MELBA ELEMENTARY SCHOOL",
        "district": "MELBA JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160207000359",
    },
    {
        "school": "MIDDLETON MILL CREEK ELEMENTARY",
        "district": "MIDDLETON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160213000376",
    },
    {
        "school": "MIDDLETON HIGH SCHOOL",
        "district": "MIDDLETON DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160213000377",
    },
    {
        "school": "MIDDLETON MIDDLE SCHOOL",
        "district": "MIDDLETON DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160213000378",
    },
    {
        "school": "MIDDLETON HEIGHTS ELEMENTARY",
        "district": "MIDDLETON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160213000675",
    },
    {
        "school": "MIDDLETON ACADEMY",
        "district": "MIDDLETON DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160213000777",
    },
    {
        "school": "IOWA ELEMENTARY",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000375",
    },
    {
        "school": "SHERMAN ELEMENTARY",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000379",
    },
    {
        "school": "PARK RIDGE ELEMENTARY",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000383",
    },
    {
        "school": "CENTENNIAL ELEMENTARY SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000409",
    },
    {
        "school": "CENTRAL ELEMENTARY",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000410",
    },
    {
        "school": "NAMPA EARLY CHILDHOOD CENTER",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160234000416",
    },
    {
        "school": "SOUTH MIDDLE SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000419",
    },
    {
        "school": "WEST MIDDLE SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000422",
    },
    {
        "school": "SNAKE RIVER ELEMENTARY",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000507",
    },
    {
        "school": "NAMPA SENIOR HIGH SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000514",
    },
    {
        "school": "SKYVIEW HIGH SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000515",
    },
    {
        "school": "GREENHURST ELEMENTARY SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000677",
    },
    {
        "school": "UNION HIGH SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160234000762",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000773",
    },
    {
        "school": "OWYHEE ELEMENTARY SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000774",
    },
    {
        "school": "REAGAN ELEMENTARY SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000775",
    },
    {
        "school": "NOTUS ELEMENTARY SCHOOL",
        "district": "NOTUS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160246000430",
    },
    {
        "school": "NOTUS JR/SR HIGH SCHOOL",
        "district": "NOTUS DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160246000431",
    },
    {
        "school": "PARMA MIDDLE SCHOOL",
        "district": "PARMA DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160255000080",
    },
    {
        "school": "MAXINE JOHNSON ELEMENTARY",
        "district": "PARMA DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160255000449",
    },
    {
        "school": "PARMA HIGH SCHOOL",
        "district": "PARMA DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160255000451",
    },
    {
        "school": "WILDER HIGH SCHOOL",
        "district": "WILDER DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160348000530",
    },
    {
        "school": "WILDER ELEMENTARY SCHOOL",
        "district": "WILDER DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160348000585",
    },
    {
        "school": "HOMEDALE HIGH SCHOOL",
        "district": "HOMEDALE JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160147000248",
    },
    {
        "school": "HOMEDALE ELEMENTARY SCHOOL",
        "district": "HOMEDALE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160147000250",
    },
    {
        "school": "HOMEDALE MIDDLE SCHOOL",
        "district": "HOMEDALE JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160147000767",
    },
    {
        "school": "MARSING ELEMENTARY SCHOOL",
        "district": "MARSING JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160198000351",
    },
    {
        "school": "MARSING HIGH SCHOOL",
        "district": "MARSING JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160198000352",
    },
    {
        "school": "MARSING MIDDLE SCHOOL",
        "district": "MARSING JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160198000636",
    },
    {
        "school": "ALBION ELEMENTARY SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000122",
    },
    {
        "school": "ALMO ELEMENTARY SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000123",
    },
    {
        "school": "BURLEY SENIOR HIGH SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000124",
    },
    {
        "school": "BURLEY JUNIOR HIGH SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000125",
    },
    {
        "school": "DECLO ELEMENTARY SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000126",
    },
    {
        "school": "DECLO SENIOR HIGH SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000127",
    },
    {
        "school": "DWORSHAK ELEMENTARY SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000128",
    },
    {
        "school": "RAFT RIVER ELEMENTARY SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000129",
    },
    {
        "school": "MOUNTAIN VIEW ELEMENTARY",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000130",
    },
    {
        "school": "OAKLEY ELEMENTARY SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000131",
    },
    {
        "school": "OAKLEY JR/SR HIGH SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000132",
    },
    {
        "school": "RAFT RIVER JR/SR HIGH SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000134",
    },
    {
        "school": "WHITE PINE ELEMENTARY",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000387",
    },
    {
        "school": "CASSIA JR/SR HIGH SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160066000540",
    },
    {
        "school": "DECLO JR HIGH SCHOOL",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066000610",
    },
    {
        "school": "PRESCHOOL CENTER",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Not reported",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160066000743",
    },
    {
        "school": "CASSIA REGIONAL TECHNICAL CENTER",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160066000782",
    },
    {
        "school": "MT HARRISON JR/SR HIGH",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160219000158",
    },
    {
        "school": "MINI-CASSIA JUVENILE DETENTION CENTER",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160219000166",
    },
    {
        "school": "ACEQUIA ELEMENTARY SCHOOL",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160219000380",
    },
    {
        "school": "EAST MINICO MIDDLE SCHOOL",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160219000381",
    },
    {
        "school": "HEYBURN ELEMENTARY SCHOOL",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160219000382",
    },
    {
        "school": "MINICO SENIOR HIGH SCHOOL",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160219000385",
    },
    {
        "school": "WEST MINICO MIDDLE SCHOOL",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160219000389",
    },
    {
        "school": "PAUL ELEMENTARY SCHOOL",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160219000641",
    },
    {
        "school": "RUPERT ELEMENTARY SCHOOL",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160219000666",
    },
    {
        "school": "TIMBERLAKE JUNIOR HIGH SCHOOL",
        "district": "LAKELAND DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160180000842",
    },
    {
        "school": "TIMBERLAKE SENIOR HIGH SCHOOL",
        "district": "LAKELAND DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160180000843",
    },
    {
        "school": "RIVER CITY MIDDLE SCHOOL",
        "district": "POST FALLS DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160267000844",
    },
    {
        "school": "HAYDEN MEADOWS ELEMENTARY SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000114",
    },
    {
        "school": "BORAH ELEMENTARY SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000146",
    },
    {
        "school": "BRYAN ELEMENTARY SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000147",
    },
    {
        "school": "CANFIELD MIDDLE SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000148",
    },
    {
        "school": "COEUR D'ALENE HIGH SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000149",
    },
    {
        "school": "DALTON ELEMENTARY SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000150",
    },
    {
        "school": "ATLAS ELEMENTARY SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000152",
    },
    {
        "school": "LAKES MAGNET SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000153",
    },
    {
        "school": "RAMSEY MAGNET SCHOOL OF SCIENCE",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000155",
    },
    {
        "school": "SORENSEN MAGNET SCHOOL OF THE ARTS AND HUMANITIES",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000156",
    },
    {
        "school": "WINTON ELEMENTARY SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000157",
    },
    {
        "school": "FERNAN STEM ACADEMY",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000208",
    },
    {
        "school": "LAKE CITY HIGH SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000291",
    },
    {
        "school": "VENTURE HIGH SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160078000694",
    },
    {
        "school": "CDA JUVENILE DETENTION CENTER",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160078000704",
    },
    {
        "school": "WOODLAND MIDDLE SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000747",
    },
    {
        "school": "SKYWAY ELEMENTARY SCHOOL",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078000799",
    },
    {
        "school": "HARRISON ELEMENTARY SCHOOL",
        "district": "KOOTENAI DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160174000302",
    },
    {
        "school": "KOOTENAI JR/SR HIGH SCHOOL",
        "district": "KOOTENAI DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160174000303",
    },
    {
        "school": "BETTY KIEFER ELEMENTARY SCHOOL",
        "district": "LAKELAND DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160180000295",
    },
    {
        "school": "ATHOL ELEMENTARY SCHOOL",
        "district": "LAKELAND DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160180000309",
    },
    {
        "school": "JOHN BROWN ELEMENTARY SCHOOL",
        "district": "LAKELAND DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160180000310",
    },
    {
        "school": "LAKELAND SENIOR HIGH SCHOOL",
        "district": "LAKELAND DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160180000311",
    },
    {
        "school": "LAKELAND JUNIOR HIGH SCHOOL",
        "district": "LAKELAND DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160180000312",
    },
    {
        "school": "SPIRIT LAKE ELEMENTARY SCHOOL",
        "district": "LAKELAND DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160180000313",
    },
    {
        "school": "MOUNTAINVIEW ALTERNATIVE HIGH SCHOOL",
        "district": "LAKELAND DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160180000437",
    },
    {
        "school": "GARWOOD ELEMENTARY SCHOOL",
        "district": "LAKELAND DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160180000734",
    },
    {
        "school": "PRAIRIE VIEW ELEMENTARY",
        "district": "POST FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160267000209",
    },
    {
        "school": "FREDERICK POST KINDER CENTER",
        "district": "POST FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160267000448",
    },
    {
        "school": "PONDEROSA ELEMENTARY SCHOOL",
        "district": "POST FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160267000487",
    },
    {
        "school": "POST FALLS HIGH SCHOOL",
        "district": "POST FALLS DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160267000488",
    },
    {
        "school": "POST FALLS MIDDLE SCHOOL",
        "district": "POST FALLS DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160267000489",
    },
    {
        "school": "SELTICE ELEMENTARY SCHOOL",
        "district": "POST FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160267000490",
    },
    {
        "school": "NEW VISION HIGH SCHOOL",
        "district": "POST FALLS DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160267000705",
    },
    {
        "school": "MULLAN TRAIL ELEMENTARY SCHOOL",
        "district": "POST FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160267000800",
    },
    {
        "school": "HILLCREST HIGH SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000024",
    },
    {
        "school": "AMMON ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000167",
    },
    {
        "school": "ROCKY MOUNTAIN MIDDLE SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000168",
    },
    {
        "school": "BONNEVILLE HIGH SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000169",
    },
    {
        "school": "FAIRVIEW ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000172",
    },
    {
        "school": "FALLS VALLEY ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000173",
    },
    {
        "school": "HILLVIEW ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000175",
    },
    {
        "school": "IONA ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000176",
    },
    {
        "school": "UCON ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000178",
    },
    {
        "school": "LINCOLN HIGH SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160093000361",
    },
    {
        "school": "CLOVERDALE ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000630",
    },
    {
        "school": "SANDCREEK MIDDLE SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000651",
    },
    {
        "school": "SPECIAL SERVICES CENTER",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160093000663",
    },
    {
        "school": "TIEBREAKER ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000670",
    },
    {
        "school": "A H BUSH ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000252",
    },
    {
        "school": "DORA ERICKSON ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000256",
    },
    {
        "school": "EAGLE ROCK MIDDLE SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000257",
    },
    {
        "school": "EDGEMONT GARDENS ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000258",
    },
    {
        "school": "ETHEL BOYES ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000260",
    },
    {
        "school": "HAWTHORNE ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000261",
    },
    {
        "school": "IDAHO FALLS SENIOR HIGH SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000262",
    },
    {
        "school": "LINDEN PARK ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000263",
    },
    {
        "school": "LONGFELLOW ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000264",
    },
    {
        "school": "SKYLINE SENIOR HIGH SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000268",
    },
    {
        "school": "TEMPLE VIEW ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000269",
    },
    {
        "school": "THERESA BUNKER ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000270",
    },
    {
        "school": "3B JUVENILE DETENTION CENTER",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160153000605",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000633",
    },
    {
        "school": "EMERSON HIGH SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160153000697",
    },
    {
        "school": "SUNNYSIDE ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000725",
    },
    {
        "school": "FOX HOLLOW ELEMENTARY SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000726",
    },
    {
        "school": "TAYLORVIEW MIDDLE SCHOOL",
        "district": "IDAHO FALLS DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153000727",
    },
    {
        "school": "CAREER & TECHNICAL EDUCATION CENTER",
        "district": "IDAHO FALLS DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160153000784",
    },
    {
        "school": "SWAN VALLEY ELEMENTARY SCHOOL",
        "district": "SWAN VALLEY ELEMENTARY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160312000541",
    },
    {
        "school": "MIDWAY ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160157000274",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160157000276",
    },
    {
        "school": "RIGBY HIGH SCHOOL",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160157000277",
    },
    {
        "school": "ROBERTS ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160157000278",
    },
    {
        "school": "JEFFERSON HIGH SCHOOL",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160157000626",
    },
    {
        "school": "HARWOOD ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160157000634",
    },
    {
        "school": "RIRIE JR/SR HIGH SCHOOL",
        "district": "RIRIE JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160279000429",
    },
    {
        "school": "RIRIE ELEMENTARY SCHOOL",
        "district": "RIRIE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160279000435",
    },
    {
        "school": "HAMER ELEMENTARY SCHOOL",
        "district": "WEST JEFFERSON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160340000273",
    },
    {
        "school": "TERRETON ELEMENTARY SCHOOL",
        "district": "WEST JEFFERSON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160340000280",
    },
    {
        "school": "WEST JEFFERSON HIGH SCHOOL",
        "district": "WEST JEFFERSON DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160340000281",
    },
    {
        "school": "BASIN ALTERNATIVE HIGH SCHOOL",
        "district": "TETON COUNTY DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160318000884",
    },
    {
        "school": "TETON HIGH SCHOOL",
        "district": "TETON COUNTY DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160318000543",
    },
    {
        "school": "TETON MIDDLE SCHOOL",
        "district": "TETON COUNTY DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160318000544",
    },
    {
        "school": "TETONIA ELEMENTARY SCHOOL",
        "district": "TETON COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160318000545",
    },
    {
        "school": "VICTOR ELEMENTARY SCHOOL",
        "district": "TETON COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160318000547",
    },
    {
        "school": "DRIGGS ELEMENTARY SCHOOL",
        "district": "TETON COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160318000754",
    },
    {
        "school": "LAPWAI MIDDLE/HIGH SCHOOL",
        "district": "LAPWAI DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160183000854",
    },
    {
        "school": "CULDESAC SCHOOL",
        "district": "CULDESAC JOINT DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160087000164",
    },
    {
        "school": "LAPWAI ELEMENTARY SCHOOL",
        "district": "LAPWAI DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160183000317",
    },
    {
        "school": "REGION 2 JUVENILE DETENTION CENTER",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160186000170",
    },
    {
        "school": "CAMELOT ELEMENTARY SCHOOL",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160186000320",
    },
    {
        "school": "CENTENNIAL ELEMENTARY SCHOOL",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160186000321",
    },
    {
        "school": "JENIFER JUNIOR HIGH SCHOOL",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160186000322",
    },
    {
        "school": "LEWISTON HIGH SCHOOL",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160186000323",
    },
    {
        "school": "MCGHEE ELEMENTARY SCHOOL",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160186000324",
    },
    {
        "school": "MCSORLEY ELEMENTARY SCHOOL",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160186000325",
    },
    {
        "school": "ORCHARDS ELEMENTARY SCHOOL",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160186000327",
    },
    {
        "school": "SACAJAWEA JUNIOR HIGH SCHOOL",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160186000328",
    },
    {
        "school": "WEBSTER ELEMENTARY SCHOOL",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160186000329",
    },
    {
        "school": "WHITMAN ELEMENTARY SCHOOL",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160186000330",
    },
    {
        "school": "TAMMANY HIGH SCHOOL",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160186000711",
    },
    {
        "school": "OAKWOOD ELEMENTARY SCHOOL",
        "district": "PRESTON JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160096000181",
    },
    {
        "school": "PRESTON HIGH SCHOOL",
        "district": "PRESTON JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160096000182",
    },
    {
        "school": "PRESTON JR HIGH SCHOOL",
        "district": "PRESTON JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160096000612",
    },
    {
        "school": "PIONEER ELEMENTARY SCHOOL",
        "district": "PRESTON JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160096000709",
    },
    {
        "school": "FRANKLIN COUNTY HIGH SCHOOL",
        "district": "PRESTON JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160096000764",
    },
    {
        "school": "WEST SIDE SENIOR HIGH SCHOOL",
        "district": "WEST SIDE JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160342000388",
    },
    {
        "school": "BEUTLER MIDDLE SCHOOL",
        "district": "WEST SIDE JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160342000412",
    },
    {
        "school": "HAROLD B LEE ELEMENTARY SCHOOL",
        "district": "WEST SIDE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160342000563",
    },
    {
        "school": "GENESEE SCHOOL",
        "district": "GENESEE JOINT DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160120000845",
    },
    {
        "school": "TROY ELEMENTARY SCHOOL",
        "district": "TROY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000900581",
    },
    {
        "school": "TROY JR/SR HIGH SCHOOL",
        "district": "TROY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000900582",
    },
    {
        "school": "BOVILL ELEMENTARY SCHOOL",
        "district": "WHITEPINE JOINT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160001000578",
    },
    {
        "school": "DEARY SCHOOL",
        "district": "WHITEPINE JOINT SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160001000579",
    },
    {
        "school": "JULIAETTA ELEMENTARY SCHOOL",
        "district": "KENDRICK JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160168000298",
    },
    {
        "school": "KENDRICK JR/SR HIGH SCHOOL",
        "district": "KENDRICK JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160168000299",
    },
    {
        "school": "PARADISE CREEK REGIONAL HIGH SCHOOL",
        "district": "MOSCOW DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160222000154",
    },
    {
        "school": "A B MCDONALD ELEMENTARY SCHOOL",
        "district": "MOSCOW DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160222000390",
    },
    {
        "school": "J RUSSELL ELEMENTARY SCHOOL",
        "district": "MOSCOW DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160222000391",
    },
    {
        "school": "LENA WHITMORE ELEMENTARY SCHOOL",
        "district": "MOSCOW DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160222000392",
    },
    {
        "school": "MOSCOW MIDDLE SCHOOL",
        "district": "MOSCOW DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160222000393",
    },
    {
        "school": "MOSCOW HIGH SCHOOL",
        "district": "MOSCOW DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160222000394",
    },
    {
        "school": "WEST PARK ELEMENTARY SCHOOL",
        "district": "MOSCOW DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160222000395",
    },
    {
        "school": "MOSCOW CHARTER SCHOOL",
        "district": "MOSCOW DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160222000749",
    },
    {
        "school": "POTLATCH ELEMENTARY SCHOOL",
        "district": "POTLATCH DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160270000494",
    },
    {
        "school": "POTLATCH JR/SR HIGH SCHOOL",
        "district": "POTLATCH DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160270000495",
    },
    {
        "school": "RICHARD MCKENNA CHARTER SCHOOL - ONLINE",
        "district": "IDAHO VIRTUAL HIGH SCHOOL INC.",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000500862",
    },
    {
        "school": "GLENNS FERRY ELEMENTARY SCHOOL",
        "district": "GLENNS FERRY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160123000219",
    },
    {
        "school": "GLENNS FERRY HIGH SCHOOL",
        "district": "GLENNS FERRY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160123000220",
    },
    {
        "school": "GLENNS FERRY MIDDLE SCHOOL",
        "district": "GLENNS FERRY JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160123000744",
    },
    {
        "school": "PINE ELEM/JR HIGH SCHOOL",
        "district": "MOUNTAIN HOME DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160225000266",
    },
    {
        "school": "EAST ELEMENTARY SCHOOL",
        "district": "MOUNTAIN HOME DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160225000396",
    },
    {
        "school": "MOUNTAIN HOME SR HIGH SCHOOL",
        "district": "MOUNTAIN HOME DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160225000397",
    },
    {
        "school": "STEPHENSEN ELEMENTARY SCHOOL",
        "district": "MOUNTAIN HOME DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160225000400",
    },
    {
        "school": "MOUNTAIN HOME JUNIOR HIGH SCHOOL",
        "district": "MOUNTAIN HOME DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160225000401",
    },
    {
        "school": "NORTH ELEMENTARY SCHOOL",
        "district": "MOUNTAIN HOME DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160225000402",
    },
    {
        "school": "WEST ELEMENTARY SCHOOL",
        "district": "MOUNTAIN HOME DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160225000403",
    },
    {
        "school": "HACKER MIDDLE SCHOOL",
        "district": "MOUNTAIN HOME DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160225000745",
    },
    {
        "school": "PRAIRIE ELEM/JR HIGH SCHOOL",
        "district": "PRAIRIE ELEMENTARY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160273000496",
    },
    {
        "school": "FRUITLAND ELEMENTARY SCHOOL",
        "district": "FRUITLAND DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160114000211",
    },
    {
        "school": "FRUITLAND HIGH SCHOOL",
        "district": "FRUITLAND DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160114000212",
    },
    {
        "school": "FRUITLAND MIDDLE SCHOOL",
        "district": "FRUITLAND DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160114000213",
    },
    {
        "school": "NEW PLYMOUTH ELEMENTARY",
        "district": "NEW PLYMOUTH DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160237000423",
    },
    {
        "school": "NEW PLYMOUTH MIDDLE SCHOOL",
        "district": "NEW PLYMOUTH DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160237000580",
    },
    {
        "school": "NEW PLYMOUTH HIGH SCHOOL",
        "district": "NEW PLYMOUTH DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160237000736",
    },
    {
        "school": "PAYETTE PRIMARY SCHOOL",
        "district": "PAYETTE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160258000171",
    },
    {
        "school": "PAYETTE HIGH SCHOOL",
        "district": "PAYETTE JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160258000454",
    },
    {
        "school": "MCCAIN MIDDLE SCHOOL",
        "district": "PAYETTE JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160258000455",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "PAYETTE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160258000456",
    },
    {
        "school": "PAYETTE ALTERNATIVE HIGH SCHOOL",
        "district": "PAYETTE JOINT DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160258000699",
    },
    {
        "school": "J.R. SIMPLOT ELEMENTARY SCHOOL",
        "district": "AMERICAN FALLS JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160006000816",
    },
    {
        "school": "AMERICAN FALLS HIGH SCHOOL",
        "district": "AMERICAN FALLS JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160006000003",
    },
    {
        "school": "HILLCREST ELEMENTARY SCHOOL",
        "district": "AMERICAN FALLS JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160006000005",
    },
    {
        "school": "WILLIAM THOMAS MIDDLE SCHOOL",
        "district": "AMERICAN FALLS JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160006000589",
    },
    {
        "school": "AMERICAN FALLS ACADEMY",
        "district": "AMERICAN FALLS JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160006000768",
    },
    {
        "school": "ARBON ELEMENTARY SCHOOL",
        "district": "ARBON ELEMENTARY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160009000006",
    },
    {
        "school": "ROCKLAND PUBLIC SCHOOL",
        "district": "ROCKLAND DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160282000501",
    },
    {
        "school": "DOWNEY ELEMENTARY SCHOOL",
        "district": "MARSH VALLEY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160195000344",
    },
    {
        "school": "INKOM ELEMENTARY SCHOOL",
        "district": "MARSH VALLEY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160195000345",
    },
    {
        "school": "LAVA ELEMENTARY SCHOOL",
        "district": "MARSH VALLEY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160195000346",
    },
    {
        "school": "MARSH VALLEY HIGH SCHOOL",
        "district": "MARSH VALLEY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160195000347",
    },
    {
        "school": "MARSH VALLEY MIDDLE SCHOOL",
        "district": "MARSH VALLEY JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160195000348",
    },
    {
        "school": "MOUNTAIN VIEW ELEMENTARY SCHOOL",
        "district": "MARSH VALLEY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160195000349",
    },
    {
        "school": "POCATELLO JUVENILE DETENTION",
        "district": "POCATELLO DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160264000186",
    },
    {
        "school": "CHUBBUCK ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000464",
    },
    {
        "school": "CLAUDE A WILCOX ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000465",
    },
    {
        "school": "EDAHOW ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000467",
    },
    {
        "school": "NEW HORIZON HIGH SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160264000468",
    },
    {
        "school": "FRANKLIN MIDDLE SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000469",
    },
    {
        "school": "GREENACRES ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000470",
    },
    {
        "school": "HAWTHORNE MIDDLE SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000471",
    },
    {
        "school": "HIGHLAND HIGH SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000472",
    },
    {
        "school": "INDIAN HILLS ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000473",
    },
    {
        "school": "IRVING MIDDLE SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000474",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000475",
    },
    {
        "school": "LEWIS & CLARK ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000476",
    },
    {
        "school": "POCATELLO HIGH SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000478",
    },
    {
        "school": "LINCOLN PRESCHOOL CENTER",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160264000479",
    },
    {
        "school": "SYRINGA ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000481",
    },
    {
        "school": "TENDOY ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000482",
    },
    {
        "school": "TYHEE ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000483",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000484",
    },
    {
        "school": "GATE CITY ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000642",
    },
    {
        "school": "CENTURY HIGH SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000646",
    },
    {
        "school": "RULON M ELLIS ELEMENTARY SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264000659",
    },
    {
        "school": "KINPORT MIDDLE SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160264000686",
    },
    {
        "school": "FIVE-COUNTY DETENTION CENTER",
        "district": "FREMONT COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160111000912",
    },
    {
        "school": "VALLEY VIEW ALTERNATIVE HIGH SCHOOL",
        "district": "SUGAR-SALEM JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160309000853",
    },
    {
        "school": "ASHTON ELEMENTARY SCHOOL",
        "district": "FREMONT COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160111000200",
    },
    {
        "school": "NORTH FREMONT JR/SR HIGH SCHOOL",
        "district": "FREMONT COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160111000203",
    },
    {
        "school": "PARKER-EGIN ELEMENTARY SCHOOL",
        "district": "FREMONT COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160111000204",
    },
    {
        "school": "SOUTH FREMONT HIGH SCHOOL",
        "district": "FREMONT COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160111000205",
    },
    {
        "school": "TETON ELEMENTARY SCHOOL",
        "district": "FREMONT COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160111000207",
    },
    {
        "school": "HENRYS FORK ELEMENTARY",
        "district": "FREMONT COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160111000622",
    },
    {
        "school": "SOUTH FREMONT JR HIGH",
        "district": "FREMONT COUNTY JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160111000625",
    },
    {
        "school": "MADISON MIDDLE SCHOOL",
        "district": "MADISON DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160192000210",
    },
    {
        "school": "CENTRAL HIGH SCHOOL",
        "district": "MADISON DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160192000296",
    },
    {
        "school": "ADAMS ELEMENTARY SCHOOL",
        "district": "MADISON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160192000333",
    },
    {
        "school": "BURTON ELEMENTARY SCHOOL",
        "district": "MADISON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160192000336",
    },
    {
        "school": "HIBBARD ELEMENTARY SCHOOL",
        "district": "MADISON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160192000337",
    },
    {
        "school": "KENNEDY ELEMENTARY SCHOOL",
        "district": "MADISON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160192000338",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "MADISON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160192000339",
    },
    {
        "school": "MADISON JUNIOR HIGH SCHOOL",
        "district": "MADISON DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160192000340",
    },
    {
        "school": "MADISON SENIOR HIGH SCHOOL",
        "district": "MADISON DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160192000341",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "SUGAR-SALEM JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160309000537",
    },
    {
        "school": "SUGAR-SALEM HIGH SCHOOL",
        "district": "SUGAR-SALEM JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160309000538",
    },
    {
        "school": "KERSHAW INTERMEDIATE SCHOOL",
        "district": "SUGAR-SALEM JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160309000645",
    },
    {
        "school": "SUGAR-SALEM JUNIOR HIGH SCHOOL",
        "district": "SUGAR-SALEM JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160309000702",
    },
    {
        "school": "FALLS CITY ACADEMY",
        "district": "JEROME JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160159000097",
    },
    {
        "school": "HORIZON ELEMENTARY SCHOOL",
        "district": "JEROME JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160159000272",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "JEROME JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160159000283",
    },
    {
        "school": "JEROME HIGH SCHOOL",
        "district": "JEROME JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160159000284",
    },
    {
        "school": "JEROME MIDDLE SCHOOL",
        "district": "JEROME JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160159000285",
    },
    {
        "school": "JEROME ACADEMY",
        "district": "JEROME JOINT DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160159000289",
    },
    {
        "school": "VALLEY SCHOOL",
        "district": "VALLEY DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160327000558",
    },
    {
        "school": "POPPLEWELL ELEMENTARY SCHOOL",
        "district": "BUHL JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160048000101",
    },
    {
        "school": "BUHL HIGH SCHOOL",
        "district": "BUHL JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160048000102",
    },
    {
        "school": "BUHL MIDDLE SCHOOL",
        "district": "BUHL JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160048000103",
    },
    {
        "school": "CASTLEFORD SCHOOL",
        "district": "CASTLEFORD DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160069000137",
    },
    {
        "school": "FILER ELEMENTARY SCHOOL",
        "district": "FILER DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160105000193",
    },
    {
        "school": "FILER HIGH SCHOOL",
        "district": "FILER DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160105000194",
    },
    {
        "school": "HOLLISTER ELEMENTARY SCHOOL",
        "district": "FILER DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160105000195",
    },
    {
        "school": "FILER MIDDLE SCHOOL",
        "district": "FILER DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160105000631",
    },
    {
        "school": "HANSEN ELEMENTARY SCHOOL",
        "district": "HANSEN DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160141000241",
    },
    {
        "school": "HANSEN JR/SR HIGH SCHOOL",
        "district": "HANSEN DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160141000757",
    },
    {
        "school": "KIMBERLY MIDDLE SCHOOL",
        "district": "KIMBERLY DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160171000179",
    },
    {
        "school": "KIMBERLY ELEMENTARY SCHOOL",
        "district": "KIMBERLY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160171000300",
    },
    {
        "school": "KIMBERLY HIGH SCHOOL",
        "district": "KIMBERLY DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160171000635",
    },
    {
        "school": "THREE CREEK ELEM/JR HIGH SCHOOL",
        "district": "THREE CREEK JOINT ELEMENTARY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160321000546",
    },
    {
        "school": "OREGON TRAIL ELEMENTARY SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324000316",
    },
    {
        "school": "BICKEL ELEMENTARY SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324000548",
    },
    {
        "school": "HARRISON ELEMENTARY SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324000549",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324000550",
    },
    {
        "school": "MORNINGSIDE ELEMENTARY SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324000551",
    },
    {
        "school": "VERA C O'LEARY MIDDLE SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324000552",
    },
    {
        "school": "ROBERT STUART MIDDLE SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324000553",
    },
    {
        "school": "SAWTOOTH ELEMENTARY SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324000554",
    },
    {
        "school": "TWIN FALLS HIGH SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324000555",
    },
    {
        "school": "I B PERRINE ELEMENTARY SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324000660",
    },
    {
        "school": "MAGIC VALLEY HIGH SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160324000703",
    },
    {
        "school": "SNAKE RIVER JUVENILE DETENTION",
        "district": "TWIN FALLS DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160324000739",
    },
    {
        "school": "BRIDGE ACADEMY",
        "district": "TWIN FALLS DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160324000755",
    },
    {
        "school": "Seth Whitman Elem Sch",
        "district": "Belvidere CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170579005760",
    },
    {
        "school": "Prairieview-Ogden Jr High Sch",
        "district": "Prairieview-Ogden CCSD 197",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170033005766",
    },
    {
        "school": "Prairieview-Ogden North Elem",
        "district": "Prairieview-Ogden CCSD 197",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170033005767",
    },
    {
        "school": "Prairieview-Ogden South Elem",
        "district": "Prairieview-Ogden CCSD 197",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170033005768",
    },
    {
        "school": "Urban Prep Chtr Acad Englewood HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005884",
    },
    {
        "school": "Providence-Englewood Elem Charter",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005885",
    },
    {
        "school": "Thomas Early Childhood Center",
        "district": "City of Chicago SD 299",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005886",
    },
    {
        "school": "Chicago Virtual Charter School",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005894",
    },
    {
        "school": "Richton Square School",
        "district": "Matteson ESD 162",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172502005778",
    },
    {
        "school": "Westbrook Early Learning Cntr",
        "district": "Mount Prospect SD 57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172721005771",
    },
    {
        "school": "North Campus",
        "district": "Township HSD 211",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173045005782",
    },
    {
        "school": "Colin Powell Middle Sch",
        "district": "ESD 159",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173630005774",
    },
    {
        "school": "Early Learning Center",
        "district": "West Chicago ESD 33",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174155005865",
    },
    {
        "school": "Project Indian",
        "district": "Grundy/Kendall ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018405892",
    },
    {
        "school": "Aux Sable",
        "district": "Minooka CCSD 201",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172631005818",
    },
    {
        "school": "Opdyke-Belle Rive Grade Sch",
        "district": "Opdyke-Belle-Rive CCSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170557005895",
    },
    {
        "school": "Geneva Middle Sch North",
        "district": "Geneva CUSD 304",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171638005827",
    },
    {
        "school": "Plank Junior High",
        "district": "CUSD 308",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027005820",
    },
    {
        "school": "Grande Reserve Elem Sch",
        "district": "Yorkville CUSD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396005819",
    },
    {
        "school": "Deer Path Middle Sch East",
        "district": "Lake Forest SD 67",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172175005830",
    },
    {
        "school": "Early Learning Center",
        "district": "Waukegan CUSD 60",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125005882",
    },
    {
        "school": "Alternative Education Center",
        "district": "Decatur SD 61",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185005840",
    },
    {
        "school": "Alton Middle School",
        "district": "Alton CUSD 11",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170360005841",
    },
    {
        "school": "East Elementary School",
        "district": "Alton CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170360005842",
    },
    {
        "school": "North Elementary School",
        "district": "Alton CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170360005843",
    },
    {
        "school": "Grand Chain Alternative Center",
        "district": "Jamp Spec Educ Services",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170032905757",
    },
    {
        "school": "Katie Harper-Wright Elem",
        "district": "East St Louis SD 189",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332005849",
    },
    {
        "school": "Gordon Bush Elementary",
        "district": "East St Louis SD 189",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332005866",
    },
    {
        "school": "Pioneer Grove Educational Center",
        "district": "Lincoln-Way Area Spec Ed JA Dist",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170009705864",
    },
    {
        "school": "Monee Education Center",
        "district": "Crete Monee CUSD 201U",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171125005861",
    },
    {
        "school": "Wilson Creek Elem Sch",
        "district": "Manhattan SD 114",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172427005857",
    },
    {
        "school": "Spencer Trail",
        "district": "New Lenox SD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814005858",
    },
    {
        "school": "Spencer Pointe",
        "district": "New Lenox SD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814005859",
    },
    {
        "school": "Spencer Crossing",
        "district": "New Lenox SD 122",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814005860",
    },
    {
        "school": "Aux Sable Middle Sch",
        "district": "Plainfield SD 202",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174005862",
    },
    {
        "school": "Orenic Intermediate School",
        "district": "Troy CCSD 30C",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173951005856",
    },
    {
        "school": "John J Lukancic Middle Sch",
        "district": "Valley View CUSD 365U",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007005863",
    },
    {
        "school": "Brown County Middle School",
        "district": "Brown County CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172730005720",
    },
    {
        "school": "RAP Elizabeth",
        "district": "Carroll/Jo Daviess/Stephenson ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017004640",
    },
    {
        "school": "West Carroll High School",
        "district": "West Carroll CUSD 314",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170031004970",
    },
    {
        "school": "West Carroll Middle School",
        "district": "West Carroll CUSD 314",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170031004976",
    },
    {
        "school": "West Carroll Primary",
        "district": "West Carroll CUSD 314",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170031005013",
    },
    {
        "school": "Tristar Acad Safe Sch Program",
        "district": "Bnd/Chrstn/Effngh/Fytt/Mntgmr ROE",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016504627",
    },
    {
        "school": "Aspire Alternative High School",
        "district": "Bnd/Chrstn/Effngh/Fytt/Mntgmr ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016505759",
    },
    {
        "school": "Vandalia Elementary School",
        "district": "Vandalia CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174014004629",
    },
    {
        "school": "Benton Grade Sch K-4",
        "district": "Benton CCSD 47",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170595004752",
    },
    {
        "school": "Crescent City Grade School",
        "district": "Crescent Iroquois CUSD 249",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032305620",
    },
    {
        "school": "River Ridge Elementary School",
        "district": "River Ridge CUSD 210",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000105651",
    },
    {
        "school": "Parkside Elementary School",
        "district": "Lawrence County CUD 20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172215004560",
    },
    {
        "school": "Perandoe Educational Program",
        "district": "Perandoe Spec Educ District",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "173131005845",
    },
    {
        "school": "Rushville-Industry High School",
        "district": "Schuyler-Industry CUSD 5",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170033205812",
    },
    {
        "school": "Washington Elem School",
        "district": "Schuyler-Industry CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170033205814",
    },
    {
        "school": "Webster Elem School",
        "district": "Schuyler-Industry CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170033205815",
    },
    {
        "school": "Windsor Jr & Sr High School",
        "district": "Windsor CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174269004676",
    },
    {
        "school": "Freeport Alternative High Sch",
        "district": "Carroll/Jo Daviess/Stephenson ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017005649",
    },
    {
        "school": "Norris City Annex",
        "district": "Wabash & Ohio Valley Sp Ed Dist",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "174048005809",
    },
    {
        "school": "Shawnee Elementary School",
        "district": "Shawnee CUSD 84",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174299004312",
    },
    {
        "school": "Brown County High School",
        "district": "Brown County CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172730002893",
    },
    {
        "school": "Brown County Elementary School",
        "district": "Brown County CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172730002894",
    },
    {
        "school": "Eastland Elementary School",
        "district": "Eastland CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000703846",
    },
    {
        "school": "Eastland Jr/Sr High School",
        "district": "Eastland CUSD 308",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000705083",
    },
    {
        "school": "Chadwick Elem School",
        "district": "Chadwick-Milledgeville CUSD 399",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170940004571",
    },
    {
        "school": "Milledgeville High School",
        "district": "Chadwick-Milledgeville CUSD 399",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170940005404",
    },
    {
        "school": "Chadwick Junior High School",
        "district": "Chadwick-Milledgeville CUSD 399",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170940005405",
    },
    {
        "school": "Milledgeville Elem School",
        "district": "Chadwick-Milledgeville CUSD 399",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170940005406",
    },
    {
        "school": "A-C Central Middle School",
        "district": "A-C Central CUSD 262",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010500245",
    },
    {
        "school": "A-C Central High School",
        "district": "A-C Central CUSD 262",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010505357",
    },
    {
        "school": "A-C Central Elementary School",
        "district": "A-C Central CUSD 262",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010505359",
    },
    {
        "school": "Beardstown Jr/Sr High School",
        "district": "Beardstown CUSD 15",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170531000216",
    },
    {
        "school": "Gard Elementary School",
        "district": "Beardstown CUSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170531000217",
    },
    {
        "school": "Grand Ave Sch",
        "district": "Beardstown CUSD 15",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170531000218",
    },
    {
        "school": "Virginia Jr/ Sr High School",
        "district": "Virginia CUSD 64",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174041004070",
    },
    {
        "school": "Virginia Elem School",
        "district": "Virginia CUSD 64",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174041004871",
    },
    {
        "school": "Casey-Westfield Jr/Sr HS",
        "district": "Casey-Westfield CUSD 4C",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000205087",
    },
    {
        "school": "Monroe Elem School",
        "district": "Casey-Westfield CUSD 4C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000205089",
    },
    {
        "school": "Marshall High School",
        "district": "Marshall CUSD 2C",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172487002695",
    },
    {
        "school": "Marshall Jr High School",
        "district": "Marshall CUSD 2C",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172487002696",
    },
    {
        "school": "North Elem School",
        "district": "Marshall CUSD 2C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172487002697",
    },
    {
        "school": "South Elem School",
        "district": "Marshall CUSD 2C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172487002698",
    },
    {
        "school": "Martinsville Jr- Sr High School",
        "district": "Martinsville CUSD 3C",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172490002700",
    },
    {
        "school": "Martinsville Elem School",
        "district": "Martinsville CUSD 3C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172490004727",
    },
    {
        "school": "Clay City Jr High School",
        "district": "Clay City CUSD 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171034001251",
    },
    {
        "school": "Clay City High School",
        "district": "Clay City CUSD 10",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171034001252",
    },
    {
        "school": "Clay City Elem School",
        "district": "Clay City CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171034004575",
    },
    {
        "school": "Flora High School",
        "district": "Flora CUSD 35",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171540001841",
    },
    {
        "school": "Floyd Henson Jr High Sch",
        "district": "Flora CUSD 35",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171540001846",
    },
    {
        "school": "North Clay Community High School",
        "district": "North Clay CUSD 25",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172881003025",
    },
    {
        "school": "North Clay Elem/Jr High Sch",
        "district": "North Clay CUSD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172881004772",
    },
    {
        "school": "Hutsonville Elem and Jr High Sch",
        "district": "Hutsonville CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171992002248",
    },
    {
        "school": "Hutsonville High School",
        "district": "Hutsonville CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171992002249",
    },
    {
        "school": "Oblong Elem School",
        "district": "Oblong CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172942003074",
    },
    {
        "school": "Oblong High School",
        "district": "Oblong CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172942003075",
    },
    {
        "school": "Palestine Grade School",
        "district": "Palestine CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173048003169",
    },
    {
        "school": "Palestine High School",
        "district": "Palestine CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173048003170",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Robinson CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173423003506",
    },
    {
        "school": "Nuttall Middle School",
        "district": "Robinson CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173423003507",
    },
    {
        "school": "Robinson High School",
        "district": "Robinson CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173423003508",
    },
    {
        "school": "Washington Elem School",
        "district": "Robinson CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173423003509",
    },
    {
        "school": "Blue Ridge High School",
        "district": "Blue Ridge CUSD 18",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000305119",
    },
    {
        "school": "Ruth M Schneider Elem School",
        "district": "Blue Ridge CUSD 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000305121",
    },
    {
        "school": "Clinton High School",
        "district": "Clinton CUSD 15",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171044001260",
    },
    {
        "school": "Clinton Jr High School",
        "district": "Clinton CUSD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171044001261",
    },
    {
        "school": "Douglas Elem School",
        "district": "Clinton CUSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171044001262",
    },
    {
        "school": "Clinton Elem School",
        "district": "Clinton CUSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171044001263",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Clinton CUSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171044001264",
    },
    {
        "school": "Arcola Elementary School",
        "district": "Arcola CUSD 306",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170396000082",
    },
    {
        "school": "Arcola High School",
        "district": "Arcola CUSD 306",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170396000083",
    },
    {
        "school": "Arthur Grade School",
        "district": "Arthur CUSD 305",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170426000120",
    },
    {
        "school": "Arthur-Lovington-Atwood-Hammond",
        "district": "Arthur CUSD 305",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170426000121",
    },
    {
        "school": "East Prairie Middle School",
        "district": "Tuscola CUSD 301",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173960003999",
    },
    {
        "school": "North Ward Elementary School",
        "district": "Tuscola CUSD 301",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173960004000",
    },
    {
        "school": "Tuscola High School",
        "district": "Tuscola CUSD 301",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173960004001",
    },
    {
        "school": "Villa Grove High School",
        "district": "Villa Grove CUSD 302",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174032004051",
    },
    {
        "school": "Villa Grove Elem School",
        "district": "Villa Grove CUSD 302",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174032004869",
    },
    {
        "school": "Villa Grove Jr High School",
        "district": "Villa Grove CUSD 302",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174032004870",
    },
    {
        "school": "Shiloh High School",
        "district": "Shiloh CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012200702",
    },
    {
        "school": "Shiloh Elementary School",
        "district": "Shiloh CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012200705",
    },
    {
        "school": "Chrisman Elem School",
        "district": "Edgar County CUD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171337001629",
    },
    {
        "school": "Chrisman High School",
        "district": "Edgar County CUD 6",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171337001630",
    },
    {
        "school": "Chrisman-Scottland Jr High School",
        "district": "Edgar County CUD 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171337003896",
    },
    {
        "school": "Kansas Elem School",
        "district": "Kansas CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172079002370",
    },
    {
        "school": "Kansas High School",
        "district": "Kansas CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172079002371",
    },
    {
        "school": "Creative Center for Children",
        "district": "Paris-Union SD 95",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173075001169",
    },
    {
        "school": "Carolyn Wenz Elem School",
        "district": "Paris-Union SD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173075003194",
    },
    {
        "school": "Memorial Elementary School",
        "district": "Paris-Union SD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173075003196",
    },
    {
        "school": "Mayo Middle School",
        "district": "Paris-Union SD 95",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173075005323",
    },
    {
        "school": "Crestwood Jr High School",
        "district": "Paris CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173078003200",
    },
    {
        "school": "Crestwood Elem School",
        "district": "Paris CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173078004786",
    },
    {
        "school": "Albion Grade School",
        "district": "Edwards County CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171350001634",
    },
    {
        "school": "Edwards County High School",
        "district": "Edwards County CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171350001636",
    },
    {
        "school": "West Salem Grade School",
        "district": "Edwards County CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171350001637",
    },
    {
        "school": "New Approach Alternative H S",
        "district": "Bnd/Chrstn/Effngh/Fytt/Mntgmr ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016502272",
    },
    {
        "school": "FOCUS Safe Sch Program",
        "district": "Bnd/Chrstn/Effngh/Fytt/Mntgmr ROE",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016502287",
    },
    {
        "school": "Brownstown Jr High School",
        "district": "Brownstown CUSD 201",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170744000382",
    },
    {
        "school": "Brownstown High School",
        "district": "Brownstown CUSD 201",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170744000383",
    },
    {
        "school": "Brownstown Elem School",
        "district": "Brownstown CUSD 201",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170744004556",
    },
    {
        "school": "Ramsey Elem School",
        "district": "Ramsey CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173309003434",
    },
    {
        "school": "Ramsey High School",
        "district": "Ramsey CUSD 204",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173309003435",
    },
    {
        "school": "St Elmo Jr High School",
        "district": "St Elmo CUSD 202",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173723003863",
    },
    {
        "school": "St Elmo Sr High School",
        "district": "St Elmo CUSD 202",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173723003864",
    },
    {
        "school": "St Elmo Elem School",
        "district": "St Elmo CUSD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173723004843",
    },
    {
        "school": "Vandalia Community High School",
        "district": "Vandalia CUSD 203",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174014004044",
    },
    {
        "school": "Christopher High",
        "district": "Christopher USD 99",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170021703614",
    },
    {
        "school": "Christopher Elem School",
        "district": "Christopher USD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170021703615",
    },
    {
        "school": "Akin Comm Cons Elem School",
        "district": "Akin CCSD 91",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170321000014",
    },
    {
        "school": "Benton Grade Sch 5-8",
        "district": "Benton CCSD 47",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170595004370",
    },
    {
        "school": "Benton Cons High School",
        "district": "Benton Cons HSD 103",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170597000278",
    },
    {
        "school": "Ewing-Northern Elem School",
        "district": "Ewing Northern CCSD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171464001811",
    },
    {
        "school": "Sesser-Valier High School",
        "district": "Sesser-Valier CUSD 196",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173594003730",
    },
    {
        "school": "Sesser-Valier Elem School",
        "district": "Sesser-Valier CUSD 196",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173594004830",
    },
    {
        "school": "Sesser-Valier Jr High School",
        "district": "Sesser-Valier CUSD 196",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173594004831",
    },
    {
        "school": "Central Jr High School",
        "district": "Frankfort CUSD 168",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174158004165",
    },
    {
        "school": "Denning Elementary School",
        "district": "Frankfort CUSD 168",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174158004166",
    },
    {
        "school": "Frankfort Intermediate School",
        "district": "Frankfort CUSD 168",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174158004167",
    },
    {
        "school": "Frankfort Comm High School",
        "district": "Frankfort CUSD 168",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174158004168",
    },
    {
        "school": "Zeigler-Royalton Jr High School",
        "district": "Zeigler-Royalton CUSD 188",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174380004348",
    },
    {
        "school": "Zeigler-Royalton High School",
        "district": "Zeigler-Royalton CUSD 188",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174380004349",
    },
    {
        "school": "Zeigler-Royalton Elem School",
        "district": "Zeigler-Royalton CUSD 188",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174380004897",
    },
    {
        "school": "Gallatin High School",
        "district": "Gallatin CUSD 7",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170004505236",
    },
    {
        "school": "Gallatin Elementary School",
        "district": "Gallatin CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170004505239",
    },
    {
        "school": "Gallatin Junior High School",
        "district": "Gallatin CUSD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170004505560",
    },
    {
        "school": "Carrollton Grade School",
        "district": "Carrollton CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170861000500",
    },
    {
        "school": "Carrollton High School",
        "district": "Carrollton CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170861000501",
    },
    {
        "school": "Greenfield Elem School",
        "district": "Greenfield CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171767002063",
    },
    {
        "school": "Greenfield High School",
        "district": "Greenfield CUSD 10",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171767002064",
    },
    {
        "school": "North Greene Jr/Sr High Sch",
        "district": "North Greene CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174224004246",
    },
    {
        "school": "North Greene Elem",
        "district": "North Greene CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174224004249",
    },
    {
        "school": "Hamilton Jr/Sr High Sch",
        "district": "Hamilton CCSD 328",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171806002084",
    },
    {
        "school": "Hamilton Elementary School",
        "district": "Hamilton CCSD 328",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171806002085",
    },
    {
        "school": "Nauvoo Elem School",
        "district": "Nauvoo-Colusa CUSD 325",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172778004761",
    },
    {
        "school": "Southeastern Jr/Sr High School",
        "district": "Southeastern CUSD 337",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173661003771",
    },
    {
        "school": "Southeastern Elementary School",
        "district": "Southeastern CUSD 337",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173661004801",
    },
    {
        "school": "Warsaw Elem School",
        "district": "Warsaw CUSD 316",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174089004101",
    },
    {
        "school": "Warsaw Sr High School",
        "district": "Warsaw CUSD 316",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174089004102",
    },
    {
        "school": "Hardin County High School",
        "district": "Hardin County CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171820004400",
    },
    {
        "school": "Hardin County Elem School",
        "district": "Hardin County CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171820004656",
    },
    {
        "school": "Hardin County Jr High School",
        "district": "Hardin County CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171820004657",
    },
    {
        "school": "Bryce Ash Grove Ed Ctr",
        "district": "Iroquois Special Education",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005105565",
    },
    {
        "school": "Cissna Park Sr High School",
        "district": "Cissna Park CUSD 6",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171029001250",
    },
    {
        "school": "Cissna Park Elementary School",
        "district": "Cissna Park CUSD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171029004573",
    },
    {
        "school": "Cissna Park Jr High School",
        "district": "Cissna Park CUSD 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171029004574",
    },
    {
        "school": "Ashkum Early Literacy Center",
        "district": "Central CUSD 4",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171041001255",
    },
    {
        "school": "Central High School",
        "district": "Central CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171041001256",
    },
    {
        "school": "Chebanse Elem School",
        "district": "Central CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171041001257",
    },
    {
        "school": "John L Nash Middle School",
        "district": "Central CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171041001259",
    },
    {
        "school": "Donovan Jr High School",
        "district": "Donovan CUSD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171251000818",
    },
    {
        "school": "Donovan Elem School",
        "district": "Donovan CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171251001503",
    },
    {
        "school": "Donovan Sr High School",
        "district": "Donovan CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171251001504",
    },
    {
        "school": "Glenn Raymond Middle School",
        "district": "Iroquois County CUSD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172017000820",
    },
    {
        "school": "Nettie Davis Elem School",
        "district": "Iroquois County CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172017002267",
    },
    {
        "school": "Wanda Kendall Elem School",
        "district": "Iroquois County CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172017002268",
    },
    {
        "school": "Watseka Comm High School",
        "district": "Iroquois County CUSD 9",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172017002269",
    },
    {
        "school": "Iroquois West Elem Sch/Thawville",
        "district": "Iroquois West CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172018000102",
    },
    {
        "school": "Iroquois West Elem Sch/Danforth",
        "district": "Iroquois West CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172018004922",
    },
    {
        "school": "Iroquois West Elem School/Gilman",
        "district": "Iroquois West CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172018004923",
    },
    {
        "school": "Iroquois West High School",
        "district": "Iroquois West CUSD 10",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172018004924",
    },
    {
        "school": "Iroquois West Middle School",
        "district": "Iroquois West CUSD 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172018004925",
    },
    {
        "school": "Jasper Co Jr High",
        "district": "Jasper County CUD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172038002298",
    },
    {
        "school": "Newton Comm High School",
        "district": "Jasper County CUD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172038002299",
    },
    {
        "school": "Newton Elem School",
        "district": "Jasper County CUD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172038002303",
    },
    {
        "school": "Ste Marie Elem School",
        "district": "Jasper County CUD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172038004680",
    },
    {
        "school": "River Ridge High School",
        "district": "River Ridge CUSD 210",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000105115",
    },
    {
        "school": "River Ridge Middle School",
        "district": "River Ridge CUSD 210",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000105116",
    },
    {
        "school": "East Dubuque Elem School",
        "district": "East Dubuque USD 119",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171305001549",
    },
    {
        "school": "East Dubuque High School",
        "district": "East Dubuque USD 119",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171305001550",
    },
    {
        "school": "Galena High School",
        "district": "Galena USD 120",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171605001912",
    },
    {
        "school": "Galena Middle School",
        "district": "Galena USD 120",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171605001913",
    },
    {
        "school": "Galena Primary School",
        "district": "Galena USD 120",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171605001914",
    },
    {
        "school": "Scales Mound High School",
        "district": "Scales Mound CUSD 211",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173561003710",
    },
    {
        "school": "Scales Mound Elem School",
        "district": "Scales Mound CUSD 211",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173561004827",
    },
    {
        "school": "Scales Mound Jr High School",
        "district": "Scales Mound CUSD 211",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173561004828",
    },
    {
        "school": "Stockton Middle School",
        "district": "Stockton CUSD 206",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173798000246",
    },
    {
        "school": "Stockton Elem School",
        "district": "Stockton CUSD 206",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173798003890",
    },
    {
        "school": "Stockton Sr High School",
        "district": "Stockton CUSD 206",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173798003891",
    },
    {
        "school": "Warren Jr/Sr High School",
        "district": "Warren CUSD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174074004094",
    },
    {
        "school": "Warren Elementary School",
        "district": "Warren CUSD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174074004435",
    },
    {
        "school": "Goreville High School",
        "district": "Goreville CUD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170001405224",
    },
    {
        "school": "Goreville Elementary School",
        "district": "Goreville CUD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170001405225",
    },
    {
        "school": "Buncombe Cons School",
        "district": "Buncombe Cons SD 43",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170774000391",
    },
    {
        "school": "Cypress Elem School",
        "district": "Cypress SD 64",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171152001372",
    },
    {
        "school": "New Simpson Hill Dist 32",
        "district": "New Simpson Hill SD 32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172816003817",
    },
    {
        "school": "Vienna Elem School Dist 55",
        "district": "Vienna SD 55",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174026004049",
    },
    {
        "school": "Vienna High School",
        "district": "Vienna HSD 133",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174029004050",
    },
    {
        "school": "Bridgeport Grade School",
        "district": "Red Hill CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172213002482",
    },
    {
        "school": "Red Hill Jr/Sr High School",
        "district": "Red Hill CUSD 10",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172213005283",
    },
    {
        "school": "Sumner Attendance Center",
        "district": "Red Hill CUSD 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172213005430",
    },
    {
        "school": "Lawrenceville High School",
        "district": "Lawrence County CUD 20",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172215002488",
    },
    {
        "school": "Parkview Jr High School",
        "district": "Lawrence County CUD 20",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172215002492",
    },
    {
        "school": "Illini Central High School",
        "district": "Illini Central CUSD 189",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011305387",
    },
    {
        "school": "Illini Central Grade School",
        "district": "Illini Central CUSD 189",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011305388",
    },
    {
        "school": "Illini Central Middle School",
        "district": "Illini Central CUSD 189",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011305577",
    },
    {
        "school": "Havana High School",
        "district": "Havana CUSD 126",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171851002143",
    },
    {
        "school": "New Central Elem School",
        "district": "Havana CUSD 126",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171851002144",
    },
    {
        "school": "Havana Jr High School",
        "district": "Havana CUSD 126",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171851004407",
    },
    {
        "school": "Beckemeyer Elem School",
        "district": "Hillsboro CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171920002201",
    },
    {
        "school": "Coffeen Elem School",
        "district": "Hillsboro CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171920002203",
    },
    {
        "school": "Hillsboro High School",
        "district": "Hillsboro CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171920002206",
    },
    {
        "school": "Hillsboro Jr High School",
        "district": "Hillsboro CUSD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171920002207",
    },
    {
        "school": "Litchfield Prekindergarten",
        "district": "Litchfield CUSD 12",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172325001146",
    },
    {
        "school": "J D Colt Elem School",
        "district": "Litchfield CUSD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172325002558",
    },
    {
        "school": "Litchfield Middle School",
        "district": "Litchfield CUSD 12",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172325002559",
    },
    {
        "school": "Litchfield Senior High School",
        "district": "Litchfield CUSD 12",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172325002560",
    },
    {
        "school": "Madison Park Elem School",
        "district": "Litchfield CUSD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172325002561",
    },
    {
        "school": "Russell Elem School",
        "district": "Litchfield CUSD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172325002563",
    },
    {
        "school": "Nokomis Jr/Sr High Sch",
        "district": "Nokomis CUSD 22",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172856002990",
    },
    {
        "school": "North Elem School",
        "district": "Nokomis CUSD 22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172856002992",
    },
    {
        "school": "Farmersville Elem School",
        "district": "Panhandle CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173066003188",
    },
    {
        "school": "Lincolnwood High School",
        "district": "Panhandle CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173066003190",
    },
    {
        "school": "Raymond Grade School",
        "district": "Panhandle CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173066003191",
    },
    {
        "school": "Lincolnwood Jr High School",
        "district": "Panhandle CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173066003192",
    },
    {
        "school": "Okaw Valley High School",
        "district": "Okaw Valley CUSD 302",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170022304221",
    },
    {
        "school": "Okaw Valley Elementary School",
        "district": "Okaw Valley CUSD 302",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170022304544",
    },
    {
        "school": "Sullivan Elem School",
        "district": "Sullivan CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173813003905",
    },
    {
        "school": "Sullivan High School",
        "district": "Sullivan CUSD 300",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173813003906",
    },
    {
        "school": "Sullivan Middle School",
        "district": "Sullivan CUSD 300",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173813003907",
    },
    {
        "school": "Pinckneyville Elem School",
        "district": "Pinckneyville SD 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000903322",
    },
    {
        "school": "Pinckneyville Middle School",
        "district": "Pinckneyville SD 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000903323",
    },
    {
        "school": "Du Quoin High School",
        "district": "Du Quoin CUSD 300",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171276001530",
    },
    {
        "school": "Du Quoin  Middle School",
        "district": "Du Quoin CUSD 300",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171276001531",
    },
    {
        "school": "Du Quoin  Elementary School",
        "district": "Du Quoin CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171276001535",
    },
    {
        "school": "Community Cons School",
        "district": "CCSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173156003324",
    },
    {
        "school": "Pinckneyville Comm High School",
        "district": "Pinckneyville CHSD 101",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173162003326",
    },
    {
        "school": "Tamaroa Elem School",
        "district": "Tamaroa School Dist 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173855003928",
    },
    {
        "school": "Blue Ridge Intermediate-Jr HS",
        "district": "Blue Ridge CUSD 18",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000305123",
    },
    {
        "school": "Griggsville-Perry Middle School",
        "district": "Griggsville-Perry CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171779001063",
    },
    {
        "school": "Griggsville-Perry High School",
        "district": "Griggsville-Perry CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171779002073",
    },
    {
        "school": "Griggsville-Perry Primary School",
        "district": "Griggsville-Perry CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171779004652",
    },
    {
        "school": "Pittsfield High School",
        "district": "Pikeland CUSD 10",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173171003332",
    },
    {
        "school": "Pittsfield South Elem School",
        "district": "Pikeland CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173171003333",
    },
    {
        "school": "Pikeland Community School",
        "district": "Pikeland CUSD 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173171005518",
    },
    {
        "school": "Pleasant Hill Elem School",
        "district": "Pleasant Hill CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173189003345",
    },
    {
        "school": "Pleasant Hill High School",
        "district": "Pleasant Hill CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173189003346",
    },
    {
        "school": "Pope County Elementary School",
        "district": "Pope Co CUD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173228003371",
    },
    {
        "school": "Pope Co High School",
        "district": "Pope Co CUD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173228003372",
    },
    {
        "school": "Meridian High School",
        "district": "Meridian CUSD 101",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172697002873",
    },
    {
        "school": "Meridian Elementary School",
        "district": "Meridian CUSD 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172697002874",
    },
    {
        "school": "Century Jr/Sr High School",
        "district": "Century CUSD 100",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173963004003",
    },
    {
        "school": "Century Elementary School",
        "district": "Century CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173963004861",
    },
    {
        "school": "Chester Elem School",
        "district": "Chester CUSD 139",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170981000578",
    },
    {
        "school": "Chester High School",
        "district": "Chester CUSD 139",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170981000579",
    },
    {
        "school": "Coulterville High School",
        "district": "Coulterville USD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171098001330",
    },
    {
        "school": "Coulterville Elementary School",
        "district": "Coulterville USD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171098004583",
    },
    {
        "school": "Coulterville Junior High School",
        "district": "Coulterville USD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171098004584",
    },
    {
        "school": "Prairie Du Rocher Elem School",
        "district": "Prairie Du Rocher CCSD 134",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173249003379",
    },
    {
        "school": "Red Bud Elem School",
        "district": "Red Bud CUSD 132",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173330003447",
    },
    {
        "school": "Red Bud High School",
        "district": "Red Bud CUSD 132",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173330003448",
    },
    {
        "school": "Sparta High School",
        "district": "Sparta CUSD 140",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173690003804",
    },
    {
        "school": "Sparta Lincoln School",
        "district": "Sparta CUSD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173690003806",
    },
    {
        "school": "Evansville Attendance Center",
        "district": "Sparta CUSD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173690004459",
    },
    {
        "school": "Steeleville Elem School",
        "district": "Steeleville CUSD 138",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173765003878",
    },
    {
        "school": "Steeleville High School",
        "district": "Steeleville CUSD 138",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173765003879",
    },
    {
        "school": "ASSIST TAOEP 12",
        "district": "Clay/Cwford/Jsper/Lwrnce/Rhland",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017302440",
    },
    {
        "school": "Richland County High School",
        "district": "Richland County CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171329001583",
    },
    {
        "school": "Richland County Middle School",
        "district": "Richland County CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171329001584",
    },
    {
        "school": "Richland County Elementary School",
        "district": "Richland County CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171329003418",
    },
    {
        "school": "Cowden-Herrick Jr/Sr High School",
        "district": "Cowden-Herrick CUSD 3A",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170017602389",
    },
    {
        "school": "Cowden-Herrick Grade School",
        "district": "Cowden-Herrick CUSD 3A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170017602401",
    },
    {
        "school": "Okaw Valley Middle School",
        "district": "Okaw Valley CUSD 302",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170022304224",
    },
    {
        "school": "Main Street Elementary School",
        "district": "Shelbyville CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173609003738",
    },
    {
        "school": "Moulton Elementary School",
        "district": "Shelbyville CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173609003739",
    },
    {
        "school": "Shelbyville High School",
        "district": "Shelbyville CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173609003740",
    },
    {
        "school": "Shelbyville Kindergarten Center",
        "district": "Shelbyville CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173609005522",
    },
    {
        "school": "Stewardson-Strasburg Elem School",
        "district": "Stewardson-Strasburg CUD 5A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173783003886",
    },
    {
        "school": "Stewardson-Strasburg High School",
        "district": "Stewardson-Strasburg CUD 5A",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173783003887",
    },
    {
        "school": "Windsor Elem School",
        "district": "Windsor CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174269004290",
    },
    {
        "school": "RAP Freeport",
        "district": "Carroll/Jo Daviess/Stephenson ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017002342",
    },
    {
        "school": "Anna Junior High School",
        "district": "Anna CCSD 37",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170375000064",
    },
    {
        "school": "Davie Elem School",
        "district": "Anna CCSD 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170375000065",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Anna CCSD 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170375000066",
    },
    {
        "school": "Anna-Jonesboro High School",
        "district": "Anna Jonesboro CHSD 81",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170378000067",
    },
    {
        "school": "Cobden Jr High School",
        "district": "Cobden SUD 17",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171057001273",
    },
    {
        "school": "Cobden High School",
        "district": "Cobden SUD 17",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171057001274",
    },
    {
        "school": "Cobden Elem School",
        "district": "Cobden SUD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171057004576",
    },
    {
        "school": "Dongola High School",
        "district": "Dongola USD 66",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171248001502",
    },
    {
        "school": "Dongola Elementary School",
        "district": "Dongola USD 66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171248004609",
    },
    {
        "school": "Dongola Jr High School",
        "district": "Dongola USD 66",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171248004610",
    },
    {
        "school": "Jonesboro Elem School",
        "district": "County of Union Sch Dist No43",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172064002353",
    },
    {
        "school": "Lick Creek Elem School",
        "district": "Lick Creek CCSD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172286002532",
    },
    {
        "school": "Shawnee High School",
        "district": "Shawnee CUSD 84",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174299004313",
    },
    {
        "school": "Shawnee Jr High School",
        "district": "Shawnee CUSD 84",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174299004315",
    },
    {
        "school": "Allendale Elementary School",
        "district": "Allendale CCSD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170345004514",
    },
    {
        "school": "Mount Carmel High School",
        "district": "Wabash CUSD 348",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174047004073",
    },
    {
        "school": "Mt Carmel Elementary School",
        "district": "Wabash CUSD 348",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174047004075",
    },
    {
        "school": "Mt Carmel Junior High School",
        "district": "Wabash CUSD 348",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174047004372",
    },
    {
        "school": "Mt Carmel Grade School",
        "district": "Wabash CUSD 348",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174047004373",
    },
    {
        "school": "Ashley Com Consolidated School",
        "district": "Ashley CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170434000125",
    },
    {
        "school": "Irvington Elem School",
        "district": "Irvington CCSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172019002273",
    },
    {
        "school": "Nashville Grade School",
        "district": "Nashville CCSD 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172772002466",
    },
    {
        "school": "Nashville Comm High School",
        "district": "Nashville CHSD 99",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172774002947",
    },
    {
        "school": "Oakdale Grade School",
        "district": "Oakdale CCSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172931003071",
    },
    {
        "school": "Okawville Grade School",
        "district": "West Washington Co CUD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174175004180",
    },
    {
        "school": "Okawville Jr/Sr High School",
        "district": "West Washington Co CUD 10",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174175004182",
    },
    {
        "school": "Cisne High School",
        "district": "North Wayne CUSD 200",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171024001246",
    },
    {
        "school": "Cisne Middle School",
        "district": "North Wayne CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171024001247",
    },
    {
        "school": "Johnsonville Elem School",
        "district": "North Wayne CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171024001248",
    },
    {
        "school": "Mount Erie Elem School",
        "district": "North Wayne CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171024001249",
    },
    {
        "school": "Center Street Elem School",
        "district": "Fairfield PSD 112",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171471001814",
    },
    {
        "school": "North Side Elem School",
        "district": "Fairfield PSD 112",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171471001815",
    },
    {
        "school": "Geff Elem School",
        "district": "Geff CCSD 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171632001946",
    },
    {
        "school": "Jasper Elem School",
        "district": "Jasper CCSD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172037002294",
    },
    {
        "school": "Fairfield Comm High School",
        "district": "Fairfield Comm H S Dist 225",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172618001816",
    },
    {
        "school": "New Hope Elem School",
        "district": "New Hope CCSD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172811002964",
    },
    {
        "school": "Wayne City Attendance Center",
        "district": "Wayne City CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174136004150",
    },
    {
        "school": "Wayne City High School",
        "district": "Wayne City CUSD 100",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174136004151",
    },
    {
        "school": "Norris City-Omaha Elem School",
        "district": "Norris City-Omaha-Enfield CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000403009",
    },
    {
        "school": "Norris City-Omaha-Enfield H S",
        "district": "Norris City-Omaha-Enfield CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000403010",
    },
    {
        "school": "Booth Elementary School",
        "district": "Norris City-Omaha-Enfield CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000405125",
    },
    {
        "school": "Jefferson Attendance Center",
        "district": "Carmi-White County CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170850000470",
    },
    {
        "school": "Carmi-White County High School",
        "district": "Carmi-White County CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170850000472",
    },
    {
        "school": "Lincoln Attendance Center",
        "district": "Carmi-White County CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170850000474",
    },
    {
        "school": "Brownsville Attendance Center",
        "district": "Carmi-White County CUSD 5",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170850000475",
    },
    {
        "school": "Carmi White Cnty Jr High Sch",
        "district": "Carmi-White County CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170850000476",
    },
    {
        "school": "Prekindergarten Facility",
        "district": "Carmi-White County CUSD 5",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170850001622",
    },
    {
        "school": "Washington Attendance Center",
        "district": "Carmi-White County CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170850005297",
    },
    {
        "school": "Grayville Jr Sr High School",
        "district": "Grayville CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171758002058",
    },
    {
        "school": "Wells Elementary School",
        "district": "Grayville CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171758002060",
    },
    {
        "school": "Midwest Central High School",
        "district": "Midwest Central CUSD 191",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396205578",
    },
    {
        "school": "Midwest Central Primary School",
        "district": "Midwest Central CUSD 191",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396205580",
    },
    {
        "school": "Midwest Central Middle School",
        "district": "Midwest Central CUSD 191",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396201455",
    },
    {
        "school": "Regional Alop School",
        "district": "DeWitt/Livingstn/Logan/McLean ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017705694",
    },
    {
        "school": "Kingsley Jr High School",
        "district": "McLean County USD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862005695",
    },
    {
        "school": "Olympia South Elem Sch",
        "district": "Olympia CUSD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172989003092",
    },
    {
        "school": "Thomas Metcalf School",
        "district": "ISU  Laboratory Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170009904504",
    },
    {
        "school": "University High School",
        "district": "ISU  Laboratory Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170009904506",
    },
    {
        "school": "Ridgeview High School",
        "district": "Ridgeview CUSD 19",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010905366",
    },
    {
        "school": "Ridgeview Jr High School",
        "district": "Ridgeview CUSD 19",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010905367",
    },
    {
        "school": "Ridgeview Elementary School",
        "district": "Ridgeview CUSD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010905369",
    },
    {
        "school": "Safe School Program",
        "district": "DeWitt/Livingstn/Logan/McLean ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017702636",
    },
    {
        "school": "Sarah A Raymond Sch of Early Educ",
        "district": "Bloomington SD 87",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170648000046",
    },
    {
        "school": "Bent Elem School",
        "district": "Bloomington SD 87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170648000317",
    },
    {
        "school": "Bloomington High School",
        "district": "Bloomington SD 87",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170648000318",
    },
    {
        "school": "Bloomington Jr High School",
        "district": "Bloomington SD 87",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170648000319",
    },
    {
        "school": "Irving Elementary School",
        "district": "Bloomington SD 87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170648000321",
    },
    {
        "school": "Oakland Elementary School",
        "district": "Bloomington SD 87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170648000323",
    },
    {
        "school": "Sheridan Elem School",
        "district": "Bloomington SD 87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170648000325",
    },
    {
        "school": "Stevenson Elem School",
        "district": "Bloomington SD 87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170648000326",
    },
    {
        "school": "Washington Elem School",
        "district": "Bloomington SD 87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170648000327",
    },
    {
        "school": "Tri-Valley Middle School",
        "district": "Tri Valley CUSD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171392001735",
    },
    {
        "school": "Tri-Valley High School",
        "district": "Tri Valley CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171392001736",
    },
    {
        "school": "Tri-Valley Elem School",
        "district": "Tri Valley CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171392004628",
    },
    {
        "school": "Heyworth Elem School",
        "district": "Heyworth CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171887002173",
    },
    {
        "school": "Heyworth Jr-Sr High School",
        "district": "Heyworth CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171887002174",
    },
    {
        "school": "LeRoy Junior High School",
        "district": "LeRoy CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172262002513",
    },
    {
        "school": "LeRoy High School",
        "district": "LeRoy CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172262002514",
    },
    {
        "school": "LeRoy Elementary School",
        "district": "LeRoy CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172262004698",
    },
    {
        "school": "Lexington Jr High School",
        "district": "Lexington CUSD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172271002518",
    },
    {
        "school": "Lexington High School",
        "district": "Lexington CUSD 7",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172271002519",
    },
    {
        "school": "Lexington Elem School",
        "district": "Lexington CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172271004699",
    },
    {
        "school": "Pepper Ridge Elementary School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862000765",
    },
    {
        "school": "Normal Community West High School",
        "district": "McLean County USD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862001386",
    },
    {
        "school": "Cedar Ridge Elem School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862002994",
    },
    {
        "school": "Carlock Elem School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862002995",
    },
    {
        "school": "Chiddix Jr High School",
        "district": "McLean County USD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862002996",
    },
    {
        "school": "Colene Hoose Elem School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862002997",
    },
    {
        "school": "Fairview Elem School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862002999",
    },
    {
        "school": "Glenn Elem School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862003000",
    },
    {
        "school": "Hudson Elem School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862003001",
    },
    {
        "school": "Normal Community High School",
        "district": "McLean County USD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862003002",
    },
    {
        "school": "Oakdale Elem School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862003003",
    },
    {
        "school": "Parkside Jr High School",
        "district": "McLean County USD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862003004",
    },
    {
        "school": "Sugar Creek Elem School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862003005",
    },
    {
        "school": "Prairieland Elementary School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862003589",
    },
    {
        "school": "Fox Creek Elementary School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862004341",
    },
    {
        "school": "Grove Elementary School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862004347",
    },
    {
        "school": "Northpoint Elementary School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862005320",
    },
    {
        "school": "Parkside Elementary School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862005321",
    },
    {
        "school": "Towanda Elem School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862005556",
    },
    {
        "school": "Olympia North Elem Sch",
        "district": "Olympia CUSD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172989003093",
    },
    {
        "school": "Olympia High School",
        "district": "Olympia CUSD 16",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172989003096",
    },
    {
        "school": "Olympia Middle School",
        "district": "Olympia CUSD 16",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172989005185",
    },
    {
        "school": "Olympia West Elem Sch",
        "district": "Olympia CUSD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172989003095",
    },
    {
        "school": "West Central High School",
        "district": "West Central CUSD 235",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170031905597",
    },
    {
        "school": "West Central Middle School",
        "district": "West Central CUSD 235",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170031905598",
    },
    {
        "school": "West Central Elementary School",
        "district": "West Central CUSD 235",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170031905599",
    },
    {
        "school": "West Central Early Childhood",
        "district": "West Central CUSD 235",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170031905600",
    },
    {
        "school": "Central Elem School",
        "district": "Lewistown CUSD 97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170015302515",
    },
    {
        "school": "Lewistown Jr/Sr High School",
        "district": "Lewistown CUSD 97",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170015302517",
    },
    {
        "school": "Astoria High School",
        "district": "Astoria CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170444000130",
    },
    {
        "school": "Astoria Elem School",
        "district": "Astoria CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170444004529",
    },
    {
        "school": "Astoria Junior High School",
        "district": "Astoria CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170444005139",
    },
    {
        "school": "Canton High School",
        "district": "Canton Union SD 66",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170828000438",
    },
    {
        "school": "Eastview Elementary School",
        "district": "Canton Union SD 66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170828000439",
    },
    {
        "school": "Ingersoll Middle School",
        "district": "Canton Union SD 66",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170828000440",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Canton Union SD 66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170828000442",
    },
    {
        "school": "Westview Elementary School",
        "district": "Canton Union SD 66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170828000444",
    },
    {
        "school": "Cuba Middle School",
        "district": "CUSD 3 Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171140001369",
    },
    {
        "school": "Cuba Sr High School",
        "district": "CUSD 3 Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171140001370",
    },
    {
        "school": "Cuba Elem School",
        "district": "CUSD 3 Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171140001371",
    },
    {
        "school": "Spoon River Valley Jr High Sch",
        "district": "Spoon River Valley CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173696003808",
    },
    {
        "school": "Spoon River Valley Sr High Sch",
        "district": "Spoon River Valley CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173696003809",
    },
    {
        "school": "Spoon River Valley Elem School",
        "district": "Spoon River Valley CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173696004838",
    },
    {
        "school": "V I T Sr High School",
        "district": "V I T CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173849003925",
    },
    {
        "school": "V I T Jr High School",
        "district": "V I T CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173849003926",
    },
    {
        "school": "V I T Elementary School",
        "district": "V I T CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173849004850",
    },
    {
        "school": "Cairo Jr/Sr High School",
        "district": "Cairo USD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170807000420",
    },
    {
        "school": "Cairo Elementary School",
        "district": "Cairo USD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170807000424",
    },
    {
        "school": "Egyptian Jr High School",
        "district": "Egyptian CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171359001655",
    },
    {
        "school": "Egyptian Elem School",
        "district": "Egyptian CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171359001656",
    },
    {
        "school": "Egyptian Sr High School",
        "district": "Egyptian CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171359001657",
    },
    {
        "school": "Tri-County Center",
        "district": "Tri-County Sp Ed Jnt Agreement",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005205825",
    },
    {
        "school": "Cope Alternative School",
        "district": "Alxndr/Jcksn/Pulsk/Prry/Union ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019002866",
    },
    {
        "school": "Trico Elementary School",
        "district": "Trico CUSD 176",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170825000435",
    },
    {
        "school": "Trico Jr High School",
        "district": "Trico CUSD 176",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170825000436",
    },
    {
        "school": "Trico Senior High School",
        "district": "Trico CUSD 176",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170825000437",
    },
    {
        "school": "Thomas Elementary School",
        "district": "Carbondale ESD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170834000448",
    },
    {
        "school": "Carbondale Middle School",
        "district": "Carbondale ESD 95",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170834000449",
    },
    {
        "school": "Parrish Elem School",
        "district": "Carbondale ESD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170834000450",
    },
    {
        "school": "Lewis School",
        "district": "Carbondale ESD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170834000452",
    },
    {
        "school": "Carbondale Comm H S",
        "district": "Carbondale CHSD 165",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170837000454",
    },
    {
        "school": "DeSoto Elementary School",
        "district": "DeSoto Cons SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171215001472",
    },
    {
        "school": "Elverado Primary School",
        "district": "Elverado CUSD 196",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171386001731",
    },
    {
        "school": "Elverado High School",
        "district": "Elverado CUSD 196",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171386001732",
    },
    {
        "school": "Elverado Junior High School",
        "district": "Elverado CUSD 196",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171386001733",
    },
    {
        "school": "Elverado Intermediate School",
        "district": "Elverado CUSD 196",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171386001734",
    },
    {
        "school": "Giant City Elem School",
        "district": "Giant City CCSD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171659001964",
    },
    {
        "school": "Murphysboro High School",
        "district": "Murphysboro CUSD 186",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172761002925",
    },
    {
        "school": "Murphysboro Middle School",
        "district": "Murphysboro CUSD 186",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172761002926",
    },
    {
        "school": "Gen John A Logan Attendance Cntr",
        "district": "Murphysboro CUSD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172761004396",
    },
    {
        "school": "Carruthers Elementary School",
        "district": "Murphysboro CUSD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172761005285",
    },
    {
        "school": "Unity Point Elem School",
        "district": "Unity Point CCSD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173993004010",
    },
    {
        "school": "Tri-County Ward",
        "district": "Tri-County Sp Ed Jnt Agreement",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005203643",
    },
    {
        "school": "Tri-County South - Choate",
        "district": "Tri-County Sp Ed Jnt Agreement",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005204759",
    },
    {
        "school": "Selmaville Elem School",
        "district": "Selmaville CCSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173577005019",
    },
    {
        "school": "Kaskaskia Education Center",
        "district": "Kaskaskia Spec Educ District",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170007405111",
    },
    {
        "school": "Grand Prairie Elem School",
        "district": "Grand Prairie CCSD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171719002022",
    },
    {
        "school": "Bridges Learning Center",
        "district": "Kaskaskia Spec Educ District",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170007403419",
    },
    {
        "school": "South Central High School",
        "district": "South Central CUD 401",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011405391",
    },
    {
        "school": "South Central Middle School",
        "district": "South Central CUD 401",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011405392",
    },
    {
        "school": "South Central Elementary-Kinmundy",
        "district": "South Central CUD 401",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011405393",
    },
    {
        "school": "Central City Elem School",
        "district": "Central City SD 133",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170918000527",
    },
    {
        "school": "Centralia High School",
        "district": "Centralia HSD 200",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170930000538",
    },
    {
        "school": "Iuka Comm Cons School",
        "district": "Iuka CCSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172025002277",
    },
    {
        "school": "Kell Grade School",
        "district": "Kell Cons SD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172091002377",
    },
    {
        "school": "Patoka Sr High School",
        "district": "Patoka CUSD 100",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173087003219",
    },
    {
        "school": "Patoka Elem School",
        "district": "Patoka CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173087004787",
    },
    {
        "school": "Patoka Jr High School",
        "district": "Patoka CUSD 100",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173087004788",
    },
    {
        "school": "Raccoon Cons Elem School",
        "district": "Raccoon Cons SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173303003433",
    },
    {
        "school": "Hawthorn Elem School",
        "district": "Salem SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173516003679",
    },
    {
        "school": "Franklin Park Middle School",
        "district": "Salem SD 111",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173516003680",
    },
    {
        "school": "Salem Community High School",
        "district": "Salem CHSD 600",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173519003681",
    },
    {
        "school": "Sandoval Jr High School",
        "district": "Sandoval CUSD 501",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173531003688",
    },
    {
        "school": "Sandoval Sr High School",
        "district": "Sandoval CUSD 501",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173531003689",
    },
    {
        "school": "Sandoval Elem School",
        "district": "Sandoval CUSD 501",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173531004825",
    },
    {
        "school": "Hoyleton Education Center",
        "district": "Kaskaskia Spec Educ District",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170007405110",
    },
    {
        "school": "Schiller Elem School",
        "district": "Centralia SD 135",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170927000536",
    },
    {
        "school": "North Wamac Grade School",
        "district": "North Wamac SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174068004088",
    },
    {
        "school": "Willow Grove Elem School",
        "district": "Willow Grove SD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174251001739",
    },
    {
        "school": "Jordan Elem School",
        "district": "Centralia SD 135",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170927000534",
    },
    {
        "school": "Centralia Jr High School",
        "district": "Centralia SD 135",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170927000535",
    },
    {
        "school": "Centralia Pre-Kindergarten Ctr",
        "district": "Centralia SD 135",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170927005585",
    },
    {
        "school": "St Joseph Middle School",
        "district": "St Joseph CCSD 169",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173738005765",
    },
    {
        "school": "Unity West",
        "district": "Tolono CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173912004645",
    },
    {
        "school": "Unity East",
        "district": "Tolono CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173912004648",
    },
    {
        "school": "Monticello Middle School",
        "district": "Monticello CUSD 25",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172655005715",
    },
    {
        "school": "GCMS High School",
        "district": "Gibson City-Melvin-Sibley CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170004100254",
    },
    {
        "school": "GCMS Middle School",
        "district": "Gibson City-Melvin-Sibley CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170004100268",
    },
    {
        "school": "GCMS Elementary School",
        "district": "Gibson City-Melvin-Sibley CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170004100272",
    },
    {
        "school": "Paxton-Buckley-Loda High School",
        "district": "Paxton-Buckley-Loda CUD 10",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170765005478",
    },
    {
        "school": "Paxton-Buckley-Loda Jr High Sch",
        "district": "Paxton-Buckley-Loda CUD 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170765005479",
    },
    {
        "school": "Clara Peterson Elem School",
        "district": "Paxton-Buckley-Loda CUD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170765005480",
    },
    {
        "school": "Tri-Point Jr High/Elementary",
        "district": "Tri Point CUSD 6-J",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173948000171",
    },
    {
        "school": "Tri Point Elementary School",
        "district": "Tri Point CUSD 6-J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173948003992",
    },
    {
        "school": "Tri-Point High School",
        "district": "Tri Point CUSD 6-J",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173948003994",
    },
    {
        "school": "Bement High School",
        "district": "Bement CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170582000263",
    },
    {
        "school": "Bement Elementary School",
        "district": "Bement CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170582004540",
    },
    {
        "school": "Bement Middle School",
        "district": "Bement CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170582004541",
    },
    {
        "school": "Cerro Gordo Jr and Sr High Sch",
        "district": "Cerro Gordo CUSD 100",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170933000540",
    },
    {
        "school": "Cerro Gordo Elem School",
        "district": "Cerro Gordo CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170933004570",
    },
    {
        "school": "Deland-Weldon Middle School",
        "district": "Deland-Weldon CUSD 57",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171203001456",
    },
    {
        "school": "Deland-Weldon High School",
        "district": "Deland-Weldon CUSD 57",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171203001457",
    },
    {
        "school": "Deland-Weldon Elem School",
        "district": "Deland-Weldon CUSD 57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171203004600",
    },
    {
        "school": "Washington School",
        "district": "Monticello CUSD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172655000766",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Monticello CUSD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172655002842",
    },
    {
        "school": "Monticello High School",
        "district": "Monticello CUSD 25",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172655002843",
    },
    {
        "school": "White Heath Elem School",
        "district": "Monticello CUSD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172655002845",
    },
    {
        "school": "University of Illinois High Sch",
        "district": "University of Ill Lab School",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170010004505",
    },
    {
        "school": "Heritage High School",
        "district": "Heritage CUSD 8",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010605361",
    },
    {
        "school": "Heritage JH and Elem Sch",
        "district": "Heritage CUSD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010605363",
    },
    {
        "school": "R E A D Y Program",
        "district": "Champaign/Ford ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017102351",
    },
    {
        "school": "Juvenile Detention Center",
        "district": "Champaign/Ford ROE",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017103882",
    },
    {
        "school": "Bottenfield Elem School",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000543",
    },
    {
        "school": "Carrie Busey Elem School",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000544",
    },
    {
        "school": "Centennial High School",
        "district": "Champaign CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000545",
    },
    {
        "school": "Central High School",
        "district": "Champaign CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000546",
    },
    {
        "school": "Dr Howard Elem School",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000547",
    },
    {
        "school": "Garden Hills Elem School",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000548",
    },
    {
        "school": "Edison Middle School",
        "district": "Champaign CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000549",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Champaign CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000550",
    },
    {
        "school": "Kenwood Elem School",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000551",
    },
    {
        "school": "Robeson Elem School",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000553",
    },
    {
        "school": "Washington Elem School",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000555",
    },
    {
        "school": "Westview Elem School",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000556",
    },
    {
        "school": "Champaign Early Chldhd Cntr",
        "district": "Champaign CUSD 4",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942000558",
    },
    {
        "school": "Stratton Elementary School",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942002356",
    },
    {
        "school": "Vernon L Barkstall Elementary Sch",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942002361",
    },
    {
        "school": "Franklin Middle School",
        "district": "Champaign CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942005407",
    },
    {
        "school": "South Side Elementary School",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942005409",
    },
    {
        "school": "Fisher Grade School",
        "district": "Fisher CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171518001836",
    },
    {
        "school": "Fisher Jr/Sr High School",
        "district": "Fisher CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171518001837",
    },
    {
        "school": "Gifford Grade School",
        "district": "Gifford CCSD 188",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171665001969",
    },
    {
        "school": "Ludlow Elementary School",
        "district": "Ludlow CCSD 142",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172370002590",
    },
    {
        "school": "Middletown Prairie Elementary",
        "district": "Mahomet-Seymour CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172406000683",
    },
    {
        "school": "Lincoln Trail Elem School",
        "district": "Mahomet-Seymour CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172406002626",
    },
    {
        "school": "Mahomet-Seymour High School",
        "district": "Mahomet-Seymour CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172406002627",
    },
    {
        "school": "Mahomet-Seymour Jr High School",
        "district": "Mahomet-Seymour CUSD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172406002628",
    },
    {
        "school": "Broadmeadow Elem School",
        "district": "Rantoul City SD 137",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173321003439",
    },
    {
        "school": "Eastlawn Elem School",
        "district": "Rantoul City SD 137",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173321003440",
    },
    {
        "school": "J W Eater Jr High School",
        "district": "Rantoul City SD 137",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173321003441",
    },
    {
        "school": "Northview Elem School",
        "district": "Rantoul City SD 137",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173321003443",
    },
    {
        "school": "Pleasant Acres Elem School",
        "district": "Rantoul City SD 137",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173321003444",
    },
    {
        "school": "Rantoul Twp High School",
        "district": "Rantoul Township HSD 193",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173324003445",
    },
    {
        "school": "St Joseph Elem School",
        "district": "St Joseph CCSD 169",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173738003873",
    },
    {
        "school": "St Joseph-Ogden High School",
        "district": "St Joseph Ogden CHSD 305",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173741003874",
    },
    {
        "school": "Thomasboro Grade School",
        "district": "Thomasboro CCSD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173879003945",
    },
    {
        "school": "Unity Jr High School",
        "district": "Tolono CUSD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173912003971",
    },
    {
        "school": "Unity High School",
        "district": "Tolono CUSD 7",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173912003973",
    },
    {
        "school": "Leal Elem School",
        "district": "Urbana SD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173996004011",
    },
    {
        "school": "M L King Jr Elem School",
        "district": "Urbana SD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173996004012",
    },
    {
        "school": "Dr Preston L Williams Jr Elem Sch",
        "district": "Urbana SD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173996004013",
    },
    {
        "school": "Thomas Paine Elem School",
        "district": "Urbana SD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173996004014",
    },
    {
        "school": "Urbana High School",
        "district": "Urbana SD 116",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173996004015",
    },
    {
        "school": "Urbana Middle School",
        "district": "Urbana SD 116",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173996004017",
    },
    {
        "school": "Yankee Ridge Elem School",
        "district": "Urbana SD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173996004021",
    },
    {
        "school": "Wiley Elementary School",
        "district": "Urbana SD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173996005456",
    },
    {
        "school": "Urbana Early Childhood Ctr",
        "district": "Urbana SD 116",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173996005524",
    },
    {
        "school": "Lerna Bridges",
        "district": "Clk/Cls/Cmbn/Dglas/Edgr/Mltr/Shlb",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017504660",
    },
    {
        "school": "Arland D Williams Jr Elem Sch",
        "district": "Mattoon CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172505005654",
    },
    {
        "school": "Riddle Elementary School",
        "district": "Mattoon CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172505005655",
    },
    {
        "school": "Paris Bridges",
        "district": "Clk/Cls/Cmbn/Dglas/Edgr/Mltr/Shlb",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017504659",
    },
    {
        "school": "Shelbyville Bridges",
        "district": "Clk/Cls/Cmbn/Dglas/Edgr/Mltr/Shlb",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017504672",
    },
    {
        "school": "H E L P  Marshall",
        "district": "Eastern IL Area of Spec Educ",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002300685",
    },
    {
        "school": "Treatment & Learning Center-H",
        "district": "Eastern IL Area of Spec Educ",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002304730",
    },
    {
        "school": "LIFE Academy",
        "district": "Eastern IL Area of Spec Educ",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002304731",
    },
    {
        "school": "Pathways  ROE 11",
        "district": "Clk/Cls/Cmbn/Dglas/Edgr/Mltr/Shlb",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017502384",
    },
    {
        "school": "Ashmore Elem School",
        "district": "Charleston CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170960000565",
    },
    {
        "school": "Carl Sandburg Elem School",
        "district": "Charleston CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170960000566",
    },
    {
        "school": "Charleston High School",
        "district": "Charleston CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170960000567",
    },
    {
        "school": "Charleston Middle School",
        "district": "Charleston CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170960000568",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Charleston CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170960000569",
    },
    {
        "school": "Mark Twain Elem School",
        "district": "Charleston CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170960000572",
    },
    {
        "school": "Mattoon High School",
        "district": "Mattoon CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172505002734",
    },
    {
        "school": "Mattoon Middle School",
        "district": "Mattoon CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172505002735",
    },
    {
        "school": "Lake Crest Elem School",
        "district": "Oakland CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172934003072",
    },
    {
        "school": "Oakland High School",
        "district": "Oakland CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172934003073",
    },
    {
        "school": "Neoga Jr/Sr High School",
        "district": "Neoga CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172784002952",
    },
    {
        "school": "Neoga Elementary School",
        "district": "Neoga CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172784002953",
    },
    {
        "school": "Cumberland Middle School",
        "district": "Cumberland CUSD 77",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173909003965",
    },
    {
        "school": "Cumberland High School",
        "district": "Cumberland CUSD 77",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173909003966",
    },
    {
        "school": "Cumberland Elem School",
        "district": "Cumberland CUSD 77",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173909004855",
    },
    {
        "school": "Treatment & Learning Center",
        "district": "Eastern IL Area of Spec Educ",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002305042",
    },
    {
        "school": "Fresh Start Treatment & Learning",
        "district": "Eastern IL Area of Spec Educ",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002301922",
    },
    {
        "school": "North Shore Academy Elem",
        "district": "Northern Suburban Spec Ed Dist",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003105831",
    },
    {
        "school": "Ed & Life Skills Transition",
        "district": "Northern Suburban Spec Ed Dist",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003105832",
    },
    {
        "school": "West 40 Reg Safe Sch Middle Prg",
        "district": "Region 06 West Cook ISC 2",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170022104691",
    },
    {
        "school": "Harbor Academy Reg Safe Sch Prg",
        "district": "Region 06 West Cook ISC 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170022104694",
    },
    {
        "school": "Morton Alternative Schools",
        "district": "Region 06 West Cook ISC 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170022104700",
    },
    {
        "school": "Park School",
        "district": "Evanston Dists 65/202 Jnt Agr",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170024604578",
    },
    {
        "school": "Julia S Molloy Education Center",
        "district": "Niles Twp District for Spec Educ",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170025504690",
    },
    {
        "school": "Care Program",
        "district": "Eisenhower Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170031205028",
    },
    {
        "school": "Developmental Learning Pgm   DLP",
        "district": "Eisenhower Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170031205037",
    },
    {
        "school": "Newcomer Center",
        "district": "Township HSD 214",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170417004679",
    },
    {
        "school": "Freedom Middle School",
        "district": "Berwyn South SD 100",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170609005026",
    },
    {
        "school": "Geo T Wilkins Jr High School",
        "district": "Indian Springs SD 109",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170717004585",
    },
    {
        "school": "River Valley School",
        "district": "Lemont-Bromberek CSD 113A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170729005661",
    },
    {
        "school": "Phoenix Military Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004715",
    },
    {
        "school": "Ashburn Community Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004718",
    },
    {
        "school": "Belmont-Cragin Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004720",
    },
    {
        "school": "National Teachers Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004722",
    },
    {
        "school": "Talman Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004726",
    },
    {
        "school": "Chicago Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005061",
    },
    {
        "school": "Bowen High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005072",
    },
    {
        "school": "North-Grand High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005074",
    },
    {
        "school": "Raby High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005075",
    },
    {
        "school": "Clark Acad Prep Magnet High Schl",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005076",
    },
    {
        "school": "Rickover Naval Academy High Schl",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005078",
    },
    {
        "school": "Chicago Math & Sci Elem Charter",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005092",
    },
    {
        "school": "Namaste Elem Charter School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005102",
    },
    {
        "school": "Claremont Academy Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005109",
    },
    {
        "school": "James R Doolittle Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005167",
    },
    {
        "school": "Spry Community Links High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005677",
    },
    {
        "school": "Asian Human Srvcs-Passage Chrtr",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005682",
    },
    {
        "school": "New Field Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005687",
    },
    {
        "school": "Durkin Park Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005690",
    },
    {
        "school": "Calmeca Acad Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005691",
    },
    {
        "school": "North River Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005692",
    },
    {
        "school": "Uplift Community High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005787",
    },
    {
        "school": "World Language High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005788",
    },
    {
        "school": "Douglass Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005789",
    },
    {
        "school": "Devry Advantage Academy High Schl",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005790",
    },
    {
        "school": "Lindblom Math & Science Acad HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005791",
    },
    {
        "school": "Bronzeville Scholastic HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005792",
    },
    {
        "school": "School of Social Justice HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005793",
    },
    {
        "school": "Multicultural Acad Scholarshp HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005794",
    },
    {
        "school": "Infinity Math  Science & Tech HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005795",
    },
    {
        "school": "Erie Elem Charter School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005797",
    },
    {
        "school": "Legacy Elem Charter School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005799",
    },
    {
        "school": "Suder Montessori Elem Magnet Schl",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005801",
    },
    {
        "school": "Tarkington Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005803",
    },
    {
        "school": "Woodrow Wilson Elem School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020005025",
    },
    {
        "school": "Unity Jr High School",
        "district": "Cicero SD 99",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020005660",
    },
    {
        "school": "New Beginnings Learning Academy",
        "district": "Dolton SD 149",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171242005043",
    },
    {
        "school": "Washington Junior High",
        "district": "Dolton SD 148",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171245005040",
    },
    {
        "school": "Liberty Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371004792",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371005613",
    },
    {
        "school": "Ridge Family Center for Learning",
        "district": "Comm Cons SD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377004568",
    },
    {
        "school": "Early Childhood Center",
        "district": "Elmwood Park CUSD 401",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171410004687",
    },
    {
        "school": "Joseph E Hill Education Center",
        "district": "Evanston CCSD 65",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446004569",
    },
    {
        "school": "Attea Middle School",
        "district": "Glenview CCSD 34",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171692005657",
    },
    {
        "school": "J Sterling Morton Freshman Cntr",
        "district": "J S Morton HSD 201",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172688005044",
    },
    {
        "school": "Niles Central",
        "district": "Niles Twp HSD 219",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172853005783",
    },
    {
        "school": "Glenbrook Off-Campus Center",
        "district": "Northfield Twp HSD 225",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172901005784",
    },
    {
        "school": "Gwendolyn Brooks Middle School",
        "district": "Oak Park ESD 97",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172925004581",
    },
    {
        "school": "Percy Julian Middle School",
        "district": "Oak Park ESD 97",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172925004582",
    },
    {
        "school": "Winston Campus Jr High",
        "district": "Palatine CCSD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042005020",
    },
    {
        "school": "Proviso Math and Science Academy",
        "district": "Proviso Twp HSD 209",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173291005781",
    },
    {
        "school": "Liberty Junior High School",
        "district": "Burbank SD 111",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173681005027",
    },
    {
        "school": "Genoa Elementary School",
        "district": "Genoa Kingston CUSD 424",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171641005693",
    },
    {
        "school": "Herman E Dummer",
        "district": "Sandwich CUSD 430",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173537004741",
    },
    {
        "school": "DuPage Alop",
        "district": "DuPage ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017905696",
    },
    {
        "school": "Henry Puffer School",
        "district": "Downers Grove GSD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254005197",
    },
    {
        "school": "Hawk Hollow Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371004794",
    },
    {
        "school": "Norton Creek Elementary School",
        "district": "St Charles CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717005708",
    },
    {
        "school": "Owen Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169005697",
    },
    {
        "school": "Winfield Central School",
        "district": "Winfield SD 34",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174272005191",
    },
    {
        "school": "Early Childhood Dev Cntr",
        "district": "Aurora East USD 131",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468005826",
    },
    {
        "school": "Herget Middle School",
        "district": "Aurora West USD 129",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471005616",
    },
    {
        "school": "Algonquin Lakes Elem Sch",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855004800",
    },
    {
        "school": "Liberty Elementary School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855004802",
    },
    {
        "school": "Otter Creek Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371004797",
    },
    {
        "school": "South Elgin High School",
        "district": "SD U-46",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371005611",
    },
    {
        "school": "Kenyon Woods Middle School",
        "district": "SD U-46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371005612",
    },
    {
        "school": "Hilltop Elementary School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371005614",
    },
    {
        "school": "Timber Trails Elementary School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371005615",
    },
    {
        "school": "Heartland Elementary School",
        "district": "Geneva CUSD 304",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171638004805",
    },
    {
        "school": "Kaneland Blackberry Creek Elem",
        "district": "Kaneland CUSD 302",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172448005617",
    },
    {
        "school": "Kaneland McDole Elem School",
        "district": "Kaneland CUSD 302",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172448005618",
    },
    {
        "school": "Corron Elementary School",
        "district": "St Charles CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717005707",
    },
    {
        "school": "Oswego East High School",
        "district": "CUSD 308",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027005337",
    },
    {
        "school": "Prairie Point Elem School",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027005344",
    },
    {
        "school": "Churchill Elem School",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027005365",
    },
    {
        "school": "Lakewood Creek Elementary",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027005698",
    },
    {
        "school": "Yorkville Intermediate School",
        "district": "Yorkville CUSD 115",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396005211",
    },
    {
        "school": "Arbor Academy",
        "district": "Northern Suburban Spec Ed Dist",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003105833",
    },
    {
        "school": "Neal Math Science Academy",
        "district": "North Chicago SD 187",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011004813",
    },
    {
        "school": "A J Katzenmaier Academy",
        "district": "North Chicago SD 187",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011004814",
    },
    {
        "school": "Evelyn Alexander School",
        "district": "North Chicago SD 187",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011004815",
    },
    {
        "school": "Lake Co Collaborative Alop",
        "district": "Lake ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019305829",
    },
    {
        "school": "Lakes Community High School",
        "district": "CHSD 117",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170387005622",
    },
    {
        "school": "Prairieview School",
        "district": "Grayslake CCSD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171752004810",
    },
    {
        "school": "Grayslake North High School",
        "district": "Grayslake CHSD 127",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171755005623",
    },
    {
        "school": "River Trail School",
        "district": "Gurnee SD 56",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171780005712",
    },
    {
        "school": "Olive C Martin School",
        "district": "Lake Villa CCSD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172187004809",
    },
    {
        "school": "Spencer Loomis Elementary School",
        "district": "Lake Zurich CUSD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172190005713",
    },
    {
        "school": "Millburn Middle School",
        "district": "Millburn CCSD 24",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172610005621",
    },
    {
        "school": "Lincoln Prairie Elem School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855004804",
    },
    {
        "school": "Martin Elementary School",
        "district": "Huntley Comm Sch Dist 158",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171983004840",
    },
    {
        "school": "Heineman Middle School",
        "district": "Huntley Comm Sch Dist 158",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171983005640",
    },
    {
        "school": "Marlowe Middle School",
        "district": "Huntley Comm Sch Dist 158",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171983005641",
    },
    {
        "school": "Mackeben Elementary School",
        "district": "Huntley Comm Sch Dist 158",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171983005733",
    },
    {
        "school": "Conley Elementary School",
        "district": "Huntley Comm Sch Dist 158",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171983005734",
    },
    {
        "school": "Lincoln School RSSP",
        "district": "Will ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170021304927",
    },
    {
        "school": "Pioneer Path",
        "district": "Channahon SD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170954005729",
    },
    {
        "school": "Fairmont School",
        "district": "Fairmont SD 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171476004930",
    },
    {
        "school": "Carl Sandburg Elementary",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058004928",
    },
    {
        "school": "Thompson Instructional Center",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058004929",
    },
    {
        "school": "Sator Sanchez Elem School",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058005730",
    },
    {
        "school": "Lynne Thigpen Elem School",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058005731",
    },
    {
        "school": "Ludwig Elem School",
        "district": "Will County SD 92",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172373004931",
    },
    {
        "school": "Walnut Trails Elem School",
        "district": "Minooka CCSD 201",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172631005199",
    },
    {
        "school": "Liberty Junior High School",
        "district": "New Lenox SD 122",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814004933",
    },
    {
        "school": "Bednarcik Junior High School",
        "district": "CUSD 308",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027004768",
    },
    {
        "school": "Homestead Elementary School",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027004769",
    },
    {
        "school": "Wolfs Crossing Elem School",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027005457",
    },
    {
        "school": "Drauden Point Middle School",
        "district": "Plainfield SD 202",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174004935",
    },
    {
        "school": "Ridge Elementary School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174004938",
    },
    {
        "school": "Eagle Pointe Elementary School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174004941",
    },
    {
        "school": "Plainfield Academy",
        "district": "Plainfield SD 202",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174004942",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174005732",
    },
    {
        "school": "Plainfield North High School",
        "district": "Plainfield SD 202",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174005747",
    },
    {
        "school": "Richard Ira Jones Middle School",
        "district": "Plainfield SD 202",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174005748",
    },
    {
        "school": "Charles Reed Elementary Sch",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174005749",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174005750",
    },
    {
        "school": "Bernard J Ward Elem School",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007005751",
    },
    {
        "school": "Skoff Elementary",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007005752",
    },
    {
        "school": "A E R O Educational Center",
        "district": "A E R O  Spec Educ Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002404632",
    },
    {
        "school": "P R I D E School",
        "district": "A E R O  Spec Educ Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002404633",
    },
    {
        "school": "Speed Program for Adaptive Learn",
        "district": "Speed SEJA #802",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002901305",
    },
    {
        "school": "Speed Independence High School",
        "district": "Speed SEJA #802",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002901314",
    },
    {
        "school": "Speed Independence Elem Sch",
        "district": "Speed SEJA #802",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002901323",
    },
    {
        "school": "Speed Early Learning Center",
        "district": "Speed SEJA #802",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002904498",
    },
    {
        "school": "PAEC Education Center  EC",
        "district": "Proviso Area Exceptional Child",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003001966",
    },
    {
        "school": "PAEC Alternative Elementary",
        "district": "Proviso Area Exceptional Child",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003004485",
    },
    {
        "school": "PAEC Alternative High School",
        "district": "Proviso Area Exceptional Child",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003004486",
    },
    {
        "school": "Proviso Area Except Child Center",
        "district": "Proviso Area Exceptional Child",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003004490",
    },
    {
        "school": "James Whitcomb Riley School",
        "district": "NW Suburban Spec Educ Org",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003201603",
    },
    {
        "school": "Timber Ridge School",
        "district": "NW Suburban Spec Educ Org",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003203950",
    },
    {
        "school": "Kirk School",
        "district": "NW Suburban Spec Educ Org",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003205094",
    },
    {
        "school": "Miner School",
        "district": "NW Suburban Spec Educ Org",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003205095",
    },
    {
        "school": "Regl Inst Scholastic Excellence",
        "district": "Region 07 South Cook ISC 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170018802593",
    },
    {
        "school": "North Cook Young Adult Academy",
        "district": "Region 05 North Cook ISC 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170022003951",
    },
    {
        "school": "Hazelgreen Elem School",
        "district": "Alsip-Hazlgrn-Oaklwn SD 126",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170348000028",
    },
    {
        "school": "Lane Elem School",
        "district": "Alsip-Hazlgrn-Oaklwn SD 126",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170348000029",
    },
    {
        "school": "Stony Creek Elem School",
        "district": "Alsip-Hazlgrn-Oaklwn SD 126",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170348000030",
    },
    {
        "school": "Prairie Jr High School",
        "district": "Alsip-Hazlgrn-Oaklwn SD 126",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170348000031",
    },
    {
        "school": "Arbor Park Middle School",
        "district": "Arbor Park SD 145",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170393000078",
    },
    {
        "school": "Kimberly Heights Elem School",
        "district": "Arbor Park SD 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170393000079",
    },
    {
        "school": "Morton Gingerwood Elem School",
        "district": "Arbor Park SD 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170393000080",
    },
    {
        "school": "Scarlet Oak Elem School",
        "district": "Arbor Park SD 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170393000081",
    },
    {
        "school": "Argo Community High School",
        "district": "Argo CHSD 217",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170402000088",
    },
    {
        "school": "Dr Donald Wharton Elem School",
        "district": "Summit SD 104",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170405000089",
    },
    {
        "school": "Heritage Middle School",
        "district": "Summit SD 104",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170405000090",
    },
    {
        "school": "Otis P Graves Elem School",
        "district": "Summit SD 104",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170405000091",
    },
    {
        "school": "W W Walker Elem School",
        "district": "Summit SD 104",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170405000092",
    },
    {
        "school": "Walsh Elem School",
        "district": "Summit SD 104",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170405000093",
    },
    {
        "school": "Dryden Elem School",
        "district": "Arlington Heights SD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170414000095",
    },
    {
        "school": "Greenbrier Elem School",
        "district": "Arlington Heights SD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170414000096",
    },
    {
        "school": "Ivy Hill Elem School",
        "district": "Arlington Heights SD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170414000097",
    },
    {
        "school": "Olive-Mary Stitt School",
        "district": "Arlington Heights SD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170414000098",
    },
    {
        "school": "Patton Elem School",
        "district": "Arlington Heights SD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170414000099",
    },
    {
        "school": "Westgate Elem School",
        "district": "Arlington Heights SD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170414000100",
    },
    {
        "school": "Windsor Elementary School",
        "district": "Arlington Heights SD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170414000101",
    },
    {
        "school": "South Middle School",
        "district": "Arlington Heights SD 25",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170414000105",
    },
    {
        "school": "Thomas Middle School",
        "district": "Arlington Heights SD 25",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170414000106",
    },
    {
        "school": "Young Adult Program",
        "district": "Township HSD 214",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170417000036",
    },
    {
        "school": "Buffalo Grove High School",
        "district": "Township HSD 214",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170417000110",
    },
    {
        "school": "Elk Grove High School",
        "district": "Township HSD 214",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170417000111",
    },
    {
        "school": "John Hersey High School",
        "district": "Township HSD 214",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170417000113",
    },
    {
        "school": "Prospect High School",
        "district": "Township HSD 214",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170417000114",
    },
    {
        "school": "Rolling Meadows High School",
        "district": "Township HSD 214",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170417000115",
    },
    {
        "school": "The Academy at Forest View",
        "district": "Township HSD 214",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170417000116",
    },
    {
        "school": "Wheeling High School",
        "district": "Township HSD 214",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170417000117",
    },
    {
        "school": "Vanguard School",
        "district": "Township HSD 214",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170417001965",
    },
    {
        "school": "Hamlin Upper Grade Center",
        "district": "Atwood Heights SD 125",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170456000135",
    },
    {
        "school": "Lawn Manor School",
        "district": "Atwood Heights SD 125",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170456000136",
    },
    {
        "school": "Meadow Lane School",
        "district": "Atwood Heights SD 125",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170456000137",
    },
    {
        "school": "Marie Murphy School",
        "district": "Avoca SD 37",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170480000043",
    },
    {
        "school": "Avoca West Elem School",
        "district": "Avoca SD 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170480000177",
    },
    {
        "school": "Barrington Mdle Sch- Prairie Cmps",
        "district": "Barrington CUSD 220",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505000044",
    },
    {
        "school": "Hough Street Elem School",
        "district": "Barrington CUSD 220",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505000190",
    },
    {
        "school": "Barrington Middle Sch Station",
        "district": "Barrington CUSD 220",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505000192",
    },
    {
        "school": "Arnett C Lines Elem School",
        "district": "Barrington CUSD 220",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505000195",
    },
    {
        "school": "Grove Avenue Elem School",
        "district": "Barrington CUSD 220",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505000196",
    },
    {
        "school": "Barbara B Rose Elem School",
        "district": "Barrington CUSD 220",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505002987",
    },
    {
        "school": "Grant Elem School",
        "district": "Bellwood SD 88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170576000247",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Bellwood SD 88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170576000248",
    },
    {
        "school": "McKinley Elem School",
        "district": "Bellwood SD 88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170576000250",
    },
    {
        "school": "Thurgood Marshall Elem School",
        "district": "Bellwood SD 88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170576000251",
    },
    {
        "school": "Roosevelt Middle School",
        "district": "Bellwood SD 88",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170576000253",
    },
    {
        "school": "Grant Primary",
        "district": "Bellwood SD 88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170576005264",
    },
    {
        "school": "MacArthur Middle School",
        "district": "Berkeley SD 87",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170600000279",
    },
    {
        "school": "J W Riley Intermediate School",
        "district": "Berkeley SD 87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170600000280",
    },
    {
        "school": "Northlake Middle School",
        "district": "Berkeley SD 87",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170600000281",
    },
    {
        "school": "Sunnyside Intermediate School",
        "district": "Berkeley SD 87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170600000282",
    },
    {
        "school": "Jefferson Primary School",
        "district": "Berkeley SD 87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170600000283",
    },
    {
        "school": "Whittier Primary School",
        "district": "Berkeley SD 87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170600000284",
    },
    {
        "school": "Prairie Oak School",
        "district": "Berwyn North SD 98",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170606000285",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Berwyn North SD 98",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170606000286",
    },
    {
        "school": "Karel Havlicek Elem School",
        "district": "Berwyn North SD 98",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170606000287",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Berwyn North SD 98",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170606000288",
    },
    {
        "school": "Emerson Elem School",
        "district": "Berwyn South SD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170609000289",
    },
    {
        "school": "Irving Elem School",
        "district": "Berwyn South SD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170609000291",
    },
    {
        "school": "Komensky Elem School",
        "district": "Berwyn South SD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170609000292",
    },
    {
        "school": "Pershing Elem School",
        "district": "Berwyn South SD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170609000293",
    },
    {
        "school": "Heritage Middle School",
        "district": "Berwyn South SD 100",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170609003422",
    },
    {
        "school": "Hiawatha Elem School",
        "district": "Berwyn South SD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170609003423",
    },
    {
        "school": "Piper School",
        "district": "Berwyn South SD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170609005296",
    },
    {
        "school": "Bloom High School",
        "district": "Bloom Twp HSD 206",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170642000312",
    },
    {
        "school": "Bloom Trail High School",
        "district": "Bloom Twp HSD 206",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170642000313",
    },
    {
        "school": "Dist 206 Alternative High School",
        "district": "Bloom Twp HSD 206",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170642004546",
    },
    {
        "school": "Everett F Kerr Middle School",
        "district": "Cook County SD 130",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170651000328",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Cook County SD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170651000332",
    },
    {
        "school": "Nathan Hale Intermediate",
        "district": "Cook County SD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170651000333",
    },
    {
        "school": "Nathan Hale Middle School",
        "district": "Cook County SD 130",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170651000334",
    },
    {
        "school": "Nathan Hale Primary School",
        "district": "Cook County SD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170651000335",
    },
    {
        "school": "Paul Revere Intermediate School",
        "district": "Cook County SD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170651000336",
    },
    {
        "school": "Whittier Elementary School",
        "district": "Cook County SD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170651000338",
    },
    {
        "school": "Veterans Memorial Middle Sch",
        "district": "Cook County SD 130",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170651004244",
    },
    {
        "school": "Paul Revere Primary School",
        "district": "Cook County SD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170651004251",
    },
    {
        "school": "George Washington Elementary Sch",
        "district": "Cook County SD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170651004253",
    },
    {
        "school": "Horace Mann School",
        "district": "Cook County SD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170651005401",
    },
    {
        "school": "A B Shepard High Sch (Campus)",
        "district": "CHSD 218",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170654000339",
    },
    {
        "school": "DD Eisenhower High Sch (Campus)",
        "district": "CHSD 218",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170654000342",
    },
    {
        "school": "H L Richards High Sch(Campus)",
        "district": "CHSD 218",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170654000343",
    },
    {
        "school": "Delta Learning Center",
        "district": "CHSD 218",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170654000747",
    },
    {
        "school": "Bremen High School",
        "district": "Bremen CHSD 228",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170705000364",
    },
    {
        "school": "Hillcrest High School",
        "district": "Bremen CHSD 228",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170705000365",
    },
    {
        "school": "Oak Forest High School",
        "district": "Bremen CHSD 228",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170705000366",
    },
    {
        "school": "Tinley Park High School",
        "district": "Bremen CHSD 228",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170705000367",
    },
    {
        "school": "Bridgeview Elem School",
        "district": "Indian Springs SD 109",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170717000368",
    },
    {
        "school": "Frank A Brodnicki Elem School",
        "district": "Indian Springs SD 109",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170717000369",
    },
    {
        "school": "George T Wilkins Elem School",
        "district": "Indian Springs SD 109",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170717000371",
    },
    {
        "school": "Robina Lyle Elementary School",
        "district": "Indian Springs SD 109",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170717000372",
    },
    {
        "school": "Old Quarry Middle Sch",
        "district": "Lemont-Bromberek CSD 113A",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170729001933",
    },
    {
        "school": "Oakwood School",
        "district": "Lemont-Bromberek CSD 113A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170729002507",
    },
    {
        "school": "Brook Park Elem School",
        "district": "Brookfield Lagrange Park SD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170732000380",
    },
    {
        "school": "S E Gross  Middle School",
        "district": "Brookfield Lagrange Park SD 95",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170732000727",
    },
    {
        "school": "Burnham Elem School",
        "district": "Burnham SD 154-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170786000400",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Lincoln ESD 156",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170810000425",
    },
    {
        "school": "Burr Oak Elem School",
        "district": "Calumet Public SD 132",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170813000426",
    },
    {
        "school": "Calumet Elem School",
        "district": "Calumet Public SD 132",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170813000427",
    },
    {
        "school": "Burr Oak Academy",
        "district": "Calumet Public SD 132",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170813005144",
    },
    {
        "school": "Amos Alonzo Stagg High School",
        "district": "Cons HSD 230",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170840000458",
    },
    {
        "school": "Carl Sandburg High School",
        "district": "Cons HSD 230",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170840000459",
    },
    {
        "school": "Victor J Andrew High School",
        "district": "Cons HSD 230",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170840000460",
    },
    {
        "school": "Logandale Middle School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000048",
    },
    {
        "school": "Chavez Elem Multicultural Acad Ct",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000411",
    },
    {
        "school": "Jordan Elem Community School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000441",
    },
    {
        "school": "Audubon Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000581",
    },
    {
        "school": "Avalon Park Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000582",
    },
    {
        "school": "Barnard Elem Comp Math & Sci Ctr",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000585",
    },
    {
        "school": "Barry Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000586",
    },
    {
        "school": "Amundsen High School",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000587",
    },
    {
        "school": "Dunbar Vocational Career Acad HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000588",
    },
    {
        "school": "Barton Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000589",
    },
    {
        "school": "Bass Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000590",
    },
    {
        "school": "Bateman Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000591",
    },
    {
        "school": "Nicholson Tech Acad Elem Sch",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000597",
    },
    {
        "school": "Beaubien Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000601",
    },
    {
        "school": "Beethoven Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000602",
    },
    {
        "school": "Beidler Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000603",
    },
    {
        "school": "Belding Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000604",
    },
    {
        "school": "Bell Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000605",
    },
    {
        "school": "Bennett Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000607",
    },
    {
        "school": "Black Magnet Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000609",
    },
    {
        "school": "Blaine Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000610",
    },
    {
        "school": "Bond Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000611",
    },
    {
        "school": "Boone Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000612",
    },
    {
        "school": "Bradwell Comm Arts & Sci Elem Sch",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000614",
    },
    {
        "school": "Haley Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000615",
    },
    {
        "school": "Brennemann Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000616",
    },
    {
        "school": "Brentano Elem Math & Science Acad",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000617",
    },
    {
        "school": "Bridge Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000618",
    },
    {
        "school": "Bright Elem School",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000619",
    },
    {
        "school": "Brown  W Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000621",
    },
    {
        "school": "Brownell Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000622",
    },
    {
        "school": "Bouchet Elem Math & Science Acad",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000623",
    },
    {
        "school": "Budlong Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000625",
    },
    {
        "school": "Bogan High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000626",
    },
    {
        "school": "Burbank Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000627",
    },
    {
        "school": "Turner-Drew Elem Language Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000628",
    },
    {
        "school": "Burke Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000629",
    },
    {
        "school": "Burley Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000632",
    },
    {
        "school": "Burnham Elem Inclusive Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000633",
    },
    {
        "school": "Burnside Elem Scholastic Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000635",
    },
    {
        "school": "Burr Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000636",
    },
    {
        "school": "Burroughs Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000637",
    },
    {
        "school": "Brunson Math & Sci Specialty Elem",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000638",
    },
    {
        "school": "Byrne Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000640",
    },
    {
        "school": "Caldwell Elem Acad of Math & Sci",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000641",
    },
    {
        "school": "De Diego Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000643",
    },
    {
        "school": "Cameron Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000646",
    },
    {
        "school": "Canty Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000647",
    },
    {
        "school": "Carnegie Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000648",
    },
    {
        "school": "Curtis Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000650",
    },
    {
        "school": "Mays Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000651",
    },
    {
        "school": "Carroll Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000652",
    },
    {
        "school": "Carter Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000653",
    },
    {
        "school": "Cassell Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000655",
    },
    {
        "school": "Cather Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000656",
    },
    {
        "school": "Chalmers Elem Specialty School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000657",
    },
    {
        "school": "Chappell Elem School",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000658",
    },
    {
        "school": "Chase Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000659",
    },
    {
        "school": "Clay Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000661",
    },
    {
        "school": "Cleveland Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000663",
    },
    {
        "school": "Clinton Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000664",
    },
    {
        "school": "Clissold Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000665",
    },
    {
        "school": "Coles Elem Language Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000666",
    },
    {
        "school": "Beasley Elem Magnet Academic Ctr",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000668",
    },
    {
        "school": "Columbus Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000669",
    },
    {
        "school": "Carver Military Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000671",
    },
    {
        "school": "Cook Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000672",
    },
    {
        "school": "Coonley Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000674",
    },
    {
        "school": "Metcalfe Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000675",
    },
    {
        "school": "Cooper Elem Dual Language Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000676",
    },
    {
        "school": "Corkery Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000677",
    },
    {
        "school": "Crown Elem Comm Acd Fine Arts Ctr",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000678",
    },
    {
        "school": "Darwin Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000679",
    },
    {
        "school": "Prosser Career Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000681",
    },
    {
        "school": "Dulles Elem School",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000682",
    },
    {
        "school": "Davis N Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000687",
    },
    {
        "school": "Dawes Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000689",
    },
    {
        "school": "Deneen Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000691",
    },
    {
        "school": "Decatur Classical Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000692",
    },
    {
        "school": "Cook Co Juvenile Det -York Alt HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000693",
    },
    {
        "school": "Robinson Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000694",
    },
    {
        "school": "Dett Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000695",
    },
    {
        "school": "Chopin Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000697",
    },
    {
        "school": "Dever Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000698",
    },
    {
        "school": "Dewey Elem Academy of Fine Arts",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000706",
    },
    {
        "school": "Disney Elem Magnet School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000709",
    },
    {
        "school": "Dixon Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000710",
    },
    {
        "school": "Garvey  M Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000712",
    },
    {
        "school": "Young Magnet High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000714",
    },
    {
        "school": "Richards Career Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000718",
    },
    {
        "school": "Hanson Park Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000720",
    },
    {
        "school": "Juarez Community Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000722",
    },
    {
        "school": "Dore Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000725",
    },
    {
        "school": "Drake Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000728",
    },
    {
        "school": "Drummond Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000729",
    },
    {
        "school": "Leland Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000730",
    },
    {
        "school": "Dubois Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000731",
    },
    {
        "school": "Dunne Technology Acad Elem Sch",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000734",
    },
    {
        "school": "Dvorak Technology Acad Elem Sch",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000737",
    },
    {
        "school": "Earle Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000738",
    },
    {
        "school": "Eberhart Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000739",
    },
    {
        "school": "Ebinger Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000741",
    },
    {
        "school": "Edgebrook Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000743",
    },
    {
        "school": "Edwards Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000744",
    },
    {
        "school": "Gunsaulus Elem Scholastic Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000745",
    },
    {
        "school": "Ellington Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000748",
    },
    {
        "school": "Ericson Elem Scholastic Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000752",
    },
    {
        "school": "Esmond Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000753",
    },
    {
        "school": "Everett Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000755",
    },
    {
        "school": "Evers Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000757",
    },
    {
        "school": "Simeon Career Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000758",
    },
    {
        "school": "Falconer Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000759",
    },
    {
        "school": "Kellman Corporate Community Elem",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000760",
    },
    {
        "school": "Faraday Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000762",
    },
    {
        "school": "Agassiz Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000763",
    },
    {
        "school": "Farnsworth Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000764",
    },
    {
        "school": "Randolph Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000769",
    },
    {
        "school": "Fernwood Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000770",
    },
    {
        "school": "Field Elem School",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000771",
    },
    {
        "school": "Fiske Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000773",
    },
    {
        "school": "Fort Dearborn Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000774",
    },
    {
        "school": "Franklin Elem Fine Arts Center",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000777",
    },
    {
        "school": "Fuller Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000778",
    },
    {
        "school": "Fulton Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000780",
    },
    {
        "school": "Funston Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000781",
    },
    {
        "school": "Gale Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000782",
    },
    {
        "school": "Gallistel Elem Language Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000783",
    },
    {
        "school": "Garvy  J Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000784",
    },
    {
        "school": "Gary Elem School",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000785",
    },
    {
        "school": "Kanoon Elem Magnet School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000787",
    },
    {
        "school": "Farragut Career Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000788",
    },
    {
        "school": "Fenger Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000792",
    },
    {
        "school": "Goethe Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000794",
    },
    {
        "school": "Owens Community Academy ES",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000796",
    },
    {
        "school": "Goudy Technology Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000797",
    },
    {
        "school": "Foreman High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000799",
    },
    {
        "school": "Graham  A Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000800",
    },
    {
        "school": "White Elem Career Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000801",
    },
    {
        "school": "Gray Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000803",
    },
    {
        "school": "Alcott Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000804",
    },
    {
        "school": "Greeley Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000805",
    },
    {
        "school": "Greene N Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000806",
    },
    {
        "school": "Gregory Math & Sci Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000807",
    },
    {
        "school": "Grissom Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000808",
    },
    {
        "school": "Gage Park High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000809",
    },
    {
        "school": "Gresham Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000811",
    },
    {
        "school": "Grimes Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000812",
    },
    {
        "school": "Haines Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000815",
    },
    {
        "school": "Gillespie Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000816",
    },
    {
        "school": "Hendricks Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000817",
    },
    {
        "school": "Hale Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000819",
    },
    {
        "school": "Hamilton Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000822",
    },
    {
        "school": "Hamline Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000823",
    },
    {
        "school": "Hammond Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000824",
    },
    {
        "school": "Bret Harte Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000826",
    },
    {
        "school": "Harvard Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000830",
    },
    {
        "school": "Haugan Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000831",
    },
    {
        "school": "Hawthorne Elem Scholastic Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000832",
    },
    {
        "school": "Hayt Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000834",
    },
    {
        "school": "Healy Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000835",
    },
    {
        "school": "Hearst Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000836",
    },
    {
        "school": "Hedges Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000837",
    },
    {
        "school": "McDowell Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000839",
    },
    {
        "school": "Hefferan Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000840",
    },
    {
        "school": "Henderson Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000842",
    },
    {
        "school": "Henry Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000844",
    },
    {
        "school": "Herzl Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000847",
    },
    {
        "school": "Harlan Community Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000851",
    },
    {
        "school": "Harper High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000852",
    },
    {
        "school": "Hibbard Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000854",
    },
    {
        "school": "Higgins Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000855",
    },
    {
        "school": "King Academy of Social Justice",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000856",
    },
    {
        "school": "Hitch Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000857",
    },
    {
        "school": "Holden Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000858",
    },
    {
        "school": "Earhart Elem Opt for Knowl School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000859",
    },
    {
        "school": "Keller Elem Gifted Magnet School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000860",
    },
    {
        "school": "Holmes Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000861",
    },
    {
        "school": "Howe Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000862",
    },
    {
        "school": "Hoyne Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000864",
    },
    {
        "school": "Hughes  C Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000865",
    },
    {
        "school": "Hurley Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000866",
    },
    {
        "school": "Irving Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000867",
    },
    {
        "school": "Jackson A Elem Language Acad",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000868",
    },
    {
        "school": "Jahn Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000869",
    },
    {
        "school": "Jamieson Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000870",
    },
    {
        "school": "Jensen Elem Scholastic Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000875",
    },
    {
        "school": "Pilsen Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000878",
    },
    {
        "school": "Hirsch Metropolitan High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000879",
    },
    {
        "school": "Johnson Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000880",
    },
    {
        "school": "Jungman Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000881",
    },
    {
        "school": "Kellogg Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000882",
    },
    {
        "school": "Kershaw Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000883",
    },
    {
        "school": "Addams Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000884",
    },
    {
        "school": "Kilmer Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000886",
    },
    {
        "school": "Poe Elem Classical School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000888",
    },
    {
        "school": "Hubbard High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000889",
    },
    {
        "school": "Kinzie Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000890",
    },
    {
        "school": "Kipling Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000892",
    },
    {
        "school": "Hyde Park Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000893",
    },
    {
        "school": "Cook Co Juvenile-Jefferson Alt HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000894",
    },
    {
        "school": "Julian High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000895",
    },
    {
        "school": "Wildwood Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000898",
    },
    {
        "school": "Hughes L Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000899",
    },
    {
        "school": "Lozano Elem Bilingual & Intl Ctr",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000901",
    },
    {
        "school": "Kozminski Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000903",
    },
    {
        "school": "LaSalle Elem Language Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000905",
    },
    {
        "school": "Lawndale Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000907",
    },
    {
        "school": "Lewis Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000911",
    },
    {
        "school": "Courtenay Elem Language Arts Ctr",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000914",
    },
    {
        "school": "Libby Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000916",
    },
    {
        "school": "Lincoln Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000918",
    },
    {
        "school": "Linne Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000919",
    },
    {
        "school": "Kelly High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000920",
    },
    {
        "school": "Kelvyn Park High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000923",
    },
    {
        "school": "Kennedy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000924",
    },
    {
        "school": "Kenwood Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000925",
    },
    {
        "school": "Lloyd Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000926",
    },
    {
        "school": "Locke  J Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000927",
    },
    {
        "school": "Smith  W Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000928",
    },
    {
        "school": "Lovett Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000929",
    },
    {
        "school": "Lowell Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000930",
    },
    {
        "school": "King College Prep High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000931",
    },
    {
        "school": "Lyon Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000934",
    },
    {
        "school": "Madison Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000935",
    },
    {
        "school": "Manierre Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000936",
    },
    {
        "school": "Mann Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000937",
    },
    {
        "school": "Marsh Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000939",
    },
    {
        "school": "Marquette Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000940",
    },
    {
        "school": "Lake View High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000941",
    },
    {
        "school": "Lane Technical High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000942",
    },
    {
        "school": "Chicago Vocational Career Acad HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000943",
    },
    {
        "school": "Mason Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000944",
    },
    {
        "school": "Mayer Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000950",
    },
    {
        "school": "McClellan Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000952",
    },
    {
        "school": "McCormick Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000955",
    },
    {
        "school": "McCutcheon Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000956",
    },
    {
        "school": "McDade Elem Classical School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000957",
    },
    {
        "school": "McKay Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000958",
    },
    {
        "school": "McPherson Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000959",
    },
    {
        "school": "Melody Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000963",
    },
    {
        "school": "Talcott Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000964",
    },
    {
        "school": "Mitchell Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000965",
    },
    {
        "school": "Mollison Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000966",
    },
    {
        "school": "Monroe Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000968",
    },
    {
        "school": "Moos Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000969",
    },
    {
        "school": "Morrill Elem Math & Sci School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000970",
    },
    {
        "school": "Inter-American Elem Magnet School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000971",
    },
    {
        "school": "Marshall Metropolitan High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000972",
    },
    {
        "school": "Mount Greenwood Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000974",
    },
    {
        "school": "Mather High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000977",
    },
    {
        "school": "Mount Vernon Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000978",
    },
    {
        "school": "Mozart Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000979",
    },
    {
        "school": "Brown R Elem Community Acad",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000981",
    },
    {
        "school": "Murphy Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000983",
    },
    {
        "school": "Murray Elem Language Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000984",
    },
    {
        "school": "Nash Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000985",
    },
    {
        "school": "Neil Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000987",
    },
    {
        "school": "Nettelhorst Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000988",
    },
    {
        "school": "Jones College Prep High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000990",
    },
    {
        "school": "Newberry Elem Math & Science Acad",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000991",
    },
    {
        "school": "Nightingale Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000992",
    },
    {
        "school": "Carver Primary School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000993",
    },
    {
        "school": "Nixon Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000994",
    },
    {
        "school": "Nobel Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000996",
    },
    {
        "school": "Norwood Park Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000997",
    },
    {
        "school": "Northside Learning Center",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993000999",
    },
    {
        "school": "Armour Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001001",
    },
    {
        "school": "Morgan Park High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001002",
    },
    {
        "school": "Ogden Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001003",
    },
    {
        "school": "Oglesby Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001004",
    },
    {
        "school": "OKeeffe Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001005",
    },
    {
        "school": "Onahan Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001009",
    },
    {
        "school": "Oriole Park Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001010",
    },
    {
        "school": "Piccolo Elem Specialty School",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001011",
    },
    {
        "school": "Otis Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001012",
    },
    {
        "school": "OToole Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001013",
    },
    {
        "school": "Owen Elem Scholastic Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001015",
    },
    {
        "school": "Palmer Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001017",
    },
    {
        "school": "Vaughn Occupational High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001018",
    },
    {
        "school": "Parker Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001019",
    },
    {
        "school": "Park Manor Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001021",
    },
    {
        "school": "Parkside Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001022",
    },
    {
        "school": "Pasteur Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001023",
    },
    {
        "school": "Peck Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001025",
    },
    {
        "school": "Peirce Elem Intl Studies School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001027",
    },
    {
        "school": "Penn Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001028",
    },
    {
        "school": "Washington  H Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001031",
    },
    {
        "school": "Pershing Elem Humanities Magnet",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001032",
    },
    {
        "school": "Peterson Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001033",
    },
    {
        "school": "Pickard Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001034",
    },
    {
        "school": "Pirie Elem Fine Arts & Academic C",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001036",
    },
    {
        "school": "Plamondon Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001037",
    },
    {
        "school": "Portage Park Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001039",
    },
    {
        "school": "Prescott Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001040",
    },
    {
        "school": "Prussing Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001043",
    },
    {
        "school": "Tanner Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001044",
    },
    {
        "school": "Pulaski Intl Sch of Chicago",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001045",
    },
    {
        "school": "Pullman Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001046",
    },
    {
        "school": "Ray Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001047",
    },
    {
        "school": "Ravenswood Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001050",
    },
    {
        "school": "Reavis Elem Math & Sci Spec Schl",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001052",
    },
    {
        "school": "Reilly Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001054",
    },
    {
        "school": "Reinberg Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001055",
    },
    {
        "school": "Revere Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001056",
    },
    {
        "school": "Rogers Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001059",
    },
    {
        "school": "Phillips Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001061",
    },
    {
        "school": "Ruggles Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001064",
    },
    {
        "school": "Ryder Elem Math & Sci Spec School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001065",
    },
    {
        "school": "Sauganash Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001067",
    },
    {
        "school": "Sawyer Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001068",
    },
    {
        "school": "Sayre Elem Language Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001070",
    },
    {
        "school": "Ashe Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001071",
    },
    {
        "school": "Corliss High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001072",
    },
    {
        "school": "Scammon Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001073",
    },
    {
        "school": "Graham  R Training Center",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001076",
    },
    {
        "school": "Schmid Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001077",
    },
    {
        "school": "Schubert Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001079",
    },
    {
        "school": "Seward Elem Communication Arts Ac",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001080",
    },
    {
        "school": "Sheridan Elem Math & Science Acad",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001083",
    },
    {
        "school": "Mireles Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001084",
    },
    {
        "school": "Sherman Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001085",
    },
    {
        "school": "Clemente Community Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001086",
    },
    {
        "school": "Sherwood Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001087",
    },
    {
        "school": "Jackson M Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001091",
    },
    {
        "school": "Shields Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001092",
    },
    {
        "school": "Roosevelt High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001093",
    },
    {
        "school": "Shoesmith Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001094",
    },
    {
        "school": "Shoop Math-Sci Tech Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001095",
    },
    {
        "school": "Skinner Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001096",
    },
    {
        "school": "Smyser Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001097",
    },
    {
        "school": "Smyth  J Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001098",
    },
    {
        "school": "Cardenas Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001099",
    },
    {
        "school": "Solomon Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001100",
    },
    {
        "school": "Spencer Technology Acad Elem Sch",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001101",
    },
    {
        "school": "Stagg Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001102",
    },
    {
        "school": "Stevenson Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001103",
    },
    {
        "school": "Stone Elem Scholastic Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001105",
    },
    {
        "school": "Spry Elem Community School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001106",
    },
    {
        "school": "Stowe Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001109",
    },
    {
        "school": "Schurz High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001111",
    },
    {
        "school": "Senn High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001114",
    },
    {
        "school": "Sullivan Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001116",
    },
    {
        "school": "Sumner Elem Math & Sci Comm Acad",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001117",
    },
    {
        "school": "Sutherland Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001118",
    },
    {
        "school": "Swift Elem Specialty School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001119",
    },
    {
        "school": "Taylor Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001120",
    },
    {
        "school": "Thorp  J N Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001122",
    },
    {
        "school": "Thorp  O A Elem Scholastic Acad",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001123",
    },
    {
        "school": "Tilton Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001124",
    },
    {
        "school": "Manley Career Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001125",
    },
    {
        "school": "Tonti Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001127",
    },
    {
        "school": "Ninos Heroes Elem Academic Ctr",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001128",
    },
    {
        "school": "Twain Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001130",
    },
    {
        "school": "Vanderpoel Elem Magnet School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001131",
    },
    {
        "school": "Lavizzo Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001135",
    },
    {
        "school": "Walsh Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001136",
    },
    {
        "school": "Volta Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001138",
    },
    {
        "school": "Steinmetz College Prep HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001139",
    },
    {
        "school": "Wacker Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001141",
    },
    {
        "school": "Ward  J Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001143",
    },
    {
        "school": "Wadsworth Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001144",
    },
    {
        "school": "Washington  G Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001145",
    },
    {
        "school": "Waters Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001147",
    },
    {
        "school": "Webster Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001148",
    },
    {
        "school": "Sullivan High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001149",
    },
    {
        "school": "Wentworth Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001150",
    },
    {
        "school": "Westcott Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001151",
    },
    {
        "school": "Taft High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001153",
    },
    {
        "school": "Pritzker Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001154",
    },
    {
        "school": "Whistler Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001155",
    },
    {
        "school": "Joplin Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001156",
    },
    {
        "school": "Whitney Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001157",
    },
    {
        "school": "Whittier Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001159",
    },
    {
        "school": "Tilden Career Communty Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001161",
    },
    {
        "school": "Woodson South Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001163",
    },
    {
        "school": "Till Elem Math & Science Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001165",
    },
    {
        "school": "Warren Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001166",
    },
    {
        "school": "Aldridge Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001168",
    },
    {
        "school": "Young Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001171",
    },
    {
        "school": "Dirksen Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001174",
    },
    {
        "school": "Yates Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001176",
    },
    {
        "school": "Depriest Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001177",
    },
    {
        "school": "Von Steuben Metro Science HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001180",
    },
    {
        "school": "Armstrong G Elem IntL Studies",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001181",
    },
    {
        "school": "Cuffe Math-Sci Tech Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001183",
    },
    {
        "school": "Lincoln Park High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001185",
    },
    {
        "school": "Foster Park Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001186",
    },
    {
        "school": "Washington G High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001189",
    },
    {
        "school": "McNair Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001191",
    },
    {
        "school": "Wells Community Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001192",
    },
    {
        "school": "Hay Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001193",
    },
    {
        "school": "Cullen Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001194",
    },
    {
        "school": "Curie Metropolitan High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001198",
    },
    {
        "school": "Green  W Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001209",
    },
    {
        "school": "Clark  G R Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001210",
    },
    {
        "school": "Ward  L Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001212",
    },
    {
        "school": "Powell Elem Paideia Comm Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001213",
    },
    {
        "school": "Lee Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001214",
    },
    {
        "school": "Salazar Elem Bilingual Center",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001215",
    },
    {
        "school": "Langford A Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001217",
    },
    {
        "school": "Finkl Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001351",
    },
    {
        "school": "Ariel Elem Community Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001607",
    },
    {
        "school": "Little Village Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001608",
    },
    {
        "school": "Zapata Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001609",
    },
    {
        "school": "Ortiz De Dominguez Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001610",
    },
    {
        "school": "Lara Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001612",
    },
    {
        "school": "Telpochcalli Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001613",
    },
    {
        "school": "Wells Preparatory Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001614",
    },
    {
        "school": "Woodlawn Elem Community School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001615",
    },
    {
        "school": "Hancock College Preparatory HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993001980",
    },
    {
        "school": "Brooks College Prep Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993002031",
    },
    {
        "school": "West Park Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993002042",
    },
    {
        "school": "Peace and Education Coalition HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993002596",
    },
    {
        "school": "Marine Leadership Academy - Ames",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993002618",
    },
    {
        "school": "Fairfield Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993002631",
    },
    {
        "school": "Northside College Preparatory Hs",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993003481",
    },
    {
        "school": "Chicago Military Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993003487",
    },
    {
        "school": "Locke A Elem Charter Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993003564",
    },
    {
        "school": "Sandoval Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993003566",
    },
    {
        "school": "Northwest Middle School",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993003567",
    },
    {
        "school": "Vick Early Childhood & Family Ctr",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993003570",
    },
    {
        "school": "Payton College Preparatory HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993003989",
    },
    {
        "school": "Hampton Elem Fine & Perf Arts Sch",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993003995",
    },
    {
        "school": "Colemon J Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004016",
    },
    {
        "school": "Hope College Prep High School",
        "district": "City of Chicago SD 299",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004266",
    },
    {
        "school": "Columbia Explorers Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004277",
    },
    {
        "school": "Chicago Academy Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004286",
    },
    {
        "school": "Christopher Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004376",
    },
    {
        "school": "Rudolph Elem Learning Center",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004382",
    },
    {
        "school": "Simpson Acad HS for Young Women",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004383",
    },
    {
        "school": "Daley Elem Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004913",
    },
    {
        "school": "Madero Middle School",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004915",
    },
    {
        "school": "Sabin Elem Magnet School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004916",
    },
    {
        "school": "Saucedo Elem Scholastic Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004917",
    },
    {
        "school": "Edison Elem Regional Gifted Cntr",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004944",
    },
    {
        "school": "Orozco Elem Fine Arts & Sciences",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004954",
    },
    {
        "school": "Morton Elem Career Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004956",
    },
    {
        "school": "Albany Park Multicultural Elem",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004962",
    },
    {
        "school": "Beard Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004965",
    },
    {
        "school": "Blair Early Childhood Center",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993004966",
    },
    {
        "school": "Chicago HS for Agricult Sciences",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005147",
    },
    {
        "school": "Stock Early Childhood Center",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005151",
    },
    {
        "school": "South Loop Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005268",
    },
    {
        "school": "Lenart Elem Regional Gifted Ctr",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005269",
    },
    {
        "school": "Casals Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005303",
    },
    {
        "school": "Southside Occupational Acad HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005305",
    },
    {
        "school": "Perez Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005410",
    },
    {
        "school": "Ruiz Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005413",
    },
    {
        "school": "Brighton Park Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005486",
    },
    {
        "school": "Evergreen Academy Elem School",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005489",
    },
    {
        "school": "Carson Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005546",
    },
    {
        "school": "McAuliffe Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005547",
    },
    {
        "school": "Galileo Elem Math & Sci Schol Acd",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005548",
    },
    {
        "school": "Highland School",
        "district": "Chicago Heights SD 170",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170996000055",
    },
    {
        "school": "Garfield Elem School",
        "district": "Chicago Heights SD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170996001220",
    },
    {
        "school": "Greenbriar Elem School",
        "district": "Chicago Heights SD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170996001221",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Chicago Heights SD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170996001222",
    },
    {
        "school": "Kennedy Elem School",
        "district": "Chicago Heights SD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170996001223",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Chicago Heights SD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170996001224",
    },
    {
        "school": "Roosevelt Elem School",
        "district": "Chicago Heights SD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170996001225",
    },
    {
        "school": "U S Grant Elem School",
        "district": "Chicago Heights SD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170996001226",
    },
    {
        "school": "Washington-McKinley Elem Sch",
        "district": "Chicago Heights SD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170996001227",
    },
    {
        "school": "Wilson Elem School",
        "district": "Chicago Heights SD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170996001228",
    },
    {
        "school": "Elden D Finley Jr High School",
        "district": "Chicago Ridge SD 127-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170999001229",
    },
    {
        "school": "Ridge Central Elem School",
        "district": "Chicago Ridge SD 127-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170999001230",
    },
    {
        "school": "Ridge Lawn Elementary School",
        "district": "Chicago Ridge SD 127-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170999001232",
    },
    {
        "school": "Liberty Elem School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020000277",
    },
    {
        "school": "Abe Lincoln Elem School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020001235",
    },
    {
        "school": "Cicero East Elem School",
        "district": "Cicero SD 99",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020001236",
    },
    {
        "school": "Columbus  East Elem School",
        "district": "Cicero SD 99",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020001237",
    },
    {
        "school": "Daniel Burnham Elem School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020001238",
    },
    {
        "school": "Drexel Elem School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020001239",
    },
    {
        "school": "Goodwin Elementary School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020001240",
    },
    {
        "school": "McKinley Elem School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020001241",
    },
    {
        "school": "Sherlock Elem School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020001242",
    },
    {
        "school": "T Roosevelt Elem School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020001243",
    },
    {
        "school": "Cicero West Elementary School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020002479",
    },
    {
        "school": "Columbus West Elementary School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020002480",
    },
    {
        "school": "Warren Park School",
        "district": "Cicero SD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020005153",
    },
    {
        "school": "Elizabeth Meyer School",
        "district": "Skokie SD 73-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171038000711",
    },
    {
        "school": "John Middleton Elem School",
        "district": "Skokie SD 73-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171038001253",
    },
    {
        "school": "Oliver McCracken Middle School",
        "district": "Skokie SD 73-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171038001254",
    },
    {
        "school": "Medgar Evers Primary Acadmc Cntr",
        "district": "Ford Heights SD 169",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171095001328",
    },
    {
        "school": "Cottage Grove Upper Grade Center",
        "district": "Ford Heights SD 169",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171095005419",
    },
    {
        "school": "Meadowview  School",
        "district": "Country Club Hills SD 160",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171101001331",
    },
    {
        "school": "Southwood Middle School",
        "district": "Country Club Hills SD 160",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171101001332",
    },
    {
        "school": "Zenon J Sykuta  School",
        "district": "Country Club Hills SD 160",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171101001334",
    },
    {
        "school": "Algonquin Middle School",
        "district": "CCSD 62",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171212001460",
    },
    {
        "school": "Central Elem School",
        "district": "CCSD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171212001461",
    },
    {
        "school": "Chippewa Middle School",
        "district": "CCSD 62",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171212001462",
    },
    {
        "school": "Cumberland Elem School",
        "district": "CCSD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171212001463",
    },
    {
        "school": "Forest Elem School",
        "district": "CCSD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171212001464",
    },
    {
        "school": "Iroquois Community School",
        "district": "CCSD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171212001465",
    },
    {
        "school": "North Elementary School",
        "district": "CCSD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171212001466",
    },
    {
        "school": "Orchard Place Elem School",
        "district": "CCSD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171212001467",
    },
    {
        "school": "Plainfield Elem School",
        "district": "CCSD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171212001468",
    },
    {
        "school": "South Elem School",
        "district": "CCSD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171212001469",
    },
    {
        "school": "Terrace Elem School",
        "district": "CCSD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171212001470",
    },
    {
        "school": "Caroline Sibley Elem School",
        "district": "Dolton SD 149",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171242001489",
    },
    {
        "school": "Diekman Elem School",
        "district": "Dolton SD 149",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171242001490",
    },
    {
        "school": "Berger-Vandenberg Elem School",
        "district": "Dolton SD 149",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171242001493",
    },
    {
        "school": "Carol Moseley Braun School",
        "district": "Dolton SD 149",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171242003924",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Dolton SD 148",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171245001495",
    },
    {
        "school": "Riverdale School",
        "district": "Dolton SD 148",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171245001497",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Dolton SD 148",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171245001498",
    },
    {
        "school": "Roosevelt Elem School",
        "district": "Dolton SD 148",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171245001500",
    },
    {
        "school": "Washington Elem School",
        "district": "Dolton SD 148",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171245001501",
    },
    {
        "school": "Early Childhood Cntr",
        "district": "Dolton SD 148",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171245001598",
    },
    {
        "school": "Lincoln Junior High School",
        "district": "Dolton SD 148",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171245004257",
    },
    {
        "school": "Roosevelt Junior High School",
        "district": "Dolton SD 148",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171245004919",
    },
    {
        "school": "Park Elementary School",
        "district": "Dolton SD 148",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171245005420",
    },
    {
        "school": "Apollo Elem School",
        "district": "East Maine SD 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171314000063",
    },
    {
        "school": "Mark Twain Elem School",
        "district": "East Maine SD 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171314001551",
    },
    {
        "school": "Gemini Jr High School",
        "district": "East Maine SD 63",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171314001552",
    },
    {
        "school": "V H Nelson Elem School",
        "district": "East Maine SD 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171314001553",
    },
    {
        "school": "Washington Elem School",
        "district": "East Maine SD 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171314001555",
    },
    {
        "school": "Melzer School",
        "district": "East Maine SD 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171314005276",
    },
    {
        "school": "East Prairie Elem School",
        "district": "East Prairie SD 73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171326001578",
    },
    {
        "school": "Lindop Elem School",
        "district": "Lindop SD 92",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171344001633",
    },
    {
        "school": "Eastview Middle School",
        "district": "SD U-46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001441",
    },
    {
        "school": "Bartlett Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001667",
    },
    {
        "school": "Elgin High School",
        "district": "SD U-46",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001674",
    },
    {
        "school": "Glenbrook Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001677",
    },
    {
        "school": "Hanover Countryside Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001679",
    },
    {
        "school": "Huff Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001684",
    },
    {
        "school": "Lords Park Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001685",
    },
    {
        "school": "Laurel Hill Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001687",
    },
    {
        "school": "Tefft Middle School",
        "district": "SD U-46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001691",
    },
    {
        "school": "Oakhill Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001695",
    },
    {
        "school": "Ontarioville Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001697",
    },
    {
        "school": "Parkwood Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001698",
    },
    {
        "school": "Ridge Circle Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001699",
    },
    {
        "school": "Sunnydale Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001702",
    },
    {
        "school": "Streamwood High School",
        "district": "SD U-46",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001703",
    },
    {
        "school": "Canton Middle School",
        "district": "SD U-46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001705",
    },
    {
        "school": "Heritage Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001709",
    },
    {
        "school": "Independence Preschool",
        "district": "SD U-46",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001728",
    },
    {
        "school": "Nature Ridge Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371003644",
    },
    {
        "school": "Clearmont Elem School",
        "district": "Comm Cons SD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001711",
    },
    {
        "school": "Adm Richard E Byrd Elem School",
        "district": "Comm Cons SD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001713",
    },
    {
        "school": "Devonshire School",
        "district": "Comm Cons SD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001714",
    },
    {
        "school": "Grove Jr High School",
        "district": "Comm Cons SD 59",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001715",
    },
    {
        "school": "Forest View Elem School",
        "district": "Comm Cons SD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001716",
    },
    {
        "school": "Robert Frost Elem School",
        "district": "Comm Cons SD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001717",
    },
    {
        "school": "Brentwood Elem School",
        "district": "Comm Cons SD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001718",
    },
    {
        "school": "Holmes Jr High School",
        "district": "Comm Cons SD 59",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001719",
    },
    {
        "school": "Juliette Low Elem School",
        "district": "Comm Cons SD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001722",
    },
    {
        "school": "Rupley Elem School",
        "district": "Comm Cons SD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001723",
    },
    {
        "school": "Salt Creek Elem School",
        "district": "Comm Cons SD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001726",
    },
    {
        "school": "John Jay Elem School",
        "district": "Comm Cons SD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001727",
    },
    {
        "school": "Friendship Jr High School",
        "district": "Comm Cons SD 59",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171377001730",
    },
    {
        "school": "Elmwood Elem School",
        "district": "Elmwood Park CUSD 401",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171410001760",
    },
    {
        "school": "Elmwood Park High School",
        "district": "Elmwood Park CUSD 401",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171410001761",
    },
    {
        "school": "John Mills Elem School",
        "district": "Elmwood Park CUSD 401",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171410001762",
    },
    {
        "school": "Elm Middle School",
        "district": "Elmwood Park CUSD 401",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171410005506",
    },
    {
        "school": "Dr Bessie Rhodes-Global Studies",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001216",
    },
    {
        "school": "Chute Middle School",
        "district": "Evanston CCSD 65",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001786",
    },
    {
        "school": "Dawes Elementary School",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001787",
    },
    {
        "school": "Dewey Elem School",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001788",
    },
    {
        "school": "Rice Childrens Center",
        "district": "Evanston CCSD 65",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001789",
    },
    {
        "school": "Haven Middle School",
        "district": "Evanston CCSD 65",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001790",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001792",
    },
    {
        "school": "Lincolnwood Elem School",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001793",
    },
    {
        "school": "Dr ML King Jr Literary&Fine Arts",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001794",
    },
    {
        "school": "Nichols Middle School",
        "district": "Evanston CCSD 65",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001795",
    },
    {
        "school": "Oakton Elem School",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001796",
    },
    {
        "school": "Orrington Elem School",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001797",
    },
    {
        "school": "Walker Elem School",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001801",
    },
    {
        "school": "Washington Elem School",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001802",
    },
    {
        "school": "Willard Elem School",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446001803",
    },
    {
        "school": "Kingsley Elementary School",
        "district": "Evanston CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171446005537",
    },
    {
        "school": "Evanston Twp High School",
        "district": "Evanston Twp HSD 202",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171449001804",
    },
    {
        "school": "Central Middle School",
        "district": "Evergreen Park ESD 124",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171455001805",
    },
    {
        "school": "Northeast Elem School",
        "district": "Evergreen Park ESD 124",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171455001806",
    },
    {
        "school": "Northwest School",
        "district": "Evergreen Park ESD 124",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171455001807",
    },
    {
        "school": "Southeast Elem School",
        "district": "Evergreen Park ESD 124",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171455001808",
    },
    {
        "school": "Southwest Elem School",
        "district": "Evergreen Park ESD 124",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171455001809",
    },
    {
        "school": "Evergreen Park High School",
        "district": "Evergreen Park CHSD 231",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171458001810",
    },
    {
        "school": "Fairview South Elementary School",
        "district": "Fairview SD 72",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171482001820",
    },
    {
        "school": "Flossmoor Hills Elem School",
        "district": "Flossmoor SD 161",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171542001848",
    },
    {
        "school": "Parker Junior High School",
        "district": "Flossmoor SD 161",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171542001849",
    },
    {
        "school": "Heather Hill Elem School",
        "district": "Flossmoor SD 161",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171542001850",
    },
    {
        "school": "Serena Hills Elem School",
        "district": "Flossmoor SD 161",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171542001851",
    },
    {
        "school": "Western Avenue Elem School",
        "district": "Flossmoor SD 161",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171542001853",
    },
    {
        "school": "Forest Park Middle School",
        "district": "Forest Park SD 91",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171545001858",
    },
    {
        "school": "Betsy Ross Elem School",
        "district": "Forest Park SD 91",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171545001859",
    },
    {
        "school": "Field Stevenson Elem School",
        "district": "Forest Park SD 91",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171545001860",
    },
    {
        "school": "Garfield Elem School",
        "district": "Forest Park SD 91",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171545001861",
    },
    {
        "school": "Grant-White Elem School",
        "district": "Forest Park SD 91",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171545004636",
    },
    {
        "school": "Kerkstra Elem School",
        "district": "Forest Ridge SD 142",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171548001862",
    },
    {
        "school": "Lee R Foster Elem School",
        "district": "Forest Ridge SD 142",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171548001863",
    },
    {
        "school": "Jack Hille Middle School",
        "district": "Forest Ridge SD 142",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171548001864",
    },
    {
        "school": "Ridge Early Childhood Center",
        "district": "Forest Ridge SD 142",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171548001865",
    },
    {
        "school": "North Elem School",
        "district": "Franklin Park SD 84",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171578001886",
    },
    {
        "school": "Hester Jr High School",
        "district": "Franklin Park SD 84",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171578001887",
    },
    {
        "school": "Dan H Pietrini Elem School",
        "district": "Franklin Park SD 84",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171578001888",
    },
    {
        "school": "Passow Elementary School",
        "district": "Franklin Park SD 84",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171578001889",
    },
    {
        "school": "South Elem School",
        "district": "Glencoe SD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171686001992",
    },
    {
        "school": "Central School",
        "district": "Glencoe SD 35",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171686001993",
    },
    {
        "school": "West School",
        "district": "Glencoe SD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171686005280",
    },
    {
        "school": "Glen Grove Elem School",
        "district": "Glenview CCSD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171692001998",
    },
    {
        "school": "Henking Elem School",
        "district": "Glenview CCSD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171692001999",
    },
    {
        "school": "Hoffman Elem School",
        "district": "Glenview CCSD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171692002000",
    },
    {
        "school": "Lyon Elem School",
        "district": "Glenview CCSD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171692002001",
    },
    {
        "school": "Pleasant Ridge Elem School",
        "district": "Glenview CCSD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171692002002",
    },
    {
        "school": "Springman Middle School",
        "district": "Glenview CCSD 34",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171692002003",
    },
    {
        "school": "Westbrook Elementary School",
        "district": "Glenview CCSD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171692002004",
    },
    {
        "school": "Brookwood Middle School",
        "district": "Brookwood SD 167",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171695002005",
    },
    {
        "school": "Brookwood Jr High School",
        "district": "Brookwood SD 167",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171695002006",
    },
    {
        "school": "Hickory Bend Elem School",
        "district": "Brookwood SD 167",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171695002007",
    },
    {
        "school": "Longwood Elem School",
        "district": "Brookwood SD 167",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171695002008",
    },
    {
        "school": "Hickory Point Elem School",
        "district": "Northbrook ESD 27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171785002078",
    },
    {
        "school": "Shabonee School",
        "district": "Northbrook ESD 27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171785002079",
    },
    {
        "school": "Wood Oaks Jr High School",
        "district": "Northbrook ESD 27",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171785002081",
    },
    {
        "school": "Riley Preschool",
        "district": "Harvey SD 152",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171845001937",
    },
    {
        "school": "Brooks Middle School",
        "district": "Harvey SD 152",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171845002129",
    },
    {
        "school": "Bryant Elem School",
        "district": "Harvey SD 152",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171845002130",
    },
    {
        "school": "Maya Angelou Elem Sch",
        "district": "Harvey SD 152",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171845002131",
    },
    {
        "school": "Holmes Elem School",
        "district": "Harvey SD 152",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171845002133",
    },
    {
        "school": "Whittier Elem School",
        "district": "Harvey SD 152",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171845004658",
    },
    {
        "school": "Lincoln Elem School",
        "district": "W Harvey-Dixmoor PSD 147",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171848002139",
    },
    {
        "school": "Martin L King Elem School",
        "district": "W Harvey-Dixmoor PSD 147",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171848004405",
    },
    {
        "school": "Rosa L Parks Middle School",
        "district": "W Harvey-Dixmoor PSD 147",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171848005018",
    },
    {
        "school": "Barack H Obama Learning Academy",
        "district": "Hazel Crest SD 152-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171860002152",
    },
    {
        "school": "Jesse C White Learning Academy",
        "district": "Hazel Crest SD 152-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171860002156",
    },
    {
        "school": "Highlands Elem School",
        "district": "LaGrange Highlands SD 106",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171911002195",
    },
    {
        "school": "Highlands Middle School",
        "district": "LaGrange Highlands SD 106",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171911002197",
    },
    {
        "school": "Hillside Elem School",
        "district": "Hillside SD 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171923002210",
    },
    {
        "school": "James Hart School",
        "district": "Homewood SD 153",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171953002230",
    },
    {
        "school": "Willow School",
        "district": "Homewood SD 153",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171953002231",
    },
    {
        "school": "Winston Churchill School",
        "district": "Homewood SD 153",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171953002233",
    },
    {
        "school": "Homewood-Flossmoor High School",
        "district": "Homewood Flossmoor CHSD 233",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171956002235",
    },
    {
        "school": "Schrum Memorial School",
        "district": "Hoover-Schrum Memorial SD 157",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171968000742",
    },
    {
        "school": "Hoover Elem School",
        "district": "Hoover-Schrum Memorial SD 157",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171968002242",
    },
    {
        "school": "The Joseph Sears School",
        "district": "Kenilworth SD 38",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172097002378",
    },
    {
        "school": "Prairie View Middle School",
        "district": "Kirby SD 140",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172127000294",
    },
    {
        "school": "Fernway Park Elem School",
        "district": "Kirby SD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172127002398",
    },
    {
        "school": "Helen Keller Elem School",
        "district": "Kirby SD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172127002399",
    },
    {
        "school": "Virgil I Grissom Middle School",
        "district": "Kirby SD 140",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172127002402",
    },
    {
        "school": "Millennium Elem School",
        "district": "Kirby SD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172127003424",
    },
    {
        "school": "John A Bannes Elem School",
        "district": "Kirby SD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172127005174",
    },
    {
        "school": "Christa McAuliffe School",
        "district": "Kirby SD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172127005282",
    },
    {
        "school": "Komarek Elem School",
        "district": "Komarek SD 94",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172142002410",
    },
    {
        "school": "Congress Park Elem School",
        "district": "La Grange SD 102",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172160002420",
    },
    {
        "school": "Cossitt Ave Elem School",
        "district": "La Grange SD 102",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172160002421",
    },
    {
        "school": "Forest Road Elem School",
        "district": "La Grange SD 102",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172160002422",
    },
    {
        "school": "Ogden Ave Elem School",
        "district": "La Grange SD 102",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172160002423",
    },
    {
        "school": "Park Junior High School",
        "district": "La Grange SD 102",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172160002424",
    },
    {
        "school": "Hodgkins Elem School",
        "district": "La Grange SD 105 South",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172163002425",
    },
    {
        "school": "Ideal Elem School",
        "district": "La Grange SD 105 South",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172163002426",
    },
    {
        "school": "Seventh Ave Elem School",
        "district": "La Grange SD 105 South",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172163002427",
    },
    {
        "school": "Spring Ave Elem School",
        "district": "La Grange SD 105 South",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172163002428",
    },
    {
        "school": "Wm F Gurrie Middle School",
        "district": "La Grange SD 105 South",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172163002429",
    },
    {
        "school": "Coolidge Elementary School",
        "district": "Lansing SD 158",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172202002467",
    },
    {
        "school": "Oak Glen Elem School",
        "district": "Lansing SD 158",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172202002468",
    },
    {
        "school": "Memorial Jr High School",
        "district": "Lansing SD 158",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172202002470",
    },
    {
        "school": "Reavis Elem School",
        "district": "Lansing SD 158",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172202002471",
    },
    {
        "school": "Lester Crawl Primary Ctr",
        "district": "Lansing SD 158",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172202002568",
    },
    {
        "school": "Lemont Twp High School",
        "district": "Lemont Twp HSD 210",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172250002508",
    },
    {
        "school": "East Leyden High School",
        "district": "Leyden CHSD 212",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172274002520",
    },
    {
        "school": "West Leyden High School",
        "district": "Leyden CHSD 212",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172274002522",
    },
    {
        "school": "Lincoln Hall Middle School",
        "district": "Lincolnwood SD 74",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172310002549",
    },
    {
        "school": "Rutledge Hall Elem School",
        "district": "Lincolnwood SD 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172310002550",
    },
    {
        "school": "Todd Hall Elem School",
        "district": "Lincolnwood SD 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172310002551",
    },
    {
        "school": "Edison Elem School",
        "district": "Lyons SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172385002595",
    },
    {
        "school": "Home Elem School",
        "district": "Lyons SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172385002597",
    },
    {
        "school": "J W Robinson Jr Elem School",
        "district": "Lyons SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172385002598",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Lyons SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172385002599",
    },
    {
        "school": "Washington Middle School",
        "district": "Lyons SD 103",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172385002600",
    },
    {
        "school": "Costello School",
        "district": "Lyons SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172385003902",
    },
    {
        "school": "Lyons Twp High Sch",
        "district": "Lyons Twp HSD 204",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172388002601",
    },
    {
        "school": "Maine East High School",
        "district": "Maine Township HSD 207",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172409005030",
    },
    {
        "school": "Maine South High School",
        "district": "Maine Township HSD 207",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172409005031",
    },
    {
        "school": "Maine West High School",
        "district": "Maine Township HSD 207",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172409005032",
    },
    {
        "school": "Ralph J Frost Academy",
        "district": "Maine Township HSD 207",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172409005034",
    },
    {
        "school": "Enger School",
        "district": "Mannheim SD 83",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172433002641",
    },
    {
        "school": "Mannheim Middle School",
        "district": "Mannheim SD 83",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172433002642",
    },
    {
        "school": "Roy Elem School",
        "district": "Mannheim SD 83",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172433002643",
    },
    {
        "school": "Scott Elementary School",
        "district": "Mannheim SD 83",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172433002644",
    },
    {
        "school": "Westdale Elem School",
        "district": "Mannheim SD 83",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172433002645",
    },
    {
        "school": "Maple School",
        "district": "Northbrook/Glenview SD 30",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172442002649",
    },
    {
        "school": "Wescott Elementary School",
        "district": "Northbrook/Glenview SD 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172442002650",
    },
    {
        "school": "Willowbrook Elem School",
        "district": "Northbrook/Glenview SD 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172442002651",
    },
    {
        "school": "Prairie-Hills Junior High School",
        "district": "Prairie-Hills ESD 144",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172472002673",
    },
    {
        "school": "Fieldcrest Elem School",
        "district": "Prairie-Hills ESD 144",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172472002676",
    },
    {
        "school": "Highlands Elem School",
        "district": "Prairie-Hills ESD 144",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172472002677",
    },
    {
        "school": "Markham Park Elem School",
        "district": "Prairie-Hills ESD 144",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172472002678",
    },
    {
        "school": "Nob Hill Elem School",
        "district": "Prairie-Hills ESD 144",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172472002679",
    },
    {
        "school": "Chateaux School",
        "district": "Prairie-Hills ESD 144",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172472002680",
    },
    {
        "school": "Mae Jemison School",
        "district": "Prairie-Hills ESD 144",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172472004254",
    },
    {
        "school": "Illinois School",
        "district": "Matteson ESD 162",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172502002581",
    },
    {
        "school": "Arcadia Elem School",
        "district": "Matteson ESD 162",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172502002717",
    },
    {
        "school": "Indiana Elem School",
        "district": "Matteson ESD 162",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172502002718",
    },
    {
        "school": "Matteson Elem School",
        "district": "Matteson ESD 162",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172502002719",
    },
    {
        "school": "Sauk Elem School",
        "district": "Matteson ESD 162",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172502002720",
    },
    {
        "school": "O W Huth Middle School",
        "district": "Matteson ESD 162",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172502002721",
    },
    {
        "school": "Emerson Elem School",
        "district": "Maywood-Melrose Park-Broadview 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172511002737",
    },
    {
        "school": "Garfield Elem School",
        "district": "Maywood-Melrose Park-Broadview 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172511002738",
    },
    {
        "school": "Jane Addams Elem School",
        "district": "Maywood-Melrose Park-Broadview 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172511002740",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Maywood-Melrose Park-Broadview 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172511002742",
    },
    {
        "school": "Melrose Park Elem School",
        "district": "Maywood-Melrose Park-Broadview 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172511002743",
    },
    {
        "school": "Roosevelt Elem School",
        "district": "Maywood-Melrose Park-Broadview 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172511002744",
    },
    {
        "school": "Washington Dual Language Academy",
        "district": "Maywood-Melrose Park-Broadview 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172511002747",
    },
    {
        "school": "Spaulding School",
        "district": "Midlothian SD 143",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172592001284",
    },
    {
        "school": "Central Park Elem School",
        "district": "Midlothian SD 143",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172592002785",
    },
    {
        "school": "Kolmar Elem School",
        "district": "Midlothian SD 143",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172592002786",
    },
    {
        "school": "Springfield Elem School",
        "district": "Midlothian SD 143",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172592002788",
    },
    {
        "school": "Golf Middle School",
        "district": "Golf ESD 67",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172682002867",
    },
    {
        "school": "Hynes Elem School",
        "district": "Golf ESD 67",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172682002868",
    },
    {
        "school": "Park View Elem School",
        "district": "Morton Grove SD 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172685002870",
    },
    {
        "school": "J Sterling Morton East High Sch",
        "district": "J S Morton HSD 201",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172688002871",
    },
    {
        "school": "J Sterling Morton West High Sch",
        "district": "J S Morton HSD 201",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172688002872",
    },
    {
        "school": "J Sterling Morton Alternative Sch",
        "district": "J S Morton HSD 201",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172688003949",
    },
    {
        "school": "Lions Park Elem School",
        "district": "Mount Prospect SD 57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172721001596",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Mount Prospect SD 57",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172721002885",
    },
    {
        "school": "Fairview Elem School",
        "district": "Mount Prospect SD 57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172721002888",
    },
    {
        "school": "New Trier Township H S Winnetka",
        "district": "New Trier Twp HSD 203",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172820002975",
    },
    {
        "school": "New Trier Township H S Northfield",
        "district": "New Trier Twp HSD 203",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172820004263",
    },
    {
        "school": "Clarence E Culver School",
        "district": "Niles ESD 71",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172850002476",
    },
    {
        "school": "Niles North High School",
        "district": "Niles Twp HSD 219",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172853002986",
    },
    {
        "school": "Niles West High School",
        "district": "Niles Twp HSD 219",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172853002988",
    },
    {
        "school": "J Leigh Elem School",
        "district": "Norridge SD 80",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172865003008",
    },
    {
        "school": "Glen Oaks Elem School",
        "district": "North Palos SD 117",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172889003028",
    },
    {
        "school": "H H Conrady Jr High School",
        "district": "North Palos SD 117",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172889003029",
    },
    {
        "school": "Oak Ridge Elem School",
        "district": "North Palos SD 117",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172889003030",
    },
    {
        "school": "Dorn Primary Center",
        "district": "North Palos SD 117",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172889003031",
    },
    {
        "school": "Dr Kenneth M Sorrick School",
        "district": "North Palos SD 117",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172889004243",
    },
    {
        "school": "Greenbriar Elem School",
        "district": "Northbrook SD 28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172898003038",
    },
    {
        "school": "Meadowbrook Elem School",
        "district": "Northbrook SD 28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172898003039",
    },
    {
        "school": "Northbrook Junior High School",
        "district": "Northbrook SD 28",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172898003040",
    },
    {
        "school": "Westmoor Elem School",
        "district": "Northbrook SD 28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172898003041",
    },
    {
        "school": "Glenbrook North High School",
        "district": "Northfield Twp HSD 225",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172901003042",
    },
    {
        "school": "Glenbrook South High School",
        "district": "Northfield Twp HSD 225",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172901003043",
    },
    {
        "school": "Glenbrook Evening High School",
        "district": "Northfield Twp HSD 225",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172901005045",
    },
    {
        "school": "Hometown Elem School",
        "district": "Oak Lawn-Hometown SD 123",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172919003050",
    },
    {
        "school": "J Covington Elem School",
        "district": "Oak Lawn-Hometown SD 123",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172919003051",
    },
    {
        "school": "J M Hannum Elem School",
        "district": "Oak Lawn-Hometown SD 123",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172919003052",
    },
    {
        "school": "Kolmar Avenue Elem School",
        "district": "Oak Lawn-Hometown SD 123",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172919003053",
    },
    {
        "school": "Sward Elem School",
        "district": "Oak Lawn-Hometown SD 123",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172919003056",
    },
    {
        "school": "Oak Lawn-Hometown Middle Sch",
        "district": "Oak Lawn-Hometown SD 123",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172919005184",
    },
    {
        "school": "Oak Lawn Comm High School",
        "district": "Oak Lawn CHSD 229",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172922003059",
    },
    {
        "school": "Abraham Lincoln Elem School",
        "district": "Oak Park ESD 97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172925003060",
    },
    {
        "school": "Horace Mann Elem School",
        "district": "Oak Park ESD 97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172925003062",
    },
    {
        "school": "Irving Elem School",
        "district": "Oak Park ESD 97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172925003063",
    },
    {
        "school": "Longfellow Elem School",
        "district": "Oak Park ESD 97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172925003064",
    },
    {
        "school": "Oliver W Holmes Elem School",
        "district": "Oak Park ESD 97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172925003065",
    },
    {
        "school": "Whittier Elem School",
        "district": "Oak Park ESD 97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172925003067",
    },
    {
        "school": "William Beye Elem School",
        "district": "Oak Park ESD 97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172925003068",
    },
    {
        "school": "William Hatch Elem School",
        "district": "Oak Park ESD 97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172925003069",
    },
    {
        "school": "Oak Park & River Forest High Sch",
        "district": "Oak Park - River Forest SD 200",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172928003070",
    },
    {
        "school": "Century Junior High School",
        "district": "Orland SD 135",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173022001597",
    },
    {
        "school": "Meadow Ridge School",
        "district": "Orland SD 135",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173022002530",
    },
    {
        "school": "Orland Park Elem School",
        "district": "Orland SD 135",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173022003122",
    },
    {
        "school": "Liberty Elem School",
        "district": "Orland SD 135",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173022003124",
    },
    {
        "school": "Orland Jr High School",
        "district": "Orland SD 135",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173022003126",
    },
    {
        "school": "High Point Elem School",
        "district": "Orland SD 135",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173022003127",
    },
    {
        "school": "Prairie Elem School",
        "district": "Orland SD 135",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173022003128",
    },
    {
        "school": "Orland Center School",
        "district": "Orland SD 135",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173022005187",
    },
    {
        "school": "Jerling Junior High School",
        "district": "Orland SD 135",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173022005540",
    },
    {
        "school": "Centennial School",
        "district": "Orland SD 135",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173022005541",
    },
    {
        "school": "John G Conyers Learning Academy",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042001179",
    },
    {
        "school": "Central Road Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003144",
    },
    {
        "school": "Hunting Ridge Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003145",
    },
    {
        "school": "Jane Addams Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003146",
    },
    {
        "school": "Kimball Hill Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003148",
    },
    {
        "school": "Lake Louise Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003149",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003150",
    },
    {
        "school": "Marion Jordan Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003151",
    },
    {
        "school": "Stuart R Paddock School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003152",
    },
    {
        "school": "Pleasant Hill Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003153",
    },
    {
        "school": "Plum Grove Jr High School",
        "district": "Palatine CCSD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003154",
    },
    {
        "school": "Gray M Sanborn Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003155",
    },
    {
        "school": "Virginia Lake Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003156",
    },
    {
        "school": "Carl Sandburg Jr High School",
        "district": "Palatine CCSD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003157",
    },
    {
        "school": "Willow Bend Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003159",
    },
    {
        "school": "Walter R Sundling Jr High Sch",
        "district": "Palatine CCSD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003160",
    },
    {
        "school": "Winston Campus Elementary",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003161",
    },
    {
        "school": "Thomas Jefferson Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042003162",
    },
    {
        "school": "Frank C Whiteley Elem School",
        "district": "Palatine CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173042005441",
    },
    {
        "school": "Hoffman Estates High School",
        "district": "Township HSD 211",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173045003164",
    },
    {
        "school": "J B Conant High School",
        "district": "Township HSD 211",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173045003165",
    },
    {
        "school": "Palatine High School",
        "district": "Township HSD 211",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173045003166",
    },
    {
        "school": "Schaumburg High School",
        "district": "Township HSD 211",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173045003167",
    },
    {
        "school": "Wm Fremd High School",
        "district": "Township HSD 211",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173045003168",
    },
    {
        "school": "Higgins Education Center",
        "district": "Township HSD 211",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173045004421",
    },
    {
        "school": "Chippewa Elem School",
        "district": "Palos Heights SD 128",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173057003175",
    },
    {
        "school": "Navajo Heights Elem School",
        "district": "Palos Heights SD 128",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173057003176",
    },
    {
        "school": "Independence Jr High School",
        "district": "Palos Heights SD 128",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173057003177",
    },
    {
        "school": "Indian Hill",
        "district": "Palos Heights SD 128",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173057003904",
    },
    {
        "school": "Palos East Elementary School",
        "district": "Palos CCSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173060003180",
    },
    {
        "school": "Palos South Middle School",
        "district": "Palos CCSD 118",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173060003181",
    },
    {
        "school": "Palos West Elementary School",
        "district": "Palos CCSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173060003182",
    },
    {
        "school": "Barack Obama Sch of Ldership",
        "district": "Park Forest SD 163",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173081003202",
    },
    {
        "school": "Blackhawk Primary Center",
        "district": "Park Forest SD 163",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173081003203",
    },
    {
        "school": "Mohawk Primary Center",
        "district": "Park Forest SD 163",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173081003207",
    },
    {
        "school": "Michelle Obama Sch of Technology",
        "district": "Park Forest SD 163",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173081003209",
    },
    {
        "school": "21st Century Primary Center",
        "district": "Park Forest SD 163",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173081003429",
    },
    {
        "school": "Emerson Middle School",
        "district": "Park Ridge CCSD 64",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173084002472",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Park Ridge CCSD 64",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173084003210",
    },
    {
        "school": "Eugene Field Elem School",
        "district": "Park Ridge CCSD 64",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173084003212",
    },
    {
        "school": "George B Carpenter Elem School",
        "district": "Park Ridge CCSD 64",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173084003213",
    },
    {
        "school": "Theodore Roosevelt Elem School",
        "district": "Park Ridge CCSD 64",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173084003215",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Park Ridge CCSD 64",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173084003216",
    },
    {
        "school": "George Washington Elem School",
        "district": "Park Ridge CCSD 64",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173084003217",
    },
    {
        "school": "School Dist 133 Annex",
        "district": "Gen George Patton SD 133",
        "level": "Not reported",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173090001936",
    },
    {
        "school": "Gen George Patton Elem School",
        "district": "Gen George Patton SD 133",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173090003220",
    },
    {
        "school": "Pennoyer Elem School",
        "district": "Pennoyer SD 79",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173120003250",
    },
    {
        "school": "Pleasantdale Elementary School",
        "district": "Pleasantdale SD 107",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173204003354",
    },
    {
        "school": "Pleasantdale Middle Sch",
        "district": "Pleasantdale SD 107",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173204005539",
    },
    {
        "school": "Kellar School",
        "district": "Posen-Robbins ESD 143-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173237001286",
    },
    {
        "school": "Gordon School",
        "district": "Posen-Robbins ESD 143-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173237001290",
    },
    {
        "school": "Childs Elem School",
        "district": "Posen-Robbins ESD 143-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173237003373",
    },
    {
        "school": "Posen Elem School",
        "district": "Posen-Robbins ESD 143-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173237003376",
    },
    {
        "school": "Turner Elem School",
        "district": "Posen-Robbins ESD 143-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173237003377",
    },
    {
        "school": "Anne Sullivan Elem School",
        "district": "Prospect Heights SD 23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173285003402",
    },
    {
        "school": "Dwight D Eisenhower Elem School",
        "district": "Prospect Heights SD 23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173285003403",
    },
    {
        "school": "Betsy Ross Elem School",
        "district": "Prospect Heights SD 23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173285003404",
    },
    {
        "school": "MacArthur Middle School",
        "district": "Prospect Heights SD 23",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173285003405",
    },
    {
        "school": "Proviso East High School",
        "district": "Proviso Twp HSD 209",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173291003406",
    },
    {
        "school": "Proviso West High School",
        "district": "Proviso Twp HSD 209",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173291003407",
    },
    {
        "school": "Reavis High School",
        "district": "Reavis Twp HSD 220",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173327003446",
    },
    {
        "school": "Rhodes Elem School",
        "district": "Rhodes SD 84-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173339003457",
    },
    {
        "school": "Rich Central Campus High School",
        "district": "Rich Twp HSD 227",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173342003458",
    },
    {
        "school": "Rich East Campus High School",
        "district": "Rich Twp HSD 227",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173342003459",
    },
    {
        "school": "Rich South Campus High School",
        "district": "Rich Twp HSD 227",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173342003460",
    },
    {
        "school": "Columbus Manor Elem School",
        "district": "Ridgeland SD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173369003464",
    },
    {
        "school": "Ernest F Kolb Elem School",
        "district": "Ridgeland SD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173369003465",
    },
    {
        "school": "George W Lieb Elem School",
        "district": "Ridgeland SD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173369003466",
    },
    {
        "school": "Harnew Elem School",
        "district": "Ridgeland SD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173369003467",
    },
    {
        "school": "Simmons Middle School",
        "district": "Ridgeland SD 122",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173369003468",
    },
    {
        "school": "Ridgewood Comm High School",
        "district": "Ridgewood CHSD 234",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173372003469",
    },
    {
        "school": "Lincoln Elem School",
        "district": "River Forest SD 90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173381003471",
    },
    {
        "school": "Roosevelt School",
        "district": "River Forest SD 90",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173381003472",
    },
    {
        "school": "Willard Elem School",
        "district": "River Forest SD 90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173381003475",
    },
    {
        "school": "River Grove Elem School",
        "district": "River Grove SD 85-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173384003476",
    },
    {
        "school": "Euclid Elem School",
        "district": "River Trails SD 26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173387003477",
    },
    {
        "school": "Indian Grove Elem School",
        "district": "River Trails SD 26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173387003478",
    },
    {
        "school": "River Trails Middle School",
        "district": "River Trails SD 26",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173387003480",
    },
    {
        "school": "A F Ames Elem School",
        "district": "Riverside SD 96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173399003491",
    },
    {
        "school": "Blythe Park Elem School",
        "district": "Riverside SD 96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173399003492",
    },
    {
        "school": "Central Elem School",
        "district": "Riverside SD 96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173399003493",
    },
    {
        "school": "Hollywood Elem School",
        "district": "Riverside SD 96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173399003494",
    },
    {
        "school": "L J Hauser Jr High School",
        "district": "Riverside SD 96",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173399003495",
    },
    {
        "school": "Riverside Brookfield Twp HS",
        "district": "Riverside-Brookfield Twp SD 208",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173402003496",
    },
    {
        "school": "Helen Keller JHS",
        "district": "Schaumburg CCSD 54",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474000707",
    },
    {
        "school": "Lincoln Prairie School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003420",
    },
    {
        "school": "Adlai Stevenson Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003631",
    },
    {
        "school": "Adolph Link Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003632",
    },
    {
        "school": "Albert Einstein Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003633",
    },
    {
        "school": "Anne Fox Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003634",
    },
    {
        "school": "Campanelli Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003635",
    },
    {
        "school": "Buzz Aldrin Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003636",
    },
    {
        "school": "Dwight D Eisenhower JHS",
        "district": "Schaumburg CCSD 54",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003637",
    },
    {
        "school": "Enders-Salk Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003638",
    },
    {
        "school": "Fairview Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003640",
    },
    {
        "school": "Frederick Nerge Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003641",
    },
    {
        "school": "Hanover Highlands Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003642",
    },
    {
        "school": "Hoover Math and Science Academy",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003645",
    },
    {
        "school": "Jane Addams JHS",
        "district": "Schaumburg CCSD 54",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003646",
    },
    {
        "school": "John Muir Literacy Academy",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003647",
    },
    {
        "school": "Lakeview Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003648",
    },
    {
        "school": "MacArthur Intrntl Spanish Acad",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003649",
    },
    {
        "school": "Michael Collins Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003650",
    },
    {
        "school": "Nathan Hale Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003651",
    },
    {
        "school": "Neil Armstrong Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003652",
    },
    {
        "school": "Robert Frost JHS",
        "district": "Schaumburg CCSD 54",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003653",
    },
    {
        "school": "Thomas Dooley Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003656",
    },
    {
        "school": "Winston Churchill Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474003658",
    },
    {
        "school": "Elizabeth Blackwell Elem School",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474004427",
    },
    {
        "school": "Margaret Mead JHS",
        "district": "Schaumburg CCSD 54",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474004428",
    },
    {
        "school": "Everett Dirksen Elementary Sch",
        "district": "Schaumburg CCSD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474005450",
    },
    {
        "school": "Rosemont Elem School",
        "district": "Rosemont ESD 78",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173477003659",
    },
    {
        "school": "Sandridge Elem School",
        "district": "Sandridge SD 172",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173534003690",
    },
    {
        "school": "Rickover Jr High School",
        "district": "CCSD 168",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173546003698",
    },
    {
        "school": "Strassburg Elem",
        "district": "CCSD 168",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173546003699",
    },
    {
        "school": "Wagoner Elem",
        "district": "CCSD 168",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173546003700",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Schiller Park SD 81",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173564003711",
    },
    {
        "school": "John F Kennedy Elem School",
        "district": "Schiller Park SD 81",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173564003712",
    },
    {
        "school": "Washington Elem School",
        "district": "Schiller Park SD 81",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173564003713",
    },
    {
        "school": "Neil Armstrong Elem School",
        "district": "ESD 159",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173630003751",
    },
    {
        "school": "Sieden Prairie Elementary School",
        "district": "ESD 159",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173630003752",
    },
    {
        "school": "Woodgate Elem School",
        "district": "ESD 159",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173630003753",
    },
    {
        "school": "Marya Yates Elementary School",
        "district": "ESD 159",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173630004834",
    },
    {
        "school": "Devonshire Elem School",
        "district": "Skokie SD 68",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173645003756",
    },
    {
        "school": "Highland Elementary School",
        "district": "Skokie SD 68",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173645003757",
    },
    {
        "school": "Jane Stenson School",
        "district": "Skokie SD 68",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173645003758",
    },
    {
        "school": "Old Orchard Jr High School",
        "district": "Skokie SD 68",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173645003759",
    },
    {
        "school": "Lincoln Jr High School",
        "district": "Skokie SD 69",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173648003760",
    },
    {
        "school": "Madison Elem School",
        "district": "Skokie SD 69",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173648003761",
    },
    {
        "school": "Thomas Edison Elem School",
        "district": "Skokie SD 69",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173648003762",
    },
    {
        "school": "McKinley Elem School",
        "district": "South Holland SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173672001600",
    },
    {
        "school": "Greenwood Elem School",
        "district": "South Holland SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173672003776",
    },
    {
        "school": "McKinley Jr High School",
        "district": "South Holland SD 150",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173672003779",
    },
    {
        "school": "Coolidge Middle School",
        "district": "South Holland SD 151",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173675003780",
    },
    {
        "school": "Eisenhower School",
        "district": "South Holland SD 151",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173675003781",
    },
    {
        "school": "Madison School",
        "district": "South Holland SD 151",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173675003782",
    },
    {
        "school": "Taft School",
        "district": "South Holland SD 151",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173675003783",
    },
    {
        "school": "Edward J Tobin Elem School",
        "district": "Burbank SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173681003786",
    },
    {
        "school": "J B Kennedy Elem School",
        "district": "Burbank SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173681003787",
    },
    {
        "school": "Maddock Elementary School",
        "district": "Burbank SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173681003788",
    },
    {
        "school": "Luther Burbank Elem School",
        "district": "Burbank SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173681003790",
    },
    {
        "school": "F B Mccord Elem School",
        "district": "Burbank SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173681003791",
    },
    {
        "school": "Richard Byrd Elementary School",
        "district": "Burbank SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173681003794",
    },
    {
        "school": "Columbia Central School",
        "district": "Steger SD 194",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173768003880",
    },
    {
        "school": "Steger Primary Center",
        "district": "Steger SD 194",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173768003884",
    },
    {
        "school": "Charles J Sahs Elem School",
        "district": "Central Stickney SD 110",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173786003888",
    },
    {
        "school": "Nathan Hale Elem School",
        "district": "Sunnybrook SD 171",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173837003916",
    },
    {
        "school": "Heritage Middle School",
        "district": "Sunnybrook SD 171",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173837005543",
    },
    {
        "school": "Middlefork Primary School",
        "district": "Sunset Ridge SD 29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173840003917",
    },
    {
        "school": "Sunset Ridge Elem School",
        "district": "Sunset Ridge SD 29",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173840003918",
    },
    {
        "school": "Wolcott School",
        "district": "Thornton SD 154",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173891005071",
    },
    {
        "school": "Thornton Fractnl No High School",
        "district": "Thornton Fractional Twp HSD 215",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173894003952",
    },
    {
        "school": "Thornton Fractnl So High School",
        "district": "Thornton Fractional Twp HSD 215",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173894003953",
    },
    {
        "school": "Thornridge High School",
        "district": "Thornton Twp HSD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173897003954",
    },
    {
        "school": "Thornton Township High School",
        "district": "Thornton Twp HSD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173897003955",
    },
    {
        "school": "Thornwood High School",
        "district": "Thornton Twp HSD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173897003956",
    },
    {
        "school": "Arnold W Kruse Ed Center",
        "district": "CCSD 146",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173903003957",
    },
    {
        "school": "Bert H Fulton School",
        "district": "CCSD 146",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173903003958",
    },
    {
        "school": "Central Middle School",
        "district": "CCSD 146",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173903003959",
    },
    {
        "school": "Memorial Elem School",
        "district": "CCSD 146",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173903003961",
    },
    {
        "school": "Walter F Fierke Ed Center",
        "district": "CCSD 146",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173903003962",
    },
    {
        "school": "Union Ridge Elem School",
        "district": "Union Ridge SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173978004006",
    },
    {
        "school": "Wentworth Jr High School",
        "district": "Calumet City SD 155",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174152003426",
    },
    {
        "school": "Wentworth Intermediate School",
        "district": "Calumet City SD 155",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174152003427",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Calumet City SD 155",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174152004883",
    },
    {
        "school": "Henry Winkelman Elem School",
        "district": "West Northfield SD 31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174170004175",
    },
    {
        "school": "Field School",
        "district": "West Northfield SD 31",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174170004176",
    },
    {
        "school": "Westchester Primary School",
        "district": "Westchester SD 92-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174179000716",
    },
    {
        "school": "Westchester Intermediate School",
        "district": "Westchester SD 92-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174179004184",
    },
    {
        "school": "Westchester Middle School",
        "district": "Westchester SD 92-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174179004185",
    },
    {
        "school": "Field Park Elem School",
        "district": "Western Springs SD 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174182004187",
    },
    {
        "school": "Forest Hills Elem School",
        "district": "Western Springs SD 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174182004188",
    },
    {
        "school": "John Laidlaw Elem School",
        "district": "Western Springs SD 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174182004189",
    },
    {
        "school": "McClure Jr High School",
        "district": "Western Springs SD 101",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174182004192",
    },
    {
        "school": "Jack London Middle School",
        "district": "Wheeling CCSD 21",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221001184",
    },
    {
        "school": "Mark Twain Elem School",
        "district": "Wheeling CCSD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221004228",
    },
    {
        "school": "Cooper Middle School",
        "district": "Wheeling CCSD 21",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221004230",
    },
    {
        "school": "J W Riley Elem School",
        "district": "Wheeling CCSD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221004231",
    },
    {
        "school": "Robert Frost Elem School",
        "district": "Wheeling CCSD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221004232",
    },
    {
        "school": "Edgar A Poe Elem School",
        "district": "Wheeling CCSD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221004233",
    },
    {
        "school": "Booth Tarkington Elem School",
        "district": "Wheeling CCSD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221004234",
    },
    {
        "school": "Henry W Longfellow Elem School",
        "district": "Wheeling CCSD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221004236",
    },
    {
        "school": "Eugene Field Elem School",
        "district": "Wheeling CCSD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221004237",
    },
    {
        "school": "Walt Whitman Elem School",
        "district": "Wheeling CCSD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221004238",
    },
    {
        "school": "Oliver W Holmes Middle School",
        "district": "Wheeling CCSD 21",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221004240",
    },
    {
        "school": "Joyce Kilmer Elem School",
        "district": "Wheeling CCSD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221004242",
    },
    {
        "school": "Willow Springs Elem School",
        "district": "Willow Springs SD 108",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174257004273",
    },
    {
        "school": "Highcrest Middle School",
        "district": "Wilmette SD 39",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174260001195",
    },
    {
        "school": "Central Elem School",
        "district": "Wilmette SD 39",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174260004275",
    },
    {
        "school": "Harper Elem School",
        "district": "Wilmette SD 39",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174260004276",
    },
    {
        "school": "McKenzie Elem School",
        "district": "Wilmette SD 39",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174260004278",
    },
    {
        "school": "Romona Elem School",
        "district": "Wilmette SD 39",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174260004279",
    },
    {
        "school": "Wilmette Junior High School",
        "district": "Wilmette SD 39",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174260004280",
    },
    {
        "school": "The Skokie School",
        "district": "Winnetka SD 36",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174284002469",
    },
    {
        "school": "Carleton W Washburne School",
        "district": "Winnetka SD 36",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174284004298",
    },
    {
        "school": "Crow Island Elem School",
        "district": "Winnetka SD 36",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174284004299",
    },
    {
        "school": "Greeley Elem School",
        "district": "Winnetka SD 36",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174284004300",
    },
    {
        "school": "Hubbard Woods Elem School",
        "district": "Winnetka SD 36",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174284004301",
    },
    {
        "school": "Worth Elem School",
        "district": "Worth SD 127",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174338004338",
    },
    {
        "school": "Worth Jr High School",
        "district": "Worth SD 127",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174338004339",
    },
    {
        "school": "Worthwoods Elem School",
        "district": "Worth SD 127",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174338004342",
    },
    {
        "school": "KEC Central EFE 170",
        "district": "De Kalb ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017802632",
    },
    {
        "school": "Cortland Elementary School",
        "district": "DeKalb CUSD 428",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200000468",
    },
    {
        "school": "DeKalb High School",
        "district": "DeKalb CUSD 428",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200001449",
    },
    {
        "school": "Huntley Middle School",
        "district": "DeKalb CUSD 428",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200001450",
    },
    {
        "school": "Jefferson Elem School",
        "district": "DeKalb CUSD 428",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200001451",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "DeKalb CUSD 428",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200001452",
    },
    {
        "school": "Littlejohn Elem School",
        "district": "DeKalb CUSD 428",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200001453",
    },
    {
        "school": "Gwendolyn Brooks Elem Sch",
        "district": "DeKalb CUSD 428",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200003572",
    },
    {
        "school": "Malta Elementary School",
        "district": "DeKalb CUSD 428",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200004019",
    },
    {
        "school": "Tyler Elementary School",
        "district": "DeKalb CUSD 428",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200005275",
    },
    {
        "school": "Genoa-Kingston Middle School",
        "district": "Genoa Kingston CUSD 424",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171641001959",
    },
    {
        "school": "Genoa-Kingston High School",
        "district": "Genoa Kingston CUSD 424",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171641001960",
    },
    {
        "school": "Kingston Elementary School",
        "district": "Genoa Kingston CUSD 424",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171641001961",
    },
    {
        "school": "Hinckley-Big Rock Elem Sch",
        "district": "Hinckley Big Rock CUSD 429",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171926002212",
    },
    {
        "school": "Hinckley-Big Rock High School",
        "district": "Hinckley Big Rock CUSD 429",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171926002213",
    },
    {
        "school": "Hiawatha Jr/Sr High School",
        "district": "Hiawatha CUSD 426",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172130002403",
    },
    {
        "school": "Hiawatha Elem Sch PreK-5",
        "district": "Hiawatha CUSD 426",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172130004685",
    },
    {
        "school": "Lynn G Haskin Elementary School",
        "district": "Sandwich CUSD 430",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173537003691",
    },
    {
        "school": "Prairie View Elem School",
        "district": "Sandwich CUSD 430",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173537003692",
    },
    {
        "school": "Sandwich Community High School",
        "district": "Sandwich CUSD 430",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173537003693",
    },
    {
        "school": "W W Woodbury Elem School",
        "district": "Sandwich CUSD 430",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173537003695",
    },
    {
        "school": "Sandwich Middle School",
        "district": "Sandwich CUSD 430",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173537004314",
    },
    {
        "school": "Indian Creek Middle School",
        "district": "Indian Creek CUSD 425",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173597000455",
    },
    {
        "school": "Indian Creek Elementary School",
        "district": "Indian Creek CUSD 425",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173597003732",
    },
    {
        "school": "Indian Creek High School",
        "district": "Indian Creek CUSD 425",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173597003733",
    },
    {
        "school": "Somonauk High School",
        "district": "Somonauk CUSD 432",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173657003764",
    },
    {
        "school": "Somonauk Middle School",
        "district": "Somonauk CUSD 432",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173657004322",
    },
    {
        "school": "James R Wood Elem School",
        "district": "Somonauk CUSD 432",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173657004429",
    },
    {
        "school": "South Prairie Elementary School",
        "district": "Sycamore CUSD 427",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173846002633",
    },
    {
        "school": "North Elementary School",
        "district": "Sycamore CUSD 427",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173846003919",
    },
    {
        "school": "Southeast Elem School",
        "district": "Sycamore CUSD 427",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173846003920",
    },
    {
        "school": "West Elem School",
        "district": "Sycamore CUSD 427",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173846003921",
    },
    {
        "school": "Sycamore High School",
        "district": "Sycamore CUSD 427",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173846003922",
    },
    {
        "school": "Sycamore Middle School",
        "district": "Sycamore CUSD 427",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173846003923",
    },
    {
        "school": "Philip J Rock Center and School",
        "district": "Philip J Rock Center and School",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003905229",
    },
    {
        "school": "Lincoln Academy",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015201401",
    },
    {
        "school": "Partners for Success-Old Mill Sch",
        "district": "DuPage ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017902654",
    },
    {
        "school": "Army Trail Elem School",
        "district": "Addison SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170315000005",
    },
    {
        "school": "Fullerton Elem School",
        "district": "Addison SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170315000006",
    },
    {
        "school": "Indian Trail Jr High School",
        "district": "Addison SD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170315000007",
    },
    {
        "school": "Lake Park Elem School",
        "district": "Addison SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170315000008",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Addison SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170315000009",
    },
    {
        "school": "Wesley Elem School",
        "district": "Addison SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170315000010",
    },
    {
        "school": "Stone Elem School",
        "district": "Addison SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170315000011",
    },
    {
        "school": "Ardmore Elem School",
        "district": "Addison SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170315000478",
    },
    {
        "school": "Benjamin Middle School",
        "district": "Benjamin SD 25",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170588000264",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Benjamin SD 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170588000265",
    },
    {
        "school": "Blackhawk Middle School",
        "district": "Bensenville SD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170591000266",
    },
    {
        "school": "W A Johnson Sch",
        "district": "Bensenville SD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170591000269",
    },
    {
        "school": "Tioga Elementary School",
        "district": "Bensenville SD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170591000270",
    },
    {
        "school": "Dujardin Elementary School",
        "district": "Bloomingdale SD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170645000315",
    },
    {
        "school": "Westfield Middle School",
        "district": "Bloomingdale SD 13",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170645000316",
    },
    {
        "school": "Erickson Elementary School",
        "district": "Bloomingdale SD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170645000488",
    },
    {
        "school": "Brook Forest Elem School",
        "district": "Butler SD 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170798000405",
    },
    {
        "school": "Butler Junior High School",
        "district": "Butler SD 53",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170798004936",
    },
    {
        "school": "Cass Jr High School",
        "district": "Cass SD 63",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170879000519",
    },
    {
        "school": "Concord Elem School",
        "district": "Cass SD 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170879000520",
    },
    {
        "school": "Elizabeth Ide Elem School",
        "district": "Center Cass SD 66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170897000522",
    },
    {
        "school": "Lakeview Jr High School",
        "district": "Center Cass SD 66",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170897000523",
    },
    {
        "school": "Prairieview Elementary School",
        "district": "Center Cass SD 66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170897004020",
    },
    {
        "school": "Carol Stream Elem School",
        "district": "CCSD 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171047001266",
    },
    {
        "school": "Roy De Shane Elementary School",
        "district": "CCSD 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171047001268",
    },
    {
        "school": "Western Trails Elem School",
        "district": "CCSD 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171047001269",
    },
    {
        "school": "Cloverdale  Elem School",
        "district": "CCSD 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171047004033",
    },
    {
        "school": "Elsie C Johnson Elem Sch",
        "district": "CCSD 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171047004387",
    },
    {
        "school": "Stratford Middle School",
        "district": "CCSD 93",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171047005306",
    },
    {
        "school": "Jay Stream Middle School",
        "district": "CCSD 93",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171047005307",
    },
    {
        "school": "Heritage Lakes Elem School",
        "district": "CCSD 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171047005498",
    },
    {
        "school": "Belle Aire Elem School",
        "district": "Downers Grove GSD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001505",
    },
    {
        "school": "El Sierra Elem School",
        "district": "Downers Grove GSD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001506",
    },
    {
        "school": "Fairmount Elem School",
        "district": "Downers Grove GSD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001507",
    },
    {
        "school": "Herrick Middle School",
        "district": "Downers Grove GSD 58",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001508",
    },
    {
        "school": "Highland Elem School",
        "district": "Downers Grove GSD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001509",
    },
    {
        "school": "Hillcrest Elem School",
        "district": "Downers Grove GSD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001510",
    },
    {
        "school": "Indian Trail Elem School",
        "district": "Downers Grove GSD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001511",
    },
    {
        "school": "Kingsley Elem School",
        "district": "Downers Grove GSD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001512",
    },
    {
        "school": "Lester Elem School",
        "district": "Downers Grove GSD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001513",
    },
    {
        "school": "O Neill Middle School",
        "district": "Downers Grove GSD 58",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001514",
    },
    {
        "school": "Pierce Downer Elem School",
        "district": "Downers Grove GSD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001515",
    },
    {
        "school": "Whittier Elem School",
        "district": "Downers Grove GSD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171254001517",
    },
    {
        "school": "Comm H S Dist 99 - North H S",
        "district": "CHSD 99",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171257001518",
    },
    {
        "school": "Comm H S Dist 99 - South High Sch",
        "district": "CHSD 99",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171257001519",
    },
    {
        "school": "Prairieview Elementary School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371000070",
    },
    {
        "school": "Sycamore Trails Elementary School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371000073",
    },
    {
        "school": "Horizon Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001681",
    },
    {
        "school": "Wayne Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001706",
    },
    {
        "school": "Spring Trail Elementary School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001725",
    },
    {
        "school": "Bartlett High School",
        "district": "SD U-46",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371002108",
    },
    {
        "school": "Centennial School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371005566",
    },
    {
        "school": "Addison Trail High School",
        "district": "DuPage HSD 88",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171394001737",
    },
    {
        "school": "Willowbrook High School",
        "district": "DuPage HSD 88",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171394001738",
    },
    {
        "school": "Bryan Middle School",
        "district": "Elmhurst SD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001740",
    },
    {
        "school": "Churchville Middle School",
        "district": "Elmhurst SD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001741",
    },
    {
        "school": "Conrad Fischer Elem School",
        "district": "Elmhurst SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001742",
    },
    {
        "school": "Edison Elem School",
        "district": "Elmhurst SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001745",
    },
    {
        "school": "Emerson Elem School",
        "district": "Elmhurst SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001746",
    },
    {
        "school": "Field Elem School",
        "district": "Elmhurst SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001747",
    },
    {
        "school": "Hawthorne Elem School",
        "district": "Elmhurst SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001748",
    },
    {
        "school": "Jackson Elem School",
        "district": "Elmhurst SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001749",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Elmhurst SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001750",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Elmhurst SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001751",
    },
    {
        "school": "Sandburg Middle  School",
        "district": "Elmhurst SD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001754",
    },
    {
        "school": "York Comm High School",
        "district": "Elmhurst SD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397001755",
    },
    {
        "school": "Early Childhood",
        "district": "Elmhurst SD 205",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171397002095",
    },
    {
        "school": "Fenton High School",
        "district": "Fenton CHSD 100",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171503001832",
    },
    {
        "school": "Abraham Lincoln Elem School",
        "district": "Glen Ellyn SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171680001981",
    },
    {
        "school": "Benjamin Franklin Elem School",
        "district": "Glen Ellyn SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171680001982",
    },
    {
        "school": "Churchill Elem School",
        "district": "Glen Ellyn SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171680001983",
    },
    {
        "school": "Forest Glen Elem School",
        "district": "Glen Ellyn SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171680001984",
    },
    {
        "school": "Hadley Junior High School",
        "district": "Glen Ellyn SD 41",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171680001987",
    },
    {
        "school": "Glenbard East High School",
        "district": "Glenbard Twp HSD 87",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171683001988",
    },
    {
        "school": "Glenbard North High School",
        "district": "Glenbard Twp HSD 87",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171683001989",
    },
    {
        "school": "Glenbard South High School",
        "district": "Glenbard Twp HSD 87",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171683001990",
    },
    {
        "school": "Glenbard West High School",
        "district": "Glenbard Twp HSD 87",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171683001991",
    },
    {
        "school": "Edgewood Elem School",
        "district": "Woodridge SD 68",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171704002010",
    },
    {
        "school": "Goodrich Elem School",
        "district": "Woodridge SD 68",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171704002011",
    },
    {
        "school": "John L Sipley Elem School",
        "district": "Woodridge SD 68",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171704002012",
    },
    {
        "school": "Meadowview Elem School",
        "district": "Woodridge SD 68",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171704002013",
    },
    {
        "school": "Thomas Jefferson Jr High School",
        "district": "Woodridge SD 68",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171704002014",
    },
    {
        "school": "Willow Creek Elem School",
        "district": "Woodridge SD 68",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171704002015",
    },
    {
        "school": "William F Murphy Elem School",
        "district": "Woodridge SD 68",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171704002016",
    },
    {
        "school": "Gower Middle School",
        "district": "Gower SD 62",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171716002020",
    },
    {
        "school": "Gower West Elem School",
        "district": "Gower SD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171716002021",
    },
    {
        "school": "Elm Elem School",
        "district": "Hinsdale CCSD 181",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171929002214",
    },
    {
        "school": "Hinsdale Middle School",
        "district": "Hinsdale CCSD 181",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171929002215",
    },
    {
        "school": "Madison Elem School",
        "district": "Hinsdale CCSD 181",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171929002216",
    },
    {
        "school": "Monroe Elem School",
        "district": "Hinsdale CCSD 181",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171929002217",
    },
    {
        "school": "Oak Elem School",
        "district": "Hinsdale CCSD 181",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171929002218",
    },
    {
        "school": "Prospect Elem School",
        "district": "Hinsdale CCSD 181",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171929002219",
    },
    {
        "school": "The Lane Elem School",
        "district": "Hinsdale CCSD 181",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171929002220",
    },
    {
        "school": "Walker School",
        "district": "Hinsdale CCSD 181",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171929002221",
    },
    {
        "school": "Clarendon Hills Middle School",
        "district": "Hinsdale CCSD 181",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171929004036",
    },
    {
        "school": "Hinsdale Central High School",
        "district": "Hinsdale Twp HSD 86",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171932002222",
    },
    {
        "school": "Hinsdale South High School",
        "district": "Hinsdale Twp HSD 86",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171932002223",
    },
    {
        "school": "Elmer H Franzen Intermediate Sch",
        "district": "Itasca SD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172022002274",
    },
    {
        "school": "F E Peacock Middle School",
        "district": "Itasca SD 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172022002275",
    },
    {
        "school": "Raymond Benson Primary School",
        "district": "Itasca SD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172022002276",
    },
    {
        "school": "Waterbury Elem School",
        "district": "Keeneyville SD 20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172088002374",
    },
    {
        "school": "Spring Wood Middle School",
        "district": "Keeneyville SD 20",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172088002375",
    },
    {
        "school": "Greenbrook Elem School",
        "district": "Keeneyville SD 20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172088004682",
    },
    {
        "school": "Eisenhower Jr High School",
        "district": "Darien SD 61",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172145002411",
    },
    {
        "school": "Mark DeLay School",
        "district": "Darien SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172145002413",
    },
    {
        "school": "Lace Elem School",
        "district": "Darien SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172145002414",
    },
    {
        "school": "Lake Park High School",
        "district": "Lake Park CHSD 108",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172184002454",
    },
    {
        "school": "Lisle High School",
        "district": "Lisle CUSD 202",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172320002553",
    },
    {
        "school": "Lisle Jr High School",
        "district": "Lisle CUSD 202",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172320002554",
    },
    {
        "school": "Glenn Westlake Middle School",
        "district": "Lombard SD 44",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172346000104",
    },
    {
        "school": "Madison Elementary School",
        "district": "Lombard SD 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172346000107",
    },
    {
        "school": "Butterfield Elem School",
        "district": "Lombard SD 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172346002575",
    },
    {
        "school": "Wm Hammerschmidt Elem School",
        "district": "Lombard SD 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172346002576",
    },
    {
        "school": "Park View Elem School",
        "district": "Lombard SD 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172346002577",
    },
    {
        "school": "Pleasant Lane Elem School",
        "district": "Lombard SD 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172346002580",
    },
    {
        "school": "Manor Hill Elem School",
        "district": "Lombard SD 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172346002583",
    },
    {
        "school": "Holmes Elem School",
        "district": "Maercker SD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172400002623",
    },
    {
        "school": "Maercker Elem School",
        "district": "Maercker SD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172400002624",
    },
    {
        "school": "Westview Hills Middle School",
        "district": "Maercker SD 60",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172400002625",
    },
    {
        "school": "Black Hawk Elem School",
        "district": "Marquardt SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172478002686",
    },
    {
        "school": "G Stanley Hall Elem School",
        "district": "Marquardt SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172478002687",
    },
    {
        "school": "Marquardt Middle School",
        "district": "Marquardt SD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172478002688",
    },
    {
        "school": "Reskin Elem School",
        "district": "Marquardt SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172478002689",
    },
    {
        "school": "Winnebago Elem School",
        "district": "Marquardt SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172478002690",
    },
    {
        "school": "Medinah Middle School",
        "district": "Medinah SD 11",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172550002762",
    },
    {
        "school": "Medinah Intermediate School",
        "district": "Medinah SD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172550002763",
    },
    {
        "school": "Medinah Primary School",
        "district": "Medinah SD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172550002764",
    },
    {
        "school": "Beebe Elem School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002929",
    },
    {
        "school": "Ellsworth Elem School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002930",
    },
    {
        "school": "Elmwood Elem School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002931",
    },
    {
        "school": "Highlands Elem School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002932",
    },
    {
        "school": "Jefferson Jr High School",
        "district": "Naperville CUSD 203",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002933",
    },
    {
        "school": "Lincoln Jr High School",
        "district": "Naperville CUSD 203",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002934",
    },
    {
        "school": "Madison Jr High School",
        "district": "Naperville CUSD 203",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002935",
    },
    {
        "school": "Maplebrook Elem School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002936",
    },
    {
        "school": "Mill Street Elem School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002937",
    },
    {
        "school": "Naper Elem School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002938",
    },
    {
        "school": "Naperville Central High School",
        "district": "Naperville CUSD 203",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002939",
    },
    {
        "school": "Naperville North High School",
        "district": "Naperville CUSD 203",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002940",
    },
    {
        "school": "Prairie Elem School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002941",
    },
    {
        "school": "Scott Elementary School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002942",
    },
    {
        "school": "Steeple Run Elem School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002943",
    },
    {
        "school": "Washington Jr High School",
        "district": "Naperville CUSD 203",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771002944",
    },
    {
        "school": "Ranch View Elementary School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771005182",
    },
    {
        "school": "Kennedy Junior High School",
        "district": "Naperville CUSD 203",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771005436",
    },
    {
        "school": "Meadow Glens Elementary School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771005437",
    },
    {
        "school": "Burr Ridge Middle School",
        "district": "CCSD 180",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173051003171",
    },
    {
        "school": "Anne M Jeans Elem School",
        "district": "CCSD 180",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173051003172",
    },
    {
        "school": "Americana Intermediate School",
        "district": "Queen Bee SD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173297003413",
    },
    {
        "school": "Glenside Middle School",
        "district": "Queen Bee SD 16",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173297003415",
    },
    {
        "school": "Roselle Middle School",
        "district": "Roselle SD 12",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173471003629",
    },
    {
        "school": "Spring Hills Elem School",
        "district": "Roselle SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173471003630",
    },
    {
        "school": "John E Albright Middle School",
        "district": "Salt Creek SD 48",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173522003682",
    },
    {
        "school": "Salt Creek Elem School",
        "district": "Salt Creek SD 48",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173522003683",
    },
    {
        "school": "Stella May Swartz Elem School",
        "district": "Salt Creek SD 48",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173522003684",
    },
    {
        "school": "Stevenson School",
        "district": "SD 45 DuPage County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174035001402",
    },
    {
        "school": "Ardmore Elem School",
        "district": "SD 45 DuPage County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174035004052",
    },
    {
        "school": "North Elem School",
        "district": "SD 45 DuPage County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174035004055",
    },
    {
        "school": "Jackson Middle School",
        "district": "SD 45 DuPage County",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174035004057",
    },
    {
        "school": "Jefferson Middle School",
        "district": "SD 45 DuPage County",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174035004058",
    },
    {
        "school": "Schafer Elem School",
        "district": "SD 45 DuPage County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174035004059",
    },
    {
        "school": "Westmore Elem School",
        "district": "SD 45 DuPage County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174035004061",
    },
    {
        "school": "York Center Elem School",
        "district": "SD 45 DuPage County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174035004062",
    },
    {
        "school": "Community High School",
        "district": "CHSD 94",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174044004071",
    },
    {
        "school": "Arbor View Elem School",
        "district": "CCSD 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174050004076",
    },
    {
        "school": "Briar Glen Elem School",
        "district": "CCSD 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174050004077",
    },
    {
        "school": "Glen Crest Middle School",
        "district": "CCSD 89",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174050004078",
    },
    {
        "school": "Park View Elem School",
        "district": "CCSD 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174050004079",
    },
    {
        "school": "Westfield Elem School",
        "district": "CCSD 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174050004080",
    },
    {
        "school": "Currier Elementary School",
        "district": "West Chicago ESD 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174155000775",
    },
    {
        "school": "Wegner Elementary School",
        "district": "West Chicago ESD 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174155000789",
    },
    {
        "school": "Gary Elementary School",
        "district": "West Chicago ESD 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174155004159",
    },
    {
        "school": "Indian Knoll Elem School",
        "district": "West Chicago ESD 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174155004160",
    },
    {
        "school": "Pioneer Elem School",
        "district": "West Chicago ESD 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174155004162",
    },
    {
        "school": "Turner Elem School",
        "district": "West Chicago ESD 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174155004163",
    },
    {
        "school": "Leman Middle School",
        "district": "West Chicago ESD 33",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174155004164",
    },
    {
        "school": "Reba O Steck Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169000219",
    },
    {
        "school": "Francis Granger Middle School",
        "district": "Indian Prairie CUSD 204",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169000491",
    },
    {
        "school": "Gwendolyn Brooks Elementary",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169001415",
    },
    {
        "school": "White Eagle Elementary",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169001420",
    },
    {
        "school": "Prairie Children Preschool",
        "district": "Indian Prairie CUSD 204",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169001618",
    },
    {
        "school": "Mary Lou Cowlishaw Elementary",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169002094",
    },
    {
        "school": "Peter M Gombert Elementary Sch",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169002657",
    },
    {
        "school": "Still Middle School",
        "district": "Indian Prairie CUSD 204",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169003597",
    },
    {
        "school": "Nancy Young Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169003608",
    },
    {
        "school": "Indian Plains Alternative School",
        "district": "Indian Prairie CUSD 204",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169003613",
    },
    {
        "school": "Thayer J Hill Middle School",
        "district": "Indian Prairie CUSD 204",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169004170",
    },
    {
        "school": "Longwood Elem School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169004172",
    },
    {
        "school": "Waubonsie Valley High School",
        "district": "Indian Prairie CUSD 204",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169004173",
    },
    {
        "school": "Brookdale Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169005210",
    },
    {
        "school": "Georgetown Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169005294",
    },
    {
        "school": "McCarty Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169005458",
    },
    {
        "school": "May Watts Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169005460",
    },
    {
        "school": "C E Miller Elem School",
        "district": "CUSD 201",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174198004199",
    },
    {
        "school": "J T Manning Elem School",
        "district": "CUSD 201",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174198004200",
    },
    {
        "school": "Westmont High School",
        "district": "CUSD 201",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174198004202",
    },
    {
        "school": "Westmont Jr High School",
        "district": "CUSD 201",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174198004203",
    },
    {
        "school": "Jefferson Early Childhood Center",
        "district": "CUSD 200",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218002088",
    },
    {
        "school": "Carl Sandburg Elem School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004207",
    },
    {
        "school": "Edison Middle School",
        "district": "CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004209",
    },
    {
        "school": "Emerson Elem School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004210",
    },
    {
        "school": "Franklin Middle School",
        "district": "CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004211",
    },
    {
        "school": "Hawthorne Elem School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004212",
    },
    {
        "school": "Lincoln Elem School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004214",
    },
    {
        "school": "Longfellow Elem School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004215",
    },
    {
        "school": "Lowell Elem School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004216",
    },
    {
        "school": "Madison Elem School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004217",
    },
    {
        "school": "Pleasant Hill Elem School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004219",
    },
    {
        "school": "Wheaton Warrenville South H S",
        "district": "CUSD 200",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004222",
    },
    {
        "school": "Wheaton North High School",
        "district": "CUSD 200",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004223",
    },
    {
        "school": "Whittier Elem School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004225",
    },
    {
        "school": "Wiesbrook Elem School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004226",
    },
    {
        "school": "Bower Elem School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218004437",
    },
    {
        "school": "Hubble Middle School",
        "district": "CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218005077",
    },
    {
        "school": "Washington Elementary School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218005461",
    },
    {
        "school": "Clifford Johnson School",
        "district": "CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218005526",
    },
    {
        "school": "Monroe Middle School",
        "district": "CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174218005558",
    },
    {
        "school": "Winfield Primary School",
        "district": "Winfield SD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174272004292",
    },
    {
        "school": "Oakbrook Elem School",
        "district": "Wood Dale SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174302004316",
    },
    {
        "school": "Westview Elem School",
        "district": "Wood Dale SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174302004317",
    },
    {
        "school": "Wood Dale Jr High School",
        "district": "Wood Dale SD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174302004318",
    },
    {
        "school": "Early Childhood Education Center",
        "district": "Wood Dale SD 7",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174302005212",
    },
    {
        "school": "Premier Academy Morris",
        "district": "Grundy/Kendall ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018402707",
    },
    {
        "school": "Braceville Elem School",
        "district": "Braceville SD 75",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170684000354",
    },
    {
        "school": "Coal City Elem School",
        "district": "Coal City CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171053001270",
    },
    {
        "school": "Coal City High School",
        "district": "Coal City CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171053001271",
    },
    {
        "school": "Coal City Middle School",
        "district": "Coal City CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171053001272",
    },
    {
        "school": "Coal City Intermediate School",
        "district": "Coal City CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171053004056",
    },
    {
        "school": "Gardner Elem School",
        "district": "Gardner CCSD 72C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171623001941",
    },
    {
        "school": "Gardner-South Wilmington Twp H S",
        "district": "Gardner S Wilmington Twp HSD 73",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171626001942",
    },
    {
        "school": "Mazon-Verona-Kinsman Elem School",
        "district": "Mazon-Verona-Kinsman ESD 2C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172519002749",
    },
    {
        "school": "Mazon-Verona-Kinsman Middle Sch",
        "district": "Mazon-Verona-Kinsman ESD 2C",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172519002750",
    },
    {
        "school": "Minooka Intermediate School",
        "district": "Minooka CCSD 201",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172631002099",
    },
    {
        "school": "Minooka Elem School",
        "district": "Minooka CCSD 201",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172631002798",
    },
    {
        "school": "Minooka Jr High School",
        "district": "Minooka CCSD 201",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172631002799",
    },
    {
        "school": "Minooka Community High School",
        "district": "Minooka CHSD 111",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172634002800",
    },
    {
        "school": "Shabbona Middle School",
        "district": "Morris SD 54",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172661002850",
    },
    {
        "school": "White Oak Elementary",
        "district": "Morris SD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172661004379",
    },
    {
        "school": "Morris Community High School",
        "district": "Morris CHSD 101",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172664002851",
    },
    {
        "school": "Nettle Creek Elem School",
        "district": "Nettle Creek CCSD 24C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172793002957",
    },
    {
        "school": "Saratoga Elem School",
        "district": "Saratoga CCSD 60C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173540003696",
    },
    {
        "school": "South Wilmington Grade School",
        "district": "South Wilmington CCSD 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173684003795",
    },
    {
        "school": "Mades-Johnstone Center",
        "district": "Mid-Valley Special Ed Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005404841",
    },
    {
        "school": "Illinois Mathematics and Science",
        "district": "Il Mathematics & Science Academy",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010105114",
    },
    {
        "school": "New Beginnings Regnl Safe Sch Pgm",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019102878",
    },
    {
        "school": "Henry W Cowherd Middle School",
        "district": "Aurora East USD 131",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000040",
    },
    {
        "school": "East High School",
        "district": "Aurora East USD 131",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000143",
    },
    {
        "school": "C F Simmons Middle School",
        "district": "Aurora East USD 131",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000144",
    },
    {
        "school": "C I Johnson Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000145",
    },
    {
        "school": "C M Bardwell Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000146",
    },
    {
        "school": "G N Dieterich Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000147",
    },
    {
        "school": "John Gates Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000148",
    },
    {
        "school": "K D Waldo Middle School",
        "district": "Aurora East USD 131",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000149",
    },
    {
        "school": "L D Brady Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000150",
    },
    {
        "school": "Mabel O Donnell Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000151",
    },
    {
        "school": "Nicholas A Hermes Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000152",
    },
    {
        "school": "Oak Park Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000153",
    },
    {
        "school": "Olney C Allen Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000154",
    },
    {
        "school": "Rose E Krug Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000155",
    },
    {
        "school": "W S Beaupre Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468000156",
    },
    {
        "school": "Edna Rollins Elem School",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468005473",
    },
    {
        "school": "Nicholson Elem School",
        "district": "Aurora West USD 129",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000157",
    },
    {
        "school": "Washington Middle School",
        "district": "Aurora West USD 129",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000160",
    },
    {
        "school": "Hill Elem School",
        "district": "Aurora West USD 129",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000161",
    },
    {
        "school": "Greenman Elem School",
        "district": "Aurora West USD 129",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000163",
    },
    {
        "school": "Freeman Elem School",
        "district": "Aurora West USD 129",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000164",
    },
    {
        "school": "Hall Elem School",
        "district": "Aurora West USD 129",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000165",
    },
    {
        "school": "Schneider Elem School",
        "district": "Aurora West USD 129",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000166",
    },
    {
        "school": "McCleery Elem School",
        "district": "Aurora West USD 129",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000167",
    },
    {
        "school": "Smith Elem School",
        "district": "Aurora West USD 129",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000168",
    },
    {
        "school": "Hope D Wall TMH Child Dev Ctr",
        "district": "Aurora West USD 129",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000169",
    },
    {
        "school": "Goodwin Elem School",
        "district": "Aurora West USD 129",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000172",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Aurora West USD 129",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000173",
    },
    {
        "school": "West Aurora High School",
        "district": "Aurora West USD 129",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471000174",
    },
    {
        "school": "Jewel Middle School",
        "district": "Aurora West USD 129",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471002889",
    },
    {
        "school": "Fearn Elementary School",
        "district": "Aurora West USD 129",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471004402",
    },
    {
        "school": "Todd  Early Childhood Center",
        "district": "Aurora West USD 129",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170471005474",
    },
    {
        "school": "Sunny Hill Elem School",
        "district": "Barrington CUSD 220",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505000193",
    },
    {
        "school": "Alice Gustafson Elem School",
        "district": "Batavia USD 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170522000200",
    },
    {
        "school": "Sam Rotolo Middle Sch",
        "district": "Batavia USD 101",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170522000201",
    },
    {
        "school": "Batavia Sr High School",
        "district": "Batavia USD 101",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170522000202",
    },
    {
        "school": "H C Storm Elem School",
        "district": "Batavia USD 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170522000203",
    },
    {
        "school": "J B Nelson Elem School",
        "district": "Batavia USD 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170522000204",
    },
    {
        "school": "Louise White Elem School",
        "district": "Batavia USD 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170522000205",
    },
    {
        "school": "Grace McWayne Elementary School",
        "district": "Batavia USD 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170522000499",
    },
    {
        "school": "Hoover Wood Elem School",
        "district": "Batavia USD 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170522004397",
    },
    {
        "school": "Central Middle School",
        "district": "Central CUSD 301",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170783000396",
    },
    {
        "school": "Central High School",
        "district": "Central CUSD 301",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170783000397",
    },
    {
        "school": "Howard B Thomas Grade School",
        "district": "Central CUSD 301",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170783000398",
    },
    {
        "school": "Lily Lake Grade School",
        "district": "Central CUSD 301",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170783000399",
    },
    {
        "school": "Prairie View Grade School",
        "district": "Central CUSD 301",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170783004063",
    },
    {
        "school": "Hampshire Middle School",
        "district": "CUSD 300",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000479",
    },
    {
        "school": "Dundee Middle School",
        "district": "CUSD 300",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000480",
    },
    {
        "school": "Dundee Highlands Elem School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000481",
    },
    {
        "school": "Golfview Elem School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000483",
    },
    {
        "school": "Hampshire Elem School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000484",
    },
    {
        "school": "Hampshire High School",
        "district": "CUSD 300",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000485",
    },
    {
        "school": "Dundee-Crown High School",
        "district": "CUSD 300",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000487",
    },
    {
        "school": "Meadowdale Elem School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000492",
    },
    {
        "school": "Parkview Elementary School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000493",
    },
    {
        "school": "Sleepy Hollow Elem School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000494",
    },
    {
        "school": "Westfield Community School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855001729",
    },
    {
        "school": "Oak Ridge School",
        "district": "CUSD 300",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855002897",
    },
    {
        "school": "Carpentersville Middle School",
        "district": "CUSD 300",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855004910",
    },
    {
        "school": "Perry Elementary School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855004912",
    },
    {
        "school": "Lakewood School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855005298",
    },
    {
        "school": "Delacey Family Educ Ctr",
        "district": "CUSD 300",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855005568",
    },
    {
        "school": "Central School Program",
        "district": "SD U-46",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371000833",
    },
    {
        "school": "Abbott Middle School",
        "district": "SD U-46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001664",
    },
    {
        "school": "Century Oaks Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001665",
    },
    {
        "school": "Dream Academy",
        "district": "SD U-46",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001666",
    },
    {
        "school": "Channing Memorial Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001668",
    },
    {
        "school": "Clinton Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001669",
    },
    {
        "school": "Coleman Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001670",
    },
    {
        "school": "Garfield Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001671",
    },
    {
        "school": "Ellis Middle School",
        "district": "SD U-46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001673",
    },
    {
        "school": "Kimball Middle School",
        "district": "SD U-46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001675",
    },
    {
        "school": "Harriet Gifford Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001676",
    },
    {
        "school": "Highland Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001680",
    },
    {
        "school": "Hillcrest Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001683",
    },
    {
        "school": "Larsen Middle School",
        "district": "SD U-46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001689",
    },
    {
        "school": "Larkin High School",
        "district": "SD U-46",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001690",
    },
    {
        "school": "Lowrie Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001692",
    },
    {
        "school": "McKinley Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001694",
    },
    {
        "school": "Ronald D O Neal",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001700",
    },
    {
        "school": "Washington Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001704",
    },
    {
        "school": "Willard Elem School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001707",
    },
    {
        "school": "Fox Meadow Elementary School",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371001724",
    },
    {
        "school": "Creekside Elem",
        "district": "SD U-46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371002887",
    },
    {
        "school": "Geneva 304 Early Learning Center",
        "district": "Geneva CUSD 304",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171638000841",
    },
    {
        "school": "Mill Creek School",
        "district": "Geneva CUSD 304",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171638001743",
    },
    {
        "school": "Geneva Middle Sch South",
        "district": "Geneva CUSD 304",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171638001953",
    },
    {
        "school": "Williamsburg Elem School",
        "district": "Geneva CUSD 304",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171638001954",
    },
    {
        "school": "Geneva Community High School",
        "district": "Geneva CUSD 304",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171638001955",
    },
    {
        "school": "Harrison Street Elem School",
        "district": "Geneva CUSD 304",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171638001956",
    },
    {
        "school": "Western Avenue Elem School",
        "district": "Geneva CUSD 304",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171638001957",
    },
    {
        "school": "Hinckley-Big Rock Middle Sch",
        "district": "Hinckley Big Rock CUSD 429",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171926002211",
    },
    {
        "school": "Kaneland Senior High School",
        "district": "Kaneland CUSD 302",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172448002655",
    },
    {
        "school": "Kaneland John Shields Elem Sch",
        "district": "Kaneland CUSD 302",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172448002910",
    },
    {
        "school": "Kaneland Harter Middle School",
        "district": "Kaneland CUSD 302",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172448005035",
    },
    {
        "school": "Kaneland John Stewart Elem Sch",
        "district": "Kaneland CUSD 302",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172448005036",
    },
    {
        "school": "Wredling Middle School",
        "district": "St Charles CUSD 303",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717001443",
    },
    {
        "school": "Anderson Elem School",
        "district": "St Charles CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717003851",
    },
    {
        "school": "Davis Primary School",
        "district": "St Charles CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717003852",
    },
    {
        "school": "Lincoln Elem School",
        "district": "St Charles CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717003854",
    },
    {
        "school": "Munhall Elem School",
        "district": "St Charles CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717003856",
    },
    {
        "school": "Richmond Intermediate Sch",
        "district": "St Charles CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717003857",
    },
    {
        "school": "St Charles East High School",
        "district": "St Charles CUSD 303",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717003858",
    },
    {
        "school": "Thompson Middle School",
        "district": "St Charles CUSD 303",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717003859",
    },
    {
        "school": "Wasco Elem School",
        "district": "St Charles CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717003860",
    },
    {
        "school": "Wild Rose Elem School",
        "district": "St Charles CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717003861",
    },
    {
        "school": "St Charles North High School",
        "district": "St Charles CUSD 303",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717004064",
    },
    {
        "school": "Bell-Graham Elementary School",
        "district": "St Charles CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717004065",
    },
    {
        "school": "Ferson Creek School",
        "district": "St Charles CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717005452",
    },
    {
        "school": "YEA Program",
        "district": "Grundy/Kendall ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018402725",
    },
    {
        "school": "Oswego GOAL",
        "district": "Grundy/Kendall ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018402767",
    },
    {
        "school": "Lisbon Grade School",
        "district": "Lisbon CCSD 90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172316002552",
    },
    {
        "school": "Newark Comm High School",
        "district": "Newark CHSD 18",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172826002977",
    },
    {
        "school": "Newark Elem School",
        "district": "Newark CCSD 66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172827002978",
    },
    {
        "school": "Millbrook Junior High School",
        "district": "Newark CCSD 66",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172827005319",
    },
    {
        "school": "Old Post Elementary School",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027002101",
    },
    {
        "school": "Boulder Hill Elem School",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027003129",
    },
    {
        "school": "Long Beach Elem School",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027003131",
    },
    {
        "school": "Oswego High School",
        "district": "CUSD 308",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027003132",
    },
    {
        "school": "Thompson Jr High School",
        "district": "CUSD 308",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027003133",
    },
    {
        "school": "Traughber Jr High School",
        "district": "CUSD 308",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027003134",
    },
    {
        "school": "Fox Chase Elementary School",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027004390",
    },
    {
        "school": "Plainfield South High School",
        "district": "Plainfield SD 202",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174004524",
    },
    {
        "school": "Centennial Elem School",
        "district": "Plano CUSD 88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173177003340",
    },
    {
        "school": "P H Miller Elem School",
        "district": "Plano CUSD 88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173177003341",
    },
    {
        "school": "Plano High School",
        "district": "Plano CUSD 88",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173177003342",
    },
    {
        "school": "Plano Middle School",
        "district": "Plano CUSD 88",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173177003343",
    },
    {
        "school": "Yorkville Grade School",
        "district": "Yorkville CUSD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396004359",
    },
    {
        "school": "Yorkville Middle School",
        "district": "Yorkville CUSD 115",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396004360",
    },
    {
        "school": "Bristol Grade School",
        "district": "Yorkville CUSD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396004361",
    },
    {
        "school": "Circle Center Grade School",
        "district": "Yorkville CUSD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396004362",
    },
    {
        "school": "Yorkville High School",
        "district": "Yorkville CUSD 115",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396004363",
    },
    {
        "school": "Kenneth Murphy School",
        "district": "Beach Park CCSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170001000022",
    },
    {
        "school": "Oak Crest School",
        "district": "Beach Park CCSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170001000211",
    },
    {
        "school": "Howe Elementary School",
        "district": "Beach Park CCSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170001000212",
    },
    {
        "school": "Beach Park Middle School",
        "district": "Beach Park CCSD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170001000213",
    },
    {
        "school": "Newport Elem School",
        "district": "Beach Park CCSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170001005141",
    },
    {
        "school": "North Shore Academy",
        "district": "Northern Suburban Spec Ed Dist",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003104501",
    },
    {
        "school": "Gages Lake School",
        "district": "Spec Educ Dist Lake County/Sedol",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005904440",
    },
    {
        "school": "John Powers Center",
        "district": "Spec Educ Dist Lake County/Sedol",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005904468",
    },
    {
        "school": "Laremont School",
        "district": "Spec Educ Dist Lake County/Sedol",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005904472",
    },
    {
        "school": "Cyd Lash Academy",
        "district": "Spec Educ Dist Lake County/Sedol",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005905106",
    },
    {
        "school": "North Chicago Community High Sch",
        "district": "North Chicago SD 187",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011005370",
    },
    {
        "school": "Forrestal Elem School",
        "district": "North Chicago SD 187",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011005372",
    },
    {
        "school": "Indian Trail Elem School",
        "district": "North Shore SD 112",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011902183",
    },
    {
        "school": "Braeside Elem School",
        "district": "North Shore SD 112",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011902185",
    },
    {
        "school": "Edgewood Middle School",
        "district": "North Shore SD 112",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011902186",
    },
    {
        "school": "Ravinia Elem School",
        "district": "North Shore SD 112",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011902189",
    },
    {
        "school": "Sherwood Elem School",
        "district": "North Shore SD 112",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011902191",
    },
    {
        "school": "Northwood Jr High School",
        "district": "North Shore SD 112",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011902198",
    },
    {
        "school": "Oak Terrace Elem School",
        "district": "North Shore SD 112",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011902199",
    },
    {
        "school": "Wayne Thomas Elem School",
        "district": "North Shore SD 112",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011902200",
    },
    {
        "school": "Red Oak Elem School",
        "district": "North Shore SD 112",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011904408",
    },
    {
        "school": "ROE Alternative Prog of Lake Co",
        "district": "Lake ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019302965",
    },
    {
        "school": "Prairie Crossing Charter School",
        "district": "Prairie Crossing Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170021803731",
    },
    {
        "school": "Antioch Upper Grade School",
        "district": "Antioch CCSD 34",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170384000072",
    },
    {
        "school": "Oakland Elementary School",
        "district": "Antioch CCSD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170384000074",
    },
    {
        "school": "W C Petty Elementary School",
        "district": "Antioch CCSD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170384004366",
    },
    {
        "school": "Hillcrest Elementary School",
        "district": "Antioch CCSD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170384004417",
    },
    {
        "school": "Antioch Comm High School",
        "district": "CHSD 117",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170387000075",
    },
    {
        "school": "Allendale School",
        "district": "CHSD 117",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170387005136",
    },
    {
        "school": "Meridian School",
        "district": "Aptakisic-Tripp CCSD 102",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170390000871",
    },
    {
        "school": "Aptakisic Junior High School",
        "district": "Aptakisic-Tripp CCSD 102",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170390004367",
    },
    {
        "school": "Earl Pritchett School",
        "district": "Aptakisic-Tripp CCSD 102",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170390004368",
    },
    {
        "school": "Tripp School",
        "district": "Aptakisic-Tripp CCSD 102",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170390005137",
    },
    {
        "school": "Bannockburn School",
        "district": "Bannockburn SD 106",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170495000186",
    },
    {
        "school": "Barrington High School",
        "district": "Barrington CUSD 220",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505000188",
    },
    {
        "school": "North Barrington Elem School",
        "district": "Barrington CUSD 220",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505000191",
    },
    {
        "school": "Roslyn Road Elem School",
        "district": "Barrington CUSD 220",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505000194",
    },
    {
        "school": "Big Hollow Primary School",
        "district": "Big Hollow SD 38",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170627000306",
    },
    {
        "school": "Big Hollow Middle School",
        "district": "Big Hollow SD 38",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170627000307",
    },
    {
        "school": "Big Hollow Elem School",
        "district": "Big Hollow SD 38",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170627004081",
    },
    {
        "school": "Alan B Shepard Middle School",
        "district": "Deerfield SD 109",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171198001437",
    },
    {
        "school": "Kipling Elem School",
        "district": "Deerfield SD 109",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171198001438",
    },
    {
        "school": "Walden Elem School",
        "district": "Deerfield SD 109",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171198001439",
    },
    {
        "school": "Wilmot Elem School",
        "district": "Deerfield SD 109",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171198001440",
    },
    {
        "school": "South Park Elem School",
        "district": "Deerfield SD 109",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171198001442",
    },
    {
        "school": "Charles J Caruso Middle School",
        "district": "Deerfield SD 109",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171198001444",
    },
    {
        "school": "Diamond Lake Elem School",
        "district": "Diamond Lake SD 76",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171221001474",
    },
    {
        "school": "West Oak Middle School",
        "district": "Diamond Lake SD 76",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171221001475",
    },
    {
        "school": "Fairhaven School",
        "district": "Diamond Lake SD 76",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171221005571",
    },
    {
        "school": "Emmons Grade School",
        "district": "Emmons SD 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171425001767",
    },
    {
        "school": "Stanton School",
        "district": "Fox Lake GSD 114",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171563001877",
    },
    {
        "school": "Lotus School",
        "district": "Fox Lake GSD 114",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171563005507",
    },
    {
        "school": "Fremont Elem School",
        "district": "Fremont SD 79",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171593001909",
    },
    {
        "school": "Fremont Intermediate School",
        "district": "Fremont SD 79",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171593002969",
    },
    {
        "school": "Gavin Central Elementary School",
        "district": "Gavin SD 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171629001943",
    },
    {
        "school": "Gavin South Middle School",
        "district": "Gavin SD 37",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171629001945",
    },
    {
        "school": "Grant Community High School",
        "district": "Grant CHSD 124",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171734002050",
    },
    {
        "school": "Grass Lake Elem School",
        "district": "Grass Lake SD 36",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171749002053",
    },
    {
        "school": "Meadowview School",
        "district": "Grayslake CCSD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171752001752",
    },
    {
        "school": "Grayslake Middle School",
        "district": "Grayslake CCSD 46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171752002054",
    },
    {
        "school": "Frederick School",
        "district": "Grayslake CCSD 46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171752004091",
    },
    {
        "school": "Woodview School",
        "district": "Grayslake CCSD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171752005281",
    },
    {
        "school": "Avon Center Elem School",
        "district": "Grayslake CCSD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171752005313",
    },
    {
        "school": "Grayslake Central High School",
        "district": "Grayslake CHSD 127",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171755002057",
    },
    {
        "school": "Prairie Trail School",
        "district": "Gurnee SD 56",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171780002074",
    },
    {
        "school": "Spaulding Elementary School",
        "district": "Gurnee SD 56",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171780002075",
    },
    {
        "school": "Viking School",
        "district": "Gurnee SD 56",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171780002076",
    },
    {
        "school": "Hawthorn Townline Elem Sch",
        "district": "Hawthorn CCSD 73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171857000077",
    },
    {
        "school": "Hawthorn Middle School North",
        "district": "Hawthorn CCSD 73",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171857002149",
    },
    {
        "school": "Hawthorn Middle School South",
        "district": "Hawthorn CCSD 73",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171857002150",
    },
    {
        "school": "Hawthorn Elem School North",
        "district": "Hawthorn CCSD 73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171857002151",
    },
    {
        "school": "Hawthorn Aspen Elem School",
        "district": "Hawthorn CCSD 73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171857003707",
    },
    {
        "school": "Hawthorn Elem School South",
        "district": "Hawthorn CCSD 73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171857005172",
    },
    {
        "school": "Deerfield High School",
        "district": "Twp HSD 113",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171908002193",
    },
    {
        "school": "Highland Park High School",
        "district": "Twp HSD 113",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171908002194",
    },
    {
        "school": "Kildeer Countryside Elem School",
        "district": "Kildeer Countryside CCSD 96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172103002386",
    },
    {
        "school": "Willow Grove Early Learning Ctr",
        "district": "Kildeer Countryside CCSD 96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172103002388",
    },
    {
        "school": "Woodlawn Middle School",
        "district": "Kildeer Countryside CCSD 96",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172103003715",
    },
    {
        "school": "Country Meadows Elem School",
        "district": "Kildeer Countryside CCSD 96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172103003716",
    },
    {
        "school": "Ivy Hall Elementary School",
        "district": "Kildeer Countryside CCSD 96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172103003718",
    },
    {
        "school": "Prairie Elementary School",
        "district": "Kildeer Countryside CCSD 96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172103004410",
    },
    {
        "school": "Twin Groves Middle School",
        "district": "Kildeer Countryside CCSD 96",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172103005513",
    },
    {
        "school": "Lake Bluff Middle School",
        "district": "Lake Bluff ESD 65",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172172002444",
    },
    {
        "school": "Cherokee Elem School",
        "district": "Lake Forest SD 67",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172175002447",
    },
    {
        "school": "Deer Path Middle Sch West",
        "district": "Lake Forest SD 67",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172175002449",
    },
    {
        "school": "Everett Elem School",
        "district": "Lake Forest SD 67",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172175002450",
    },
    {
        "school": "Sheridan Elem School",
        "district": "Lake Forest SD 67",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172175002451",
    },
    {
        "school": "Lake Forest High School",
        "district": "Lake Forest CHSD 115",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172178002452",
    },
    {
        "school": "B J Hooper Elem School",
        "district": "Lake Villa CCSD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172187002457",
    },
    {
        "school": "Peter J Palombi School",
        "district": "Lake Villa CCSD 41",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172187002459",
    },
    {
        "school": "William L Thompson School",
        "district": "Lake Villa CCSD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172187003657",
    },
    {
        "school": "Lake Zurich Middle - S Campus",
        "district": "Lake Zurich CUSD 95",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172190000517",
    },
    {
        "school": "Isaac Fox Elementary School",
        "district": "Lake Zurich CUSD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172190000518",
    },
    {
        "school": "Lake Zurich High School",
        "district": "Lake Zurich CUSD 95",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172190002460",
    },
    {
        "school": "Lake Zurich Middle - N Campus",
        "district": "Lake Zurich CUSD 95",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172190002461",
    },
    {
        "school": "May Whitney Elem School",
        "district": "Lake Zurich CUSD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172190002462",
    },
    {
        "school": "Seth Paine Elem School",
        "district": "Lake Zurich CUSD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172190002464",
    },
    {
        "school": "Sarah Adams Elementary School",
        "district": "Lake Zurich CUSD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172190004411",
    },
    {
        "school": "Butterfield School",
        "district": "Libertyville SD 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172280002525",
    },
    {
        "school": "Copeland Manor Elem School",
        "district": "Libertyville SD 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172280002527",
    },
    {
        "school": "Rockland Elem School",
        "district": "Libertyville SD 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172280002528",
    },
    {
        "school": "Highland Middle School",
        "district": "Libertyville SD 70",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172280002529",
    },
    {
        "school": "Adler Park School",
        "district": "Libertyville SD 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172280005318",
    },
    {
        "school": "Libertyville High School",
        "district": "CHSD 128",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172283002531",
    },
    {
        "school": "Vernon Hills High School",
        "district": "CHSD 128",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172283004092",
    },
    {
        "school": "Half Day School",
        "district": "Lincolnshire-Prairieview SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172309000103",
    },
    {
        "school": "Daniel Wright Jr High School",
        "district": "Lincolnshire-Prairieview SD 103",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172309002545",
    },
    {
        "school": "Laura B Sprague School",
        "district": "Lincolnshire-Prairieview SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172309002547",
    },
    {
        "school": "Millburn Elem School",
        "district": "Millburn CCSD 24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172610002792",
    },
    {
        "school": "Carl Sandburg Middle School",
        "district": "Mundelein ESD 75",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172754002914",
    },
    {
        "school": "Mechanics Grove Elem School",
        "district": "Mundelein ESD 75",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172754002917",
    },
    {
        "school": "Washington Elem School",
        "district": "Mundelein ESD 75",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172754002918",
    },
    {
        "school": "Mundelein Cons High School",
        "district": "Mundelein Cons HSD 120",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172757002919",
    },
    {
        "school": "Oak Grove Elem School",
        "district": "Oak Grove SD 68 Green Oaks",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172913003047",
    },
    {
        "school": "Adlai E Stevenson High School",
        "district": "Adlai E Stevenson HSD 125",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173258003385",
    },
    {
        "school": "Rondout Elem School",
        "district": "Rondout SD 72",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173462003626",
    },
    {
        "school": "Pleviak Elem School",
        "district": "Round Lake CUSD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173499002974",
    },
    {
        "school": "Indian Hill Elem School",
        "district": "Round Lake CUSD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173499003664",
    },
    {
        "school": "Round Lake Middle School",
        "district": "Round Lake CUSD 116",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173499003665",
    },
    {
        "school": "Raymond Ellis Elem School",
        "district": "Round Lake CUSD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173499003666",
    },
    {
        "school": "Round Lake Beach Elem School",
        "district": "Round Lake CUSD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173499003667",
    },
    {
        "school": "Round Lake Senior High School",
        "district": "Round Lake CUSD 116",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173499003668",
    },
    {
        "school": "Village Elementary School",
        "district": "Round Lake CUSD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173499003669",
    },
    {
        "school": "W J Murphy Elem School",
        "district": "Round Lake CUSD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173499003670",
    },
    {
        "school": "Warren Township High School",
        "district": "Warren Twp HSD 121",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174080004097",
    },
    {
        "school": "Wauconda High School",
        "district": "Wauconda CUSD 118",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174119004119",
    },
    {
        "school": "Wauconda Grade School",
        "district": "Wauconda CUSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174119004120",
    },
    {
        "school": "Wauconda Middle School",
        "district": "Wauconda CUSD 118",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174119004121",
    },
    {
        "school": "Robert Crown School",
        "district": "Wauconda CUSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174119005208",
    },
    {
        "school": "Robert E Abbott Middle School",
        "district": "Waukegan CUSD 60",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125000206",
    },
    {
        "school": "Miguel Juarez Middle School",
        "district": "Waukegan CUSD 60",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125001753",
    },
    {
        "school": "Andrew Cooke Magnet Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004122",
    },
    {
        "school": "Clearview Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004123",
    },
    {
        "school": "Daniel Webster Middle School",
        "district": "Waukegan CUSD 60",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004124",
    },
    {
        "school": "Carman-Buckner Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004125",
    },
    {
        "school": "Glen Flora Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004126",
    },
    {
        "school": "Glenwood Elementary School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004127",
    },
    {
        "school": "Greenwood Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004128",
    },
    {
        "school": "H R McCall Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004129",
    },
    {
        "school": "Hyde Park Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004130",
    },
    {
        "school": "Jack Benny Middle School",
        "district": "Waukegan CUSD 60",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004131",
    },
    {
        "school": "John S Clark Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004132",
    },
    {
        "school": "Little Fort Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004134",
    },
    {
        "school": "Lyon Magnet Elementary School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004135",
    },
    {
        "school": "North Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004136",
    },
    {
        "school": "Oakdale Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004137",
    },
    {
        "school": "Thomas Jefferson Middle School",
        "district": "Waukegan CUSD 60",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004138",
    },
    {
        "school": "Washington Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004139",
    },
    {
        "school": "Waukegan High School",
        "district": "Waukegan CUSD 60",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125004141",
    },
    {
        "school": "North Prairie Jr High",
        "district": "Winthrop Harbor SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174290003654",
    },
    {
        "school": "Westfield  School",
        "district": "Winthrop Harbor SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174290003655",
    },
    {
        "school": "Woodland Primary School",
        "district": "Woodland CCSD 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174311000220",
    },
    {
        "school": "Woodland Elementary",
        "district": "Woodland CCSD 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174311002114",
    },
    {
        "school": "Woodland Middle School",
        "district": "Woodland CCSD 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174311004324",
    },
    {
        "school": "Woodland Intermediate Sch",
        "district": "Woodland CCSD 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174311004325",
    },
    {
        "school": "Lakeview School",
        "district": "Zion ESD 6",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174386000238",
    },
    {
        "school": "Beulah Park Elem School",
        "district": "Zion ESD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174386004350",
    },
    {
        "school": "Zion Central Middle School",
        "district": "Zion ESD 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174386004351",
    },
    {
        "school": "East Elementary School",
        "district": "Zion ESD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174386004352",
    },
    {
        "school": "Elmwood Elem School",
        "district": "Zion ESD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174386004353",
    },
    {
        "school": "Shiloh Park Elem School",
        "district": "Zion ESD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174386004355",
    },
    {
        "school": "West Elementary School",
        "district": "Zion ESD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174386004356",
    },
    {
        "school": "Zion-Benton Twnshp Hi Sch",
        "district": "Zion-Benton Twp HSD 126",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174389004357",
    },
    {
        "school": "Marengo Comm Middle School",
        "district": "Marengo-Union E Cons D 165",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170007703147",
    },
    {
        "school": "Locust Elem School",
        "district": "Marengo-Union E Cons D 165",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170007705249",
    },
    {
        "school": "Evergreen Academy",
        "district": "McHenry ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020003117",
    },
    {
        "school": "Nippersink Middle School",
        "district": "Nippersink SD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170022204117",
    },
    {
        "school": "Richmond Grade School",
        "district": "Nippersink SD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170022204118",
    },
    {
        "school": "Spring Grove Elementary School",
        "district": "Nippersink SD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170022204143",
    },
    {
        "school": "Alden-Hebron Middle School",
        "district": "Alden Hebron SD 19",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170330000016",
    },
    {
        "school": "Alden-Hebron High School",
        "district": "Alden Hebron SD 19",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170330000017",
    },
    {
        "school": "Alden Hebron Elem School",
        "district": "Alden Hebron SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170330004512",
    },
    {
        "school": "Countryside Elem School",
        "district": "Barrington CUSD 220",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505000189",
    },
    {
        "school": "Algonquin Middle School",
        "district": "CUSD 300",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000477",
    },
    {
        "school": "Eastview Elem School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000482",
    },
    {
        "school": "Harry D Jacobs High School",
        "district": "CUSD 300",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000486",
    },
    {
        "school": "Lake in the Hills Elem School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000490",
    },
    {
        "school": "Kenneth E Neubert Elem School",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855000495",
    },
    {
        "school": "Briargate Elem School",
        "district": "Cary CCSD 26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170873000512",
    },
    {
        "school": "Cary Jr High School",
        "district": "Cary CCSD 26",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170873000513",
    },
    {
        "school": "Three Oaks School",
        "district": "Cary CCSD 26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170873000573",
    },
    {
        "school": "Deer Path Elem School",
        "district": "Cary CCSD 26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170873003137",
    },
    {
        "school": "Canterbury Elem School",
        "district": "Crystal Lake CCSD 47",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135001357",
    },
    {
        "school": "Husmann Elem School",
        "district": "Crystal Lake CCSD 47",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135001358",
    },
    {
        "school": "Coventry Elem School",
        "district": "Crystal Lake CCSD 47",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135001359",
    },
    {
        "school": "Lundahl Middle School",
        "district": "Crystal Lake CCSD 47",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135001360",
    },
    {
        "school": "North Elem School",
        "district": "Crystal Lake CCSD 47",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135001361",
    },
    {
        "school": "Richard F Bernotas Middle Sch",
        "district": "Crystal Lake CCSD 47",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135001362",
    },
    {
        "school": "South Elem School",
        "district": "Crystal Lake CCSD 47",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135001364",
    },
    {
        "school": "West Elem School",
        "district": "Crystal Lake CCSD 47",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135001365",
    },
    {
        "school": "Hannah Beardsley Middle School",
        "district": "Crystal Lake CCSD 47",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135001799",
    },
    {
        "school": "Woods Creek Elementary School",
        "district": "Crystal Lake CCSD 47",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135002147",
    },
    {
        "school": "Glacier Ridge Elementary School",
        "district": "Crystal Lake CCSD 47",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135004457",
    },
    {
        "school": "Indian Prairie Elem School",
        "district": "Crystal Lake CCSD 47",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171135005586",
    },
    {
        "school": "Cary-Grove Community High School",
        "district": "CHSD 155",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171137001366",
    },
    {
        "school": "Crystal Lake Central High School",
        "district": "CHSD 155",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171137001367",
    },
    {
        "school": "Crystal Lake South High School",
        "district": "CHSD 155",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171137001368",
    },
    {
        "school": "Prairie Ridge High School",
        "district": "CHSD 155",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171137002154",
    },
    {
        "school": "Algonquin Road Elem School",
        "district": "Fox River Grove Cons SD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171566001878",
    },
    {
        "school": "Fox River Grove Middle School",
        "district": "Fox River Grove Cons SD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171566005508",
    },
    {
        "school": "Harrison Elem School",
        "district": "Harrison SD 36",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171836002120",
    },
    {
        "school": "Harvard High School",
        "district": "Harvard CUSD 50",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171842002125",
    },
    {
        "school": "Harvard Jr High School",
        "district": "Harvard CUSD 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171842002126",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Harvard CUSD 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171842002127",
    },
    {
        "school": "Huntley High School",
        "district": "Huntley Comm Sch Dist 158",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171983002247",
    },
    {
        "school": "Chesak Elementary School",
        "district": "Huntley Comm Sch Dist 158",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171983004181",
    },
    {
        "school": "Leggee Elementary School",
        "district": "Huntley Comm Sch Dist 158",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171983004183",
    },
    {
        "school": "Johnsburg Elementary School",
        "district": "Johnsburg CUSD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172049002314",
    },
    {
        "school": "Johnsburg High School",
        "district": "Johnsburg CUSD 12",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172049002315",
    },
    {
        "school": "Johnsburg Jr High School",
        "district": "Johnsburg CUSD 12",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172049002316",
    },
    {
        "school": "Ringwood School Primary Ctr",
        "district": "Johnsburg CUSD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172049002318",
    },
    {
        "school": "Marengo High School",
        "district": "Marengo CHSD 154",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172457002661",
    },
    {
        "school": "Edgebrook Elem School",
        "district": "McHenry CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172529002754",
    },
    {
        "school": "Hilltop Elem School",
        "district": "McHenry CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172529002755",
    },
    {
        "school": "McHenry Middle School",
        "district": "McHenry CCSD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172529002757",
    },
    {
        "school": "Parkland School",
        "district": "McHenry CCSD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172529002758",
    },
    {
        "school": "Valley View Elem School",
        "district": "McHenry CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172529002759",
    },
    {
        "school": "Chauncey H Duker School",
        "district": "McHenry CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172529004456",
    },
    {
        "school": "Riverwood Elementary School",
        "district": "McHenry CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172529005434",
    },
    {
        "school": "Landmark Elem School",
        "district": "McHenry CCSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172529005514",
    },
    {
        "school": "McHenry  East High School",
        "district": "McHenry CHSD 156",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172532002760",
    },
    {
        "school": "McHenry High School-West Campus",
        "district": "McHenry CHSD 156",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172532002761",
    },
    {
        "school": "Prairie Grove Elem School",
        "district": "Prairie Grove CSD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173252003380",
    },
    {
        "school": "Prairie Grove Junior High School",
        "district": "Prairie Grove CSD 46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173252003735",
    },
    {
        "school": "Richmond-Burton High School",
        "district": "Richmond-Burton CHSD 157",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173351003463",
    },
    {
        "school": "Riley Comm Cons School",
        "district": "Riley CCSD 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173375003470",
    },
    {
        "school": "Cotton Creek School",
        "district": "Wauconda CUSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174119001454",
    },
    {
        "school": "Mary Endres Elementary School",
        "district": "Woodstock CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333003178",
    },
    {
        "school": "Verda Dierzen Early Learning Ctr",
        "district": "Woodstock CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333004186",
    },
    {
        "school": "Creekside Middle School",
        "district": "Woodstock CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333004328",
    },
    {
        "school": "Dean Street Elem School",
        "district": "Woodstock CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333004329",
    },
    {
        "school": "Greenwood Elem School",
        "district": "Woodstock CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333004330",
    },
    {
        "school": "Northwood Middle School",
        "district": "Woodstock CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333004333",
    },
    {
        "school": "Woodstock High School",
        "district": "Woodstock CUSD 200",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333004335",
    },
    {
        "school": "Westwood Elem School",
        "district": "Woodstock CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333005213",
    },
    {
        "school": "Olson Elementary School",
        "district": "Woodstock CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333005462",
    },
    {
        "school": "Martin P McKay Education Center",
        "district": "Lincoln-Way Area Spec Ed JA Dist",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170009704503",
    },
    {
        "school": "Beecher Elem School",
        "district": "Beecher CUSD 200U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170543000222",
    },
    {
        "school": "Beecher High School",
        "district": "Beecher CUSD 200U",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170543000223",
    },
    {
        "school": "Beecher Junior High School",
        "district": "Beecher CUSD 200U",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170543004523",
    },
    {
        "school": "Milne Grove Elem School",
        "district": "Lockport SD 91",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170921000528",
    },
    {
        "school": "Kelvin Grove Jr High School",
        "district": "Lockport SD 91",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170921000529",
    },
    {
        "school": "Chaney-Monge School",
        "district": "Chaney-Monge SD 88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170951004940",
    },
    {
        "school": "Channahon Junior High School",
        "district": "Channahon SD 17",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170954000562",
    },
    {
        "school": "N B Galloway Elem School",
        "district": "Channahon SD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170954000563",
    },
    {
        "school": "Three Rivers School",
        "district": "Channahon SD 17",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170954001556",
    },
    {
        "school": "Balmoral Elem Sch",
        "district": "Crete Monee CUSD 201U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171125001342",
    },
    {
        "school": "Crete Elementary School",
        "district": "Crete Monee CUSD 201U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171125001343",
    },
    {
        "school": "Crete-Monee High School",
        "district": "Crete Monee CUSD 201U",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171125001344",
    },
    {
        "school": "Crete-Monee Middle School",
        "district": "Crete Monee CUSD 201U",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171125001347",
    },
    {
        "school": "Monee Elementary School",
        "district": "Crete Monee CUSD 201U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171125001348",
    },
    {
        "school": "Talala Elementary School",
        "district": "Crete Monee CUSD 201U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171125001349",
    },
    {
        "school": "Coretta Scott King Magnet Sch",
        "district": "Crete Monee CUSD 201U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171125001350",
    },
    {
        "school": "Elwood C C School",
        "district": "Elwood CCSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171416001763",
    },
    {
        "school": "Grand Prairie Elementary School",
        "district": "Frankfort CCSD 157C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171570001867",
    },
    {
        "school": "Chelsea Elem School",
        "district": "Frankfort CCSD 157C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171570001880",
    },
    {
        "school": "Hickory Creek Middle School",
        "district": "Frankfort CCSD 157C",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171570001881",
    },
    {
        "school": "Goodings Grove School",
        "district": "Homer CCSD 33C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171950002226",
    },
    {
        "school": "Homer Jr High School",
        "district": "Homer CCSD 33C",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171950002228",
    },
    {
        "school": "Luther J Schilling School",
        "district": "Homer CCSD 33C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171950004518",
    },
    {
        "school": "William J Butler School",
        "district": "Homer CCSD 33C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171950004519",
    },
    {
        "school": "Hadley Middle School",
        "district": "Homer CCSD 33C",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171950005316",
    },
    {
        "school": "A O Marshall Elem School",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002323",
    },
    {
        "school": "M J Cunningham Elem Sch",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002325",
    },
    {
        "school": "Dirksen Junior High School",
        "district": "Joliet PSD 86",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002326",
    },
    {
        "school": "Edna Keith Elem School",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002327",
    },
    {
        "school": "Eisenhower Academy",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002328",
    },
    {
        "school": "Farragut Elem School",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002331",
    },
    {
        "school": "Forest Park Individual Ed School",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002332",
    },
    {
        "school": "Gompers Junior High School",
        "district": "Joliet PSD 86",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002333",
    },
    {
        "school": "Hufford Junior High School",
        "district": "Joliet PSD 86",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002334",
    },
    {
        "school": "Marycrest Early Childhood Center",
        "district": "Joliet PSD 86",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002337",
    },
    {
        "school": "Pershing Elem School",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002340",
    },
    {
        "school": "T E Culbertson Elem School",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002344",
    },
    {
        "school": "Taft Elementary School",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002345",
    },
    {
        "school": "Thomas Jefferson Elem School",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002346",
    },
    {
        "school": "Woodland Elem School",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002347",
    },
    {
        "school": "Washington Jr High & Academy Prgm",
        "district": "Joliet PSD 86",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058002348",
    },
    {
        "school": "Joliet Central High School",
        "district": "Joliet Twp HSD 204",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172061002350",
    },
    {
        "school": "Joliet West High School",
        "district": "Joliet Twp HSD 204",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172061002352",
    },
    {
        "school": "Joliet Twp High Sch - Alternate",
        "district": "Joliet Twp HSD 204",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172061005022",
    },
    {
        "school": "Laraway School",
        "district": "Laraway CCSD 70C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172205002473",
    },
    {
        "school": "Lincoln-Way Central High School",
        "district": "Lincoln Way CHSD 210",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172307002543",
    },
    {
        "school": "Lincoln-Way East High School",
        "district": "Lincoln Way CHSD 210",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172307002544",
    },
    {
        "school": "Lockport Township High Sch East",
        "district": "Lockport Twp HSD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172335002571",
    },
    {
        "school": "Oak Prairie Jr High School",
        "district": "Will County SD 92",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172373001008",
    },
    {
        "school": "Reed Elem School",
        "district": "Will County SD 92",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172373001035",
    },
    {
        "school": "Walsh Elem School",
        "district": "Will County SD 92",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172373002592",
    },
    {
        "school": "Manhattan Jr High School",
        "district": "Manhattan SD 114",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172427001557",
    },
    {
        "school": "Anna McDonald Elem School",
        "district": "Manhattan SD 114",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172427002639",
    },
    {
        "school": "Mokena Elem School",
        "district": "Mokena SD 159",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172637002801",
    },
    {
        "school": "Mokena Jr High School",
        "district": "Mokena SD 159",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172637002802",
    },
    {
        "school": "Mokena Intermediate School",
        "district": "Mokena SD 159",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172637004521",
    },
    {
        "school": "River Woods Elementary School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771005286",
    },
    {
        "school": "Kingsley Elementary School",
        "district": "Naperville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771005516",
    },
    {
        "school": "Oster-Oakview  School",
        "district": "New Lenox SD 122",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814001559",
    },
    {
        "school": "Haines Elem School",
        "district": "New Lenox SD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814002966",
    },
    {
        "school": "Bentley Elem School",
        "district": "New Lenox SD 122",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814002968",
    },
    {
        "school": "Alex M Martino Jr High School",
        "district": "New Lenox SD 122",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814002970",
    },
    {
        "school": "Arnold J Tyler School",
        "district": "New Lenox SD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814002971",
    },
    {
        "school": "Nelson Prairie School",
        "district": "New Lenox SD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814003777",
    },
    {
        "school": "Nelson Ridge School",
        "district": "New Lenox SD 122",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814003778",
    },
    {
        "school": "The Wheatlands Elementary School",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027004384",
    },
    {
        "school": "Peotone Intermediate Center",
        "district": "Peotone CUSD 207U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173129003301",
    },
    {
        "school": "Peotone Elem School",
        "district": "Peotone CUSD 207U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173129003302",
    },
    {
        "school": "Peotone High School",
        "district": "Peotone CUSD 207U",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173129003303",
    },
    {
        "school": "Peotone Jr High School",
        "district": "Peotone CUSD 207U",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173129003304",
    },
    {
        "school": "Walkers Grove Elementary School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174000139",
    },
    {
        "school": "Timber Ridge Middle School",
        "district": "Plainfield SD 202",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174001873",
    },
    {
        "school": "Wesmere Elementary School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174001874",
    },
    {
        "school": "Lakewood Falls Elem School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174002209",
    },
    {
        "school": "Central Elem School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174003335",
    },
    {
        "school": "Crystal Lawns Elem School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174003336",
    },
    {
        "school": "Grand Prairie Elem School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174003337",
    },
    {
        "school": "Indian Trail Middle School",
        "district": "Plainfield SD 202",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174003338",
    },
    {
        "school": "Plainfield High School",
        "district": "Plainfield SD 202",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174003339",
    },
    {
        "school": "Heritage Grove Middle School",
        "district": "Plainfield SD 202",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174003785",
    },
    {
        "school": "River View Elementary School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174003792",
    },
    {
        "school": "Meadow View Elementary School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174004206",
    },
    {
        "school": "Creekside Elementary School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174004537",
    },
    {
        "school": "Bonnie McBeth  Learning Ctr",
        "district": "Plainfield SD 202",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174004539",
    },
    {
        "school": "Reed-Custer Elementary School",
        "district": "Reed Custer CUSD 255U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173338003453",
    },
    {
        "school": "Reed-Custer Middle School",
        "district": "Reed Custer CUSD 255U",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173338003454",
    },
    {
        "school": "Reed-Custer High School",
        "district": "Reed Custer CUSD 255U",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173338003456",
    },
    {
        "school": "Richland Elem School",
        "district": "Richland GSD 88A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173345003461",
    },
    {
        "school": "Rockdale Elem School",
        "district": "Rockdale SD 84",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173447003552",
    },
    {
        "school": "Steger Intermediate Center",
        "district": "Steger SD 194",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173768003881",
    },
    {
        "school": "Arbury Hills Elem School",
        "district": "Summit Hill SD 161",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173822003910",
    },
    {
        "school": "Frankfort Square Elem School",
        "district": "Summit Hill SD 161",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173822003911",
    },
    {
        "school": "Indian Trail Elem School",
        "district": "Summit Hill SD 161",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173822003912",
    },
    {
        "school": "Summit Hill Junior High School",
        "district": "Summit Hill SD 161",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173822003913",
    },
    {
        "school": "Dr Julian Rogus School",
        "district": "Summit Hill SD 161",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173822004522",
    },
    {
        "school": "Walker Intermediate School",
        "district": "Summit Hill SD 161",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173822005454",
    },
    {
        "school": "Taft Grade School",
        "district": "Taft SD 90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173852003927",
    },
    {
        "school": "Troy Heritage Trail School",
        "district": "Troy CCSD 30C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173951001854",
    },
    {
        "school": "Troy Middle School",
        "district": "Troy CCSD 30C",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173951003996",
    },
    {
        "school": "Troy Craughwell School",
        "district": "Troy CCSD 30C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173951003997",
    },
    {
        "school": "Troy Shorewood School",
        "district": "Troy CCSD 30C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173951003998",
    },
    {
        "school": "Troy Cronin Elem School",
        "district": "Troy CCSD 30C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173951004516",
    },
    {
        "school": "Union Elementary School",
        "district": "Union SD 81",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173966004004",
    },
    {
        "school": "Valley View Early Childhood Cntr",
        "district": "Valley View CUSD 365U",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007001875",
    },
    {
        "school": "Brooks Middle School",
        "district": "Valley View CUSD 365U",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004024",
    },
    {
        "school": "Bolingbrook High School",
        "district": "Valley View CUSD 365U",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004025",
    },
    {
        "school": "John R Tibbott Elem School",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004026",
    },
    {
        "school": "Hubert H Humphrey Middle School",
        "district": "Valley View CUSD 365U",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004027",
    },
    {
        "school": "Independence Elem School",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004028",
    },
    {
        "school": "Irene King Elem School",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004029",
    },
    {
        "school": "Jane Addams Middle School",
        "district": "Valley View CUSD 365U",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004030",
    },
    {
        "school": "Jonas E Salk Elem School",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004031",
    },
    {
        "school": "Robert C Hill Elem School",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004034",
    },
    {
        "school": "Romeoville High School",
        "district": "Valley View CUSD 365U",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004035",
    },
    {
        "school": "A Vito Martinez Middle School",
        "district": "Valley View CUSD 365U",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004037",
    },
    {
        "school": "Wood View Elem School",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004038",
    },
    {
        "school": "Pioneer Elementary School",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004208",
    },
    {
        "school": "Jamie McGee Elementary School",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004434",
    },
    {
        "school": "Kenneth L Hermansen Elementary",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004542",
    },
    {
        "school": "Oak View Elem School",
        "district": "Valley View CUSD 365U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174007004864",
    },
    {
        "school": "Patterson Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169000489",
    },
    {
        "school": "V Blanche Graham Elementary",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169001617",
    },
    {
        "school": "Neuqua Valley High School",
        "district": "Indian Prairie CUSD 204",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169002092",
    },
    {
        "school": "Clifford Crone Middle School",
        "district": "Indian Prairie CUSD 204",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169002093",
    },
    {
        "school": "Oliver Julian Kendall Elem School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169002656",
    },
    {
        "school": "Arlene Welch Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169003609",
    },
    {
        "school": "Wayne Builta Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169003610",
    },
    {
        "school": "Scullen Middle School",
        "district": "Indian Prairie CUSD 204",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169004354",
    },
    {
        "school": "Fry Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169004365",
    },
    {
        "school": "Robert Clow Elem Sch",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169004436",
    },
    {
        "school": "Gordon Gregory Middle School",
        "district": "Indian Prairie CUSD 204",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169005293",
    },
    {
        "school": "Spring Brook Elementary School",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169005459",
    },
    {
        "school": "L J Stevens Intermediate School",
        "district": "Wilmington CUSD 209U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174263004281",
    },
    {
        "school": "Bruning Elem School",
        "district": "Wilmington CUSD 209U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174263004282",
    },
    {
        "school": "Wilmington Middle School",
        "district": "Wilmington CUSD 209U",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174263004283",
    },
    {
        "school": "Wilmington High School",
        "district": "Wilmington CUSD 209U",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174263004284",
    },
    {
        "school": "Georgetown-Ridge Farm High School",
        "district": "Georgetown-Ridge Farm CUD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170009205255",
    },
    {
        "school": "Mary Miller Junior High School",
        "district": "Georgetown-Ridge Farm CUD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170009205256",
    },
    {
        "school": "Pine Crest Elementary School",
        "district": "Georgetown-Ridge Farm CUD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170009205258",
    },
    {
        "school": "Middlefork School RSSP",
        "district": "Vermilion ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170021103291",
    },
    {
        "school": "Armstrong-Ellis Elem School",
        "district": "Armstrong-Ellis Cons SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170420000118",
    },
    {
        "school": "Armstrong High School",
        "district": "Armstrong Twp HSD 225",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170423000119",
    },
    {
        "school": "Bismarck-Henning Jr High School",
        "district": "Bismarck Henning CUSD",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170639000308",
    },
    {
        "school": "Coop HS 1",
        "district": "Bismarck Henning CUSD",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170639000309",
    },
    {
        "school": "Bismarck-Henning Elem School",
        "district": "Bismarck Henning CUSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170639000310",
    },
    {
        "school": "Oakwood Grade School",
        "district": "Oakwood CUSD 76",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171080001316",
    },
    {
        "school": "Oakwood High School",
        "district": "Oakwood CUSD 76",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171080001317",
    },
    {
        "school": "Oakwood Junior High School",
        "district": "Oakwood CUSD 76",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171080005308",
    },
    {
        "school": "Judith Giacoma Elem School",
        "district": "Westville CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171082001318",
    },
    {
        "school": "Westville High School",
        "district": "Westville CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171082001320",
    },
    {
        "school": "Westville Jr High School",
        "district": "Westville CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171082001321",
    },
    {
        "school": "Danville High School",
        "district": "Danville CCSD 118",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179001382",
    },
    {
        "school": "Edison Elem School",
        "district": "Danville CCSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179001385",
    },
    {
        "school": "Garfield Elem School",
        "district": "Danville CCSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179001387",
    },
    {
        "school": "Liberty Elem School",
        "district": "Danville CCSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179001388",
    },
    {
        "school": "Meade Park Elem School",
        "district": "Danville CCSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179001391",
    },
    {
        "school": "North Ridge Middle School",
        "district": "Danville CCSD 118",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179001392",
    },
    {
        "school": "South View Upper Elem School",
        "district": "Danville CCSD 118",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179001395",
    },
    {
        "school": "Northeast Elem Magnet School",
        "district": "Danville CCSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179003297",
    },
    {
        "school": "Southwest  Elem School",
        "district": "Danville CCSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179004515",
    },
    {
        "school": "Mark Denman Elementary School",
        "district": "Danville CCSD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179005274",
    },
    {
        "school": "Hoopeston Area Middle School",
        "district": "Hoopeston Area CUSD 11",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171966002237",
    },
    {
        "school": "Hoopeston Area High School",
        "district": "Hoopeston Area CUSD 11",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171966002238",
    },
    {
        "school": "John Greer Elem School",
        "district": "Hoopeston Area CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171966002240",
    },
    {
        "school": "Maple Elem School",
        "district": "Hoopeston Area CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171966004665",
    },
    {
        "school": "Potomac Elem School",
        "district": "Potomac CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173209003356",
    },
    {
        "school": "Rossville-Alvin Elem School",
        "district": "Rossville-Alvin CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173487003662",
    },
    {
        "school": "Middle Fork School",
        "district": "Vermilion Assoc for Spec Educ",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "174022002205",
    },
    {
        "school": "Reg'l Safe School Program ROE #28",
        "district": "Bureau/Henry/Stark ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016804775",
    },
    {
        "school": "Excel Alternative Program",
        "district": "Henry-Stark County Spec Ed Dist",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170032205824",
    },
    {
        "school": "Central Junior High",
        "district": "Kewanee CUSD 229",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172100005610",
    },
    {
        "school": "Eagle Ridge School",
        "district": "Carbon Cliff-Barstow SD 36",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170831004885",
    },
    {
        "school": "Moline HS at Coolidge Campus",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640004886",
    },
    {
        "school": "AlWood Elem School",
        "district": "AlWood CUSD 225",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170366000057",
    },
    {
        "school": "AlWood  Middle/High School",
        "district": "AlWood CUSD 225",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170366000058",
    },
    {
        "school": "Annawan Grade School",
        "district": "Annawan CUSD 226",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170381000068",
    },
    {
        "school": "Annawan High School",
        "district": "Annawan CUSD 226",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170381000069",
    },
    {
        "school": "Cambridge Jr/Sr High School",
        "district": "Cambridge CUSD 227",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170816000429",
    },
    {
        "school": "Cambridge Comm Grade School",
        "district": "Cambridge CUSD 227",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170816004561",
    },
    {
        "school": "Colona Grade School",
        "district": "Colona SD 190",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171069001293",
    },
    {
        "school": "Galva Jr-Sr High School",
        "district": "Galva CUSD 224",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171614001939",
    },
    {
        "school": "Galva Elem School",
        "district": "Galva CUSD 224",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171614005563",
    },
    {
        "school": "Geneseo High School",
        "district": "Geneseo CUSD 228",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171635001948",
    },
    {
        "school": "Geneseo Middle School",
        "district": "Geneseo CUSD 228",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171635001949",
    },
    {
        "school": "Millikin Elem School",
        "district": "Geneseo CUSD 228",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171635001950",
    },
    {
        "school": "Northside Elem School",
        "district": "Geneseo CUSD 228",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171635001951",
    },
    {
        "school": "Southwest Elem School",
        "district": "Geneseo CUSD 228",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171635001952",
    },
    {
        "school": "Irving Elem School",
        "district": "Kewanee CUSD 229",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172100002379",
    },
    {
        "school": "Central Elem",
        "district": "Kewanee CUSD 229",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172100002380",
    },
    {
        "school": "Belle Alexander Elem School",
        "district": "Kewanee CUSD 229",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172100002381",
    },
    {
        "school": "Lyle School",
        "district": "Kewanee CUSD 229",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172100002382",
    },
    {
        "school": "Kewanee High School",
        "district": "Kewanee CUSD 229",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172100002383",
    },
    {
        "school": "C R Hanna Elem School",
        "district": "Orion CUSD 223",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173020003119",
    },
    {
        "school": "Orion High School",
        "district": "Orion CUSD 223",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173020003120",
    },
    {
        "school": "Orion Middle School",
        "district": "Orion CUSD 223",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173020003121",
    },
    {
        "school": "Wethersfield Elem School",
        "district": "Wethersfield CUSD 230",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174206004204",
    },
    {
        "school": "Wethersfield Jr/Sr High School",
        "district": "Wethersfield CUSD 230",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174206004205",
    },
    {
        "school": "Matherville Intermediate School",
        "district": "Sherrard CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173618003745",
    },
    {
        "school": "Sherrard Elementary School",
        "district": "Sherrard CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173618003746",
    },
    {
        "school": "Winola Elementary School",
        "district": "Sherrard CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173618005341",
    },
    {
        "school": "Phoenix Program",
        "district": "Black Hawk Area Sp Ed District",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170008405113",
    },
    {
        "school": "Bowlesburg Elem School",
        "district": "East Moline SD 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171317001560",
    },
    {
        "school": "Glenview Middle School",
        "district": "East Moline SD 37",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171317001561",
    },
    {
        "school": "Hillcrest Elem School",
        "district": "East Moline SD 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171317001562",
    },
    {
        "school": "Ridgewood Elem School",
        "district": "East Moline SD 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171317001565",
    },
    {
        "school": "Wells Elem School",
        "district": "East Moline SD 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171317001566",
    },
    {
        "school": "Hampton Elem School",
        "district": "Hampton SD 29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171809002087",
    },
    {
        "school": "Jane Addams Elementary School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640000112",
    },
    {
        "school": "Jefferson Early Childhood Ctr",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640001824",
    },
    {
        "school": "Benjamin Franklin Elem School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002805",
    },
    {
        "school": "Butterworth Elem School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002810",
    },
    {
        "school": "George Washington Elem School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002814",
    },
    {
        "school": "Hamilton Elem School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002816",
    },
    {
        "school": "Bicentennial Elem School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002817",
    },
    {
        "school": "John Deere Middle School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002818",
    },
    {
        "school": "Lincoln-Irving Elem School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002820",
    },
    {
        "school": "Logan Elem School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002821",
    },
    {
        "school": "Moline Sr High School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002824",
    },
    {
        "school": "Roosevelt Elem School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002825",
    },
    {
        "school": "Woodrow Wilson Middle School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002827",
    },
    {
        "school": "Willard Elem School",
        "district": "Moline-Coal Valley CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172640002828",
    },
    {
        "school": "Riverdale Elem School",
        "district": "Riverdale CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173393003483",
    },
    {
        "school": "Riverdale Sr High School",
        "district": "Riverdale CUSD 100",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173393003484",
    },
    {
        "school": "Riverdale Middle School",
        "district": "Riverdale CUSD 100",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173393003485",
    },
    {
        "school": "Denkmann Elem School",
        "district": "Rock Island SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441003526",
    },
    {
        "school": "Earl H Hanson Elem School",
        "district": "Rock Island SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441003527",
    },
    {
        "school": "Eugene Field Elem School",
        "district": "Rock Island SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441003528",
    },
    {
        "school": "Washington Jr High School",
        "district": "Rock Island SD 41",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441003529",
    },
    {
        "school": "Frances Willard Elem School",
        "district": "Rock Island SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441003530",
    },
    {
        "school": "Longfellow Elem School",
        "district": "Rock Island SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441003534",
    },
    {
        "school": "Ridgewood Elem School",
        "district": "Rock Island SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441003535",
    },
    {
        "school": "Thomas Jefferson Elem School",
        "district": "Rock Island SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441003536",
    },
    {
        "school": "Edison Jr High School",
        "district": "Rock Island SD 41",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441003538",
    },
    {
        "school": "Rock Island High School",
        "district": "Rock Island SD 41",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441003540",
    },
    {
        "school": "Thurgood Marshall Learning Ctr",
        "district": "Rock Island SD 41",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441005338",
    },
    {
        "school": "Andalusia Elem School",
        "district": "Rockridge CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173444003545",
    },
    {
        "school": "Illinois City Elem School",
        "district": "Rockridge CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173444003547",
    },
    {
        "school": "Rockridge High School",
        "district": "Rockridge CUSD 300",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173444003549",
    },
    {
        "school": "Rockridge Jr High School",
        "district": "Rockridge CUSD 300",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173444003550",
    },
    {
        "school": "Taylor Ridge Elem School",
        "district": "Rockridge CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173444003551",
    },
    {
        "school": "Sherrard High School",
        "district": "Sherrard CUSD 200",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173618003747",
    },
    {
        "school": "Sherrard Jr High School",
        "district": "Sherrard CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173618003748",
    },
    {
        "school": "Northeast Jr High School",
        "district": "Silvis SD 34",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173636003755",
    },
    {
        "school": "George O Barr School",
        "district": "Silvis SD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173636004835",
    },
    {
        "school": "United Twp High School",
        "district": "United Twp HSD 30",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173987004008",
    },
    {
        "school": "St Marys Adolescent Ed Program",
        "district": "Macon/Piatt ROE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019705839",
    },
    {
        "school": "Sangamon Valley High School",
        "district": "Sangamon Valley CUSD 9",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032405625",
    },
    {
        "school": "Sangamon Valley Primary School",
        "district": "Sangamon Valley CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032405627",
    },
    {
        "school": "Hope Academy",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185005629",
    },
    {
        "school": "Sangamon Valley Middle School",
        "district": "Sangamon Valley CUSD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032405626",
    },
    {
        "school": "Sangamon Valley  Intermediate Sch",
        "district": "Sangamon Valley CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032405628",
    },
    {
        "school": "Meridian High School",
        "district": "Meridian CUSD 15",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012300873",
    },
    {
        "school": "Meridian Middle School",
        "district": "Meridian CUSD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012300876",
    },
    {
        "school": "Meridian Elem School",
        "district": "Meridian CUSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012300877",
    },
    {
        "school": "Futures Unlimited",
        "district": "Macon/Piatt ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019703048",
    },
    {
        "school": "Milligan Academy Rssp",
        "district": "Macon/Piatt ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019703057",
    },
    {
        "school": "Argenta-Oreana Elementary School",
        "district": "Argenta-Oreana CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170399000084",
    },
    {
        "school": "Argenta-Oreana High School",
        "district": "Argenta-Oreana CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170399000085",
    },
    {
        "school": "Argenta-Oreana Middle School",
        "district": "Argenta-Oreana CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170399000086",
    },
    {
        "school": "Garfield Montessori School",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001398",
    },
    {
        "school": "Dennis Elem School",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001399",
    },
    {
        "school": "Durfee Magnet Elementary",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001400",
    },
    {
        "school": "Enterprise Elem School",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001403",
    },
    {
        "school": "Benjamin Franklin Elem School",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001404",
    },
    {
        "school": "Eisenhower High School",
        "district": "Decatur SD 61",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001405",
    },
    {
        "school": "Mary W French Academy",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001406",
    },
    {
        "school": "Muffley Elem School",
        "district": "Decatur SD 61",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001407",
    },
    {
        "school": "Oak Grove Accelerated School",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001408",
    },
    {
        "school": "MacArthur High School",
        "district": "Decatur SD 61",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001411",
    },
    {
        "school": "South Shores Elem School",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001418",
    },
    {
        "school": "Stevenson Accelerated School",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001421",
    },
    {
        "school": "Michael E Baum Elem School",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001423",
    },
    {
        "school": "Parsons Accelerated School",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185001432",
    },
    {
        "school": "Stephen Decatur Middle School",
        "district": "Decatur SD 61",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185004100",
    },
    {
        "school": "Robertson Charter School",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185004424",
    },
    {
        "school": "Johns Hill Magnet School",
        "district": "Decatur SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185005156",
    },
    {
        "school": "Pershing Early Learning Center",
        "district": "Decatur SD 61",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185005582",
    },
    {
        "school": "Maroa-Forsyth Middle School",
        "district": "Maroa Forsyth CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172475002683",
    },
    {
        "school": "Maroa-Forsyth Senior High Sch",
        "district": "Maroa Forsyth CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172475002684",
    },
    {
        "school": "Maroa-Forsyth Grade School",
        "district": "Maroa Forsyth CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172475004725",
    },
    {
        "school": "Mt Zion Jr High School",
        "district": "Mt Zion CUSD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172739002905",
    },
    {
        "school": "McGaughey Elem School",
        "district": "Mt Zion CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172739002907",
    },
    {
        "school": "Mt Zion High School",
        "district": "Mt Zion CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172739002908",
    },
    {
        "school": "Mt Zion Elem School",
        "district": "Mt Zion CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172739002909",
    },
    {
        "school": "Mt Zion Intermediate School",
        "district": "Mt Zion CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172739002911",
    },
    {
        "school": "Warrensburg-Latham High School",
        "district": "Warrensburg-Latham CUSD 11",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174083004099",
    },
    {
        "school": "Warrensburg-Latham Elem Sch",
        "district": "Warrensburg-Latham CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174083004876",
    },
    {
        "school": "Nachusa Campus School",
        "district": "Lee/Ogle/Whiteside ROE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019505735",
    },
    {
        "school": "Rock River Challenge",
        "district": "Lee/Ogle/Whiteside ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019504852",
    },
    {
        "school": "Amboy Central Elem School",
        "district": "Amboy CUSD 272",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170369000059",
    },
    {
        "school": "Amboy High School",
        "district": "Amboy CUSD 272",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170369000060",
    },
    {
        "school": "Amboy Jr High School",
        "district": "Amboy CUSD 272",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170369000061",
    },
    {
        "school": "Ashton-Franklin Cntr Middle Sch",
        "district": "Ashton-Franklin Center CUSD 275",
        "level": "Not reported",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170438000126",
    },
    {
        "school": "Ashton-Franklin Center HS",
        "district": "Ashton-Franklin Center CUSD 275",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170438000127",
    },
    {
        "school": "Ashton-Franklin Center Elem Sch",
        "district": "Ashton-Franklin Center CUSD 275",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170438004527",
    },
    {
        "school": "Dixon High School",
        "district": "Dixon USD 170",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171233001481",
    },
    {
        "school": "Madison School",
        "district": "Dixon USD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171233001483",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Dixon USD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171233001484",
    },
    {
        "school": "Washington Elem School",
        "district": "Dixon USD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171233001486",
    },
    {
        "school": "Reagan Middle School",
        "district": "Dixon USD 170",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171233005309",
    },
    {
        "school": "Paw Paw Elem School",
        "district": "Paw Paw CUSD 271",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172235002503",
    },
    {
        "school": "Steward Elementary School",
        "district": "Steward ESD 220",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173780003885",
    },
    {
        "school": "Altamont Grade School",
        "district": "Altamont CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170351000033",
    },
    {
        "school": "Altamont High School",
        "district": "Altamont CUSD 10",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170351000034",
    },
    {
        "school": "Beecher City Grade School",
        "district": "Beecher City CUSD 20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170546000224",
    },
    {
        "school": "Beecher City Jr-Sr High School",
        "district": "Beecher City CUSD 20",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170546000225",
    },
    {
        "school": "Dieterich Jr/Sr High School",
        "district": "Dieterich CUSD 30",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171224001477",
    },
    {
        "school": "Dieterich Elem School",
        "district": "Dieterich CUSD 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171224004604",
    },
    {
        "school": "Effingham Junior High School",
        "district": "Effingham CUSD 40",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171356000654",
    },
    {
        "school": "Effingham High School",
        "district": "Effingham CUSD 40",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171356001648",
    },
    {
        "school": "Early Learning Center",
        "district": "Effingham CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171356001650",
    },
    {
        "school": "South Side Grade School",
        "district": "Effingham CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171356001652",
    },
    {
        "school": "Central Grade School",
        "district": "Effingham CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171356002291",
    },
    {
        "school": "Teutopolis Junior High School",
        "district": "Teutopolis CUSD 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173876001890",
    },
    {
        "school": "Teutopolis Grade School",
        "district": "Teutopolis CUSD 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173876003943",
    },
    {
        "school": "Teutopolis High School",
        "district": "Teutopolis CUSD 50",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173876003944",
    },
    {
        "school": "Dakota Elementary School",
        "district": "Dakota CUSD 201",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171161001373",
    },
    {
        "school": "Dakota Jr Sr High School",
        "district": "Dakota CUSD 201",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171161001374",
    },
    {
        "school": "Jones Farrar Intl Baccalaureate",
        "district": "Freeport SD 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171590001137",
    },
    {
        "school": "Center Elem School",
        "district": "Freeport SD 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171590001897",
    },
    {
        "school": "Blackhawk Elem School",
        "district": "Freeport SD 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171590001898",
    },
    {
        "school": "Lincoln-Douglas Elementary School",
        "district": "Freeport SD 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171590001899",
    },
    {
        "school": "Empire Elem School",
        "district": "Freeport SD 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171590001900",
    },
    {
        "school": "Taylor Park Elem School",
        "district": "Freeport SD 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171590001901",
    },
    {
        "school": "Freeport High School",
        "district": "Freeport SD 145",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171590001902",
    },
    {
        "school": "Freeport Middle School",
        "district": "Freeport SD 145",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171590001903",
    },
    {
        "school": "Carl Sandburg Middle Sch",
        "district": "Freeport SD 145",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171590001904",
    },
    {
        "school": "Lena-Winslow Elem School",
        "district": "Lena Winslow CUSD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172253002509",
    },
    {
        "school": "Lena-Winslow High School",
        "district": "Lena Winslow CUSD 202",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172253002510",
    },
    {
        "school": "Lena-Winslow Jr High School",
        "district": "Lena Winslow CUSD 202",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172253002511",
    },
    {
        "school": "Orangeville Jr High School",
        "district": "Orangeville CUSD 203",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173006003112",
    },
    {
        "school": "Orangeville High School",
        "district": "Orangeville CUSD 203",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173006003113",
    },
    {
        "school": "Orangeville Elem School",
        "district": "Orangeville CUSD 203",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173006004782",
    },
    {
        "school": "Pearl City High School",
        "district": "Pearl City CUSD 200",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173102003227",
    },
    {
        "school": "Pearl City Elementary School",
        "district": "Pearl City CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173102004790",
    },
    {
        "school": "Pearl City Jr High School",
        "district": "Pearl City CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173102004791",
    },
    {
        "school": "Monmouth-Roseville High Sch",
        "district": "Monmouth-Roseville CUSD 238",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032005601",
    },
    {
        "school": "Monmouth-Roseville Jr High Sch",
        "district": "Monmouth-Roseville CUSD 238",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032005602",
    },
    {
        "school": "Harding Primary School",
        "district": "Monmouth-Roseville CUSD 238",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032005603",
    },
    {
        "school": "Lincoln Early Childhood School",
        "district": "Monmouth-Roseville CUSD 238",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032005604",
    },
    {
        "school": "United High School",
        "district": "United CUSD 304",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032105608",
    },
    {
        "school": "United Elem Sch - North",
        "district": "United CUSD 304",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032105609",
    },
    {
        "school": "RAES RSSP",
        "district": "Henderson/Knox/Mercer/Warren ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019202923",
    },
    {
        "school": "Nielson Elementary School",
        "district": "Galesburg CUSD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171608001916",
    },
    {
        "school": "Churchill Jr High School",
        "district": "Galesburg CUSD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171608001917",
    },
    {
        "school": "Steele School",
        "district": "Galesburg CUSD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171608001918",
    },
    {
        "school": "Galesburg High School",
        "district": "Galesburg CUSD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171608001923",
    },
    {
        "school": "Silas Willard Elem School",
        "district": "Galesburg CUSD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171608001928",
    },
    {
        "school": "Lombard Jr High School",
        "district": "Galesburg CUSD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171608001929",
    },
    {
        "school": "King School",
        "district": "Galesburg CUSD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171608001931",
    },
    {
        "school": "Gale School",
        "district": "Galesburg CUSD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171608001934",
    },
    {
        "school": "Bright Futures Pre-K Prog",
        "district": "Galesburg CUSD 205",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171608005164",
    },
    {
        "school": "Knoxville Jr High School",
        "district": "Knoxville CUSD 202",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172139002406",
    },
    {
        "school": "Knoxville Sr High School",
        "district": "Knoxville CUSD 202",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172139002407",
    },
    {
        "school": "Mable Woolsey Elem School",
        "district": "Knoxville CUSD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172139002408",
    },
    {
        "school": "R O W V A Jr and  Sr High School",
        "district": "R O W V A CUSD 208",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172994003102",
    },
    {
        "school": "R O W V A  Elem School",
        "district": "R O W V A CUSD 208",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172994003104",
    },
    {
        "school": "Williamsfield Middle School",
        "district": "Williamsfield CUSD 210",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174245004267",
    },
    {
        "school": "Williamsfield High School",
        "district": "Williamsfield CUSD 210",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174245004268",
    },
    {
        "school": "Williamsfield Elem School",
        "district": "Williamsfield CUSD 210",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174245004891",
    },
    {
        "school": "ROE 20 Learning Alt Branch School",
        "district": "Edw/Glt/Hlt/Hdn/Pop/Sln/Wbh/Wn/Wh",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018002658",
    },
    {
        "school": "Carrier Mills-Stonefort Elem Sch",
        "district": "Carrier Mills-Stonefort CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170858000497",
    },
    {
        "school": "Carrier Mills-Stonefort H S",
        "district": "Carrier Mills-Stonefort CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170858000498",
    },
    {
        "school": "Eldorado Elem School",
        "district": "Eldorado CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171366001661",
    },
    {
        "school": "Eldorado High School",
        "district": "Eldorado CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171366001662",
    },
    {
        "school": "Eldorado Middle School",
        "district": "Eldorado CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171366001663",
    },
    {
        "school": "Galatia Jr High",
        "district": "Galatia CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171602001910",
    },
    {
        "school": "Galatia High School",
        "district": "Galatia CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171602001911",
    },
    {
        "school": "Galatia Elem School",
        "district": "Galatia CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171602004639",
    },
    {
        "school": "Harrisburg High School",
        "district": "Harrisburg CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171827002113",
    },
    {
        "school": "Harrisburg Middle School",
        "district": "Harrisburg CUSD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171827002116",
    },
    {
        "school": "East Side Intermediate School",
        "district": "Harrisburg CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171827004403",
    },
    {
        "school": "West Side Primary School",
        "district": "Harrisburg CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171827004404",
    },
    {
        "school": "ROE20 Learning Alternative Branch",
        "district": "Edw/Glt/Hlt/Hdn/Pop/Sln/Wbh/Wn/Wh",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018002669",
    },
    {
        "school": "Ivan K Garrison Center",
        "district": "Four Rivers Spec Educ Dist",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170008005349",
    },
    {
        "school": "Triopia Grade School",
        "district": "Triopia CUSD 27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171083001322",
    },
    {
        "school": "Triopia Jr-Sr High School",
        "district": "Triopia CUSD 27",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171083001324",
    },
    {
        "school": "Franklin Jr/Sr High School",
        "district": "Franklin CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171575001885",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Franklin CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171575005160",
    },
    {
        "school": "Washington Elem School",
        "district": "Jacksonville SD 117",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172028002279",
    },
    {
        "school": "Jacksonville High School",
        "district": "Jacksonville SD 117",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172028002280",
    },
    {
        "school": "Eisenhower Elem School",
        "district": "Jacksonville SD 117",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172028002282",
    },
    {
        "school": "South Jacksonville Elem School",
        "district": "Jacksonville SD 117",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172028002283",
    },
    {
        "school": "Clay Court",
        "district": "Jacksonville SD 117",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172028002284",
    },
    {
        "school": "Jacksonville Middle School",
        "district": "Jacksonville SD 117",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172028002285",
    },
    {
        "school": "Murrayville-Woodson Elem School",
        "district": "Jacksonville SD 117",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172028002286",
    },
    {
        "school": "North Jacksonville School",
        "district": "Jacksonville SD 117",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172028002288",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Jacksonville SD 117",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172028002289",
    },
    {
        "school": "Walnut Court Early Years Prgm",
        "district": "Jacksonville SD 117",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172028004190",
    },
    {
        "school": "Meredosia-Chambersburg High Sch",
        "district": "Meredosia-Chambersburg CUSD 11",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172568002776",
    },
    {
        "school": "Meredosia-Chambersburg Jr High",
        "district": "Meredosia-Chambersburg CUSD 11",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172568002777",
    },
    {
        "school": "Meredosia-Chambersburg Elem Sch",
        "district": "Meredosia-Chambersburg CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172568004736",
    },
    {
        "school": "Waverly Elementary School",
        "district": "Waverly CUSD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174128004144",
    },
    {
        "school": "Waverly Jr/Sr  High School",
        "district": "Waverly CUSD 6",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174128004145",
    },
    {
        "school": "Bluffs High School",
        "district": "Scott-Morgan CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170660000348",
    },
    {
        "school": "Bluffs Elementary School",
        "district": "Scott-Morgan CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170660004551",
    },
    {
        "school": "Bluffs Junior High School",
        "district": "Scott-Morgan CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170660004552",
    },
    {
        "school": "Winchester Elem School",
        "district": "Winchester CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174266004287",
    },
    {
        "school": "Winchester High School",
        "district": "Winchester CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174266004288",
    },
    {
        "school": "Salt School",
        "district": "Iroquois/Kankakee ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018905710",
    },
    {
        "school": "Liberty Intermediate School",
        "district": "Bourbonnais SD 53",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170675005828",
    },
    {
        "school": "Kankakee Area Co-Op Day School",
        "district": "Kankakee Area Spec Educ Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005605105",
    },
    {
        "school": "I Kan Regional Alternatve Att Ctr",
        "district": "Iroquois/Kankakee ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018902916",
    },
    {
        "school": "Alan B Shepard Elem School",
        "district": "Bourbonnais SD 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170675000350",
    },
    {
        "school": "Bourbonnais Upper Grade Center",
        "district": "Bourbonnais SD 53",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170675000351",
    },
    {
        "school": "Shabbona Elem School",
        "district": "Bourbonnais SD 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170675000353",
    },
    {
        "school": "Noel Levasseur Elem School",
        "district": "Bourbonnais SD 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170675004371",
    },
    {
        "school": "Bradley East Elem School",
        "district": "Bradley SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170693000358",
    },
    {
        "school": "Bradley West Elem School",
        "district": "Bradley SD 61",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170693000359",
    },
    {
        "school": "Bradley Central Middle School",
        "district": "Bradley SD 61",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170693000853",
    },
    {
        "school": "Bradley-Bourbonnais C High School",
        "district": "Bradley Bourbonnais CHSD 307",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170696000360",
    },
    {
        "school": "Grant Park Elem School",
        "district": "Grant Park CUSD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171737002051",
    },
    {
        "school": "Grant Park High School",
        "district": "Grant Park CUSD 6",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171737002052",
    },
    {
        "school": "Bonfield Grade School",
        "district": "Herscher CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171884002167",
    },
    {
        "school": "Herscher Intermediate Sch",
        "district": "Herscher CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171884002169",
    },
    {
        "school": "Herscher High School",
        "district": "Herscher CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171884002170",
    },
    {
        "school": "Limestone Middle Sch",
        "district": "Herscher CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171884002171",
    },
    {
        "school": "Proegler School",
        "district": "Kankakee SD 111",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172076000502",
    },
    {
        "school": "Edison Primary School",
        "district": "Kankakee SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172076002357",
    },
    {
        "school": "Taft Primary School",
        "district": "Kankakee SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172076002358",
    },
    {
        "school": "Kankakee High School",
        "district": "Kankakee SD 111",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172076002362",
    },
    {
        "school": "Steuben Elementary School",
        "district": "Kankakee SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172076002364",
    },
    {
        "school": "Lincoln Cltrl Ctr-Montessori Elem",
        "district": "Kankakee SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172076002365",
    },
    {
        "school": "King Middle Grade School",
        "district": "Kankakee SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172076002366",
    },
    {
        "school": "Mark Twain Primary School",
        "district": "Kankakee SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172076002367",
    },
    {
        "school": "Kankakee Junior High School",
        "district": "Kankakee SD 111",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172076005023",
    },
    {
        "school": "John Kennedy Middle Grade School",
        "district": "Kankakee SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172076005569",
    },
    {
        "school": "Manteno Elem School",
        "district": "Manteno CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172439002646",
    },
    {
        "school": "Manteno High School",
        "district": "Manteno CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172439002647",
    },
    {
        "school": "Manteno Middle School",
        "district": "Manteno CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172439002648",
    },
    {
        "school": "Je-Neir Elem School",
        "district": "Momence CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172643002830",
    },
    {
        "school": "Momence High School",
        "district": "Momence CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172643002831",
    },
    {
        "school": "Momence Jr High School",
        "district": "Momence CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172643002832",
    },
    {
        "school": "Lorenzo R Smith Elem School",
        "district": "Pembroke CCSD 259",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173114003248",
    },
    {
        "school": "St Anne Elem School",
        "district": "St Anne CCSD 256",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173712003849",
    },
    {
        "school": "St Anne Comm High School",
        "district": "St Anne CHSD 302",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173714003850",
    },
    {
        "school": "St George Elem School",
        "district": "St George CCSD 258",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173732003865",
    },
    {
        "school": "New Holland-Middletown Elem Sch",
        "district": "New Holland-Middletown ED 88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010305347",
    },
    {
        "school": "Chester-East Lincoln Elem School",
        "district": "Chester-East Lincoln CCSD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170985000580",
    },
    {
        "school": "Emden Elementary School",
        "district": "Hartsburg Emden CUSD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171839002121",
    },
    {
        "school": "Hartsburg-Emden Jr-Sr High School",
        "district": "Hartsburg Emden CUSD 21",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171839002123",
    },
    {
        "school": "Adams Elem School",
        "district": "Lincoln ESD 27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172298002536",
    },
    {
        "school": "Central Elem School",
        "district": "Lincoln ESD 27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172298002537",
    },
    {
        "school": "Lincoln Jr High School",
        "district": "Lincoln ESD 27",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172298002539",
    },
    {
        "school": "Northwest Elem School",
        "district": "Lincoln ESD 27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172298002540",
    },
    {
        "school": "Washington-Monroe Elem School",
        "district": "Lincoln ESD 27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172298002541",
    },
    {
        "school": "Lincoln Comm High School",
        "district": "Lincoln CHSD 404",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172305002542",
    },
    {
        "school": "Mount Pulaski Elem School",
        "district": "Mt Pulaski CUSD 23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172729002891",
    },
    {
        "school": "Mount Pulaski High School",
        "district": "Mt Pulaski CUSD 23",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172729002892",
    },
    {
        "school": "West Lincoln-Broadwell Elem Sch",
        "district": "West Lincoln-Broadwell ESD 92",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174160004169",
    },
    {
        "school": "New Horizons",
        "district": "West Central IL Spec Educ Coop",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170027205699",
    },
    {
        "school": "Project Insight",
        "district": "West Central IL Spec Educ Coop",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170027205700",
    },
    {
        "school": "West Prairie High School",
        "district": "West Prairie CUSD 103",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170031405701",
    },
    {
        "school": "West Prairie Middle School",
        "district": "West Prairie CUSD 103",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170031405702",
    },
    {
        "school": "West Prairie North Elementary",
        "district": "West Prairie CUSD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170031405703",
    },
    {
        "school": "West Prairie South Elementary",
        "district": "West Prairie CUSD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170031405704",
    },
    {
        "school": "ROYALS Academy Carthage",
        "district": "Hancck/Fultn/Schuylr/McDonogh ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018602815",
    },
    {
        "school": "ROYALS RSSP Carthage",
        "district": "Hancck/Fultn/Schuylr/McDonogh ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018602823",
    },
    {
        "school": "ROYALS Academy Macomb",
        "district": "Hancck/Fultn/Schuylr/McDonogh ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018602819",
    },
    {
        "school": "ROYALS RSSP Macomb",
        "district": "Hancck/Fultn/Schuylr/McDonogh ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018602822",
    },
    {
        "school": "Bushnell-Prairie City High Sch",
        "district": "Bushnell Prairie City CUSD 170",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170795000401",
    },
    {
        "school": "Bushnell-Prairie City Jr High Sch",
        "district": "Bushnell Prairie City CUSD 170",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170795000402",
    },
    {
        "school": "Bushnell-Prairie City Elem Sch",
        "district": "Bushnell Prairie City CUSD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170795000403",
    },
    {
        "school": "Macomb Junior High School",
        "district": "Macomb CUSD 185",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172392001701",
    },
    {
        "school": "Edison Elementary School",
        "district": "Macomb CUSD 185",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172392002605",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Macomb CUSD 185",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172392002607",
    },
    {
        "school": "MacArthur Early Childhood Center",
        "district": "Macomb CUSD 185",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172392002609",
    },
    {
        "school": "Macomb Senior High School",
        "district": "Macomb CUSD 185",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172392002611",
    },
    {
        "school": "Williamson Co Learning Cntr",
        "district": "Williamson Co Spec Educ District",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170011805810",
    },
    {
        "school": "Williamson Co Intensive Program",
        "district": "Williamson Co Spec Educ District",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170011805811",
    },
    {
        "school": "Starquest Acad RSSP North",
        "district": "Frankln/Johnsn/Massc/Willimsn ROE",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018202674",
    },
    {
        "school": "Project Echo",
        "district": "Frankln/Johnsn/Massc/Willimsn ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018202670",
    },
    {
        "school": "Tri-C Elementary School",
        "district": "Carterville CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170864000503",
    },
    {
        "school": "Carterville High School",
        "district": "Carterville CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170864000504",
    },
    {
        "school": "Carterville Jr High Sch",
        "district": "Carterville CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170864000505",
    },
    {
        "school": "Crab Orchard High School",
        "district": "Crab Orchard CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171110001338",
    },
    {
        "school": "Crab Orchard Elementary School",
        "district": "Crab Orchard CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171110004587",
    },
    {
        "school": "Herrin C U S D 4 Elem School",
        "district": "Herrin CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171881001624",
    },
    {
        "school": "Herrin High School",
        "district": "Herrin CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171881002161",
    },
    {
        "school": "North Side Primary Center",
        "district": "Herrin CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171881002164",
    },
    {
        "school": "Herrin Middle School",
        "district": "Herrin CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171881005511",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Johnston City CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172055002319",
    },
    {
        "school": "Johnston City High School",
        "district": "Johnston City CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172055002320",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Johnston City CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172055002321",
    },
    {
        "school": "Washington Middle School",
        "district": "Johnston City CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172055002322",
    },
    {
        "school": "Adams School",
        "district": "Marion CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172460002662",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Marion CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172460002663",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Marion CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172460002664",
    },
    {
        "school": "Longfellow Elem School",
        "district": "Marion CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172460002665",
    },
    {
        "school": "Marion High School",
        "district": "Marion CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172460002666",
    },
    {
        "school": "Marion Jr High School",
        "district": "Marion CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172460002667",
    },
    {
        "school": "Washington Elem School",
        "district": "Marion CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172460002668",
    },
    {
        "school": "Dahlgren Elem School",
        "district": "Hamilton Co CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171079001307",
    },
    {
        "school": "East Side Elementary School",
        "district": "Hamilton Co CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171079001309",
    },
    {
        "school": "Hamilton County Jr/Sr High School",
        "district": "Hamilton Co CUSD 10",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171079004391",
    },
    {
        "school": "Hamilton County Preschool Center",
        "district": "Hamilton Co CUSD 10",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171079005155",
    },
    {
        "school": "Oakland Education Center",
        "district": "Franklin-Jefferson Co Sp Ed Dist",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170004805562",
    },
    {
        "school": "Bethel Grade School",
        "district": "Bethel SD 82",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170618000305",
    },
    {
        "school": "Farrington Elem School",
        "district": "Farrington CCSD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171494001831",
    },
    {
        "school": "Field Elementary School",
        "district": "Field CCSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171509001833",
    },
    {
        "school": "McClellan Elementary School",
        "district": "McClellan CCSD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172526002753",
    },
    {
        "school": "Zadok Casey Middle School",
        "district": "Mount Vernon SD 80",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172734002898",
    },
    {
        "school": "J L Buford Intermediate Ed Ctr",
        "district": "Mount Vernon SD 80",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172734002902",
    },
    {
        "school": "Dr Nick Osborne Primary Center",
        "district": "Mount Vernon SD 80",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172734004392",
    },
    {
        "school": "Dr Andy Hall Early Educ Ctr",
        "district": "Mount Vernon SD 80",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172734004393",
    },
    {
        "school": "Mount Vernon High School",
        "district": "Mt Vernon Twp HSD 201",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172736002904",
    },
    {
        "school": "Rome Comm Cons Elem School",
        "district": "Rome CCSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173459003625",
    },
    {
        "school": "Summersville Grade School",
        "district": "Summersville SD 79",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173819003908",
    },
    {
        "school": "Waltonville Grade School",
        "district": "Waltonville CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174065004086",
    },
    {
        "school": "Waltonville High School",
        "district": "Waltonville CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174065004087",
    },
    {
        "school": "Bureau Valley High School",
        "district": "Bureau Valley CUSD 340",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012501425",
    },
    {
        "school": "Bureau Valley North",
        "district": "Bureau Valley CUSD 340",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012501426",
    },
    {
        "school": "Bureau Valley Elemntry-Wyanet",
        "district": "Bureau Valley CUSD 340",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012502860",
    },
    {
        "school": "Dalzell Grade School",
        "district": "Dalzell SD 98",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171170001378",
    },
    {
        "school": "DePue High School",
        "district": "DePue USD 103",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171209001459",
    },
    {
        "school": "DePue Elem School",
        "district": "DePue USD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171209004603",
    },
    {
        "school": "Hall High School",
        "district": "Hall HSD 502",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171803002082",
    },
    {
        "school": "Ladd Comm Cons Sch",
        "district": "Ladd CCSD 94",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172151002419",
    },
    {
        "school": "Van Orin Elem School",
        "district": "La Moille CUSD 303",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172168002433",
    },
    {
        "school": "La Moille High School",
        "district": "La Moille CUSD 303",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172168002434",
    },
    {
        "school": "Allen Junior High School",
        "district": "La Moille CUSD 303",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172168002435",
    },
    {
        "school": "Malden Grade School",
        "district": "Malden CCSD 84",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172412002635",
    },
    {
        "school": "Ohio Com Cons Grade School",
        "district": "Ohio CCSD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172970003084",
    },
    {
        "school": "Ohio Community High School",
        "district": "Ohio CHSD 505",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172973003085",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Princeton ESD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173267003388",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Princeton ESD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173267003389",
    },
    {
        "school": "Logan Jr High School",
        "district": "Princeton ESD 115",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173267003390",
    },
    {
        "school": "Princeton High School",
        "district": "Princeton HSD 500",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173270003392",
    },
    {
        "school": "John F Kennedy Elem School",
        "district": "Spring Valley CCSD 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173705003812",
    },
    {
        "school": "Northlawn Jr High School",
        "district": "Streator ESD 44",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011205381",
    },
    {
        "school": "Centennial Elem School",
        "district": "Streator ESD 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011205382",
    },
    {
        "school": "Kimes Elem School",
        "district": "Streator ESD 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011205383",
    },
    {
        "school": "Lostant Elem School",
        "district": "Lostant CUSD 425",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012002584",
    },
    {
        "school": "LMP ROE",
        "district": "La Salle/Marshall/Putnam ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019402993",
    },
    {
        "school": "Circuit Breaker School",
        "district": "LaSalle Putnam Alliance",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022804420",
    },
    {
        "school": "Ransom Grade School",
        "district": "Allen-Otter Creek CCSD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170342000026",
    },
    {
        "school": "Marseilles Elementary School",
        "district": "Marseilles ESD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170546605466",
    },
    {
        "school": "Deer Park C C Elem School",
        "district": "Deer Park CCSD 82",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171191001436",
    },
    {
        "school": "Earlville Jr/Sr High School",
        "district": "Earlville CUSD 9",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171293001541",
    },
    {
        "school": "Earlville Elem School",
        "district": "Earlville CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171293004615",
    },
    {
        "school": "Harding Grade School",
        "district": "Serena CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171588001893",
    },
    {
        "school": "Serena High School",
        "district": "Serena CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171588001894",
    },
    {
        "school": "Sheridan Elem School",
        "district": "Serena CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171588001896",
    },
    {
        "school": "Grand Ridge School",
        "district": "Grand Ridge CCSD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171722002023",
    },
    {
        "school": "Lincoln Jr High School",
        "district": "La Salle ESD 122",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172208002477",
    },
    {
        "school": "Northwest Elem School",
        "district": "La Salle ESD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172208002478",
    },
    {
        "school": "La Salle-Peru Twp High School",
        "district": "La Salle-Peru Twp HSD 120",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172211002481",
    },
    {
        "school": "Leland High School",
        "district": "Leland CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172287002533",
    },
    {
        "school": "Leland Elem School",
        "district": "Leland CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172287004701",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Mendota CCSD 289",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172562002772",
    },
    {
        "school": "Northbrook School",
        "district": "Mendota CCSD 289",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172562002773",
    },
    {
        "school": "Blackstone Elem School",
        "district": "Mendota CCSD 289",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172562004735",
    },
    {
        "school": "Mendota Twp High School",
        "district": "Mendota Twp HSD 280",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172565002775",
    },
    {
        "school": "Milton Pope Elem School",
        "district": "Miller Twp CCSD 210",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172625002795",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Oglesby ESD 125",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172967003082",
    },
    {
        "school": "Washington Elem School",
        "district": "Oglesby ESD 125",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172967003083",
    },
    {
        "school": "Central Intermediate School",
        "district": "Ottawa ESD 141",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173030003135",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Ottawa ESD 141",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173030003136",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Ottawa ESD 141",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173030003138",
    },
    {
        "school": "McKinley Elem School",
        "district": "Ottawa ESD 141",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173030003139",
    },
    {
        "school": "Shepherd Middle School",
        "district": "Ottawa ESD 141",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173030003140",
    },
    {
        "school": "Ottawa Township High School",
        "district": "Ottawa Twp HSD 140",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173033003141",
    },
    {
        "school": "Northview Elem School",
        "district": "Peru ESD 124",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173138003308",
    },
    {
        "school": "Parkside Middle School",
        "district": "Peru ESD 124",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173138003309",
    },
    {
        "school": "Rutland Elem School",
        "district": "Rutland CCSD 230",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173510003676",
    },
    {
        "school": "Seneca Elem School South Campus",
        "district": "Seneca CCSD 170",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173582003021",
    },
    {
        "school": "Seneca Grade School North Campus",
        "district": "Seneca CCSD 170",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173582003727",
    },
    {
        "school": "Seneca High School",
        "district": "Seneca Twp HSD 160",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173585003728",
    },
    {
        "school": "Streator Twp High School",
        "district": "Streator Twp HSD 40",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173810003903",
    },
    {
        "school": "Tonica Grade School",
        "district": "Tonica CCSD 79",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173918003976",
    },
    {
        "school": "Wallace Elem School",
        "district": "Wallace CCSD 195",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174053004082",
    },
    {
        "school": "Waltham Elementary School",
        "district": "Waltham CCSD 185",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174062004085",
    },
    {
        "school": "Woodland High School",
        "district": "Woodland CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173807003900",
    },
    {
        "school": "Woodland Elementary/Jr High Sch",
        "district": "Woodland CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173807004848",
    },
    {
        "school": "Putnam County Jr High School",
        "district": "Putnam County CUSD 535",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173296003409",
    },
    {
        "school": "Putnam County High School",
        "district": "Putnam County CUSD 535",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173296003412",
    },
    {
        "school": "Putnam County Elem School",
        "district": "Putnam County CUSD 535",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173296004807",
    },
    {
        "school": "Joppa Jr & Sr High School",
        "district": "Joppa-Maple Grove UD 38",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170001505226",
    },
    {
        "school": "Maple Grove Elem School",
        "district": "Joppa-Maple Grove UD 38",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170001505227",
    },
    {
        "school": "Massac Jr High School",
        "district": "Massac UD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172500002708",
    },
    {
        "school": "Metropolis Elem School",
        "district": "Massac UD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172500002710",
    },
    {
        "school": "Unity Elem School",
        "district": "Massac UD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172500002711",
    },
    {
        "school": "Franklin Elem School",
        "district": "Massac UD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172500002712",
    },
    {
        "school": "Massac County High School",
        "district": "Massac UD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172500002713",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Massac UD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172500002714",
    },
    {
        "school": "Brookport Elementary School",
        "district": "Massac UD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172500002715",
    },
    {
        "school": "El Paso-Gridley Jr High School",
        "district": "El Paso-Gridley CUSD 11",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032605635",
    },
    {
        "school": "Farmington Central Jr High Sch",
        "district": "Farmington Central CUSD 265",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170004405737",
    },
    {
        "school": "Farmington Central Elem Sch",
        "district": "Farmington Central CUSD 265",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170004405738",
    },
    {
        "school": "Greeley Alternative School",
        "district": "Peoria ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020305736",
    },
    {
        "school": "Day Treatment",
        "district": "Peoria SD 150",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123005846",
    },
    {
        "school": "Bradford Jr High School",
        "district": "Bradford CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170688004784",
    },
    {
        "school": "Pekin Preschool Family Ed Center",
        "district": "Pekin PSD 108",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173108004905",
    },
    {
        "school": "El Paso-Gridley High School",
        "district": "El Paso-Gridley CUSD 11",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032605634",
    },
    {
        "school": "Centennial School",
        "district": "El Paso-Gridley CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032605636",
    },
    {
        "school": "Jefferson Park School",
        "district": "El Paso-Gridley CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032605637",
    },
    {
        "school": "Germantown Hills Middle School",
        "district": "Germantown Hills SD 69",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171656005639",
    },
    {
        "school": "Henry-Senachwine High School",
        "district": "Henry-Senachwine CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011505395",
    },
    {
        "school": "Henry-Senachwine Grade School",
        "district": "Henry-Senachwine CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011505396",
    },
    {
        "school": "Midland High School",
        "district": "Midland CUSD 7",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012601479",
    },
    {
        "school": "Midland Middle School",
        "district": "Midland CUSD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012601482",
    },
    {
        "school": "Midland Elementary School",
        "district": "Midland CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012601488",
    },
    {
        "school": "Bradford Grade School",
        "district": "Bradford CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170688000355",
    },
    {
        "school": "Stark County Junior High School",
        "district": "Stark County CUSD 100",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173749000012",
    },
    {
        "school": "Stark County Elem Sch",
        "district": "Stark County CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173749003687",
    },
    {
        "school": "Stark County High School",
        "district": "Stark County CUSD 100",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173749003979",
    },
    {
        "school": "Fieldcrest Intermediate School",
        "district": "Fieldcrest CUSD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171510004856",
    },
    {
        "school": "Lowpoint-Washburn Elem School",
        "district": "Lowpoint-Washburn CUSD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174092004877",
    },
    {
        "school": "Farmington Central High Sch",
        "district": "Farmington Central CUSD 265",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170004405230",
    },
    {
        "school": "Bartonville Elem School",
        "district": "Bartonville SD 66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170519000199",
    },
    {
        "school": "Brimfield Grade School",
        "district": "Brimfield CUSD 309",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170720000374",
    },
    {
        "school": "Brimfield High School",
        "district": "Brimfield CUSD 309",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170720000375",
    },
    {
        "school": "Dunlap Grade School",
        "district": "Dunlap CUSD 323",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171270001521",
    },
    {
        "school": "Dunlap High School",
        "district": "Dunlap CUSD 323",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171270001522",
    },
    {
        "school": "Dunlap Middle School",
        "district": "Dunlap CUSD 323",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171270001523",
    },
    {
        "school": "Wilder-Waite Grade School",
        "district": "Dunlap CUSD 323",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171270001524",
    },
    {
        "school": "Banner Elementary School",
        "district": "Dunlap CUSD 323",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171270004389",
    },
    {
        "school": "Ridgeview Elementary School",
        "district": "Dunlap CUSD 323",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171270004470",
    },
    {
        "school": "Elmwood Elem School",
        "district": "Elmwood CUSD 322",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171405001756",
    },
    {
        "school": "Elmwood Junior High School",
        "district": "Elmwood CUSD 322",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171405001757",
    },
    {
        "school": "Elmwood High School",
        "district": "Elmwood CUSD 322",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171405001758",
    },
    {
        "school": "Hollis Consolidated Grade Sch",
        "district": "Hollis Cons SD 328",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171942002224",
    },
    {
        "school": "Illini Bluffs High School",
        "district": "Illini Bluffs CUSD 327",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171996002250",
    },
    {
        "school": "Illini Bluffs Elementary School",
        "district": "Illini Bluffs CUSD 327",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171996002252",
    },
    {
        "school": "Illini Bluffs Middle School",
        "district": "Illini Bluffs CUSD 327",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171996002254",
    },
    {
        "school": "Il Valley Central High School",
        "district": "Il Valley Central USD 321",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171997002256",
    },
    {
        "school": "Mossville Elementary School",
        "district": "Il Valley Central USD 321",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171997002257",
    },
    {
        "school": "South Elementary School",
        "district": "Il Valley Central USD 321",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171997002261",
    },
    {
        "school": "Chillicothe Elementary Center",
        "district": "Il Valley Central USD 321",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171997005426",
    },
    {
        "school": "Limestone Walters Elem School",
        "district": "Limestone Walters CCSD 316",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172292002534",
    },
    {
        "school": "Limestone Community High School",
        "district": "Limestone CHSD 310",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172295002535",
    },
    {
        "school": "Monroe Elem School",
        "district": "Monroe SD 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172649002840",
    },
    {
        "school": "Norwood Elem School",
        "district": "Norwood ESD 63",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172904003218",
    },
    {
        "school": "Norwood Primary School",
        "district": "Norwood ESD 63",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172904005440",
    },
    {
        "school": "Oak Grove School",
        "district": "Oak Grove SD 68  Bartonville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172910003045",
    },
    {
        "school": "Valeska Hinton Early Ch Ed Ctr",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123000593",
    },
    {
        "school": "Washington Gifted School",
        "district": "Peoria SD 150",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123000973",
    },
    {
        "school": "Franklin Primary School",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003259",
    },
    {
        "school": "Glen Oak Comm Learning Cntr",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003262",
    },
    {
        "school": "Harrison Comm Learning Cntr",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003265",
    },
    {
        "school": "Hines Primary School",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003266",
    },
    {
        "school": "Lincoln School",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003268",
    },
    {
        "school": "Kellar Primary School",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003269",
    },
    {
        "school": "Manual Academy",
        "district": "Peoria SD 150",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003274",
    },
    {
        "school": "Northmoor Primary School",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003276",
    },
    {
        "school": "Peoria High School",
        "district": "Peoria SD 150",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003278",
    },
    {
        "school": "Richwoods High School",
        "district": "Peoria SD 150",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003280",
    },
    {
        "school": "Robert A Jamieson School",
        "district": "Peoria SD 150",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003281",
    },
    {
        "school": "Roosevelt Magnet School",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003283",
    },
    {
        "school": "Thomas Jefferson Primary School",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003286",
    },
    {
        "school": "Whittier Primary School",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003293",
    },
    {
        "school": "Dr Maude A Sanders Primary School",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123003294",
    },
    {
        "school": "Charter Oak Primary School",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123004422",
    },
    {
        "school": "Rolling Acres Middle School",
        "district": "Peoria SD 150",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123005324",
    },
    {
        "school": "Sterling Middle School",
        "district": "Peoria SD 150",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123005325",
    },
    {
        "school": "Von Steuben Middle School",
        "district": "Peoria SD 150",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123005326",
    },
    {
        "school": "Calvin Coolidge Middle School",
        "district": "Peoria SD 150",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123005329",
    },
    {
        "school": "Charles A Lindbergh Middle School",
        "district": "Peoria SD 150",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123005332",
    },
    {
        "school": "Mark W Bills Middle School",
        "district": "Peoria SD 150",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123005336",
    },
    {
        "school": "Peoria Heights High School",
        "district": "Peoria Heights CUSD 325",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173127003300",
    },
    {
        "school": "Peoria Heights Grade School",
        "district": "Peoria Heights CUSD 325",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173127004474",
    },
    {
        "school": "Pleasant Hill Elem School",
        "district": "Pleasant Hill SD 69",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173186003344",
    },
    {
        "school": "Pleasant Valley Elem School",
        "district": "Pleasant Valley SD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173195003350",
    },
    {
        "school": "Princeville Elem School",
        "district": "Princeville CUSD 326",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173277003395",
    },
    {
        "school": "Princeville High School",
        "district": "Princeville CUSD 326",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173277003396",
    },
    {
        "school": "Schramm Education Center",
        "district": "Tazewell-Mason Cntys Sp Ed Assoc",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170009104616",
    },
    {
        "school": "ROE 53 Safe School",
        "district": "Mason/Tazewell/Woodford ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020904502",
    },
    {
        "school": "Central Intermediate Sch",
        "district": "Central SD 51",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170915000524",
    },
    {
        "school": "LaSalle Elem School",
        "district": "Creve Coeur SD 76",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171129001353",
    },
    {
        "school": "Parkview Jr High School",
        "district": "Creve Coeur SD 76",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171129001354",
    },
    {
        "school": "Dee-Mack Intermediate School",
        "district": "Deer Creek-Mackinaw CUSD 701",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171188001433",
    },
    {
        "school": "Dee-Mack High School",
        "district": "Deer Creek-Mackinaw CUSD 701",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171188001434",
    },
    {
        "school": "Dee-Mack Primary/Jr High",
        "district": "Deer Creek-Mackinaw CUSD 701",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171188001435",
    },
    {
        "school": "Delavan High School",
        "district": "Delavan CUSD 703",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171206001458",
    },
    {
        "school": "Delavan Elementary School",
        "district": "Delavan CUSD 703",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171206004601",
    },
    {
        "school": "Delavan Jr High School",
        "district": "Delavan CUSD 703",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171206004602",
    },
    {
        "school": "East Peoria High School",
        "district": "East Peoria CHSD 309",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171323001567",
    },
    {
        "school": "Armstrong-Oakview Elem School",
        "district": "East Peoria SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171324001568",
    },
    {
        "school": "Central Jr High School",
        "district": "East Peoria SD 86",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171324001569",
    },
    {
        "school": "Woodrow Wilson Elem School",
        "district": "East Peoria SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171324001570",
    },
    {
        "school": "Glendale Elem School",
        "district": "East Peoria SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171324001571",
    },
    {
        "school": "Lincoln Elem School",
        "district": "East Peoria SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171324001572",
    },
    {
        "school": "P L Bolin Elem School",
        "district": "East Peoria SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171324001574",
    },
    {
        "school": "Don D Shute Elem School",
        "district": "East Peoria SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171324001575",
    },
    {
        "school": "Grundy Elem School",
        "district": "Morton CUSD 709",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172680002861",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Morton CUSD 709",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172680002862",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Morton CUSD 709",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172680002863",
    },
    {
        "school": "Morton High School",
        "district": "Morton CUSD 709",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172680002864",
    },
    {
        "school": "Morton Jr High School",
        "district": "Morton CUSD 709",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172680002865",
    },
    {
        "school": "Lettie Brown Elementary School",
        "district": "Morton CUSD 709",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172680005284",
    },
    {
        "school": "Georgetowne Middle School",
        "district": "N Pekin & Marquette Hght SD 102",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172892003034",
    },
    {
        "school": "Marquette Elem School",
        "district": "N Pekin & Marquette Hght SD 102",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172892003035",
    },
    {
        "school": "Rogers Elementary School",
        "district": "N Pekin & Marquette Hght SD 102",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172892003036",
    },
    {
        "school": "Broadmoor Junior High School",
        "district": "Pekin PSD 108",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173108003230",
    },
    {
        "school": "Willow Elem School",
        "district": "Pekin PSD 108",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173108003231",
    },
    {
        "school": "Edison Junior High School",
        "district": "Pekin PSD 108",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173108003233",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Pekin PSD 108",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173108003234",
    },
    {
        "school": "C B Smith Elem School",
        "district": "Pekin PSD 108",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173108003235",
    },
    {
        "school": "Wilson Intermediate School",
        "district": "Pekin PSD 108",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173108003236",
    },
    {
        "school": "L E Starke Elem School",
        "district": "Pekin PSD 108",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173108003237",
    },
    {
        "school": "Scott Altman Primary School",
        "district": "Pekin PSD 108",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173108003238",
    },
    {
        "school": "Dirksen Elementary School",
        "district": "Pekin PSD 108",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173108005048",
    },
    {
        "school": "Washington Intermediate School",
        "district": "Pekin PSD 108",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173108005189",
    },
    {
        "school": "Pekin Community High School",
        "district": "Pekin CSD 303",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173111003245",
    },
    {
        "school": "Rankin Elem School",
        "district": "Rankin CSD 98",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173312003436",
    },
    {
        "school": "Robein Elem School",
        "district": "Robein SD 85",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173417003504",
    },
    {
        "school": "South Pekin Elem School",
        "district": "South Pekin SD 137",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173678003784",
    },
    {
        "school": "Spring Lake Elem School",
        "district": "Spring Lake CCSD 606",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173702003811",
    },
    {
        "school": "Tremont Middle School",
        "district": "Tremont CUSD 702",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173939003984",
    },
    {
        "school": "Tremont High School",
        "district": "Tremont CUSD 702",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173939003985",
    },
    {
        "school": "Tremont Elem School",
        "district": "Tremont CUSD 702",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173939004857",
    },
    {
        "school": "Washington Comm High School",
        "district": "Washington CHSD 308",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174098004105",
    },
    {
        "school": "J L Hensey Elem School",
        "district": "District 50 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174101004106",
    },
    {
        "school": "Beverly Manor Elementary School",
        "district": "District 50 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174101004878",
    },
    {
        "school": "Lincoln Grade School",
        "district": "Washington SD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174104004108",
    },
    {
        "school": "Washington Middle School",
        "district": "Washington SD 52",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174104004109",
    },
    {
        "school": "Congerville Elem School",
        "district": "Eureka CUD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171443001779",
    },
    {
        "school": "Davenport Elem School",
        "district": "Eureka CUD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171443001780",
    },
    {
        "school": "Eureka High School",
        "district": "Eureka CUD 140",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171443001781",
    },
    {
        "school": "Eureka Middle School",
        "district": "Eureka CUD 140",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171443001782",
    },
    {
        "school": "Goodfield Elem School",
        "district": "Eureka CUD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171443001783",
    },
    {
        "school": "Fieldcrest High School",
        "district": "Fieldcrest CUSD 6",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171510000013",
    },
    {
        "school": "Fieldcrest Primary School",
        "district": "Fieldcrest CUSD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171510004740",
    },
    {
        "school": "Germantown Hills Elementary Sch",
        "district": "Germantown Hills SD 69",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171656004398",
    },
    {
        "school": "Metamora Grade School",
        "district": "Metamora CCSD 1",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172574002783",
    },
    {
        "school": "Metamora High School",
        "district": "County of Woodford School",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172577002784",
    },
    {
        "school": "Riverview Elem School",
        "district": "Riverview CCSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173411003500",
    },
    {
        "school": "Roanoke-Benson High School",
        "district": "Roanoke Benson CUSD 60",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173414003501",
    },
    {
        "school": "Roanoke-Benson Jr High School",
        "district": "Roanoke Benson CUSD 60",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173414003502",
    },
    {
        "school": "Sowers Elementary School",
        "district": "Roanoke Benson CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173414003503",
    },
    {
        "school": "Lowpoint-Washburn Jr Sr High Sch",
        "district": "Lowpoint-Washburn CUSD 21",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174092004104",
    },
    {
        "school": "Prairie Central Primary West",
        "district": "Prairie Central CUSD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000505190",
    },
    {
        "school": "Prairie Central Upper Elementary",
        "district": "Prairie Central CUSD 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000502056",
    },
    {
        "school": "Prairie Central High School",
        "district": "Prairie Central CUSD 8",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000505126",
    },
    {
        "school": "Prairie Central Jr High School",
        "district": "Prairie Central CUSD 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000505127",
    },
    {
        "school": "Prairie Central  Elem School",
        "district": "Prairie Central CUSD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000505129",
    },
    {
        "school": "Prairie Central Primary East",
        "district": "Prairie Central CUSD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170000505130",
    },
    {
        "school": "Saunemin Elem School",
        "district": "Saunemin CCSD 438",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170006505246",
    },
    {
        "school": "Livingston County Academy",
        "district": "Livingston Co Spec Services Unit",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022904332",
    },
    {
        "school": "Livingston Co Crossroads Academy",
        "district": "Livingston Co Spec Services Unit",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022904334",
    },
    {
        "school": "Cornell Elem School",
        "district": "Cornell CCSD 426",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171086001325",
    },
    {
        "school": "Dwight Common School",
        "district": "Dwight Common SD 232",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171284001537",
    },
    {
        "school": "Dwight High School",
        "district": "Dwight Twp HSD 230",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171287001538",
    },
    {
        "school": "Odell Grade School",
        "district": "Odell CCSD 435",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172952003077",
    },
    {
        "school": "Central Elem School",
        "district": "Pontiac CCSD 429",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173216003362",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Pontiac CCSD 429",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173216003363",
    },
    {
        "school": "Washington Elem School",
        "district": "Pontiac CCSD 429",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173216003364",
    },
    {
        "school": "Pontiac Jr High School",
        "district": "Pontiac CCSD 429",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173216003365",
    },
    {
        "school": "Pontiac High School",
        "district": "Pontiac Twp HSD 90",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173222003369",
    },
    {
        "school": "Graymont Elem School",
        "district": "Rooks Creek CCSD 425",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173465003627",
    },
    {
        "school": "Central Elementary Grade School",
        "district": "Central CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170822000430",
    },
    {
        "school": "Central High School",
        "district": "Central CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170822000431",
    },
    {
        "school": "Central Junior High School",
        "district": "Central CUSD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170822005402",
    },
    {
        "school": "Central 3-4 Middle School",
        "district": "Central CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170822005403",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Liberty CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172277002523",
    },
    {
        "school": "Liberty High School",
        "district": "Liberty CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172277002524",
    },
    {
        "school": "Unity High School",
        "district": "CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172559002771",
    },
    {
        "school": "Unity Elementary School",
        "district": "CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172559004734",
    },
    {
        "school": "Seymour Elementary School",
        "district": "Payson CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173099003225",
    },
    {
        "school": "Seymour High School",
        "district": "Payson CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173099003226",
    },
    {
        "school": "Thomas S Baldwin Elem Sch Site 2",
        "district": "Quincy SD 172",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173300003359",
    },
    {
        "school": "Quincy Sr High School",
        "district": "Quincy SD 172",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173300005053",
    },
    {
        "school": "Quincy Jr High School",
        "district": "Quincy SD 172",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173300005054",
    },
    {
        "school": "Sarah Atwater Denman Elem Site 2",
        "district": "Quincy SD 172",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173300005055",
    },
    {
        "school": "Colonel George Iles Elem Sch",
        "district": "Quincy SD 172",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173300005056",
    },
    {
        "school": "Lincoln-Douglas Elementary School",
        "district": "Quincy SD 172",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173300005059",
    },
    {
        "school": "Dr. Abby Fox Rooney Elem Sch",
        "district": "Quincy SD 172",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173300005060",
    },
    {
        "school": "Adams Co Juvenile Detention Cntr",
        "district": "Quincy SD 172",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173300005082",
    },
    {
        "school": "Early Childhood",
        "district": "Quincy SD 172",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173300005520",
    },
    {
        "school": "Byron High School 9-12",
        "district": "Byron CUSD 226",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170801000407",
    },
    {
        "school": "Byron Middle School",
        "district": "Byron CUSD 226",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170801000408",
    },
    {
        "school": "Mary Morgan Elem Sch",
        "district": "Byron CUSD 226",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170801004559",
    },
    {
        "school": "Creston Elem School",
        "district": "Creston CCSD 161",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171122001341",
    },
    {
        "school": "Eswood C C Grade School",
        "district": "Eswood CCSD 269",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171441001778",
    },
    {
        "school": "Forreston Jr/Sr High Sch",
        "district": "Forrestville Valley CUSD 221",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171549001868",
    },
    {
        "school": "Forreston Grade School",
        "district": "Forrestville Valley CUSD 221",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171549001869",
    },
    {
        "school": "Kings Elementary School",
        "district": "Kings Cons SD 144",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172113002392",
    },
    {
        "school": "Meridian Jr High School",
        "district": "Meridian CUSD 223",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172569002778",
    },
    {
        "school": "Highland Elem School",
        "district": "Meridian CUSD 223",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172569002779",
    },
    {
        "school": "Monroe Center Grade School",
        "district": "Meridian CUSD 223",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172569002780",
    },
    {
        "school": "Stillman Valley High School",
        "district": "Meridian CUSD 223",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172569002781",
    },
    {
        "school": "Oregon Elem Sch",
        "district": "Oregon CUSD 220",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173016003116",
    },
    {
        "school": "Oregon High School",
        "district": "Oregon CUSD 220",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173016003118",
    },
    {
        "school": "David L Rahn Jr High School",
        "district": "Oregon CUSD 220",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173016005588",
    },
    {
        "school": "Centennial Elem School",
        "district": "Polo CUSD 222",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173210003358",
    },
    {
        "school": "Polo Comm High School",
        "district": "Polo CUSD 222",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173210003360",
    },
    {
        "school": "Aplington Middle School",
        "district": "Polo CUSD 222",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173210003361",
    },
    {
        "school": "Central Elem School",
        "district": "Rochelle CCSD 231",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173426003511",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Rochelle CCSD 231",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173426003512",
    },
    {
        "school": "May Elem School",
        "district": "Rochelle CCSD 231",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173426003513",
    },
    {
        "school": "Rochelle Middle School",
        "district": "Rochelle CCSD 231",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173426003514",
    },
    {
        "school": "Tilton Elem School",
        "district": "Rochelle CCSD 231",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173426003515",
    },
    {
        "school": "Rochelle Twp High School",
        "district": "Rochelle Twp HSD 212",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173429003516",
    },
    {
        "school": "German Valley Grade School",
        "district": "Forrestville Valley CUSD 221",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171549001866",
    },
    {
        "school": "Belvidere Central Middle School",
        "district": "Belvidere CUSD 100",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170579004634",
    },
    {
        "school": "North Boone Middle School",
        "district": "North Boone CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172870004967",
    },
    {
        "school": "Regional Alternative School",
        "district": "Boone/Winnebago ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016605647",
    },
    {
        "school": "Pecatonica Comm Middle School",
        "district": "Pecatonica CUSD 321",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173105005648",
    },
    {
        "school": "Blackhawk Elementary School",
        "district": "County of Winnebago SD 320",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173660004638",
    },
    {
        "school": "Reg'l Learning Center Star Boone",
        "district": "Boone/Winnebago ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016602335",
    },
    {
        "school": "Belvidere High School",
        "district": "Belvidere CUSD 100",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170579000255",
    },
    {
        "school": "Belvidere South Middle School",
        "district": "Belvidere CUSD 100",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170579000256",
    },
    {
        "school": "Caledonia Elem School",
        "district": "Belvidere CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170579000257",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Belvidere CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170579000259",
    },
    {
        "school": "Perry Elem School",
        "district": "Belvidere CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170579000261",
    },
    {
        "school": "Washington Academy",
        "district": "Belvidere CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170579000262",
    },
    {
        "school": "Meehan Elementary School",
        "district": "Belvidere CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170579001089",
    },
    {
        "school": "North Boone Upper Elem Sch",
        "district": "North Boone CUSD 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172870001115",
    },
    {
        "school": "Capron Elem School",
        "district": "North Boone CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172870003011",
    },
    {
        "school": "Manchester Elem School",
        "district": "North Boone CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172870003012",
    },
    {
        "school": "North Boone High School",
        "district": "North Boone CUSD 200",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172870003013",
    },
    {
        "school": "Poplar Grove Elem School",
        "district": "North Boone CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172870003014",
    },
    {
        "school": "Reg'l Learning Center Star Winn",
        "district": "Boone/Winnebago ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016602313",
    },
    {
        "school": "Reg'l Learning Academy Star Winn",
        "district": "Boone/Winnebago ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016602338",
    },
    {
        "school": "Durand High School",
        "district": "Durand CUSD 322",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171281001536",
    },
    {
        "school": "Durand Elem School",
        "district": "Durand CUSD 322",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171281004613",
    },
    {
        "school": "Durand Jr High School",
        "district": "Durand CUSD 322",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171281004614",
    },
    {
        "school": "Dolan Ctr Maryville Farm Campus",
        "district": "Durand CUSD 322",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171281005157",
    },
    {
        "school": "Olson Park Elem School",
        "district": "Harlem UD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171824000670",
    },
    {
        "school": "Donald C Parker Early Educ Center",
        "district": "Harlem UD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171824001907",
    },
    {
        "school": "Harlem High School",
        "district": "Harlem UD 122",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171824002100",
    },
    {
        "school": "Maple Elem School",
        "district": "Harlem UD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171824002103",
    },
    {
        "school": "Marquette Elem School",
        "district": "Harlem UD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171824002104",
    },
    {
        "school": "Rock Cut Elem School",
        "district": "Harlem UD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171824002105",
    },
    {
        "school": "Loves Park Elem School",
        "district": "Harlem UD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171824002106",
    },
    {
        "school": "Ralston Elem School",
        "district": "Harlem UD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171824002107",
    },
    {
        "school": "Windsor Elem School",
        "district": "Harlem UD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171824002109",
    },
    {
        "school": "Harlem Middle School",
        "district": "Harlem UD 122",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171824005017",
    },
    {
        "school": "Machesney Elem School",
        "district": "Harlem UD 122",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171824005530",
    },
    {
        "school": "Hononegah CHD High School",
        "district": "Hononegah CHD 207",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171962002236",
    },
    {
        "school": "Ledgewood Elem School",
        "district": "Kinnikinnick CCSD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172118002397",
    },
    {
        "school": "Roscoe Middle School",
        "district": "Kinnikinnick CCSD 131",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172118003821",
    },
    {
        "school": "Kinnikinnick School",
        "district": "Kinnikinnick CCSD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172118003822",
    },
    {
        "school": "Stone Creek School",
        "district": "Kinnikinnick CCSD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172118005428",
    },
    {
        "school": "Pecatonica Elem School",
        "district": "Pecatonica CUSD 321",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173105003228",
    },
    {
        "school": "Pecatonica High School",
        "district": "Pecatonica CUSD 321",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173105003229",
    },
    {
        "school": "Prairie Hill Elem School",
        "district": "Prairie Hill CCSD 133",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173255003381",
    },
    {
        "school": "Lewis Lemon Elementary",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451000240",
    },
    {
        "school": "Montessori Elementary School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451001589",
    },
    {
        "school": "Kennedy Middle School",
        "district": "Rockford SD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003394",
    },
    {
        "school": "Rockford Envrnmntl Science Acad",
        "district": "Rockford SD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003397",
    },
    {
        "school": "Wilson ASPIRE",
        "district": "Rockford SD 205",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003553",
    },
    {
        "school": "Brookview Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003557",
    },
    {
        "school": "Abraham Lincoln Middle School",
        "district": "Rockford SD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003558",
    },
    {
        "school": "Clifford P Carlson Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003559",
    },
    {
        "school": "Conklin Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003561",
    },
    {
        "school": "Ellis Elementary School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003563",
    },
    {
        "school": "Gregory Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003571",
    },
    {
        "school": "Julia Lathrop Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003574",
    },
    {
        "school": "Haskell Elementary School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003575",
    },
    {
        "school": "Swan Hillman Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003576",
    },
    {
        "school": "Guilford High School",
        "district": "Rockford SD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003577",
    },
    {
        "school": "Maud E Johnson Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003579",
    },
    {
        "school": "Kishwaukee Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003580",
    },
    {
        "school": "McIntosh Elementary",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003581",
    },
    {
        "school": "Bernard W Flinn Middle School",
        "district": "Rockford SD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003583",
    },
    {
        "school": "Jefferson High School",
        "district": "Rockford SD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003585",
    },
    {
        "school": "Rolling Green",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003587",
    },
    {
        "school": "Auburn High School",
        "district": "Rockford SD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003599",
    },
    {
        "school": "Rockford East High School",
        "district": "Rockford SD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003600",
    },
    {
        "school": "R K Welsh Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003601",
    },
    {
        "school": "West View Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003602",
    },
    {
        "school": "Whitehead Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003603",
    },
    {
        "school": "Cherry Valley Elementary School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003604",
    },
    {
        "school": "Thurgood Marshall Elementary",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003605",
    },
    {
        "school": "Barbour Two-Way Lang Immersion",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003607",
    },
    {
        "school": "Arthur Froberg Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003618",
    },
    {
        "school": "Spring Creek Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003620",
    },
    {
        "school": "C Henry Bloom Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451003621",
    },
    {
        "school": "Eisenhower Middle School",
        "district": "Rockford SD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451004426",
    },
    {
        "school": "Fairview Early Childhood Center",
        "district": "Rockford SD 205",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451005200",
    },
    {
        "school": "Washington Elementary School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451005447",
    },
    {
        "school": "West Middle School",
        "district": "Rockford SD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451005448",
    },
    {
        "school": "Roosevelt Center",
        "district": "Rockford SD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451005449",
    },
    {
        "school": "Riverdahl Elem School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451005531",
    },
    {
        "school": "Whitman Post Elem School",
        "district": "Rockton SD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173454001134",
    },
    {
        "school": "Rockton Elem School",
        "district": "Rockton SD 140",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173454003623",
    },
    {
        "school": "Stephen Mack Middle School",
        "district": "Rockton SD 140",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173454003624",
    },
    {
        "school": "Shirland C C School",
        "district": "Shirland CCSD 134",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173624003750",
    },
    {
        "school": "South Beloit Jr High School",
        "district": "County of Winnebago SD 320",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173660002341",
    },
    {
        "school": "Riverview Elementary School",
        "district": "County of Winnebago SD 320",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173660003766",
    },
    {
        "school": "South Beloit Sr High School",
        "district": "County of Winnebago SD 320",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173660003768",
    },
    {
        "school": "Clark Elementary School",
        "district": "County of Winnebago SD 320",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173660004430",
    },
    {
        "school": "Jean McNair Elementary School",
        "district": "Winnebago CUSD 323",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174279003401",
    },
    {
        "school": "Dorothy Simon Elem School",
        "district": "Winnebago CUSD 323",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174279004294",
    },
    {
        "school": "Winnebago Middle School",
        "district": "Winnebago CUSD 323",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174279004295",
    },
    {
        "school": "Winnebago High School",
        "district": "Winnebago CUSD 323",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174279004297",
    },
    {
        "school": "Dorris Intermediate Sch",
        "district": "Collinsville CUSD 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065005632",
    },
    {
        "school": "Liberty Middle School",
        "district": "Edwardsville CUSD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353005717",
    },
    {
        "school": "Madison Student Support Center",
        "district": "Madison CUSD 12",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172397005633",
    },
    {
        "school": "Freeburg Elem School",
        "district": "Freeburg CCSD 70",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171582005721",
    },
    {
        "school": "Delores Moye Elem School",
        "district": "O Fallon CCSD 90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172976005722",
    },
    {
        "school": "Shiloh Middle School",
        "district": "Shiloh Village SD 85",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173621005739",
    },
    {
        "school": "Whiteside Middle School",
        "district": "Whiteside SD 115",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174230004889",
    },
    {
        "school": "Wolf Branch Middle School",
        "district": "Wolf Branch SD 113",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174296005723",
    },
    {
        "school": "Greenville Elem School",
        "district": "Bond County CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171773002066",
    },
    {
        "school": "Bond Cty Comm Unit 2 High School",
        "district": "Bond County CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171773002067",
    },
    {
        "school": "Greenville Jr High School",
        "district": "Bond County CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171773002068",
    },
    {
        "school": "Pocahontas Center",
        "district": "Bond County CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171773002069",
    },
    {
        "school": "Sorento Elem School",
        "district": "Bond County CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171773002070",
    },
    {
        "school": "Mulberry Grove Sr High School",
        "district": "Mulberry Grove CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172745002912",
    },
    {
        "school": "Mulberry Grove Elem School",
        "district": "Mulberry Grove CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172745004755",
    },
    {
        "school": "Mulberry Grove Jr High School",
        "district": "Mulberry Grove CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172745004756",
    },
    {
        "school": "Brussels High School",
        "district": "Brussels CUSD 42",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010205345",
    },
    {
        "school": "Brussels Grade School",
        "district": "Brussels CUSD 42",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170010205346",
    },
    {
        "school": "Calhoun High School",
        "district": "Calhoun CUSD 40",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171818002089",
    },
    {
        "school": "Calhoun Elementary/ Jr High Sch",
        "district": "Calhoun CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171818004438",
    },
    {
        "school": "Bunker Hill High School",
        "district": "Bunker Hill CUSD 8",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170777000392",
    },
    {
        "school": "Wolf Ridge Education Center",
        "district": "Bunker Hill CUSD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170777000394",
    },
    {
        "school": "Carlinville High School",
        "district": "Carlinville CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170843000461",
    },
    {
        "school": "Carlinville Middle School",
        "district": "Carlinville CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170843000462",
    },
    {
        "school": "Carlinville Primary School",
        "district": "Carlinville CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170843000464",
    },
    {
        "school": "Carlinville Intermediate School",
        "district": "Carlinville CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170843004563",
    },
    {
        "school": "Gillespie Middle School",
        "district": "Gillespie CUSD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171668000560",
    },
    {
        "school": "Gillespie High School",
        "district": "Gillespie CUSD 7",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171668001971",
    },
    {
        "school": "Ben-Gil Elementary School",
        "district": "Gillespie CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171668001973",
    },
    {
        "school": "Mt Olive High School",
        "district": "Mount Olive CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172718002883",
    },
    {
        "school": "Mt Olive Elementary School",
        "district": "Mount Olive CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172718004751",
    },
    {
        "school": "Northwestern Jr High School",
        "district": "Northwestern CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173054003173",
    },
    {
        "school": "Northwestern High School",
        "district": "Northwestern CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173054003174",
    },
    {
        "school": "Northwestern Elem School",
        "district": "Northwestern CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173054004785",
    },
    {
        "school": "Brighton North Primary School",
        "district": "Southwestern CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173150003316",
    },
    {
        "school": "Medora Intermediate School",
        "district": "Southwestern CUSD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173150003318",
    },
    {
        "school": "Shipman Elem School",
        "district": "Southwestern CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173150003319",
    },
    {
        "school": "Southwestern High School",
        "district": "Southwestern CUSD 9",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173150003320",
    },
    {
        "school": "Southwestern Middle School",
        "district": "Southwestern CUSD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173150003321",
    },
    {
        "school": "Staunton High School",
        "district": "Staunton CUSD 6",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173759003877",
    },
    {
        "school": "Staunton Elem School",
        "district": "Staunton CUSD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173759004844",
    },
    {
        "school": "Staunton Jr High School",
        "district": "Staunton CUSD 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173759004845",
    },
    {
        "school": "Albers Elem School",
        "district": "Albers SD 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170327000015",
    },
    {
        "school": "Aviston Elem School",
        "district": "Aviston SD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170474000175",
    },
    {
        "school": "Central Comm High School",
        "district": "Central CHSD 71",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170477000176",
    },
    {
        "school": "Bartelso Elem School",
        "district": "Bartelso SD 57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170516000198",
    },
    {
        "school": "Beckemeyer Elem School",
        "district": "Breese ESD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170701000362",
    },
    {
        "school": "Breese Elem School",
        "district": "Breese ESD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170701000363",
    },
    {
        "school": "Carlyle Elementary School",
        "district": "Carlyle CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170846000465",
    },
    {
        "school": "Carlyle High School",
        "district": "Carlyle CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170846000466",
    },
    {
        "school": "Carlyle Junior High School",
        "district": "Carlyle CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170846001172",
    },
    {
        "school": "Damiansville Elem School",
        "district": "Damiansville SD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171173001379",
    },
    {
        "school": "Germantown Elem School",
        "district": "Germantown SD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171653001962",
    },
    {
        "school": "St Rose Elem School",
        "district": "St Rose SD 14-15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173747003876",
    },
    {
        "school": "Trenton Elem School",
        "district": "Wesclin CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173942003987",
    },
    {
        "school": "Wesclin Sr High School",
        "district": "Wesclin CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173942003990",
    },
    {
        "school": "New Baden Elementary School",
        "district": "Wesclin CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173942004858",
    },
    {
        "school": "ROE Adult Learning Ctr Jersey",
        "district": "Calhoun/Greene/Jersy/Macoupin ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016903091",
    },
    {
        "school": "ROE Safe Sch Greene",
        "district": "Calhoun/Greene/Jersy/Macoupin ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016903099",
    },
    {
        "school": "Grafton Elem School",
        "district": "Jersey CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172043002308",
    },
    {
        "school": "Jersey Community Middle School",
        "district": "Jersey CUSD 100",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172043002309",
    },
    {
        "school": "Jersey Comm High School",
        "district": "Jersey CUSD 100",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172043002310",
    },
    {
        "school": "Jerseyville East Elem School",
        "district": "Jersey CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172043002311",
    },
    {
        "school": "Jerseyville West Elem School",
        "district": "Jersey CUSD 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172043002312",
    },
    {
        "school": "ROE Adult Learning Ctr Macoupin",
        "district": "Calhoun/Greene/Jersy/Macoupin ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016903058",
    },
    {
        "school": "ROE Safe Sch Macoupin",
        "district": "Calhoun/Greene/Jersy/Macoupin ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016903098",
    },
    {
        "school": "Alton High School",
        "district": "Alton CUSD 11",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170360000035",
    },
    {
        "school": "Gilson Brown Elem School",
        "district": "Alton CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170360000037",
    },
    {
        "school": "Lewis & Clark Elem School",
        "district": "Alton CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170360000042",
    },
    {
        "school": "Lovejoy Elem School",
        "district": "Alton CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170360000049",
    },
    {
        "school": "Eunice Smith Elem School",
        "district": "Alton CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170360000056",
    },
    {
        "school": "Mark Twain",
        "district": "Alton CUSD 11",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170360001473",
    },
    {
        "school": "West Elementary School",
        "district": "Alton CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170360004116",
    },
    {
        "school": "Bethalto East Primary School",
        "district": "Bethalto CUSD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170612000296",
    },
    {
        "school": "Civic Memorial High School",
        "district": "Bethalto CUSD 8",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170612000298",
    },
    {
        "school": "Meadowbrook Intermediate Sch",
        "district": "Bethalto CUSD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170612000301",
    },
    {
        "school": "Wilbur Trimpe Middle School",
        "district": "Bethalto CUSD 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170612000302",
    },
    {
        "school": "Parkside Primary School",
        "district": "Bethalto CUSD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170612003103",
    },
    {
        "school": "Collinsville Middle School",
        "district": "Collinsville CUSD 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065001279",
    },
    {
        "school": "Kreitner Elem School",
        "district": "Collinsville CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065001281",
    },
    {
        "school": "John A Renfro Elementary School",
        "district": "Collinsville CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065001282",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Collinsville CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065001283",
    },
    {
        "school": "Summit Elementary School",
        "district": "Collinsville CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065001285",
    },
    {
        "school": "Maryville Elem School",
        "district": "Collinsville CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065001287",
    },
    {
        "school": "Webster Elementary School",
        "district": "Collinsville CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065001288",
    },
    {
        "school": "East Alton Middle School",
        "district": "East Alton SD 13",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171296001542",
    },
    {
        "school": "Eastwood Elem School",
        "district": "East Alton SD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171296001543",
    },
    {
        "school": "Washington Elem School",
        "district": "East Alton SD 13",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171296001546",
    },
    {
        "school": "East Alton-Wood River High Sch",
        "district": "East Alton-Wood River CHSD 14",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171299001547",
    },
    {
        "school": "Columbus Elem School",
        "district": "Edwardsville CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353001638",
    },
    {
        "school": "Edwardsville High School",
        "district": "Edwardsville CUSD 7",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353001639",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Edwardsville CUSD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353001640",
    },
    {
        "school": "Glen Carbon Elem School",
        "district": "Edwardsville CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353001641",
    },
    {
        "school": "LeClaire Elem School",
        "district": "Edwardsville CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353001642",
    },
    {
        "school": "N O Nelson Elem School",
        "district": "Edwardsville CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353001643",
    },
    {
        "school": "Hamel Elementary School",
        "district": "Edwardsville CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353001644",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Edwardsville CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353002145",
    },
    {
        "school": "Midway School",
        "district": "Edwardsville CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353004625",
    },
    {
        "school": "Worden Elementary School",
        "district": "Edwardsville CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353005310",
    },
    {
        "school": "District 7 Alternative School",
        "district": "Edwardsville CUSD 7",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353005311",
    },
    {
        "school": "Coolidge Junior High Sch",
        "district": "Granite City CUSD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171728002024",
    },
    {
        "school": "Frohardt Elem School",
        "district": "Granite City CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171728002026",
    },
    {
        "school": "Granite City High School",
        "district": "Granite City CUSD 9",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171728002028",
    },
    {
        "school": "Maryville Elem School",
        "district": "Granite City CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171728002034",
    },
    {
        "school": "Mitchell Elementary School",
        "district": "Granite City CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171728002036",
    },
    {
        "school": "Wilson Elem School",
        "district": "Granite City CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171728002045",
    },
    {
        "school": "Prather Elementary School",
        "district": "Granite City CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171728005016",
    },
    {
        "school": "Alhambra Primary School",
        "district": "Highland CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171899002176",
    },
    {
        "school": "Grantfork Upper Elementary Sch",
        "district": "Highland CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171899002177",
    },
    {
        "school": "Highland Primary School",
        "district": "Highland CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171899002178",
    },
    {
        "school": "Highland High School",
        "district": "Highland CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171899002179",
    },
    {
        "school": "Highland Middle School",
        "district": "Highland CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171899002180",
    },
    {
        "school": "Highland Elementary  School",
        "district": "Highland CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171899004111",
    },
    {
        "school": "Madison Senior High School",
        "district": "Madison CUSD 12",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172397002622",
    },
    {
        "school": "Roxana Junior High School",
        "district": "Roxana CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173501003671",
    },
    {
        "school": "Central Intermediate School",
        "district": "Roxana CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173501003673",
    },
    {
        "school": "Roxana Sr High School",
        "district": "Roxana CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173501003674",
    },
    {
        "school": "South Primary School",
        "district": "Roxana CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173501004822",
    },
    {
        "school": "Silver Creek Elementary",
        "district": "Triad CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173735003734",
    },
    {
        "school": "Marine Elem School",
        "district": "Triad CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173735003866",
    },
    {
        "school": "Triad Middle School",
        "district": "Triad CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173735003868",
    },
    {
        "school": "St Jacob Elem School",
        "district": "Triad CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173735003869",
    },
    {
        "school": "Triad High School",
        "district": "Triad CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173735003870",
    },
    {
        "school": "C A Henning School",
        "district": "Triad CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173735005343",
    },
    {
        "school": "Venice Elem School",
        "district": "Venice CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174020004047",
    },
    {
        "school": "Hartford Elem School",
        "district": "Wood River-Hartford ESD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174305004319",
    },
    {
        "school": "Lewis-Clark Elem School",
        "district": "Wood River-Hartford ESD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174305004320",
    },
    {
        "school": "Lewis-Clark Jr High School",
        "district": "Wood River-Hartford ESD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174305004321",
    },
    {
        "school": "Centralia Alternative School",
        "district": "Clintn/Jeffrsn/Marin/Washngtn ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017402445",
    },
    {
        "school": "Safe School Program  Centralia",
        "district": "Clintn/Jeffrsn/Marin/Washngtn ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017402446",
    },
    {
        "school": "Clnton/Mrn/Wshngtn Pre-Kind Prog",
        "district": "Clintn/Jeffrsn/Marin/Washngtn ROE",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017402456",
    },
    {
        "school": "CCSI Alternative School",
        "district": "Monroe/Randolph ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020203189",
    },
    {
        "school": "Columbia Middle School",
        "district": "Columbia CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171074001294",
    },
    {
        "school": "Columbia High School",
        "district": "Columbia CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171074001295",
    },
    {
        "school": "Parkview Elementary School",
        "district": "Columbia CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171074005587",
    },
    {
        "school": "Valmeyer High School",
        "district": "Valmeyer CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174008004039",
    },
    {
        "school": "Valmeyer Elementary School",
        "district": "Valmeyer CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174008004865",
    },
    {
        "school": "Valmeyer Jr High",
        "district": "Valmeyer CUSD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174008004866",
    },
    {
        "school": "Rogers Elem School",
        "district": "Waterloo CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174107000187",
    },
    {
        "school": "Waterloo Junior High School",
        "district": "Waterloo CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174107004112",
    },
    {
        "school": "Waterloo High School",
        "district": "Waterloo CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174107004113",
    },
    {
        "school": "W J Zahnow Elem School",
        "district": "Waterloo CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174107004879",
    },
    {
        "school": "Monroe/Randolph Red Brick Sch",
        "district": "Monroe/Randolph ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020203193",
    },
    {
        "school": "Saint Clair Co ROE Safe School",
        "district": "Saint Clair ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020803239",
    },
    {
        "school": "Belle Valley School",
        "district": "Belle Valley SD 119",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170558000229",
    },
    {
        "school": "Abraham Lincoln Elem School",
        "district": "Belleville SD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170561000231",
    },
    {
        "school": "Central Jr High School",
        "district": "Belleville SD 118",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170561000232",
    },
    {
        "school": "Douglas Elem School",
        "district": "Belleville SD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170561000233",
    },
    {
        "school": "Franklin Elem School",
        "district": "Belleville SD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170561000234",
    },
    {
        "school": "Henry Raab Elem School",
        "district": "Belleville SD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170561000235",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Belleville SD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170561000236",
    },
    {
        "school": "Roosevelt Elem School",
        "district": "Belleville SD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170561000237",
    },
    {
        "school": "Union Elem School",
        "district": "Belleville SD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170561000239",
    },
    {
        "school": "West Jr High School",
        "district": "Belleville SD 118",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170561000241",
    },
    {
        "school": "Westhaven Elementary",
        "district": "Belleville SD 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170561002196",
    },
    {
        "school": "Belleville High School-East",
        "district": "Belleville Twp HSD 201",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170564000242",
    },
    {
        "school": "Belleville High School-West",
        "district": "Belleville Twp HSD 201",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170564000243",
    },
    {
        "school": "Belleville Twp HS-Night/Alt Sch",
        "district": "Belleville Twp HSD 201",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170564005591",
    },
    {
        "school": "Cahokia High School",
        "district": "Cahokia CUSD 187",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170804000409",
    },
    {
        "school": "Oliver Parks 6th Grade School",
        "district": "Cahokia CUSD 187",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170804000410",
    },
    {
        "school": "Penniman Elem School",
        "district": "Cahokia CUSD 187",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170804000412",
    },
    {
        "school": "Huffman Elem School",
        "district": "Cahokia CUSD 187",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170804000413",
    },
    {
        "school": "Lalumier Elem School",
        "district": "Cahokia CUSD 187",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170804000414",
    },
    {
        "school": "Maplewood Elem School",
        "district": "Cahokia CUSD 187",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170804000415",
    },
    {
        "school": "Elizabeth Morris Elem School",
        "district": "Cahokia CUSD 187",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170804000416",
    },
    {
        "school": "Central Elem School",
        "district": "Central SD 104",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170917000526",
    },
    {
        "school": "Collinsville High School",
        "district": "Collinsville CUSD 10",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065001278",
    },
    {
        "school": "Twin Echo Elem School",
        "district": "Collinsville CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065001289",
    },
    {
        "school": "Caseyville Elementary School",
        "district": "Collinsville CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065001292",
    },
    {
        "school": "Dupo Jr High School",
        "district": "Dupo CUSD 196",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171272001526",
    },
    {
        "school": "Dupo High School",
        "district": "Dupo CUSD 196",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171272001527",
    },
    {
        "school": "Bluffview  Elem School",
        "district": "Dupo CUSD 196",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171272004193",
    },
    {
        "school": "East St Louis-Lincoln Middle Sch",
        "district": "East St Louis SD 189",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332003243",
    },
    {
        "school": "Vivian Adams Early Child Ctr",
        "district": "East St Louis SD 189",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332003246",
    },
    {
        "school": "SIU Charter Sch of East St Louis",
        "district": "East St Louis SD 189",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332003770",
    },
    {
        "school": "East St Louis Senior High School",
        "district": "East St Louis SD 189",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332004975",
    },
    {
        "school": "Mason/Clark Middle Sch",
        "district": "East St Louis SD 189",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332004977",
    },
    {
        "school": "Dunbar Elem School",
        "district": "East St Louis SD 189",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332004987",
    },
    {
        "school": "Annette Officer Elementary",
        "district": "East St Louis SD 189",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332005001",
    },
    {
        "school": "St Clair Co Juv Detention Center",
        "district": "East St Louis SD 189",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332005221",
    },
    {
        "school": "Ellis Elem School",
        "district": "Harmony Emge SD 175",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171422001764",
    },
    {
        "school": "Emge Junior High School",
        "district": "Harmony Emge SD 175",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171422001765",
    },
    {
        "school": "Freeburg Primary Center",
        "district": "Freeburg CCSD 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171582001891",
    },
    {
        "school": "Freeburg Community High Sch",
        "district": "Freeburg CHSD 77",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171584001892",
    },
    {
        "school": "Grant Middle School",
        "district": "Grant CCSD 110",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171731002047",
    },
    {
        "school": "Illini Elem School",
        "district": "Grant CCSD 110",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171731002049",
    },
    {
        "school": "High Mount Elem School",
        "district": "High Mount SD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171896002175",
    },
    {
        "school": "Lebanon Elem School",
        "district": "Lebanon CUSD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172230002497",
    },
    {
        "school": "Lebanon High School",
        "district": "Lebanon CUSD 9",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172230002498",
    },
    {
        "school": "Lovejoy Technology Academy",
        "district": "Brooklyn UD 188",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172364002587",
    },
    {
        "school": "Lovejoy Elementary School",
        "district": "Brooklyn UD 188",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172364004710",
    },
    {
        "school": "Lovejoy Middle School",
        "district": "Brooklyn UD 188",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172364004711",
    },
    {
        "school": "Marissa Jr & Sr High School",
        "district": "Marissa CUSD 40",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172465002672",
    },
    {
        "school": "Marissa Elem School",
        "district": "Marissa CUSD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172465004724",
    },
    {
        "school": "Mascoutah High School",
        "district": "Mascoutah CUD 19",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172494002701",
    },
    {
        "school": "Mascoutah Middle School",
        "district": "Mascoutah CUD 19",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172494002702",
    },
    {
        "school": "Mascoutah Elem School",
        "district": "Mascoutah CUD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172494002705",
    },
    {
        "school": "Scott Elem School",
        "district": "Mascoutah CUD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172494003240",
    },
    {
        "school": "Millstadt Consolidated School",
        "district": "Millstadt CCSD 160",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172619002794",
    },
    {
        "school": "New Athens High School",
        "district": "New Athens CUSD 60",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172796002958",
    },
    {
        "school": "New Athens Elem",
        "district": "New Athens CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172796004763",
    },
    {
        "school": "New Athens Jr High",
        "district": "New Athens CUSD 60",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172796004764",
    },
    {
        "school": "Estelle Kampmeyer Elem School",
        "district": "O Fallon CCSD 90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172976003086",
    },
    {
        "school": "J Emmett Hinchcliffe Sr Elem Sch",
        "district": "O Fallon CCSD 90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172976003087",
    },
    {
        "school": "Laverna Evans Elem School",
        "district": "O Fallon CCSD 90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172976003088",
    },
    {
        "school": "Fulton Jr High School",
        "district": "O Fallon CCSD 90",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172976003241",
    },
    {
        "school": "Marie Schaefer Elem School",
        "district": "O Fallon CCSD 90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172976003767",
    },
    {
        "school": "O Fallon High School",
        "district": "O Fallon Twp HSD 203",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172979003090",
    },
    {
        "school": "Pontiac Jr High School",
        "district": "Pontiac-W Holliday SD 105",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173219003367",
    },
    {
        "school": "William Holliday Elem School",
        "district": "Pontiac-W Holliday SD 105",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173219003368",
    },
    {
        "school": "Shiloh Elementary School",
        "district": "Shiloh Village SD 85",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173621003749",
    },
    {
        "school": "Signal Hill Elem School",
        "district": "Signal Hill SD 181",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173633003754",
    },
    {
        "school": "Smithton Elem School",
        "district": "Smithton CCSD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173651003763",
    },
    {
        "school": "St Libory Elem School",
        "district": "St Libory Cons SD 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173744003875",
    },
    {
        "school": "Whiteside Elem School",
        "district": "Whiteside SD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174230004250",
    },
    {
        "school": "Wolf Branch Elem School",
        "district": "Wolf Branch SD 113",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174296004310",
    },
    {
        "school": "Pathways School",
        "district": "Belleville Area Special Services",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "174396305592",
    },
    {
        "school": "Cantrall Intermediate School",
        "district": "Athens CUSD 213",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170447005624",
    },
    {
        "school": "Early Learning Center",
        "district": "Springfield SD 186",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708005743",
    },
    {
        "school": "IYC Chicago",
        "district": "IDJJ Sch Dist 428",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170000603793",
    },
    {
        "school": "IL Center for Rehab & Educ-R",
        "district": "Dept of Human Services",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170009805220",
    },
    {
        "school": "Illinois Youth Center-Warrenville",
        "district": "IDJJ Sch Dist 428",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170000604460",
    },
    {
        "school": "Il Youth Center - Pere Marquette",
        "district": "IDJJ Sch Dist 428",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170000604488",
    },
    {
        "school": "Illinois Youth Ctr - St Charles",
        "district": "IDJJ Sch Dist 428",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170000604464",
    },
    {
        "school": "Athens Sr High School",
        "district": "Athens CUSD 213",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170447000131",
    },
    {
        "school": "Athens Junior High School",
        "district": "Athens CUSD 213",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170447004530",
    },
    {
        "school": "Greenview Jr/Sr High School",
        "district": "Greenview CUSD 200",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171770002065",
    },
    {
        "school": "Greenview Elementary School",
        "district": "Greenview CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171770004649",
    },
    {
        "school": "Petersburg Elem School",
        "district": "Porta CUSD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173141003312",
    },
    {
        "school": "Porta High School",
        "district": "Porta CUSD 202",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173141003313",
    },
    {
        "school": "Porta Central",
        "district": "Porta CUSD 202",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173141004796",
    },
    {
        "school": "Illinois School for the Deaf",
        "district": "Dept of Human Services",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170009805218",
    },
    {
        "school": "Il Sch for the Visually Impaired",
        "district": "Dept of Human Services",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170009805219",
    },
    {
        "school": "School District 428 IYC-HRB",
        "district": "IDJJ Sch Dist 428",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170000604902",
    },
    {
        "school": "SASED Central-Proj Ican & Pace",
        "district": "Sangamon Area Spec Ed Dist",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170011605397",
    },
    {
        "school": "Sangamon County Learning Academy",
        "district": "Menard/Sangamon ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020603258",
    },
    {
        "school": "Sangamon Safe School Program",
        "district": "Menard/Sangamon ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020603267",
    },
    {
        "school": "Cantrall Elem School",
        "district": "Athens CUSD 213",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170447000132",
    },
    {
        "school": "Auburn Jr High at Divernon",
        "district": "Auburn CUSD 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170462000141",
    },
    {
        "school": "Auburn High School",
        "district": "Auburn CUSD 10",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170462000142",
    },
    {
        "school": "Auburn Elem School",
        "district": "Auburn CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170462004532",
    },
    {
        "school": "Ball Elementary School",
        "district": "Ball Chatham CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170492000182",
    },
    {
        "school": "Chatham Elem School",
        "district": "Ball Chatham CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170492000183",
    },
    {
        "school": "Glenwood High School",
        "district": "Ball Chatham CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170492000184",
    },
    {
        "school": "Glenwood Middle School",
        "district": "Ball Chatham CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170492000185",
    },
    {
        "school": "Glenwood Intermediate Sch",
        "district": "Ball Chatham CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170492004497",
    },
    {
        "school": "New Berlin Jr High School",
        "district": "New Berlin CUSD 16",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172799002959",
    },
    {
        "school": "New Berlin High School",
        "district": "New Berlin CUSD 16",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172799002960",
    },
    {
        "school": "New Berlin Elementary School",
        "district": "New Berlin CUSD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172799004766",
    },
    {
        "school": "Pawnee Jr/Sr High Sch",
        "district": "Pawnee CUSD 11",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173093003221",
    },
    {
        "school": "Pawnee Grade School",
        "district": "Pawnee CUSD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173093004789",
    },
    {
        "school": "Pleasant Plains Middle School",
        "district": "Pleasant Plains CUSD 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173192003348",
    },
    {
        "school": "Pleasant Plains High School",
        "district": "Pleasant Plains CUSD 8",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173192003349",
    },
    {
        "school": "Farmingdale Elem School",
        "district": "Pleasant Plains CUSD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173192004799",
    },
    {
        "school": "Riverton Elem School",
        "district": "Riverton CUSD 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173410003497",
    },
    {
        "school": "Riverton High School",
        "district": "Riverton CUSD 14",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173410003498",
    },
    {
        "school": "Riverton Middle School",
        "district": "Riverton CUSD 14",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173410003499",
    },
    {
        "school": "Rochester Elem EC-1 Sch",
        "district": "Rochester CUSD 3A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173432003517",
    },
    {
        "school": "Rochester High School",
        "district": "Rochester CUSD 3A",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173432003518",
    },
    {
        "school": "Rochester Jr High School",
        "district": "Rochester CUSD 3A",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173432003519",
    },
    {
        "school": "Rochester Intermediate School",
        "district": "Rochester CUSD 3A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173432003520",
    },
    {
        "school": "Elizabeth Graham Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708000989",
    },
    {
        "school": "Douglas School",
        "district": "Springfield SD 186",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708000998",
    },
    {
        "school": "Lawrence Education Center",
        "district": "Springfield SD 186",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003279",
    },
    {
        "school": "Springfield Ball Charter School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003773",
    },
    {
        "school": "Benjamin Franklin Middle School",
        "district": "Springfield SD 186",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003814",
    },
    {
        "school": "Black Hawk Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003815",
    },
    {
        "school": "Butler Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003816",
    },
    {
        "school": "Dubois Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003818",
    },
    {
        "school": "Enos Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003819",
    },
    {
        "school": "Fairview Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003820",
    },
    {
        "school": "Hazel Dell Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003824",
    },
    {
        "school": "Iles Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003825",
    },
    {
        "school": "Jane Addams Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003826",
    },
    {
        "school": "Laketown Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003828",
    },
    {
        "school": "Lanphier High School",
        "district": "Springfield SD 186",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003829",
    },
    {
        "school": "Lincoln Magnet School",
        "district": "Springfield SD 186",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003830",
    },
    {
        "school": "Matheny-Withrow Elem Sch",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003831",
    },
    {
        "school": "McClernand Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003832",
    },
    {
        "school": "Owen Marsh Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003833",
    },
    {
        "school": "Ridgely Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003835",
    },
    {
        "school": "Sandburg Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003836",
    },
    {
        "school": "Southern View Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003837",
    },
    {
        "school": "Springfield High School",
        "district": "Springfield SD 186",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003838",
    },
    {
        "school": "Springfield Southeast High Sch",
        "district": "Springfield SD 186",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003839",
    },
    {
        "school": "U S Grant Middle School",
        "district": "Springfield SD 186",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003841",
    },
    {
        "school": "Feitshans Elem Sch",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003843",
    },
    {
        "school": "Washington Middle School",
        "district": "Springfield SD 186",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003844",
    },
    {
        "school": "Wilcox Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708003847",
    },
    {
        "school": "Lindsay School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708004194",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Springfield SD 186",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708004431",
    },
    {
        "school": "Harvard Park Elem School",
        "district": "Springfield SD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708005291",
    },
    {
        "school": "Edwin A Lee Elementary School",
        "district": "Springfield SD 186",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708005593",
    },
    {
        "school": "Tri-City High School",
        "district": "Tri City CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173945003991",
    },
    {
        "school": "Tri-City Elem School",
        "district": "Tri City CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173945004859",
    },
    {
        "school": "Tri-City Jr High School",
        "district": "Tri City CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173945004860",
    },
    {
        "school": "Sherman Elem School",
        "district": "Williamsville CUSD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174248004269",
    },
    {
        "school": "Williamsville High School",
        "district": "Williamsville CUSD 15",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174248004271",
    },
    {
        "school": "Williamsville Jr High School",
        "district": "Williamsville CUSD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174248004272",
    },
    {
        "school": "Early Step Pre-School",
        "district": "River Bend CUSD 2",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173395004920",
    },
    {
        "school": "Erie Elem School",
        "district": "Erie CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171435001772",
    },
    {
        "school": "Erie High School",
        "district": "Erie CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171435001773",
    },
    {
        "school": "Erie Middle School",
        "district": "Erie CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171435001774",
    },
    {
        "school": "Montmorency CCSD #145",
        "district": "Montmorency CCSD 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172659002846",
    },
    {
        "school": "Morrison High School",
        "district": "Morrison CUSD 6",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172671002852",
    },
    {
        "school": "Morrison Jr High School",
        "district": "Morrison CUSD 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172671002853",
    },
    {
        "school": "Northside School",
        "district": "Morrison CUSD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172671002854",
    },
    {
        "school": "Southside School",
        "district": "Morrison CUSD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172671002855",
    },
    {
        "school": "PLT Middle School",
        "district": "Prophetstown-Lyndon-Tampico CUSD3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173283001844",
    },
    {
        "school": "Tampico Elem School",
        "district": "Prophetstown-Lyndon-Tampico CUSD3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173283001852",
    },
    {
        "school": "Prophetstown Elem School",
        "district": "Prophetstown-Lyndon-Tampico CUSD3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173283003399",
    },
    {
        "school": "Prophetstown High School",
        "district": "Prophetstown-Lyndon-Tampico CUSD3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173283003400",
    },
    {
        "school": "Fulton High School",
        "district": "River Bend CUSD 2",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173395003488",
    },
    {
        "school": "River Bend Middle School",
        "district": "River Bend CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173395003489",
    },
    {
        "school": "Fulton Elem School",
        "district": "River Bend CUSD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173395003490",
    },
    {
        "school": "Dillon Elementary School",
        "district": "Rock Falls ESD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173435003521",
    },
    {
        "school": "Merrill Elem School",
        "district": "Rock Falls ESD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173435003522",
    },
    {
        "school": "Rock Falls Middle School",
        "district": "Rock Falls ESD 13",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173435003523",
    },
    {
        "school": "Rock Falls Township High School",
        "district": "Rock Falls Twp HSD 301",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173438003525",
    },
    {
        "school": "Franklin Elem School",
        "district": "Sterling CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174231004252",
    },
    {
        "school": "Jefferson Elem School",
        "district": "Sterling CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174231004255",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Sterling CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174231004256",
    },
    {
        "school": "Washington Elem School",
        "district": "Sterling CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174231004260",
    },
    {
        "school": "Sterling High School",
        "district": "Sterling CUSD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174231004261",
    },
    {
        "school": "Challand Middle School",
        "district": "Sterling CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174231004264",
    },
    {
        "school": "Central A & M Middle School",
        "district": "Central A & M CUD 21",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170910000129",
    },
    {
        "school": "Bond Primary",
        "district": "Central A & M CUD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170910004528",
    },
    {
        "school": "Kemmerer Village School",
        "district": "Central A & M CUD 21",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170910005138",
    },
    {
        "school": "Edinburg High School",
        "district": "Edinburg CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171341001632",
    },
    {
        "school": "Edinburg Elem School",
        "district": "Edinburg CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171341004622",
    },
    {
        "school": "Edinburg Jr High School",
        "district": "Edinburg CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171341004623",
    },
    {
        "school": "Morrisonville Jr High School",
        "district": "Morrisonville CUSD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172676002857",
    },
    {
        "school": "Morrisonville High School",
        "district": "Morrisonville CUSD 1",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172676002858",
    },
    {
        "school": "Morrisonville Elem School",
        "district": "Morrisonville CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172676004743",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Pana CUSD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173063003183",
    },
    {
        "school": "Pana Jr High School",
        "district": "Pana CUSD 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173063003184",
    },
    {
        "school": "Pana Sr High School",
        "district": "Pana CUSD 8",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173063003186",
    },
    {
        "school": "Washington Elem School",
        "district": "Pana CUSD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173063003187",
    },
    {
        "school": "South Fork Jr Sr High School",
        "district": "South Fork SD 14",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173664005069",
    },
    {
        "school": "South Fork Elementary School",
        "district": "South Fork SD 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173664005070",
    },
    {
        "school": "Memorial Elem School",
        "district": "Taylorville CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173870003934",
    },
    {
        "school": "North Elem School",
        "district": "Taylorville CUSD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173870003935",
    },
    {
        "school": "Taylorville Jr High School",
        "district": "Taylorville CUSD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173870003937",
    },
    {
        "school": "Taylorville Sr High School",
        "district": "Taylorville CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173870003938",
    },
    {
        "school": "Central A & M High School",
        "district": "Central A & M CUD 21",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170910002875",
    },
    {
        "school": "Gregory Intermediate",
        "district": "Central A & M CUD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170910004747",
    },
    {
        "school": "Jeff H Towles Intermediate School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363002175",
    },
    {
        "school": "Cedar Canyon Elementary School",
        "district": "Northwest Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180825002166",
    },
    {
        "school": "Prairie Crossing Elementary School",
        "district": "Benton Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180048002403",
    },
    {
        "school": "Cedar Crest Intermediate School",
        "district": "Southeast Dubois Co Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181064002177",
    },
    {
        "school": "Prairie View Elementary School",
        "district": "Goshen Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180393002180",
    },
    {
        "school": "Marion Early Childhood Ed Cntr",
        "district": "Marion Community Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180639002396",
    },
    {
        "school": "Grant County Special Ed Coop",
        "district": "Mississinewa Community School Corp",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180687002149",
    },
    {
        "school": "Options Charter School Noblesville",
        "district": "Options Charter School Noblesville",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180005602313",
    },
    {
        "school": "West Clay Elementary School",
        "district": "Carmel Clay Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120002185",
    },
    {
        "school": "Riverside Junior High",
        "district": "Hamilton Southeastern Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065002182",
    },
    {
        "school": "Fishers High School",
        "district": "Hamilton Southeastern Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065002392",
    },
    {
        "school": "Maple Glen Elementary",
        "district": "Westfield-Washington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181308002184",
    },
    {
        "school": "Geist Montessori Academy",
        "district": "Geist Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180006102387",
    },
    {
        "school": "East Chicago Lighthouse",
        "district": "East Chicago Lighthouse Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180005402235",
    },
    {
        "school": "Avondale Meadows Academy",
        "district": "Avondale Meadows Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180005702314",
    },
    {
        "school": "Herron High School",
        "district": "Herron Charter",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180005802315",
    },
    {
        "school": "Hope Academy",
        "district": "Hope Academy",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180005902386",
    },
    {
        "school": "Center for Inquiry School 84",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002391",
    },
    {
        "school": "Clarence Farrington School 61",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002393",
    },
    {
        "school": "Frederick Douglass School 19",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002395",
    },
    {
        "school": "James Russell Lowell School 51",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002404",
    },
    {
        "school": "Early Learning Center",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567002205",
    },
    {
        "school": "Riverside Intermediate",
        "district": "Plymouth Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180906002211",
    },
    {
        "school": "Lost River Career Cooperative",
        "district": "Lost River Career Cooperative",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180003601686",
    },
    {
        "school": "Heritage Hills Middle School",
        "district": "North Spencer County Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180801001898",
    },
    {
        "school": "Blackford Jr-Sr High School",
        "district": "Blackford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180057000102",
    },
    {
        "school": "Montpelier School",
        "district": "Blackford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180057000107",
    },
    {
        "school": "North Side Elementary School",
        "district": "Blackford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180057000108",
    },
    {
        "school": "Southside Elementary School",
        "district": "Blackford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180057000126",
    },
    {
        "school": "Crawford County High School",
        "district": "Crawford County Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180244000279",
    },
    {
        "school": "South Crawford Elementary School",
        "district": "Crawford County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180244000281",
    },
    {
        "school": "Crawford County Middle School",
        "district": "Crawford County Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180244000282",
    },
    {
        "school": "East Crawford Elementary School",
        "district": "Crawford County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180244000283",
    },
    {
        "school": "West Crawford Elementary School",
        "district": "Crawford County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180244000284",
    },
    {
        "school": "Attica Elementary School",
        "district": "Attica Consolidated School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180021000049",
    },
    {
        "school": "Attica High School",
        "district": "Attica Consolidated School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180021000050",
    },
    {
        "school": "Covington Community High School",
        "district": "Covington Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180243000275",
    },
    {
        "school": "Covington Elementary School",
        "district": "Covington Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180243000276",
    },
    {
        "school": "Covington Middle School",
        "district": "Covington Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180243000277",
    },
    {
        "school": "Fountain Central High School",
        "district": "Southeast Fountain School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181062001742",
    },
    {
        "school": "Southeast Fountain Elementary",
        "district": "Southeast Fountain School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181062001743",
    },
    {
        "school": "Caston Elementary School",
        "district": "Caston School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180141000206",
    },
    {
        "school": "Caston Jr-Sr High School",
        "district": "Caston School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180141000207",
    },
    {
        "school": "Columbia Elementary School",
        "district": "Rochester Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180963001574",
    },
    {
        "school": "George M Riddle Elementary School",
        "district": "Rochester Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180963001575",
    },
    {
        "school": "Rochester Community High School",
        "district": "Rochester Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180963001576",
    },
    {
        "school": "Rochester Community Middle School",
        "district": "Rochester Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180963001577",
    },
    {
        "school": "Tri-County Primary School",
        "district": "Tri-County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181143001848",
    },
    {
        "school": "Bloomfield Elementary School",
        "district": "Jay School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180498000910",
    },
    {
        "school": "East Elementary School",
        "district": "Jay School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180498000911",
    },
    {
        "school": "East Jay County Middle School",
        "district": "Jay School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180498000912",
    },
    {
        "school": "General Shanks Elem School",
        "district": "Jay School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180498000913",
    },
    {
        "school": "Jay County High School",
        "district": "Jay School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180498000914",
    },
    {
        "school": "Redkey Elementary School",
        "district": "Jay School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180498000917",
    },
    {
        "school": "West Jay County Middle School",
        "district": "Jay School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180498000918",
    },
    {
        "school": "Westlawn Elementary School",
        "district": "Jay School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180498000919",
    },
    {
        "school": "Lakeland Jr/Sr High School",
        "district": "Lakeland School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180552000996",
    },
    {
        "school": "Prairie Heights Elementary School",
        "district": "Prairie Heights Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180930001524",
    },
    {
        "school": "Prairie Heights Middle School",
        "district": "Prairie Heights Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180930001525",
    },
    {
        "school": "Prairie Heights Sr High School",
        "district": "Prairie Heights Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180930001526",
    },
    {
        "school": "Meadowview Elementary School",
        "district": "Westview School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181311001587",
    },
    {
        "school": "Shipshewana-Scott Elementary Sch",
        "district": "Westview School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181311002077",
    },
    {
        "school": "Topeka Elementary School",
        "district": "Westview School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181311002078",
    },
    {
        "school": "Westview Jr-Sr High School",
        "district": "Westview School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181311002079",
    },
    {
        "school": "Westview Elementary School",
        "district": "Westview School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181311002365",
    },
    {
        "school": "Loogootee High School",
        "district": "Loogootee Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180606001067",
    },
    {
        "school": "Loogootee Elementary School",
        "district": "Loogootee Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180606001069",
    },
    {
        "school": "Loogootee Middle School",
        "district": "Loogootee Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180606001070",
    },
    {
        "school": "Shoals Community Elementary School",
        "district": "Shoals Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181017001634",
    },
    {
        "school": "Shoals Community High School",
        "district": "Shoals Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181017001635",
    },
    {
        "school": "Orleans Elementary School",
        "district": "Orleans Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180849001436",
    },
    {
        "school": "Orleans Jr-Sr High School",
        "district": "Orleans Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180849001437",
    },
    {
        "school": "Paoli Jr & Sr High School",
        "district": "Paoli Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180864001438",
    },
    {
        "school": "Throop Elementary School",
        "district": "Paoli Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180864001439",
    },
    {
        "school": "Springs Valley Comm High School",
        "district": "Springs Valley Com School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181098001795",
    },
    {
        "school": "Springs Valley Elementary School",
        "district": "Springs Valley Com School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181098001796",
    },
    {
        "school": "Rosedale Elementary School",
        "district": "Southwest Parke Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181090002286",
    },
    {
        "school": "Riverton Parke Jr-Sr High School",
        "district": "Southwest Parke Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181090002287",
    },
    {
        "school": "Montezuma Elementary School",
        "district": "Southwest Parke Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181090002288",
    },
    {
        "school": "Cannelton Elementary & High School",
        "district": "Cannelton City Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180117000191",
    },
    {
        "school": "Perry Central Elementary School",
        "district": "Perry Central Com Schools Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180174000232",
    },
    {
        "school": "Perry Central Jr-Sr High School",
        "district": "Perry Central Com Schools Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180174000234",
    },
    {
        "school": "William Tell Elementary School",
        "district": "Tell City-Troy Twp School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181126001282",
    },
    {
        "school": "Tell City Jr-Sr High School",
        "district": "Tell City-Troy Twp School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181126001819",
    },
    {
        "school": "Eastern Pulaski Elementary School",
        "district": "Eastern Pulaski Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180711001204",
    },
    {
        "school": "Winamac Community High School",
        "district": "Eastern Pulaski Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180711001205",
    },
    {
        "school": "Winamac Community Middle School",
        "district": "Eastern Pulaski Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180711001206",
    },
    {
        "school": "West Central Middle School",
        "district": "West Central School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180936001517",
    },
    {
        "school": "West Central Senior High School",
        "district": "West Central School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180936001529",
    },
    {
        "school": "West Central Elementary School",
        "district": "West Central School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180936002213",
    },
    {
        "school": "Lee L Driver Middle School",
        "district": "Randolph Central School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180177000235",
    },
    {
        "school": "O R Baker Elementary School",
        "district": "Randolph Central School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180177000236",
    },
    {
        "school": "Willard Elementary School",
        "district": "Randolph Central School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180177000241",
    },
    {
        "school": "Winchester Community High School",
        "district": "Randolph Central School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180177000242",
    },
    {
        "school": "Deerfield Elementary School",
        "district": "Randolph Central School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180177002191",
    },
    {
        "school": "North Side Elementary School",
        "district": "Randolph Eastern School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180318000414",
    },
    {
        "school": "Union City Community Jr/Sr High",
        "district": "Randolph Eastern School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180318000415",
    },
    {
        "school": "Monroe Central Jr-Sr High School",
        "district": "Monroe Central School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180708001202",
    },
    {
        "school": "Monroe Central Elementary School",
        "district": "Monroe Central School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180708002226",
    },
    {
        "school": "Randolph Southern Elementary Sch",
        "district": "Randolph Southern School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181074001762",
    },
    {
        "school": "Randolph Southern Jr-Sr High Sch",
        "district": "Randolph Southern School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181074001763",
    },
    {
        "school": "Union Elementary School",
        "district": "Union School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181173001874",
    },
    {
        "school": "Union Junior & High School",
        "district": "Union School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181173001875",
    },
    {
        "school": "Jac-Cen-Del MS/HS",
        "district": "Jac-Cen-Del Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180480000907",
    },
    {
        "school": "Jac-Cen-Del Elementary School",
        "district": "Jac-Cen-Del Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180480002353",
    },
    {
        "school": "Milan Elementary School",
        "district": "Milan Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180663001167",
    },
    {
        "school": "Milan High School",
        "district": "Milan Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180663001168",
    },
    {
        "school": "Milan Middle School",
        "district": "Milan Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180663001626",
    },
    {
        "school": "South Ripley High School",
        "district": "South Ripley Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181053001729",
    },
    {
        "school": "South Ripley Elementary School",
        "district": "South Ripley Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181053002380",
    },
    {
        "school": "Southeastern Career Center",
        "district": "Southeastern Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "181066001748",
    },
    {
        "school": "Arlington Elementary School",
        "district": "Rush County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180975001591",
    },
    {
        "school": "Milroy Elementary School",
        "district": "Rush County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180975001594",
    },
    {
        "school": "Rushville Consolidated High School",
        "district": "Rush County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180975001596",
    },
    {
        "school": "Benjamin Rush Middle School",
        "district": "Rush County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180975002240",
    },
    {
        "school": "Nancy Hanks Elementary School",
        "district": "North Spencer County Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180801000167",
    },
    {
        "school": "Lincoln Trail Elementary School",
        "district": "North Spencer County Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180801000174",
    },
    {
        "school": "Chrisney Elementary School",
        "district": "North Spencer County Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180801001373",
    },
    {
        "school": "David Turnham Education Center",
        "district": "North Spencer County Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180801001375",
    },
    {
        "school": "Heritage Hills High School",
        "district": "North Spencer County Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180801001376",
    },
    {
        "school": "Luce Elementary School",
        "district": "South Spencer County Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181056001731",
    },
    {
        "school": "Rockport-Ohio Elementary School",
        "district": "South Spencer County Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181056001732",
    },
    {
        "school": "South Spencer High School",
        "district": "South Spencer County Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181056001733",
    },
    {
        "school": "South Spencer Middle School",
        "district": "South Spencer County Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181056001734",
    },
    {
        "school": "Knox Community High School",
        "district": "Knox Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180534000938",
    },
    {
        "school": "Knox Community Middle School",
        "district": "Knox Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180534000939",
    },
    {
        "school": "Knox Community Elementary School",
        "district": "Knox Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180534000940",
    },
    {
        "school": "North Judson-San Pierre Elem Sch",
        "district": "North Judson-San Pierre Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180780001328",
    },
    {
        "school": "N Judson-San Pierre Jr Sr High Sch",
        "district": "North Judson-San Pierre Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180780001330",
    },
    {
        "school": "Oregon-Davis Jr-Sr High School",
        "district": "Oregon-Davis School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180846001435",
    },
    {
        "school": "Oregon-Davis Elementary School",
        "district": "Oregon-Davis School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180846002209",
    },
    {
        "school": "Switzerland Co Middle School",
        "district": "Switzerland County School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181122000806",
    },
    {
        "school": "Jefferson-Craig Elementary School",
        "district": "Switzerland County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181122001808",
    },
    {
        "school": "Switzerland Co Senior High School",
        "district": "Switzerland County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181122001811",
    },
    {
        "school": "Switzerland Co Elementary School",
        "district": "Switzerland County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181122002170",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Union Co/Clg Corner Joint Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181161001867",
    },
    {
        "school": "Union County Middle School",
        "district": "Union Co/Clg Corner Joint Sch Dist",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181161001868",
    },
    {
        "school": "Union County High School",
        "district": "Union Co/Clg Corner Joint Sch Dist",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181161001869",
    },
    {
        "school": "College Corner Union Elem School",
        "district": "Union Co/Clg Corner Joint Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181161001870",
    },
    {
        "school": "Pine Village Elementary School",
        "district": "M S D Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180608001072",
    },
    {
        "school": "Seeger Memorial Jr-Sr High School",
        "district": "M S D Warren County",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180608001073",
    },
    {
        "school": "Warren Central Elementary School",
        "district": "M S D Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180608001074",
    },
    {
        "school": "Williamsport Elementary School",
        "district": "M S D Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180608001075",
    },
    {
        "school": "Frontier Jr-Sr High School",
        "district": "Frontier School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180381000603",
    },
    {
        "school": "Frontier Elementary",
        "district": "Frontier School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180381000604",
    },
    {
        "school": "North White High School",
        "district": "North White School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180813001396",
    },
    {
        "school": "Tri-County Intermediate School",
        "district": "Tri-County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181143001845",
    },
    {
        "school": "Tri-County Jr/Sr High School",
        "district": "Tri-County School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181143001846",
    },
    {
        "school": "Eastlawn Elementary School",
        "district": "Twin Lakes School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181158001859",
    },
    {
        "school": "Meadowlawn Elementary School",
        "district": "Twin Lakes School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181158001860",
    },
    {
        "school": "Oaklawn Elementary School",
        "district": "Twin Lakes School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181158001861",
    },
    {
        "school": "Roosevelt Middle School",
        "district": "Twin Lakes School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181158001862",
    },
    {
        "school": "Twin Lakes Senior High School",
        "district": "Twin Lakes School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181158001863",
    },
    {
        "school": "Anderson Elementary School",
        "district": "Anderson Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180015001847",
    },
    {
        "school": "Eastside Elementary School",
        "district": "Anderson Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180015002109",
    },
    {
        "school": "Erskine Elementary School",
        "district": "Anderson Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180015002110",
    },
    {
        "school": "Maple Ridge Elementary School",
        "district": "South Madison Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181044001676",
    },
    {
        "school": "Alexandria-Monroe Elementary",
        "district": "Alexandria Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180012000009",
    },
    {
        "school": "Alexandria-Monroe Intermediate",
        "district": "Alexandria Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180012000010",
    },
    {
        "school": "Alexandria-Monroe High School",
        "district": "Alexandria Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180012000011",
    },
    {
        "school": "Edgewood Elementary School",
        "district": "Anderson Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180015000020",
    },
    {
        "school": "Anderson High School",
        "district": "Anderson Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180015000029",
    },
    {
        "school": "Tenth Street Elementary School",
        "district": "Anderson Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180015000041",
    },
    {
        "school": "Valley Grove Elementary School",
        "district": "Anderson Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180015000044",
    },
    {
        "school": "Elwood Elementary School",
        "district": "Elwood Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180330000448",
    },
    {
        "school": "Elwood Jr-Sr High School",
        "district": "Elwood Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180330000449",
    },
    {
        "school": "John H Hinds Career Center",
        "district": "Elwood Community School Corp",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180330000451",
    },
    {
        "school": "Elwood Intermediate School",
        "district": "Elwood Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180330002309",
    },
    {
        "school": "Pendleton Heights High School",
        "district": "South Madison Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181044001711",
    },
    {
        "school": "Pendleton Heights Middle School",
        "district": "South Madison Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181044001712",
    },
    {
        "school": "Pendleton Elementary School",
        "district": "South Madison Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181044001713",
    },
    {
        "school": "East Elementary School",
        "district": "South Madison Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181044002167",
    },
    {
        "school": "Frankton Elementary School",
        "district": "Frankton-Lapel Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181288002049",
    },
    {
        "school": "Frankton Jr-Sr High School",
        "district": "Frankton-Lapel Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181288002050",
    },
    {
        "school": "Lapel Elementary School",
        "district": "Frankton-Lapel Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181288002052",
    },
    {
        "school": "Lapel Sr High School",
        "district": "Frankton-Lapel Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181288002328",
    },
    {
        "school": "Fremont Middle School",
        "district": "Fremont Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180378000177",
    },
    {
        "school": "Fremont Elementary School",
        "district": "Fremont Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180378000600",
    },
    {
        "school": "Fremont High School",
        "district": "Fremont Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180378000601",
    },
    {
        "school": "Hamilton Community Elementary Sch",
        "district": "Hamilton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180423000723",
    },
    {
        "school": "Hamilton Community High School",
        "district": "Hamilton Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180423000724",
    },
    {
        "school": "Ryan Park Elementary School",
        "district": "M S D Steuben County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181110001629",
    },
    {
        "school": "Angola High School",
        "district": "M S D Steuben County",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181110001797",
    },
    {
        "school": "Angola Middle School",
        "district": "M S D Steuben County",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181110001798",
    },
    {
        "school": "Carlin Park Elementary School",
        "district": "M S D Steuben County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181110001799",
    },
    {
        "school": "Hendry Park Elementary School",
        "district": "M S D Steuben County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181110001800",
    },
    {
        "school": "Pleasant Lake Elementary School",
        "district": "M S D Steuben County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181110001801",
    },
    {
        "school": "DeKalb High School",
        "district": "DeKalb Co Ctl United Sch Dist",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180159000220",
    },
    {
        "school": "DeKalb Middle School",
        "district": "DeKalb Co Ctl United Sch Dist",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180159000221",
    },
    {
        "school": "James R Watson Elementary School",
        "district": "DeKalb Co Ctl United Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180159000222",
    },
    {
        "school": "McKenney-Harrison Elementary Sch",
        "district": "DeKalb Co Ctl United Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180159000225",
    },
    {
        "school": "Waterloo Elementary School",
        "district": "DeKalb Co Ctl United Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180159000226",
    },
    {
        "school": "Country Meadow Elementary School",
        "district": "DeKalb Co Ctl United Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180159000847",
    },
    {
        "school": "Butler Elementary School",
        "district": "DeKalb Co Eastern Com Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180306000404",
    },
    {
        "school": "Eastside Junior-Senior High School",
        "district": "DeKalb Co Eastern Com Sch Dist",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180306000405",
    },
    {
        "school": "Riverdale Elementary School",
        "district": "DeKalb Co Eastern Com Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180306000406",
    },
    {
        "school": "Garrett High School",
        "district": "Garrett-Keyser-Butler Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180384000605",
    },
    {
        "school": "J E Ober Elementary School",
        "district": "Garrett-Keyser-Butler Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180384000606",
    },
    {
        "school": "Garrett Middle School",
        "district": "Garrett-Keyser-Butler Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180384001389",
    },
    {
        "school": "Northeast IN Spec Ed Coop",
        "district": "DeKalb Co Eastern Com Sch Dist",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180306002234",
    },
    {
        "school": "Burris Elementary School",
        "district": "Mitchell Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180690001194",
    },
    {
        "school": "Hatfield Elementary School",
        "district": "Mitchell Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180690001196",
    },
    {
        "school": "Mitchell High School",
        "district": "Mitchell Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180690001198",
    },
    {
        "school": "Mitchell Jr High School",
        "district": "Mitchell Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180690002151",
    },
    {
        "school": "Oolitic Middle School",
        "district": "North Lawrence Com Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786000446",
    },
    {
        "school": "Shawswick Middle School",
        "district": "North Lawrence Com Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786000461",
    },
    {
        "school": "Bedford Middle School",
        "district": "North Lawrence Com Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786001336",
    },
    {
        "school": "Bedford-North Lawrence High School",
        "district": "North Lawrence Com Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786001337",
    },
    {
        "school": "Fayetteville Elementary School",
        "district": "North Lawrence Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786001339",
    },
    {
        "school": "Heltonville Elementary School",
        "district": "North Lawrence Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786001340",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "North Lawrence Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786001341",
    },
    {
        "school": "Needmore Elementary School",
        "district": "North Lawrence Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786001342",
    },
    {
        "school": "North Lawrence Career Center",
        "district": "North Lawrence Com Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180786001343",
    },
    {
        "school": "Dollens Elementary School",
        "district": "North Lawrence Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786001344",
    },
    {
        "school": "Parkview Primary School",
        "district": "North Lawrence Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786001345",
    },
    {
        "school": "Shawswick Elementary School",
        "district": "North Lawrence Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786001346",
    },
    {
        "school": "Springville Elementary School",
        "district": "North Lawrence Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786001347",
    },
    {
        "school": "Stalker Elementary School",
        "district": "North Lawrence Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786001348",
    },
    {
        "school": "Parkview Intermediate School",
        "district": "North Lawrence Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180786002206",
    },
    {
        "school": "Summit Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063002127",
    },
    {
        "school": "Edgewood Primary School",
        "district": "Richland-Bean Blossom C S C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180948001707",
    },
    {
        "school": "Edgewood Intermediate School",
        "district": "Richland-Bean Blossom C S C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180948001708",
    },
    {
        "school": "Greene-Sullivan Sp Ed Sch",
        "district": "Greene-Sullivan Sp Ed Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180000702265",
    },
    {
        "school": "White River Valley Elementary Sch",
        "district": "White River Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180000802090",
    },
    {
        "school": "White River Valley High School",
        "district": "White River Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180000802302",
    },
    {
        "school": "White River Valley Middle School",
        "district": "White River Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180000802304",
    },
    {
        "school": "Bloomfield Elementary School",
        "district": "Bloomfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180060000112",
    },
    {
        "school": "Bloomfield Jr-Sr High School",
        "district": "Bloomfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180060000113",
    },
    {
        "school": "Eastern Greene Elementary School",
        "district": "Eastern Greene Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180309000407",
    },
    {
        "school": "Eastern Greene High School",
        "district": "Eastern Greene Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180309000408",
    },
    {
        "school": "Linton-Stockton Elementary",
        "district": "Linton-Stockton School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180591001048",
    },
    {
        "school": "Linton-Stockton High School",
        "district": "Linton-Stockton School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180591001049",
    },
    {
        "school": "Linton-Stockton Middle School",
        "district": "Linton-Stockton School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180591002147",
    },
    {
        "school": "Shakamak Elementary School",
        "district": "M S D Shakamak Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181011001622",
    },
    {
        "school": "Shakamak Jr-Sr High School",
        "district": "M S D Shakamak Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181011001623",
    },
    {
        "school": "McCormick's Creek Elementary Sch",
        "district": "Spencer-Owen Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181095001511",
    },
    {
        "school": "Gosport Elementary School",
        "district": "Spencer-Owen Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181095001787",
    },
    {
        "school": "Owen Valley Middle School",
        "district": "Spencer-Owen Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181095001790",
    },
    {
        "school": "Owen Valley Community High School",
        "district": "Spencer-Owen Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181095001791",
    },
    {
        "school": "Patricksburg Elementary School",
        "district": "Spencer-Owen Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181095001792",
    },
    {
        "school": "Spencer Elementary School",
        "district": "Spencer-Owen Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181095001794",
    },
    {
        "school": "Arlington Heights Elementary Sch",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000117",
    },
    {
        "school": "Binford Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000118",
    },
    {
        "school": "Bloomington High School North",
        "district": "Monroe County Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000119",
    },
    {
        "school": "Bloomington High School South",
        "district": "Monroe County Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000120",
    },
    {
        "school": "Childs Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000123",
    },
    {
        "school": "Clear Creek Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000124",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000127",
    },
    {
        "school": "Grandview Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000128",
    },
    {
        "school": "Lakeview Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000129",
    },
    {
        "school": "Lora L Batchelor Middle School",
        "district": "Monroe County Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000130",
    },
    {
        "school": "Marlin Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000131",
    },
    {
        "school": "Rogers Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000132",
    },
    {
        "school": "Templeton Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000135",
    },
    {
        "school": "Unionville Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000136",
    },
    {
        "school": "University Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063000138",
    },
    {
        "school": "Jackson Creek Middle School",
        "district": "Monroe County Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063001123",
    },
    {
        "school": "Tri-North Middle School",
        "district": "Monroe County Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063002232",
    },
    {
        "school": "Hoosier Hills Career Center",
        "district": "Monroe County Community Sch Corp",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180063002266",
    },
    {
        "school": "Highland Park Elementary School",
        "district": "Monroe County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063002347",
    },
    {
        "school": "Edgewood Early Childhood Center",
        "district": "Richland-Bean Blossom C S C",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180948000261",
    },
    {
        "school": "Forest Hills Spec Educ Coop",
        "district": "Richland-Bean Blossom C S C",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180948000278",
    },
    {
        "school": "Edgewood High School",
        "district": "Richland-Bean Blossom C S C",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180948001546",
    },
    {
        "school": "Edgewood Junior High School",
        "district": "Richland-Bean Blossom C S C",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180948001547",
    },
    {
        "school": "Thea Bowman Leadership Academy",
        "district": "Thea Bowman Leadership Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180002501807",
    },
    {
        "school": "Charter School of the Dunes",
        "district": "Charter School of the Dunes",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180002701815",
    },
    {
        "school": "East Chicago Urban Enterprise Acad",
        "district": "East Chicago Urban Enterprise Acad",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180004802163",
    },
    {
        "school": "Gary Lighthouse Charter School",
        "district": "Gary Lighthouse Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180005202155",
    },
    {
        "school": "Jerry Ross Elementary School",
        "district": "Crown Point Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180249002025",
    },
    {
        "school": "Glen Park Acad for Excel in Lrn",
        "district": "Gary Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180387002102",
    },
    {
        "school": "Daniel Hale Williams Elem Sch",
        "district": "Gary Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180387002104",
    },
    {
        "school": "Frank O'Bannon Elementary School",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432002106",
    },
    {
        "school": "Hanover Central Middle School",
        "district": "Hanover Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180435001908",
    },
    {
        "school": "Hebron Middle School",
        "district": "M S D Boone Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180075002216",
    },
    {
        "school": "DeMotte Elementary School",
        "district": "Kankakee Valley School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180528000932",
    },
    {
        "school": "Kankakee Valley High School",
        "district": "Kankakee Valley School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180528000933",
    },
    {
        "school": "Kankakee Valley Middle School",
        "district": "Kankakee Valley School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180528000934",
    },
    {
        "school": "Wheatfield Elementary School",
        "district": "Kankakee Valley School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180528000935",
    },
    {
        "school": "Kankakee Valley Intermediate Sch",
        "district": "Kankakee Valley School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180528001412",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "North Newton School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180792001360",
    },
    {
        "school": "Rensselaer Central Primary School",
        "district": "Rensselaer Central School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180942001542",
    },
    {
        "school": "Rensselaer Central High School",
        "district": "Rensselaer Central School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180942001543",
    },
    {
        "school": "Rensselaer Middle School",
        "district": "Rensselaer Central School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180942001544",
    },
    {
        "school": "Van Rensselaer Elementary School",
        "district": "Rensselaer Central School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180942001545",
    },
    {
        "school": "Lake Village Elementary School",
        "district": "North Newton School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180792001359",
    },
    {
        "school": "Morocco Elementary School",
        "district": "North Newton School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180792001361",
    },
    {
        "school": "North Newton Jr-Sr High School",
        "district": "North Newton School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180792001363",
    },
    {
        "school": "South Newton Elementary School",
        "district": "South Newton School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181047000768",
    },
    {
        "school": "South Newton Middle School",
        "district": "South Newton School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181047001473",
    },
    {
        "school": "South Newton Senior High School",
        "district": "South Newton School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181047001722",
    },
    {
        "school": "Crown Point High School",
        "district": "Crown Point Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180249000293",
    },
    {
        "school": "Douglas MacArthur Elem School",
        "district": "Crown Point Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180249000294",
    },
    {
        "school": "Dwight D Eisenhower Elem School",
        "district": "Crown Point Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180249000295",
    },
    {
        "school": "Lake Street Elementary School",
        "district": "Crown Point Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180249000296",
    },
    {
        "school": "Robert Taft Middle School",
        "district": "Crown Point Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180249000297",
    },
    {
        "school": "Solon Robinson Elementary School",
        "district": "Crown Point Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180249000298",
    },
    {
        "school": "Timothy Ball Elementary School",
        "district": "Crown Point Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180249000299",
    },
    {
        "school": "Winfield Elementary School",
        "district": "Crown Point Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180249000300",
    },
    {
        "school": "Abraham Lincoln Elementary School",
        "district": "School City of East Chicago",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180288000362",
    },
    {
        "school": "Benjamin Harrison Elementary Sch",
        "district": "School City of East Chicago",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180288000364",
    },
    {
        "school": "Carrie Gosch PK Center",
        "district": "School City of East Chicago",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180288000365",
    },
    {
        "school": "George Washington Elementary Sch",
        "district": "School City of East Chicago",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180288000368",
    },
    {
        "school": "Joseph Block Middle School",
        "district": "School City of East Chicago",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180288000370",
    },
    {
        "school": "William McKinley Elementary School",
        "district": "School City of East Chicago",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180288000375",
    },
    {
        "school": "East Chicago Central High School",
        "district": "School City of East Chicago",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180288002272",
    },
    {
        "school": "Alexander Hamilton Elementary Sch",
        "district": "Lake Station Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180291000376",
    },
    {
        "school": "Thomas A Edison Jr-Sr HS",
        "district": "Lake Station Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180291000380",
    },
    {
        "school": "Virgil I Bailey Elementary School",
        "district": "Lake Station Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180291000381",
    },
    {
        "school": "Banneker Elementary at Marquette",
        "district": "Gary Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180387000613",
    },
    {
        "school": "Beveridge Elementary School",
        "district": "Gary Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180387000615",
    },
    {
        "school": "Frankie Woods McCullough Academy",
        "district": "Gary Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180387000620",
    },
    {
        "school": "Gary Career Center",
        "district": "Gary Community School Corp",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180387000625",
    },
    {
        "school": "Mary M Bethune Early Child Dev Ctr",
        "district": "Gary Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180387000640",
    },
    {
        "school": "West Side Leadership Academy",
        "district": "Gary Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180387000648",
    },
    {
        "school": "Beiriger Elementary School",
        "district": "Griffith Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180417000717",
    },
    {
        "school": "Eldon Ready Elementary School",
        "district": "Griffith Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180417000718",
    },
    {
        "school": "Elsie Wadsworth Elementary School",
        "district": "Griffith Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180417000719",
    },
    {
        "school": "Griffith Middle School",
        "district": "Griffith Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180417000721",
    },
    {
        "school": "Griffith Senior High School",
        "district": "Griffith Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180417000722",
    },
    {
        "school": "Abraham Lincoln Elementary School",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000730",
    },
    {
        "school": "Benjamin Franklin Elementary Sch",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000731",
    },
    {
        "school": "Charles N Scott Middle School",
        "district": "School City of Hammond",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000732",
    },
    {
        "school": "Donald E Gavit Middle/High School",
        "district": "School City of Hammond",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000734",
    },
    {
        "school": "George Rogers Clark Md/HS",
        "district": "School City of Hammond",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000735",
    },
    {
        "school": "Hammond High School",
        "district": "School City of Hammond",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000736",
    },
    {
        "school": "Area Career Center",
        "district": "School City of Hammond",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180432000737",
    },
    {
        "school": "Henry W Eggers Middle School",
        "district": "School City of Hammond",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000738",
    },
    {
        "school": "Kenwood Elementary School",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000740",
    },
    {
        "school": "Lew Wallace Elementary School",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000743",
    },
    {
        "school": "Maywood Elementary School",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000744",
    },
    {
        "school": "Morton Senior High School",
        "district": "School City of Hammond",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000746",
    },
    {
        "school": "Thomas Jefferson Elementary School",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000749",
    },
    {
        "school": "Warren G Harding Elementary School",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000750",
    },
    {
        "school": "Washington Irving Elementary Sch",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432000751",
    },
    {
        "school": "Thomas A Edison Elementary School",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432002236",
    },
    {
        "school": "Morton Elementary School",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432002237",
    },
    {
        "school": "Hanover Central High School",
        "district": "Hanover Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180435000753",
    },
    {
        "school": "Jane Ball Elementary School",
        "district": "Hanover Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180435000754",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Hanover Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180435000871",
    },
    {
        "school": "Allen J Warren Elementary School",
        "district": "School Town of Highland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180456000762",
    },
    {
        "school": "Highland High School",
        "district": "School Town of Highland",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180456000763",
    },
    {
        "school": "Highland Middle School",
        "district": "School Town of Highland",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180456000764",
    },
    {
        "school": "Judith Morton Johnston Elementary",
        "district": "School Town of Highland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180456000766",
    },
    {
        "school": "Mildred Merkley Elementary School",
        "district": "School Town of Highland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180456000767",
    },
    {
        "school": "Southridge Elementary School",
        "district": "School Town of Highland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180456000769",
    },
    {
        "school": "Joan Martin Elementary School",
        "district": "School City of Hobart",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180459000214",
    },
    {
        "school": "Early Learning Center-George Earle",
        "district": "School City of Hobart",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180459000772",
    },
    {
        "school": "Hobart Middle School",
        "district": "School City of Hobart",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180459000773",
    },
    {
        "school": "Hobart High School",
        "district": "School City of Hobart",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180459000774",
    },
    {
        "school": "Liberty Elementary School",
        "district": "School City of Hobart",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180459000775",
    },
    {
        "school": "Ridge View Elementary School",
        "district": "School City of Hobart",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180459000777",
    },
    {
        "school": "Henry S Evans Elementary School",
        "district": "River Forest Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180462000778",
    },
    {
        "school": "John I Meister Elementary School",
        "district": "River Forest Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180462000779",
    },
    {
        "school": "River Forest Middle School",
        "district": "River Forest Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180462000780",
    },
    {
        "school": "River Forest High School",
        "district": "River Forest Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180462000781",
    },
    {
        "school": "George Bibich Elementary School",
        "district": "Lake Central School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180545000980",
    },
    {
        "school": "James H Watson Elementary School",
        "district": "Lake Central School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180545000981",
    },
    {
        "school": "Kahler Middle School",
        "district": "Lake Central School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180545000982",
    },
    {
        "school": "Kolling Elementary School",
        "district": "Lake Central School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180545000983",
    },
    {
        "school": "Lake Central High School",
        "district": "Lake Central School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180545000984",
    },
    {
        "school": "Michael Grimmer Middle School",
        "district": "Lake Central School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180545000985",
    },
    {
        "school": "Peifer Elementary School",
        "district": "Lake Central School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180545000986",
    },
    {
        "school": "Protsman Elementary School",
        "district": "Lake Central School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180545000987",
    },
    {
        "school": "Homan Elementary School",
        "district": "Lake Central School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180545002143",
    },
    {
        "school": "Calumet New Tech High School",
        "district": "Lake Ridge New Tech Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180546000989",
    },
    {
        "school": "Lake Ridge New Tech Middle School",
        "district": "Lake Ridge New Tech Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180546000992",
    },
    {
        "school": "Longfellow New Tech Elementary Sch",
        "district": "Lake Ridge New Tech Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180546000993",
    },
    {
        "school": "Ernest R Elliott Elementary School",
        "district": "School Town of Munster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180735001253",
    },
    {
        "school": "Frank H Hammond Elementary School",
        "district": "School Town of Munster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180735001254",
    },
    {
        "school": "James B Eads Elementary School",
        "district": "School Town of Munster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180735001255",
    },
    {
        "school": "Munster High School",
        "district": "School Town of Munster",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180735001257",
    },
    {
        "school": "Wilbur Wright Middle School",
        "district": "School Town of Munster",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180735001259",
    },
    {
        "school": "Eagle Park Community School",
        "district": "NW Indiana Special Education Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180832002208",
    },
    {
        "school": "Edgar L Miller Elementary School",
        "district": "Merrillville Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180969001580",
    },
    {
        "school": "Merrillville Intermediate School",
        "district": "Merrillville Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180969001581",
    },
    {
        "school": "Henry P Fieler Elementary School",
        "district": "Merrillville Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180969001582",
    },
    {
        "school": "Homer Iddings Elementary School",
        "district": "Merrillville Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180969001583",
    },
    {
        "school": "John Wood Elementary School",
        "district": "Merrillville Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180969001584",
    },
    {
        "school": "Jonas E Salk Elementary School",
        "district": "Merrillville Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180969001585",
    },
    {
        "school": "Merrillville High School",
        "district": "Merrillville Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180969001586",
    },
    {
        "school": "Pierce Middle School",
        "district": "Merrillville Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180969001588",
    },
    {
        "school": "Lake Prairie Elementary School",
        "district": "Tri-Creek School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181146001850",
    },
    {
        "school": "Lowell Middle School",
        "district": "Tri-Creek School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181146001851",
    },
    {
        "school": "Lowell Senior High School",
        "district": "Tri-Creek School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181146001852",
    },
    {
        "school": "Oak Hill Elementary School",
        "district": "Tri-Creek School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181146001853",
    },
    {
        "school": "Three Creeks Elem School",
        "district": "Tri-Creek School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181146002360",
    },
    {
        "school": "Whiting Middle School",
        "district": "School City of Whiting",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181320000398",
    },
    {
        "school": "Nathan Hale Elementary School",
        "district": "School City of Whiting",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181320002081",
    },
    {
        "school": "Whiting High School",
        "district": "School City of Whiting",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181320002082",
    },
    {
        "school": "Hebron Elementary School",
        "district": "M S D Boone Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180075000152",
    },
    {
        "school": "Hebron High School",
        "district": "M S D Boone Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180075000153",
    },
    {
        "school": "Bailly Elementary School",
        "district": "Duneland School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180280000331",
    },
    {
        "school": "Brummitt Elementary School",
        "district": "Duneland School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180280000332",
    },
    {
        "school": "Chesterton Senior High School",
        "district": "Duneland School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180280000333",
    },
    {
        "school": "Jackson Elementary School",
        "district": "Duneland School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180280000334",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Duneland School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180280000335",
    },
    {
        "school": "Liberty Intermediate School",
        "district": "Duneland School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180280000336",
    },
    {
        "school": "Newton Yost Elementary School",
        "district": "Duneland School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180280000337",
    },
    {
        "school": "Westchester Intermediate School",
        "district": "Duneland School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180280000338",
    },
    {
        "school": "Chesterton Middle School",
        "district": "Duneland School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180280001624",
    },
    {
        "school": "Morgan Township Middle/High School",
        "district": "East Porter County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180900001214",
    },
    {
        "school": "Kouts Elementary School",
        "district": "East Porter County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180900001496",
    },
    {
        "school": "Kouts Middle/High School",
        "district": "East Porter County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180900001497",
    },
    {
        "school": "Washington Twp Middle/High School",
        "district": "East Porter County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180900002009",
    },
    {
        "school": "Morgan Township Elementary School",
        "district": "East Porter County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180900002378",
    },
    {
        "school": "Washington Twp Elementary School",
        "district": "East Porter County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180900002379",
    },
    {
        "school": "Porter County Education Services",
        "district": "Porter County Education Services",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180913001507",
    },
    {
        "school": "Central Elementary School",
        "district": "Portage Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180915001508",
    },
    {
        "school": "Crisman Elementary School",
        "district": "Portage Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180915001509",
    },
    {
        "school": "Ethel R Jones Elementary School",
        "district": "Portage Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180915001510",
    },
    {
        "school": "George L Myers Elementary School",
        "district": "Portage Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180915001512",
    },
    {
        "school": "Paul Saylor Elementary School",
        "district": "Portage Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180915001513",
    },
    {
        "school": "Portage High School",
        "district": "Portage Township Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180915001514",
    },
    {
        "school": "Rowena Kyle Elementary School",
        "district": "Portage Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180915001515",
    },
    {
        "school": "South Haven Elementary School",
        "district": "Portage Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180915001516",
    },
    {
        "school": "Wallace Aylesworth Elementary",
        "district": "Portage Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180915001518",
    },
    {
        "school": "William Fegely Middle School",
        "district": "Portage Township Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180915001519",
    },
    {
        "school": "Willowcreek Middle School",
        "district": "Portage Township Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180915002212",
    },
    {
        "school": "Boone Grove Middle School",
        "district": "Porter Township School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180918000523",
    },
    {
        "school": "Boone Grove Elementary School",
        "district": "Porter Township School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180918001520",
    },
    {
        "school": "Boone Grove High School",
        "district": "Porter Township School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180918001521",
    },
    {
        "school": "Porter Lakes Elementary School",
        "district": "Porter Township School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180918001522",
    },
    {
        "school": "Union Township Middle School",
        "district": "Union Township School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181170000793",
    },
    {
        "school": "Union Center Elementary School",
        "district": "Union Township School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181170001872",
    },
    {
        "school": "Wheeler High School",
        "district": "Union Township School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181170001873",
    },
    {
        "school": "John Simatovich Elementary School",
        "district": "Union Township School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181170002218",
    },
    {
        "school": "Flint Lake Elementary School",
        "district": "Valparaiso Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181197000163",
    },
    {
        "school": "Benjamin Franklin Middle School",
        "district": "Valparaiso Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181197001881",
    },
    {
        "school": "Central Elementary School",
        "district": "Valparaiso Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181197001882",
    },
    {
        "school": "Cooks Corners Elementary School",
        "district": "Valparaiso Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181197001883",
    },
    {
        "school": "Memorial Elementary School",
        "district": "Valparaiso Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181197001886",
    },
    {
        "school": "Northview Elementary School",
        "district": "Valparaiso Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181197001887",
    },
    {
        "school": "Parkview Elementary School",
        "district": "Valparaiso Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181197001888",
    },
    {
        "school": "Thomas Jefferson Elementary School",
        "district": "Valparaiso Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181197001889",
    },
    {
        "school": "Thomas Jefferson Middle School",
        "district": "Valparaiso Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181197001890",
    },
    {
        "school": "Valparaiso High School",
        "district": "Valparaiso Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181197001891",
    },
    {
        "school": "Porter County Career Center",
        "district": "Valparaiso Community Schools",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "181197002361",
    },
    {
        "school": "Lawrenceburg Primary School",
        "district": "Lawrenceburg Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180570001695",
    },
    {
        "school": "Batesville High School",
        "district": "Batesville Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180039000084",
    },
    {
        "school": "Brookville Elementary School",
        "district": "Franklin County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180370000587",
    },
    {
        "school": "Franklin County Middle School",
        "district": "Franklin County Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180370000589",
    },
    {
        "school": "Mount Carmel School",
        "district": "Franklin County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180370000591",
    },
    {
        "school": "Laurel School",
        "district": "Franklin County Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180370002221",
    },
    {
        "school": "Franklin County High",
        "district": "Franklin County Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180370002336",
    },
    {
        "school": "Batesville Middle School",
        "district": "Batesville Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180039000085",
    },
    {
        "school": "Batesville Intermediate School",
        "district": "Batesville Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180039000087",
    },
    {
        "school": "Batesville Primary School",
        "district": "Batesville Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180039002381",
    },
    {
        "school": "Aurora Elementary School",
        "district": "South Dearborn Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180024000051",
    },
    {
        "school": "Dillsboro Elementary School",
        "district": "South Dearborn Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180024000053",
    },
    {
        "school": "Manchester Elementary School",
        "district": "South Dearborn Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180024000054",
    },
    {
        "school": "Moores Hill Elementary School",
        "district": "South Dearborn Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180024000055",
    },
    {
        "school": "South Dearborn High School",
        "district": "South Dearborn Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180024000056",
    },
    {
        "school": "South Dearborn Middle School",
        "district": "South Dearborn Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180024000958",
    },
    {
        "school": "Central Elementary School",
        "district": "Lawrenceburg Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180570001035",
    },
    {
        "school": "Greendale Middle School",
        "district": "Lawrenceburg Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180570001036",
    },
    {
        "school": "Lawrenceburg High School",
        "district": "Lawrenceburg Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180570001037",
    },
    {
        "school": "Bright Elementary School",
        "district": "Sunman-Dearborn Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181119000371",
    },
    {
        "school": "East Central High School",
        "district": "Sunman-Dearborn Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181119001802",
    },
    {
        "school": "North Dearborn Elementary School",
        "district": "Sunman-Dearborn Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181119001803",
    },
    {
        "school": "Sunman-Dearborn Middle School",
        "district": "Sunman-Dearborn Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181119002300",
    },
    {
        "school": "Ohio County Elementary School",
        "district": "Rising Sun-Ohio Co Com",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180960001572",
    },
    {
        "school": "Rising Sun High School",
        "district": "Rising Sun-Ohio Co Com",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180960001573",
    },
    {
        "school": "Sunman Elementary School",
        "district": "Sunman-Dearborn Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181119001805",
    },
    {
        "school": "Central Middle School",
        "district": "Bartholomew Con School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000063",
    },
    {
        "school": "Columbus East High School",
        "district": "Bartholomew Con School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000065",
    },
    {
        "school": "Columbus North High School",
        "district": "Bartholomew Con School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000066",
    },
    {
        "school": "L F Smith Elementary",
        "district": "Bartholomew Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000070",
    },
    {
        "school": "Lillian Schmitt Elementary School",
        "district": "Bartholomew Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000071",
    },
    {
        "school": "Mount Healthy Elementary School",
        "district": "Bartholomew Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000075",
    },
    {
        "school": "Northside Middle School",
        "district": "Bartholomew Con School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000076",
    },
    {
        "school": "Parkside Elementary School",
        "district": "Bartholomew Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000077",
    },
    {
        "school": "Rockcreek Elementary School",
        "district": "Bartholomew Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000079",
    },
    {
        "school": "Southside Elementary School",
        "district": "Bartholomew Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000080",
    },
    {
        "school": "Taylorsville Elementary School",
        "district": "Bartholomew Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000081",
    },
    {
        "school": "W D Richards Elementary School",
        "district": "Bartholomew Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036000082",
    },
    {
        "school": "Columbus Area Career Connection",
        "district": "Bartholomew Con School Corp",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180036000369",
    },
    {
        "school": "Clifty Creek Elementary School",
        "district": "Bartholomew Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036002188",
    },
    {
        "school": "Hauser Jr-Sr High School",
        "district": "Flat Rock-Hawcreek School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180357000509",
    },
    {
        "school": "Hope Elementary School",
        "district": "Flat Rock-Hawcreek School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180357000510",
    },
    {
        "school": "Whitewater Career Center",
        "district": "Fayette County School Corporation",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180351000495",
    },
    {
        "school": "Connersville Middle School",
        "district": "Fayette County School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180351000496",
    },
    {
        "school": "Connersville Sr High School",
        "district": "Fayette County School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180351000498",
    },
    {
        "school": "Eastview Elementary School",
        "district": "Fayette County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180351000499",
    },
    {
        "school": "Everton Elementary School",
        "district": "Fayette County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180351000500",
    },
    {
        "school": "Fayette Central Elementary",
        "district": "Fayette County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180351000501",
    },
    {
        "school": "Frazee Elementary School",
        "district": "Fayette County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180351000503",
    },
    {
        "school": "Grandview Elementary School",
        "district": "Fayette County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180351000504",
    },
    {
        "school": "Maplewood Elementary School",
        "district": "Fayette County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180351000505",
    },
    {
        "school": "Anna Willson School",
        "district": "Crawfordsville Community Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180246000285",
    },
    {
        "school": "Crawfordsville Sr High School",
        "district": "Crawfordsville Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180246000287",
    },
    {
        "school": "Crawfordsville Middle School",
        "district": "Crawfordsville Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180246000289",
    },
    {
        "school": "Laura Hose Elementary School",
        "district": "Crawfordsville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180246000290",
    },
    {
        "school": "Meredith Nicholson Elementary Sch",
        "district": "Crawfordsville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180246000291",
    },
    {
        "school": "Mollie B Hoover Elementary School",
        "district": "Crawfordsville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180246000292",
    },
    {
        "school": "North Montgomery High School",
        "district": "North Montgomery Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180790001357",
    },
    {
        "school": "Northridge Middle School",
        "district": "North Montgomery Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180790002293",
    },
    {
        "school": "Pleasant Hill Elementary School",
        "district": "North Montgomery Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180790002321",
    },
    {
        "school": "Lester B Sommer Elementary School",
        "district": "North Montgomery Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180790002322",
    },
    {
        "school": "Sugar Creek Elementary School",
        "district": "North Montgomery Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180790002323",
    },
    {
        "school": "Ladoga Elementary School",
        "district": "South Montgomery Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181045001714",
    },
    {
        "school": "New Market Elementary School",
        "district": "South Montgomery Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181045001715",
    },
    {
        "school": "Southmont Sr High School",
        "district": "South Montgomery Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181045001716",
    },
    {
        "school": "Walnut Elementary School",
        "district": "South Montgomery Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181045001717",
    },
    {
        "school": "Southmont Jr High School",
        "district": "South Montgomery Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181045002325",
    },
    {
        "school": "Adams Central Elementary School",
        "district": "Adams Central Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180006000006",
    },
    {
        "school": "Adams Central High School",
        "district": "Adams Central Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180006000007",
    },
    {
        "school": "Adams Central Middle School",
        "district": "Adams Central Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180006000008",
    },
    {
        "school": "Bellmont Middle School",
        "district": "North Adams Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180768001313",
    },
    {
        "school": "Bellmont Senior High School",
        "district": "North Adams Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180768001314",
    },
    {
        "school": "Bellmont Elementary",
        "district": "North Adams Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180768001316",
    },
    {
        "school": "South Adams Elementary School",
        "district": "South Adams Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181026001640",
    },
    {
        "school": "South Adams Middle School",
        "district": "South Adams Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181026001641",
    },
    {
        "school": "South Adams High School",
        "district": "South Adams Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181026001642",
    },
    {
        "school": "Jimtown Intermediate School",
        "district": "Baugo Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180042002026",
    },
    {
        "school": "Jimtown Elementary School",
        "district": "Baugo Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180042000089",
    },
    {
        "school": "Jimtown High School",
        "district": "Baugo Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180042000090",
    },
    {
        "school": "Jimtown Junior High School",
        "district": "Baugo Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180042000091",
    },
    {
        "school": "Concord Community High School",
        "district": "Concord Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180240000269",
    },
    {
        "school": "Concord East Side Elementary Sch",
        "district": "Concord Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180240000270",
    },
    {
        "school": "Concord Junior High School",
        "district": "Concord Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180240000271",
    },
    {
        "school": "Concord Ox-Bow Elementary School",
        "district": "Concord Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180240000272",
    },
    {
        "school": "Concord South Side Elementary Sch",
        "district": "Concord Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180240000273",
    },
    {
        "school": "Concord West Side Elem School",
        "district": "Concord Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180240000274",
    },
    {
        "school": "Beardsley Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000423",
    },
    {
        "school": "Bristol Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000424",
    },
    {
        "school": "Cleveland Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000426",
    },
    {
        "school": "Eastwood Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000427",
    },
    {
        "school": "Elkhart Area Career Center",
        "district": "Elkhart Community Schools",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180327000428",
    },
    {
        "school": "Elkhart Central High School",
        "district": "Elkhart Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000429",
    },
    {
        "school": "Elkhart Memorial High School",
        "district": "Elkhart Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000430",
    },
    {
        "school": "Hawthorne Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000431",
    },
    {
        "school": "Mary Beck Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000434",
    },
    {
        "school": "Mary Feeser Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000435",
    },
    {
        "school": "Mary Daly Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000436",
    },
    {
        "school": "Monger Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000437",
    },
    {
        "school": "North Side Middle School",
        "district": "Elkhart Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000438",
    },
    {
        "school": "Osolo Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000439",
    },
    {
        "school": "Pierre Moran Middle School",
        "district": "Elkhart Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000440",
    },
    {
        "school": "Pinewood Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000441",
    },
    {
        "school": "Riverview Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000443",
    },
    {
        "school": "Roosevelt STEAM Academy",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000444",
    },
    {
        "school": "West Side Middle School",
        "district": "Elkhart Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000445",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Elkhart Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327000447",
    },
    {
        "school": "Fairfield Jr-Sr High School",
        "district": "Fairfield Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180348000491",
    },
    {
        "school": "Millersburg Elementary- Middle Sch",
        "district": "Fairfield Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180348000492",
    },
    {
        "school": "New Paris Elementary School",
        "district": "Fairfield Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180348000493",
    },
    {
        "school": "Benton Elementary School",
        "district": "Fairfield Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180348001238",
    },
    {
        "school": "Chamberlain Elementary School",
        "district": "Goshen Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180393000652",
    },
    {
        "school": "Chandler Elementary School",
        "district": "Goshen Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180393000653",
    },
    {
        "school": "Goshen High School",
        "district": "Goshen Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180393000654",
    },
    {
        "school": "Model Elementary School",
        "district": "Goshen Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180393000656",
    },
    {
        "school": "Parkside Elementary School",
        "district": "Goshen Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180393000657",
    },
    {
        "school": "Goshen Middle School",
        "district": "Goshen Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180393000659",
    },
    {
        "school": "Waterford Elementary School",
        "district": "Goshen Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180393000660",
    },
    {
        "school": "West Goshen Elementary School",
        "district": "Goshen Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180393000661",
    },
    {
        "school": "Orchard View School",
        "district": "Middlebury Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180660000199",
    },
    {
        "school": "Northridge Middle School",
        "district": "Middlebury Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180660001162",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Middlebury Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180660001163",
    },
    {
        "school": "Middlebury Elementary School",
        "district": "Middlebury Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180660001164",
    },
    {
        "school": "Northridge High School",
        "district": "Middlebury Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180660001165",
    },
    {
        "school": "York Elementary School",
        "district": "Middlebury Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180660001166",
    },
    {
        "school": "Wakarusa Elementary School",
        "district": "Wa-Nee Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181224000028",
    },
    {
        "school": "Woodview Elementary School",
        "district": "Wa-Nee Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181224000034",
    },
    {
        "school": "Nappanee Elementary School",
        "district": "Wa-Nee Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181224001954",
    },
    {
        "school": "North Wood High School",
        "district": "Wa-Nee Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181224001956",
    },
    {
        "school": "North Wood Middle School",
        "district": "Wa-Nee Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181224001958",
    },
    {
        "school": "Signature School Inc",
        "district": "Signature School Inc",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180002100319",
    },
    {
        "school": "Joshua Academy",
        "district": "Joshua Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003702146",
    },
    {
        "school": "Francisco Elementary School",
        "district": "East Gibson School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180294000382",
    },
    {
        "school": "Barton Township Elementary",
        "district": "East Gibson School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180294000383",
    },
    {
        "school": "Oakland City Elementary School",
        "district": "East Gibson School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180294000384",
    },
    {
        "school": "Waldo J Wood Memorial High",
        "district": "East Gibson School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180294000386",
    },
    {
        "school": "Waldo J Wood Memorial JHS",
        "district": "East Gibson School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180294000622",
    },
    {
        "school": "Princeton Comm Intermediate School",
        "district": "North Gibson School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180777001324",
    },
    {
        "school": "Princeton Comm Primary School",
        "district": "North Gibson School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180777001325",
    },
    {
        "school": "Princeton Community High School",
        "district": "North Gibson School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180777001326",
    },
    {
        "school": "Princeton Community Middle",
        "district": "North Gibson School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180777001327",
    },
    {
        "school": "Gibson Southern High School",
        "district": "South Gibson School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181035001688",
    },
    {
        "school": "Haubstadt Community School",
        "district": "South Gibson School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181035001689",
    },
    {
        "school": "Owensville Community School",
        "district": "South Gibson School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181035001691",
    },
    {
        "school": "Fort Branch Community School",
        "district": "South Gibson School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181035002230",
    },
    {
        "school": "Farmersville Elementary School",
        "district": "M S D Mount Vernon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180729001223",
    },
    {
        "school": "Marrs Elementary School",
        "district": "M S D Mount Vernon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180729001225",
    },
    {
        "school": "Mount Vernon High School",
        "district": "M S D Mount Vernon",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180729001226",
    },
    {
        "school": "Mount Vernon Jr High School",
        "district": "M S D Mount Vernon",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180729001227",
    },
    {
        "school": "West Elementary School",
        "district": "M S D Mount Vernon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180729001228",
    },
    {
        "school": "North Elementary School",
        "district": "M S D North Posey Co Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180795001364",
    },
    {
        "school": "North Posey Junior High School",
        "district": "M S D North Posey Co Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180795001365",
    },
    {
        "school": "North Posey High School",
        "district": "M S D North Posey Co Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180795001366",
    },
    {
        "school": "South Terrace Elementary",
        "district": "M S D North Posey Co Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180795001367",
    },
    {
        "school": "Benjamin Bosse High School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000456",
    },
    {
        "school": "Caze Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000457",
    },
    {
        "school": "Cedar Hall Community School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000458",
    },
    {
        "school": "Central High School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000459",
    },
    {
        "school": "Cynthia Heights Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000460",
    },
    {
        "school": "Delaware Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000462",
    },
    {
        "school": "Dexter Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000463",
    },
    {
        "school": "Fairlawn Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000465",
    },
    {
        "school": "Francis Joseph Reitz High School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000466",
    },
    {
        "school": "Glenwood Leadership Academy",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000467",
    },
    {
        "school": "Harper Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000468",
    },
    {
        "school": "Hebron Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000470",
    },
    {
        "school": "Helfrich Park STEM Academy",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000471",
    },
    {
        "school": "Highland Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000472",
    },
    {
        "school": "Evans School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000473",
    },
    {
        "school": "Lincoln School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000475",
    },
    {
        "school": "Lodge Community School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000476",
    },
    {
        "school": "McGary Middle School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000477",
    },
    {
        "school": "North High School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000478",
    },
    {
        "school": "Perry Heights Middle School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000480",
    },
    {
        "school": "Plaza Park International Prep Acad",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000481",
    },
    {
        "school": "Scott Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000482",
    },
    {
        "school": "Stockwell Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000483",
    },
    {
        "school": "Stringtown Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000484",
    },
    {
        "school": "Tekoppel Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000485",
    },
    {
        "school": "Thompkins Middle School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000486",
    },
    {
        "school": "Vogel Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000487",
    },
    {
        "school": "Washington Middle School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000488",
    },
    {
        "school": "West Terrace Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000489",
    },
    {
        "school": "William Henry Harrison High School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345000490",
    },
    {
        "school": "Daniel Wertz Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345002275",
    },
    {
        "school": "Boonville High School",
        "district": "Warrick County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001975",
    },
    {
        "school": "Boonville Middle School",
        "district": "Warrick County School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001976",
    },
    {
        "school": "Castle High School",
        "district": "Warrick County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001977",
    },
    {
        "school": "Castle North Middle School",
        "district": "Warrick County School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001978",
    },
    {
        "school": "Chandler Elementary School",
        "district": "Warrick County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001979",
    },
    {
        "school": "Elberfeld Elementary School",
        "district": "Warrick County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001980",
    },
    {
        "school": "John H Castle Elementary School",
        "district": "Warrick County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001981",
    },
    {
        "school": "Loge Elementary School",
        "district": "Warrick County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001982",
    },
    {
        "school": "Lynnville Elementary School",
        "district": "Warrick County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001983",
    },
    {
        "school": "Newburgh Elementary School",
        "district": "Warrick County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001984",
    },
    {
        "school": "Oakdale Elementary School",
        "district": "Warrick County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001985",
    },
    {
        "school": "Tecumseh High School",
        "district": "Warrick County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001986",
    },
    {
        "school": "Tennyson Elementary School",
        "district": "Warrick County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001987",
    },
    {
        "school": "Yankeetown Elementary School",
        "district": "Warrick County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239001988",
    },
    {
        "school": "Sharon Elementary School",
        "district": "Warrick County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239002179",
    },
    {
        "school": "Timothy L Johnson Academy",
        "district": "Timothy L Johnson Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180001301774",
    },
    {
        "school": "Covington Elementary School",
        "district": "M S D Southwest Allen County Schls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003001810",
    },
    {
        "school": "Lafayette Meadow School",
        "district": "M S D Southwest Allen County Schls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003002044",
    },
    {
        "school": "Allen Co Juvenile Center",
        "district": "Fort Wayne Community Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363002174",
    },
    {
        "school": "Little Turtle Elementary School",
        "district": "Whitley County Con Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180228002135",
    },
    {
        "school": "Aboite Elementary School",
        "district": "M S D Southwest Allen County Schls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003000001",
    },
    {
        "school": "Homestead Senior High School",
        "district": "M S D Southwest Allen County Schls",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003000002",
    },
    {
        "school": "Woodside Middle School",
        "district": "M S D Southwest Allen County Schls",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003000005",
    },
    {
        "school": "Whispering Meadow Elementary Sch",
        "district": "M S D Southwest Allen County Schls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003000083",
    },
    {
        "school": "Summit Middle School",
        "district": "M S D Southwest Allen County Schls",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003000116",
    },
    {
        "school": "Haverhill Elementary School",
        "district": "M S D Southwest Allen County Schls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003002186",
    },
    {
        "school": "Deer Ridge Elementary",
        "district": "M S D Southwest Allen County Schls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003002329",
    },
    {
        "school": "Heritage Jr/Sr High School",
        "district": "East Allen County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285000344",
    },
    {
        "school": "New Haven Primary School",
        "district": "East Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285000345",
    },
    {
        "school": "Heritage Elementary School",
        "district": "East Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285000346",
    },
    {
        "school": "Leo Elementary School",
        "district": "East Allen County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285000348",
    },
    {
        "school": "Leo Junior/Senior High School",
        "district": "East Allen County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285000349",
    },
    {
        "school": "New Haven Intermediate School",
        "district": "East Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285000350",
    },
    {
        "school": "New Haven Jr/Sr High School",
        "district": "East Allen County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285000353",
    },
    {
        "school": "Southwick Elementary School",
        "district": "East Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285000356",
    },
    {
        "school": "Woodlan Jr/Sr High School",
        "district": "East Allen County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285000361",
    },
    {
        "school": "Cedarville Elementary School",
        "district": "East Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285000954",
    },
    {
        "school": "Adams Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000511",
    },
    {
        "school": "Arlington Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000514",
    },
    {
        "school": "Blackhawk Middle School",
        "district": "Fort Wayne Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000516",
    },
    {
        "school": "Bloomingdale Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000517",
    },
    {
        "school": "Brentwood Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000518",
    },
    {
        "school": "Bunche Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000519",
    },
    {
        "school": "Forest Park Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000522",
    },
    {
        "school": "Francis M Price Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000524",
    },
    {
        "school": "Franke Park Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000525",
    },
    {
        "school": "Fred H Croninger Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000527",
    },
    {
        "school": "Glenwood Park Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000529",
    },
    {
        "school": "Harrison Hill Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000530",
    },
    {
        "school": "Indian Village Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000532",
    },
    {
        "school": "J Wilbur Haley Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000533",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Fort Wayne Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000534",
    },
    {
        "school": "John S Irwin Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000535",
    },
    {
        "school": "Kekionga Middle School",
        "district": "Fort Wayne Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000537",
    },
    {
        "school": "Lakeside Middle School",
        "district": "Fort Wayne Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000538",
    },
    {
        "school": "Lane Middle School",
        "district": "Fort Wayne Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000539",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000540",
    },
    {
        "school": "Lindley Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000541",
    },
    {
        "school": "Mabel K Holland Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000543",
    },
    {
        "school": "Maplewood Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000544",
    },
    {
        "school": "Memorial Park Middle School",
        "district": "Fort Wayne Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000546",
    },
    {
        "school": "Merle J Abbett Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000547",
    },
    {
        "school": "Miami Middle School",
        "district": "Fort Wayne Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000548",
    },
    {
        "school": "North Side High School",
        "district": "Fort Wayne Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000550",
    },
    {
        "school": "Northcrest Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000551",
    },
    {
        "school": "Northrop High School",
        "district": "Fort Wayne Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000552",
    },
    {
        "school": "Northwood Middle School",
        "district": "Fort Wayne Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000553",
    },
    {
        "school": "Portage Middle School",
        "district": "Fort Wayne Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000555",
    },
    {
        "school": "R Nelson Snider High School",
        "district": "Fort Wayne Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000556",
    },
    {
        "school": "Robert C Harris Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000558",
    },
    {
        "school": "Saint Joseph Central School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000559",
    },
    {
        "school": "Shawnee Middle School",
        "district": "Fort Wayne Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000560",
    },
    {
        "school": "South Side High School",
        "district": "Fort Wayne Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000562",
    },
    {
        "school": "South Wayne Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000563",
    },
    {
        "school": "Levan R Scott Academy",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000564",
    },
    {
        "school": "Washington Center Elementary Sch",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000566",
    },
    {
        "school": "Washington Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000567",
    },
    {
        "school": "Wayne High School",
        "district": "Fort Wayne Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000568",
    },
    {
        "school": "Waynedale Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000569",
    },
    {
        "school": "Weisser Park Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000570",
    },
    {
        "school": "Willard Shambaugh Elementary Sch",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000572",
    },
    {
        "school": "Study Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363000948",
    },
    {
        "school": "Whitney M Young Early Childhood",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363001541",
    },
    {
        "school": "Fairfield Elementary School",
        "district": "Fort Wayne Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180363002197",
    },
    {
        "school": "Oak View Elementary School",
        "district": "Northwest Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180825000016",
    },
    {
        "school": "Hickory Center Elementary School",
        "district": "Northwest Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180825000937",
    },
    {
        "school": "Maple Creek Middle School",
        "district": "Northwest Allen County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180825001380",
    },
    {
        "school": "Arcola School",
        "district": "Northwest Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180825001413",
    },
    {
        "school": "Carroll High School",
        "district": "Northwest Allen County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180825001414",
    },
    {
        "school": "Huntertown Elementary School",
        "district": "Northwest Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180825001415",
    },
    {
        "school": "Perry Hill Elementary School",
        "district": "Northwest Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180825001416",
    },
    {
        "school": "Allen Co Youth Services Center",
        "district": "Northwest Allen County Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "IN",
        "nces_id": "180825002160",
    },
    {
        "school": "Carroll Middle School",
        "district": "Northwest Allen County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180825002294",
    },
    {
        "school": "Bluffton High School",
        "district": "M S D Bluffton-Harrison",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180072000146",
    },
    {
        "school": "Bluffton-Harrison Middle School",
        "district": "M S D Bluffton-Harrison",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180072000147",
    },
    {
        "school": "Bluffton-Harrison Elementary Sch",
        "district": "M S D Bluffton-Harrison",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180072000149",
    },
    {
        "school": "Lancaster Central School",
        "district": "Northern Wells Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180822001409",
    },
    {
        "school": "Norwell High School",
        "district": "Northern Wells Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180822001410",
    },
    {
        "school": "Ossian Elementary",
        "district": "Northern Wells Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180822001411",
    },
    {
        "school": "Norwell Middle School",
        "district": "Northern Wells Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180822002159",
    },
    {
        "school": "Southern Wells Elementary School",
        "district": "Southern Wells Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181077001764",
    },
    {
        "school": "Southern Wells Jr-Sr High School",
        "district": "Southern Wells Com Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181077001765",
    },
    {
        "school": "Columbia City High School",
        "district": "Whitley County Con Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180228000267",
    },
    {
        "school": "Indian Springs Middle School",
        "district": "Whitley County Con Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180228000824",
    },
    {
        "school": "Northern Heights Elementary School",
        "district": "Whitley County Con Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180228001185",
    },
    {
        "school": "Coesse School",
        "district": "Whitley County Con Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180228001871",
    },
    {
        "school": "Mary Raber Elementary School",
        "district": "Whitley County Con Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180228002108",
    },
    {
        "school": "Churubusco Elementary School",
        "district": "Smith-Green Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181023001637",
    },
    {
        "school": "Churubusco Jr-Sr High School",
        "district": "Smith-Green Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181023001638",
    },
    {
        "school": "Clinton Central Elementary School",
        "district": "Clinton Central School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180213000256",
    },
    {
        "school": "Clinton Central Junior-Senior HS",
        "district": "Clinton Central School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180213000257",
    },
    {
        "school": "Clinton Prairie Jr-Sr High School",
        "district": "Clinton Prairie School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180216000258",
    },
    {
        "school": "Clinton Prairie Elementary School",
        "district": "Clinton Prairie School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180216002245",
    },
    {
        "school": "Frankfort Middle School",
        "district": "Community Schools of Frankfort",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180366000573",
    },
    {
        "school": "Frankfort High School",
        "district": "Community Schools of Frankfort",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180366000574",
    },
    {
        "school": "Suncrest Elementary School",
        "district": "Community Schools of Frankfort",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180366000602",
    },
    {
        "school": "Rossville Elementary School",
        "district": "Rossville Con School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180972001589",
    },
    {
        "school": "Rossville Middle/Senior High Sch",
        "district": "Rossville Con School District",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180972001590",
    },
    {
        "school": "Greensburg Elementary",
        "district": "Greensburg Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180408002056",
    },
    {
        "school": "North Decatur Elementary School",
        "district": "Decatur County Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180261000308",
    },
    {
        "school": "North Decatur Jr-Sr High School",
        "district": "Decatur County Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180261000309",
    },
    {
        "school": "South Decatur Elementary School",
        "district": "Decatur County Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180261000310",
    },
    {
        "school": "South Decatur Jr-Sr High School",
        "district": "Decatur County Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180261000311",
    },
    {
        "school": "Greensburg Community High School",
        "district": "Greensburg Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180408000704",
    },
    {
        "school": "Greensburg Community Jr High",
        "district": "Greensburg Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180408000705",
    },
    {
        "school": "Flint Springs Elementary",
        "district": "Huntington Co Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180471002093",
    },
    {
        "school": "Andrews Elementary School",
        "district": "Huntington Co Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180471000782",
    },
    {
        "school": "Crestview Middle School",
        "district": "Huntington Co Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180471000784",
    },
    {
        "school": "Huntington North High School",
        "district": "Huntington Co Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180471000786",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Huntington Co Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180471000788",
    },
    {
        "school": "Riverview School",
        "district": "Huntington Co Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180471000790",
    },
    {
        "school": "Roanoke Elementary School",
        "district": "Huntington Co Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180471000791",
    },
    {
        "school": "Salamonie School",
        "district": "Huntington Co Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180471000792",
    },
    {
        "school": "Stonegate Elementary",
        "district": "Zionsville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180283001854",
    },
    {
        "school": "Zionsville West Middle School",
        "district": "Zionsville Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180283002046",
    },
    {
        "school": "Logansport Juvenile Correctional",
        "district": "Indiana Department of Correction",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180000601946",
    },
    {
        "school": "Options Charter School - Carmel",
        "district": "Options Charter School - Carmel",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180001601738",
    },
    {
        "school": "Creekside Middle School",
        "district": "Carmel Clay Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120002083",
    },
    {
        "school": "Hamilton Heights Primary School",
        "district": "Hamilton Heights School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180426001653",
    },
    {
        "school": "Sheridan Middle School",
        "district": "Sheridan Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180648001655",
    },
    {
        "school": "Brooks School Elementary",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065001866",
    },
    {
        "school": "Geist Elementary School",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065002060",
    },
    {
        "school": "Sand Creek Elementary",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065002061",
    },
    {
        "school": "JB Stephens Elementary School",
        "district": "Greenfield-Central Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180405001665",
    },
    {
        "school": "McCordsville Elementary School",
        "district": "Mt Vernon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180726002192",
    },
    {
        "school": "Hickory Elementary School",
        "district": "Avon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027001675",
    },
    {
        "school": "Avon Intermediate School West",
        "district": "Avon Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027002092",
    },
    {
        "school": "White Lick Elementary School",
        "district": "Brownsburg Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180102001671",
    },
    {
        "school": "Brownsburg East Middle School",
        "district": "Brownsburg Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180102002086",
    },
    {
        "school": "Tri-West Middle School",
        "district": "North West Hendricks Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180810001670",
    },
    {
        "school": "Center Grove Middle School North",
        "district": "Center Grove Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180144001912",
    },
    {
        "school": "Grassy Creek Elementary School",
        "district": "Clark-Pleasant Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180189002094",
    },
    {
        "school": "21st Century Charter Sch of Gary",
        "district": "21st Century Charter Sch of Gary",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180004602162",
    },
    {
        "school": "Pendleton Juvenile Correctional",
        "district": "Indiana Department of Correction",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180000601935",
    },
    {
        "school": "LaPorte Juvenile Correctional",
        "district": "Indiana Department of Correction",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180000601943",
    },
    {
        "school": "Irvington Community School",
        "district": "Irvington Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180001401756",
    },
    {
        "school": "Christel House Academy South",
        "district": "Christel House Academy South",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180001801789",
    },
    {
        "school": "Indiana School For The Blind",
        "district": "IN Sch for the Blind & Vis Imprd",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180002302257",
    },
    {
        "school": "Indiana School For The Deaf",
        "district": "Indiana School For The Deaf",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180002402258",
    },
    {
        "school": "KIPP Indy College Prep Middle",
        "district": "KIPP Indy College Prep Middle",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180002802136",
    },
    {
        "school": "SE Neighborhood Sch of Excellence",
        "district": "SE Neighborhood Sch of Excellence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003302144",
    },
    {
        "school": "Andrew J Brown Academy",
        "district": "Andrew J Brown Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180004201816",
    },
    {
        "school": "Charles A Tindley Accelerated Sch",
        "district": "Charles A Tindley Accelerated Sch",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180004502137",
    },
    {
        "school": "Victory College Prep Academy",
        "district": "Victory College Prep Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180005102165",
    },
    {
        "school": "Gold Academy",
        "district": "M S D Decatur Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180264002111",
    },
    {
        "school": "Blue Academy",
        "district": "M S D Decatur Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180264002112",
    },
    {
        "school": "Thompson Crossing Elementary Sch",
        "district": "Franklin Township Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180375002113",
    },
    {
        "school": "Winding Ridge Elementary School",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567002114",
    },
    {
        "school": "Jeremiah Gray Elementary School",
        "district": "Perry Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001687",
    },
    {
        "school": "Rosa Parks Elementary School",
        "district": "Perry Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001809",
    },
    {
        "school": "Southport 6th Grade Academy",
        "district": "Perry Township Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882002115",
    },
    {
        "school": "Perry Meridian 6th Grade Academy",
        "district": "Perry Township Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882002119",
    },
    {
        "school": "Liberty Park Elementary School",
        "district": "M S D Warren Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001690",
    },
    {
        "school": "Ben Davis Ninth Grade Center",
        "district": "M S D Wayne Township",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002122",
    },
    {
        "school": "Bridgeport Elementary School",
        "district": "M S D Wayne Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002123",
    },
    {
        "school": "Monrovia Middle School",
        "district": "Monroe-Gregg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180414002129",
    },
    {
        "school": "Area 30 Career Center",
        "district": "Area 30 Career Center Edu Inter",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180003402107",
    },
    {
        "school": "Brown County High School",
        "district": "Brown County School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180096000169",
    },
    {
        "school": "Helmsburg Elementary School",
        "district": "Brown County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180096000170",
    },
    {
        "school": "Sprunica Elementary School",
        "district": "Brown County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180096000172",
    },
    {
        "school": "Van Buren Elementary School",
        "district": "Brown County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180096000173",
    },
    {
        "school": "Brown County Junior High",
        "district": "Brown County School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180096002190",
    },
    {
        "school": "Cloverdale Elementary School",
        "district": "Cloverdale Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180222000264",
    },
    {
        "school": "Cloverdale High School",
        "district": "Cloverdale Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180222000265",
    },
    {
        "school": "Cloverdale Middle School",
        "district": "Cloverdale Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180222001283",
    },
    {
        "school": "Greencastle Middle School",
        "district": "Greencastle Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180399000689",
    },
    {
        "school": "Greencastle Senior High School",
        "district": "Greencastle Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180399000690",
    },
    {
        "school": "Martha J Ridpath Elementary School",
        "district": "Greencastle Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180399000691",
    },
    {
        "school": "Tzouanakis Intermediate School",
        "district": "Greencastle Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180399000693",
    },
    {
        "school": "Deer Meadow Primary School",
        "district": "Greencastle Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180399001625",
    },
    {
        "school": "North Putnam Middle School",
        "district": "North Putnam Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180798000316",
    },
    {
        "school": "Bainbridge Elementary School",
        "district": "North Putnam Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180798001368",
    },
    {
        "school": "North Putnam Sr High School",
        "district": "North Putnam Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180798001369",
    },
    {
        "school": "Roachdale Elementary School",
        "district": "North Putnam Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180798001371",
    },
    {
        "school": "Fillmore Elementary School",
        "district": "South Putnam Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181050001724",
    },
    {
        "school": "South Putnam High School",
        "district": "South Putnam Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181050001726",
    },
    {
        "school": "Central Elementary School",
        "district": "South Putnam Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181050002253",
    },
    {
        "school": "Union Elementary School",
        "district": "Zionsville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180283000340",
    },
    {
        "school": "Zionsville Community High School",
        "district": "Zionsville Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180283000341",
    },
    {
        "school": "Zionsville Middle School",
        "district": "Zionsville Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180283000342",
    },
    {
        "school": "Eagle Elementary School",
        "district": "Zionsville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180283001219",
    },
    {
        "school": "Zionsville Pleasant View Elem Sch",
        "district": "Zionsville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180283001551",
    },
    {
        "school": "Central Elementary School",
        "district": "Lebanon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180579001038",
    },
    {
        "school": "Harney Elementary School",
        "district": "Lebanon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180579001039",
    },
    {
        "school": "Lebanon Middle School",
        "district": "Lebanon Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180579001040",
    },
    {
        "school": "Lebanon Senior High School",
        "district": "Lebanon Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180579001041",
    },
    {
        "school": "Perry Worth Elementary School",
        "district": "Lebanon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180579001042",
    },
    {
        "school": "Hattie B Stokes Elementary School",
        "district": "Lebanon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180579001043",
    },
    {
        "school": "Granville Wells Elementary School",
        "district": "Western Boone Co Com Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181299002064",
    },
    {
        "school": "Thorntown Elementary School",
        "district": "Western Boone Co Com Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181299002065",
    },
    {
        "school": "Western Boone Jr-Sr High School",
        "district": "Western Boone Co Com Sch Dist",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181299002066",
    },
    {
        "school": "Smoky Row Elementary School",
        "district": "Carmel Clay Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120000036",
    },
    {
        "school": "Carmel Elementary School",
        "district": "Carmel Clay Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120000192",
    },
    {
        "school": "Carmel High School",
        "district": "Carmel Clay Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120000193",
    },
    {
        "school": "Carmel Middle School",
        "district": "Carmel Clay Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120000194",
    },
    {
        "school": "Clay Middle School",
        "district": "Carmel Clay Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120000195",
    },
    {
        "school": "College Wood Elementary School",
        "district": "Carmel Clay Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120000196",
    },
    {
        "school": "Mohawk Trails Elementary School",
        "district": "Carmel Clay Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120000198",
    },
    {
        "school": "Woodbrook Elementary School",
        "district": "Carmel Clay Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120000200",
    },
    {
        "school": "Prairie Trace Elementary School",
        "district": "Carmel Clay Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120000991",
    },
    {
        "school": "Towne Meadow Elementary School",
        "district": "Carmel Clay Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120001405",
    },
    {
        "school": "Forest Dale Elementary School",
        "district": "Carmel Clay Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120002101",
    },
    {
        "school": "Orchard Park Elementary School",
        "district": "Carmel Clay Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120002267",
    },
    {
        "school": "Cherry Tree Elementary School",
        "district": "Carmel Clay Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180120002332",
    },
    {
        "school": "Hamilton Heights Middle School",
        "district": "Hamilton Heights School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180426000727",
    },
    {
        "school": "Hamilton Heights High School",
        "district": "Hamilton Heights School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180426000728",
    },
    {
        "school": "Hamilton Heights Elementary School",
        "district": "Hamilton Heights School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180426002134",
    },
    {
        "school": "Sheridan Elementary School",
        "district": "Sheridan Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180648001125",
    },
    {
        "school": "Sheridan High School",
        "district": "Sheridan Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180648001127",
    },
    {
        "school": "Noblesville West Middle School",
        "district": "Noblesville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180765000639",
    },
    {
        "school": "White River Elementary School",
        "district": "Noblesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180765001246",
    },
    {
        "school": "Noblesville High School",
        "district": "Noblesville Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180765001309",
    },
    {
        "school": "Noblesville East Middle School",
        "district": "Noblesville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180765001310",
    },
    {
        "school": "North Elementary School",
        "district": "Noblesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180765001311",
    },
    {
        "school": "Stony Creek Elementary School",
        "district": "Noblesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180765001312",
    },
    {
        "school": "Hinkle Creek Elementary School",
        "district": "Noblesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180765002158",
    },
    {
        "school": "Hazel Dell Elementary School",
        "district": "Noblesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180765002340",
    },
    {
        "school": "Hamilton SE Int and Jr High Sch",
        "district": "Hamilton Southeastern Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065000133",
    },
    {
        "school": "Lantern Road Elementary School",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065000373",
    },
    {
        "school": "Harrison Parkway Elementary School",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065000967",
    },
    {
        "school": "Fall Creek Intermediate School",
        "district": "Hamilton Southeastern Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065000970",
    },
    {
        "school": "Fishers Junior High School",
        "district": "Hamilton Southeastern Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065001245",
    },
    {
        "school": "Hoosier Road Elementary School",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065001560",
    },
    {
        "school": "Durbin Elementary School",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065001749",
    },
    {
        "school": "Fall Creek Elementary School",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065001750",
    },
    {
        "school": "Fishers Elementary School",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065001751",
    },
    {
        "school": "Hamilton Southeastern HS",
        "district": "Hamilton Southeastern Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065001752",
    },
    {
        "school": "Sand Creek Intermediate School",
        "district": "Hamilton Southeastern Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065001753",
    },
    {
        "school": "Cumberland Road Elem School",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065002168",
    },
    {
        "school": "New Britton Elementary School",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065002368",
    },
    {
        "school": "Shamrock Springs Elementary School",
        "district": "Westfield-Washington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181308000134",
    },
    {
        "school": "Westfield Intermediate School",
        "district": "Westfield-Washington Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181308000857",
    },
    {
        "school": "Carey Ridge Elementary School",
        "district": "Westfield-Washington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181308000977",
    },
    {
        "school": "Oak Trace Elementary School",
        "district": "Westfield-Washington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181308001392",
    },
    {
        "school": "Washington Woods Elementary School",
        "district": "Westfield-Washington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181308002073",
    },
    {
        "school": "Westfield Middle School",
        "district": "Westfield-Washington Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181308002074",
    },
    {
        "school": "Westfield High School",
        "district": "Westfield-Washington Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181308002075",
    },
    {
        "school": "Eastern Hancock Elementary School",
        "district": "Eastern Hancock Co Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180312000409",
    },
    {
        "school": "Eastern Hancock High School",
        "district": "Eastern Hancock Co Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180312000410",
    },
    {
        "school": "Eastern Hancock Middle School",
        "district": "Eastern Hancock Co Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180312000658",
    },
    {
        "school": "Eden Elementary School",
        "district": "Greenfield-Central Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180405000694",
    },
    {
        "school": "Greenfield Intermediate School",
        "district": "Greenfield-Central Com Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180405000695",
    },
    {
        "school": "Greenfield-Central High School",
        "district": "Greenfield-Central Com Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180405000696",
    },
    {
        "school": "Harris Elementary School",
        "district": "Greenfield-Central Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180405000697",
    },
    {
        "school": "Maxwell Intermediate School",
        "district": "Greenfield-Central Com Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180405000699",
    },
    {
        "school": "Weston Elementary School",
        "district": "Greenfield-Central Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180405000702",
    },
    {
        "school": "Mt Comfort Elementary School",
        "district": "Mt Vernon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180726001220",
    },
    {
        "school": "Mt Vernon High School",
        "district": "Mt Vernon Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180726001221",
    },
    {
        "school": "Mt Vernon Middle School",
        "district": "Mt Vernon Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180726001222",
    },
    {
        "school": "Fortville Elementary School",
        "district": "Mt Vernon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180726002152",
    },
    {
        "school": "Sugar Creek Elementary Sch",
        "district": "Southern Hancock Co Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181071001407",
    },
    {
        "school": "Brandywine Elementary School",
        "district": "Southern Hancock Co Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181071001758",
    },
    {
        "school": "New Palestine Jr High School",
        "district": "Southern Hancock Co Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181071001759",
    },
    {
        "school": "New Palestine Elementary School",
        "district": "Southern Hancock Co Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181071001760",
    },
    {
        "school": "New Palestine High School",
        "district": "Southern Hancock Co Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181071001761",
    },
    {
        "school": "Avon High School",
        "district": "Avon Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027000057",
    },
    {
        "school": "White Oak Elementary School",
        "district": "Avon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027000058",
    },
    {
        "school": "Maple Elementary School",
        "district": "Avon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027000059",
    },
    {
        "school": "Sycamore Elementary School",
        "district": "Avon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027000390",
    },
    {
        "school": "Avon Intermediate School East",
        "district": "Avon Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027001256",
    },
    {
        "school": "Avon Middle School South",
        "district": "Avon Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027002095",
    },
    {
        "school": "Pine Tree Elementary School",
        "district": "Avon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027002330",
    },
    {
        "school": "Eagle Elementary School",
        "district": "Brownsburg Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180102000045",
    },
    {
        "school": "Brownsburg High School",
        "district": "Brownsburg Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180102000176",
    },
    {
        "school": "Brownsburg West Middle School",
        "district": "Brownsburg Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180102000178",
    },
    {
        "school": "Brown Elementary School",
        "district": "Brownsburg Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180102000994",
    },
    {
        "school": "Delaware Trail Elementary School",
        "district": "Brownsburg Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180102001567",
    },
    {
        "school": "Cardinal Elementary School",
        "district": "Brownsburg Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180102001570",
    },
    {
        "school": "Danville Community High School",
        "district": "Danville Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180255000304",
    },
    {
        "school": "Danville Middle School",
        "district": "Danville Community School Corp",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180255000305",
    },
    {
        "school": "North Elementary School",
        "district": "Danville Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180255000306",
    },
    {
        "school": "South Elementary School",
        "district": "Danville Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180255000307",
    },
    {
        "school": "Cascade Middle School",
        "district": "Mill Creek Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180666001170",
    },
    {
        "school": "Cascade Senior High School",
        "district": "Mill Creek Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180666001171",
    },
    {
        "school": "Mill Creek East Elementary",
        "district": "Mill Creek Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180666001172",
    },
    {
        "school": "Mill Creek West Elementary",
        "district": "Mill Creek Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180666002248",
    },
    {
        "school": "North Salem Elementary School",
        "district": "North West Hendricks Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180810001385",
    },
    {
        "school": "Pittsboro Elementary School",
        "district": "North West Hendricks Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180810001386",
    },
    {
        "school": "Tri-West Senior High School",
        "district": "North West Hendricks Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180810001387",
    },
    {
        "school": "Brentwood Elementary School",
        "district": "Plainfield Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180897001492",
    },
    {
        "school": "Central Elementary School",
        "district": "Plainfield Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180897001493",
    },
    {
        "school": "Plainfield High School",
        "district": "Plainfield Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180897001494",
    },
    {
        "school": "Van Buren Elementary School",
        "district": "Plainfield Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180897001495",
    },
    {
        "school": "Plainfield Community Middle School",
        "district": "Plainfield Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180897002357",
    },
    {
        "school": "Center Grove Elementary School",
        "district": "Center Grove Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180144000208",
    },
    {
        "school": "Center Grove High School",
        "district": "Center Grove Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180144000209",
    },
    {
        "school": "Center Grove Middle School Central",
        "district": "Center Grove Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180144000210",
    },
    {
        "school": "North Grove Elementary School",
        "district": "Center Grove Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180144000211",
    },
    {
        "school": "Sugar Grove Elementary School",
        "district": "Center Grove Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180144000662",
    },
    {
        "school": "Maple Grove Elementary School",
        "district": "Center Grove Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180144002105",
    },
    {
        "school": "Pleasant Grove Elementary School",
        "district": "Center Grove Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180144002333",
    },
    {
        "school": "Central Nine Career Center",
        "district": "Central Nine Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180147002269",
    },
    {
        "school": "Break-O-Day Elementary School",
        "district": "Clark-Pleasant Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180189000243",
    },
    {
        "school": "Clark Elementary School",
        "district": "Clark-Pleasant Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180189000244",
    },
    {
        "school": "Clark Pleasant Middle School",
        "district": "Clark-Pleasant Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180189000245",
    },
    {
        "school": "Whiteland Community High School",
        "district": "Clark-Pleasant Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180189000246",
    },
    {
        "school": "Whiteland Elementary School",
        "district": "Clark-Pleasant Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180189000247",
    },
    {
        "school": "Sawmill Woods Elementary School",
        "district": "Clark-Pleasant Community Sch Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180189001028",
    },
    {
        "school": "Edinburgh Comm Middle School",
        "district": "Edinburgh Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180324000213",
    },
    {
        "school": "East Side Elementary School",
        "district": "Edinburgh Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180324000421",
    },
    {
        "school": "Edinburgh Community High School",
        "district": "Edinburgh Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180324000422",
    },
    {
        "school": "Franklin Community Middle School",
        "district": "Franklin Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180369000580",
    },
    {
        "school": "Franklin Community High School",
        "district": "Franklin Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180369000581",
    },
    {
        "school": "Needham Elementary School",
        "district": "Franklin Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180369000583",
    },
    {
        "school": "Northwood Elementary School",
        "district": "Franklin Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180369000584",
    },
    {
        "school": "Union Elementary School",
        "district": "Franklin Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180369000585",
    },
    {
        "school": "Webb Elementary School",
        "district": "Franklin Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180369000586",
    },
    {
        "school": "Creekside Elementary School",
        "district": "Franklin Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180369001030",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Greenwood Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180411000670",
    },
    {
        "school": "Greenwood Community High Sch",
        "district": "Greenwood Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180411000709",
    },
    {
        "school": "Greenwood Middle School",
        "district": "Greenwood Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180411000710",
    },
    {
        "school": "Greenwood Northeast Elementary Sch",
        "district": "Greenwood Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180411000711",
    },
    {
        "school": "Southwest Elementary School",
        "district": "Greenwood Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180411000712",
    },
    {
        "school": "V O Isom Central Elem School",
        "district": "Greenwood Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180411000713",
    },
    {
        "school": "Indian Creek Intermediate School",
        "district": "Nineveh-Hensley-Jackson United",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180762000064",
    },
    {
        "school": "Indian Creek Middle School",
        "district": "Nineveh-Hensley-Jackson United",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180762001302",
    },
    {
        "school": "Indian Creek Sr High School",
        "district": "Nineveh-Hensley-Jackson United",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180762001303",
    },
    {
        "school": "Indian Creek Elementary School",
        "district": "Nineveh-Hensley-Jackson United",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180762001306",
    },
    {
        "school": "Beech Grove Middle School",
        "district": "Beech Grove City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180045000092",
    },
    {
        "school": "Beech Grove Sr High School",
        "district": "Beech Grove City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180045000093",
    },
    {
        "school": "Central Elementary School",
        "district": "Beech Grove City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180045000094",
    },
    {
        "school": "South Grove Intermediate School",
        "district": "Beech Grove City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180045000095",
    },
    {
        "school": "Hornet Park Elementary School",
        "district": "Beech Grove City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180045000881",
    },
    {
        "school": "Decatur Central High School",
        "district": "M S D Decatur Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180264000312",
    },
    {
        "school": "Decatur Middle School",
        "district": "M S D Decatur Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180264000313",
    },
    {
        "school": "Stephen Decatur Elementary School",
        "district": "M S D Decatur Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180264000315",
    },
    {
        "school": "West Newton Elementary School",
        "district": "M S D Decatur Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180264000317",
    },
    {
        "school": "Liberty Early Elementary School",
        "district": "M S D Decatur Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180264001065",
    },
    {
        "school": "Valley Mills Elementary School",
        "district": "M S D Decatur Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180264002271",
    },
    {
        "school": "Acton Elementary School",
        "district": "Franklin Township Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180375000595",
    },
    {
        "school": "Bunker Hill Elementary School",
        "district": "Franklin Township Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180375000596",
    },
    {
        "school": "Franklin Central High School",
        "district": "Franklin Township Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180375000597",
    },
    {
        "school": "Franklin Township Middle Sch West",
        "district": "Franklin Township Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180375000598",
    },
    {
        "school": "Arlington Elementary School",
        "district": "Franklin Township Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180375002222",
    },
    {
        "school": "Mary Adams Elementary School",
        "district": "Franklin Township Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180375002349",
    },
    {
        "school": "Anna Brochhausen School 88",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000797",
    },
    {
        "school": "Arsenal Technical High School",
        "district": "Indianapolis Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000801",
    },
    {
        "school": "Brookside School 54",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000805",
    },
    {
        "school": "Carl Wilde School 79",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000808",
    },
    {
        "school": "Charles Warren Fairbanks Sch 105",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000811",
    },
    {
        "school": "Christian Park School 82",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000812",
    },
    {
        "school": "Cold Spring School",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000814",
    },
    {
        "school": "Crispus Attucks High School",
        "district": "Indianapolis Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000815",
    },
    {
        "school": "Daniel Webster School 46",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000817",
    },
    {
        "school": "Eleanor Skillen School 34",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000821",
    },
    {
        "school": "IPS/Butler Lab at Eliza Blaker 55",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000822",
    },
    {
        "school": "Ernie Pyle School 90",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000826",
    },
    {
        "school": "Floro Torrence School 83",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000829",
    },
    {
        "school": "Francis W Parker School 56",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000831",
    },
    {
        "school": "Francis Bellamy Pre-School Center",
        "district": "Indianapolis Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000833",
    },
    {
        "school": "Phalen at Francis Scott Key 103",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000834",
    },
    {
        "school": "George W Julian School 57",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000841",
    },
    {
        "school": "H L Harshman Middle School",
        "district": "Indianapolis Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000844",
    },
    {
        "school": "James Whitcomb Riley School 43",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000854",
    },
    {
        "school": "Jonathan Jennings School 109",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000858",
    },
    {
        "school": "Lew Wallace School 107",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000864",
    },
    {
        "school": "James A Garfield School 31",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000866",
    },
    {
        "school": "Louis B Russell Jr School 48",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000867",
    },
    {
        "school": "Edison School of the Arts 47",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000872",
    },
    {
        "school": "Meredith Nicholson School 96",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000873",
    },
    {
        "school": "Paul I Miller School 114",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000882",
    },
    {
        "school": "Ralph Waldo Emerson School 58",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000883",
    },
    {
        "school": "Raymond F Brandes School 65",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000884",
    },
    {
        "school": "Riverside School 44",
        "district": "Indianapolis Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000885",
    },
    {
        "school": "Robert Lee Frost School 106",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000887",
    },
    {
        "school": "Stephen Foster School 67",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000890",
    },
    {
        "school": "Theodore Potter School 74",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000893",
    },
    {
        "school": "Thomas D Gregg School 15",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000896",
    },
    {
        "school": "IPS/Butler Lab at William Bell 60",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000901",
    },
    {
        "school": "William McKinley School 39",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000903",
    },
    {
        "school": "William Penn School 49",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477000904",
    },
    {
        "school": "George S Buck School 94",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477001426",
    },
    {
        "school": "Arlington Woods School 99",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477001427",
    },
    {
        "school": "Center For Inquiry School 2",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477001440",
    },
    {
        "school": "George Washington High School",
        "district": "Indianapolis Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477001446",
    },
    {
        "school": "Shortridge High School",
        "district": "Indianapolis Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002238",
    },
    {
        "school": "Rousseau McClellan School 91",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002277",
    },
    {
        "school": "Fall Creek Valley Middle School",
        "district": "M S D Lawrence Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567000139",
    },
    {
        "school": "Forest Glen Elementary School",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567000150",
    },
    {
        "school": "McKenzie Career Center",
        "district": "M S D Lawrence Township",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180567000725",
    },
    {
        "school": "Belzer Middle School",
        "district": "M S D Lawrence Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567001023",
    },
    {
        "school": "Brook Park Elementary School",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567001024",
    },
    {
        "school": "Crestview Elementary School",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567001026",
    },
    {
        "school": "Harrison Hill Elementary School",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567001027",
    },
    {
        "school": "Lawrence Central High School",
        "district": "M S D Lawrence Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567001029",
    },
    {
        "school": "Lawrence North High School",
        "district": "M S D Lawrence Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567001031",
    },
    {
        "school": "Mary Evelyn Castle Elementary Sch",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567001032",
    },
    {
        "school": "Oaklandon Elementary School",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567001033",
    },
    {
        "school": "Skiles Test Elementary School",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567001034",
    },
    {
        "school": "Sunnyside Elementary School",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567001066",
    },
    {
        "school": "Indian Creek Elementary School",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567002278",
    },
    {
        "school": "Amy Beverland Elementary",
        "district": "M S D Lawrence Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180567002339",
    },
    {
        "school": "Abraham Lincoln Elementary School",
        "district": "Perry Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001455",
    },
    {
        "school": "Clinton Young Elementary School",
        "district": "Perry Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001456",
    },
    {
        "school": "Douglas MacArthur Elementary Sch",
        "district": "Perry Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001457",
    },
    {
        "school": "Glenns Valley Elementary School",
        "district": "Perry Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001459",
    },
    {
        "school": "Homecroft Elementary School",
        "district": "Perry Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001460",
    },
    {
        "school": "Southport Middle School",
        "district": "Perry Township Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001462",
    },
    {
        "school": "Perry Meridian Middle School",
        "district": "Perry Township Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001463",
    },
    {
        "school": "Perry Meridian High School",
        "district": "Perry Township Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001464",
    },
    {
        "school": "Southport Elementary School",
        "district": "Perry Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001466",
    },
    {
        "school": "Southport High School",
        "district": "Perry Township Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001467",
    },
    {
        "school": "William Henry Burkhart Elementary",
        "district": "Perry Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001469",
    },
    {
        "school": "Winchester Village Elementary",
        "district": "Perry Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882001470",
    },
    {
        "school": "Mary Bryan Elementary School",
        "district": "Perry Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180882002280",
    },
    {
        "school": "New Augusta Public Academy - North",
        "district": "M S D Pike Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891000513",
    },
    {
        "school": "Fishback Creek Public Academy",
        "district": "M S D Pike Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891001099",
    },
    {
        "school": "New Augusta Public Academy - South",
        "district": "M S D Pike Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891001275",
    },
    {
        "school": "Central Elementary School",
        "district": "M S D Pike Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891001484",
    },
    {
        "school": "Eastbrook Elementary School",
        "district": "M S D Pike Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891001485",
    },
    {
        "school": "Guion Creek Elementary School",
        "district": "M S D Pike Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891001486",
    },
    {
        "school": "Guion Creek Middle School",
        "district": "M S D Pike Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891001487",
    },
    {
        "school": "Lincoln Middle School",
        "district": "M S D Pike Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891001488",
    },
    {
        "school": "Pike High School",
        "district": "M S D Pike Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891001489",
    },
    {
        "school": "Snacks Crossing Elementary School",
        "district": "M S D Pike Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891001598",
    },
    {
        "school": "Eagle Creek Elementary School",
        "district": "M S D Pike Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891002250",
    },
    {
        "school": "College Park Elementary School",
        "district": "M S D Pike Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891002324",
    },
    {
        "school": "Deer Run Elementary",
        "district": "M S D Pike Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180891002374",
    },
    {
        "school": "Arthur C Newby Elementary School 2",
        "district": "School Town of Speedway",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181092001780",
    },
    {
        "school": "Carl G Fisher Elementary School 1",
        "district": "School Town of Speedway",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181092001781",
    },
    {
        "school": "Frank H Wheeler Elementary Sch 4",
        "district": "School Town of Speedway",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181092001782",
    },
    {
        "school": "James A Allison Elementary Sch 3",
        "district": "School Town of Speedway",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181092001783",
    },
    {
        "school": "Speedway Junior High School",
        "district": "School Town of Speedway",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181092001784",
    },
    {
        "school": "Speedway Senior High School",
        "district": "School Town of Speedway",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181092001785",
    },
    {
        "school": "Raymond Park Intermediate & Middle",
        "district": "M S D Warren Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236000229",
    },
    {
        "school": "Warren Early Childhood Center",
        "district": "M S D Warren Township",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236000726",
    },
    {
        "school": "Brookview Elementary School",
        "district": "M S D Warren Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001959",
    },
    {
        "school": "Creston Intermediate & Middle Schl",
        "district": "M S D Warren Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001961",
    },
    {
        "school": "Eastridge Elementary School",
        "district": "M S D Warren Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001962",
    },
    {
        "school": "Grassy Creek Elementary School",
        "district": "M S D Warren Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001963",
    },
    {
        "school": "Hawthorne Elementary School",
        "district": "M S D Warren Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001964",
    },
    {
        "school": "Lakeside Elementary School",
        "district": "M S D Warren Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001966",
    },
    {
        "school": "Lowell Elementary School",
        "district": "M S D Warren Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001967",
    },
    {
        "school": "Pleasant Run Elementary School",
        "district": "M S D Warren Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001969",
    },
    {
        "school": "Stonybrook Intermediate & Middle",
        "district": "M S D Warren Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001970",
    },
    {
        "school": "Sunny Heights Elementary School",
        "district": "M S D Warren Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001971",
    },
    {
        "school": "Walker Career Center",
        "district": "M S D Warren Township",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "181236001972",
    },
    {
        "school": "Warren Central High School",
        "district": "M S D Warren Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181236001973",
    },
    {
        "school": "Allisonville Elementary School",
        "district": "M S D Washington Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002010",
    },
    {
        "school": "Eastwood Middle School",
        "district": "M S D Washington Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002013",
    },
    {
        "school": "Greenbriar Elementary School",
        "district": "M S D Washington Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002016",
    },
    {
        "school": "J Everett Light Career Center",
        "district": "M S D Washington Township",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "181272002018",
    },
    {
        "school": "Nora Elementary School",
        "district": "M S D Washington Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002020",
    },
    {
        "school": "North Central High School",
        "district": "M S D Washington Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002021",
    },
    {
        "school": "Northview Middle School",
        "district": "M S D Washington Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002022",
    },
    {
        "school": "Spring Mill Elementary School",
        "district": "M S D Washington Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002023",
    },
    {
        "school": "Westlane Middle School",
        "district": "M S D Washington Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002024",
    },
    {
        "school": "Crooked Creek Elementary School",
        "district": "M S D Washington Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002255",
    },
    {
        "school": "Fox Hill Elementary School",
        "district": "M S D Washington Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002376",
    },
    {
        "school": "North Wayne Elementary School",
        "district": "M S D Wayne Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281000238",
    },
    {
        "school": "Ben Davis High School",
        "district": "M S D Wayne Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002028",
    },
    {
        "school": "Chapel Glen Elementary School",
        "district": "M S D Wayne Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002030",
    },
    {
        "school": "Chapelwood Elementary School",
        "district": "M S D Wayne Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002031",
    },
    {
        "school": "Chapel Hill 7th & 8th Grade Center",
        "district": "M S D Wayne Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002032",
    },
    {
        "school": "Garden City Elementary School",
        "district": "M S D Wayne Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002033",
    },
    {
        "school": "Maplewood Elementary School",
        "district": "M S D Wayne Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002034",
    },
    {
        "school": "McClelland Elementary School",
        "district": "M S D Wayne Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002035",
    },
    {
        "school": "Rhoades Elementary School",
        "district": "M S D Wayne Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002036",
    },
    {
        "school": "Robey Elementary School",
        "district": "M S D Wayne Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002037",
    },
    {
        "school": "Lynhurst 7th & 8th Grade Center",
        "district": "M S D Wayne Township",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002039",
    },
    {
        "school": "Stout Field Elementary School",
        "district": "M S D Wayne Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002040",
    },
    {
        "school": "Westlake Elementary School",
        "district": "M S D Wayne Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002042",
    },
    {
        "school": "Eminence Jr-Sr High School",
        "district": "Eminence Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180333000454",
    },
    {
        "school": "Eminence Elementary School",
        "district": "Eminence Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180333002274",
    },
    {
        "school": "Monrovia Elementary School",
        "district": "Monroe-Gregg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180414000715",
    },
    {
        "school": "Monrovia High School",
        "district": "Monroe-Gregg School District",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180414000716",
    },
    {
        "school": "Brooklyn STEM Academy",
        "district": "M S D Martinsville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180651001128",
    },
    {
        "school": "Centerton Elementary School",
        "district": "M S D Martinsville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180651001129",
    },
    {
        "school": "Charles L Smith Arts Academy",
        "district": "M S D Martinsville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180651001131",
    },
    {
        "school": "Green Township Elementary School",
        "district": "M S D Martinsville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180651001132",
    },
    {
        "school": "Martinsville High School",
        "district": "M S D Martinsville Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180651001135",
    },
    {
        "school": "Paragon Elementary School",
        "district": "M S D Martinsville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180651001138",
    },
    {
        "school": "Poston Road Elementary School",
        "district": "M S D Martinsville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180651001139",
    },
    {
        "school": "South Elementary School",
        "district": "M S D Martinsville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180651002355",
    },
    {
        "school": "Mooresville High School",
        "district": "Mooresville Con School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180714001207",
    },
    {
        "school": "Neil Armstrong Elementary School",
        "district": "Mooresville Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180714001208",
    },
    {
        "school": "Newby Memorial Elementary School",
        "district": "Mooresville Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180714001209",
    },
    {
        "school": "North Madison Elementary School",
        "district": "Mooresville Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180714001210",
    },
    {
        "school": "Northwood Elementary School",
        "district": "Mooresville Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180714001211",
    },
    {
        "school": "Paul Hadley Middle School",
        "district": "Mooresville Con School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180714001212",
    },
    {
        "school": "Waverly Elementary School",
        "district": "Mooresville Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180714001213",
    },
    {
        "school": "Blue River Career Ctr",
        "district": "Blue River Career Programs",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180000900115",
    },
    {
        "school": "Morristown Elementary School",
        "district": "Shelby Eastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180321000417",
    },
    {
        "school": "Morristown Jr-Sr High School",
        "district": "Shelby Eastern Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180321000418",
    },
    {
        "school": "Waldron Elementary School",
        "district": "Shelby Eastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180321000419",
    },
    {
        "school": "Waldron Jr-Sr High School",
        "district": "Shelby Eastern Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180321000420",
    },
    {
        "school": "Triton Central High School",
        "district": "Northwestern Con School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180831001423",
    },
    {
        "school": "Triton Central Elementary School",
        "district": "Northwestern Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180831001424",
    },
    {
        "school": "Triton Central Middle School",
        "district": "Northwestern Con School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180831001425",
    },
    {
        "school": "Coulston Elementary School",
        "district": "Shelbyville Central Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181014001627",
    },
    {
        "school": "Shelbyville Middle School",
        "district": "Shelbyville Central Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181014001630",
    },
    {
        "school": "Shelbyville Sr High School",
        "district": "Shelbyville Central Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181014001631",
    },
    {
        "school": "Thomas A Hendricks Elementary Sch",
        "district": "Shelbyville Central Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181014001632",
    },
    {
        "school": "William F Loper Elementary School",
        "district": "Shelbyville Central Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181014001633",
    },
    {
        "school": "Southwestern Elementary School",
        "district": "Southwestern Con Sch Shelby Co",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181083001768",
    },
    {
        "school": "Southwestern High School",
        "district": "Southwestern Con Sch Shelby Co",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181083001769",
    },
    {
        "school": "Fifth Street Elementary School",
        "district": "Greater Jasper Consolidated Schs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180396000683",
    },
    {
        "school": "Ireland Elementary School",
        "district": "Greater Jasper Consolidated Schs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180396000684",
    },
    {
        "school": "Jasper High School",
        "district": "Greater Jasper Consolidated Schs",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180396000685",
    },
    {
        "school": "Jasper Middle School",
        "district": "Greater Jasper Consolidated Schs",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180396000686",
    },
    {
        "school": "Tenth Street School",
        "district": "Greater Jasper Consolidated Schs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180396000687",
    },
    {
        "school": "Exceptional Children's Cooperative",
        "district": "Greater Jasper Consolidated Schs",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180396002132",
    },
    {
        "school": "Celestine Elementary School",
        "district": "Northeast Dubois Co Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180812001388",
    },
    {
        "school": "Dubois Elementary School",
        "district": "Northeast Dubois Co Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180812001390",
    },
    {
        "school": "Dubois Middle School",
        "district": "Northeast Dubois Co Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180812001391",
    },
    {
        "school": "Northeast Dubois High School",
        "district": "Northeast Dubois Co Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180812001393",
    },
    {
        "school": "Ferdinand Elementary School",
        "district": "Southeast Dubois Co Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181064001744",
    },
    {
        "school": "Forest Park Jr-Sr High School",
        "district": "Southeast Dubois Co Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181064001745",
    },
    {
        "school": "Pine Ridge Elementary School",
        "district": "Southeast Dubois Co Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181064001746",
    },
    {
        "school": "Huntingburg Elementary School",
        "district": "Southwest Dubois Co Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181087001236",
    },
    {
        "school": "Holland Elementary School",
        "district": "Southwest Dubois Co Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181087001776",
    },
    {
        "school": "Southridge Middle School",
        "district": "Southwest Dubois Co Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181087001777",
    },
    {
        "school": "Southridge High School",
        "district": "Southwest Dubois Co Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181087001779",
    },
    {
        "school": "Pike Central Middle School",
        "district": "Pike County School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180890000889",
    },
    {
        "school": "Petersburg Elementary School",
        "district": "Pike County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180890001481",
    },
    {
        "school": "Pike Central High School",
        "district": "Pike County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180890001482",
    },
    {
        "school": "Winslow Elementary School",
        "district": "Pike County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180890001483",
    },
    {
        "school": "Central Noble Elementary School",
        "district": "Central Noble Com School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180171000228",
    },
    {
        "school": "Central Noble Junior Senior HS",
        "district": "Central Noble Com School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180171000230",
    },
    {
        "school": "Central Noble Primary School",
        "district": "Central Noble Com School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180171000231",
    },
    {
        "school": "Avilla Elementary School",
        "district": "East Noble School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180297000387",
    },
    {
        "school": "East Noble High School",
        "district": "East Noble School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180297000389",
    },
    {
        "school": "North Side Elementary School",
        "district": "East Noble School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180297000392",
    },
    {
        "school": "Rome City Elementary School",
        "district": "East Noble School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180297000393",
    },
    {
        "school": "Wayne Center Elem School",
        "district": "East Noble School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180297000394",
    },
    {
        "school": "South Side Elementary School",
        "district": "East Noble School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180297000888",
    },
    {
        "school": "East Noble Middle School",
        "district": "East Noble School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180297002335",
    },
    {
        "school": "West Noble Primary School",
        "district": "West Noble School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181290002055",
    },
    {
        "school": "West Noble High School",
        "district": "West Noble School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181290002058",
    },
    {
        "school": "West Noble Middle School",
        "district": "West Noble School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181290002059",
    },
    {
        "school": "West Noble Elementary School",
        "district": "West Noble School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181290002231",
    },
    {
        "school": "Howard Elementary School",
        "district": "Northwestern School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180204000253",
    },
    {
        "school": "Northwestern Elementary School",
        "district": "Northwestern School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180204000254",
    },
    {
        "school": "Northwestern Senior High School",
        "district": "Northwestern School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180204000255",
    },
    {
        "school": "Northwestern Middle School",
        "district": "Northwestern School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180204002334",
    },
    {
        "school": "Eastern Elementary School",
        "district": "Eastern Howard School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180315000412",
    },
    {
        "school": "Eastern High School",
        "district": "Eastern Howard School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180315000413",
    },
    {
        "school": "Western Primary School",
        "district": "Western School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180447000755",
    },
    {
        "school": "Western High School",
        "district": "Western School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180447000756",
    },
    {
        "school": "Western Intermediate School",
        "district": "Western School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180447002224",
    },
    {
        "school": "Western Middle School",
        "district": "Western School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180447002225",
    },
    {
        "school": "Bon Air Elementary School",
        "district": "Kokomo School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180537000942",
    },
    {
        "school": "Boulevard Elementary School",
        "district": "Kokomo School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180537000943",
    },
    {
        "school": "Elwood Haynes Elementary School",
        "district": "Kokomo School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180537000946",
    },
    {
        "school": "Kokomo High School",
        "district": "Kokomo School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180537000947",
    },
    {
        "school": "Lafayette Park Elementary School",
        "district": "Kokomo School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180537000950",
    },
    {
        "school": "Pettit Park School",
        "district": "Kokomo School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180537000956",
    },
    {
        "school": "Sycamore Elementary School",
        "district": "Kokomo School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180537000959",
    },
    {
        "school": "Wallace Elementary School",
        "district": "Kokomo School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180537000960",
    },
    {
        "school": "Bon Air Middle School",
        "district": "Kokomo School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180537000995",
    },
    {
        "school": "Central Middle School",
        "district": "Kokomo School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180537000998",
    },
    {
        "school": "Maple Crest Middle School",
        "district": "Kokomo School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180537001018",
    },
    {
        "school": "Kokomo Area Career Center",
        "district": "Kokomo School Corporation",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180537002239",
    },
    {
        "school": "Taylor Middle School",
        "district": "Taylor Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181125001263",
    },
    {
        "school": "Taylor Elementary School",
        "district": "Taylor Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181125001812",
    },
    {
        "school": "Taylor High School",
        "district": "Taylor Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181125001814",
    },
    {
        "school": "Tri Central Middle-High School",
        "district": "Tri-Central Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180804001379",
    },
    {
        "school": "Tri Central Elementary",
        "district": "Tri-Central Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180804002227",
    },
    {
        "school": "Tipton Middle School",
        "district": "Tipton Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181140001842",
    },
    {
        "school": "Tipton High School",
        "district": "Tipton Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181140001843",
    },
    {
        "school": "Tipton Elementary School",
        "district": "Tipton Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181140001844",
    },
    {
        "school": "Wea Ridge Middle School",
        "district": "Tippecanoe School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001920",
    },
    {
        "school": "Benton Central Jr-Sr High School",
        "district": "Benton Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180048000097",
    },
    {
        "school": "Boswell Elementary School",
        "district": "Benton Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180048000098",
    },
    {
        "school": "Otterbein Elementary School",
        "district": "Benton Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180048000100",
    },
    {
        "school": "Carroll Senior High School",
        "district": "Carroll Consolidated School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180129000203",
    },
    {
        "school": "Carroll Elementary School",
        "district": "Carroll Consolidated School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180129002103",
    },
    {
        "school": "Delphi Community High School",
        "district": "Delphi Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180270000326",
    },
    {
        "school": "Delphi Community Middle School",
        "district": "Delphi Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180270000327",
    },
    {
        "school": "Delphi Community Elementary School",
        "district": "Delphi Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180270000328",
    },
    {
        "school": "Amelia Earhart Elementary School",
        "district": "Lafayette School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540000545",
    },
    {
        "school": "Edgelea Elementary School",
        "district": "Lafayette School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540000963",
    },
    {
        "school": "Glen Acres Elementary School",
        "district": "Lafayette School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540000965",
    },
    {
        "school": "Greater Lafayette Area SE",
        "district": "Lafayette School Corporation",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180540000966",
    },
    {
        "school": "Jefferson High School",
        "district": "Lafayette School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540000968",
    },
    {
        "school": "Miami Elementary School",
        "district": "Lafayette School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540000971",
    },
    {
        "school": "Murdock Elementary School",
        "district": "Lafayette School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540000972",
    },
    {
        "school": "Lafayette Sunnyside Intermediate",
        "district": "Lafayette School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540000974",
    },
    {
        "school": "Lafayette Tecumseh Jr High School",
        "district": "Lafayette School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540000975",
    },
    {
        "school": "Thomas Miller Elementary School",
        "district": "Lafayette School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540000976",
    },
    {
        "school": "Vinton Elementary School",
        "district": "Lafayette School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540000978",
    },
    {
        "school": "Burnett Creek Elementary School",
        "district": "Tippecanoe School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001304",
    },
    {
        "school": "Wea Ridge Elementary School",
        "district": "Tippecanoe School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001305",
    },
    {
        "school": "Battle Ground Elementary School",
        "district": "Tippecanoe School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001821",
    },
    {
        "school": "Battle Ground Middle School",
        "district": "Tippecanoe School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001822",
    },
    {
        "school": "Dayton Elementary School",
        "district": "Tippecanoe School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001824",
    },
    {
        "school": "East Tipp Middle School",
        "district": "Tippecanoe School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001825",
    },
    {
        "school": "Hershey Elementary School",
        "district": "Tippecanoe School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001826",
    },
    {
        "school": "Klondike Elementary School",
        "district": "Tippecanoe School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001827",
    },
    {
        "school": "Klondike Middle School",
        "district": "Tippecanoe School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001828",
    },
    {
        "school": "Mayflower Mill Elementary School",
        "district": "Tippecanoe School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001829",
    },
    {
        "school": "McCutcheon High School",
        "district": "Tippecanoe School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001830",
    },
    {
        "school": "Mintonye Elementary School",
        "district": "Tippecanoe School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001831",
    },
    {
        "school": "Southwestern Middle School",
        "district": "Tippecanoe School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001832",
    },
    {
        "school": "Wainwright Middle School",
        "district": "Tippecanoe School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001833",
    },
    {
        "school": "William Henry Harrison High School",
        "district": "Tippecanoe School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134001835",
    },
    {
        "school": "James Cole Elementary School",
        "district": "Tippecanoe School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134002326",
    },
    {
        "school": "West Lafayette Elementary School",
        "district": "West Lafayette Com School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181287002043",
    },
    {
        "school": "West Lafayette Intermediate School",
        "district": "West Lafayette Com School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181287002045",
    },
    {
        "school": "West Lafayette Jr/Sr High School",
        "district": "West Lafayette Com School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181287002048",
    },
    {
        "school": "Columbia Elementary School",
        "district": "Logansport Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180603001051",
    },
    {
        "school": "Columbia 6th Grade Academy",
        "district": "Logansport Community Sch Corp",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180603001052",
    },
    {
        "school": "Century Career Center",
        "district": "Logansport Community Sch Corp",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180603001054",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Logansport Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180603001055",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Logansport Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180603001056",
    },
    {
        "school": "Logansport Junior High School",
        "district": "Logansport Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180603001058",
    },
    {
        "school": "Logansport Area Jnt Spec Ed",
        "district": "Logansport Community Sch Corp",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180603001059",
    },
    {
        "school": "Logansport Community High School",
        "district": "Logansport Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180603001060",
    },
    {
        "school": "Landis Elementary School",
        "district": "Logansport Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180603002366",
    },
    {
        "school": "Pioneer Elementary School",
        "district": "Pioneer Regional School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180894001490",
    },
    {
        "school": "Pioneer Jr-Sr High School",
        "district": "Pioneer Regional School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180894001491",
    },
    {
        "school": "Lewis Cass High School",
        "district": "Lewis Cass Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181068001755",
    },
    {
        "school": "Lewis Cass Elementary School",
        "district": "Lewis Cass Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181068002169",
    },
    {
        "school": "Community Montessori",
        "district": "Community Montessori Inc",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180001101737",
    },
    {
        "school": "Highland Hills Middle School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741002057",
    },
    {
        "school": "East Washington Middle School",
        "district": "East Washington School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180300000073",
    },
    {
        "school": "Eastern High School",
        "district": "East Washington School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180300000395",
    },
    {
        "school": "East Washington Elementary School",
        "district": "East Washington School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180300002195",
    },
    {
        "school": "Bradie Shrum Elementary",
        "district": "Salem Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180981000357",
    },
    {
        "school": "Salem High School",
        "district": "Salem Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180981001600",
    },
    {
        "school": "Salem Middle School",
        "district": "Salem Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180981001601",
    },
    {
        "school": "West Washington Elementary School",
        "district": "West Washington School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181293002062",
    },
    {
        "school": "West Washington Jr-Sr High School",
        "district": "West Washington School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181293002063",
    },
    {
        "school": "Clarksville Middle School",
        "district": "Clarksville Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180192000248",
    },
    {
        "school": "Clarksville Senior High School",
        "district": "Clarksville Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180192000249",
    },
    {
        "school": "Clarksville Elementary School",
        "district": "Clarksville Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180192000251",
    },
    {
        "school": "Charlestown Senior High School",
        "district": "Greater Clark County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000663",
    },
    {
        "school": "Bridgepoint Elementary School",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000665",
    },
    {
        "school": "Jeffersonville High School",
        "district": "Greater Clark County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000666",
    },
    {
        "school": "Jonathan Jennings Elementary Sch",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000667",
    },
    {
        "school": "Maple Elementary School",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000668",
    },
    {
        "school": "New Washington Elementary School",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000671",
    },
    {
        "school": "New Washington Middle/High School",
        "district": "Greater Clark County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000672",
    },
    {
        "school": "Northaven Elementary School",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000673",
    },
    {
        "school": "Parkview Middle School",
        "district": "Greater Clark County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000674",
    },
    {
        "school": "Parkwood Elementary School",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000675",
    },
    {
        "school": "Pleasant Ridge Elementary School",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000676",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000677",
    },
    {
        "school": "Spring Hill Elementary School",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000679",
    },
    {
        "school": "Thomas Jefferson Elementary School",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000680",
    },
    {
        "school": "Utica Elementary School",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000681",
    },
    {
        "school": "W E Wilson Elementary",
        "district": "Greater Clark County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394000682",
    },
    {
        "school": "Old Corden Porter School",
        "district": "Greater Clark County Schools",
        "level": "High",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180394000832",
    },
    {
        "school": "Clark County Middle/High School",
        "district": "Greater Clark County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IN",
        "nces_id": "180394000839",
    },
    {
        "school": "Charlestown Middle School",
        "district": "Greater Clark County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394002128",
    },
    {
        "school": "River Valley Middle School",
        "district": "Greater Clark County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180394002131",
    },
    {
        "school": "Floyds Knobs Elementary School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741000852",
    },
    {
        "school": "Prosser Career Education Center",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180741001262",
    },
    {
        "school": "Fairmont Elementary School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741001264",
    },
    {
        "school": "Floyd Central High School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741001265",
    },
    {
        "school": "Georgetown Elementary School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741001267",
    },
    {
        "school": "Grant Line Elementary School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741001268",
    },
    {
        "school": "Green Valley Elementary School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741001269",
    },
    {
        "school": "Greenville Elementary School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741001270",
    },
    {
        "school": "Hazelwood Middle School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741001271",
    },
    {
        "school": "Nathaniel Scribner Middle School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741001276",
    },
    {
        "school": "New Albany Senior High School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741001277",
    },
    {
        "school": "S Ellen Jones Elementary School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741001278",
    },
    {
        "school": "Slate Run Elementary School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741001281",
    },
    {
        "school": "Mount Tabor Elementary School",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741002204",
    },
    {
        "school": "Morgan Elementary School",
        "district": "North Harrison Com School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180069000142",
    },
    {
        "school": "North Harrison Elementary School",
        "district": "North Harrison Com School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180069000143",
    },
    {
        "school": "North Harrison High School",
        "district": "North Harrison Com School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180069000144",
    },
    {
        "school": "North Harrison Middle School",
        "district": "North Harrison Com School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180069000145",
    },
    {
        "school": "Lanesville Elementary School",
        "district": "Lanesville Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180372000592",
    },
    {
        "school": "Lanesville Jr-Sr HS",
        "district": "Lanesville Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180372000593",
    },
    {
        "school": "Corydon Intermediate School",
        "district": "South Harrison Com Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181036000385",
    },
    {
        "school": "Corydon Elementary School",
        "district": "South Harrison Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181036001693",
    },
    {
        "school": "Heth-Washington Elementary School",
        "district": "South Harrison Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181036001696",
    },
    {
        "school": "New Middletown Elementary School",
        "district": "South Harrison Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181036001698",
    },
    {
        "school": "Harrison County Spec Ed Coop",
        "district": "South Harrison Com Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "181036002098",
    },
    {
        "school": "Corydon Central High School",
        "district": "South Harrison Com Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181036002282",
    },
    {
        "school": "Corydon Central Jr High School",
        "district": "South Harrison Com Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181036002283",
    },
    {
        "school": "South Central Elementary",
        "district": "South Harrison Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181036002284",
    },
    {
        "school": "South Central Jr & Sr High School",
        "district": "South Harrison Com Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181036002285",
    },
    {
        "school": "Deputy Elementary School",
        "district": "Madison Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180612001085",
    },
    {
        "school": "Anderson Elementary School",
        "district": "Madison Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180612001088",
    },
    {
        "school": "Lydia Middleton Elementary School",
        "district": "Madison Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180612001089",
    },
    {
        "school": "Madison Consolidated High School",
        "district": "Madison Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180612001090",
    },
    {
        "school": "Madison Consolidated Jr High Sch",
        "district": "Madison Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180612001091",
    },
    {
        "school": "Rykers' Ridge Elementary School",
        "district": "Madison Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180612001093",
    },
    {
        "school": "Southwestern Elementary School",
        "district": "Southwestern-Jefferson Co Con",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181080001766",
    },
    {
        "school": "Southwestern High School",
        "district": "Southwestern-Jefferson Co Con",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181080001767",
    },
    {
        "school": "Eastbrook High School",
        "district": "Eastbrook Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180303000399",
    },
    {
        "school": "Eastbrook Junior High School",
        "district": "Eastbrook Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180303002273",
    },
    {
        "school": "Allen Elementary School",
        "district": "Marion Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180639001107",
    },
    {
        "school": "Frances Slocum Elem School",
        "district": "Marion Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180639001110",
    },
    {
        "school": "John L McCulloch Junior High Sch",
        "district": "Marion Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180639001112",
    },
    {
        "school": "John W Kendall Elem School",
        "district": "Marion Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180639001113",
    },
    {
        "school": "Justice Thurgood Marshall Intrmd",
        "district": "Marion Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180639001115",
    },
    {
        "school": "Marion High School",
        "district": "Marion Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180639001117",
    },
    {
        "school": "Riverview Elementary School",
        "district": "Marion Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180639001119",
    },
    {
        "school": "Marion Regional Career Center",
        "district": "Marion Community Schools",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180639002150",
    },
    {
        "school": "Mississinewa High School",
        "district": "Mississinewa Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180687001189",
    },
    {
        "school": "R J Baskett Middle School",
        "district": "Mississinewa Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180687001190",
    },
    {
        "school": "Northview Elementary School",
        "district": "Mississinewa Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180687001191",
    },
    {
        "school": "Westview Elementary School",
        "district": "Mississinewa Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180687001193",
    },
    {
        "school": "Oak Hill High School",
        "district": "Oak Hill United School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180834001429",
    },
    {
        "school": "Oak Hill Junior High School",
        "district": "Oak Hill United School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180834001430",
    },
    {
        "school": "Swayzee Elementary School",
        "district": "Oak Hill United School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180834001431",
    },
    {
        "school": "Sweetser Elementary School",
        "district": "Oak Hill United School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180834001432",
    },
    {
        "school": "Converse Elementary School",
        "district": "Oak Hill United School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180834001428",
    },
    {
        "school": "Madison-Grant Jr./Sr. High School",
        "district": "Madison-Grant United School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180624001097",
    },
    {
        "school": "Park Elementary School",
        "district": "Madison-Grant United School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180624001098",
    },
    {
        "school": "Summitville School",
        "district": "Madison-Grant United School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180624001100",
    },
    {
        "school": "South Central Elementary School",
        "district": "South Central Com School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180219000262",
    },
    {
        "school": "South Central Jr-Sr High School",
        "district": "South Central Com School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180219000263",
    },
    {
        "school": "F Willard Crichfield Elementary",
        "district": "LaPorte Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180558001009",
    },
    {
        "school": "Hailmann Elementary School",
        "district": "LaPorte Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180558001010",
    },
    {
        "school": "Handley Elementary School",
        "district": "LaPorte Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180558001011",
    },
    {
        "school": "Kesling Intermediate School",
        "district": "LaPorte Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180558001012",
    },
    {
        "school": "Kingsbury Elementary School",
        "district": "LaPorte Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180558001013",
    },
    {
        "school": "Kingsford Heights Elementary Sch",
        "district": "LaPorte Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180558001014",
    },
    {
        "school": "LaPorte High School",
        "district": "LaPorte Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180558001015",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "LaPorte Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180558001016",
    },
    {
        "school": "Riley Elementary School",
        "district": "LaPorte Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180558001020",
    },
    {
        "school": "Indian Trail Elementary School",
        "district": "LaPorte Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180558002338",
    },
    {
        "school": "Westville Elementary School",
        "district": "M S D of New Durham Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180747001293",
    },
    {
        "school": "Westville High School",
        "district": "M S D of New Durham Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180747001294",
    },
    {
        "school": "A K Smith Area Career Center",
        "district": "Michigan City Area Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180657000433",
    },
    {
        "school": "Barker Middle School",
        "district": "Michigan City Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001140",
    },
    {
        "school": "Coolspring Elementary School",
        "district": "Michigan City Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001143",
    },
    {
        "school": "Edgewood Elementary School",
        "district": "Michigan City Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001145",
    },
    {
        "school": "Joy Elementary School",
        "district": "Michigan City Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001150",
    },
    {
        "school": "Knapp Elementary School",
        "district": "Michigan City Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001151",
    },
    {
        "school": "Marsh Elementary School",
        "district": "Michigan City Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001153",
    },
    {
        "school": "Martin T Krueger Middle School",
        "district": "Michigan City Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001154",
    },
    {
        "school": "Lake Hills Elementary School",
        "district": "Michigan City Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001155",
    },
    {
        "school": "Niemann Elementary School",
        "district": "Michigan City Area Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001156",
    },
    {
        "school": "Michigan City High School",
        "district": "Michigan City Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001160",
    },
    {
        "school": "Springfield Elementary School",
        "district": "Michigan City Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001161",
    },
    {
        "school": "Pine Elementary School",
        "district": "Michigan City Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180657001158",
    },
    {
        "school": "Burris Laboratory School",
        "district": "Burris Laboratory School",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180003800185",
    },
    {
        "school": "Indiana Academy for Sci Math Hmn",
        "district": "Indiana Academy for Sci Math Hmn",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180004102348",
    },
    {
        "school": "Albany Elementary School",
        "district": "Delaware Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180266000318",
    },
    {
        "school": "Delta High School",
        "district": "Delaware Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180266000320",
    },
    {
        "school": "Eaton Elementary School",
        "district": "Delaware Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180266000322",
    },
    {
        "school": "Delta Middle School",
        "district": "Delaware Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180266000323",
    },
    {
        "school": "Royerton Elementary School",
        "district": "Delaware Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180266000324",
    },
    {
        "school": "Wes-Del Elementary School",
        "district": "Wes-Del Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180450000758",
    },
    {
        "school": "Wes-Del Middle/Senior High School",
        "district": "Wes-Del Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180450000761",
    },
    {
        "school": "Selma Elementary School",
        "district": "Liberty-Perry Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180588001045",
    },
    {
        "school": "Selma Middle School",
        "district": "Liberty-Perry Community Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180588001046",
    },
    {
        "school": "Wapahani High School",
        "district": "Liberty-Perry Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180588001047",
    },
    {
        "school": "Cowan Elementary School",
        "district": "Cowan Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180702001199",
    },
    {
        "school": "Cowan High School",
        "district": "Cowan Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180702001200",
    },
    {
        "school": "Pleasant View Elementary School",
        "district": "Yorktown Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180723001215",
    },
    {
        "school": "Yorktown Elementary School",
        "district": "Yorktown Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180723001216",
    },
    {
        "school": "Yorktown High School",
        "district": "Yorktown Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180723001217",
    },
    {
        "school": "Yorktown Middle School",
        "district": "Yorktown Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180723001218",
    },
    {
        "school": "Youth Opportunity Center",
        "district": "Muncie Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IN",
        "nces_id": "180732001232",
    },
    {
        "school": "Grissom Elementary School",
        "district": "Muncie Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180732001235",
    },
    {
        "school": "Longfellow Elementary School",
        "district": "Muncie Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180732001237",
    },
    {
        "school": "Muncie Area Career Center",
        "district": "Muncie Community Schools",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180732001241",
    },
    {
        "school": "Muncie Central High School",
        "district": "Muncie Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180732001242",
    },
    {
        "school": "North View Elementary School",
        "district": "Muncie Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180732001243",
    },
    {
        "school": "West View Elementary School",
        "district": "Muncie Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180732001251",
    },
    {
        "school": "Southside Middle School",
        "district": "Muncie Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180732001252",
    },
    {
        "school": "South View Elementary School",
        "district": "Muncie Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180732002153",
    },
    {
        "school": "Northside Middle School",
        "district": "Muncie Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180732002320",
    },
    {
        "school": "Daleville Elementary School",
        "district": "Daleville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180984001602",
    },
    {
        "school": "Daleville Jr-Sr High School",
        "district": "Daleville Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180984001603",
    },
    {
        "school": "Knightstown Intermediate School",
        "district": "C A Beard Memorial School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180106002012",
    },
    {
        "school": "Blue River Valley Elementary Sch",
        "district": "Blue River Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180066000140",
    },
    {
        "school": "Blue River Valley Jr-Sr High Sch",
        "district": "Blue River Valley Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180066000141",
    },
    {
        "school": "Knightstown High School",
        "district": "C A Beard Memorial School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180106000189",
    },
    {
        "school": "Knightstown Elementary School",
        "district": "C A Beard Memorial School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180106002290",
    },
    {
        "school": "James Whitcomb Riley Elem School",
        "district": "New Castle Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180744001286",
    },
    {
        "school": "New Castle Middle School",
        "district": "New Castle Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180744001288",
    },
    {
        "school": "Sunnyside Elementary School",
        "district": "New Castle Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180744001289",
    },
    {
        "school": "New Castle High School",
        "district": "New Castle Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180744001290",
    },
    {
        "school": "Westwood Elementary School",
        "district": "New Castle Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180744001291",
    },
    {
        "school": "Wilbur Wright Elementary School",
        "district": "New Castle Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180744001292",
    },
    {
        "school": "Eastwood Elementary School",
        "district": "New Castle Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180744002156",
    },
    {
        "school": "Parker Elementary School",
        "district": "New Castle Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180744002157",
    },
    {
        "school": "Shenandoah High School",
        "district": "Shenandoah School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180828001420",
    },
    {
        "school": "Shenandoah Middle School",
        "district": "Shenandoah School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180828001421",
    },
    {
        "school": "Shenandoah Elementary School",
        "district": "Shenandoah School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180828002356",
    },
    {
        "school": "Tri Junior-Senior High School",
        "district": "South Henry School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181038001702",
    },
    {
        "school": "Tri-Elementary School",
        "district": "South Henry School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181038001703",
    },
    {
        "school": "Graham Creek Elementary School",
        "district": "Jennings County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180519000921",
    },
    {
        "school": "Hayden Elementary School",
        "district": "Jennings County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180519000922",
    },
    {
        "school": "Jennings County High School",
        "district": "Jennings County School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180519000923",
    },
    {
        "school": "North Vernon Elementary School",
        "district": "Jennings County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180519000924",
    },
    {
        "school": "Jennings County Middle School",
        "district": "Jennings County School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180519000925",
    },
    {
        "school": "Scipio Elementary School",
        "district": "Jennings County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180519000927",
    },
    {
        "school": "Brush Creek Elementary School",
        "district": "Jennings County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180519000928",
    },
    {
        "school": "Sand Creek Elementary School",
        "district": "Jennings County School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180519001417",
    },
    {
        "school": "Maconaquah Elementary School",
        "district": "Maconaquah School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180609001077",
    },
    {
        "school": "Maconaquah High School",
        "district": "Maconaquah School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180609001078",
    },
    {
        "school": "Maconaquah Middle School",
        "district": "Maconaquah School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180609001079",
    },
    {
        "school": "Pipe Creek Elementary School",
        "district": "Maconaquah School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180609002318",
    },
    {
        "school": "North Miami Elementary School",
        "district": "North Miami Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180789001350",
    },
    {
        "school": "North Miami Middle/High School",
        "district": "North Miami Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180789001351",
    },
    {
        "school": "Blair Pointe Upper Elementary",
        "district": "Peru Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180885001471",
    },
    {
        "school": "Elmwood Primary Learning Center",
        "district": "Peru Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180885001472",
    },
    {
        "school": "Peru High School",
        "district": "Peru Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180885001476",
    },
    {
        "school": "Peru Junior High School",
        "district": "Peru Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180885001477",
    },
    {
        "school": "Argos Community Elementary",
        "district": "Argos Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180018000047",
    },
    {
        "school": "Argos Comm Jr-Sr High School",
        "district": "Argos Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180018000048",
    },
    {
        "school": "Bremen Elementary/Middle School",
        "district": "Bremen Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180090000166",
    },
    {
        "school": "Bremen Senior High School",
        "district": "Bremen Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180090000168",
    },
    {
        "school": "Culver Community Middle/High Sch",
        "district": "Culver Community Schools Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180252000301",
    },
    {
        "school": "Culver Elementary School",
        "district": "Culver Community Schools Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180252000302",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Plymouth Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180906001498",
    },
    {
        "school": "Lincoln Junior High School",
        "district": "Plymouth Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180906001499",
    },
    {
        "school": "Plymouth High School",
        "district": "Plymouth Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180906001500",
    },
    {
        "school": "Washington Discovery Academy",
        "district": "Plymouth Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180906001501",
    },
    {
        "school": "Webster Elementary School",
        "district": "Plymouth Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180906001502",
    },
    {
        "school": "Menominee Elementary School",
        "district": "Plymouth Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180906001503",
    },
    {
        "school": "Triton Elementary School",
        "district": "Triton School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181149001855",
    },
    {
        "school": "Triton Jr-Sr High School",
        "district": "Triton School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181149001856",
    },
    {
        "school": "LaVille Elementary School",
        "district": "Union-North United School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181191002242",
    },
    {
        "school": "LaVille Jr-Sr High School",
        "district": "Union-North United School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181191001879",
    },
    {
        "school": "Centerville-Abington Elem School",
        "district": "Centerville-Abington Com Schs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180156000215",
    },
    {
        "school": "Centerville-Abington Jr High Sch",
        "district": "Centerville-Abington Com Schs",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180156000216",
    },
    {
        "school": "Centerville Sr High School",
        "district": "Centerville-Abington Com Schs",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180156000217",
    },
    {
        "school": "Rose Hamilton Elementary School",
        "district": "Centerville-Abington Com Schs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180156000218",
    },
    {
        "school": "Hagerstown Elementary School",
        "district": "Nettle Creek School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180738001260",
    },
    {
        "school": "Hagerstown Jr-Sr High School",
        "district": "Nettle Creek School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180738001261",
    },
    {
        "school": "Northeastern High School",
        "district": "Northeastern Wayne Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180819001406",
    },
    {
        "school": "Northeastern Elementary School",
        "district": "Northeastern Wayne Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180819002228",
    },
    {
        "school": "Community Youth Services",
        "district": "Richmond Community Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180951000366",
    },
    {
        "school": "Charles Elementary School",
        "district": "Richmond Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180951001553",
    },
    {
        "school": "Crestdale Elementary School",
        "district": "Richmond Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180951001554",
    },
    {
        "school": "Dennis Intermediate School",
        "district": "Richmond Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180951001555",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Richmond Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180951001556",
    },
    {
        "school": "Test Intermediate School",
        "district": "Richmond Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180951001561",
    },
    {
        "school": "Richmond High School",
        "district": "Richmond Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180951001566",
    },
    {
        "school": "Vaile Elementary School",
        "district": "Richmond Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180951001569",
    },
    {
        "school": "Westview Elementary School",
        "district": "Richmond Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180951001571",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Western Wayne Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181305000561",
    },
    {
        "school": "Western Wayne Elementary School",
        "district": "Western Wayne Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181305000807",
    },
    {
        "school": "Lincoln Sr High School",
        "district": "Western Wayne Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181305002069",
    },
    {
        "school": "Austin Elementary School",
        "district": "Scott County School District 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180999001604",
    },
    {
        "school": "Austin High School",
        "district": "Scott County School District 1",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180999001605",
    },
    {
        "school": "Austin Middle School",
        "district": "Scott County School District 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180999001606",
    },
    {
        "school": "Scottsburg Elem School",
        "district": "Scott County School District 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181002001608",
    },
    {
        "school": "Johnson Elementary School",
        "district": "Scott County School District 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181002001609",
    },
    {
        "school": "Lexington Elementary School",
        "district": "Scott County School District 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181002001610",
    },
    {
        "school": "Scottsburg Middle School",
        "district": "Scott County School District 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181002001611",
    },
    {
        "school": "Scottsburg Senior High School",
        "district": "Scott County School District 2",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181002001612",
    },
    {
        "school": "Vienna-Finley Elementary School",
        "district": "Scott County School District 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181002001614",
    },
    {
        "school": "Brownstown Central High School",
        "district": "Brownstown Cnt Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180105000180",
    },
    {
        "school": "Brownstown Central Middle School",
        "district": "Brownstown Cnt Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180105000181",
    },
    {
        "school": "Brownstown Elementary School",
        "district": "Brownstown Cnt Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180105000182",
    },
    {
        "school": "Medora Jr & Sr High School",
        "district": "Medora Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180123000201",
    },
    {
        "school": "Medora Elementary School",
        "district": "Medora Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180123002268",
    },
    {
        "school": "Cortland Elementary School",
        "district": "Seymour Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181008001615",
    },
    {
        "school": "Emerson Elementary School",
        "district": "Seymour Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181008001616",
    },
    {
        "school": "Margaret R Brown Elementary School",
        "district": "Seymour Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181008001617",
    },
    {
        "school": "Seymour Senior High School",
        "district": "Seymour Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181008001618",
    },
    {
        "school": "Seymour-Jackson Elementary School",
        "district": "Seymour Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181008001619",
    },
    {
        "school": "Seymour-Redding Elementary School",
        "district": "Seymour Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181008001620",
    },
    {
        "school": "Seymour Middle School",
        "district": "Seymour Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181008002214",
    },
    {
        "school": "Crothersville Elementary School",
        "district": "Crothersville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181206001892",
    },
    {
        "school": "Crothersville Jr-Sr High School",
        "district": "Crothersville Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181206001893",
    },
    {
        "school": "LaSalle Academy",
        "district": "South Bend Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001709",
    },
    {
        "school": "Marshall Traditional School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001865",
    },
    {
        "school": "Rise Up Academy at Eggleston",
        "district": "South Bend Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001878",
    },
    {
        "school": "Prairie View Elementary School",
        "district": "New Prairie United School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180756000411",
    },
    {
        "school": "New Prairie High School",
        "district": "New Prairie United School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180756001298",
    },
    {
        "school": "New Prairie Middle School",
        "district": "New Prairie United School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180756001299",
    },
    {
        "school": "Rolling Prairie Elementary School",
        "district": "New Prairie United School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180756001301",
    },
    {
        "school": "Oaklawn Campus Program",
        "district": "School City of Mishawaka",
        "level": "High",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180684000531",
    },
    {
        "school": "Battell Elementary School",
        "district": "School City of Mishawaka",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180684001174",
    },
    {
        "school": "Beiger Elementary School",
        "district": "School City of Mishawaka",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180684001175",
    },
    {
        "school": "Emmons Elementary School",
        "district": "School City of Mishawaka",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180684001177",
    },
    {
        "school": "Fred J Hums Elementary School",
        "district": "School City of Mishawaka",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180684001178",
    },
    {
        "school": "John J Young Middle School",
        "district": "School City of Mishawaka",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180684001179",
    },
    {
        "school": "Lasalle Elementary School",
        "district": "School City of Mishawaka",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180684001181",
    },
    {
        "school": "Mishawaka High School",
        "district": "School City of Mishawaka",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180684001183",
    },
    {
        "school": "Twin Branch Elementary School",
        "district": "School City of Mishawaka",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180684001186",
    },
    {
        "school": "Liberty Elementary School",
        "district": "School City of Mishawaka",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180684001285",
    },
    {
        "school": "Olive Township Elementary School",
        "district": "New Prairie United School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180756001300",
    },
    {
        "school": "Horizon Elementary School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876000526",
    },
    {
        "school": "Discovery Middle School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876000794",
    },
    {
        "school": "Meadow's Edge Elementary School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876001141",
    },
    {
        "school": "Northpoint Elementary School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876001148",
    },
    {
        "school": "Elm Road Elementary School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876001442",
    },
    {
        "school": "Elsie Rogers Elementary School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876001443",
    },
    {
        "school": "Madison Elementary School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876001447",
    },
    {
        "school": "Mary Frank Harris Elementary Sch",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876001448",
    },
    {
        "school": "Moran Elementary School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876001449",
    },
    {
        "school": "Penn High School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876001451",
    },
    {
        "school": "Schmucker Middle School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876001452",
    },
    {
        "school": "Virgil I Grissom Middle School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876001453",
    },
    {
        "school": "Walt Disney Elementary School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876001454",
    },
    {
        "school": "Bittersweet Elementary School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876002161",
    },
    {
        "school": "Prairie Vista Elementary School",
        "district": "Penn-Harris-Madison School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180876002341",
    },
    {
        "school": "Harold C Urey Middle School",
        "district": "John Glenn School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180912001504",
    },
    {
        "school": "John Glenn High School",
        "district": "John Glenn School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180912001505",
    },
    {
        "school": "Walkerton Elementary School",
        "district": "John Glenn School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180912001506",
    },
    {
        "school": "North Liberty School",
        "district": "John Glenn School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180912002210",
    },
    {
        "school": "Wilson Elementary School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029000069",
    },
    {
        "school": "Juvenile Justice Center",
        "district": "South Bend Community School Corp",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "IN",
        "nces_id": "181029000898",
    },
    {
        "school": "Coquillard Elementary School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001644",
    },
    {
        "school": "Jackson Middle School",
        "district": "South Bend Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001645",
    },
    {
        "school": "Harrison Elementary School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001646",
    },
    {
        "school": "Tarkington Elementary School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001647",
    },
    {
        "school": "Clay High School",
        "district": "South Bend Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001649",
    },
    {
        "school": "Clay International Academy",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001650",
    },
    {
        "school": "Darden Elementary School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001651",
    },
    {
        "school": "Hay Elementary School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001654",
    },
    {
        "school": "Madison S.T.E.A.M. Academy",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001658",
    },
    {
        "school": "Monroe Elementary School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001659",
    },
    {
        "school": "Riley High School",
        "district": "South Bend Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001660",
    },
    {
        "school": "Dickinson Fine Arts Academy",
        "district": "South Bend Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001661",
    },
    {
        "school": "Adams High School",
        "district": "South Bend Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001662",
    },
    {
        "school": "Kennedy Academy",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001663",
    },
    {
        "school": "Nuner Fine Arts Academy",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001664",
    },
    {
        "school": "Lafayette Early Childhood Center",
        "district": "South Bend Community School Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001667",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001669",
    },
    {
        "school": "Marquette Montessori Academy",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001672",
    },
    {
        "school": "McKinley Elementary School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001673",
    },
    {
        "school": "Muessel Elementary School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001674",
    },
    {
        "school": "Navarre Middle School",
        "district": "South Bend Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001679",
    },
    {
        "school": "Swanson Traditional School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001680",
    },
    {
        "school": "Edison Middle School",
        "district": "South Bend Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001681",
    },
    {
        "school": "Jefferson Traditional School",
        "district": "South Bend Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001682",
    },
    {
        "school": "Warren Elementary School",
        "district": "South Bend Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001683",
    },
    {
        "school": "Washington High School",
        "district": "South Bend Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029001684",
    },
    {
        "school": "Rural Community Academy",
        "district": "Rural Community Schools Inc",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180004302138",
    },
    {
        "school": "Northeast North Elementary School",
        "district": "Northeast School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180816001400",
    },
    {
        "school": "Northeast East Elementary School",
        "district": "Northeast School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180816001401",
    },
    {
        "school": "North Central Jr/Sr High School",
        "district": "Northeast School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180816001402",
    },
    {
        "school": "Carlisle Elementary School",
        "district": "Southwest School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181086001770",
    },
    {
        "school": "Sullivan Elementary School",
        "district": "Southwest School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181086001771",
    },
    {
        "school": "Sullivan High School",
        "district": "Southwest School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181086001773",
    },
    {
        "school": "Sullivan Middle School",
        "district": "Southwest School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181086002359",
    },
    {
        "school": "Northview High School",
        "district": "Clay Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180084000154",
    },
    {
        "school": "Clay City Elementary School",
        "district": "Clay Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180084000156",
    },
    {
        "school": "Clay City Jr-Sr High School",
        "district": "Clay Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180084000157",
    },
    {
        "school": "East Side Elementary School",
        "district": "Clay Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180084000158",
    },
    {
        "school": "Forest Park Elementary School",
        "district": "Clay Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180084000159",
    },
    {
        "school": "Jackson Township Elementary School",
        "district": "Clay Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180084000160",
    },
    {
        "school": "Meridian Street Elementary School",
        "district": "Clay Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180084000161",
    },
    {
        "school": "Staunton Elementary School",
        "district": "Clay Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180084000162",
    },
    {
        "school": "Van Buren Elementary School",
        "district": "Clay Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180084000164",
    },
    {
        "school": "North Clay Middle School",
        "district": "Clay Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180084000165",
    },
    {
        "school": "North Vermillion Elementary School",
        "district": "North Vermillion Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180807000184",
    },
    {
        "school": "North Vermillion High School",
        "district": "North Vermillion Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180807001384",
    },
    {
        "school": "Central Elementary School",
        "district": "South Vermillion Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181059001735",
    },
    {
        "school": "Ernie Pyle Elementary School",
        "district": "South Vermillion Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181059001736",
    },
    {
        "school": "South Vermillion High School",
        "district": "South Vermillion Com Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181059001739",
    },
    {
        "school": "South Vermillion Middle School",
        "district": "South Vermillion Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181059001740",
    },
    {
        "school": "Van Duyn Elementary School",
        "district": "South Vermillion Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181059001741",
    },
    {
        "school": "Covered Bridge Spec Ed Dist",
        "district": "Covered Bridge Spec Ed Dist",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180242002233",
    },
    {
        "school": "McLean Education Center (Alt)",
        "district": "Vigo County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209000926",
    },
    {
        "school": "Benjamin Franklin Elem School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001894",
    },
    {
        "school": "Blanche E Fuqua Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001895",
    },
    {
        "school": "Sugar Creek Consolidated Elem Sch",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001899",
    },
    {
        "school": "Davis Park Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001901",
    },
    {
        "school": "Deming Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001902",
    },
    {
        "school": "Dixie Bee Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001903",
    },
    {
        "school": "Farrington Grove Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001904",
    },
    {
        "school": "Fayette Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001905",
    },
    {
        "school": "Honey Creek Middle School",
        "district": "Vigo County School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001907",
    },
    {
        "school": "Lost Creek Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001909",
    },
    {
        "school": "Meadows Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001910",
    },
    {
        "school": "Otter Creek Middle School",
        "district": "Vigo County School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001911",
    },
    {
        "school": "Riley Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001913",
    },
    {
        "school": "Rio Grande Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001914",
    },
    {
        "school": "Sarah Scott Middle School",
        "district": "Vigo County School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001915",
    },
    {
        "school": "Sugar Grove Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001916",
    },
    {
        "school": "Terre Haute North Vigo High School",
        "district": "Vigo County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001917",
    },
    {
        "school": "Terre Haute South Vigo High School",
        "district": "Vigo County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001918",
    },
    {
        "school": "Terre Town Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001919",
    },
    {
        "school": "West Vigo Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001922",
    },
    {
        "school": "West Vigo High School",
        "district": "Vigo County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001923",
    },
    {
        "school": "West Vigo Middle School",
        "district": "Vigo County School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001924",
    },
    {
        "school": "Woodrow Wilson Middle School",
        "district": "Vigo County School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209001925",
    },
    {
        "school": "Adelaide De Vaney Elementary Sch",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209002172",
    },
    {
        "school": "Hoosier Prairie Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209002173",
    },
    {
        "school": "Ouabache Elementary School",
        "district": "Vigo County School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209002176",
    },
    {
        "school": "Booker T Washington Alt Sch",
        "district": "Vigo County School Corp",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IN",
        "nces_id": "181209002344",
    },
    {
        "school": "North Knox Primary School",
        "district": "North Knox School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180783001332",
    },
    {
        "school": "North Knox Jr-Sr High School",
        "district": "North Knox School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180783001334",
    },
    {
        "school": "North Knox Intermediate",
        "district": "North Knox School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180783001335",
    },
    {
        "school": "South Knox Elementary School",
        "district": "South Knox School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181041001705",
    },
    {
        "school": "South Knox Middle-High School",
        "district": "South Knox School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181041001706",
    },
    {
        "school": "Benjamin Franklin Elementary Sch",
        "district": "Vincennes Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181212001926",
    },
    {
        "school": "Francis Vigo Elementary School",
        "district": "Vincennes Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181212001927",
    },
    {
        "school": "George Rogers Clark School",
        "district": "Vincennes Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181212001928",
    },
    {
        "school": "James Whitcomb Riley Elem Sch",
        "district": "Vincennes Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181212001929",
    },
    {
        "school": "Lincoln High School",
        "district": "Vincennes Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181212001931",
    },
    {
        "school": "Tecumseh-Harrison Elementary Sch",
        "district": "Vincennes Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181212001932",
    },
    {
        "school": "Manchester Elementary School",
        "district": "Manchester Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180627001101",
    },
    {
        "school": "Manchester Intermediate School",
        "district": "Manchester Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180627001102",
    },
    {
        "school": "Manchester Jr-Sr High School",
        "district": "Manchester Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180627001103",
    },
    {
        "school": "Heartland Career Center",
        "district": "Heartland Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "181193001880",
    },
    {
        "school": "O J Neighbours Elementary School",
        "district": "Wabash City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181215001937",
    },
    {
        "school": "Wabash High School",
        "district": "Wabash City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181215001940",
    },
    {
        "school": "Wabash Middle School",
        "district": "Wabash City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181215002301",
    },
    {
        "school": "Metro North Elementary School",
        "district": "M S D Wabash County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181218001944",
    },
    {
        "school": "Northfield Jr-Sr High School",
        "district": "M S D Wabash County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181218001945",
    },
    {
        "school": "Southwood Elementary School",
        "district": "M S D Wabash County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181218001947",
    },
    {
        "school": "Southwood Jr-Sr High School",
        "district": "M S D Wabash County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181218001948",
    },
    {
        "school": "Wabash/Miami Area Prog Excpt",
        "district": "M S D Wabash County Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "181218001950",
    },
    {
        "school": "White's Jr-Sr High School",
        "district": "M S D Wabash County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181218001951",
    },
    {
        "school": "Sharp Creek Elementary School",
        "district": "M S D Wabash County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181218002178",
    },
    {
        "school": "Akron Elementary School",
        "district": "Tippecanoe Valley School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181137001836",
    },
    {
        "school": "Milford School",
        "district": "Wawasee Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180555001001",
    },
    {
        "school": "North Webster Elementary School",
        "district": "Wawasee Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180555001003",
    },
    {
        "school": "Syracuse Elementary School",
        "district": "Wawasee Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180555001005",
    },
    {
        "school": "Wawasee High School",
        "district": "Wawasee Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180555001007",
    },
    {
        "school": "Wawasee Middle School",
        "district": "Wawasee Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180555002354",
    },
    {
        "school": "Tippecanoe Valley Middle School",
        "district": "Tippecanoe Valley School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181137000397",
    },
    {
        "school": "Mentone Elementary School",
        "district": "Tippecanoe Valley School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181137001838",
    },
    {
        "school": "Tippecanoe Valley High School",
        "district": "Tippecanoe Valley School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181137001839",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Warsaw Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181242001992",
    },
    {
        "school": "Leesburg Elementary School",
        "district": "Warsaw Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181242001993",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Warsaw Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181242001994",
    },
    {
        "school": "Madison Elementary School",
        "district": "Warsaw Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181242001995",
    },
    {
        "school": "Warsaw Community High School",
        "district": "Warsaw Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181242001999",
    },
    {
        "school": "Edgewood Middle School",
        "district": "Warsaw Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181242002000",
    },
    {
        "school": "Washington Elementary School",
        "district": "Warsaw Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181242002001",
    },
    {
        "school": "Lakeview Middle School",
        "district": "Warsaw Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181242002364",
    },
    {
        "school": "Eisenhower Elementary School",
        "district": "Warsaw Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181242002371",
    },
    {
        "school": "Harrison Elementary School",
        "district": "Warsaw Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181242002372",
    },
    {
        "school": "Pierceton Elementary School",
        "district": "Whitko Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181323002084",
    },
    {
        "school": "South Whitley Elementary School",
        "district": "Whitko Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181323002087",
    },
    {
        "school": "Whitko Jr/Sr High School",
        "district": "Whitko Community School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181323002089",
    },
    {
        "school": "North Daviess Elementary School",
        "district": "North Daviess Com Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180771001648",
    },
    {
        "school": "Barr Reeve Elementary School",
        "district": "Barr-Reeve Community Schools Inc",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180033000060",
    },
    {
        "school": "Barr Reeve Middle/High School",
        "district": "Barr-Reeve Community Schools Inc",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180033000061",
    },
    {
        "school": "Barr Reeve Primary Grade School",
        "district": "Barr-Reeve Community Schools Inc",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180033000062",
    },
    {
        "school": "North Daviess Jr-Sr High School",
        "district": "North Daviess Com Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180771001319",
    },
    {
        "school": "Twin Rivers Career & Tech Ed Area",
        "district": "Twin Rivers Career & Tech Ed Area",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "181160002241",
    },
    {
        "school": "Helen Griffith Elementary School",
        "district": "Washington Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181245002002",
    },
    {
        "school": "Lena Dunn Elementary School",
        "district": "Washington Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181245002003",
    },
    {
        "school": "North Elementary School",
        "district": "Washington Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181245002004",
    },
    {
        "school": "Veale Elementary School",
        "district": "Washington Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181245002005",
    },
    {
        "school": "Washington High School",
        "district": "Washington Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181245002006",
    },
    {
        "school": "Washington Junior High School",
        "district": "Washington Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181245002007",
    },
    {
        "school": "Winfield Middle School",
        "district": "Winfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201305001826",
    },
    {
        "school": "Rock Hills Elementary School",
        "district": "Rock Hills",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200002901830",
    },
    {
        "school": "Rock Hills Jr/Sr High School",
        "district": "Rock Hills",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200002901837",
    },
    {
        "school": "Prairie Creek Elementary",
        "district": "Spring Hill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201185001852",
    },
    {
        "school": "Sunrise Point Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001841",
    },
    {
        "school": "St. Hosp. Training Center Parsons",
        "district": "St. Hosp. Training Center Parsons",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200002201857",
    },
    {
        "school": "Leavenworth Virtual School",
        "district": "Leavenworth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200843001850",
    },
    {
        "school": "Tipton Community School",
        "district": "Waconda",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200447001844",
    },
    {
        "school": "Osage City Middle School",
        "district": "Osage City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201023001839",
    },
    {
        "school": "Belleville East Elementary",
        "district": "Republic County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200003001834",
    },
    {
        "school": "Explorer Elementary School",
        "district": "Goddard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200654001856",
    },
    {
        "school": "Washington County High School",
        "district": "Washington Co. Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200002801828",
    },
    {
        "school": "Turner Sixth Grade Academy",
        "district": "Turner-Kansas City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201236001859",
    },
    {
        "school": "Chisholm Life Skills Center",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001104",
    },
    {
        "school": "Southern Coffey County Jr. High School",
        "district": "LeRoy-Gridley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200867001794",
    },
    {
        "school": "Marshall Elementary School",
        "district": "Eureka",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200612001740",
    },
    {
        "school": "Lakeside Elementary",
        "district": "Waconda",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200447001801",
    },
    {
        "school": "Western Plains North Elem",
        "district": "Western Plains",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200002000496",
    },
    {
        "school": "Western Plains High",
        "district": "Western Plains",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200002000498",
    },
    {
        "school": "Western Plains South Elem/Jr High",
        "district": "Western Plains",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200002000501",
    },
    {
        "school": "Rawlins County Elementary",
        "district": "Rawlins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200002300579",
    },
    {
        "school": "Rawlins County Jr/Sr High School",
        "district": "Rawlins County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200002300580",
    },
    {
        "school": "Humboldt High School",
        "district": "Humboldt",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200759000247",
    },
    {
        "school": "Humboldt Middle School",
        "district": "Humboldt",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200759000248",
    },
    {
        "school": "Jefferson Elem",
        "district": "Iola",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200774000240",
    },
    {
        "school": "Lincoln Elem",
        "district": "Iola",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200774000241",
    },
    {
        "school": "McKinley Elem",
        "district": "Iola",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200774000242",
    },
    {
        "school": "Iola Middle School",
        "district": "Iola",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200774000243",
    },
    {
        "school": "Iola Sr High",
        "district": "Iola",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200774000244",
    },
    {
        "school": "Marmaton Valley Elem",
        "district": "Marmaton Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200966000237",
    },
    {
        "school": "Marmaton Valley High",
        "district": "Marmaton Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200966000238",
    },
    {
        "school": "Anderson County Jr/Sr High School",
        "district": "Garnett",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200645000206",
    },
    {
        "school": "Greeley Elem",
        "district": "Garnett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200645000766",
    },
    {
        "school": "Westphalia",
        "district": "Garnett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200645000768",
    },
    {
        "school": "Crest Elementary",
        "district": "Crest",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200804001274",
    },
    {
        "school": "Crest High",
        "district": "Crest",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200804001275",
    },
    {
        "school": "Medicine Lodge Grade School",
        "district": "Barber County North",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200945000229",
    },
    {
        "school": "Eugene Ware Elem",
        "district": "Fort Scott",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200618000146",
    },
    {
        "school": "Winfield Scott Elem",
        "district": "Fort Scott",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200618000147",
    },
    {
        "school": "Fort Scott Middle School",
        "district": "Fort Scott",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200618000148",
    },
    {
        "school": "Fort Scott Sr High",
        "district": "Fort Scott",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200618000149",
    },
    {
        "school": "Uniontown High School",
        "district": "Uniontown",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201245000150",
    },
    {
        "school": "West Bourbon Elementary",
        "district": "Uniontown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201245000151",
    },
    {
        "school": "Hiawatha Elem",
        "district": "Hiawatha",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000600975",
    },
    {
        "school": "Hiawatha Sr High",
        "district": "Hiawatha",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000600976",
    },
    {
        "school": "Hiawatha Middle School",
        "district": "Hiawatha",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000601728",
    },
    {
        "school": "Everest Middle",
        "district": "South Brown County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200747001040",
    },
    {
        "school": "Horton Elem",
        "district": "South Brown County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200747001041",
    },
    {
        "school": "Horton High",
        "district": "South Brown County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200747001042",
    },
    {
        "school": "Cedar Vale Elem",
        "district": "Cedar Vale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200450000443",
    },
    {
        "school": "Cedar Vale High",
        "district": "Cedar Vale",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200450000444",
    },
    {
        "school": "Sedan Elem",
        "district": "Chautauqua Co Community",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201152000445",
    },
    {
        "school": "Sedan High",
        "district": "Chautauqua Co Community",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201152000446",
    },
    {
        "school": "Central Elem",
        "district": "Baxter Springs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200381001504",
    },
    {
        "school": "Lincoln Elem",
        "district": "Baxter Springs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200381001505",
    },
    {
        "school": "Baxter Springs High",
        "district": "Baxter Springs",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200381001508",
    },
    {
        "school": "Highland Elem",
        "district": "Columbus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200507001340",
    },
    {
        "school": "Park Elem",
        "district": "Columbus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200507001341",
    },
    {
        "school": "Central Elem",
        "district": "Columbus",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200507001342",
    },
    {
        "school": "Columbus High",
        "district": "Columbus",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200507001343",
    },
    {
        "school": "Liberty Elem",
        "district": "Galena",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200636001385",
    },
    {
        "school": "Spring Grove Primary Center",
        "district": "Galena",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200636001386",
    },
    {
        "school": "Galena High",
        "district": "Galena",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200636001387",
    },
    {
        "school": "Galena Middle School",
        "district": "Galena",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200636001511",
    },
    {
        "school": "Riverton Middle",
        "district": "Riverton",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201113000872",
    },
    {
        "school": "Riverton Elem",
        "district": "Riverton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201113000925",
    },
    {
        "school": "Riverton High",
        "district": "Riverton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201113000926",
    },
    {
        "school": "Cheylin Jr/Sr High",
        "district": "Cheylin",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200479000482",
    },
    {
        "school": "Cheylin Elementary",
        "district": "Cheylin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200479000582",
    },
    {
        "school": "St Francis Elem",
        "district": "St Francis Comm Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201188000483",
    },
    {
        "school": "St Francis High",
        "district": "St Francis Comm Sch",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201188000484",
    },
    {
        "school": "Ashland Elem",
        "district": "Ashland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200351000084",
    },
    {
        "school": "Ashland High",
        "district": "Ashland",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200351000086",
    },
    {
        "school": "Ashland Junior High School",
        "district": "Ashland",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200351001650",
    },
    {
        "school": "Minneola Elem",
        "district": "Minneola",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200960000082",
    },
    {
        "school": "Minneola High",
        "district": "Minneola",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200960000083",
    },
    {
        "school": "Garfield Elem",
        "district": "Clay Center",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200489000821",
    },
    {
        "school": "Lincoln Elem",
        "district": "Clay Center",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200489000822",
    },
    {
        "school": "Clay Center Community Middle",
        "district": "Clay Center",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200489000823",
    },
    {
        "school": "Clay Center Community High",
        "district": "Clay Center",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200489000824",
    },
    {
        "school": "Wakefield Elem",
        "district": "Clay Center",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200489000828",
    },
    {
        "school": "Wakefield High",
        "district": "Clay Center",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200489000829",
    },
    {
        "school": "Concordia Middle",
        "district": "Concordia",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200510000643",
    },
    {
        "school": "Concordia Jr-Sr High",
        "district": "Concordia",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200510000644",
    },
    {
        "school": "Concordia Elementary",
        "district": "Concordia",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200510000984",
    },
    {
        "school": "Glasco Elem",
        "district": "Southern Cloud",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200651000647",
    },
    {
        "school": "Glasco High",
        "district": "Southern Cloud",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200651000648",
    },
    {
        "school": "Miltonvale Elem",
        "district": "Southern Cloud",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200651000649",
    },
    {
        "school": "Miltonvale High",
        "district": "Southern Cloud",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200651000650",
    },
    {
        "school": "Burlington High",
        "district": "Burlington",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200429000178",
    },
    {
        "school": "LeRoy Elem",
        "district": "LeRoy-Gridley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200867000179",
    },
    {
        "school": "Southern Coffey County High School",
        "district": "LeRoy-Gridley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200867000180",
    },
    {
        "school": "Gridley Elem",
        "district": "LeRoy-Gridley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200867000181",
    },
    {
        "school": "Lebo Elem",
        "district": "Lebo-Waverly",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201281000173",
    },
    {
        "school": "Lebo High",
        "district": "Lebo-Waverly",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201281000174",
    },
    {
        "school": "Waverly Elem",
        "district": "Lebo-Waverly",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201281000175",
    },
    {
        "school": "Waverly High",
        "district": "Lebo-Waverly",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201281000176",
    },
    {
        "school": "South Central High School",
        "district": "Comanche County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200504000491",
    },
    {
        "school": "South Central Elementary School",
        "district": "Comanche County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200504000492",
    },
    {
        "school": "South Central Middle School",
        "district": "Comanche County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200504000493",
    },
    {
        "school": "Oberlin Elem",
        "district": "Oberlin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201008000475",
    },
    {
        "school": "Decatur Community Jr/Sr High",
        "district": "Oberlin",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201008000477",
    },
    {
        "school": "Dwight D. Eisenhower Elementary",
        "district": "Abilene",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200318001059",
    },
    {
        "school": "Kennedy Elem",
        "district": "Abilene",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200318001060",
    },
    {
        "school": "McKinley Elem",
        "district": "Abilene",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200318001061",
    },
    {
        "school": "Abilene Middle School",
        "district": "Abilene",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200318001062",
    },
    {
        "school": "Abilene High School",
        "district": "Abilene",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200318001063",
    },
    {
        "school": "Blue Ridge Elem",
        "district": "Chapman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200462001246",
    },
    {
        "school": "Chapman Elem",
        "district": "Chapman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200462001247",
    },
    {
        "school": "Chapman Middle School",
        "district": "Chapman",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200462001248",
    },
    {
        "school": "Chapman High",
        "district": "Chapman",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200462001249",
    },
    {
        "school": "Enterprise Elem",
        "district": "Chapman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200462001250",
    },
    {
        "school": "Rural Center Elem",
        "district": "Chapman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200462001251",
    },
    {
        "school": "Herington Elem",
        "district": "Herington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200711001307",
    },
    {
        "school": "Herington Middle Sch",
        "district": "Herington",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200711001308",
    },
    {
        "school": "Herington High",
        "district": "Herington",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200711001309",
    },
    {
        "school": "Hope Elem",
        "district": "Rural Vista",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200744001287",
    },
    {
        "school": "Hope High",
        "district": "Rural Vista",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200744001288",
    },
    {
        "school": "Solomon Elem",
        "district": "Solomon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201176000883",
    },
    {
        "school": "Solomon High",
        "district": "Solomon",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201176000884",
    },
    {
        "school": "Kinsley-Offerle Elementary Pre-K-5",
        "district": "Kinsley-Offerle",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200810000701",
    },
    {
        "school": "Lewis Elem",
        "district": "Lewis",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200870001479",
    },
    {
        "school": "Elk Valley Elementary",
        "district": "Elk Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200576000435",
    },
    {
        "school": "Elk Valley High School",
        "district": "Elk Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200576000436",
    },
    {
        "school": "Ellsworth Elem",
        "district": "Ellsworth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200587000610",
    },
    {
        "school": "Ellsworth High",
        "district": "Ellsworth",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200587000611",
    },
    {
        "school": "Kanopolis Middle",
        "district": "Ellsworth",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200587000612",
    },
    {
        "school": "Grinnell Grade School",
        "district": "Grinnell Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200678000464",
    },
    {
        "school": "Quinter Elem",
        "district": "Quinter Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201095000472",
    },
    {
        "school": "Quinter Jr-Sr High",
        "district": "Quinter Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201095000473",
    },
    {
        "school": "Hill City Elem",
        "district": "Graham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200726000429",
    },
    {
        "school": "Kepley Middle School",
        "district": "Ulysses",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201242000067",
    },
    {
        "school": "Sullivan Elem",
        "district": "Ulysses",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201242000068",
    },
    {
        "school": "Ulysses High",
        "district": "Ulysses",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201242000069",
    },
    {
        "school": "Hickok Elem",
        "district": "Ulysses",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201242000070",
    },
    {
        "school": "Cimarron Elem",
        "district": "Cimarron-Ensign",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200480000009",
    },
    {
        "school": "Cimarron High",
        "district": "Cimarron-Ensign",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200480000010",
    },
    {
        "school": "Copeland Elem",
        "district": "Copeland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200519001270",
    },
    {
        "school": "South Gray Jr High",
        "district": "Copeland",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200519001713",
    },
    {
        "school": "Ingalls Elem",
        "district": "Ingalls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200768001272",
    },
    {
        "school": "Ingalls High School/Junior High",
        "district": "Ingalls",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200768001273",
    },
    {
        "school": "Montezuma Elem",
        "district": "Montezuma",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200963000782",
    },
    {
        "school": "South Gray High",
        "district": "Montezuma",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200963000783",
    },
    {
        "school": "Greeley County Elem School",
        "district": "Greeley County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200669000013",
    },
    {
        "school": "Greeley County Jr./Sr. High",
        "district": "Greeley County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200669000014",
    },
    {
        "school": "Eureka Jr/Sr High",
        "district": "Eureka",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200612000873",
    },
    {
        "school": "Hamilton Elem",
        "district": "Hamilton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200687000877",
    },
    {
        "school": "Hamilton High",
        "district": "Hamilton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200687000878",
    },
    {
        "school": "Madison Elem",
        "district": "Madison-Virgil",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200909000861",
    },
    {
        "school": "Madison High",
        "district": "Madison-Virgil",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200909000862",
    },
    {
        "school": "Syracuse Elem",
        "district": "Syracuse",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201215001347",
    },
    {
        "school": "Syracuse High",
        "district": "Syracuse",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201215001348",
    },
    {
        "school": "Anthony Elem",
        "district": "Chaparral Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200339000747",
    },
    {
        "school": "Chaparral Jr/Sr High",
        "district": "Chaparral Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200339000749",
    },
    {
        "school": "Harper Elem",
        "district": "Chaparral Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200339000750",
    },
    {
        "school": "Puls Elem",
        "district": "Attica",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200357001513",
    },
    {
        "school": "Attica High",
        "district": "Attica",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200357001514",
    },
    {
        "school": "Satanta Elem",
        "district": "Satanta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201140001502",
    },
    {
        "school": "Satanta Jr-Sr High",
        "district": "Satanta",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201140001503",
    },
    {
        "school": "Sublette Elem",
        "district": "Sublette",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201209000800",
    },
    {
        "school": "Sublette High",
        "district": "Sublette",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201209000801",
    },
    {
        "school": "Sublette Middle",
        "district": "Sublette",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201209001687",
    },
    {
        "school": "Hodgeman County Elementary",
        "district": "Hodgeman County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200780000107",
    },
    {
        "school": "Hodgeman County High",
        "district": "Hodgeman County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200780000108",
    },
    {
        "school": "Deerfield Middle School",
        "district": "Deerfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200540000004",
    },
    {
        "school": "Deerfield Elem",
        "district": "Deerfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200540000074",
    },
    {
        "school": "Deerfield High",
        "district": "Deerfield",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200540000075",
    },
    {
        "school": "Lakin Elem",
        "district": "Lakin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200828000072",
    },
    {
        "school": "Lakin High",
        "district": "Lakin",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200828000073",
    },
    {
        "school": "Lakin Middle",
        "district": "Lakin",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200828001637",
    },
    {
        "school": "Cunningham Elem",
        "district": "Cunningham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200537000634",
    },
    {
        "school": "Cunningham High",
        "district": "Cunningham",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200537000635",
    },
    {
        "school": "Kingman High",
        "district": "Kingman - Norwich",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200807000629",
    },
    {
        "school": "Norwich High",
        "district": "Kingman - Norwich",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200807000632",
    },
    {
        "school": "Kiowa County Elem/Jr. High",
        "district": "Kiowa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200672001009",
    },
    {
        "school": "Kiowa County High School",
        "district": "Kiowa County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200672001010",
    },
    {
        "school": "Haviland Elem",
        "district": "Haviland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200699001253",
    },
    {
        "school": "Dighton Elem",
        "district": "Dighton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200555001294",
    },
    {
        "school": "Dighton High",
        "district": "Dighton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200555001296",
    },
    {
        "school": "Healy Elem",
        "district": "Healy Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200708001225",
    },
    {
        "school": "Healy High",
        "district": "Healy Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200708001226",
    },
    {
        "school": "Lincoln Elem",
        "district": "Lincoln",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200879000486",
    },
    {
        "school": "Lincoln Jr/Sr High",
        "district": "Lincoln",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200879000487",
    },
    {
        "school": "Winona Elem",
        "district": "Triplains",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001300414",
    },
    {
        "school": "Winona High",
        "district": "Triplains",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001300415",
    },
    {
        "school": "Oakley Elem",
        "district": "Oakley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201005000412",
    },
    {
        "school": "Oakley Sr High",
        "district": "Oakley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201005000413",
    },
    {
        "school": "Oakley Middle School",
        "district": "Oakley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201005001707",
    },
    {
        "school": "Windom Elem",
        "district": "Little River",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200888001103",
    },
    {
        "school": "Goessel Elem",
        "district": "Goessel",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200657000963",
    },
    {
        "school": "Goessel High",
        "district": "Goessel",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200657000964",
    },
    {
        "school": "Hillsboro Elem",
        "district": "Durham-Hillsboro-Lehigh",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200729000960",
    },
    {
        "school": "Hillsboro Middle/High School",
        "district": "Durham-Hillsboro-Lehigh",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200729000961",
    },
    {
        "school": "Marion Middle",
        "district": "Marion-Florence",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200924000947",
    },
    {
        "school": "Marion High",
        "district": "Marion-Florence",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200924000948",
    },
    {
        "school": "Marion Elem",
        "district": "Marion-Florence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200924000949",
    },
    {
        "school": "Peabody-Burns Elementary",
        "district": "Peabody-Burns",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201059000900",
    },
    {
        "school": "Peabody-Burns Jr/Sr High School",
        "district": "Peabody-Burns",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201059000902",
    },
    {
        "school": "Marysville Jr/Sr High",
        "district": "Marysville",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001600762",
    },
    {
        "school": "Marysville Elem",
        "district": "Marysville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001601674",
    },
    {
        "school": "Frankfort Elem",
        "district": "Vermillion",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200456000832",
    },
    {
        "school": "Frankfort High",
        "district": "Vermillion",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200456000833",
    },
    {
        "school": "Valley Heights Elem",
        "district": "Valley Heights",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201278001381",
    },
    {
        "school": "Valley Heights Elementary - Waterville",
        "district": "Valley Heights",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201278001382",
    },
    {
        "school": "Valley Heights Jr/Sr High",
        "district": "Valley Heights",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201278001383",
    },
    {
        "school": "Fowler Elem",
        "district": "Fowler",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200621000103",
    },
    {
        "school": "Fowler High",
        "district": "Fowler",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200621000104",
    },
    {
        "school": "Meade Elem",
        "district": "Meade",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200942000105",
    },
    {
        "school": "Meade High",
        "district": "Meade",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200942000106",
    },
    {
        "school": "Beloit Elem",
        "district": "Beloit",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200387000409",
    },
    {
        "school": "Beloit Jr-Sr High",
        "district": "Beloit",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200387000410",
    },
    {
        "school": "Council Grove Elementary School",
        "district": "Morris County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200528000986",
    },
    {
        "school": "Council Grove Junior Senior High School",
        "district": "Morris County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200528000988",
    },
    {
        "school": "White City Elem",
        "district": "Rural Vista",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200744001289",
    },
    {
        "school": "White City High",
        "district": "Rural Vista",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200744001290",
    },
    {
        "school": "Elkhart Middle School",
        "district": "Elkhart",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200579000079",
    },
    {
        "school": "Elkhart Elem",
        "district": "Elkhart",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200579000080",
    },
    {
        "school": "Elkhart High",
        "district": "Elkhart",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200579000081",
    },
    {
        "school": "Rolla Elem (PreK-5)",
        "district": "Rolla",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201119000076",
    },
    {
        "school": "Rolla JH/HS (6-12)",
        "district": "Rolla",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201119000077",
    },
    {
        "school": "Centralia Elem",
        "district": "Vermillion",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200456000830",
    },
    {
        "school": "Centralia High",
        "district": "Vermillion",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200456000831",
    },
    {
        "school": "Royster Middle School",
        "district": "Chanute Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200459000972",
    },
    {
        "school": "Chanute High",
        "district": "Chanute Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200459000973",
    },
    {
        "school": "Ness City Elem",
        "district": "Ness City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200993000499",
    },
    {
        "school": "Ness City High",
        "district": "Ness City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200993000500",
    },
    {
        "school": "Almena Elem",
        "district": "Northern Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200327000061",
    },
    {
        "school": "Northern Valley High",
        "district": "Northern Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200327000062",
    },
    {
        "school": "Eisenhower Elem",
        "district": "Norton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201002000058",
    },
    {
        "school": "Norton Jr High",
        "district": "Norton Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201002000059",
    },
    {
        "school": "Norton High",
        "district": "Norton Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201002000060",
    },
    {
        "school": "Lakeside Junior/Senior High School",
        "district": "Waconda",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200447000406",
    },
    {
        "school": "Natoma Elem",
        "district": "Paradise",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200985000904",
    },
    {
        "school": "Natoma High (6-12)",
        "district": "Paradise",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200985000905",
    },
    {
        "school": "Osborne Elem",
        "district": "Osborne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201029000881",
    },
    {
        "school": "Osborne Junior/Senior High",
        "district": "Osborne County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201029000882",
    },
    {
        "school": "Larned Middle School",
        "district": "Ft Larned",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200837001354",
    },
    {
        "school": "Larned Sr High",
        "district": "Ft Larned",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200837001355",
    },
    {
        "school": "Long Island Middle School",
        "district": "Northern Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200327000063",
    },
    {
        "school": "Logan Elem",
        "district": "Logan",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200891000607",
    },
    {
        "school": "Logan High",
        "district": "Logan",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200891000608",
    },
    {
        "school": "Phillipsburg Elem",
        "district": "Phillipsburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201065000604",
    },
    {
        "school": "Phillipsburg Middle",
        "district": "Phillipsburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201065000605",
    },
    {
        "school": "Phillipsburg High",
        "district": "Phillipsburg",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201065000606",
    },
    {
        "school": "Southwest Elem",
        "district": "Pratt",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201089000840",
    },
    {
        "school": "Liberty Middle School",
        "district": "Pratt",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201089000841",
    },
    {
        "school": "Pratt Sr High",
        "district": "Pratt",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201089000842",
    },
    {
        "school": "Skyline Elem",
        "district": "Skyline Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201143001074",
    },
    {
        "school": "Skyline High",
        "district": "Skyline Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201143001075",
    },
    {
        "school": "Pike Valley Elem",
        "district": "Pike Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200531001018",
    },
    {
        "school": "Pike Valley High",
        "district": "Pike Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200531001021",
    },
    {
        "school": "Pike Valley Jr High",
        "district": "Pike Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200531001586",
    },
    {
        "school": "Chase Elem",
        "district": "Chase-Raymond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200465000912",
    },
    {
        "school": "Chase High",
        "district": "Chase-Raymond",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200465000913",
    },
    {
        "school": "Raymond Jr High",
        "district": "Chase-Raymond",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200465000914",
    },
    {
        "school": "Little River Junior High",
        "district": "Little River",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200888001101",
    },
    {
        "school": "Little River High",
        "district": "Little River",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200888001102",
    },
    {
        "school": "Lyons Central Elementary",
        "district": "Lyons",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200903000927",
    },
    {
        "school": "Lyons Park Elementary",
        "district": "Lyons",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200903000928",
    },
    {
        "school": "Lyons Middle School",
        "district": "Lyons",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200903000929",
    },
    {
        "school": "Lyons High School",
        "district": "Lyons",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200903000930",
    },
    {
        "school": "Sterling Grade School",
        "district": "Sterling",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201203000808",
    },
    {
        "school": "Sterling Junior High/Senior High",
        "district": "Sterling",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201203000809",
    },
    {
        "school": "Palco Jr. High",
        "district": "Palco",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201047000396",
    },
    {
        "school": "Palco High",
        "district": "Palco",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201047000398",
    },
    {
        "school": "Plainville Elem",
        "district": "Plainville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201074000399",
    },
    {
        "school": "Plainville High",
        "district": "Plainville",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201074000400",
    },
    {
        "school": "Stockton Elem",
        "district": "Stockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201206000401",
    },
    {
        "school": "Stockton High",
        "district": "Stockton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201206000402",
    },
    {
        "school": "Otis-Bison Elementary",
        "district": "Otis-Bison",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200402000922",
    },
    {
        "school": "Otis-Bison Junior/Senior High School",
        "district": "Otis-Bison",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200402000923",
    },
    {
        "school": "La Crosse Elementary",
        "district": "LaCrosse",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200822000889",
    },
    {
        "school": "La Crosse High",
        "district": "LaCrosse",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200822000890",
    },
    {
        "school": "La Crosse Middle School",
        "district": "LaCrosse",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200822000891",
    },
    {
        "school": "Bickerdyke Elem",
        "district": "Russell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201131000942",
    },
    {
        "school": "Simpson Elem",
        "district": "Russell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201131000943",
    },
    {
        "school": "Ruppenthal Middle",
        "district": "Russell County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201131000944",
    },
    {
        "school": "Russell High",
        "district": "Russell County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201131000945",
    },
    {
        "school": "Scott City Lower Elem",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001701216",
    },
    {
        "school": "Scott City Middle",
        "district": "Scott County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001701217",
    },
    {
        "school": "Scott City High",
        "district": "Scott County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001701219",
    },
    {
        "school": "Hoxie Elem",
        "district": "Hoxie Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200753000965",
    },
    {
        "school": "Hoxie High",
        "district": "Hoxie Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200753000966",
    },
    {
        "school": "Golden Plains Elem",
        "district": "Golden Plains",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201104000576",
    },
    {
        "school": "Goodland Jr-Sr. High School",
        "district": "Goodland",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200658000717",
    },
    {
        "school": "West Elementary",
        "district": "Goodland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200658000720",
    },
    {
        "school": "Smith Center Elem",
        "district": "Smith Center",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000700155",
    },
    {
        "school": "Smith Center Jr Sr High",
        "district": "Smith Center",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000700156",
    },
    {
        "school": "Macksville Elem",
        "district": "Macksville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200906000712",
    },
    {
        "school": "Macksville High",
        "district": "Macksville",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200906000713",
    },
    {
        "school": "St John Elem",
        "district": "St John-Hudson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201191000710",
    },
    {
        "school": "St John High",
        "district": "St John-Hudson",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201191000711",
    },
    {
        "school": "Stafford Elementary",
        "district": "Stafford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201197000707",
    },
    {
        "school": "Stafford Middle School/High School",
        "district": "Stafford",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201197000708",
    },
    {
        "school": "Stanton County Elementary",
        "district": "Stanton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200786001144",
    },
    {
        "school": "Stanton County Jr./Sr. High School",
        "district": "Stanton County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200786001145",
    },
    {
        "school": "Hugoton Elem",
        "district": "Hugoton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200756000055",
    },
    {
        "school": "Hugoton Middle",
        "district": "Hugoton Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200756000056",
    },
    {
        "school": "Hugoton High",
        "district": "Hugoton Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200756000057",
    },
    {
        "school": "Moscow Elem",
        "district": "Moscow Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200972000053",
    },
    {
        "school": "Moscow High",
        "district": "Moscow Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200972000054",
    },
    {
        "school": "Brewster Elem",
        "district": "Brewster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200408000569",
    },
    {
        "school": "Brewster High",
        "district": "Brewster",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200408000570",
    },
    {
        "school": "Colby Elem",
        "district": "Colby Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200501000571",
    },
    {
        "school": "Colby Middle School",
        "district": "Colby Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200501000572",
    },
    {
        "school": "Colby Senior High",
        "district": "Colby Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200501000573",
    },
    {
        "school": "Golden Plains Middle",
        "district": "Golden Plains",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201104000574",
    },
    {
        "school": "Golden Plains High",
        "district": "Golden Plains",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201104000575",
    },
    {
        "school": "Trego Grade School",
        "district": "Wakeeney",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201263000050",
    },
    {
        "school": "Trego Community High",
        "district": "Wakeeney",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201263000051",
    },
    {
        "school": "Prairie Heights Elementary School",
        "district": "Morris County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200528000985",
    },
    {
        "school": "Sharon Springs Elem",
        "district": "Wallace County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201161000168",
    },
    {
        "school": "Wallace County High",
        "district": "Wallace County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201161000169",
    },
    {
        "school": "Weskan Elem",
        "district": "Weskan",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201290000171",
    },
    {
        "school": "Weskan High",
        "district": "Weskan",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201290000172",
    },
    {
        "school": "Hanover Elem",
        "district": "Barnes",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001200094",
    },
    {
        "school": "Hanover High",
        "district": "Barnes",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001200095",
    },
    {
        "school": "Linn Elem",
        "district": "Barnes",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001200096",
    },
    {
        "school": "Linn High",
        "district": "Barnes",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001200097",
    },
    {
        "school": "Clifton-Clyde Grade School K-3",
        "district": "Clifton-Clyde",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200495000099",
    },
    {
        "school": "Clifton-Clyde Sr High",
        "district": "Clifton-Clyde",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200495000102",
    },
    {
        "school": "Clifton-Clyde Middle School",
        "district": "Clifton-Clyde",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200495001612",
    },
    {
        "school": "Wichita County Elementary",
        "district": "Leoti",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200861001221",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Fredonia",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200627001302",
    },
    {
        "school": "Fredonia Jr./Sr. High School",
        "district": "Fredonia",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200627001304",
    },
    {
        "school": "Heller Elem",
        "district": "Neodesha",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200990001195",
    },
    {
        "school": "North Lawn Elem",
        "district": "Neodesha",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200990001196",
    },
    {
        "school": "Neodesha High",
        "district": "Neodesha",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200990001197",
    },
    {
        "school": "Yates Center Elem",
        "district": "Woodson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201311000769",
    },
    {
        "school": "Yates Center High",
        "district": "Woodson",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201311000770",
    },
    {
        "school": "Atchison High  School",
        "district": "Atchison Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200354000956",
    },
    {
        "school": "Atchison Middle School",
        "district": "Atchison Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200354000958",
    },
    {
        "school": "Atchison Elementary School",
        "district": "Atchison Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200354001126",
    },
    {
        "school": "Community Elementary",
        "district": "Coffeyville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200498001772",
    },
    {
        "school": "Lincoln Memorial Elem",
        "district": "Caney Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200441001064",
    },
    {
        "school": "Caney Valley High",
        "district": "Caney Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200441001065",
    },
    {
        "school": "Lincoln Central Elem",
        "district": "Cherryvale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200474001122",
    },
    {
        "school": "Cherryvale Sr / Middle School",
        "district": "Cherryvale",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200474001125",
    },
    {
        "school": "Field Kindley High",
        "district": "Coffeyville",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200498001112",
    },
    {
        "school": "Roosevelt Middle",
        "district": "Coffeyville",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200498001597",
    },
    {
        "school": "Independence Middle",
        "district": "Independence",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200765001120",
    },
    {
        "school": "Independence Sr High",
        "district": "Independence",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200765001121",
    },
    {
        "school": "Eisenhower Elem",
        "district": "Independence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200765001711",
    },
    {
        "school": "Comanche Middle School",
        "district": "Dodge City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558001743",
    },
    {
        "school": "Bucklin Elem",
        "district": "Bucklin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200414001190",
    },
    {
        "school": "Bucklin High",
        "district": "Bucklin",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200414001191",
    },
    {
        "school": "Beeson Elementary",
        "district": "Dodge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558000879",
    },
    {
        "school": "Linn Elementary",
        "district": "Dodge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558000887",
    },
    {
        "school": "Soule Elementary School",
        "district": "Dodge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558000888",
    },
    {
        "school": "Central Elem",
        "district": "Dodge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558001089",
    },
    {
        "school": "Miller Elem",
        "district": "Dodge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558001091",
    },
    {
        "school": "Northwest Elem",
        "district": "Dodge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558001092",
    },
    {
        "school": "Sunnyside Elem",
        "district": "Dodge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558001093",
    },
    {
        "school": "Dodge City Middle School",
        "district": "Dodge City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558001094",
    },
    {
        "school": "Dodge City High School",
        "district": "Dodge City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558001095",
    },
    {
        "school": "Wilroads Gardens Elem",
        "district": "Dodge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558001096",
    },
    {
        "school": "Spearville Elem",
        "district": "Spearville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201182000836",
    },
    {
        "school": "Spearville Jr/Sr High",
        "district": "Spearville",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201182000837",
    },
    {
        "school": "Riverside Elementary",
        "district": "Emporia",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200594001796",
    },
    {
        "school": "Timmerman Elementary",
        "district": "Emporia",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200594001797",
    },
    {
        "school": "NLC Elementary School",
        "district": "North Lyon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200321000210",
    },
    {
        "school": "Northern Heights",
        "district": "North Lyon County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200321000211",
    },
    {
        "school": "Village Elem",
        "district": "Emporia",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200594000222",
    },
    {
        "school": "Walnut Elem",
        "district": "Emporia",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200594000223",
    },
    {
        "school": "W A White Elem",
        "district": "Emporia",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200594000224",
    },
    {
        "school": "Emporia Middle School",
        "district": "Emporia",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200594000225",
    },
    {
        "school": "Emporia High",
        "district": "Emporia",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200594000226",
    },
    {
        "school": "Logan Ave Elem",
        "district": "Emporia",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200594000227",
    },
    {
        "school": "Hartford Jr./Sr. High School",
        "district": "Southern Lyon County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200693000215",
    },
    {
        "school": "Neosho Rapids Elementary",
        "district": "Southern Lyon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200693000216",
    },
    {
        "school": "Olpe Elementary",
        "district": "Southern Lyon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200693000218",
    },
    {
        "school": "Olpe Jr./Sr. High School",
        "district": "Southern Lyon County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200693000219",
    },
    {
        "school": "Wiley Elem",
        "district": "Holcomb",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200735001735",
    },
    {
        "school": "Alta Brown Elem",
        "district": "Garden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001169",
    },
    {
        "school": "Abe Hubert Elementary School",
        "district": "Garden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001170",
    },
    {
        "school": "Buffalo Jones Elem",
        "district": "Garden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001172",
    },
    {
        "school": "Georgia Matthews Elem",
        "district": "Garden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001173",
    },
    {
        "school": "Horace J. Good Middle School",
        "district": "Garden City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001174",
    },
    {
        "school": "Garden City High School",
        "district": "Garden City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001175",
    },
    {
        "school": "Gertrude Walker Elem",
        "district": "Garden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001176",
    },
    {
        "school": "Jennie Barker Elem",
        "district": "Garden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001177",
    },
    {
        "school": "Jennie Wilson Elem",
        "district": "Garden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001178",
    },
    {
        "school": "Kenneth Henderson Middle",
        "district": "Garden City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001180",
    },
    {
        "school": "Plymell Elementary",
        "district": "Garden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001181",
    },
    {
        "school": "Bernadine Sitts Intermediate Ctr",
        "district": "Garden City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001207",
    },
    {
        "school": "Charles O Stones Intermediate Ctr",
        "district": "Garden City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001227",
    },
    {
        "school": "Florence Wilson Elem",
        "district": "Garden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001600",
    },
    {
        "school": "Edith Scheuerman Elem",
        "district": "Garden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001633",
    },
    {
        "school": "Victor Ornelas Elem",
        "district": "Garden City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639001653",
    },
    {
        "school": "Holcomb Elem 3-5",
        "district": "Holcomb",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200735000756",
    },
    {
        "school": "Holcomb High",
        "district": "Holcomb",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200735000757",
    },
    {
        "school": "Holcomb Middle",
        "district": "Holcomb",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200735000798",
    },
    {
        "school": "Ellinwood Elem",
        "district": "Ellinwood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200582000731",
    },
    {
        "school": "Ellinwood  Middle School",
        "district": "Ellinwood Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200582000732",
    },
    {
        "school": "Ellinwood High",
        "district": "Ellinwood Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200582000733",
    },
    {
        "school": "Eisenhower Elem",
        "district": "Great Bend",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200666001027",
    },
    {
        "school": "Jefferson Elem",
        "district": "Great Bend",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200666001028",
    },
    {
        "school": "Lincoln Elem",
        "district": "Great Bend",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200666001029",
    },
    {
        "school": "Park Elem",
        "district": "Great Bend",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200666001031",
    },
    {
        "school": "Riley Elem",
        "district": "Great Bend",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200666001032",
    },
    {
        "school": "Great Bend Middle School",
        "district": "Great Bend",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200666001034",
    },
    {
        "school": "Great Bend High School",
        "district": "Great Bend",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200666001036",
    },
    {
        "school": "Hoisington Middle",
        "district": "Hoisington",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200732001046",
    },
    {
        "school": "Hoisington High",
        "district": "Hoisington",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200732001047",
    },
    {
        "school": "Washington Elem",
        "district": "Ellis",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200585000867",
    },
    {
        "school": "Ellis Jr/Sr High",
        "district": "Ellis",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200585000868",
    },
    {
        "school": "Lincoln Elem",
        "district": "Hays",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200702001318",
    },
    {
        "school": "Woodrow Wilson Elem",
        "district": "Hays",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200702001320",
    },
    {
        "school": "Hays Middle School",
        "district": "Hays",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200702001321",
    },
    {
        "school": "Hays High",
        "district": "Hays",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200702001322",
    },
    {
        "school": "Roosevelt Elem",
        "district": "Hays",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200702001324",
    },
    {
        "school": "Kathryn O'Loughlin McCarthy Elem",
        "district": "Hays",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200702001680",
    },
    {
        "school": "Hutchinson Magnet School at Allen",
        "district": "Hutchinson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200762001734",
    },
    {
        "school": "Buhler Elem",
        "district": "Buhler",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200420000564",
    },
    {
        "school": "Buhler High",
        "district": "Buhler",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200420000565",
    },
    {
        "school": "Union Valley Elem",
        "district": "Buhler",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200420000568",
    },
    {
        "school": "Prairie Hills Middle",
        "district": "Buhler",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200420001585",
    },
    {
        "school": "Haven Elem",
        "district": "Haven Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200696000559",
    },
    {
        "school": "Haven High",
        "district": "Haven Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200696000560",
    },
    {
        "school": "Yoder Charter Elem School",
        "district": "Haven Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200696000561",
    },
    {
        "school": "Haven Middle School",
        "district": "Haven Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200696001679",
    },
    {
        "school": "Faris Elementary",
        "district": "Hutchinson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200762000531",
    },
    {
        "school": "Graber Elementary",
        "district": "Hutchinson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200762000532",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Hutchinson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200762000535",
    },
    {
        "school": "McCandless Elementary",
        "district": "Hutchinson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200762000536",
    },
    {
        "school": "Morgan Elementary",
        "district": "Hutchinson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200762000537",
    },
    {
        "school": "Wiley Elementary",
        "district": "Hutchinson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200762000539",
    },
    {
        "school": "Hutchinson High School",
        "district": "Hutchinson Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200762000544",
    },
    {
        "school": "Hutchinson Middle School 8",
        "district": "Hutchinson Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200762001635",
    },
    {
        "school": "Nickerson Elem",
        "district": "Nickerson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200999000546",
    },
    {
        "school": "Nickerson High",
        "district": "Nickerson",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200999000547",
    },
    {
        "school": "Reno Valley Middle School",
        "district": "Nickerson",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200999000548",
    },
    {
        "school": "South Hutchinson Elem",
        "district": "Nickerson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200999000549",
    },
    {
        "school": "Pretty Prairie Elem",
        "district": "Pretty Prairie",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201092000555",
    },
    {
        "school": "Pretty Prairie High",
        "district": "Pretty Prairie",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201092000556",
    },
    {
        "school": "Pretty Prairie Middle",
        "district": "Pretty Prairie",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201092000557",
    },
    {
        "school": "Wellsville Middle School",
        "district": "Wellsville",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201287001733",
    },
    {
        "school": "School for Deaf Elementary",
        "district": "School for Deaf",
        "level": "Elementary",
        "type": "Special education school",
        "state": "KS",
        "nces_id": "200001901752",
    },
    {
        "school": "School for Deaf High",
        "district": "School for Deaf",
        "level": "High",
        "type": "Special education school",
        "state": "KS",
        "nces_id": "200001901753",
    },
    {
        "school": "Riverview Elementary",
        "district": "De Soto",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549001717",
    },
    {
        "school": "Prairie Ridge Elementary School",
        "district": "De Soto",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549001758",
    },
    {
        "school": "Moonlight Elementary School",
        "district": "Gardner Edgerton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200642001716",
    },
    {
        "school": "Madison Elementary",
        "district": "Gardner Edgerton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200642001780",
    },
    {
        "school": "Pioneer Ridge Middle School",
        "district": "Gardner Edgerton",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200642001824",
    },
    {
        "school": "Nike Elementary",
        "district": "Gardner Edgerton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200642001825",
    },
    {
        "school": "Arbor Creek Elementary",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001718",
    },
    {
        "school": "Manchester Park Elementary",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001759",
    },
    {
        "school": "Clearwater Creek Elementary",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001760",
    },
    {
        "school": "Prairie Trail Middle School",
        "district": "Olathe",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001761",
    },
    {
        "school": "Ravenwood Elementary",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001781",
    },
    {
        "school": "Olathe Northwest High School",
        "district": "Olathe",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001793",
    },
    {
        "school": "Lakewood Middle",
        "district": "Blue Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001700",
    },
    {
        "school": "Liberty View Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001715",
    },
    {
        "school": "Cedar Hills Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001757",
    },
    {
        "school": "Pleasant Ridge Elementary",
        "district": "Easton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200564001773",
    },
    {
        "school": "Tonganoxie Elem",
        "district": "Tonganoxie",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201221001864",
    },
    {
        "school": "Tonganoxie Middle School",
        "district": "Tonganoxie",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201221001865",
    },
    {
        "school": "School for Blind Elementary",
        "district": "School for Blind",
        "level": "Elementary",
        "type": "Special education school",
        "state": "KS",
        "nces_id": "200001801750",
    },
    {
        "school": "School for Blind High",
        "district": "School for Blind",
        "level": "High",
        "type": "Special education school",
        "state": "KS",
        "nces_id": "200001801751",
    },
    {
        "school": "Delaware Ridge Elementary",
        "district": "Bonner Springs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200405001827",
    },
    {
        "school": "McKinley Elementary School",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001778",
    },
    {
        "school": "Central Heights High",
        "district": "Central Heights",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001400453",
    },
    {
        "school": "Central Heights Elem",
        "district": "Central Heights",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001400454",
    },
    {
        "school": "Garfield Elem",
        "district": "Ottawa",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001500459",
    },
    {
        "school": "Lincoln Elem",
        "district": "Ottawa",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001500461",
    },
    {
        "school": "Ottawa Middle School",
        "district": "Ottawa",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001500462",
    },
    {
        "school": "Ottawa Sr High",
        "district": "Ottawa",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001500463",
    },
    {
        "school": "Wellsville Elem",
        "district": "Wellsville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201287000455",
    },
    {
        "school": "Wellsville High",
        "district": "Wellsville",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201287000456",
    },
    {
        "school": "Jayhawk Elementary",
        "district": "Jayhawk",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200775000695",
    },
    {
        "school": "Jayhawk-Linn High",
        "district": "Jayhawk",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200775000696",
    },
    {
        "school": "Lacygne Elem",
        "district": "Prairie View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200825000752",
    },
    {
        "school": "Parker Elem",
        "district": "Prairie View",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200825000753",
    },
    {
        "school": "Prairie View Middle",
        "district": "Prairie View",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200825000754",
    },
    {
        "school": "Prairie View High",
        "district": "Prairie View",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200825000755",
    },
    {
        "school": "Pleasanton Elem",
        "district": "Pleasanton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201077000680",
    },
    {
        "school": "Pleasanton High",
        "district": "Pleasanton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201077000681",
    },
    {
        "school": "De Soto  High  School",
        "district": "De Soto",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549000127",
    },
    {
        "school": "Monticello Trails Middle School",
        "district": "De Soto",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549000898",
    },
    {
        "school": "Lexington Trails Middle School",
        "district": "De Soto",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549000906",
    },
    {
        "school": "Clear Creek Elem",
        "district": "De Soto",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549001457",
    },
    {
        "school": "Starside Elem",
        "district": "De Soto",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549001462",
    },
    {
        "school": "Mill Valley High School",
        "district": "De Soto",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549001723",
    },
    {
        "school": "Mize Elementary School",
        "district": "De Soto",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549001724",
    },
    {
        "school": "Gardner Elem",
        "district": "Gardner Edgerton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200642000120",
    },
    {
        "school": "Gardner Edgerton High",
        "district": "Gardner Edgerton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200642000122",
    },
    {
        "school": "Edgerton Elem",
        "district": "Gardner Edgerton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200642000123",
    },
    {
        "school": "Sunflower Elementary",
        "district": "Gardner Edgerton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200642000997",
    },
    {
        "school": "Olathe East Sr High",
        "district": "Olathe",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000040",
    },
    {
        "school": "Central Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000130",
    },
    {
        "school": "Fairview Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000131",
    },
    {
        "school": "Ridgeview Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000132",
    },
    {
        "school": "Washington Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000133",
    },
    {
        "school": "Westview Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000134",
    },
    {
        "school": "Santa Fe Trail Middle School",
        "district": "Olathe",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000135",
    },
    {
        "school": "Oregon Trail Middle School",
        "district": "Olathe",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000136",
    },
    {
        "school": "Olathe North Sr High",
        "district": "Olathe",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000137",
    },
    {
        "school": "Meadow Lane Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000140",
    },
    {
        "school": "Rolling Ridge Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000141",
    },
    {
        "school": "Northview Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000142",
    },
    {
        "school": "Havencroft Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000143",
    },
    {
        "school": "Scarborough Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000144",
    },
    {
        "school": "Black Bob Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000145",
    },
    {
        "school": "Heatherstone Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014000910",
    },
    {
        "school": "Bentwood Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001000",
    },
    {
        "school": "California Trail Middle School",
        "district": "Olathe",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001019",
    },
    {
        "school": "Cedar Creek Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001292",
    },
    {
        "school": "Regency Place Elementary",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001484",
    },
    {
        "school": "Sunnyside Elementary School",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001541",
    },
    {
        "school": "Chisholm Trail Middle School",
        "district": "Olathe",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001548",
    },
    {
        "school": "Tomahawk Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001590",
    },
    {
        "school": "Indian Trail Middle School",
        "district": "Olathe",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001601",
    },
    {
        "school": "Olathe South Sr High",
        "district": "Olathe",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001602",
    },
    {
        "school": "Prairie Center Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001617",
    },
    {
        "school": "Brougham Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001624",
    },
    {
        "school": "Indian Creek Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001625",
    },
    {
        "school": "Walnut Grove Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001626",
    },
    {
        "school": "Pioneer Trail Middle School",
        "district": "Olathe",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001655",
    },
    {
        "school": "Briarwood Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001668",
    },
    {
        "school": "Countryside Elementary",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001669",
    },
    {
        "school": "Heritage Elementary",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001670",
    },
    {
        "school": "Frontier Trail Middle School",
        "district": "Olathe",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001676",
    },
    {
        "school": "Green Springs Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001703",
    },
    {
        "school": "Mahaffie Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001704",
    },
    {
        "school": "Pleasant Ridge Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001705",
    },
    {
        "school": "Sunflower Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164000932",
    },
    {
        "school": "East Antioch Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001516",
    },
    {
        "school": "Apache Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001518",
    },
    {
        "school": "Belinder Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001521",
    },
    {
        "school": "Bluejacket-Flint",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001522",
    },
    {
        "school": "Briarwood Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001523",
    },
    {
        "school": "Brookridge Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001524",
    },
    {
        "school": "Brookwood Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001525",
    },
    {
        "school": "Comanche Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001527",
    },
    {
        "school": "Corinth Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001528",
    },
    {
        "school": "Crestview Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001529",
    },
    {
        "school": "Highlands Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001534",
    },
    {
        "school": "John Diemer Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001535",
    },
    {
        "school": "Shawanoe Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001537",
    },
    {
        "school": "Ray Marsh Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001539",
    },
    {
        "school": "Mill Creek Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001542",
    },
    {
        "school": "Nieman Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001544",
    },
    {
        "school": "Overland Park Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001546",
    },
    {
        "school": "Pawnee Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001547",
    },
    {
        "school": "Prairie Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001549",
    },
    {
        "school": "Rhein Benninghoven Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001550",
    },
    {
        "school": "Roesland Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001552",
    },
    {
        "school": "Rosehill Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001554",
    },
    {
        "school": "Rushton Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001555",
    },
    {
        "school": "Santa Fe Trail Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001556",
    },
    {
        "school": "Tomahawk Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001560",
    },
    {
        "school": "Trailwood Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001561",
    },
    {
        "school": "Westwood View Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001563",
    },
    {
        "school": "Westridge Middle",
        "district": "Shawnee Mission Pub Sch",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001565",
    },
    {
        "school": "Hocker Grove Middle",
        "district": "Shawnee Mission Pub Sch",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001566",
    },
    {
        "school": "Indian Hills Middle",
        "district": "Shawnee Mission Pub Sch",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001568",
    },
    {
        "school": "Indian Woods Middle",
        "district": "Shawnee Mission Pub Sch",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001571",
    },
    {
        "school": "Trailridge Middle",
        "district": "Shawnee Mission Pub Sch",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001573",
    },
    {
        "school": "Shawnee Mission East High",
        "district": "Shawnee Mission Pub Sch",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001574",
    },
    {
        "school": "Shawnee Mission North High",
        "district": "Shawnee Mission Pub Sch",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001575",
    },
    {
        "school": "Shawnee Mission Northwest High",
        "district": "Shawnee Mission Pub Sch",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001576",
    },
    {
        "school": "Shawnee Mission South High",
        "district": "Shawnee Mission Pub Sch",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001577",
    },
    {
        "school": "Shawnee Mission West High",
        "district": "Shawnee Mission Pub Sch",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001578",
    },
    {
        "school": "Christa McAuliffe Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001656",
    },
    {
        "school": "Broken Arrow Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001682",
    },
    {
        "school": "Rising Star Elem",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001683",
    },
    {
        "school": "Spring Hill High School",
        "district": "Spring Hill",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201185000118",
    },
    {
        "school": "Spring Hill Middle School",
        "district": "Spring Hill",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201185000119",
    },
    {
        "school": "Harmony Middle",
        "district": "Blue Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200000012",
    },
    {
        "school": "Harmony Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200000033",
    },
    {
        "school": "Stanley Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200000111",
    },
    {
        "school": "Blue Valley High",
        "district": "Blue Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200000112",
    },
    {
        "school": "Stilwell Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200000114",
    },
    {
        "school": "Blue Valley Middle",
        "district": "Blue Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200000115",
    },
    {
        "school": "Prairie Star Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200000534",
    },
    {
        "school": "Blue Valley Northwest High",
        "district": "Blue Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200000541",
    },
    {
        "school": "Heartland Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200000892",
    },
    {
        "school": "Prairie Star Middle",
        "district": "Blue Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200000994",
    },
    {
        "school": "Blue River Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001269",
    },
    {
        "school": "Pleasant Ridge Middle",
        "district": "Blue Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001291",
    },
    {
        "school": "Sunset Ridge Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001400",
    },
    {
        "school": "Lakewood Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001473",
    },
    {
        "school": "Blue Valley West High",
        "district": "Blue Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001533",
    },
    {
        "school": "Leawood Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001582",
    },
    {
        "school": "Morse Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001593",
    },
    {
        "school": "Indian Valley Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001605",
    },
    {
        "school": "Leawood Middle",
        "district": "Blue Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001606",
    },
    {
        "school": "Blue Valley North High",
        "district": "Blue Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001644",
    },
    {
        "school": "Valley Park Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001645",
    },
    {
        "school": "Oak Hill Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001657",
    },
    {
        "school": "Oxford Middle",
        "district": "Blue Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001671",
    },
    {
        "school": "Mission Trail Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001677",
    },
    {
        "school": "Cottonwood Point Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001684",
    },
    {
        "school": "Overland Trail Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001685",
    },
    {
        "school": "Overland Trail Middle",
        "district": "Blue Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001686",
    },
    {
        "school": "Basehor Elementary School",
        "district": "Basehor-Linwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200378001184",
    },
    {
        "school": "Basehor-Linwood High School",
        "district": "Basehor-Linwood",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200378001186",
    },
    {
        "school": "Linwood Elementary School",
        "district": "Basehor-Linwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200378001187",
    },
    {
        "school": "Basehor-Linwood Middle School",
        "district": "Basehor-Linwood",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200378001188",
    },
    {
        "school": "Glenwood Ridge Elementary School",
        "district": "Basehor-Linwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200378001729",
    },
    {
        "school": "Pleasant Ridge Middle",
        "district": "Easton",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200564001130",
    },
    {
        "school": "Pleasant Ridge High",
        "district": "Easton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200564001131",
    },
    {
        "school": "Bradley Elem",
        "district": "Ft Leavenworth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200633000046",
    },
    {
        "school": "Eisenhower Elem",
        "district": "Ft Leavenworth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200633000047",
    },
    {
        "school": "MacArthur Elem",
        "district": "Ft Leavenworth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200633000048",
    },
    {
        "school": "Patton Jr High",
        "district": "Ft Leavenworth",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200633000049",
    },
    {
        "school": "Lansing High 9-12",
        "district": "Lansing",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200834001230",
    },
    {
        "school": "Lansing Middle 6-8",
        "district": "Lansing",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200834001664",
    },
    {
        "school": "Leavenworth Sr High",
        "district": "Leavenworth",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200843001157",
    },
    {
        "school": "Tonganoxie High",
        "district": "Tonganoxie",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201221001205",
    },
    {
        "school": "Broadmoor Elementary",
        "district": "Louisburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200897000982",
    },
    {
        "school": "Louisburg High",
        "district": "Louisburg",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200897000983",
    },
    {
        "school": "Louisburg Middle",
        "district": "Louisburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200897001638",
    },
    {
        "school": "Trojan Elem",
        "district": "Osawatomie",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201026000771",
    },
    {
        "school": "Swenson Early Childhood Education Center",
        "district": "Osawatomie",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201026000772",
    },
    {
        "school": "Osawatomie Middle School",
        "district": "Osawatomie",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201026000773",
    },
    {
        "school": "Osawatomie High",
        "district": "Osawatomie",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201026000774",
    },
    {
        "school": "Paola Middle",
        "district": "Paola",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201050000776",
    },
    {
        "school": "Paola High",
        "district": "Paola",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201050000779",
    },
    {
        "school": "Sunflower Elem",
        "district": "Paola",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201050001627",
    },
    {
        "school": "Cottonwood Elem",
        "district": "Paola",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201050001726",
    },
    {
        "school": "Bonner Springs Elementary",
        "district": "Bonner Springs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200405000029",
    },
    {
        "school": "Robert E Clark Middle",
        "district": "Bonner Springs",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200405000030",
    },
    {
        "school": "Bonner Springs High",
        "district": "Bonner Springs",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200405000031",
    },
    {
        "school": "Edwardsville Elem",
        "district": "Bonner Springs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200405000032",
    },
    {
        "school": "Banneker Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001388",
    },
    {
        "school": "Silver City Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001390",
    },
    {
        "school": "Chelsea Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001392",
    },
    {
        "school": "Douglass Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001393",
    },
    {
        "school": "Thomas A Edison Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001394",
    },
    {
        "school": "Emerson Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001395",
    },
    {
        "school": "John Fiske Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001397",
    },
    {
        "school": "Grant Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001398",
    },
    {
        "school": "Bertram Caruthers Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001399",
    },
    {
        "school": "Mark Twain Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001401",
    },
    {
        "school": "Noble Prentis Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001405",
    },
    {
        "school": "Quindaro Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001406",
    },
    {
        "school": "Frank Rushton Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001408",
    },
    {
        "school": "New Stanley Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001409",
    },
    {
        "school": "Eugene Ware Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001410",
    },
    {
        "school": "Wm A White Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001411",
    },
    {
        "school": "Frances Willard Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001413",
    },
    {
        "school": "Central Middle",
        "district": "Kansas City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001414",
    },
    {
        "school": "Northwest Middle",
        "district": "Kansas City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001415",
    },
    {
        "school": "Argentine Middle",
        "district": "Kansas City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001417",
    },
    {
        "school": "Rosedale Middle",
        "district": "Kansas City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001418",
    },
    {
        "school": "Sumner Academy of Arts & Science",
        "district": "Kansas City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001419",
    },
    {
        "school": "Wyandotte High",
        "district": "Kansas City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001420",
    },
    {
        "school": "Arrowhead Middle",
        "district": "Kansas City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001421",
    },
    {
        "school": "Bethel Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001422",
    },
    {
        "school": "J C Harmon High",
        "district": "Kansas City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001423",
    },
    {
        "school": "F L Schlagle High",
        "district": "Kansas City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001425",
    },
    {
        "school": "Claude A Huyck Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001426",
    },
    {
        "school": "D D Eisenhower Middle",
        "district": "Kansas City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001427",
    },
    {
        "school": "Hazel Grove Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001428",
    },
    {
        "school": "John F Kennedy Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001429",
    },
    {
        "school": "Lindbergh Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001430",
    },
    {
        "school": "Stony Point South",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001431",
    },
    {
        "school": "Stony Point North",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001432",
    },
    {
        "school": "Washington High",
        "district": "Kansas City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001433",
    },
    {
        "school": "Welborn Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001434",
    },
    {
        "school": "White Church Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001435",
    },
    {
        "school": "M E Pearson Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001437",
    },
    {
        "school": "Whittier Elem",
        "district": "Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795001714",
    },
    {
        "school": "Piper High",
        "district": "Piper-Kansas City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201068000026",
    },
    {
        "school": "Piper Middle",
        "district": "Piper-Kansas City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201068001681",
    },
    {
        "school": "Junction Elementary",
        "district": "Turner-Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201236000017",
    },
    {
        "school": "Oak Grove Elem",
        "district": "Turner-Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201236000020",
    },
    {
        "school": "Turner Elem",
        "district": "Turner-Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201236000022",
    },
    {
        "school": "Turner High",
        "district": "Turner-Kansas City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201236000024",
    },
    {
        "school": "Midland Trail",
        "district": "Turner-Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201236001475",
    },
    {
        "school": "Turner Middle School",
        "district": "Turner-Kansas City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201236001520",
    },
    {
        "school": "Lawrence Virtual School",
        "district": "Lawrence",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001776",
    },
    {
        "school": "Baldwin Junior High School",
        "district": "Baldwin City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200372000703",
    },
    {
        "school": "Baldwin High School",
        "district": "Baldwin City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200372000704",
    },
    {
        "school": "Eudora High  School",
        "district": "Eudora",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200609000542",
    },
    {
        "school": "Eudora Middle School",
        "district": "Eudora",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200609000874",
    },
    {
        "school": "Sunflower Elementary",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840000778",
    },
    {
        "school": "Prairie Park Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840000793",
    },
    {
        "school": "Lawrence Southwest Middle School",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840000876",
    },
    {
        "school": "Lawrence Free State High",
        "district": "Lawrence",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001189",
    },
    {
        "school": "Broken Arrow Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001363",
    },
    {
        "school": "Cordley Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001365",
    },
    {
        "school": "Deerfield Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001366",
    },
    {
        "school": "Hillcrest Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001368",
    },
    {
        "school": "Kennedy Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001369",
    },
    {
        "school": "New York Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001370",
    },
    {
        "school": "Pinckney Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001371",
    },
    {
        "school": "Schwegler Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001372",
    },
    {
        "school": "Sunset Hill Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001373",
    },
    {
        "school": "Woodlawn Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001374",
    },
    {
        "school": "Lawrence Liberty Memorial Central Mid School",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001375",
    },
    {
        "school": "Billy Mills Middle School",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001376",
    },
    {
        "school": "Lawrence West Middle School",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001377",
    },
    {
        "school": "Lawrence High",
        "district": "Lawrence",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001378",
    },
    {
        "school": "Quail Run Elementary",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001665",
    },
    {
        "school": "Langston Hughes Elem",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200840001730",
    },
    {
        "school": "Plains Elem",
        "district": "Kismet-Plains",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200819001299",
    },
    {
        "school": "Kismet Elem",
        "district": "Kismet-Plains",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200819001298",
    },
    {
        "school": "Southwestern Heights Jr/Sr High",
        "district": "Kismet-Plains",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200819001300",
    },
    {
        "school": "MacArthur Elementary School",
        "district": "Liberal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200873001279",
    },
    {
        "school": "Liberal Sr High",
        "district": "Liberal",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200873001286",
    },
    {
        "school": "Cottonwood Elementary School",
        "district": "Liberal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200873001587",
    },
    {
        "school": "Sunflower Elementary School",
        "district": "Liberal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200873001589",
    },
    {
        "school": "Grandview Elem",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001255",
    },
    {
        "school": "Fort Riley Elem",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001257",
    },
    {
        "school": "Franklin Elem",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001258",
    },
    {
        "school": "Lincoln Elem",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001260",
    },
    {
        "school": "Morris Hill Elem",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001261",
    },
    {
        "school": "Sheridan Elem",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001262",
    },
    {
        "school": "Washington Elem",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001263",
    },
    {
        "school": "Westwood Elem",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001264",
    },
    {
        "school": "Fort Riley Middle School",
        "district": "Geary County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001265",
    },
    {
        "school": "Junction City Middle School",
        "district": "Geary County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001266",
    },
    {
        "school": "Junction City Sr High",
        "district": "Geary County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001267",
    },
    {
        "school": "Milford Elem",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001268",
    },
    {
        "school": "Eisenhower Elem",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001588",
    },
    {
        "school": "Ware Elem",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001616",
    },
    {
        "school": "Wamego Middle School",
        "district": "Wamego",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000300583",
    },
    {
        "school": "Wamego High",
        "district": "Wamego",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000300585",
    },
    {
        "school": "Central Elem",
        "district": "Wamego",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000301607",
    },
    {
        "school": "West Elem",
        "district": "Wamego",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000301608",
    },
    {
        "school": "St George Elem",
        "district": "Rock Creek",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000400597",
    },
    {
        "school": "Westmoreland Elem",
        "district": "Rock Creek",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000400599",
    },
    {
        "school": "Rock Creek Jr/Sr High School",
        "district": "Rock Creek",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000401708",
    },
    {
        "school": "Onaga Elem",
        "district": "Onaga-Havensville-Wheaton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201017000594",
    },
    {
        "school": "Onaga Senior High",
        "district": "Onaga-Havensville-Wheaton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201017000595",
    },
    {
        "school": "McCormick Elementary",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201098000855",
    },
    {
        "school": "Lee Elem",
        "district": "Manhattan-Ogden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918000846",
    },
    {
        "school": "Marlatt Elem",
        "district": "Manhattan-Ogden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918000848",
    },
    {
        "school": "Northview Elem",
        "district": "Manhattan-Ogden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918000849",
    },
    {
        "school": "Theo Roosevelt Elem",
        "district": "Manhattan-Ogden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918000850",
    },
    {
        "school": "Woodrow Wilson Elem",
        "district": "Manhattan-Ogden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918000851",
    },
    {
        "school": "Manhattan High School West/East Campus",
        "district": "Manhattan-Ogden",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918000853",
    },
    {
        "school": "Ogden Elem",
        "district": "Manhattan-Ogden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918000854",
    },
    {
        "school": "Frank V Bergman Elem",
        "district": "Manhattan-Ogden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918000938",
    },
    {
        "school": "Susan B Anthony Middle School",
        "district": "Manhattan-Ogden",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918001049",
    },
    {
        "school": "Dwight D Eisenhower Middle School",
        "district": "Manhattan-Ogden",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918001067",
    },
    {
        "school": "Amanda Arnold Elem",
        "district": "Manhattan-Ogden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918001639",
    },
    {
        "school": "Randolph Middle",
        "district": "Blue Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201098000856",
    },
    {
        "school": "Blue Valley High",
        "district": "Blue Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201098000857",
    },
    {
        "school": "Riley County Grade School",
        "district": "Riley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201110000819",
    },
    {
        "school": "Riley County High School",
        "district": "Riley County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201110000820",
    },
    {
        "school": "St Marys Elem",
        "district": "Kaw Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200797000591",
    },
    {
        "school": "St. Marys Junior Senior High",
        "district": "Kaw Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200797000592",
    },
    {
        "school": "Rossville Elem",
        "district": "Kaw Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200797000589",
    },
    {
        "school": "Rossville Jr.-Sr. High School",
        "district": "Kaw Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200797000590",
    },
    {
        "school": "Smoky Valley Virtual Charter School",
        "district": "Smoky Valley",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000201809",
    },
    {
        "school": "Soderstrom Elem",
        "district": "Smoky Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000200907",
    },
    {
        "school": "Smoky Valley Middle School",
        "district": "Smoky Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000201467",
    },
    {
        "school": "Smoky Valley High",
        "district": "Smoky Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000201649",
    },
    {
        "school": "Canton-Galva Jr./Sr. High",
        "district": "Canton-Galva",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200444001002",
    },
    {
        "school": "Canton-Galva Elementary",
        "district": "Canton-Galva",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200444001004",
    },
    {
        "school": "Inman Elem",
        "district": "Inman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200771001127",
    },
    {
        "school": "Inman Jr/Sr High School",
        "district": "Inman",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200771001128",
    },
    {
        "school": "Lincoln Elem",
        "district": "McPherson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200939000993",
    },
    {
        "school": "Roosevelt Elem",
        "district": "McPherson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200939000995",
    },
    {
        "school": "Washington Elem",
        "district": "McPherson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200939000996",
    },
    {
        "school": "McPherson Middle School",
        "district": "McPherson",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200939000998",
    },
    {
        "school": "McPherson High",
        "district": "McPherson",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200939000999",
    },
    {
        "school": "Eisenhower Elementary",
        "district": "McPherson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200939001026",
    },
    {
        "school": "Moundridge Elem",
        "district": "Moundridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200978001011",
    },
    {
        "school": "Moundridge High",
        "district": "Moundridge",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200978001012",
    },
    {
        "school": "Moundridge Middle",
        "district": "Moundridge",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200978001013",
    },
    {
        "school": "St. Paul Elementary School",
        "district": "Chetopa-St. Paul",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200477001786",
    },
    {
        "school": "Altamont Elem",
        "district": "Labette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200330001494",
    },
    {
        "school": "Labette County High School",
        "district": "Labette County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200330001495",
    },
    {
        "school": "Bartlett Elem",
        "district": "Labette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200330001496",
    },
    {
        "school": "Edna Elem",
        "district": "Labette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200330001497",
    },
    {
        "school": "Meadowview Elem",
        "district": "Labette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200330001500",
    },
    {
        "school": "Mound Valley Elem",
        "district": "Labette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200330001501",
    },
    {
        "school": "Chetopa Elem",
        "district": "Chetopa-St. Paul",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200477001492",
    },
    {
        "school": "Chetopa High",
        "district": "Chetopa-St. Paul",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200477001493",
    },
    {
        "school": "Oswego Neosho Hgts Elem",
        "district": "Oswego",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201035001489",
    },
    {
        "school": "Service Valley Charter Academy",
        "district": "Oswego",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201035001490",
    },
    {
        "school": "Oswego Junior-Senior High School",
        "district": "Oswego",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201035001491",
    },
    {
        "school": "Parsons Middle School",
        "district": "Parsons",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201056001486",
    },
    {
        "school": "Parsons Sr High",
        "district": "Parsons",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201056001487",
    },
    {
        "school": "Meadowlark Elementary",
        "district": "Pittsburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201071001795",
    },
    {
        "school": "Southeast Elementary School",
        "district": "Cherokee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200471000189",
    },
    {
        "school": "Northeast Elem",
        "district": "Northeast",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200348000183",
    },
    {
        "school": "North East High",
        "district": "Northeast",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200348000184",
    },
    {
        "school": "Southeast Junior High School",
        "district": "Cherokee",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200471000185",
    },
    {
        "school": "Southeast High",
        "district": "Cherokee",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200471000188",
    },
    {
        "school": "Frank Layden Elem",
        "district": "Frontenac Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200630000197",
    },
    {
        "school": "R V Haderlein Elem",
        "district": "Girard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200648000191",
    },
    {
        "school": "Girard Middle",
        "district": "Girard",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200648000192",
    },
    {
        "school": "Girard High",
        "district": "Girard",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200648000193",
    },
    {
        "school": "Geo E Nettels Elem",
        "district": "Pittsburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201071000201",
    },
    {
        "school": "Lakeside Elem",
        "district": "Pittsburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201071000202",
    },
    {
        "school": "Westside Elem",
        "district": "Pittsburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201071000205",
    },
    {
        "school": "Pittsburg High",
        "district": "Pittsburg",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201071000208",
    },
    {
        "school": "Pittsburg Middle School",
        "district": "Pittsburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201071001591",
    },
    {
        "school": "Troy Elem",
        "district": "Troy Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201233001038",
    },
    {
        "school": "Troy High and Middle School",
        "district": "Troy Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201233001039",
    },
    {
        "school": "Bennington Elem",
        "district": "Twin Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200396000164",
    },
    {
        "school": "Bennington Junior High/High School",
        "district": "Twin Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200396000165",
    },
    {
        "school": "Tescott Elem",
        "district": "Twin Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200396000166",
    },
    {
        "school": "Tescott Junior High/High School",
        "district": "Twin Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200396000167",
    },
    {
        "school": "Minneapolis Elementary",
        "district": "North Ottawa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200957000161",
    },
    {
        "school": "Minneapolis Jr-Sr High School",
        "district": "North Ottawa County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200957000163",
    },
    {
        "school": "Southeast Saline High",
        "district": "Southeast Of Saline",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000100523",
    },
    {
        "school": "Southeast Saline Elem",
        "district": "Southeast Of Saline",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200000100524",
    },
    {
        "school": "Ell-Saline Middle/High School",
        "district": "Ell-Saline",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200580000527",
    },
    {
        "school": "Ell-Saline Elementary",
        "district": "Ell-Saline",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200580000528",
    },
    {
        "school": "Coronado Elem",
        "district": "Salina",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137000504",
    },
    {
        "school": "Heusner Elem",
        "district": "Salina",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137000509",
    },
    {
        "school": "Meadowlark Ridge Elem",
        "district": "Salina",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137000512",
    },
    {
        "school": "Oakdale Elem",
        "district": "Salina",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137000513",
    },
    {
        "school": "Stewart Elem",
        "district": "Salina",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137000515",
    },
    {
        "school": "Sunset Elem",
        "district": "Salina",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137000517",
    },
    {
        "school": "Cottonwood Elementary School",
        "district": "Salina",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137000518",
    },
    {
        "school": "Lakewood Middle School",
        "district": "Salina",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137000519",
    },
    {
        "school": "Salina South Middle",
        "district": "Salina",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137000520",
    },
    {
        "school": "Salina High Central",
        "district": "Salina",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137000521",
    },
    {
        "school": "Salina High South",
        "district": "Salina",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137000522",
    },
    {
        "school": "Schilling Elem",
        "district": "Salina",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201137001604",
    },
    {
        "school": "Mission  Valley Elementary",
        "district": "Mission Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200606001768",
    },
    {
        "school": "Holton Elementary School",
        "district": "Holton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200738000654",
    },
    {
        "school": "Holton Middle",
        "district": "Holton",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200738000656",
    },
    {
        "school": "Holton High",
        "district": "Holton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200738000657",
    },
    {
        "school": "Royal Valley Elementary",
        "district": "Royal Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200932000658",
    },
    {
        "school": "Royal Valley High",
        "district": "Royal Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200932000659",
    },
    {
        "school": "Royal Valley Middle School",
        "district": "Royal Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200932000661",
    },
    {
        "school": "McLouth Elem",
        "district": "McLouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200936000672",
    },
    {
        "school": "McLouth High",
        "district": "McLouth",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200936000673",
    },
    {
        "school": "McLouth Middle",
        "district": "McLouth",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200936000992",
    },
    {
        "school": "Jefferson West High",
        "district": "Jefferson West",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200951000668",
    },
    {
        "school": "Jefferson West Middle",
        "district": "Jefferson West",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200951000669",
    },
    {
        "school": "Oskaloosa Elem",
        "district": "Oskaloosa Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201032000670",
    },
    {
        "school": "Valley Falls Elem",
        "district": "Valley Falls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201254000662",
    },
    {
        "school": "Valley Falls High",
        "district": "Valley Falls",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201254000663",
    },
    {
        "school": "Jefferson Co North High",
        "district": "Jefferson County North",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201302000664",
    },
    {
        "school": "Jefferson County North Elem/Middle",
        "district": "Jefferson County North",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201302001239",
    },
    {
        "school": "Burlingame Elementary",
        "district": "Burlingame Public School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200426001160",
    },
    {
        "school": "Burlingame Junior/Senior High",
        "district": "Burlingame Public School",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200426001161",
    },
    {
        "school": "Lyndon Elem",
        "district": "Lyndon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200900001007",
    },
    {
        "school": "Lyndon High",
        "district": "Lyndon",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200900001008",
    },
    {
        "school": "Marais Des Cygnes Valley Elem",
        "district": "Marais Des Cygnes Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200948001164",
    },
    {
        "school": "Marais Des Cygnes Valley High",
        "district": "Marais Des Cygnes Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200948001165",
    },
    {
        "school": "Marais Des Cygnes Valley Middle",
        "district": "Marais Des Cygnes Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200948001167",
    },
    {
        "school": "Osage City Elem",
        "district": "Osage City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201023001005",
    },
    {
        "school": "Osage City High",
        "district": "Osage City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201023001006",
    },
    {
        "school": "Carbondale Attendance Center",
        "district": "Santa Fe Trail",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201041001054",
    },
    {
        "school": "Overbrook Attendance Center",
        "district": "Santa Fe Trail",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201041001055",
    },
    {
        "school": "Santa Fe Trail High",
        "district": "Santa Fe Trail",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201041001057",
    },
    {
        "school": "Alma Elementary School",
        "district": "Wabaunsee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200324000619",
    },
    {
        "school": "Wabaunsee Sr High",
        "district": "Wabaunsee",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200324000620",
    },
    {
        "school": "Paxico Middle School",
        "district": "Wabaunsee",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200324000621",
    },
    {
        "school": "Wabaunsee Junior High",
        "district": "Wabaunsee",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200324000622",
    },
    {
        "school": "Maple Hill Elem",
        "district": "Wabaunsee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200324000623",
    },
    {
        "school": "Lecompton Elem",
        "district": "Perry Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201062000675",
    },
    {
        "school": "Perry-Lecompton Middle",
        "district": "Perry Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201062000677",
    },
    {
        "school": "Perry Lecompton High",
        "district": "Perry Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201062000678",
    },
    {
        "school": "Auburn Elementary",
        "district": "Auburn Washburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200320001066",
    },
    {
        "school": "Pauline Central Primary",
        "district": "Auburn Washburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200320001069",
    },
    {
        "school": "Pauline South Intermediate",
        "district": "Auburn Washburn",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200320001070",
    },
    {
        "school": "Wanamaker Elem",
        "district": "Auburn Washburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200320001071",
    },
    {
        "school": "Jay Shideler Elementary",
        "district": "Auburn Washburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200320001072",
    },
    {
        "school": "Washburn Rural High",
        "district": "Auburn Washburn",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200320001073",
    },
    {
        "school": "Indian Hills Elementary",
        "district": "Auburn Washburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200320001658",
    },
    {
        "school": "Washburn Rural Middle School",
        "district": "Auburn Washburn",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200320001710",
    },
    {
        "school": "Elmont Elem",
        "district": "Seaman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201149000684",
    },
    {
        "school": "West Indianola Elem",
        "district": "Seaman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201149000690",
    },
    {
        "school": "Seaman High",
        "district": "Seaman",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201149000693",
    },
    {
        "school": "Silver Lake Elem",
        "district": "Silver Lake",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201170000784",
    },
    {
        "school": "Silver Lake Jr-Sr High",
        "district": "Silver Lake",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201170000785",
    },
    {
        "school": "Berryton Elem",
        "district": "Shawnee Heights",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201218001133",
    },
    {
        "school": "Shawnee Heights Elem",
        "district": "Shawnee Heights",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201218001134",
    },
    {
        "school": "Shawnee Heights High",
        "district": "Shawnee Heights",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201218001135",
    },
    {
        "school": "Shawnee Heights Middle",
        "district": "Shawnee Heights",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201218001136",
    },
    {
        "school": "Tecumseh North Elem",
        "district": "Shawnee Heights",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201218001137",
    },
    {
        "school": "Tecumseh South Elem",
        "district": "Shawnee Heights",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201218001138",
    },
    {
        "school": "Meadows Elementary",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001114",
    },
    {
        "school": "Scott Dual Language Magnet",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001115",
    },
    {
        "school": "Williams Science and Fine Arts Magnet School",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001116",
    },
    {
        "school": "Avondale West",
        "district": "Topeka Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001440",
    },
    {
        "school": "Robinson Middle School",
        "district": "Topeka Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001442",
    },
    {
        "school": "Highland Park Central",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001445",
    },
    {
        "school": "Ross Elementary",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001447",
    },
    {
        "school": "Lowman Hill Elem",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001451",
    },
    {
        "school": "McCarter Elem",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001454",
    },
    {
        "school": "McClure Elem",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001455",
    },
    {
        "school": "McEachron Elem",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001456",
    },
    {
        "school": "Quincy Elem",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001459",
    },
    {
        "school": "Randolph Elem",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001461",
    },
    {
        "school": "State Street Elem",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001463",
    },
    {
        "school": "Stout Elem",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001464",
    },
    {
        "school": "Whitson Elem",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001466",
    },
    {
        "school": "Eisenhower Middle School",
        "district": "Topeka Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001469",
    },
    {
        "school": "Capital City",
        "district": "Topeka Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001471",
    },
    {
        "school": "Jardine Middle School",
        "district": "Topeka Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001472",
    },
    {
        "school": "Marjorie French Middle School",
        "district": "Topeka Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001474",
    },
    {
        "school": "Highland Park High",
        "district": "Topeka Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001476",
    },
    {
        "school": "Topeka High",
        "district": "Topeka Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001477",
    },
    {
        "school": "Topeka West High",
        "district": "Topeka Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001478",
    },
    {
        "school": "Chase Middle School",
        "district": "Topeka Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001595",
    },
    {
        "school": "Hope Street Charter Academy",
        "district": "Topeka Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001596",
    },
    {
        "school": "Landon Middle School",
        "district": "Topeka Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226001688",
    },
    {
        "school": "Mission Valley Junior and Senior High School",
        "district": "Mission Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200606000626",
    },
    {
        "school": "Circle Middle School",
        "district": "Circle",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201230001738",
    },
    {
        "school": "Park Hill Elementary",
        "district": "Derby",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546001721",
    },
    {
        "school": "Dwight D. Eisenhower Middle School",
        "district": "Goddard",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200654001732",
    },
    {
        "school": "Maize Central Elementary",
        "district": "Maize",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200914001783",
    },
    {
        "school": "Spaght Multimedia Magnet",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001719",
    },
    {
        "school": "Isely Traditional Magnet Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001720",
    },
    {
        "school": "Jackson Elementary",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001762",
    },
    {
        "school": "Dodge Literacy Magnet",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001798",
    },
    {
        "school": "Stucky Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001799",
    },
    {
        "school": "Jardine Technology Middle Magnet",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001800",
    },
    {
        "school": "Wellington High School",
        "district": "Wellington",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201284001769",
    },
    {
        "school": "Argonia Elem",
        "district": "Argonia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200343000740",
    },
    {
        "school": "Argonia High",
        "district": "Argonia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200343000742",
    },
    {
        "school": "Belle Plaine Elem",
        "district": "Belle Plaine",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200390000736",
    },
    {
        "school": "Belle Plaine High",
        "district": "Belle Plaine",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200390000737",
    },
    {
        "school": "Belle Plaine Middle",
        "district": "Belle Plaine",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200390001584",
    },
    {
        "school": "Caldwell Elem",
        "district": "Caldwell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200438000743",
    },
    {
        "school": "Caldwell Secondary School",
        "district": "Caldwell",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200438000744",
    },
    {
        "school": "Conway Springs Kyle Trueblood",
        "district": "Conway Springs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200513000734",
    },
    {
        "school": "Conway Springs High School",
        "district": "Conway Springs",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200513000735",
    },
    {
        "school": "Conway Springs Middle School",
        "district": "Conway Springs",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200513001701",
    },
    {
        "school": "Oxford Elem",
        "district": "Oxford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201044000738",
    },
    {
        "school": "Oxford Jr/Sr High",
        "district": "Oxford",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201044000739",
    },
    {
        "school": "South Haven Elem",
        "district": "South Haven",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201179001509",
    },
    {
        "school": "South Haven High",
        "district": "South Haven",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201179001510",
    },
    {
        "school": "Eisenhower Elem",
        "district": "Wellington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201284000722",
    },
    {
        "school": "Kennedy Elem",
        "district": "Wellington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201284000723",
    },
    {
        "school": "Lincoln Elem",
        "district": "Wellington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201284000724",
    },
    {
        "school": "Washington Elem",
        "district": "Wellington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201284000726",
    },
    {
        "school": "Wellington Middle School",
        "district": "Wellington",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201284000727",
    },
    {
        "school": "Andover Middle School",
        "district": "Andover",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200336000859",
    },
    {
        "school": "Andover High",
        "district": "Andover",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200336000860",
    },
    {
        "school": "Robert M. Martin Elementary",
        "district": "Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200336001171",
    },
    {
        "school": "Meadowlark Elementary",
        "district": "Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200336001183",
    },
    {
        "school": "Andover Central Middle School",
        "district": "Andover",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200336001564",
    },
    {
        "school": "Andover Central High School",
        "district": "Andover",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200336001567",
    },
    {
        "school": "Cottonwood Elementary",
        "district": "Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200336001610",
    },
    {
        "school": "Sunflower Elementary School",
        "district": "Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200336001727",
    },
    {
        "school": "Ewalt Elementary",
        "district": "Augusta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200363000741",
    },
    {
        "school": "Garfield Elem",
        "district": "Augusta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200363000915",
    },
    {
        "school": "Lincoln Elem",
        "district": "Augusta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200363000916",
    },
    {
        "school": "Robinson Elem",
        "district": "Augusta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200363000917",
    },
    {
        "school": "Augusta Middle School",
        "district": "Augusta",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200363000918",
    },
    {
        "school": "Augusta Sr High",
        "district": "Augusta",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200363000919",
    },
    {
        "school": "Marvin Sisk Middle School",
        "district": "Douglass Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200561000725",
    },
    {
        "school": "Leonard C Seal Elem",
        "district": "Douglass Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200561000894",
    },
    {
        "school": "Douglass High",
        "district": "Douglass Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200561000895",
    },
    {
        "school": "Grandview Elem",
        "district": "El Dorado",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200573001327",
    },
    {
        "school": "El Dorado Middle",
        "district": "El Dorado",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200573001332",
    },
    {
        "school": "El Dorado High",
        "district": "El Dorado",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200573001333",
    },
    {
        "school": "Frederic Remington High",
        "district": "Remington-Whitewater",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200624000042",
    },
    {
        "school": "Remington Elementary at Potwin",
        "district": "Remington-Whitewater",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200624000044",
    },
    {
        "school": "Remington Middle School",
        "district": "Remington-Whitewater",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200624000045",
    },
    {
        "school": "Bluestem Elementary School",
        "district": "Bluestem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200855000037",
    },
    {
        "school": "Bluestem Jr/Sr High",
        "district": "Bluestem",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200855000038",
    },
    {
        "school": "Flinthills Primary School",
        "district": "Flinthills",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201122001337",
    },
    {
        "school": "Flinthills Intermediate School",
        "district": "Flinthills",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201122001338",
    },
    {
        "school": "Rose Hill Intermediate",
        "district": "Rose Hill Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201125000870",
    },
    {
        "school": "Rose Hill Primary",
        "district": "Rose Hill Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201125000885",
    },
    {
        "school": "Rose Hill High",
        "district": "Rose Hill Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201125000886",
    },
    {
        "school": "Rose Hill Middle",
        "district": "Rose Hill Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201125001592",
    },
    {
        "school": "Circle Benton Elementary",
        "district": "Circle",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201230000802",
    },
    {
        "school": "Circle High",
        "district": "Circle",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201230000803",
    },
    {
        "school": "Circle Oil Hill Elementary",
        "district": "Circle",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201230000804",
    },
    {
        "school": "Circle Towanda Elementary",
        "district": "Circle",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201230000805",
    },
    {
        "school": "Burrton Elem",
        "district": "Burrton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200435000780",
    },
    {
        "school": "Burrton MS/HS",
        "district": "Burrton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200435000781",
    },
    {
        "school": "Halstead Middle School",
        "district": "Halstead",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200684001079",
    },
    {
        "school": "Halstead High",
        "district": "Halstead",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200684001080",
    },
    {
        "school": "Hesston Elem",
        "district": "Hesston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200717001192",
    },
    {
        "school": "Hesston Middle",
        "district": "Hesston",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200717001193",
    },
    {
        "school": "Hesston High",
        "district": "Hesston",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200717001194",
    },
    {
        "school": "Newton Sr High",
        "district": "Newton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200996000796",
    },
    {
        "school": "R L Wright  Elem",
        "district": "Sedgwick Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201155001076",
    },
    {
        "school": "Sedgwick High",
        "district": "Sedgwick Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201155001077",
    },
    {
        "school": "Cheney Elem",
        "district": "Cheney",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200467000393",
    },
    {
        "school": "Cheney Middle School  6-8",
        "district": "Cheney",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200467000394",
    },
    {
        "school": "Cheney High",
        "district": "Cheney",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200467000395",
    },
    {
        "school": "Clearwater Intermediate - Middle School",
        "district": "Clearwater",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200492000376",
    },
    {
        "school": "Clearwater Elementary West",
        "district": "Clearwater",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200492000377",
    },
    {
        "school": "Clearwater High",
        "district": "Clearwater",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200492000378",
    },
    {
        "school": "El Paso Elem",
        "district": "Derby",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546000353",
    },
    {
        "school": "Oaklawn Elem",
        "district": "Derby",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546000354",
    },
    {
        "school": "Paul B Cooper Elem",
        "district": "Derby",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546000355",
    },
    {
        "school": "Pleasantview Elem",
        "district": "Derby",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546000356",
    },
    {
        "school": "Swaney Elem",
        "district": "Derby",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546000357",
    },
    {
        "school": "Wineteer Elem",
        "district": "Derby",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546000358",
    },
    {
        "school": "Derby High School",
        "district": "Derby",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546000361",
    },
    {
        "school": "Derby Middle Sch",
        "district": "Derby",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546001598",
    },
    {
        "school": "Tanglewood Elem",
        "district": "Derby",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546001599",
    },
    {
        "school": "Derby Hills Elem",
        "district": "Derby",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546001630",
    },
    {
        "school": "Oak Street Elementary School K-4",
        "district": "Goddard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200654000379",
    },
    {
        "school": "Goddard High",
        "district": "Goddard",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200654000381",
    },
    {
        "school": "Goddard Middle School",
        "district": "Goddard",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200654000698",
    },
    {
        "school": "Challenger Intermediate School",
        "district": "Goddard",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200654001334",
    },
    {
        "school": "Amelia Earhart Elementary School",
        "district": "Goddard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200654001551",
    },
    {
        "school": "Discovery Intermediate School",
        "district": "Goddard",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200654001557",
    },
    {
        "school": "Clark Davidson Elem",
        "district": "Goddard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200654001678",
    },
    {
        "school": "Bentley Primary School",
        "district": "Halstead",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200684001078",
    },
    {
        "school": "Campus High Haysville",
        "district": "Haysville",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200705000362",
    },
    {
        "school": "Haysville Middle School",
        "district": "Haysville",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200705000363",
    },
    {
        "school": "Nelson Elem",
        "district": "Haysville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200705000364",
    },
    {
        "school": "Oatville Elem",
        "district": "Haysville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200705000365",
    },
    {
        "school": "Rex Elem",
        "district": "Haysville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200705000366",
    },
    {
        "school": "Freeman Elem",
        "district": "Haysville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200705001634",
    },
    {
        "school": "Ruth Clark Elementary K-5",
        "district": "Haysville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200705001725",
    },
    {
        "school": "Maize Elementary",
        "district": "Maize",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200914000383",
    },
    {
        "school": "Maize South Middle School",
        "district": "Maize",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200914000384",
    },
    {
        "school": "Maize Sr High",
        "district": "Maize",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200914000385",
    },
    {
        "school": "Pray-Woodman Elementary",
        "district": "Maize",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200914000978",
    },
    {
        "school": "Maize Middle School",
        "district": "Maize",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200914001105",
    },
    {
        "school": "Maize South Elementary",
        "district": "Maize",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200914001666",
    },
    {
        "school": "Mulvane Elem W D Munson",
        "district": "Mulvane",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200984000372",
    },
    {
        "school": "Mulvane High",
        "district": "Mulvane",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200984000374",
    },
    {
        "school": "Mulvane Middle School",
        "district": "Mulvane",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200984001315",
    },
    {
        "school": "Mulvane Grade School",
        "district": "Mulvane",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200984001667",
    },
    {
        "school": "Andale Elem-Middle",
        "district": "Renwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201108000386",
    },
    {
        "school": "Andale High",
        "district": "Renwick",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201108000387",
    },
    {
        "school": "Colwich Elem",
        "district": "Renwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201108000388",
    },
    {
        "school": "Garden Plain Elem",
        "district": "Renwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201108000389",
    },
    {
        "school": "Garden Plain High",
        "district": "Renwick",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201108000390",
    },
    {
        "school": "Wheatland Elem",
        "district": "Valley Center Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201251000160",
    },
    {
        "school": "Abilene Elem",
        "district": "Valley Center Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201251000367",
    },
    {
        "school": "West Elem",
        "district": "Valley Center Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201251000368",
    },
    {
        "school": "Valley Center Middle School",
        "district": "Valley Center Pub Sch",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201251000369",
    },
    {
        "school": "Valley Center High",
        "district": "Valley Center Pub Sch",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201251000370",
    },
    {
        "school": "Greiffenstein Alternative Elementary",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000100",
    },
    {
        "school": "Levy Sp Ed Center",
        "district": "Wichita",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000113",
    },
    {
        "school": "Adams Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000249",
    },
    {
        "school": "Allen Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000251",
    },
    {
        "school": "Benton Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000253",
    },
    {
        "school": "Black Traditional Magnet Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000254",
    },
    {
        "school": "Buckner Performing Arts Magnet Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000257",
    },
    {
        "school": "Caldwell Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000258",
    },
    {
        "school": "Cessna Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000260",
    },
    {
        "school": "Chisholm Trail Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000262",
    },
    {
        "school": "Clark Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000263",
    },
    {
        "school": "Cleaveland Traditional Magnet Elementary",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000264",
    },
    {
        "school": "Cloud Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000265",
    },
    {
        "school": "College Hill Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000266",
    },
    {
        "school": "Colvin Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000267",
    },
    {
        "school": "Earhart Environ Magnet Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000269",
    },
    {
        "school": "Enterprise Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000271",
    },
    {
        "school": "Franklin Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000274",
    },
    {
        "school": "Gardiner Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000276",
    },
    {
        "school": "Griffith Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000279",
    },
    {
        "school": "Price-Harris Communications Magnet",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000280",
    },
    {
        "school": "Harry Street Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000281",
    },
    {
        "school": "Hyde Intl Studies/Commun Elem Magnet",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000282",
    },
    {
        "school": "Irving Elementary",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000284",
    },
    {
        "school": "Jefferson Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000286",
    },
    {
        "school": "Kensler Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000289",
    },
    {
        "school": "Lawrence Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000292",
    },
    {
        "school": "Linwood Elementary",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000295",
    },
    {
        "school": "L'Ouverture Computer Technology Magnet",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000297",
    },
    {
        "school": "McCollom Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000298",
    },
    {
        "school": "McLean Science/Tech Magnet Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000300",
    },
    {
        "school": "Minneha Core Knowledge Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000301",
    },
    {
        "school": "Mueller Aerospace/Engineering Discovery Magne",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000302",
    },
    {
        "school": "O K Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000305",
    },
    {
        "school": "Park Elementary",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000306",
    },
    {
        "school": "Payne Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000307",
    },
    {
        "school": "Peterson Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000308",
    },
    {
        "school": "Riverside Leadership Magnet Elementary",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000310",
    },
    {
        "school": "Seltzer Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000312",
    },
    {
        "school": "Pleasant Valley Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000315",
    },
    {
        "school": "Sowers Alternative High School",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000316",
    },
    {
        "school": "Stanley Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000317",
    },
    {
        "school": "Washington Accelerated Learning Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000320",
    },
    {
        "school": "Wells Alternative Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000321",
    },
    {
        "school": "White Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000322",
    },
    {
        "school": "Woodland Health / Wellness Magnet Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000324",
    },
    {
        "school": "Woodman Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000325",
    },
    {
        "school": "Allison Traditional Magnet Middle",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000326",
    },
    {
        "school": "Brooks Magnet Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000327",
    },
    {
        "school": "Curtis Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000328",
    },
    {
        "school": "Coleman Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000329",
    },
    {
        "school": "Hadley Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000330",
    },
    {
        "school": "Hamilton Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000331",
    },
    {
        "school": "Horace Mann Dual Language Magnet",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000333",
    },
    {
        "school": "Mayberry Cultural and Fine Arts Magnet Middle",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000337",
    },
    {
        "school": "Pleasant Valley Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000339",
    },
    {
        "school": "Robinson Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000340",
    },
    {
        "school": "Wilbur Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000342",
    },
    {
        "school": "Truesdell Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000343",
    },
    {
        "school": "East High",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000344",
    },
    {
        "school": "Wichita Alternative High",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000345",
    },
    {
        "school": "North High",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000346",
    },
    {
        "school": "South High",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000347",
    },
    {
        "school": "Southeast High",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000348",
    },
    {
        "school": "West High",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000349",
    },
    {
        "school": "Heights High",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000350",
    },
    {
        "school": "Northwest High",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000351",
    },
    {
        "school": "Bostic Traditional Magnet Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299000843",
    },
    {
        "school": "Kelly Liberal Arts Academy",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001086",
    },
    {
        "school": "Beech Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001619",
    },
    {
        "school": "Gammon Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001620",
    },
    {
        "school": "Anderson Elem",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001648",
    },
    {
        "school": "Northeast Magnet High School",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001694",
    },
    {
        "school": "Enders STEM and Leadership Magnet",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001706",
    },
    {
        "school": "Adams Elem",
        "district": "Arkansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200345001232",
    },
    {
        "school": "Frances Willard Elem",
        "district": "Arkansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200345001233",
    },
    {
        "school": "Jefferson Elem",
        "district": "Arkansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200345001234",
    },
    {
        "school": "Roosevelt Elem",
        "district": "Arkansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200345001237",
    },
    {
        "school": "Arkansas City Middle Sch",
        "district": "Arkansas City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200345001240",
    },
    {
        "school": "Arkansas City High",
        "district": "Arkansas City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200345001241",
    },
    {
        "school": "C 4 Elem",
        "district": "Arkansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200345001242",
    },
    {
        "school": "I X L Elem",
        "district": "Arkansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200345001243",
    },
    {
        "school": "Central Elem",
        "district": "Central",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200423001198",
    },
    {
        "school": "Central Jr-Sr High",
        "district": "Central",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200423001200",
    },
    {
        "school": "Dexter Elem",
        "district": "Dexter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200552001244",
    },
    {
        "school": "Dexter High",
        "district": "Dexter",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200552001245",
    },
    {
        "school": "Udall Elem",
        "district": "Udall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201239001202",
    },
    {
        "school": "Udall High",
        "district": "Udall",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201239001203",
    },
    {
        "school": "Udall Middle School",
        "district": "Udall",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201239001583",
    },
    {
        "school": "Country View Elem",
        "district": "Winfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201305001206",
    },
    {
        "school": "Irving Elem",
        "district": "Winfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201305001210",
    },
    {
        "school": "Lowell Elem",
        "district": "Winfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201305001211",
    },
    {
        "school": "Whittier Elem",
        "district": "Winfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201305001212",
    },
    {
        "school": "Winfield High",
        "district": "Winfield",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201305001214",
    },
    {
        "school": "Adair County Elementary School",
        "district": "Adair County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210003002021",
    },
    {
        "school": "Allen County Career and Technical Center",
        "district": "Allen County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210007002061",
    },
    {
        "school": "Kentucky TECH - Anderson County Tech Ctr",
        "district": "Anderson County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210012002086",
    },
    {
        "school": "Happy Valley Learning Center",
        "district": "Glasgow Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210222002101",
    },
    {
        "school": "Bowling Green Technical - Glasgow",
        "district": "Glasgow Independent",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210222002109",
    },
    {
        "school": "Cumberland Tech - Southeast Campus",
        "district": "Middlesboro Independent",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210417002066",
    },
    {
        "school": "Southeast TECH",
        "district": "Middlesboro Independent",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210417002074",
    },
    {
        "school": "Cumberland Valley Health Tech Center",
        "district": "Pineville Independent",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210486002089",
    },
    {
        "school": "Cumberland Technical College",
        "district": "Pineville Independent",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210486002149",
    },
    {
        "school": "Shirley Mann Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051002022",
    },
    {
        "school": "Kentucky TECH - Ashland Reg Tech Ctr",
        "district": "Boyd County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210062002171",
    },
    {
        "school": "Ashland Technical College",
        "district": "Boyd County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210062002186",
    },
    {
        "school": "North Point Education Center",
        "district": "Boyle County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210063002041",
    },
    {
        "school": "Spring Meadows",
        "district": "Bullitt County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210075002169",
    },
    {
        "school": "Northern KY Tech - Highland Hts",
        "district": "Campbell County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210090002082",
    },
    {
        "school": "North Campbell TECH",
        "district": "Campbell County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210090002157",
    },
    {
        "school": "Madisonville Tech - Hopkinsville",
        "district": "Christian County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210115002179",
    },
    {
        "school": "Clark County Preschool",
        "district": "Clark County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210120002120",
    },
    {
        "school": "Foothills Academy",
        "district": "Clinton County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210126002162",
    },
    {
        "school": "Kentucky TECH - Daviess County Campus",
        "district": "Daviess County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210147002110",
    },
    {
        "school": "Kentucky TECH - Owensboro Campus",
        "district": "Owensboro Independent",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210459002125",
    },
    {
        "school": "Owensboro Technical College",
        "district": "Owensboro Independent",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210459002184",
    },
    {
        "school": "Fayette Regional Juvenile Det Ctr",
        "district": "Fayette County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210186002025",
    },
    {
        "school": "Central Ky Technical College",
        "district": "Fayette County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210186002067",
    },
    {
        "school": "Kentucky TECH - Central Campus",
        "district": "Fayette County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210186002075",
    },
    {
        "school": "Blackburn Education Center",
        "district": "Fayette County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210186002150",
    },
    {
        "school": "Frankfort Career Development Center",
        "district": "Franklin County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210201002165",
    },
    {
        "school": "Fulton County Elementary",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210210002113",
    },
    {
        "school": "Cumberland Tech - Harlan Campus",
        "district": "Harlan County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210254002058",
    },
    {
        "school": "Kentucky TECH - Harlan Regional Tech Ctr",
        "district": "Harlan County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210254002135",
    },
    {
        "school": "Kentucky TECH - Madisonville Reg Tech Ct",
        "district": "Hopkins County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210286002083",
    },
    {
        "school": "Madisonville Technical College",
        "district": "Hopkins County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210286002098",
    },
    {
        "school": "Madisonville Health Technology Center",
        "district": "Hopkins County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210286002158",
    },
    {
        "school": "Marion C. Moore School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299002026",
    },
    {
        "school": "J. Graham Brown School",
        "district": "Jefferson County",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299002027",
    },
    {
        "school": "Center at Riverport",
        "district": "Jefferson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299002063",
    },
    {
        "school": "Jefferson Technical College",
        "district": "Jefferson County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210299002071",
    },
    {
        "school": "The Phoenix School of Discovery",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299002121",
    },
    {
        "school": "Kentucky TECH - Jefferson Campus",
        "district": "Jefferson County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210299002146",
    },
    {
        "school": "Newcomer Academy",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299002180",
    },
    {
        "school": "Jessamine Career and Technology Center",
        "district": "Jessamine County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210303002028",
    },
    {
        "school": "Mayo Technical College",
        "district": "Johnson County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210306002038",
    },
    {
        "school": "Carl D Perkins Comprehensive Rehab Ctr",
        "district": "Johnson County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210306002103",
    },
    {
        "school": "Kentucky TECH - Mayo Regional Tech Ctr",
        "district": "Johnson County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210306002111",
    },
    {
        "school": "Northern KY Technical College",
        "district": "Kenton County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210309002068",
    },
    {
        "school": "Northern KY Tech - Edgewood",
        "district": "Kenton County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210309002076",
    },
    {
        "school": "Kenton CO Academies of Innovation & Tech",
        "district": "Kenton County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210309002092",
    },
    {
        "school": "Northern Kentucky TECH",
        "district": "Kenton County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210309002151",
    },
    {
        "school": "Northern Ky Health Technology Center",
        "district": "Kenton County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210309002166",
    },
    {
        "school": "Knox County Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210315002029",
    },
    {
        "school": "Abraham Lincoln Elementary School",
        "district": "LaRue County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210318002044",
    },
    {
        "school": "Louisa East Elementary School",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210324002079",
    },
    {
        "school": "Louisa West Elementary School",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210324002155",
    },
    {
        "school": "Eddyville Education Center",
        "district": "Lyon County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210369002108",
    },
    {
        "school": "Western KY Education Center",
        "district": "Lyon County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210369002181",
    },
    {
        "school": "West KY Technical College",
        "district": "McCracken County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210396002112",
    },
    {
        "school": "Glenn R Marshall Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372002032",
    },
    {
        "school": "Star Academy High School",
        "district": "Marshall County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210381002073",
    },
    {
        "school": "Mercer County Day Treatment",
        "district": "Mercer County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210411001491",
    },
    {
        "school": "Mercer County Senior High School",
        "district": "Mercer County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210411002168",
    },
    {
        "school": "Eastern KY Education Center",
        "district": "Morgan County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210429002133",
    },
    {
        "school": "Green River Education Center",
        "district": "Muhlenberg County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210008102081",
    },
    {
        "school": "Muhlenberg County Career & Tech Center",
        "district": "Muhlenberg County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210008102139",
    },
    {
        "school": "Luther Luckett Education Center",
        "district": "Oldham County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210453002119",
    },
    {
        "school": "La Grange Education Center",
        "district": "Oldham County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210453002144",
    },
    {
        "school": "Kentucky TECH - Hazard Regional Tech Ctr",
        "district": "Hazard Independent",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210267002100",
    },
    {
        "school": "Hazard Community College Tech Campus",
        "district": "Hazard Independent",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210267002159",
    },
    {
        "school": "Memorial Education Center",
        "district": "Pulaski County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495002065",
    },
    {
        "school": "Southside Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532002077",
    },
    {
        "school": "Trigg County Primary School",
        "district": "Trigg County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210558002093",
    },
    {
        "school": "Trigg County Intermediate School",
        "district": "Trigg County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210558002167",
    },
    {
        "school": "Union County Area Vocational Ed Center",
        "district": "Union County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210564002175",
    },
    {
        "school": "KY Advanced Tech Center",
        "district": "Warren County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210573002045",
    },
    {
        "school": "Ky TECH - Bowling Green Regional Tech Center",
        "district": "Warren County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210573002080",
    },
    {
        "school": "Bowling Green Technical College",
        "district": "Warren County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210573002132",
    },
    {
        "school": "Kentucky Advanced Technology Center",
        "district": "Warren County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210573002185",
    },
    {
        "school": "North Butler Elementary",
        "district": "Butler County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210081001976",
    },
    {
        "school": "Butler County Learning Center",
        "district": "Butler County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210081001977",
    },
    {
        "school": "Jones Park Elementary",
        "district": "Casey County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210105001981",
    },
    {
        "school": "Sunshine School",
        "district": "Harlan Independent",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210252002046",
    },
    {
        "school": "Harrison County Learning Center",
        "district": "Harrison County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210258001995",
    },
    {
        "school": "Barbourville City School",
        "district": "Barbourville Independent",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210024001969",
    },
    {
        "school": "Knox Appalachian School",
        "district": "Knox County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210315001997",
    },
    {
        "school": "Letcher County Central High School",
        "district": "Letcher County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210336001998",
    },
    {
        "school": "Lyon County Middle School",
        "district": "Lyon County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210369001950",
    },
    {
        "school": "McCreary County Middle School",
        "district": "McCreary County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210399002002",
    },
    {
        "school": "East Ridge High School",
        "district": "Pike County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001948",
    },
    {
        "school": "Feds Creek Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480002012",
    },
    {
        "school": "Belfry Middle School",
        "district": "Pike County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480002013",
    },
    {
        "school": "McBrayer Elementary School",
        "district": "Rowan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210510002016",
    },
    {
        "school": "Rowan County Preschool Center",
        "district": "Rowan County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210510002033",
    },
    {
        "school": "Horizons High School",
        "district": "Todd County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210555002034",
    },
    {
        "school": "Washington County Middle School",
        "district": "Washington County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210576002047",
    },
    {
        "school": "Wayne County Middle School",
        "district": "Wayne County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210579002020",
    },
    {
        "school": "Adair County High School",
        "district": "Adair County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210003000001",
    },
    {
        "school": "Adair Learning Academy",
        "district": "Adair County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210003001913",
    },
    {
        "school": "Adair County Middle School",
        "district": "Adair County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210003001919",
    },
    {
        "school": "Allen County Primary Center",
        "district": "Allen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210007000008",
    },
    {
        "school": "James E Bazzell Middle School",
        "district": "Allen County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210007000009",
    },
    {
        "school": "Allen County-Scottsville High School",
        "district": "Allen County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210007000010",
    },
    {
        "school": "Allen County Intermediate Center",
        "district": "Allen County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210007000013",
    },
    {
        "school": "Breathitt County High School",
        "district": "Breathitt County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210069000129",
    },
    {
        "school": "Sebastian Elementary School",
        "district": "Breathitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210069000132",
    },
    {
        "school": "Marie Roberts-Caney Elementary School",
        "district": "Breathitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210069000133",
    },
    {
        "school": "Breathitt Regional Juvenile Det Ctr",
        "district": "Breathitt County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210069001623",
    },
    {
        "school": "Breathitt County Day Treatment",
        "district": "Breathitt County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210069001842",
    },
    {
        "school": "Jackson City School",
        "district": "Jackson Independent",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210291001719",
    },
    {
        "school": "Breckinridge County High School",
        "district": "Breckinridge County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210072000137",
    },
    {
        "school": "Hardinsburg Elementary School",
        "district": "Breckinridge County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210072000138",
    },
    {
        "school": "Ben Johnson Elementary School",
        "district": "Breckinridge County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210072000139",
    },
    {
        "school": "Custer Elementary School",
        "district": "Breckinridge County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210072000140",
    },
    {
        "school": "Irvington Elementary School",
        "district": "Breckinridge County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210072000141",
    },
    {
        "school": "Breckinridge County Middle School",
        "district": "Breckinridge County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210072001304",
    },
    {
        "school": "Frederick Fraize High School",
        "district": "Cloverport Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210129000261",
    },
    {
        "school": "William H Natcher Elementary School",
        "district": "Cloverport Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210129000262",
    },
    {
        "school": "Frederick Fraize Middle School",
        "district": "Cloverport Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210129000907",
    },
    {
        "school": "Butler County High School",
        "district": "Butler County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210081000160",
    },
    {
        "school": "Green River School",
        "district": "Butler County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210081000163",
    },
    {
        "school": "Morgantown Elementary School",
        "district": "Butler County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210081000164",
    },
    {
        "school": "Butler County Middle School",
        "district": "Butler County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210081001697",
    },
    {
        "school": "Caldwell County High School",
        "district": "Caldwell County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210084000166",
    },
    {
        "school": "Caldwell County Middle School",
        "district": "Caldwell County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210084000167",
    },
    {
        "school": "Caldwell County Elementary School",
        "district": "Caldwell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210084000170",
    },
    {
        "school": "Caldwell County Primary School",
        "district": "Caldwell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210084001660",
    },
    {
        "school": "Carlisle County Middle School",
        "district": "Carlisle County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210096000185",
    },
    {
        "school": "Carlisle County High School",
        "district": "Carlisle County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210096000186",
    },
    {
        "school": "Carlisle County Elementary School",
        "district": "Carlisle County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210096000187",
    },
    {
        "school": "Cartmell Elementary",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210099000188",
    },
    {
        "school": "Kathryn Winn Primary",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210099000189",
    },
    {
        "school": "Carroll County High School",
        "district": "Carroll County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210099000190",
    },
    {
        "school": "Carroll County Middle School",
        "district": "Carroll County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210099000191",
    },
    {
        "school": "Casey County High School",
        "district": "Casey County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210105000204",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Casey County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210105000208",
    },
    {
        "school": "Casey County Middle School",
        "district": "Casey County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210105001579",
    },
    {
        "school": "Big Creek Elementary",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210123000247",
    },
    {
        "school": "Burning Springs Elementary",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210123000248",
    },
    {
        "school": "Clay County High School",
        "district": "Clay County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210123000249",
    },
    {
        "school": "Goose Rock Elementary",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210123000251",
    },
    {
        "school": "Hacker Elementary School",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210123000252",
    },
    {
        "school": "Manchester Elementary School",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210123000255",
    },
    {
        "school": "Oneida Elementary School",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210123000256",
    },
    {
        "school": "Paces Creek Elementary",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210123001413",
    },
    {
        "school": "Clay County Middle School",
        "district": "Clay County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210123001699",
    },
    {
        "school": "Horse Creek Learning Center",
        "district": "Clay County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210123001846",
    },
    {
        "school": "Albany Elementary School",
        "district": "Clinton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210126000257",
    },
    {
        "school": "Clinton County High School",
        "district": "Clinton County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210126000259",
    },
    {
        "school": "Clinton County Middle School",
        "district": "Clinton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210126000444",
    },
    {
        "school": "Crittenden County High School",
        "district": "Crittenden County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210138000279",
    },
    {
        "school": "Crittenden County Middle School",
        "district": "Crittenden County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210138000280",
    },
    {
        "school": "Crittenden County Elementary School",
        "district": "Crittenden County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210138001441",
    },
    {
        "school": "Cumberland County Elementary School",
        "district": "Cumberland County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210141000286",
    },
    {
        "school": "Cumberland County High School",
        "district": "Cumberland County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210141000287",
    },
    {
        "school": "Cumberland County Middle School",
        "district": "Cumberland County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210141001561",
    },
    {
        "school": "Isonville Elementary School",
        "district": "Elliott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210168000328",
    },
    {
        "school": "Lakeside Elementary School",
        "district": "Elliott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210168000329",
    },
    {
        "school": "Sandy Hook Elementary School",
        "district": "Elliott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210168000330",
    },
    {
        "school": "Elliott County High School",
        "district": "Elliott County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210168000331",
    },
    {
        "school": "Estill County Middle School",
        "district": "Estill County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210176000341",
    },
    {
        "school": "Estill County High School",
        "district": "Estill County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210176000342",
    },
    {
        "school": "South Irvine Early Learning Center",
        "district": "Estill County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210176000345",
    },
    {
        "school": "West Irvine Intermediate",
        "district": "Estill County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210176000346",
    },
    {
        "school": "Estill Springs Elementary",
        "district": "Estill County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210176001746",
    },
    {
        "school": "Ewing Elementary School",
        "district": "Fleming County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210192000396",
    },
    {
        "school": "Simons Middle School",
        "district": "Fleming County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210192000397",
    },
    {
        "school": "Fleming County High School",
        "district": "Fleming County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210192000398",
    },
    {
        "school": "Flemingsburg Elementary School",
        "district": "Fleming County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210192000399",
    },
    {
        "school": "E P Ward Elementary School",
        "district": "Fleming County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210192000400",
    },
    {
        "school": "Hillsboro Elementary School",
        "district": "Fleming County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210192000401",
    },
    {
        "school": "Allen Elementary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195000403",
    },
    {
        "school": "Betsy Layne High School",
        "district": "Floyd County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195000406",
    },
    {
        "school": "Betsy Layne Elementary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195000407",
    },
    {
        "school": "John M. Stumbo Elementary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195000415",
    },
    {
        "school": "Prestonsburg High School",
        "district": "Floyd County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195000423",
    },
    {
        "school": "Renaissance Learning Center",
        "district": "Floyd County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210195001004",
    },
    {
        "school": "May Valley Elementary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195001426",
    },
    {
        "school": "James D. Adams Middle School",
        "district": "Floyd County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195001670",
    },
    {
        "school": "Camp Dick Robinson Elementary School",
        "district": "Garrard County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210216000454",
    },
    {
        "school": "Garrard County High School",
        "district": "Garrard County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210216000455",
    },
    {
        "school": "Paint Lick Elementary School",
        "district": "Garrard County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210216000456",
    },
    {
        "school": "Lancaster Elementary School",
        "district": "Garrard County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210216000457",
    },
    {
        "school": "Garrard Middle School",
        "district": "Garrard County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210216001672",
    },
    {
        "school": "H W Wilkey Elementary School",
        "district": "Grayson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210230000483",
    },
    {
        "school": "Caneyville Elementary School",
        "district": "Grayson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210230000484",
    },
    {
        "school": "Clarkson Elementary School",
        "district": "Grayson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210230000485",
    },
    {
        "school": "Grayson County High School",
        "district": "Grayson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210230000486",
    },
    {
        "school": "Grayson County Middle School",
        "district": "Grayson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210230000487",
    },
    {
        "school": "Oran P Lawler Elementary School",
        "district": "Grayson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210230001702",
    },
    {
        "school": "Grayson Co. Alternative Education",
        "district": "Grayson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210230001852",
    },
    {
        "school": "Green County High School",
        "district": "Green County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210234000490",
    },
    {
        "school": "Green County Middle School",
        "district": "Green County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210234001526",
    },
    {
        "school": "Harlan Elementary School",
        "district": "Harlan Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210252000551",
    },
    {
        "school": "Harlan High School",
        "district": "Harlan Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210252000552",
    },
    {
        "school": "Cumberland Elementary School",
        "district": "Harlan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210254000091",
    },
    {
        "school": "Black Mountain Elementary School",
        "district": "Harlan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210254000532",
    },
    {
        "school": "Cawood Elementary School",
        "district": "Harlan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210254000534",
    },
    {
        "school": "Evarts Elementary School",
        "district": "Harlan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210254000539",
    },
    {
        "school": "Green Hills Elementary School",
        "district": "Harlan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210254000540",
    },
    {
        "school": "James A. Cawood Elementary",
        "district": "Harlan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210254000541",
    },
    {
        "school": "Rosspoint Elementary School",
        "district": "Harlan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210254000545",
    },
    {
        "school": "Wallins Elementary School",
        "district": "Harlan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210254000549",
    },
    {
        "school": "Eastside Elementary School",
        "district": "Harrison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210258000553",
    },
    {
        "school": "Southside Elementary School",
        "district": "Harrison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210258000554",
    },
    {
        "school": "Harrison County High School",
        "district": "Harrison County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210258000555",
    },
    {
        "school": "Harrison County Middle School",
        "district": "Harrison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210258000556",
    },
    {
        "school": "Northside Elementary School",
        "district": "Harrison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210258000557",
    },
    {
        "school": "Westside Elementary School",
        "district": "Harrison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210258000558",
    },
    {
        "school": "Bonnieville Elementary School",
        "district": "Hart County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210264000562",
    },
    {
        "school": "Cub Run Elementary School",
        "district": "Hart County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210264000563",
    },
    {
        "school": "Hart County High School",
        "district": "Hart County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210264000564",
    },
    {
        "school": "Legrande Elementary School",
        "district": "Hart County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210264000565",
    },
    {
        "school": "Memorial Elementary School",
        "district": "Hart County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210264000566",
    },
    {
        "school": "Munfordville Elementary School",
        "district": "Hart County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210264000567",
    },
    {
        "school": "Hickman County Elementary School",
        "district": "Hickman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210279000593",
    },
    {
        "school": "Hickman County High School",
        "district": "Hickman County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210279000594",
    },
    {
        "school": "Jackson County High School",
        "district": "Jackson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210294000615",
    },
    {
        "school": "McKee Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210294000617",
    },
    {
        "school": "Sand Gap Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210294000619",
    },
    {
        "school": "Tyner Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210294000620",
    },
    {
        "school": "Jackson County Middle School",
        "district": "Jackson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210294001674",
    },
    {
        "school": "Central Elementary School",
        "district": "Johnson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210306000692",
    },
    {
        "school": "Johnson County Middle School",
        "district": "Johnson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210306000800",
    },
    {
        "school": "Flat Gap Elementary School",
        "district": "Johnson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210306000801",
    },
    {
        "school": "Johnson Central High School",
        "district": "Johnson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210306000802",
    },
    {
        "school": "Porter Elementary School",
        "district": "Johnson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210306000803",
    },
    {
        "school": "W R Castle Memorial Elementary School",
        "district": "Johnson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210306000805",
    },
    {
        "school": "Highland Elementary School",
        "district": "Johnson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210306000806",
    },
    {
        "school": "Johnson County Alternative School",
        "district": "Johnson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210306001615",
    },
    {
        "school": "Paintsville Elementary School",
        "district": "Paintsville Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210468001155",
    },
    {
        "school": "Paintsville High School",
        "district": "Paintsville Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210468001156",
    },
    {
        "school": "Beaver Creek Elementary School",
        "district": "Knott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210312000826",
    },
    {
        "school": "Carr Creek Elementary School",
        "district": "Knott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210312000830",
    },
    {
        "school": "Emmalena Elementary School",
        "district": "Knott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210312000834",
    },
    {
        "school": "Hindman Elementary School",
        "district": "Knott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210312000835",
    },
    {
        "school": "Jones Fork Elementary School",
        "district": "Knott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210312000836",
    },
    {
        "school": "Knott County Central High School",
        "district": "Knott County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210312000837",
    },
    {
        "school": "Knox County Learning Academy",
        "district": "Knox County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210315000709",
    },
    {
        "school": "Dewitt Elementary School",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210315000842",
    },
    {
        "school": "Flat Lick Elementary School",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210315000843",
    },
    {
        "school": "Girdler Elementary School",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210315000844",
    },
    {
        "school": "G R Hampton Elementary School",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210315000846",
    },
    {
        "school": "Knox Central High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210315000847",
    },
    {
        "school": "Jesse D Lay Elementary School",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210315000848",
    },
    {
        "school": "Lynn Camp Schools",
        "district": "Knox County",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210315000850",
    },
    {
        "school": "Blaine Elementary School",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210324000870",
    },
    {
        "school": "Fallsburg Elementary School",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210324000871",
    },
    {
        "school": "Louisa Middle School",
        "district": "Lawrence County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210324000872",
    },
    {
        "school": "Lawrence County High School",
        "district": "Lawrence County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210324000874",
    },
    {
        "school": "Lee County Elementary School",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210327000216",
    },
    {
        "school": "Hayes Lewis Elementary School",
        "district": "Leslie County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210333000882",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Leslie County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210333000883",
    },
    {
        "school": "Leslie County High School",
        "district": "Leslie County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210333000885",
    },
    {
        "school": "W B Muncy Elementary School",
        "district": "Leslie County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210333000886",
    },
    {
        "school": "Stinnett Elementary School",
        "district": "Leslie County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210333000887",
    },
    {
        "school": "Jenkins Independent School",
        "district": "Jenkins Independent",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210300001642",
    },
    {
        "school": "Arlie Boggs Elementary School",
        "district": "Letcher County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210336000892",
    },
    {
        "school": "Fleming Neon Middle School",
        "district": "Letcher County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210336000894",
    },
    {
        "school": "Letcher Elementary School",
        "district": "Letcher County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210336000898",
    },
    {
        "school": "Cowan Elementary School",
        "district": "Letcher County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210336000900",
    },
    {
        "school": "Martha Jane Potter Elementary School",
        "district": "Letcher County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210336000901",
    },
    {
        "school": "West Whitesburg Elementary School",
        "district": "Letcher County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210336000903",
    },
    {
        "school": "Whitesburg Middle School",
        "district": "Letcher County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210336000904",
    },
    {
        "school": "Logan County High School",
        "district": "Logan County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210354001458",
    },
    {
        "school": "Adairville Elementary School",
        "district": "Logan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210354001542",
    },
    {
        "school": "Auburn Elementary School",
        "district": "Logan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210354001543",
    },
    {
        "school": "Chandlers Elementary School",
        "district": "Logan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210354001544",
    },
    {
        "school": "Lewisburg Elementary School",
        "district": "Logan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210354001545",
    },
    {
        "school": "Olmstead Elementary School",
        "district": "Logan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210354001546",
    },
    {
        "school": "R E Stevenson Elementary School",
        "district": "Russellville Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210519001274",
    },
    {
        "school": "Russellville High School",
        "district": "Russellville Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210519001275",
    },
    {
        "school": "Lyon County Elementary School",
        "district": "Lyon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210369000942",
    },
    {
        "school": "Lyon County High School",
        "district": "Lyon County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210369000943",
    },
    {
        "school": "McCreary Central High School",
        "district": "McCreary County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210399001014",
    },
    {
        "school": "Whitley City Elementary School",
        "district": "McCreary County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210399001021",
    },
    {
        "school": "McCreary County Preschool South",
        "district": "McCreary County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210399001548",
    },
    {
        "school": "McCreary Academy",
        "district": "McCreary County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210399001805",
    },
    {
        "school": "Salyersville Grade School",
        "district": "Magoffin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210375000958",
    },
    {
        "school": "Magoffin County High School",
        "district": "Magoffin County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210375000960",
    },
    {
        "school": "Herald Whitaker Middle School",
        "district": "Magoffin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210375001618",
    },
    {
        "school": "Calvary Elementary School",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210378000962",
    },
    {
        "school": "Glasscock Elementary School",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210378000963",
    },
    {
        "school": "Lebanon Elementary School",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210378000967",
    },
    {
        "school": "Marion County High School",
        "district": "Marion County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210378000970",
    },
    {
        "school": "West Marion Elementary School",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210378001619",
    },
    {
        "school": "Central Elementary School",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210381000272",
    },
    {
        "school": "Benton Elementary School",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210381000971",
    },
    {
        "school": "Calvert City Elementary School",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210381000973",
    },
    {
        "school": "Jonathan Elementary School",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210381000975",
    },
    {
        "school": "Marshall County High School",
        "district": "Marshall County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210381000976",
    },
    {
        "school": "North Marshall Middle School",
        "district": "Marshall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210381000977",
    },
    {
        "school": "Sharpe Elementary School",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210381000978",
    },
    {
        "school": "South Marshall Elementary School",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210381000979",
    },
    {
        "school": "Marshall County Technical Center",
        "district": "Marshall County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210381001509",
    },
    {
        "school": "Inez Elementary School",
        "district": "Martin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210384000982",
    },
    {
        "school": "Martin County High School",
        "district": "Martin County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210384000985",
    },
    {
        "school": "Warfield Elementary School",
        "district": "Martin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210384000988",
    },
    {
        "school": "Martin County Head Start Preschool",
        "district": "Martin County",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210384001537",
    },
    {
        "school": "Eden Elementary School",
        "district": "Martin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210384001902",
    },
    {
        "school": "Kenneth D. King Middle School",
        "district": "Mercer County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210411000482",
    },
    {
        "school": "Mercer County Elementary School",
        "district": "Mercer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210411001042",
    },
    {
        "school": "Gamaliel Elementary",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210420001052",
    },
    {
        "school": "Monroe Co Middle",
        "district": "Monroe County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210420001053",
    },
    {
        "school": "Joe Harrison Carter",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210420001054",
    },
    {
        "school": "Tompkinsville Elem",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210420001055",
    },
    {
        "school": "Monroe Co High",
        "district": "Monroe County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210420001056",
    },
    {
        "school": "Ezel Elementary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210429001066",
    },
    {
        "school": "Morgan County Middle School",
        "district": "Morgan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210429001067",
    },
    {
        "school": "Morgan County High School",
        "district": "Morgan County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210429001068",
    },
    {
        "school": "Woodsbend Youth Development Center",
        "district": "Morgan County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210429001070",
    },
    {
        "school": "East Valley Elementary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210429001549",
    },
    {
        "school": "Nicholas County Elementary School",
        "district": "Nicholas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210447001106",
    },
    {
        "school": "Nicholas County High School",
        "district": "Nicholas County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210447001107",
    },
    {
        "school": "Beaver Dam Elementary School",
        "district": "Ohio County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210450001108",
    },
    {
        "school": "Fordsville Elementary School",
        "district": "Ohio County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210450001112",
    },
    {
        "school": "Ohio County Middle School",
        "district": "Ohio County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210450001114",
    },
    {
        "school": "Horse Branch Elementary School",
        "district": "Ohio County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210450001115",
    },
    {
        "school": "Ohio County High School",
        "district": "Ohio County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210450001116",
    },
    {
        "school": "Southern Elementary School",
        "district": "Ohio County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210450001118",
    },
    {
        "school": "Wayland Alexander Elementary School",
        "district": "Ohio County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210450001119",
    },
    {
        "school": "Western Elementary School",
        "district": "Ohio County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210450001120",
    },
    {
        "school": "Owen County Elementary/Primary School",
        "district": "Owen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210456001127",
    },
    {
        "school": "Owen County High School",
        "district": "Owen County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210456001128",
    },
    {
        "school": "Maurice Bowling Middle School",
        "district": "Owen County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210456001539",
    },
    {
        "school": "Highland-Turner Elementary School",
        "district": "Breathitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210069001659",
    },
    {
        "school": "Owsley County Elementary School",
        "district": "Owsley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210462001142",
    },
    {
        "school": "Owsley County High School",
        "district": "Owsley County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210462001143",
    },
    {
        "school": "Hazard High School",
        "district": "Hazard Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210267000568",
    },
    {
        "school": "Hazard Middle School",
        "district": "Hazard Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210267000569",
    },
    {
        "school": "Roy G. Eversole Elementary School",
        "district": "Hazard Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210267000570",
    },
    {
        "school": "Perry County Central High School",
        "district": "Perry County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210477000755",
    },
    {
        "school": "Buckhorn School",
        "district": "Perry County",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210477001166",
    },
    {
        "school": "Leatherwood Elementary School",
        "district": "Perry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210477001170",
    },
    {
        "school": "Robert W Combs Elementary School",
        "district": "Perry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210477001174",
    },
    {
        "school": "Robinson Elementary School",
        "district": "Perry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210477001175",
    },
    {
        "school": "Viper Elementary School",
        "district": "Perry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210477001177",
    },
    {
        "school": "Pike County Central High School",
        "district": "Pike County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480000505",
    },
    {
        "school": "Belfry High School",
        "district": "Pike County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001179",
    },
    {
        "school": "Bevins Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001180",
    },
    {
        "school": "Dorton Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001183",
    },
    {
        "school": "Elkhorn City Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001185",
    },
    {
        "school": "Johns Creek Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001195",
    },
    {
        "school": "Kimper Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001197",
    },
    {
        "school": "Mullins Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001202",
    },
    {
        "school": "Phelps Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001203",
    },
    {
        "school": "Phelps High School",
        "district": "Pike County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001204",
    },
    {
        "school": "Belfry Elementary",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001647",
    },
    {
        "school": "Shelby Valley High School",
        "district": "Pike County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480001686",
    },
    {
        "school": "Pikeville Elementary School",
        "district": "Pikeville Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210483001213",
    },
    {
        "school": "Pikeville High School",
        "district": "Pikeville Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210483001214",
    },
    {
        "school": "Bowen Elementary School",
        "district": "Powell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210489001217",
    },
    {
        "school": "Powell County Middle School",
        "district": "Powell County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210489001218",
    },
    {
        "school": "Clay City Elementary School",
        "district": "Powell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210489001219",
    },
    {
        "school": "Powell County High School",
        "district": "Powell County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210489001220",
    },
    {
        "school": "Stanton Elementary School",
        "district": "Powell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210489001221",
    },
    {
        "school": "Robertson County School",
        "district": "Robertson County",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210504001246",
    },
    {
        "school": "Rodburn Elementary School",
        "district": "Rowan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210510000787",
    },
    {
        "school": "Clearfield Elementary School",
        "district": "Rowan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210510001254",
    },
    {
        "school": "Morehead Youth Development Center",
        "district": "Rowan County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210510001258",
    },
    {
        "school": "Rowan County Senior High School",
        "district": "Rowan County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210510001260",
    },
    {
        "school": "Tilden Hogge Elementary School",
        "district": "Rowan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210510001261",
    },
    {
        "school": "Rowan County Middle School",
        "district": "Rowan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210510001478",
    },
    {
        "school": "Jamestown Elementary School",
        "district": "Russell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210516001263",
    },
    {
        "school": "Russell Springs Elementary School",
        "district": "Russell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210516001264",
    },
    {
        "school": "Russell County High School",
        "district": "Russell County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210516001265",
    },
    {
        "school": "Salem Elementary School",
        "district": "Russell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210516001266",
    },
    {
        "school": "Russell County Middle School",
        "district": "Russell County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210516001599",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Simpson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210540001299",
    },
    {
        "school": "Franklin-Simpson Middle School",
        "district": "Simpson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210540001300",
    },
    {
        "school": "Franklin-Simpson High School",
        "district": "Simpson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210540001301",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Simpson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210540001302",
    },
    {
        "school": "Simpson Elementary School",
        "district": "Simpson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210540001435",
    },
    {
        "school": "Franklin-Simpson High School West Campus",
        "district": "Simpson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210540001652",
    },
    {
        "school": "Todd County Middle School",
        "district": "Todd County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210555001324",
    },
    {
        "school": "Todd County Central High School",
        "district": "Todd County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210555001325",
    },
    {
        "school": "North Todd Elementary School",
        "district": "Todd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210555001600",
    },
    {
        "school": "South Todd Elementary School",
        "district": "Todd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210555001601",
    },
    {
        "school": "Morganfield Elementary School",
        "district": "Union County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210564001334",
    },
    {
        "school": "Sturgis Elementary School",
        "district": "Union County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210564001336",
    },
    {
        "school": "Union County High School",
        "district": "Union County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210564001338",
    },
    {
        "school": "Uniontown Elementary School",
        "district": "Union County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210564001339",
    },
    {
        "school": "Union County Middle School",
        "district": "Union County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210564001602",
    },
    {
        "school": "Union County Learning Academy",
        "district": "Union County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210564001872",
    },
    {
        "school": "Washington County High School",
        "district": "Washington County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210576001358",
    },
    {
        "school": "Washington County Elementary School",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210576001359",
    },
    {
        "school": "North Washington Elementary School",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210576001873",
    },
    {
        "school": "Wayne County High School",
        "district": "Wayne County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210579001224",
    },
    {
        "school": "Lake Cumberland Youth Development Center",
        "district": "Wayne County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210579001361",
    },
    {
        "school": "Walker Early Learning Center",
        "district": "Wayne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210579001365",
    },
    {
        "school": "Bell Elementary School",
        "district": "Wayne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210579001367",
    },
    {
        "school": "Red River Valley Elementary School",
        "district": "Wolfe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210597001394",
    },
    {
        "school": "Rogers Elementary School",
        "district": "Wolfe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210597001395",
    },
    {
        "school": "Campton Elementary School",
        "district": "Wolfe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210597001396",
    },
    {
        "school": "Wolfe County High School",
        "district": "Wolfe County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210597001397",
    },
    {
        "school": "Wolfe County Middle School",
        "district": "Wolfe County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210597001693",
    },
    {
        "school": "East Carter County High School",
        "district": "Carter County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210102000194",
    },
    {
        "school": "Olive Hill Elementary School",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210102000198",
    },
    {
        "school": "Prichard Elementary School",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210102000199",
    },
    {
        "school": "Star Elementary School",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210102000200",
    },
    {
        "school": "West Carter County High School",
        "district": "Carter County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210102000202",
    },
    {
        "school": "Carter County Career and Technical Center",
        "district": "Carter County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210102001439",
    },
    {
        "school": "West Carter Middle School",
        "district": "Carter County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210102001661",
    },
    {
        "school": "East Carter Middle School",
        "district": "Carter County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210102001698",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210102001884",
    },
    {
        "school": "Edmonson County 5/6 Center",
        "district": "Edmonson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210162001985",
    },
    {
        "school": "Plano Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573002035",
    },
    {
        "school": "South Edmonson Elementary School",
        "district": "Edmonson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210162000319",
    },
    {
        "school": "Edmonson County Middle School",
        "district": "Edmonson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210162000321",
    },
    {
        "school": "Kyrock Elementary School",
        "district": "Edmonson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210162000322",
    },
    {
        "school": "Edmonson County High School",
        "district": "Edmonson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210162001442",
    },
    {
        "school": "Dishman McGinnis Elementary School",
        "district": "Bowling Green Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210057000100",
    },
    {
        "school": "Parker-Bennett-Curry School",
        "district": "Bowling Green Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210057000102",
    },
    {
        "school": "Potter Gray Elementary",
        "district": "Bowling Green Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210057000103",
    },
    {
        "school": "Bowling Green Junior High",
        "district": "Bowling Green Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210057000104",
    },
    {
        "school": "Bowling Green High School",
        "district": "Bowling Green Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210057000105",
    },
    {
        "school": "T C Cherry Elementary School",
        "district": "Bowling Green Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210057000106",
    },
    {
        "school": "W R McNeill Elementary School",
        "district": "Bowling Green Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210057000107",
    },
    {
        "school": "Bowling Green Learning Center",
        "district": "Bowling Green Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210057001696",
    },
    {
        "school": "Childrens Crisis Stabilization Unit",
        "district": "Bowling Green Independent",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210057001830",
    },
    {
        "school": "Warren Regional Juvenile Detention Ctr",
        "district": "Bowling Green Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210057001911",
    },
    {
        "school": "Rivendell Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210573000828",
    },
    {
        "school": "Rivendell High School",
        "district": "Warren County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210573000839",
    },
    {
        "school": "Lost River Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001164",
    },
    {
        "school": "Alvaton Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001343",
    },
    {
        "school": "Bristow Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001344",
    },
    {
        "school": "Cumberland Trace Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001346",
    },
    {
        "school": "North Warren Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001347",
    },
    {
        "school": "Oakland Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001348",
    },
    {
        "school": "Rich Pond Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001349",
    },
    {
        "school": "Richardsville Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001350",
    },
    {
        "school": "Rockfield Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001351",
    },
    {
        "school": "Warren Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001352",
    },
    {
        "school": "Warren Central High School",
        "district": "Warren County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001353",
    },
    {
        "school": "Warren East High School",
        "district": "Warren County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001354",
    },
    {
        "school": "Warren County Day Treatment",
        "district": "Warren County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210573001540",
    },
    {
        "school": "Drakes Creek Middle School",
        "district": "Warren County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001603",
    },
    {
        "school": "Henry F. Moss Middle School",
        "district": "Warren County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001604",
    },
    {
        "school": "Warren East Middle School",
        "district": "Warren County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001605",
    },
    {
        "school": "William H. Natcher Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001691",
    },
    {
        "school": "Greenwood High School",
        "district": "Warren County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001692",
    },
    {
        "school": "Jackson Academy Middle School",
        "district": "Warren County",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210573001831",
    },
    {
        "school": "Briarwood Elementary School",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573001909",
    },
    {
        "school": "Lighthouse Academy",
        "district": "Warren County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210573001926",
    },
    {
        "school": "Campbellsville Elementary School",
        "district": "Campbellsville Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210093000182",
    },
    {
        "school": "Campbellsville High School",
        "district": "Campbellsville Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210093000183",
    },
    {
        "school": "Campbellsville Middle School",
        "district": "Campbellsville Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210093000184",
    },
    {
        "school": "Campbellsville Eagle Academy",
        "district": "Campbellsville Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210093001653",
    },
    {
        "school": "Taylor County Elementary School",
        "district": "Taylor County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210552001317",
    },
    {
        "school": "Taylor County High School",
        "district": "Taylor County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210552001318",
    },
    {
        "school": "Taylor County Middle School",
        "district": "Taylor County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210552001319",
    },
    {
        "school": "Muhlenberg South Elementary",
        "district": "Muhlenberg County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210008101967",
    },
    {
        "school": "Bremen Elementary School",
        "district": "Muhlenberg County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210008101072",
    },
    {
        "school": "Longest Elementary",
        "district": "Muhlenberg County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210008101080",
    },
    {
        "school": "Muhlenberg North Middle",
        "district": "Muhlenberg County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210008101081",
    },
    {
        "school": "Central City Elementary",
        "district": "Muhlenberg County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210008101514",
    },
    {
        "school": "The Renaissance Center",
        "district": "Muhlenberg County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210008101515",
    },
    {
        "school": "Greenville Elementary School",
        "district": "Muhlenberg County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210008101516",
    },
    {
        "school": "Muhlenberg South Middle School",
        "district": "Muhlenberg County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210008101517",
    },
    {
        "school": "Camp Ernst Middle School",
        "district": "Boone County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051001971",
    },
    {
        "school": "Augusta Independent School",
        "district": "Augusta Independent",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210018001968",
    },
    {
        "school": "Campbell Ridge Elementary",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210090001978",
    },
    {
        "school": "Holmes Middle School",
        "district": "Covington Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210135001944",
    },
    {
        "school": "Holmes High School",
        "district": "Covington Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210135002049",
    },
    {
        "school": "Bracken County High School",
        "district": "Bracken County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210066000125",
    },
    {
        "school": "Taylor Elementary School",
        "district": "Bracken County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210066000128",
    },
    {
        "school": "Bracken County Middle School",
        "district": "Bracken County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210066001560",
    },
    {
        "school": "Larry A. Ryle High School",
        "district": "Boone County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000011",
    },
    {
        "school": "A M Yealey Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000079",
    },
    {
        "school": "Rector A. Jones Middle School",
        "district": "Boone County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000080",
    },
    {
        "school": "Boone County High School",
        "district": "Boone County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000081",
    },
    {
        "school": "Burlington Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000082",
    },
    {
        "school": "Conner Middle School",
        "district": "Boone County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000083",
    },
    {
        "school": "Conner High School",
        "district": "Boone County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000084",
    },
    {
        "school": "Florence Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000085",
    },
    {
        "school": "Chester Goodridge Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000086",
    },
    {
        "school": "New Haven Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000088",
    },
    {
        "school": "Ockerman Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000089",
    },
    {
        "school": "Ockerman Middle School",
        "district": "Boone County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000090",
    },
    {
        "school": "Gray Middle School",
        "district": "Boone County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051000638",
    },
    {
        "school": "Charles H. Kelly Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051001519",
    },
    {
        "school": "Hillard Collins Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051001608",
    },
    {
        "school": "Stephens Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051001695",
    },
    {
        "school": "Erpenbeck Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051001710",
    },
    {
        "school": "North Pointe Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051001883",
    },
    {
        "school": "Walton-Verona Elementary School",
        "district": "Walton-Verona Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210570001341",
    },
    {
        "school": "Walton-Verona High School",
        "district": "Walton-Verona Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210570001342",
    },
    {
        "school": "Bellevue High School",
        "district": "Bellevue Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210042000075",
    },
    {
        "school": "Grandview Elementary School",
        "district": "Bellevue Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210042000076",
    },
    {
        "school": "Grant's Lick Elementary School",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210090000180",
    },
    {
        "school": "Campbell County High School",
        "district": "Campbell County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210090000941",
    },
    {
        "school": "Campbell County Middle School",
        "district": "Campbell County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210090001306",
    },
    {
        "school": "John W. Reiley Elementary School",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210090001320",
    },
    {
        "school": "Donald E. Cline Elementary School",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210090001335",
    },
    {
        "school": "Alexandria Educational Center",
        "district": "Campbell County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210090001398",
    },
    {
        "school": "Dayton High School",
        "district": "Dayton Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210153000316",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Dayton Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210153000317",
    },
    {
        "school": "Highlands High School",
        "district": "Fort Thomas Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210204000428",
    },
    {
        "school": "Johnson Elementary School",
        "district": "Fort Thomas Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210204000429",
    },
    {
        "school": "Moyer Elementary School",
        "district": "Fort Thomas Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210204000430",
    },
    {
        "school": "Woodfill Elementary School",
        "district": "Fort Thomas Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210204000431",
    },
    {
        "school": "Highlands Middle School",
        "district": "Fort Thomas Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210204001400",
    },
    {
        "school": "Newport Primary School",
        "district": "Newport Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210444001099",
    },
    {
        "school": "Newport Intermediate School",
        "district": "Newport Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210444001100",
    },
    {
        "school": "Newport High School",
        "district": "Newport Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210444001103",
    },
    {
        "school": "Southgate Public School",
        "district": "Southgate Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210546001313",
    },
    {
        "school": "Gallatin County Lower Elementary",
        "district": "Gallatin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210213000450",
    },
    {
        "school": "Gallatin County High School",
        "district": "Gallatin County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210213000451",
    },
    {
        "school": "Gallatin County Middle School",
        "district": "Gallatin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210213001609",
    },
    {
        "school": "Gallatin County Upper Elementary",
        "district": "Gallatin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210213001850",
    },
    {
        "school": "Crittenden-Mt. Zion Elementary",
        "district": "Grant County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210225000465",
    },
    {
        "school": "Dry Ridge Elementary",
        "district": "Grant County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210225000466",
    },
    {
        "school": "Grant County High School",
        "district": "Grant County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210225000467",
    },
    {
        "school": "Grant County Middle School",
        "district": "Grant County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210225000469",
    },
    {
        "school": "Mason-Corinth Elementary",
        "district": "Grant County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210225001701",
    },
    {
        "school": "Williamstown Elementary",
        "district": "Williamstown Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210594001392",
    },
    {
        "school": "Williamstown Jr. High",
        "district": "Williamstown Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210594001393",
    },
    {
        "school": "Beechwood Elementary School",
        "district": "Beechwood Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210036000059",
    },
    {
        "school": "Beechwood High School",
        "district": "Beechwood Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210036000060",
    },
    {
        "school": "John G Carlisle Elementary",
        "district": "Covington Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210135000270",
    },
    {
        "school": "Latonia Elementary School",
        "district": "Covington Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210135000271",
    },
    {
        "school": "Ninth District Elementary",
        "district": "Covington Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210135000274",
    },
    {
        "school": "Glenn O Swing Elementary",
        "district": "Covington Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210135000275",
    },
    {
        "school": "Sixth District Elementary School",
        "district": "Covington Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210135000276",
    },
    {
        "school": "Covington Adult High School",
        "district": "Covington Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210135001495",
    },
    {
        "school": "Biggs Early Childhood Education Ctr",
        "district": "Covington Independent",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210135001664",
    },
    {
        "school": "Transformational Learning Center",
        "district": "Covington Independent",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210135001783",
    },
    {
        "school": "Lindeman Elementary School",
        "district": "Erlanger-Elsmere Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210174000334",
    },
    {
        "school": "Arnett Elementary School",
        "district": "Erlanger-Elsmere Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210174000335",
    },
    {
        "school": "Howell Elementary School",
        "district": "Erlanger-Elsmere Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210174000336",
    },
    {
        "school": "Lloyd High School",
        "district": "Erlanger-Elsmere Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210174000337",
    },
    {
        "school": "Miles Elementary School",
        "district": "Erlanger-Elsmere Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210174000338",
    },
    {
        "school": "Tichenor Middle School",
        "district": "Erlanger-Elsmere Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210174000339",
    },
    {
        "school": "Beechgrove Elementary School",
        "district": "Kenton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000807",
    },
    {
        "school": "James A Caywood Elementary School",
        "district": "Kenton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000809",
    },
    {
        "school": "Dixie Heights High School",
        "district": "Kenton County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000811",
    },
    {
        "school": "R C Hinsdale Elementary School",
        "district": "Kenton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000812",
    },
    {
        "school": "Kenton Elementary School",
        "district": "Kenton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000813",
    },
    {
        "school": "Northern Ky Youth Dev Center",
        "district": "Kenton County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210309000814",
    },
    {
        "school": "Ft Wright Elementary School",
        "district": "Kenton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000815",
    },
    {
        "school": "Piner Elementary School",
        "district": "Kenton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000816",
    },
    {
        "school": "Ryland Heights Elementary School",
        "district": "Kenton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000817",
    },
    {
        "school": "Simon Kenton High School",
        "district": "Kenton County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000818",
    },
    {
        "school": "Taylor Mill Elementary School",
        "district": "Kenton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000819",
    },
    {
        "school": "Turkey Foot Middle School",
        "district": "Kenton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000820",
    },
    {
        "school": "Twenhofel Middle School",
        "district": "Kenton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000821",
    },
    {
        "school": "Scott High School",
        "district": "Kenton County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000823",
    },
    {
        "school": "White's Tower Elementary School",
        "district": "Kenton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309000824",
    },
    {
        "school": "River Ridge Elementary School",
        "district": "Kenton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309001512",
    },
    {
        "school": "Woodland Middle School",
        "district": "Kenton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309001588",
    },
    {
        "school": "Mary A. Goetz Elementary School",
        "district": "Ludlow Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210363000938",
    },
    {
        "school": "Ludlow High School",
        "district": "Ludlow Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210363000939",
    },
    {
        "school": "Northern Elementary School",
        "district": "Pendleton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210474001160",
    },
    {
        "school": "Pendleton County High School",
        "district": "Pendleton County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210474001161",
    },
    {
        "school": "Southern Elementary School",
        "district": "Pendleton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210474001163",
    },
    {
        "school": "Phillip Sharp Middle School",
        "district": "Pendleton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210474001646",
    },
    {
        "school": "Gateway Academy to Innovation & Tech.",
        "district": "Christian County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210115001938",
    },
    {
        "school": "Martin Luther King Jr. Elementary School",
        "district": "Christian County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115002024",
    },
    {
        "school": "Trigg County Middle School",
        "district": "Trigg County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210558001328",
    },
    {
        "school": "Trigg County High School",
        "district": "Trigg County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210558001329",
    },
    {
        "school": "Christian County High School",
        "district": "Christian County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115000220",
    },
    {
        "school": "Christian County Middle School",
        "district": "Christian County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115000221",
    },
    {
        "school": "Crofton Elementary School",
        "district": "Christian County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115000222",
    },
    {
        "school": "Hopkinsville High School",
        "district": "Christian County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115000223",
    },
    {
        "school": "Indian Hills Elementary School",
        "district": "Christian County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115000224",
    },
    {
        "school": "Hopkinsville Middle School",
        "district": "Christian County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115000225",
    },
    {
        "school": "Millbrooke Elementary School",
        "district": "Christian County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115000229",
    },
    {
        "school": "Pembroke Elementary School",
        "district": "Christian County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115000231",
    },
    {
        "school": "Sinking Fork Elementary School",
        "district": "Christian County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115000232",
    },
    {
        "school": "South Christian Elementary School",
        "district": "Christian County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115000233",
    },
    {
        "school": "Christian County Day Treatment",
        "district": "Christian County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210115000234",
    },
    {
        "school": "Christian County Alternative School",
        "district": "Christian County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210115001402",
    },
    {
        "school": "Cumberland Hall School",
        "district": "Christian County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210115001912",
    },
    {
        "school": "Corbin Preschool",
        "district": "Corbin Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210132001982",
    },
    {
        "school": "Whitley County East Elementary School",
        "district": "Whitley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210588002037",
    },
    {
        "school": "Whitley Central Intermediate School",
        "district": "Whitley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210588002048",
    },
    {
        "school": "Williamsburg City School",
        "district": "Williamsburg Independent",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210591001939",
    },
    {
        "school": "Corbin Educational Center",
        "district": "Corbin Independent",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210132001622",
    },
    {
        "school": "Corbin High School",
        "district": "Corbin Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210132000266",
    },
    {
        "school": "Corbin Middle School",
        "district": "Corbin Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210132001414",
    },
    {
        "school": "Whitley County North Elementary School",
        "district": "Whitley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210588000546",
    },
    {
        "school": "Whitley County Alternative School",
        "district": "Whitley County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210588001262",
    },
    {
        "school": "Boston Elementary School",
        "district": "Whitley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210588001376",
    },
    {
        "school": "Oak Grove Elementary School",
        "district": "Whitley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210588001381",
    },
    {
        "school": "Pleasant View Elementary School",
        "district": "Whitley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210588001383",
    },
    {
        "school": "Whitley County High School",
        "district": "Whitley County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210588001386",
    },
    {
        "school": "Whitley County Middle School",
        "district": "Whitley County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210588001387",
    },
    {
        "school": "Whitley County Central Primary School",
        "district": "Whitley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210588001621",
    },
    {
        "school": "Kentucky School for the Deaf",
        "district": "Kentucky School for the Deaf District",
        "level": "Other",
        "type": "Special education school",
        "state": "KY",
        "nces_id": "210009501715",
    },
    {
        "school": "Boyle County Middle School",
        "district": "Boyle County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210063000119",
    },
    {
        "school": "Boyle County High School",
        "district": "Boyle County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210063000120",
    },
    {
        "school": "Junction City Elementary School",
        "district": "Boyle County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210063000121",
    },
    {
        "school": "Woodlawn Elementary School",
        "district": "Boyle County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210063000122",
    },
    {
        "school": "Perryville Elementary School",
        "district": "Boyle County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210063000124",
    },
    {
        "school": "Boyle County Day Treatment",
        "district": "Boyle County",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210063001713",
    },
    {
        "school": "John W. Bate Middle School",
        "district": "Danville Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210144000290",
    },
    {
        "school": "Danville High School",
        "district": "Danville Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210144000291",
    },
    {
        "school": "Sunrise Academy",
        "district": "Danville Independent",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210144000646",
    },
    {
        "school": "Lincoln County Middle School",
        "district": "Lincoln County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210348000478",
    },
    {
        "school": "Crab Orchard Elementary School",
        "district": "Lincoln County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210348000914",
    },
    {
        "school": "Highland Elementary School",
        "district": "Lincoln County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210348000915",
    },
    {
        "school": "Hustonville Elementary School",
        "district": "Lincoln County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210348000916",
    },
    {
        "school": "Lincoln County High School",
        "district": "Lincoln County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210348000918",
    },
    {
        "school": "Stanford Elementary School",
        "district": "Lincoln County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210348000920",
    },
    {
        "school": "Waynesburg Elementary School",
        "district": "Lincoln County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210348000921",
    },
    {
        "school": "Lakewood Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249001963",
    },
    {
        "school": "Creekside Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249001994",
    },
    {
        "school": "Elizabethtown High School",
        "district": "Elizabethtown Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210165000323",
    },
    {
        "school": "Helmwood Heights Elementary School",
        "district": "Elizabethtown Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210165000324",
    },
    {
        "school": "Morningside Elementary School",
        "district": "Elizabethtown Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210165000325",
    },
    {
        "school": "Talton K Stone Middle School",
        "district": "Elizabethtown Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210165000326",
    },
    {
        "school": "East Hardin Middle School",
        "district": "Hardin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000512",
    },
    {
        "school": "G C Burkhead Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000513",
    },
    {
        "school": "Cecilia Valley Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000514",
    },
    {
        "school": "Lincoln Trail Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000515",
    },
    {
        "school": "North Hardin High School",
        "district": "Hardin County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000517",
    },
    {
        "school": "James T Alton Middle School",
        "district": "Hardin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000518",
    },
    {
        "school": "Radcliff Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000519",
    },
    {
        "school": "North Middle School",
        "district": "Hardin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000520",
    },
    {
        "school": "Rineyville Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000521",
    },
    {
        "school": "Vine Grove Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000524",
    },
    {
        "school": "West Hardin Middle School",
        "district": "Hardin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000525",
    },
    {
        "school": "Central Hardin High School",
        "district": "Hardin County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249000528",
    },
    {
        "school": "Hardin County Day Treatment Center",
        "district": "Hardin County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210249000656",
    },
    {
        "school": "New Highland Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249001446",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249001471",
    },
    {
        "school": "Meadow View Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249001566",
    },
    {
        "school": "Bluegrass Middle School",
        "district": "Hardin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249001673",
    },
    {
        "school": "John Hardin High School",
        "district": "Hardin County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249001910",
    },
    {
        "school": "West Point Elementary School",
        "district": "West Point Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210585001375",
    },
    {
        "school": "Hodgenville Elementary School",
        "district": "LaRue County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210318000852",
    },
    {
        "school": "LaRue County High School",
        "district": "LaRue County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210318000853",
    },
    {
        "school": "LaRue County Middle School",
        "district": "LaRue County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210318000854",
    },
    {
        "school": "Clay Elementary School",
        "district": "Webster County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210582001369",
    },
    {
        "school": "Dixon Elementary School",
        "district": "Webster County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210582001370",
    },
    {
        "school": "Sebree Elementary School",
        "district": "Webster County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210582001372",
    },
    {
        "school": "Webster County High School",
        "district": "Webster County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210582001374",
    },
    {
        "school": "Bend Gate Elementary School",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271000571",
    },
    {
        "school": "Cairo Elementary School",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271000572",
    },
    {
        "school": "A B Chandler Elementary School",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271000573",
    },
    {
        "school": "East Heights Elementary School",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271000574",
    },
    {
        "school": "Henderson County High School",
        "district": "Henderson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271000577",
    },
    {
        "school": "Henderson County North Middle School",
        "district": "Henderson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271000578",
    },
    {
        "school": "Niagara Elementary School",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271000579",
    },
    {
        "school": "South Heights Elementary School",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271000581",
    },
    {
        "school": "Spottsville Elementary School",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271000583",
    },
    {
        "school": "Henderson County South Middle School",
        "district": "Henderson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271000585",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271000586",
    },
    {
        "school": "Robert B. Turner Elementary School",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210012001955",
    },
    {
        "school": "Westridge Elementary",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210201001989",
    },
    {
        "school": "Bridgeport Elementary School",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210201001990",
    },
    {
        "school": "Franklin County Career and Technical Ctr",
        "district": "Franklin County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210201002055",
    },
    {
        "school": "Anderson County High School",
        "district": "Anderson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210012000016",
    },
    {
        "school": "Anderson County Middle School",
        "district": "Anderson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210012000017",
    },
    {
        "school": "Saffell Street Elementary School",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210012000018",
    },
    {
        "school": "Emma B. Ward Elementary School",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210012000021",
    },
    {
        "school": "Ezra Sparrow Early Childhood Center",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210012001298",
    },
    {
        "school": "Second Street School",
        "district": "Frankfort Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210198000432",
    },
    {
        "school": "Frankfort High School",
        "district": "Frankfort Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210198000433",
    },
    {
        "school": "Panther Transition Academy",
        "district": "Frankfort Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210198001524",
    },
    {
        "school": "Bondurant Middle School",
        "district": "Franklin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210201000435",
    },
    {
        "school": "Collins Lane",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210201000437",
    },
    {
        "school": "Elkhorn Middle School",
        "district": "Franklin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210201000438",
    },
    {
        "school": "Elkhorn Elementary School",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210201000439",
    },
    {
        "school": "Franklin County High School",
        "district": "Franklin County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210201000440",
    },
    {
        "school": "Hearn Elementary",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210201000441",
    },
    {
        "school": "Peaks Mill Elementary",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210201000442",
    },
    {
        "school": "Western Hills High School",
        "district": "Franklin County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210201001420",
    },
    {
        "school": "The Academy",
        "district": "Franklin County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210201001917",
    },
    {
        "school": "BAVEL",
        "district": "Barren County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210030001970",
    },
    {
        "school": "Highland Elementary School",
        "district": "Glasgow Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210222001991",
    },
    {
        "school": "Austin Tracy Elementary School",
        "district": "Barren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210030000047",
    },
    {
        "school": "Barren County High School",
        "district": "Barren County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210030000048",
    },
    {
        "school": "Eastern Elementary School",
        "district": "Barren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210030000049",
    },
    {
        "school": "Hiseville Elementary School",
        "district": "Barren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210030000050",
    },
    {
        "school": "Park City Elementary School",
        "district": "Barren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210030000051",
    },
    {
        "school": "Red Cross Elementary School",
        "district": "Barren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210030000052",
    },
    {
        "school": "Temple Hill Elementary School",
        "district": "Barren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210030000053",
    },
    {
        "school": "Barren County Middle School",
        "district": "Barren County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210030000607",
    },
    {
        "school": "College Street Campus",
        "district": "Barren County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210030001303",
    },
    {
        "school": "Caverna Elementary School",
        "district": "Caverna Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210111000213",
    },
    {
        "school": "Glasgow Middle School",
        "district": "Glasgow Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210222000402",
    },
    {
        "school": "Glasgow High School",
        "district": "Glasgow Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210222000461",
    },
    {
        "school": "South Green Elementary School",
        "district": "Glasgow Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210222001565",
    },
    {
        "school": "Caverna High School",
        "district": "Caverna Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210111000214",
    },
    {
        "school": "Caverna Middle School",
        "district": "Caverna Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210111001914",
    },
    {
        "school": "Metcalfe County Middle School",
        "district": "Metcalfe County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210414000729",
    },
    {
        "school": "Metcalfe County High School",
        "district": "Metcalfe County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210414001044",
    },
    {
        "school": "Ashland Head Start",
        "district": "Ashland Independent",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210015002023",
    },
    {
        "school": "Boyd Co Early Childhood Academy",
        "district": "Boyd County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210062001923",
    },
    {
        "school": "Raceland-Worthington Schools Campus B",
        "district": "Raceland-Worthington Independent",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210498002015",
    },
    {
        "school": "Boyd Co Career & Tech Educ Ctr Voc Sch",
        "district": "Boyd County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210062001479",
    },
    {
        "school": "Paul G. Blazer High School",
        "district": "Ashland Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210015000022",
    },
    {
        "school": "Ashland Middle School",
        "district": "Ashland Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210015000023",
    },
    {
        "school": "Crabbe Elementary School",
        "district": "Ashland Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210015000025",
    },
    {
        "school": "Hager Elementary School",
        "district": "Ashland Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210015000026",
    },
    {
        "school": "Oakview Elementary School",
        "district": "Ashland Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210015000028",
    },
    {
        "school": "Poage Elementary School",
        "district": "Ashland Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210015000029",
    },
    {
        "school": "Charles Russell Elementary School",
        "district": "Ashland Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210015000031",
    },
    {
        "school": "Ponderosa Elementary School",
        "district": "Boyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210062000030",
    },
    {
        "school": "Boyd County High School",
        "district": "Boyd County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210062000108",
    },
    {
        "school": "Cannonsburg Elementary School",
        "district": "Boyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210062000109",
    },
    {
        "school": "Boyd County Middle School",
        "district": "Boyd County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210062000112",
    },
    {
        "school": "Summit Elementary School",
        "district": "Boyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210062000117",
    },
    {
        "school": "Catlettsburg Elementary School",
        "district": "Boyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210062000118",
    },
    {
        "school": "Ramey-Estep High School",
        "district": "Boyd County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210062000640",
    },
    {
        "school": "Fairview High School",
        "district": "Fairview Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210180000348",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Fairview Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210180001889",
    },
    {
        "school": "Raceland-Worthington Schools Campus A",
        "district": "Raceland-Worthington Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210498001465",
    },
    {
        "school": "Argillite Elementary School",
        "district": "Greenup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210240000493",
    },
    {
        "school": "Greenup County High School",
        "district": "Greenup County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210240000496",
    },
    {
        "school": "Greysbranch Elementary School",
        "district": "Greenup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210240000497",
    },
    {
        "school": "Mckell Elementary School",
        "district": "Greenup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210240000499",
    },
    {
        "school": "Wurtland Elementary School",
        "district": "Greenup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210240000504",
    },
    {
        "school": "Wurtland Middle School",
        "district": "Greenup County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210240001610",
    },
    {
        "school": "Mckell Middle School",
        "district": "Greenup County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210240001611",
    },
    {
        "school": "Campbell Elementary School",
        "district": "Raceland-Worthington Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210498001239",
    },
    {
        "school": "Raceland-Worthington High School",
        "district": "Raceland-Worthington Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210498001240",
    },
    {
        "school": "Worthington Elementary School",
        "district": "Raceland-Worthington Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210498001241",
    },
    {
        "school": "Russell-McDowell Intermediate School",
        "district": "Russell Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210513001270",
    },
    {
        "school": "Russell High School",
        "district": "Russell Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210513001272",
    },
    {
        "school": "Russell Middle School",
        "district": "Russell Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210513001273",
    },
    {
        "school": "Russell Primary School",
        "district": "Russell Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210513001626",
    },
    {
        "school": "Bourbon County Preschool Headstart",
        "district": "Bourbon County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210054002054",
    },
    {
        "school": "Edythe Jones Hayes Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186001957",
    },
    {
        "school": "Athens-Chilesburg Elementary",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186001987",
    },
    {
        "school": "Anne Mason Elementary School",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526001942",
    },
    {
        "school": "Royal Spring Middle School",
        "district": "Scott County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526002017",
    },
    {
        "school": "Cane Ridge Elementary School",
        "district": "Bourbon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210054000024",
    },
    {
        "school": "North Middletown Elementary School",
        "district": "Bourbon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210054000096",
    },
    {
        "school": "Bourbon County High School",
        "district": "Bourbon County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210054000098",
    },
    {
        "school": "Bourbon County Middle School",
        "district": "Bourbon County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210054000099",
    },
    {
        "school": "Bourbon Central Elementary School",
        "district": "Bourbon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210054001576",
    },
    {
        "school": "Paris Elementary School",
        "district": "Paris Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210471001157",
    },
    {
        "school": "Paris High School",
        "district": "Paris Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210471001158",
    },
    {
        "school": "Paris Middle School",
        "district": "Paris Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210471001159",
    },
    {
        "school": "George Rogers Clark High School",
        "district": "Clark County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210120000237",
    },
    {
        "school": "Phoenix Academy",
        "district": "Clark County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210120001624",
    },
    {
        "school": "Arlington Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000350",
    },
    {
        "school": "Ashland Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000351",
    },
    {
        "school": "Beaumont Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000353",
    },
    {
        "school": "Scapa At Bluegrass",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000354",
    },
    {
        "school": "Crawford Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000357",
    },
    {
        "school": "Bryan Station Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000358",
    },
    {
        "school": "Cassidy Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000359",
    },
    {
        "school": "Deep Springs Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000360",
    },
    {
        "school": "Dixie Elementary Magnet School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000361",
    },
    {
        "school": "Garden Springs Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000362",
    },
    {
        "school": "Harrison Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000363",
    },
    {
        "school": "Henry Clay High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000364",
    },
    {
        "school": "Lafayette High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000367",
    },
    {
        "school": "Lansdowne Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000368",
    },
    {
        "school": "Leestown Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000369",
    },
    {
        "school": "Lexington Trad Magnet School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000370",
    },
    {
        "school": "Madeline M Breckinridge Elem School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000372",
    },
    {
        "school": "Maxwell Spanish Immersion Elem School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000373",
    },
    {
        "school": "Morton Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000374",
    },
    {
        "school": "Northern Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000375",
    },
    {
        "school": "Picadome Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000376",
    },
    {
        "school": "Southern Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000377",
    },
    {
        "school": "Stonewall Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000378",
    },
    {
        "school": "Russell Cave Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000380",
    },
    {
        "school": "Tates Creek Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000381",
    },
    {
        "school": "Tates Creek Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000382",
    },
    {
        "school": "Tates Creek High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000383",
    },
    {
        "school": "Clays Mill Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000384",
    },
    {
        "school": "Yates Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000385",
    },
    {
        "school": "Glendover Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000386",
    },
    {
        "school": "Meadowthorpe Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000387",
    },
    {
        "school": "Bryan Station High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000388",
    },
    {
        "school": "Mary Todd Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000389",
    },
    {
        "school": "James Lane Allen Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000390",
    },
    {
        "school": "Jessie M Clark Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000391",
    },
    {
        "school": "Cardinal Valley Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000392",
    },
    {
        "school": "Winburn Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000393",
    },
    {
        "school": "Southern Middle School",
        "district": "Fayette County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000394",
    },
    {
        "school": "Julius Marks Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186000395",
    },
    {
        "school": "Millcreek Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186001419",
    },
    {
        "school": "Veterans Park Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186001421",
    },
    {
        "school": "Rosa Parks Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186001422",
    },
    {
        "school": "Ridge Hospital Alt. Elementary",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186001423",
    },
    {
        "school": "Ridge Hospital Alt. High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186001424",
    },
    {
        "school": "Audrey Grevious Center",
        "district": "Fayette County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210186001480",
    },
    {
        "school": "Southside Technical Center",
        "district": "Fayette County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210186001563",
    },
    {
        "school": "Eastside Technical Center",
        "district": "Fayette County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210186001564",
    },
    {
        "school": "Squires Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186001584",
    },
    {
        "school": "Paul Laurence Dunbar High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186001669",
    },
    {
        "school": "Martin L King Acad for Excellence Alt",
        "district": "Fayette County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210186001848",
    },
    {
        "school": "Rosenwald Dunbar Elementary School",
        "district": "Jessamine County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210303000092",
    },
    {
        "school": "Hattie C. Warner Elementary School",
        "district": "Jessamine County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210303000795",
    },
    {
        "school": "East Jessamine Middle School",
        "district": "Jessamine County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210303000797",
    },
    {
        "school": "Nicholasville Elementary School",
        "district": "Jessamine County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210303000798",
    },
    {
        "school": "Wilmore Elementary School",
        "district": "Jessamine County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210303000799",
    },
    {
        "school": "West Jessamine Middle School",
        "district": "Jessamine County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210303001110",
    },
    {
        "school": "Brookside Elementary School",
        "district": "Jessamine County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210303001429",
    },
    {
        "school": "West Jessamine High School",
        "district": "Jessamine County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210303001640",
    },
    {
        "school": "East Jessamine High School",
        "district": "Jessamine County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210303001641",
    },
    {
        "school": "Jessamine Early Learning Village",
        "district": "Jessamine County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210303001899",
    },
    {
        "school": "The Providence School",
        "district": "Jessamine County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210303001900",
    },
    {
        "school": "Western Elementary School",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526000530",
    },
    {
        "school": "Eastern Elementary School",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526001278",
    },
    {
        "school": "Garth Elementary School",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526001279",
    },
    {
        "school": "Georgetown Middle School",
        "district": "Scott County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526001280",
    },
    {
        "school": "Scott County High School",
        "district": "Scott County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526001283",
    },
    {
        "school": "Stamping Ground Elementary School",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526001284",
    },
    {
        "school": "Scott County Middle School",
        "district": "Scott County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526001285",
    },
    {
        "school": "Southern Elementary School",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526001286",
    },
    {
        "school": "Northern Elementary School",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526001687",
    },
    {
        "school": "Southside Elementary School",
        "district": "Woodford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210600000284",
    },
    {
        "school": "Northside Elementary School",
        "district": "Woodford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210600000320",
    },
    {
        "school": "Simmons Elementary School",
        "district": "Woodford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210600001403",
    },
    {
        "school": "Woodford County High School",
        "district": "Woodford County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210600001404",
    },
    {
        "school": "Woodford County Middle School",
        "district": "Woodford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210600001405",
    },
    {
        "school": "Huntertown Elementary School",
        "district": "Woodford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210600001468",
    },
    {
        "school": "Safe Harbor Academy",
        "district": "Woodford County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210600001840",
    },
    {
        "school": "Wyan-Pine Grove Elementary",
        "district": "Laurel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321002030",
    },
    {
        "school": "East Bernstadt Elementary School",
        "district": "East Bernstadt Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210159000318",
    },
    {
        "school": "North Laurel High School",
        "district": "Laurel County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000215",
    },
    {
        "school": "Hunter Hills Elementary School",
        "district": "Laurel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000715",
    },
    {
        "school": "London Elementary School",
        "district": "Laurel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000856",
    },
    {
        "school": "Bush Elementary School",
        "district": "Laurel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000857",
    },
    {
        "school": "South Laurel Middle School",
        "district": "Laurel County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000858",
    },
    {
        "school": "Camp Ground Elementary School",
        "district": "Laurel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000859",
    },
    {
        "school": "Colony Elementary School",
        "district": "Laurel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000860",
    },
    {
        "school": "Hazel Green Elementary School",
        "district": "Laurel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000862",
    },
    {
        "school": "Johnson Elementary School",
        "district": "Laurel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000863",
    },
    {
        "school": "Keavy Elementary School",
        "district": "Laurel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000864",
    },
    {
        "school": "South Laurel High School",
        "district": "Laurel County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000865",
    },
    {
        "school": "Sublimity Elementary School",
        "district": "Laurel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321000869",
    },
    {
        "school": "Cold Hill Elementary School",
        "district": "Laurel County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321001483",
    },
    {
        "school": "North Laurel Middle School",
        "district": "Laurel County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210321001589",
    },
    {
        "school": "Laurel County Day Treatment",
        "district": "Laurel County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210321001677",
    },
    {
        "school": "Freedom Elementary School",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075001958",
    },
    {
        "school": "Zoneton Middle School",
        "district": "Bullitt County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075001973",
    },
    {
        "school": "Shepherdsville Elementary",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075001974",
    },
    {
        "school": "Eastside Middle School",
        "district": "Bullitt County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075001975",
    },
    {
        "school": "Heuser Hearing & Language Academy",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Special education school",
        "state": "KY",
        "nces_id": "210299001941",
    },
    {
        "school": "Home of the Innocents Discovery",
        "district": "Jefferson County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001943",
    },
    {
        "school": "Home of the Innocents School",
        "district": "Jefferson County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001946",
    },
    {
        "school": "Jefferson County High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001947",
    },
    {
        "school": "Chancey Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299001959",
    },
    {
        "school": "Breckinridge Metropolitan High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001965",
    },
    {
        "school": "Bardstown Primary School",
        "district": "Bardstown Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210027002050",
    },
    {
        "school": "The New Haven School",
        "district": "Nelson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210441001937",
    },
    {
        "school": "Bloomfield Elementary School",
        "district": "Nelson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210441002006",
    },
    {
        "school": "North Oldham High School",
        "district": "Oldham County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001953",
    },
    {
        "school": "Kenwood Station Elementary School",
        "district": "Oldham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453002007",
    },
    {
        "school": "Harmony Elementary School",
        "district": "Oldham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453002008",
    },
    {
        "school": "East Oldham Middle School",
        "district": "Oldham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453002009",
    },
    {
        "school": "Painted Stone Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532001964",
    },
    {
        "school": "Taylorsville Elementary School",
        "district": "Spencer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210549002018",
    },
    {
        "school": "Hillview Academy",
        "district": "Spencer County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210549002051",
    },
    {
        "school": "Eminence High School",
        "district": "Eminence Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210171000332",
    },
    {
        "school": "Eminence Elementary School",
        "district": "Eminence Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210171000333",
    },
    {
        "school": "Campbellsburg Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210276000588",
    },
    {
        "school": "Eastern Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210276000589",
    },
    {
        "school": "Henry County High School",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210276000590",
    },
    {
        "school": "Henry County Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210276000591",
    },
    {
        "school": "New Castle Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210276000592",
    },
    {
        "school": "Stuart Pepper Middle School",
        "district": "Meade County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210405001029",
    },
    {
        "school": "Ekron Elementary School",
        "district": "Meade County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210405001032",
    },
    {
        "school": "Flaherty Elementary School",
        "district": "Meade County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210405001033",
    },
    {
        "school": "Brandenburg Primary School",
        "district": "Meade County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210405001034",
    },
    {
        "school": "Meade County High School",
        "district": "Meade County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210405001035",
    },
    {
        "school": "Payneville Elementary School",
        "district": "Meade County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210405001037",
    },
    {
        "school": "David T. Wilson Elementary",
        "district": "Meade County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210405001644",
    },
    {
        "school": "Brandenburg High School",
        "district": "Meade County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210405001930",
    },
    {
        "school": "Bardstown Elementary School",
        "district": "Bardstown Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210027000044",
    },
    {
        "school": "Bardstown High School",
        "district": "Bardstown Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210027000045",
    },
    {
        "school": "Bardstown Middle School",
        "district": "Bardstown Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210027000046",
    },
    {
        "school": "Bloomfield Middle School",
        "district": "Nelson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210441001087",
    },
    {
        "school": "Boston School",
        "district": "Nelson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210441001089",
    },
    {
        "school": "Coxs Creek Elementary School",
        "district": "Nelson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210441001091",
    },
    {
        "school": "Foster Heights Elementary School",
        "district": "Nelson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210441001093",
    },
    {
        "school": "Old Kentucky Home Middle School",
        "district": "Nelson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210441001095",
    },
    {
        "school": "Nelson County High School",
        "district": "Nelson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210441001096",
    },
    {
        "school": "Shelby County West Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532001291",
    },
    {
        "school": "Shelby County High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532001292",
    },
    {
        "school": "Simpsonville Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532001293",
    },
    {
        "school": "Shelby County East Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532001294",
    },
    {
        "school": "Clear Creek Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532001295",
    },
    {
        "school": "Wright Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532001434",
    },
    {
        "school": "Heritage Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532001688",
    },
    {
        "school": "Northside Early Childhood Center",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532001689",
    },
    {
        "school": "Ascension Academy",
        "district": "Shelby County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210532001690",
    },
    {
        "school": "Spencer County Elementary School",
        "district": "Spencer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210549001314",
    },
    {
        "school": "Spencer County High School",
        "district": "Spencer County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210549001315",
    },
    {
        "school": "Spencer County Middle School",
        "district": "Spencer County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210549001871",
    },
    {
        "school": "Bedford Elementary School",
        "district": "Trimble County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210561001330",
    },
    {
        "school": "Milton Elementary School",
        "district": "Trimble County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210561001332",
    },
    {
        "school": "Brooks Elementary School",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000144",
    },
    {
        "school": "Bullitt Central High School",
        "district": "Bullitt County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000145",
    },
    {
        "school": "Cedar Grove Elementary",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000146",
    },
    {
        "school": "Hebron Middle School",
        "district": "Bullitt County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000147",
    },
    {
        "school": "Lebanon Junction Elementary",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000148",
    },
    {
        "school": "Maryville Elementary School",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000149",
    },
    {
        "school": "MT. Washington Middle School",
        "district": "Bullitt County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000150",
    },
    {
        "school": "MT. Washington Elementary",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000151",
    },
    {
        "school": "Nichols Elementary",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000153",
    },
    {
        "school": "North Bullitt High School",
        "district": "Bullitt County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000154",
    },
    {
        "school": "Overdale Elementary School",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000155",
    },
    {
        "school": "Roby Elementary School",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000156",
    },
    {
        "school": "Riverview Opportunity Center",
        "district": "Bullitt County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210075000157",
    },
    {
        "school": "Bernheim Middle School",
        "district": "Bullitt County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075000414",
    },
    {
        "school": "Bullitt Alternative Center",
        "district": "Bullitt County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210075000929",
    },
    {
        "school": "Pleasant Grove Elementary School",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075001305",
    },
    {
        "school": "Bullitt East High School",
        "district": "Bullitt County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075001409",
    },
    {
        "school": "Bullitt Lick Middle School",
        "district": "Bullitt County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075001410",
    },
    {
        "school": "Old Mill Elementary School",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075001578",
    },
    {
        "school": "Anchorage Independent Public School",
        "district": "Anchorage Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210009000014",
    },
    {
        "school": "Kentucky School for the Blind",
        "district": "Kentucky School for the Blind District",
        "level": "Other",
        "type": "Special education school",
        "state": "KY",
        "nces_id": "210009401779",
    },
    {
        "school": "Camp Taylor Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000623",
    },
    {
        "school": "Cane Run Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000624",
    },
    {
        "school": "Eastern High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000625",
    },
    {
        "school": "Fairdale Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000626",
    },
    {
        "school": "Fern Creek Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000627",
    },
    {
        "school": "Fern Creek High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000628",
    },
    {
        "school": "Greathouse/Shryock Traditional",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000629",
    },
    {
        "school": "Greenwood Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000630",
    },
    {
        "school": "Tully Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000631",
    },
    {
        "school": "Atherton High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000632",
    },
    {
        "school": "Medora Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000633",
    },
    {
        "school": "Middletown Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000634",
    },
    {
        "school": "Okolona Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000635",
    },
    {
        "school": "Southern High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000637",
    },
    {
        "school": "Valley High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000639",
    },
    {
        "school": "Barret Traditional Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000641",
    },
    {
        "school": "Newburg Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000642",
    },
    {
        "school": "Audubon Traditional Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000643",
    },
    {
        "school": "Butler Traditional High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000644",
    },
    {
        "school": "Chenoweth Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000645",
    },
    {
        "school": "Hawthorne Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000647",
    },
    {
        "school": "Waggener High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000649",
    },
    {
        "school": "Bates Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000650",
    },
    {
        "school": "Fairdale High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000651",
    },
    {
        "school": "Kenwood Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000653",
    },
    {
        "school": "Coral Ridge Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000654",
    },
    {
        "school": "Goldsmith Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000655",
    },
    {
        "school": "St Matthews Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000658",
    },
    {
        "school": "Jeffersontown High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000659",
    },
    {
        "school": "Wilkerson Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000660",
    },
    {
        "school": "Wilder Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000661",
    },
    {
        "school": "Watson Lane Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000663",
    },
    {
        "school": "Stonestreet Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000665",
    },
    {
        "school": "Watterson Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000666",
    },
    {
        "school": "Seneca High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000667",
    },
    {
        "school": "Pleasure Ridge Park High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000668",
    },
    {
        "school": "Indian Trail Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000669",
    },
    {
        "school": "Westport Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000670",
    },
    {
        "school": "Zachary Taylor Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000671",
    },
    {
        "school": "Kerrick Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000672",
    },
    {
        "school": "Rangeland Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000674",
    },
    {
        "school": "Dixie Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000675",
    },
    {
        "school": "Cochrane Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000676",
    },
    {
        "school": "Western High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000677",
    },
    {
        "school": "Robert Frost Sixth-Grade Academy",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000678",
    },
    {
        "school": "Sanders Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000679",
    },
    {
        "school": "Smyrna Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000680",
    },
    {
        "school": "Thomas Jefferson Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000682",
    },
    {
        "school": "Blue Lick Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000683",
    },
    {
        "school": "Crums Lane Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000684",
    },
    {
        "school": "Bowen Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000685",
    },
    {
        "school": "Hite Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000686",
    },
    {
        "school": "Norton Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000687",
    },
    {
        "school": "Shacklette Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000688",
    },
    {
        "school": "Minors Lane Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000690",
    },
    {
        "school": "Doss High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000691",
    },
    {
        "school": "Slaughter Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000693",
    },
    {
        "school": "Trunnell Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000694",
    },
    {
        "school": "Ballard High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000695",
    },
    {
        "school": "Johnsontown Road Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000696",
    },
    {
        "school": "Luhr Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000697",
    },
    {
        "school": "Wheeler Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000699",
    },
    {
        "school": "Gutermuth Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000700",
    },
    {
        "school": "Wellington Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000701",
    },
    {
        "school": "Wilt Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000702",
    },
    {
        "school": "Crosby Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000703",
    },
    {
        "school": "Hartstern Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000704",
    },
    {
        "school": "Layne Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000706",
    },
    {
        "school": "Auburndale Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000707",
    },
    {
        "school": "Price Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000708",
    },
    {
        "school": "Eisenhower Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000710",
    },
    {
        "school": "Lassiter Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000711",
    },
    {
        "school": "Klondike Lane Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000712",
    },
    {
        "school": "Louisville Day",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299000713",
    },
    {
        "school": "Laukhuf Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000716",
    },
    {
        "school": "Lowe Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000717",
    },
    {
        "school": "Mill Creek Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000718",
    },
    {
        "school": "Blake Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000719",
    },
    {
        "school": "Dunn Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000722",
    },
    {
        "school": "Kammerer Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000724",
    },
    {
        "school": "Knight Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000725",
    },
    {
        "school": "Conway Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000726",
    },
    {
        "school": "Jeffersontown Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000727",
    },
    {
        "school": "Carrithers Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000728",
    },
    {
        "school": "Central High Magnet Career Academy",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000730",
    },
    {
        "school": "Wheatley Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000731",
    },
    {
        "school": "Binet School",
        "district": "Jefferson County",
        "level": "Other",
        "type": "Special education school",
        "state": "KY",
        "nces_id": "210299000732",
    },
    {
        "school": "Atkinson Academy",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000733",
    },
    {
        "school": "duPont Manual High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000734",
    },
    {
        "school": "Bloom Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000737",
    },
    {
        "school": "Engelhard Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000739",
    },
    {
        "school": "Byck Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000740",
    },
    {
        "school": "Field Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000741",
    },
    {
        "school": "Brandeis Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000742",
    },
    {
        "school": "Foster Traditional Academy",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000745",
    },
    {
        "school": "Frayser Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000747",
    },
    {
        "school": "Hazelwood Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000748",
    },
    {
        "school": "Highland Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000750",
    },
    {
        "school": "Cochran Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000751",
    },
    {
        "school": "Jacob Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000752",
    },
    {
        "school": "Iroquois High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000753",
    },
    {
        "school": "Meyzeek Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000754",
    },
    {
        "school": "Young Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000757",
    },
    {
        "school": "Jefferson County Traditional Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000760",
    },
    {
        "school": "King Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000762",
    },
    {
        "school": "Noe Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000763",
    },
    {
        "school": "Mcferran Preparatory Academy",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000764",
    },
    {
        "school": "Johnson Traditional Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000769",
    },
    {
        "school": "Maupin Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000770",
    },
    {
        "school": "Portland Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000771",
    },
    {
        "school": "Lincoln Elementary Performing Arts",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000772",
    },
    {
        "school": "Roosevelt-Perry Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000773",
    },
    {
        "school": "Rutherford Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000775",
    },
    {
        "school": "Semple Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000776",
    },
    {
        "school": "The Academy @ Shawnee",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000777",
    },
    {
        "school": "Shelby Traditional Academy",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000780",
    },
    {
        "school": "Frederick Law Olmsted Academy North",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000781",
    },
    {
        "school": "Coleridge-Taylor Montessori Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000783",
    },
    {
        "school": "Carter Traditional Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000784",
    },
    {
        "school": "Western Middle School for the Arts",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000785",
    },
    {
        "school": "Kennedy Montessori Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299000786",
    },
    {
        "school": "Churchill Park School",
        "district": "Jefferson County",
        "level": "Other",
        "type": "Special education school",
        "state": "KY",
        "nces_id": "210299000789",
    },
    {
        "school": "Louisville Metro Youth Center",
        "district": "Jefferson County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001082",
    },
    {
        "school": "Frederick Law Olmsted Academy South",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299001425",
    },
    {
        "school": "Stuart Academy",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299001427",
    },
    {
        "school": "Ahrens Educational Resource Center",
        "district": "Jefferson County",
        "level": "High",
        "type": "Special education school",
        "state": "KY",
        "nces_id": "210299001447",
    },
    {
        "school": "The Brook-KMI",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001474",
    },
    {
        "school": "Boys & Girls Haven",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001475",
    },
    {
        "school": "Mary Jo and William MacDonald Maryhurst",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001492",
    },
    {
        "school": "Waller-Williams Environmental",
        "district": "Jefferson County",
        "level": "Other",
        "type": "Special education school",
        "state": "KY",
        "nces_id": "210299001529",
    },
    {
        "school": "Farnsley Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299001530",
    },
    {
        "school": "Schaffner Traditional Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299001587",
    },
    {
        "school": "Georgia Chaffee Teenage Parent Program",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001612",
    },
    {
        "school": "Peace Academy",
        "district": "Jefferson County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001613",
    },
    {
        "school": "The Brook-Dupont",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001629",
    },
    {
        "school": "St Joseph Children's Home",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001633",
    },
    {
        "school": "Liberty High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001634",
    },
    {
        "school": "Louisville Male High",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299001705",
    },
    {
        "school": "Dawson Orman Education Center",
        "district": "Jefferson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299001774",
    },
    {
        "school": "DuValle Education Center",
        "district": "Jefferson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299001777",
    },
    {
        "school": "Breckinridge-Franklin Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299001855",
    },
    {
        "school": "Western Day Treatment",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001857",
    },
    {
        "school": "Ackerly",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299001859",
    },
    {
        "school": "Mary Ryan Academy",
        "district": "Jefferson County",
        "level": "High",
        "type": "Special education school",
        "state": "KY",
        "nces_id": "210299001860",
    },
    {
        "school": "U of L PACT Program",
        "district": "Jefferson County",
        "level": "High",
        "type": "Special education school",
        "state": "KY",
        "nces_id": "210299001935",
    },
    {
        "school": "Buckner Alternative High School",
        "district": "Oldham County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210453000735",
    },
    {
        "school": "Oldham County Preschool",
        "district": "Oldham County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453000736",
    },
    {
        "school": "Centerfield Elementary School",
        "district": "Oldham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001121",
    },
    {
        "school": "Crestwood Elementary School",
        "district": "Oldham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001122",
    },
    {
        "school": "LaGrange Elementary School",
        "district": "Oldham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001123",
    },
    {
        "school": "Oldham County High School",
        "district": "Oldham County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001125",
    },
    {
        "school": "Oldham County Middle School",
        "district": "Oldham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001126",
    },
    {
        "school": "Goshen At Hillcrest Elementary School",
        "district": "Oldham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001432",
    },
    {
        "school": "South Oldham Middle School",
        "district": "Oldham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001433",
    },
    {
        "school": "North Oldham Middle School",
        "district": "Oldham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001552",
    },
    {
        "school": "Camden Station Elementary School",
        "district": "Oldham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001597",
    },
    {
        "school": "South Oldham High School",
        "district": "Oldham County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001620",
    },
    {
        "school": "Buckner Elementary School",
        "district": "Oldham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453001817",
    },
    {
        "school": "The Robert L. Arvin Education Center",
        "district": "Oldham County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210453001818",
    },
    {
        "school": "Southside Elementary School",
        "district": "Hopkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286000474",
    },
    {
        "school": "Grapevine Elementary School",
        "district": "Hopkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286000598",
    },
    {
        "school": "Hanson Elementary School",
        "district": "Hopkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286000600",
    },
    {
        "school": "Browning Springs Middle School",
        "district": "Hopkins County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286000601",
    },
    {
        "school": "Madisonville North Hopkins High School",
        "district": "Hopkins County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286000602",
    },
    {
        "school": "Pride Elementary School",
        "district": "Hopkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286000606",
    },
    {
        "school": "West Broadway Elementary School",
        "district": "Hopkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286000611",
    },
    {
        "school": "Earlington Elementary School",
        "district": "Hopkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286000614",
    },
    {
        "school": "Jesse Stuart Elementary School",
        "district": "Hopkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286000673",
    },
    {
        "school": "James Madison Middle School",
        "district": "Hopkins County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286000681",
    },
    {
        "school": "West Hopkins School",
        "district": "Hopkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286001472",
    },
    {
        "school": "Hopkins County Central High School",
        "district": "Hopkins County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286001473",
    },
    {
        "school": "South Hopkins Middle School",
        "district": "Hopkins County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210286001499",
    },
    {
        "school": "Hopkins County Day Treatment",
        "district": "Hopkins County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210286001586",
    },
    {
        "school": "Gateway Academy High School",
        "district": "Graves County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210228001924",
    },
    {
        "school": "Graves County Central Elementary",
        "district": "Graves County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210228001992",
    },
    {
        "school": "Mayfield Elementary School",
        "district": "Mayfield Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210390002001",
    },
    {
        "school": "Fancy Farm Elementary School",
        "district": "Graves County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210228000471",
    },
    {
        "school": "Farmington Elementary School",
        "district": "Graves County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210228000473",
    },
    {
        "school": "Lowes Elementary School",
        "district": "Graves County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210228000475",
    },
    {
        "school": "Sedalia Elementary School",
        "district": "Graves County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210228000477",
    },
    {
        "school": "Symsonia Elementary School",
        "district": "Graves County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210228000479",
    },
    {
        "school": "Wingo Elementary School",
        "district": "Graves County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210228000481",
    },
    {
        "school": "Graves County Middle School",
        "district": "Graves County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210228001436",
    },
    {
        "school": "Graves County High School",
        "district": "Graves County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210228001490",
    },
    {
        "school": "Mayfield Youth Development Center",
        "district": "Graves County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210228001754",
    },
    {
        "school": "Mayfield High School",
        "district": "Mayfield Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210390000995",
    },
    {
        "school": "Mayfield Middle School",
        "district": "Mayfield Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210390000996",
    },
    {
        "school": "Mason County Intermediate School",
        "district": "Mason County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210387002000",
    },
    {
        "school": "Garrison Elementary School",
        "district": "Lewis County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210339000906",
    },
    {
        "school": "Laurel Elementary School",
        "district": "Lewis County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210339000908",
    },
    {
        "school": "Lewis County Central Elementary School",
        "district": "Lewis County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210339000909",
    },
    {
        "school": "Lewis County High School",
        "district": "Lewis County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210339000910",
    },
    {
        "school": "Tollesboro Elementary School",
        "district": "Lewis County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210339000911",
    },
    {
        "school": "Lewis County Middle School",
        "district": "Lewis County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210339001503",
    },
    {
        "school": "Mason County High School",
        "district": "Mason County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210387000989",
    },
    {
        "school": "Mason County Middle School",
        "district": "Mason County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210387000991",
    },
    {
        "school": "Charles Straub Elementary School",
        "district": "Mason County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210387001460",
    },
    {
        "school": "Bell County Alternative School",
        "district": "Bell County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210039000002",
    },
    {
        "school": "Bell County High School",
        "district": "Bell County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210039000062",
    },
    {
        "school": "Frakes School Center",
        "district": "Bell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210039000067",
    },
    {
        "school": "Lone Jack School Center",
        "district": "Bell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210039000068",
    },
    {
        "school": "Right Fork School Center",
        "district": "Bell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210039000072",
    },
    {
        "school": "Yellow Creek School Center",
        "district": "Bell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210039000074",
    },
    {
        "school": "Bell Central School Center",
        "district": "Bell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210039001881",
    },
    {
        "school": "Page School Center",
        "district": "Bell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210039001882",
    },
    {
        "school": "Middlesboro Elementary School",
        "district": "Middlesboro Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210417001048",
    },
    {
        "school": "Middlesboro Middle School",
        "district": "Middlesboro Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210417001049",
    },
    {
        "school": "Middlesboro High School",
        "district": "Middlesboro Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210417001050",
    },
    {
        "school": "Middlesboro Alternative School",
        "district": "Middlesboro Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210417001680",
    },
    {
        "school": "Owingsville Elementary School",
        "district": "Bath County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210033000056",
    },
    {
        "school": "Bath County High School",
        "district": "Bath County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210033000057",
    },
    {
        "school": "Bath County Middle School",
        "district": "Bath County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210033001606",
    },
    {
        "school": "Botts Elementary School",
        "district": "Menifee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210408001038",
    },
    {
        "school": "Menifee Elementary School",
        "district": "Menifee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210408001039",
    },
    {
        "school": "Menifee County High School",
        "district": "Menifee County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210408001040",
    },
    {
        "school": "Camargo Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210425001057",
    },
    {
        "school": "Mapleton Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210425001058",
    },
    {
        "school": "Montgomery County High School",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210425001059",
    },
    {
        "school": "Mount Sterling Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210425001060",
    },
    {
        "school": "McNabb Middle School",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210425001538",
    },
    {
        "school": "Hillcrest Hall Treatment Center",
        "district": "Montgomery County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210425001867",
    },
    {
        "school": "Gateway Children's Services",
        "district": "Montgomery County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210425001868",
    },
    {
        "school": "Calloway County High School",
        "district": "Calloway County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210087000171",
    },
    {
        "school": "East Calloway Elementary School",
        "district": "Calloway County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210087000172",
    },
    {
        "school": "North Calloway Elementary School",
        "district": "Calloway County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210087000173",
    },
    {
        "school": "Southwest Calloway Elementary School",
        "district": "Calloway County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210087000174",
    },
    {
        "school": "Calloway County Preschool Center",
        "district": "Calloway County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210087000931",
    },
    {
        "school": "Calloway County Middle School",
        "district": "Calloway County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210087001411",
    },
    {
        "school": "Murray Preschool Head Start",
        "district": "Murray Independent",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210438000933",
    },
    {
        "school": "Murray Elementary School",
        "district": "Murray Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210438001084",
    },
    {
        "school": "Murray Middle School",
        "district": "Murray Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210438001085",
    },
    {
        "school": "Murray High School",
        "district": "Murray Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210438001086",
    },
    {
        "school": "Meadow Lands Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147001949",
    },
    {
        "school": "Emerson Academy",
        "district": "Owensboro Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210459002011",
    },
    {
        "school": "North Hancock Elementary School",
        "district": "Hancock County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210246001993",
    },
    {
        "school": "Hancock County High School",
        "district": "Hancock County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210246000507",
    },
    {
        "school": "Hancock County Middle School",
        "district": "Hancock County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210246000508",
    },
    {
        "school": "South Hancock Elementary School",
        "district": "Hancock County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210246000511",
    },
    {
        "school": "Calhoun Elementary School",
        "district": "McLean County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210402001023",
    },
    {
        "school": "Livermore Elementary School",
        "district": "McLean County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210402001025",
    },
    {
        "school": "McLean County High School",
        "district": "McLean County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210402001026",
    },
    {
        "school": "Marie Gatton Phillips Elementary",
        "district": "McLean County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210402001027",
    },
    {
        "school": "McLean County Middle School",
        "district": "McLean County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210402001140",
    },
    {
        "school": "Audubon Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000054",
    },
    {
        "school": "Apollo High School",
        "district": "Daviess County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000295",
    },
    {
        "school": "F T Burns Middle School",
        "district": "Daviess County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000296",
    },
    {
        "school": "Daviess County High School",
        "district": "Daviess County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000297",
    },
    {
        "school": "Daviess County Middle School",
        "district": "Daviess County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000298",
    },
    {
        "school": "Highland Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000299",
    },
    {
        "school": "Deer Park Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000301",
    },
    {
        "school": "Sorgho Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000303",
    },
    {
        "school": "Tamarack Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000306",
    },
    {
        "school": "West Louisville Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000309",
    },
    {
        "school": "Whitesville Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000310",
    },
    {
        "school": "F T Burns Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000311",
    },
    {
        "school": "Owensboro Day Treatment",
        "district": "Daviess County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210147000312",
    },
    {
        "school": "College View Middle School",
        "district": "Daviess County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147000961",
    },
    {
        "school": "Valley Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210147000964",
    },
    {
        "school": "Heritage Park High School",
        "district": "Daviess County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210147000969",
    },
    {
        "school": "Country Heights Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147001581",
    },
    {
        "school": "East View Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147001625",
    },
    {
        "school": "Valley High School",
        "district": "Daviess County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210147001700",
    },
    {
        "school": "Cravens Elementary School",
        "district": "Owensboro Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210459001129",
    },
    {
        "school": "Estes Elementary School",
        "district": "Owensboro Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210459001130",
    },
    {
        "school": "Foust Elementary School",
        "district": "Owensboro Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210459001132",
    },
    {
        "school": "Newton Parrish Elementary School",
        "district": "Owensboro Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210459001135",
    },
    {
        "school": "Owensboro High School",
        "district": "Owensboro Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210459001136",
    },
    {
        "school": "Sutton Elementary School",
        "district": "Owensboro Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210459001139",
    },
    {
        "school": "Hager Preschool",
        "district": "Owensboro Independent",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210459001685",
    },
    {
        "school": "South Livingston Elementary School",
        "district": "Livingston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210351001999",
    },
    {
        "school": "Ballard County Middle School",
        "district": "Ballard County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210021000035",
    },
    {
        "school": "Ballard Memorial High School",
        "district": "Ballard County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210021000036",
    },
    {
        "school": "Ballard Co. Preschool/Headstart Center",
        "district": "Ballard County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210021000040",
    },
    {
        "school": "Ballard County Elementary School",
        "district": "Ballard County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210021000356",
    },
    {
        "school": "Livingston Central High School",
        "district": "Livingston County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210351000924",
    },
    {
        "school": "North Livingston Elementary School",
        "district": "Livingston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210351001133",
    },
    {
        "school": "Livingston County Middle School",
        "district": "Livingston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210351001484",
    },
    {
        "school": "Concord Elementary School",
        "district": "McCracken County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210396001001",
    },
    {
        "school": "Heath Middle School",
        "district": "McCracken County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210396001006",
    },
    {
        "school": "Lone Oak Elementary School",
        "district": "McCracken County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210396001009",
    },
    {
        "school": "Lone Oak Middle School",
        "district": "McCracken County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210396001010",
    },
    {
        "school": "Reidland Elementary School",
        "district": "McCracken County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210396001011",
    },
    {
        "school": "Reidland Middle School",
        "district": "McCracken County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210396001013",
    },
    {
        "school": "Hendron Lone Oak Elementary School",
        "district": "McCracken County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210396001431",
    },
    {
        "school": "Heath Elementary School",
        "district": "McCracken County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210396001461",
    },
    {
        "school": "McCracken Open Campus School",
        "district": "McCracken County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210396001801",
    },
    {
        "school": "McCracken Regional School",
        "district": "McCracken County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210396001862",
    },
    {
        "school": "Paducah Middle School",
        "district": "Paducah Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210465001144",
    },
    {
        "school": "Clark Elementary School",
        "district": "Paducah Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210465001146",
    },
    {
        "school": "McNabb Elementary School",
        "district": "Paducah Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210465001150",
    },
    {
        "school": "Morgan Elementary School",
        "district": "Paducah Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210465001152",
    },
    {
        "school": "Paducah Tilghman High School",
        "district": "Paducah Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210465001154",
    },
    {
        "school": "Paducah Head Start Preschool",
        "district": "Paducah Independent",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210465001571",
    },
    {
        "school": "Rockcastle County Middle School",
        "district": "Rockcastle County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210507000782",
    },
    {
        "school": "Brodhead Elementary School",
        "district": "Rockcastle County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210507001249",
    },
    {
        "school": "Mt. Vernon Elementary",
        "district": "Rockcastle County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210507001251",
    },
    {
        "school": "Rockcastle County High School",
        "district": "Rockcastle County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210507001252",
    },
    {
        "school": "Roundstone Elementary School",
        "district": "Rockcastle County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210507001253",
    },
    {
        "school": "Rockcastle Academy for Academic Achievement",
        "district": "Rockcastle County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210507001906",
    },
    {
        "school": "Berea Community Elementary School",
        "district": "Berea Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210048000077",
    },
    {
        "school": "Berea Community High School",
        "district": "Berea Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210048000078",
    },
    {
        "school": "Berea Community Middle School",
        "district": "Berea Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210048001658",
    },
    {
        "school": "Madison Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372000250",
    },
    {
        "school": "Clark Moores Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372000944",
    },
    {
        "school": "Daniel Boone Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372000945",
    },
    {
        "school": "Kingston Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372000946",
    },
    {
        "school": "Kirksville Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372000947",
    },
    {
        "school": "Kit Carson Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372000948",
    },
    {
        "school": "Madison Central High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372000949",
    },
    {
        "school": "Silver Creek Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372000950",
    },
    {
        "school": "Waco Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372000951",
    },
    {
        "school": "White Hall Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372000952",
    },
    {
        "school": "Foley Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372000953",
    },
    {
        "school": "Model Laboratory Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372001485",
    },
    {
        "school": "Model Laboratory High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372001486",
    },
    {
        "school": "Madison Southern High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372001594",
    },
    {
        "school": "Madison County Day Treatment",
        "district": "Madison County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210372001678",
    },
    {
        "school": "Shannon Johnson Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372001901",
    },
    {
        "school": "Southwestern High School",
        "district": "Pulaski County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495000506",
    },
    {
        "school": "Oak Hill Elementary School",
        "district": "Pulaski County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495000779",
    },
    {
        "school": "Burnside Elementary School",
        "district": "Pulaski County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495001225",
    },
    {
        "school": "Eubank Elementary School",
        "district": "Pulaski County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495001227",
    },
    {
        "school": "Nancy Elementary School",
        "district": "Pulaski County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495001231",
    },
    {
        "school": "Pulaski County High School",
        "district": "Pulaski County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495001233",
    },
    {
        "school": "Pulaski Elementary School",
        "district": "Pulaski County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495001234",
    },
    {
        "school": "Shopville Elementary School",
        "district": "Pulaski County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495001235",
    },
    {
        "school": "Northern Elementary School",
        "district": "Pulaski County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495001238",
    },
    {
        "school": "Southern Elementary School",
        "district": "Pulaski County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495001464",
    },
    {
        "school": "Pulaski Day Treatment~Eagle Academy",
        "district": "Pulaski County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210495001554",
    },
    {
        "school": "Southern Middle School",
        "district": "Pulaski County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495001572",
    },
    {
        "school": "Northern Middle School",
        "district": "Pulaski County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210495001573",
    },
    {
        "school": "Science Hill Elementary School",
        "district": "Science Hill Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210522001277",
    },
    {
        "school": "Hopkins Elementary School",
        "district": "Somerset Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210543001307",
    },
    {
        "school": "Somerset High School",
        "district": "Somerset Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210543001310",
    },
    {
        "school": "Meece Middle School",
        "district": "Somerset Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210543001311",
    },
    {
        "school": "Fulton County High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210210000445",
    },
    {
        "school": "Copper Mill Elementary/Middle School",
        "district": "Zachary Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003902013",
    },
    {
        "school": "Woodlawn Middle School",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054001692",
    },
    {
        "school": "Thomas Jefferson High School for Advanced Studies",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001964",
    },
    {
        "school": "Gretna No. 2 Academy for Advanced Studies",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001965",
    },
    {
        "school": "Lakeview Annex",
        "district": "Natchitoches Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114002022",
    },
    {
        "school": "Natchitoches Magnet School",
        "district": "Natchitoches Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114002025",
    },
    {
        "school": "South Plaquemines Elementary School",
        "district": "Plaquemines Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220123002026",
    },
    {
        "school": "South Plaquemines High School",
        "district": "Plaquemines Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220123002028",
    },
    {
        "school": "James Stephens Montessori School",
        "district": "Evangeline Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220063001659",
    },
    {
        "school": "Elizabeth High School",
        "district": "Allen Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220006000024",
    },
    {
        "school": "Fairview High School",
        "district": "Allen Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220006000025",
    },
    {
        "school": "Kinder Elementary School",
        "district": "Allen Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220006000026",
    },
    {
        "school": "Kinder High School",
        "district": "Allen Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220006000027",
    },
    {
        "school": "Oakdale Elementary School",
        "district": "Allen Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220006000028",
    },
    {
        "school": "Oakdale High School",
        "district": "Allen Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220006000029",
    },
    {
        "school": "Oakdale Middle School",
        "district": "Allen Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220006000030",
    },
    {
        "school": "Oberlin Elementary School",
        "district": "Allen Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220006000031",
    },
    {
        "school": "Oberlin High School",
        "district": "Allen Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220006000032",
    },
    {
        "school": "Reeves High School",
        "district": "Allen Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220006000033",
    },
    {
        "school": "Kinder Middle School",
        "district": "Allen Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220006001049",
    },
    {
        "school": "Avoyelles Public Charter School",
        "district": "Avoyelles Public Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003501494",
    },
    {
        "school": "Bunkie Elementary School",
        "district": "Avoyelles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015000061",
    },
    {
        "school": "Bunkie Magnet High School",
        "district": "Avoyelles Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015000063",
    },
    {
        "school": "Cottonport Elementary",
        "district": "Avoyelles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015000064",
    },
    {
        "school": "Lafargue Elementary School",
        "district": "Avoyelles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015000069",
    },
    {
        "school": "Marksville Elementary School",
        "district": "Avoyelles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015000072",
    },
    {
        "school": "Marksville High School",
        "district": "Avoyelles Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015000073",
    },
    {
        "school": "Avoyelles High School",
        "district": "Avoyelles Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015000075",
    },
    {
        "school": "Plaucheville Elementary School",
        "district": "Avoyelles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015000076",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Avoyelles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015000077",
    },
    {
        "school": "LA School for Ag Science",
        "district": "Avoyelles Parish",
        "level": "High",
        "type": "Career and Technical School",
        "state": "LA",
        "nces_id": "220015001378",
    },
    {
        "school": "Arcadia High School",
        "district": "Bienville Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021000090",
    },
    {
        "school": "Bienville High School",
        "district": "Bienville Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021000091",
    },
    {
        "school": "Castor High School",
        "district": "Bienville Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021000092",
    },
    {
        "school": "Crawford Elementary School",
        "district": "Bienville Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021000094",
    },
    {
        "school": "Gibsland-Coleman High School",
        "district": "Bienville Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021000095",
    },
    {
        "school": "Ringgold Elementary School",
        "district": "Bienville Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021000097",
    },
    {
        "school": "Ringgold High School",
        "district": "Bienville Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021000098",
    },
    {
        "school": "Saline High School",
        "district": "Bienville Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021000099",
    },
    {
        "school": "Caldwell Parish High School",
        "district": "Caldwell Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220036000281",
    },
    {
        "school": "Caldwell Parish Junior High School",
        "district": "Caldwell Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220036000282",
    },
    {
        "school": "Union Central Elementary School",
        "district": "Caldwell Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220036000283",
    },
    {
        "school": "Columbia Elementary School",
        "district": "Caldwell Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220036000284",
    },
    {
        "school": "Grayson Elementary School",
        "district": "Caldwell Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220036000285",
    },
    {
        "school": "Block High School",
        "district": "Catahoula Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220042000294",
    },
    {
        "school": "Central High School",
        "district": "Catahoula Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220042000295",
    },
    {
        "school": "Harrisonburg High School",
        "district": "Catahoula Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220042000298",
    },
    {
        "school": "Jonesville Elementary School",
        "district": "Catahoula Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220042000299",
    },
    {
        "school": "Sicily Island High School",
        "district": "Catahoula Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220042000304",
    },
    {
        "school": "Haynesville Elementary School",
        "district": "Claiborne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220045000307",
    },
    {
        "school": "Haynesville Jr./Sr. High School",
        "district": "Claiborne Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220045000308",
    },
    {
        "school": "Homer Elementary School",
        "district": "Claiborne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220045000310",
    },
    {
        "school": "Homer High School",
        "district": "Claiborne Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220045000311",
    },
    {
        "school": "Homer Junior High School",
        "district": "Claiborne Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220045000312",
    },
    {
        "school": "Summerfield High School",
        "district": "Claiborne Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220045000315",
    },
    {
        "school": "Griffin Middle School Academy",
        "district": "East Carroll Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220057000453",
    },
    {
        "school": "General Trass High School",
        "district": "East Carroll Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220057000454",
    },
    {
        "school": "Southside Elementary School",
        "district": "East Carroll Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220057000457",
    },
    {
        "school": "Basile High School",
        "district": "Evangeline Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220063000470",
    },
    {
        "school": "Bayou Chicot Elementary School",
        "district": "Evangeline Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220063000471",
    },
    {
        "school": "Chataignier Elementary School",
        "district": "Evangeline Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220063000473",
    },
    {
        "school": "Mamou High School",
        "district": "Evangeline Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220063000475",
    },
    {
        "school": "Mamou Elementary School",
        "district": "Evangeline Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220063000476",
    },
    {
        "school": "Pine Prairie High School",
        "district": "Evangeline Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220063000478",
    },
    {
        "school": "W. W. Stewart Elementary School",
        "district": "Evangeline Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220063000480",
    },
    {
        "school": "Vidrine Elementary School",
        "district": "Evangeline Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220063000481",
    },
    {
        "school": "Ville Platte High School",
        "district": "Evangeline Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220063000482",
    },
    {
        "school": "Ville Platte Elementary School",
        "district": "Evangeline Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220063000483",
    },
    {
        "school": "Baskin School",
        "district": "Franklin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220066000484",
    },
    {
        "school": "Fort Necessity School",
        "district": "Franklin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220066000486",
    },
    {
        "school": "Gilbert School",
        "district": "Franklin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220066000487",
    },
    {
        "school": "Crowville School",
        "district": "Franklin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220066000489",
    },
    {
        "school": "Franklin Parish High School",
        "district": "Franklin Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220066000490",
    },
    {
        "school": "Winnsboro Elementary School",
        "district": "Franklin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220066000496",
    },
    {
        "school": "Fellowship Elementary School",
        "district": "LaSalle Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220096000729",
    },
    {
        "school": "Goodpine Middle School",
        "district": "LaSalle Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220096000730",
    },
    {
        "school": "Jena Elementary School",
        "district": "LaSalle Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220096000731",
    },
    {
        "school": "Jena High School",
        "district": "LaSalle Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220096000732",
    },
    {
        "school": "Jena Junior High School",
        "district": "LaSalle Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220096000733",
    },
    {
        "school": "LaSalle High School",
        "district": "LaSalle Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220096000734",
    },
    {
        "school": "Nebo Elementary School",
        "district": "LaSalle Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220096000735",
    },
    {
        "school": "Olla-Standard Elementary School",
        "district": "LaSalle Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220096000736",
    },
    {
        "school": "LaSalle Junior High School",
        "district": "LaSalle Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220096000738",
    },
    {
        "school": "Ware Youth Center",
        "district": "Red River Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220132000784",
    },
    {
        "school": "Red River High School",
        "district": "Red River Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220132001090",
    },
    {
        "school": "Red River Elementary School",
        "district": "Red River Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220132001529",
    },
    {
        "school": "Red River Junior High School",
        "district": "Red River Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220132001530",
    },
    {
        "school": "Delhi Charter School",
        "district": "Delhi Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003801539",
    },
    {
        "school": "Delhi High School",
        "district": "Richland Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220135001095",
    },
    {
        "school": "Delhi Middle School",
        "district": "Richland Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220135001096",
    },
    {
        "school": "Delhi Elementary School",
        "district": "Richland Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220135001097",
    },
    {
        "school": "Holly Ridge Elementary School",
        "district": "Richland Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220135001098",
    },
    {
        "school": "Mangham Elementary School",
        "district": "Richland Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220135001099",
    },
    {
        "school": "Mangham High School",
        "district": "Richland Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220135001100",
    },
    {
        "school": "Mangham Junior High School",
        "district": "Richland Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220135001101",
    },
    {
        "school": "Rayville High School",
        "district": "Richland Parish",
        "level": "High",
        "type": "Career and Technical School",
        "state": "LA",
        "nces_id": "220135001102",
    },
    {
        "school": "Rayville Junior High School",
        "district": "Richland Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220135001103",
    },
    {
        "school": "Rayville Elementary School",
        "district": "Richland Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220135001104",
    },
    {
        "school": "Start Elementary School",
        "district": "Richland Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220135001106",
    },
    {
        "school": "Richland Career Center at Archibald",
        "district": "Richland Parish",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220135001631",
    },
    {
        "school": "Converse High School",
        "district": "Sabine Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220138001107",
    },
    {
        "school": "Ebarb School",
        "district": "Sabine Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220138001108",
    },
    {
        "school": "Florien High School",
        "district": "Sabine Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220138001110",
    },
    {
        "school": "Many Elementary School",
        "district": "Sabine Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220138001111",
    },
    {
        "school": "Many High School",
        "district": "Sabine Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220138001112",
    },
    {
        "school": "Many Junior High School",
        "district": "Sabine Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220138001113",
    },
    {
        "school": "Negreet High School",
        "district": "Sabine Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220138001114",
    },
    {
        "school": "Pleasant Hill High School",
        "district": "Sabine Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220138001116",
    },
    {
        "school": "Zwolle Elementary School",
        "district": "Sabine Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220138001117",
    },
    {
        "school": "Zwolle High School",
        "district": "Sabine Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220138001118",
    },
    {
        "school": "Tensas High School",
        "district": "Tensas Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220171001328",
    },
    {
        "school": "Tensas Elementary School",
        "district": "Tensas Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220171001332",
    },
    {
        "school": "Epps High School",
        "district": "West Carroll Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220195001467",
    },
    {
        "school": "Forest School",
        "district": "West Carroll Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220195001469",
    },
    {
        "school": "Kilbourne High School",
        "district": "West Carroll Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220195001471",
    },
    {
        "school": "Oak Grove High School",
        "district": "West Carroll Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220195001472",
    },
    {
        "school": "Oak Grove Elementary School",
        "district": "West Carroll Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220195002011",
    },
    {
        "school": "Atlanta High School",
        "district": "Winn Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220201001478",
    },
    {
        "school": "Calvin High School",
        "district": "Winn Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220201001479",
    },
    {
        "school": "Dodson High School",
        "district": "Winn Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220201001480",
    },
    {
        "school": "Winnfield Primary School",
        "district": "Winn Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220201001484",
    },
    {
        "school": "Winnfield Middle School",
        "district": "Winn Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220201001486",
    },
    {
        "school": "Winnfield High School",
        "district": "Winn Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220201001487",
    },
    {
        "school": "Gramercy Elementary School",
        "district": "St. James Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220150001161",
    },
    {
        "school": "Lutcher High School",
        "district": "St. James Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220150001163",
    },
    {
        "school": "Paulina Elementary School",
        "district": "St. James Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220150001165",
    },
    {
        "school": "St. James High School",
        "district": "St. James Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220150001167",
    },
    {
        "school": "Sixth Ward Elementary School",
        "district": "St. James Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220150001169",
    },
    {
        "school": "Vacherie Elementary School",
        "district": "St. James Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220150001170",
    },
    {
        "school": "Abbeville High School",
        "district": "Vermilion Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001385",
    },
    {
        "school": "Dozier Elementary School",
        "district": "Vermilion Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001387",
    },
    {
        "school": "Eaton Park Elementary School",
        "district": "Vermilion Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001389",
    },
    {
        "school": "Erath High School",
        "district": "Vermilion Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001390",
    },
    {
        "school": "Forked Island/E. Broussard Elem School",
        "district": "Vermilion Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001391",
    },
    {
        "school": "James A. Herod Elementary School",
        "district": "Vermilion Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001394",
    },
    {
        "school": "Kaplan Elementary School",
        "district": "Vermilion Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001396",
    },
    {
        "school": "Kaplan High School",
        "district": "Vermilion Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001398",
    },
    {
        "school": "Cecil Picard Elementary School at Maurice",
        "district": "Vermilion Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001399",
    },
    {
        "school": "Meaux Elementary School",
        "district": "Vermilion Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001400",
    },
    {
        "school": "Jesse Owens Elementary School",
        "district": "Vermilion Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001401",
    },
    {
        "school": "Seventh Ward Elementary School",
        "district": "Vermilion Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001403",
    },
    {
        "school": "Rene A. Rost Middle School",
        "district": "Vermilion Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001568",
    },
    {
        "school": "J.H. Williams Middle School",
        "district": "Vermilion Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001569",
    },
    {
        "school": "North Vermilion High School",
        "district": "Vermilion Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001661",
    },
    {
        "school": "Gueydan High School",
        "district": "Vermilion Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001695",
    },
    {
        "school": "Erath Middle School",
        "district": "Vermilion Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180001846",
    },
    {
        "school": "Indian Bayou Elementary School",
        "district": "Vermilion Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180002009",
    },
    {
        "school": "South Grant Elementary School",
        "district": "Grant Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220069000084",
    },
    {
        "school": "Colfax Elementary School",
        "district": "Grant Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220069000497",
    },
    {
        "school": "Grant Junior High School",
        "district": "Grant Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220069000498",
    },
    {
        "school": "Georgetown High School",
        "district": "Grant Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220069000500",
    },
    {
        "school": "Grant High School",
        "district": "Grant Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220069000501",
    },
    {
        "school": "Montgomery High School",
        "district": "Grant Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220069000502",
    },
    {
        "school": "Pollock Elementary School",
        "district": "Grant Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220069000503",
    },
    {
        "school": "Verda Elementary School",
        "district": "Grant Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220069000504",
    },
    {
        "school": "Louisiana Special Education Center",
        "district": "Louisiana Special Education Center",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220002000267",
    },
    {
        "school": "Rapides Training Academy",
        "district": "Rapides Parish",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220129000115",
    },
    {
        "school": "Acadian Elementary",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001038",
    },
    {
        "school": "Alexandria Middle Magnet School",
        "district": "Rapides Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001039",
    },
    {
        "school": "Alexandria Senior High School",
        "district": "Rapides Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001040",
    },
    {
        "school": "J.I. Barron Sr. Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001041",
    },
    {
        "school": "Bolton High School",
        "district": "Rapides Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001042",
    },
    {
        "school": "Scott M. Brame Middle School",
        "district": "Rapides Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001044",
    },
    {
        "school": "Mabel Brasher Montessori",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001045",
    },
    {
        "school": "Buckeye Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001046",
    },
    {
        "school": "Buckeye High School",
        "district": "Rapides Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001047",
    },
    {
        "school": "Cherokee Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001048",
    },
    {
        "school": "Glenmora High School",
        "district": "Rapides Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001051",
    },
    {
        "school": "Mary Goff Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001052",
    },
    {
        "school": "Horseshoe Drive Elementary New Vision Academy",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001053",
    },
    {
        "school": "D.F. Huddle Elementary",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001054",
    },
    {
        "school": "Arthur F. Smith Middle Magnet School",
        "district": "Rapides Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001055",
    },
    {
        "school": "Martin Park Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001060",
    },
    {
        "school": "J.B. Nachman Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001062",
    },
    {
        "school": "North Bayou Rapides Elementary",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001063",
    },
    {
        "school": "Oak Hill High School",
        "district": "Rapides Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001064",
    },
    {
        "school": "Paradise Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001065",
    },
    {
        "school": "Peabody Montessori Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001066",
    },
    {
        "school": "Peabody Magnet High School",
        "district": "Rapides Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001067",
    },
    {
        "school": "Pineville Elementary School",
        "district": "Rapides Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001068",
    },
    {
        "school": "Pineville High School",
        "district": "Rapides Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001069",
    },
    {
        "school": "Pineville Junior High School",
        "district": "Rapides Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001070",
    },
    {
        "school": "Plainview High School",
        "district": "Rapides Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001071",
    },
    {
        "school": "Poland Junior High School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001072",
    },
    {
        "school": "Rapides High School",
        "district": "Rapides Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001073",
    },
    {
        "school": "Carter C. Raymond Junior High School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001074",
    },
    {
        "school": "Julius Patrick 6th Grade Academy",
        "district": "Rapides Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001075",
    },
    {
        "school": "Rosenthal Montessori Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001076",
    },
    {
        "school": "Ruby-Wise Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001077",
    },
    {
        "school": "L.S. Rugg Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001078",
    },
    {
        "school": "W.O. Hall 6th Grade Academy",
        "district": "Rapides Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001080",
    },
    {
        "school": "Lessie Moore Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001081",
    },
    {
        "school": "Alma Redwine Elementary",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001083",
    },
    {
        "school": "Tioga High School",
        "district": "Rapides Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001084",
    },
    {
        "school": "Tioga Junior High School",
        "district": "Rapides Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001085",
    },
    {
        "school": "Ball Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001562",
    },
    {
        "school": "Tioga Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001563",
    },
    {
        "school": "Forest Hill Junior High School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001712",
    },
    {
        "school": "Northwood High School",
        "district": "Rapides Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001943",
    },
    {
        "school": "Hayden R. Lawrence Upper Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129001944",
    },
    {
        "school": "Morehouse Magnet School",
        "district": "Morehouse Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220111000778",
    },
    {
        "school": "Bastrop High School",
        "district": "Morehouse Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220111000805",
    },
    {
        "school": "Morehouse Junior High School",
        "district": "Morehouse Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220111000807",
    },
    {
        "school": "Delta Jr. High School",
        "district": "Morehouse Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220111000813",
    },
    {
        "school": "Duplessis Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009001540",
    },
    {
        "school": "Dutchtown High School",
        "district": "Ascension Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009001541",
    },
    {
        "school": "Raymond Laborde Correctional Center",
        "district": "Special School District",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010001627",
    },
    {
        "school": "David Wade Correctional Center",
        "district": "Special School District",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010001607",
    },
    {
        "school": "Northwestern Elementary School",
        "district": "Zachary Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003900405",
    },
    {
        "school": "Northwestern Middle School",
        "district": "Zachary Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003900406",
    },
    {
        "school": "Zachary Elementary School",
        "district": "Zachary Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003900449",
    },
    {
        "school": "Zachary High School",
        "district": "Zachary Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003900450",
    },
    {
        "school": "Baker Heights Elementary School",
        "district": "City of Baker School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220004000342",
    },
    {
        "school": "Baker Middle School",
        "district": "City of Baker School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220004000343",
    },
    {
        "school": "Baker High School",
        "district": "City of Baker School District",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220004000344",
    },
    {
        "school": "Park Ridge Academic Magnet School",
        "district": "City of Baker School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220004000410",
    },
    {
        "school": "White Hills Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054001703",
    },
    {
        "school": "Dixon Correctional Institute",
        "district": "Special School District",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010001624",
    },
    {
        "school": "Elayn Hunt Correctional Center",
        "district": "Special School District",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010001609",
    },
    {
        "school": "Louisiana Correctional Institute for Women",
        "district": "Special School District",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010001611",
    },
    {
        "school": "Riverside Alternative High School",
        "district": "Office of Juvenile Justice",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "LA",
        "nces_id": "220004701780",
    },
    {
        "school": "Riverside Alternative High School",
        "district": "Special School District",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010001614",
    },
    {
        "school": "North Corbin Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102001550",
    },
    {
        "school": "Livingston Parish Literacy & Technology Center",
        "district": "Livingston Parish",
        "level": "High",
        "type": "Career and Technical School",
        "state": "LA",
        "nces_id": "220102001678",
    },
    {
        "school": "North Live Oak Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102001719",
    },
    {
        "school": "Gray's Creek Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102001720",
    },
    {
        "school": "Southside Alternative High School",
        "district": "Office of Juvenile Justice",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "LA",
        "nces_id": "220004701781",
    },
    {
        "school": "Southside Alternative High School",
        "district": "Special School District",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010001619",
    },
    {
        "school": "Renaissance Home for Youth",
        "district": "Special School District",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010002014",
    },
    {
        "school": "Rayburn Correctional Institute",
        "district": "Special School District",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010001626",
    },
    {
        "school": "Louisiana State Penitentiary",
        "district": "Special School District",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010001621",
    },
    {
        "school": "Winn Correctional Center",
        "district": "Special School District",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010002016",
    },
    {
        "school": "Clinton Elementary School",
        "district": "East Feliciana Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220060000459",
    },
    {
        "school": "East Feliciana Middle School",
        "district": "East Feliciana Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220060000461",
    },
    {
        "school": "Jackson Elementary School",
        "district": "East Feliciana Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220060000464",
    },
    {
        "school": "East Feliciana High School",
        "district": "East Feliciana Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220060000465",
    },
    {
        "school": "Slaughter Elementary School",
        "district": "East Feliciana Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220060000468",
    },
    {
        "school": "East Feliciana Parish Enrichment Academy",
        "district": "East Feliciana Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220060000715",
    },
    {
        "school": "East Iberville Elementary/High School",
        "district": "Iberville Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220075000231",
    },
    {
        "school": "Crescent Elementary/Junior High School",
        "district": "Iberville Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220075000536",
    },
    {
        "school": "Plaquemine Senior High School",
        "district": "Iberville Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220075000543",
    },
    {
        "school": "White Castle High School",
        "district": "Iberville Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220075000550",
    },
    {
        "school": "Dorseyville Elementary School",
        "district": "Iberville Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220075001980",
    },
    {
        "school": "Iberville Elementary School",
        "district": "Iberville Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220075001997",
    },
    {
        "school": "North Iberville Elementary",
        "district": "Iberville Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220075001998",
    },
    {
        "school": "Livonia High School",
        "district": "Pointe Coupee Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220126001029",
    },
    {
        "school": "Upper Pointe Coupee Elementary School",
        "district": "Pointe Coupee Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220126001034",
    },
    {
        "school": "Valverda Elementary School",
        "district": "Pointe Coupee Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220126001036",
    },
    {
        "school": "Rosenwald Elementary School",
        "district": "Pointe Coupee Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220126002000",
    },
    {
        "school": "Rougon Elementary School",
        "district": "Pointe Coupee Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220126002001",
    },
    {
        "school": "St. Helena College and Career Academy",
        "district": "St. Helena Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220147001154",
    },
    {
        "school": "St. Helena Arts and Technology Academy",
        "district": "St. Helena Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220147001157",
    },
    {
        "school": "West Feliciana Middle School",
        "district": "West Feliciana Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220198001276",
    },
    {
        "school": "Bains Elementary School",
        "district": "West Feliciana Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220198001474",
    },
    {
        "school": "West Feliciana High School",
        "district": "West Feliciana Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220198001476",
    },
    {
        "school": "Bains Lower Elementary School",
        "district": "West Feliciana Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220198002012",
    },
    {
        "school": "G. W. Carver Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000034",
    },
    {
        "school": "Donaldsonville Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000035",
    },
    {
        "school": "Donaldsonville High School",
        "district": "Ascension Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000036",
    },
    {
        "school": "Dutchtown Middle School",
        "district": "Ascension Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000037",
    },
    {
        "school": "East Ascension High School",
        "district": "Ascension Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000038",
    },
    {
        "school": "Galvez Middle School",
        "district": "Ascension Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000039",
    },
    {
        "school": "Gonzales Middle School",
        "district": "Ascension Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000040",
    },
    {
        "school": "Gonzales Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000041",
    },
    {
        "school": "Lowery Middle School",
        "district": "Ascension Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000042",
    },
    {
        "school": "Prairieville Middle School",
        "district": "Ascension Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000044",
    },
    {
        "school": "St. Amant Middle School",
        "district": "Ascension Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000045",
    },
    {
        "school": "St. Amant High School",
        "district": "Ascension Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000046",
    },
    {
        "school": "Lowery Elementary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000047",
    },
    {
        "school": "Central Middle School",
        "district": "Ascension Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000462",
    },
    {
        "school": "Oak Grove Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009000463",
    },
    {
        "school": "Galvez Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009001862",
    },
    {
        "school": "Lake Elementary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009001863",
    },
    {
        "school": "Dutchtown Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009001976",
    },
    {
        "school": "St. Amant Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009001977",
    },
    {
        "school": "Louisiana School for the Deaf",
        "district": "LA Schools for the Deaf and Visually Impaired",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220001801789",
    },
    {
        "school": "LSU Laboratory School",
        "district": "LSU Laboratory School",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220002201922",
    },
    {
        "school": "Southern University Lab School",
        "district": "Southern University Lab School",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220002301921",
    },
    {
        "school": "EBR Readiness Superintendent Academy",
        "district": "East Baton Rouge Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000339",
    },
    {
        "school": "Arlington Preparatory Academy",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000340",
    },
    {
        "school": "Audubon Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000341",
    },
    {
        "school": "Baton Rouge Magnet High School",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000347",
    },
    {
        "school": "Belaire High School",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000349",
    },
    {
        "school": "Belfair Montessori School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000350",
    },
    {
        "school": "Bernard Terrace Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000352",
    },
    {
        "school": "Broadmoor Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000353",
    },
    {
        "school": "Broadmoor Middle School",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000354",
    },
    {
        "school": "Broadmoor Senior High School",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000355",
    },
    {
        "school": "Brownfields Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000357",
    },
    {
        "school": "Buchanan Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000358",
    },
    {
        "school": "Capitol Middle School",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000360",
    },
    {
        "school": "Cedarcrest-Southmoor Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000362",
    },
    {
        "school": "Northeast High School",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000365",
    },
    {
        "school": "Claiborne Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000367",
    },
    {
        "school": "Crestworth Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000368",
    },
    {
        "school": "The Dufrocq School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000372",
    },
    {
        "school": "Capitol Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000373",
    },
    {
        "school": "Forest Heights Academy of Excellence",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000375",
    },
    {
        "school": "Glen Oaks Park Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000376",
    },
    {
        "school": "Glen Oaks Senior High School",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000378",
    },
    {
        "school": "Greenbrier Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000380",
    },
    {
        "school": "Highland Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000383",
    },
    {
        "school": "Howell Park Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000385",
    },
    {
        "school": "Jefferson Terrace Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000388",
    },
    {
        "school": "LaBelle Aire Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000390",
    },
    {
        "school": "LaSalle Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000392",
    },
    {
        "school": "Magnolia Woods Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000394",
    },
    {
        "school": "McKinley Middle Magnet School",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000396",
    },
    {
        "school": "McKinley Senior High School",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000397",
    },
    {
        "school": "Melrose Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000398",
    },
    {
        "school": "Merrydale Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000399",
    },
    {
        "school": "Northdale Superintendent's Academy",
        "district": "East Baton Rouge Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000404",
    },
    {
        "school": "Park Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000407",
    },
    {
        "school": "Park Forest Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000408",
    },
    {
        "school": "Park Forest Middle School",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000409",
    },
    {
        "school": "Parkview Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000411",
    },
    {
        "school": "Northeast Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000416",
    },
    {
        "school": "Progress Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000417",
    },
    {
        "school": "Riveroaks Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000420",
    },
    {
        "school": "Ryan Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000421",
    },
    {
        "school": "Scotlandville Magnet High School",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000423",
    },
    {
        "school": "Sharon Hills Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000425",
    },
    {
        "school": "Shenandoah Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000426",
    },
    {
        "school": "Sherwood Middle Academic Academy",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000428",
    },
    {
        "school": "B. R. Foreign Language Acad. Immersion Magnet",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000429",
    },
    {
        "school": "Southeast Middle School",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000432",
    },
    {
        "school": "Tara High School",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000434",
    },
    {
        "school": "Twin Oaks Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000435",
    },
    {
        "school": "University Terrace Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000436",
    },
    {
        "school": "Villa del Rey Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000438",
    },
    {
        "school": "Baton Rouge Center for Visual and Performing Arts",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000439",
    },
    {
        "school": "Wedgewood Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000440",
    },
    {
        "school": "Westdale Heights Academic Magnet School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000441",
    },
    {
        "school": "Westdale Middle School",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000442",
    },
    {
        "school": "Westminster Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000443",
    },
    {
        "school": "Wildwood Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000445",
    },
    {
        "school": "Winbourne Elementary School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000446",
    },
    {
        "school": "Woodlawn High School",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000447",
    },
    {
        "school": "Children's Charter School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000628",
    },
    {
        "school": "Community School For Apprenticeship Learning",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000673",
    },
    {
        "school": "J. K. Haynes Charter Inc.",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054000679",
    },
    {
        "school": "Glasgow Middle School",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054001554",
    },
    {
        "school": "Southdowns School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220054001920",
    },
    {
        "school": "Eastern LA Mental System",
        "district": "Special School District",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010001725",
    },
    {
        "school": "South Live Oak Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000233",
    },
    {
        "school": "Albany Upper Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000400",
    },
    {
        "school": "South Walker Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000403",
    },
    {
        "school": "Eastside Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000726",
    },
    {
        "school": "Albany Lower Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000754",
    },
    {
        "school": "Albany High School",
        "district": "Livingston Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000755",
    },
    {
        "school": "Denham Springs Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000757",
    },
    {
        "school": "Denham Springs High School",
        "district": "Livingston Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000758",
    },
    {
        "school": "Denham Springs Junior High School",
        "district": "Livingston Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000759",
    },
    {
        "school": "Doyle Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000760",
    },
    {
        "school": "Doyle High School",
        "district": "Livingston Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000761",
    },
    {
        "school": "French Settlement High School",
        "district": "Livingston Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000762",
    },
    {
        "school": "Freshwater Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000763",
    },
    {
        "school": "Frost School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000764",
    },
    {
        "school": "Holden High School",
        "district": "Livingston Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000765",
    },
    {
        "school": "Live Oak Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000766",
    },
    {
        "school": "Live Oak High School",
        "district": "Livingston Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000767",
    },
    {
        "school": "Maurepas School",
        "district": "Livingston Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000768",
    },
    {
        "school": "Northside Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000769",
    },
    {
        "school": "Seventh Ward Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000770",
    },
    {
        "school": "Southside Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000771",
    },
    {
        "school": "Springfield Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000772",
    },
    {
        "school": "Springfield High School",
        "district": "Livingston Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000773",
    },
    {
        "school": "Walker High School",
        "district": "Livingston Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000774",
    },
    {
        "school": "Walker Freshman High School",
        "district": "Livingston Parish",
        "level": "Secondary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000775",
    },
    {
        "school": "Walker Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000776",
    },
    {
        "school": "Westside Junior High School",
        "district": "Livingston Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000777",
    },
    {
        "school": "Denham Springs Freshman High School",
        "district": "Livingston Parish",
        "level": "Secondary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102000904",
    },
    {
        "school": "Live Oak Middle School",
        "district": "Livingston Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102001558",
    },
    {
        "school": "Southside Junior High School",
        "district": "Livingston Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102001559",
    },
    {
        "school": "Levi Milton Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102001612",
    },
    {
        "school": "French Settlement Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102001707",
    },
    {
        "school": "Albany Middle School",
        "district": "Livingston Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102001708",
    },
    {
        "school": "Lewis Vincent Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102001709",
    },
    {
        "school": "Pinecrest Supports & Services Center",
        "district": "Special School District",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010001730",
    },
    {
        "school": "Brusly Elementary School",
        "district": "West Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220192000419",
    },
    {
        "school": "Lukeville Upper Elementary",
        "district": "West Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220192000448",
    },
    {
        "school": "Brusly High School",
        "district": "West Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220192001457",
    },
    {
        "school": "Brusly Middle School",
        "district": "West Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220192001458",
    },
    {
        "school": "Chamberlin Elementary School",
        "district": "West Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220192001459",
    },
    {
        "school": "Cohn Elementary School",
        "district": "West Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220192001460",
    },
    {
        "school": "Devall Middle School",
        "district": "West Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220192001461",
    },
    {
        "school": "Port Allen Elementary School",
        "district": "West Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220192001463",
    },
    {
        "school": "Port Allen High School",
        "district": "West Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220192001464",
    },
    {
        "school": "Port Allen Middle School",
        "district": "West Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220192001548",
    },
    {
        "school": "Central Elementary School",
        "district": "City of Bogalusa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024000102",
    },
    {
        "school": "Bogalusa High School",
        "district": "City of Bogalusa School District",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024000103",
    },
    {
        "school": "Byrd Avenue Primary School",
        "district": "City of Bogalusa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024000104",
    },
    {
        "school": "Enon Elementary School",
        "district": "Washington Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220186001420",
    },
    {
        "school": "Franklinton Elementary School",
        "district": "Washington Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220186001421",
    },
    {
        "school": "Franklinton Junior High School",
        "district": "Washington Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220186001422",
    },
    {
        "school": "Franklinton Primary School",
        "district": "Washington Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220186001423",
    },
    {
        "school": "Franklinton High School",
        "district": "Washington Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220186001424",
    },
    {
        "school": "Mt. Hermon School",
        "district": "Washington Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220186001425",
    },
    {
        "school": "Pine School",
        "district": "Washington Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220186001426",
    },
    {
        "school": "Thomas Elementary School",
        "district": "Washington Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220186001427",
    },
    {
        "school": "Varnado High School",
        "district": "Washington Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220186001429",
    },
    {
        "school": "Wesley Ray Elementary School",
        "district": "Washington Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220186001431",
    },
    {
        "school": "Armstrong Middle School",
        "district": "Acadia Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000001",
    },
    {
        "school": "Branch Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000002",
    },
    {
        "school": "Central Rayne Kindergarten School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000003",
    },
    {
        "school": "Church Point High School",
        "district": "Acadia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000004",
    },
    {
        "school": "Church Point Middle School",
        "district": "Acadia Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000005",
    },
    {
        "school": "Crowley High School",
        "district": "Acadia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000006",
    },
    {
        "school": "Crowley Middle School",
        "district": "Acadia Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000007",
    },
    {
        "school": "Crowley Kindergarten School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000008",
    },
    {
        "school": "North Crowley Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000009",
    },
    {
        "school": "Egan Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000010",
    },
    {
        "school": "Estherwood Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000011",
    },
    {
        "school": "Evangeline Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000012",
    },
    {
        "school": "Iota Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000013",
    },
    {
        "school": "Iota High School",
        "district": "Acadia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000014",
    },
    {
        "school": "Mermentau Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000015",
    },
    {
        "school": "Midland High School",
        "district": "Acadia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000016",
    },
    {
        "school": "Mire Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000017",
    },
    {
        "school": "Morse Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000018",
    },
    {
        "school": "Rayne High School",
        "district": "Acadia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000019",
    },
    {
        "school": "Richard Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000020",
    },
    {
        "school": "Ross Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000021",
    },
    {
        "school": "South Crowley Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000022",
    },
    {
        "school": "South Rayne Elementary School",
        "district": "Acadia Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003000023",
    },
    {
        "school": "Iota Middle School",
        "district": "Acadia Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003001015",
    },
    {
        "school": "Martin Petitjean Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003001504",
    },
    {
        "school": "Church Point Elementary School",
        "district": "Acadia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003001505",
    },
    {
        "school": "Carver Elementary School",
        "district": "Beauregard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018000079",
    },
    {
        "school": "DeRidder High School",
        "district": "Beauregard Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018000081",
    },
    {
        "school": "DeRidder Junior High School",
        "district": "Beauregard Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018000082",
    },
    {
        "school": "East Beauregard High School",
        "district": "Beauregard Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018000083",
    },
    {
        "school": "Merryville High School",
        "district": "Beauregard Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018000086",
    },
    {
        "school": "Pine Wood Elementary School",
        "district": "Beauregard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018000087",
    },
    {
        "school": "Singer High School",
        "district": "Beauregard Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018000088",
    },
    {
        "school": "South Beauregard High School",
        "district": "Beauregard Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018000089",
    },
    {
        "school": "East Beauregard Elementary School",
        "district": "Beauregard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018001507",
    },
    {
        "school": "K.R. Hanchey Elementary School",
        "district": "Beauregard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018001572",
    },
    {
        "school": "South Beauregard Elementary School",
        "district": "Beauregard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018001864",
    },
    {
        "school": "North Polk Elementary School",
        "district": "Vernon Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183000192",
    },
    {
        "school": "Anacoco High School",
        "district": "Vernon Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001405",
    },
    {
        "school": "East Leesville Elementary School",
        "district": "Vernon Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001406",
    },
    {
        "school": "Evans High School",
        "district": "Vernon Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001407",
    },
    {
        "school": "Hicks High School",
        "district": "Vernon Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001408",
    },
    {
        "school": "Hornbeck High School",
        "district": "Vernon Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001409",
    },
    {
        "school": "Leesville High School",
        "district": "Vernon Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001410",
    },
    {
        "school": "Leesville Junior High School",
        "district": "Vernon Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001411",
    },
    {
        "school": "Pickering Elementary School",
        "district": "Vernon Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001412",
    },
    {
        "school": "Pitkin High School",
        "district": "Vernon Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001413",
    },
    {
        "school": "Parkway Elementary School",
        "district": "Vernon Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001414",
    },
    {
        "school": "Rosepine High School",
        "district": "Vernon Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001415",
    },
    {
        "school": "Simpson High School",
        "district": "Vernon Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001416",
    },
    {
        "school": "Vernon Middle School",
        "district": "Vernon Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001417",
    },
    {
        "school": "West Leesville Elementary School",
        "district": "Vernon Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001418",
    },
    {
        "school": "Pickering High School",
        "district": "Vernon Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001664",
    },
    {
        "school": "Rosepine Elementary School",
        "district": "Vernon Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001665",
    },
    {
        "school": "Anacoco Elementary School",
        "district": "Vernon Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220183001847",
    },
    {
        "school": "Amite Elementary Magnet School",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001297",
    },
    {
        "school": "Amite High Magnet",
        "district": "Tangipahoa Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001298",
    },
    {
        "school": "Champ Cooper Elementary School",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001299",
    },
    {
        "school": "Chesbrough Elementary School",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001300",
    },
    {
        "school": "Hammond High Magnet School",
        "district": "Tangipahoa Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001304",
    },
    {
        "school": "Greenville Park Leadership Academy",
        "district": "Tangipahoa Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001305",
    },
    {
        "school": "Independence Leadership Academy",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001306",
    },
    {
        "school": "Independence High Magnet",
        "district": "Tangipahoa Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001307",
    },
    {
        "school": "Independence Magnet",
        "district": "Tangipahoa Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001308",
    },
    {
        "school": "O.W. Dillon Leadership Academy",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001309",
    },
    {
        "school": "Kentwood High Magnet School",
        "district": "Tangipahoa Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001310",
    },
    {
        "school": "Loranger Elementary School",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001311",
    },
    {
        "school": "Loranger High School",
        "district": "Tangipahoa Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001312",
    },
    {
        "school": "Midway Elementary School",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001313",
    },
    {
        "school": "Natalbany Middle",
        "district": "Tangipahoa Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001315",
    },
    {
        "school": "Lucille Nesom Memorial",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001316",
    },
    {
        "school": "Ponchatoula Junior High School",
        "district": "Tangipahoa Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001317",
    },
    {
        "school": "Ponchatoula High School",
        "district": "Tangipahoa Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001319",
    },
    {
        "school": "D.C. Reeves Elementary School",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001320",
    },
    {
        "school": "Roseland Montessori",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001321",
    },
    {
        "school": "Southeastern LA University Lab School",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001322",
    },
    {
        "school": "Spring Creek Elementary School",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001323",
    },
    {
        "school": "Tucker Memorial Elementary School",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001324",
    },
    {
        "school": "Martha Vinyard Elementary School",
        "district": "Tangipahoa Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001325",
    },
    {
        "school": "Amite Westside Middle Magnet",
        "district": "Tangipahoa Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001326",
    },
    {
        "school": "Jewel M. Sumner High School",
        "district": "Tangipahoa Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001840",
    },
    {
        "school": "Perrin Early Learning Center",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001841",
    },
    {
        "school": "Hammond Westside Montessori",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001900",
    },
    {
        "school": "Hammond Eastside Magnet",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001902",
    },
    {
        "school": "Loranger Middle School",
        "district": "Tangipahoa Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001951",
    },
    {
        "school": "Woodland Park Magnet",
        "district": "Tangipahoa Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168001991",
    },
    {
        "school": "Bayou Blue Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000697",
    },
    {
        "school": "Bayou Boeuf Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000698",
    },
    {
        "school": "Central Lafourche High School",
        "district": "Lafourche Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000699",
    },
    {
        "school": "Chackbay Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000700",
    },
    {
        "school": "Sixth Ward Middle School",
        "district": "Lafourche Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000701",
    },
    {
        "school": "Cut Off Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000702",
    },
    {
        "school": "East Thibodaux Middle School",
        "district": "Lafourche Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000703",
    },
    {
        "school": "Galliano Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000704",
    },
    {
        "school": "Golden Meadow Middle School",
        "district": "Lafourche Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000706",
    },
    {
        "school": "Golden Meadow Lower Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000707",
    },
    {
        "school": "Golden Meadow Upper Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000708",
    },
    {
        "school": "W.S. Lafargue Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000709",
    },
    {
        "school": "North Larose Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000710",
    },
    {
        "school": "Larose-Cut Off Middle School",
        "district": "Lafourche Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000711",
    },
    {
        "school": "Lockport Middle School",
        "district": "Lafourche Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000712",
    },
    {
        "school": "Lockport Lower Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000713",
    },
    {
        "school": "Lockport Upper Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000714",
    },
    {
        "school": "Raceland Middle School",
        "district": "Lafourche Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000716",
    },
    {
        "school": "Raceland Lower Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000717",
    },
    {
        "school": "Raceland Upper Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000718",
    },
    {
        "school": "St. Charles Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000719",
    },
    {
        "school": "South Lafourche High School",
        "district": "Lafourche Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000721",
    },
    {
        "school": "South Thibodaux Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000722",
    },
    {
        "school": "Thibodaux Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000724",
    },
    {
        "school": "Thibodaux High School",
        "district": "Lafourche Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000725",
    },
    {
        "school": "West Thibodaux Middle School",
        "district": "Lafourche Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090000727",
    },
    {
        "school": "South Larose Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090001603",
    },
    {
        "school": "Acadian Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001334",
    },
    {
        "school": "Bayou Black Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001335",
    },
    {
        "school": "Bourg Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001337",
    },
    {
        "school": "H. L. Bourgeois High School",
        "district": "Terrebonne Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001338",
    },
    {
        "school": "Broadmoor Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001339",
    },
    {
        "school": "Caldwell Middle School",
        "district": "Terrebonne Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001340",
    },
    {
        "school": "Coteau-Bayou Blue Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001341",
    },
    {
        "school": "Dularge Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001342",
    },
    {
        "school": "Ellender Memorial High School",
        "district": "Terrebonne Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001346",
    },
    {
        "school": "Evergreen Junior High School",
        "district": "Terrebonne Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001348",
    },
    {
        "school": "Gibson Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001349",
    },
    {
        "school": "Grand Caillou Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001350",
    },
    {
        "school": "Honduras Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001352",
    },
    {
        "school": "Houma Junior High School",
        "district": "Terrebonne Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001353",
    },
    {
        "school": "Lacache Middle School",
        "district": "Terrebonne Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001354",
    },
    {
        "school": "Legion Park Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001355",
    },
    {
        "school": "Lisa Park Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001356",
    },
    {
        "school": "Montegut Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001358",
    },
    {
        "school": "Montegut Middle School",
        "district": "Terrebonne Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001359",
    },
    {
        "school": "Mulberry Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001360",
    },
    {
        "school": "Oaklawn Junior High School",
        "district": "Terrebonne Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001361",
    },
    {
        "school": "Oakshire Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001362",
    },
    {
        "school": "Pointe-aux-Chenes Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001363",
    },
    {
        "school": "Schriever Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001365",
    },
    {
        "school": "Southdown Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001366",
    },
    {
        "school": "South Terrebonne High School",
        "district": "Terrebonne Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001367",
    },
    {
        "school": "Terrebonne High School",
        "district": "Terrebonne Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001368",
    },
    {
        "school": "Upper Little Caillou Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001370",
    },
    {
        "school": "Village East Elementary School",
        "district": "Terrebonne Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001503",
    },
    {
        "school": "School for Exceptional Children",
        "district": "Terrebonne Parish",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220174001653",
    },
    {
        "school": "Louis Miller Terrebonne Career and Technical HS",
        "district": "Terrebonne Parish",
        "level": "High",
        "type": "Career and Technical School",
        "state": "LA",
        "nces_id": "220174001658",
    },
    {
        "school": "Grand Caillou Middle School",
        "district": "Terrebonne Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220174001952",
    },
    {
        "school": "Elton High School",
        "district": "Jefferson Davis Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000561",
    },
    {
        "school": "Elton Elementary School",
        "district": "Jefferson Davis Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000562",
    },
    {
        "school": "Fenton Elementary School",
        "district": "Jefferson Davis Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000563",
    },
    {
        "school": "Hathaway High School",
        "district": "Jefferson Davis Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000564",
    },
    {
        "school": "Jennings High School",
        "district": "Jefferson Davis Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000566",
    },
    {
        "school": "Ward Elementary School",
        "district": "Jefferson Davis Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000568",
    },
    {
        "school": "Jennings Elementary School",
        "district": "Jefferson Davis Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000569",
    },
    {
        "school": "Lacassine High School",
        "district": "Jefferson Davis Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000570",
    },
    {
        "school": "Lake Arthur Elementary School",
        "district": "Jefferson Davis Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000571",
    },
    {
        "school": "Lake Arthur High School",
        "district": "Jefferson Davis Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000572",
    },
    {
        "school": "Welsh Elementary School",
        "district": "Jefferson Davis Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000573",
    },
    {
        "school": "Welsh High School",
        "district": "Jefferson Davis Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000574",
    },
    {
        "school": "Welsh-Roanoke Junior High School",
        "district": "Jefferson Davis Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220081000575",
    },
    {
        "school": "J. Wallace James Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087001546",
    },
    {
        "school": "W. D. & Mary Baker Smith Career Center",
        "district": "Lafayette Parish",
        "level": "High",
        "type": "Career and Technical School",
        "state": "LA",
        "nces_id": "220087000374",
    },
    {
        "school": "Acadian Middle School",
        "district": "Lafayette Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000659",
    },
    {
        "school": "Acadiana High School",
        "district": "Lafayette Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000660",
    },
    {
        "school": "L.J. Alleman Middle School",
        "district": "Lafayette Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000661",
    },
    {
        "school": "Alice N. Boucher Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000662",
    },
    {
        "school": "Paul Breaux Middle School",
        "district": "Lafayette Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000663",
    },
    {
        "school": "Broadmoor Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000664",
    },
    {
        "school": "Broussard Middle School",
        "district": "Lafayette Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000665",
    },
    {
        "school": "Carencro Middle School",
        "district": "Lafayette Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000666",
    },
    {
        "school": "Carencro Heights Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000667",
    },
    {
        "school": "Carencro High School",
        "district": "Lafayette Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000668",
    },
    {
        "school": "O. Comeaux High School",
        "district": "Lafayette Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000669",
    },
    {
        "school": "Katharine Drexel Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000670",
    },
    {
        "school": "Duson Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000671",
    },
    {
        "school": "J.W. Faulk Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000672",
    },
    {
        "school": "Judice Middle School",
        "district": "Lafayette Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000675",
    },
    {
        "school": "L. Leo Judice Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000676",
    },
    {
        "school": "Lafayette Middle School",
        "district": "Lafayette Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000677",
    },
    {
        "school": "Lafayette High School",
        "district": "Lafayette Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000678",
    },
    {
        "school": "Green T. Lindon Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000680",
    },
    {
        "school": "Edgar Martin Middle School",
        "district": "Lafayette Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000681",
    },
    {
        "school": "Milton Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000682",
    },
    {
        "school": "S.J. Montgomery Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000683",
    },
    {
        "school": "Myrtle Place Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000685",
    },
    {
        "school": "Northside High School",
        "district": "Lafayette Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000686",
    },
    {
        "school": "Corporal Michael Middlebrook Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000687",
    },
    {
        "school": "Prairie Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000688",
    },
    {
        "school": "Scott Middle School",
        "district": "Lafayette Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000690",
    },
    {
        "school": "Truman Early Childhood Education Center",
        "district": "Lafayette Parish",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000691",
    },
    {
        "school": "Westside Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000693",
    },
    {
        "school": "Woodvale Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000694",
    },
    {
        "school": "Youngsville Middle School",
        "district": "Lafayette Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087000695",
    },
    {
        "school": "Charles M. Burke Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087001147",
    },
    {
        "school": "Ernest Gallet Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087001173",
    },
    {
        "school": "Live Oak Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087001176",
    },
    {
        "school": "N. P. Moss Preparatory Academy",
        "district": "Lafayette Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087001397",
    },
    {
        "school": "Ossun Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087001556",
    },
    {
        "school": "Evangeline Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087001598",
    },
    {
        "school": "Ridge Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087001600",
    },
    {
        "school": "Breaux Bridge Elementary School",
        "district": "St. Martin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001216",
    },
    {
        "school": "Breaux Bridge Junior High School",
        "district": "St. Martin Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001217",
    },
    {
        "school": "Breaux Bridge Primary School",
        "district": "St. Martin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001218",
    },
    {
        "school": "Breaux Bridge High School",
        "district": "St. Martin Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001219",
    },
    {
        "school": "Catahoula Elementary School",
        "district": "St. Martin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001220",
    },
    {
        "school": "Cecilia Junior High School",
        "district": "St. Martin Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001221",
    },
    {
        "school": "Cecilia Primary School",
        "district": "St. Martin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001222",
    },
    {
        "school": "Cecilia High School",
        "district": "St. Martin Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001223",
    },
    {
        "school": "Parks Middle School",
        "district": "St. Martin Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001224",
    },
    {
        "school": "Parks Primary School",
        "district": "St. Martin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001225",
    },
    {
        "school": "St. Martinville Junior High School",
        "district": "St. Martin Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001227",
    },
    {
        "school": "St. Martinville Primary School",
        "district": "St. Martin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001228",
    },
    {
        "school": "St. Martinville Senior High School",
        "district": "St. Martin Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001229",
    },
    {
        "school": "Stephensville Elementary School",
        "district": "St. Martin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001230",
    },
    {
        "school": "Teche Elementary School",
        "district": "St. Martin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001231",
    },
    {
        "school": "Early Learning Center",
        "district": "St. Martin Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220159001645",
    },
    {
        "school": "LeBleu Settlement Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033001543",
    },
    {
        "school": "Grand Lake High School",
        "district": "Cameron Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220039000289",
    },
    {
        "school": "Hackberry High School",
        "district": "Cameron Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220039000290",
    },
    {
        "school": "Johnson Bayou High School",
        "district": "Cameron Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220039000291",
    },
    {
        "school": "South Cameron High School",
        "district": "Cameron Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220039000293",
    },
    {
        "school": "S. P. Arnett Middle School",
        "district": "Calcasieu Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000214",
    },
    {
        "school": "Barbe Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000215",
    },
    {
        "school": "Alfred M. Barbe High School",
        "district": "Calcasieu Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000216",
    },
    {
        "school": "Bell City High School",
        "district": "Calcasieu Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000217",
    },
    {
        "school": "Brentwood Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000219",
    },
    {
        "school": "Jake Drost School for Exceptional Children",
        "district": "Calcasieu Parish",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220033000220",
    },
    {
        "school": "Jessie D. Clifton Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000222",
    },
    {
        "school": "College Oaks Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000223",
    },
    {
        "school": "T. S. Cooley Elementary Magnet School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000224",
    },
    {
        "school": "DeQuincy Primary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000225",
    },
    {
        "school": "DeQuincy Middle School",
        "district": "Calcasieu Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000226",
    },
    {
        "school": "DeQuincy High School",
        "district": "Calcasieu Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000227",
    },
    {
        "school": "Dolby Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000228",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000230",
    },
    {
        "school": "Frasch Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000232",
    },
    {
        "school": "W. T. Henning Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000235",
    },
    {
        "school": "Henry Heights Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000236",
    },
    {
        "school": "Sam Houston High School",
        "district": "Calcasieu Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000237",
    },
    {
        "school": "Iowa High School",
        "district": "Calcasieu Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000238",
    },
    {
        "school": "M. J. Kaufman Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000240",
    },
    {
        "school": "John F. Kennedy Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000241",
    },
    {
        "school": "E. K. Key Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000242",
    },
    {
        "school": "LaGrange High School",
        "district": "Calcasieu Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000244",
    },
    {
        "school": "LeBlanc Middle School",
        "district": "Calcasieu Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000246",
    },
    {
        "school": "W. W. Lewis Middle School",
        "district": "Calcasieu Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000247",
    },
    {
        "school": "Maplewood Middle School",
        "district": "Calcasieu Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000248",
    },
    {
        "school": "John J. Johnson II Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000250",
    },
    {
        "school": "Ray D. Molo Middle Magnet School",
        "district": "Calcasieu Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000251",
    },
    {
        "school": "Moss Bluff Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000252",
    },
    {
        "school": "Moss Bluff Middle School",
        "district": "Calcasieu Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000253",
    },
    {
        "school": "A. A. Nelson Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000255",
    },
    {
        "school": "Oak Park Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000256",
    },
    {
        "school": "Oak Park Middle School",
        "district": "Calcasieu Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000257",
    },
    {
        "school": "Cypress Cove Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000258",
    },
    {
        "school": "Prien Lake Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000259",
    },
    {
        "school": "Combre-Fondel Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000261",
    },
    {
        "school": "St. John Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000264",
    },
    {
        "school": "Starks High School",
        "district": "Calcasieu Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000265",
    },
    {
        "school": "Sulphur High School",
        "district": "Calcasieu Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000266",
    },
    {
        "school": "Richard W. Vincent Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000268",
    },
    {
        "school": "Vinton Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000269",
    },
    {
        "school": "Vinton High School",
        "district": "Calcasieu Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000270",
    },
    {
        "school": "Vinton Middle School",
        "district": "Calcasieu Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000271",
    },
    {
        "school": "Washington/Marion Magnet High School",
        "district": "Calcasieu Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000272",
    },
    {
        "school": "T. H. Watkins Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000273",
    },
    {
        "school": "J. I. Watson Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000274",
    },
    {
        "school": "S. J. Welsh Middle School",
        "district": "Calcasieu Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000276",
    },
    {
        "school": "Western Heights Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000277",
    },
    {
        "school": "Westlake High School",
        "district": "Calcasieu Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000278",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000279",
    },
    {
        "school": "F. K. White Middle School",
        "district": "Calcasieu Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033000280",
    },
    {
        "school": "Ralph F. Wilson Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033001506",
    },
    {
        "school": "Gillis Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033001674",
    },
    {
        "school": "Pearl Watson Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033001677",
    },
    {
        "school": "Brown Upper Elementary School",
        "district": "Webster Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001432",
    },
    {
        "school": "Browning Elementary School",
        "district": "Webster Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001433",
    },
    {
        "school": "North Webster Upper Elementary School",
        "district": "Webster Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001435",
    },
    {
        "school": "Doyline High School",
        "district": "Webster Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001436",
    },
    {
        "school": "Central Elementary School",
        "district": "Webster Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001440",
    },
    {
        "school": "J. L. Jones Elementary School",
        "district": "Webster Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001442",
    },
    {
        "school": "Minden High School",
        "district": "Webster Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001444",
    },
    {
        "school": "J. A. Phillips Elementary School",
        "district": "Webster Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001445",
    },
    {
        "school": "E. S. Richardson Elementary School",
        "district": "Webster Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001446",
    },
    {
        "school": "North Webster Junior High School",
        "district": "Webster Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001447",
    },
    {
        "school": "North Webster Lower Elementary School",
        "district": "Webster Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001448",
    },
    {
        "school": "Lakeside Junior-Senior High School",
        "district": "Webster Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001450",
    },
    {
        "school": "North Webster High School",
        "district": "Webster Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001451",
    },
    {
        "school": "Webster Junior High School",
        "district": "Webster Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220189001455",
    },
    {
        "school": "Sherrouse School",
        "district": "City of Monroe School District",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108002019",
    },
    {
        "school": "Swartz Lower Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001553",
    },
    {
        "school": "West Ridge Middle School",
        "district": "Ouachita Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001557",
    },
    {
        "school": "Good Hope Middle School",
        "district": "Ouachita Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001564",
    },
    {
        "school": "Richwood Junior High School",
        "district": "Ouachita Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001683",
    },
    {
        "school": "Downsville Community Charter School",
        "district": "Union Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220177001374",
    },
    {
        "school": "Union Parish High School",
        "district": "Union Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220177001376",
    },
    {
        "school": "Union Parish Junior High School",
        "district": "Union Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220177001377",
    },
    {
        "school": "Union Parish Elementary School",
        "district": "Union Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220177001694",
    },
    {
        "school": "New Vision Learning Academy",
        "district": "New Vision Learning Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220002501000",
    },
    {
        "school": "Carroll High School",
        "district": "City of Monroe School District",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000787",
    },
    {
        "school": "Carroll Junior High School",
        "district": "City of Monroe School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000788",
    },
    {
        "school": "Carver Elementary School",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000789",
    },
    {
        "school": "J.S. Clark Magnet Elementary School",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000790",
    },
    {
        "school": "Barkdull Faulk Elementary School",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000791",
    },
    {
        "school": "Clara Hall Accelerated School",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000792",
    },
    {
        "school": "Sallie Humble Elementary School",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000793",
    },
    {
        "school": "Martin Luther King Junior High School",
        "district": "City of Monroe School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000794",
    },
    {
        "school": "Berg Jones Elementary School",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000795",
    },
    {
        "school": "Robert E. Lee Junior High School",
        "district": "City of Monroe School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000796",
    },
    {
        "school": "Lexington Elementary School",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000797",
    },
    {
        "school": "Roy Neal Shelling Sr. Elementary",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000798",
    },
    {
        "school": "Neville High School",
        "district": "City of Monroe School District",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000799",
    },
    {
        "school": "Minnie Ruffin Elementary School",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000800",
    },
    {
        "school": "Wossman High School",
        "district": "City of Monroe School District",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000803",
    },
    {
        "school": "Cypress Point Elementary School",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000831",
    },
    {
        "school": "Madison James Foster Elementary School",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108000996",
    },
    {
        "school": "Thomas Jefferson Elementary",
        "district": "City of Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220108001482",
    },
    {
        "school": "Central Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120000986",
    },
    {
        "school": "Claiborne School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120000987",
    },
    {
        "school": "Crosley Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120000988",
    },
    {
        "school": "Drew Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120000989",
    },
    {
        "school": "Jack Hayes Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120000990",
    },
    {
        "school": "Highland Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120000992",
    },
    {
        "school": "Kiroli Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120000993",
    },
    {
        "school": "Lakeshore School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120000994",
    },
    {
        "school": "Lenwil Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120000995",
    },
    {
        "school": "Boley Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120000998",
    },
    {
        "school": "Ouachita Parish High School",
        "district": "Ouachita Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001001",
    },
    {
        "school": "Ouachita Junior High School",
        "district": "Ouachita Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001002",
    },
    {
        "school": "Pinecrest Elementary/Middle School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001004",
    },
    {
        "school": "Riser Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001008",
    },
    {
        "school": "Riser Middle School",
        "district": "Ouachita Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001009",
    },
    {
        "school": "Robinson Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001010",
    },
    {
        "school": "Shady Grove Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001011",
    },
    {
        "school": "Sterlington Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001012",
    },
    {
        "school": "Sterlington High School",
        "district": "Ouachita Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001013",
    },
    {
        "school": "Swartz Upper Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001014",
    },
    {
        "school": "Swayze Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001016",
    },
    {
        "school": "West Monroe High School",
        "district": "Ouachita Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001017",
    },
    {
        "school": "Woodlawn Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001020",
    },
    {
        "school": "Woodlawn Middle School",
        "district": "Ouachita Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001021",
    },
    {
        "school": "Riverbend Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001466",
    },
    {
        "school": "Richwood High School",
        "district": "Ouachita Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001525",
    },
    {
        "school": "Calhoun Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001527",
    },
    {
        "school": "Calhoun Middle School",
        "district": "Ouachita Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001889",
    },
    {
        "school": "West Ouachita High School",
        "district": "Ouachita Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001939",
    },
    {
        "school": "George Welch Elementary School",
        "district": "Ouachita Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120001940",
    },
    {
        "school": "V. B. Glencoe Charter School",
        "district": "V. B. Glencoe Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003201375",
    },
    {
        "school": "J.S. Aucoin Elementary School",
        "district": "St. Mary Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001232",
    },
    {
        "school": "Bayou Vista Elementary School",
        "district": "St. Mary Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001234",
    },
    {
        "school": "Berwick Elementary School",
        "district": "St. Mary Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001235",
    },
    {
        "school": "Berwick High School",
        "district": "St. Mary Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001236",
    },
    {
        "school": "Berwick Junior High School",
        "district": "St. Mary Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001237",
    },
    {
        "school": "Centerville High School",
        "district": "St. Mary Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001238",
    },
    {
        "school": "W.P. Foster Elementary School",
        "district": "St. Mary Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001241",
    },
    {
        "school": "Franklin Senior High School",
        "district": "St. Mary Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001242",
    },
    {
        "school": "Franklin Junior High School",
        "district": "St. Mary Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001243",
    },
    {
        "school": "B. Edward Boudreaux Middle School",
        "district": "St. Mary Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001248",
    },
    {
        "school": "LaGrange Elementary School",
        "district": "St. Mary Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001249",
    },
    {
        "school": "Julia B. Maitland School",
        "district": "St. Mary Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001250",
    },
    {
        "school": "Morgan City High School",
        "district": "St. Mary Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001251",
    },
    {
        "school": "Morgan City Junior High School",
        "district": "St. Mary Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001252",
    },
    {
        "school": "West St. Mary High School",
        "district": "St. Mary Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001253",
    },
    {
        "school": "Patterson High School",
        "district": "St. Mary Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001254",
    },
    {
        "school": "Patterson Junior High School",
        "district": "St. Mary Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001255",
    },
    {
        "school": "Hattie A. Watts Elementary School",
        "district": "St. Mary Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001259",
    },
    {
        "school": "Wyandotte Elementary School",
        "district": "St. Mary Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001262",
    },
    {
        "school": "M.E. Norman Elementary School",
        "district": "St. Mary Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162001947",
    },
    {
        "school": "Ferriday High School",
        "district": "Concordia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220048000317",
    },
    {
        "school": "Ferriday Junior High School",
        "district": "Concordia Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220048000318",
    },
    {
        "school": "Ferriday Lower Elementary School",
        "district": "Concordia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220048000319",
    },
    {
        "school": "Ferriday Upper Elementary School",
        "district": "Concordia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220048000321",
    },
    {
        "school": "Monterey High School",
        "district": "Concordia Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220048000322",
    },
    {
        "school": "Vidalia High School",
        "district": "Concordia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220048000324",
    },
    {
        "school": "Vidalia Junior High School",
        "district": "Concordia Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220048000325",
    },
    {
        "school": "Vidalia Lower Elementary School",
        "district": "Concordia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220048000326",
    },
    {
        "school": "Vidalia Upper Elementary School",
        "district": "Concordia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220048000327",
    },
    {
        "school": "Concordia Education Center",
        "district": "Concordia Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220048001515",
    },
    {
        "school": "Louisiana School for Math Science & the Arts",
        "district": "Louisiana School for Math Science & the Arts",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220001701975",
    },
    {
        "school": "Lakeview Jr./Sr. High School",
        "district": "Natchitoches Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114000101",
    },
    {
        "school": "East Natchitoches Elementary & Middle School",
        "district": "Natchitoches Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114000828",
    },
    {
        "school": "Fairview-Alpha Elementary & Junior High School",
        "district": "Natchitoches Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114000829",
    },
    {
        "school": "Goldonna Elementary & Junior High School",
        "district": "Natchitoches Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114000830",
    },
    {
        "school": "Marthaville Elementary & Junior High School",
        "district": "Natchitoches Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114000832",
    },
    {
        "school": "Natchitoches Central High School",
        "district": "Natchitoches Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114000834",
    },
    {
        "school": "N.S.U. Elementary Lab School",
        "district": "Natchitoches Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114000836",
    },
    {
        "school": "N.S.U. Middle Lab School",
        "district": "Natchitoches Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114000838",
    },
    {
        "school": "Provencal Elementary & Junior High School",
        "district": "Natchitoches Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114000841",
    },
    {
        "school": "M.R. Weaver Elementary School",
        "district": "Natchitoches Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114000845",
    },
    {
        "school": "Natchitoches Parish Technical and Career Center",
        "district": "Natchitoches Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114001404",
    },
    {
        "school": "Natchitoches Jr. High School",
        "district": "Natchitoches Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114001616",
    },
    {
        "school": "L.P. Vaughn Elementary & Middle School",
        "district": "Natchitoches Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220114001617",
    },
    {
        "school": "Iberia Middle School",
        "district": "Iberia Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000316",
    },
    {
        "school": "Anderson Middle School",
        "district": "Iberia Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000505",
    },
    {
        "school": "Center Street Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000509",
    },
    {
        "school": "Coteau Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000510",
    },
    {
        "school": "Johnston Hopkins Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000514",
    },
    {
        "school": "Jeanerette Senior High School",
        "district": "Iberia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000519",
    },
    {
        "school": "Loreauville Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000522",
    },
    {
        "school": "Loreauville High School",
        "district": "Iberia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000523",
    },
    {
        "school": "Westgate High School",
        "district": "Iberia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000525",
    },
    {
        "school": "New Iberia Senior High School",
        "district": "Iberia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000527",
    },
    {
        "school": "North Lewis Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000528",
    },
    {
        "school": "Park Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000530",
    },
    {
        "school": "Pesson Addition Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000532",
    },
    {
        "school": "Delcambre Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072001585",
    },
    {
        "school": "St. Charles Street Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072001924",
    },
    {
        "school": "Daspit Road Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072001925",
    },
    {
        "school": "Sugarland Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072001926",
    },
    {
        "school": "Belle Place Middle School",
        "district": "Iberia Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072001927",
    },
    {
        "school": "Delcambre High School",
        "district": "Iberia Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072000511",
    },
    {
        "school": "Patrick F. Taylor Science & Technology Academy",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001667",
    },
    {
        "school": "Belle Chasse Academy",
        "district": "Belle Chasse Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220004101630",
    },
    {
        "school": "Creekside Junior High",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001591",
    },
    {
        "school": "L.P. Monteleone Junior High School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001686",
    },
    {
        "school": "Riverdale Middle School",
        "district": "Jefferson Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000320",
    },
    {
        "school": "John Q. Adams Middle School",
        "district": "Jefferson Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000576",
    },
    {
        "school": "A.C. Alexander Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000578",
    },
    {
        "school": "Judge Lionel R. Collins Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000579",
    },
    {
        "school": "Alice Birney Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000583",
    },
    {
        "school": "Bissonet Plaza Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000584",
    },
    {
        "school": "Bonnabel Magnet Academy High School",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000585",
    },
    {
        "school": "Mildred S. Harris Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000587",
    },
    {
        "school": "Bridgedale Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000588",
    },
    {
        "school": "John Clancy/Joseph Maggiore Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000590",
    },
    {
        "school": "George Cox Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000591",
    },
    {
        "school": "Helen Cox High School",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000592",
    },
    {
        "school": "Ella Dolhonde Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000595",
    },
    {
        "school": "East Jefferson High School",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000597",
    },
    {
        "school": "John Ehret High School",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000598",
    },
    {
        "school": "Allen Ellender School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000599",
    },
    {
        "school": "J.C. Ellis Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000600",
    },
    {
        "school": "Estelle Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000602",
    },
    {
        "school": "Fisher Middle/High School",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000604",
    },
    {
        "school": "Henry Ford Middle School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000605",
    },
    {
        "school": "Grand Isle High School",
        "district": "Jefferson Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000606",
    },
    {
        "school": "Greenlawn Terrace Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000607",
    },
    {
        "school": "Green Park Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000608",
    },
    {
        "school": "Gretna Middle School",
        "district": "Jefferson Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000609",
    },
    {
        "school": "Shirley Johnson/Gretna Park Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000612",
    },
    {
        "school": "Harahan Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000613",
    },
    {
        "school": "T.H. Harris Middle School",
        "district": "Jefferson Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000614",
    },
    {
        "school": "William Hart Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000615",
    },
    {
        "school": "Haynes Academy School for Advanced Studies",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000617",
    },
    {
        "school": "Hazel Park/Hilda Knoff School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000618",
    },
    {
        "school": "Phoebe Hearst School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000619",
    },
    {
        "school": "L.W. Higgins High School",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000620",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000622",
    },
    {
        "school": "Harold Keller Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000624",
    },
    {
        "school": "Grace King High School",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000625",
    },
    {
        "school": "Lincoln Elementary School for the Arts",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000629",
    },
    {
        "school": "Livaudais Middle School",
        "district": "Jefferson Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000630",
    },
    {
        "school": "L.H. Marrero Middle School",
        "district": "Jefferson Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000632",
    },
    {
        "school": "Rudolph Matas School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000634",
    },
    {
        "school": "McDonogh 26/Homedale Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000635",
    },
    {
        "school": "J.D. Meisler Middle School",
        "district": "Jefferson Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000636",
    },
    {
        "school": "Metairie Academy for Advanced Studies",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000637",
    },
    {
        "school": "Young Audiences Charter School",
        "district": "Jefferson Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000638",
    },
    {
        "school": "Vic A. Pitre Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000639",
    },
    {
        "school": "Ella C. Pittman Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000640",
    },
    {
        "school": "Riverdale High School",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000642",
    },
    {
        "school": "Marie B. Riviere Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000643",
    },
    {
        "school": "Theodore Roosevelt Middle School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000644",
    },
    {
        "school": "Walter Schneckenburger Elem School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000647",
    },
    {
        "school": "Terrytown Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000649",
    },
    {
        "school": "Washington Montessori",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000652",
    },
    {
        "school": "Kenner Discovery Health Sciences Academy",
        "district": "Jefferson Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000653",
    },
    {
        "school": "West Jefferson High School",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000654",
    },
    {
        "school": "Myrtle C. Thibodeaux Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000655",
    },
    {
        "school": "Woodland West Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000656",
    },
    {
        "school": "G.T. Woods Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000657",
    },
    {
        "school": "Stella Worley Middle School",
        "district": "Jefferson Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084000658",
    },
    {
        "school": "J.J. Audubon Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001512",
    },
    {
        "school": "Westbank Community School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001518",
    },
    {
        "school": "Joseph A. Cuillier Sr. Career Center",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Career and Technical School",
        "state": "LA",
        "nces_id": "220084001597",
    },
    {
        "school": "Paul J. Solis Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001680",
    },
    {
        "school": "Woodmere Elementary",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001681",
    },
    {
        "school": "Chateau Estates Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001704",
    },
    {
        "school": "Lucille Cherbonnier/Norbert Rillieux Elem. School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001812",
    },
    {
        "school": "Joshua Butler Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001813",
    },
    {
        "school": "Geraldine Boudreaux Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001881",
    },
    {
        "school": "Leo E. Kerner Jr. Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001882",
    },
    {
        "school": "Congetta Trippe Janet Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001883",
    },
    {
        "school": "Harry S. Truman Middle School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084001884",
    },
    {
        "school": "International School of Louisiana",
        "district": "International School of Louisiana",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003301485",
    },
    {
        "school": "New Orleans Center for Creative Arts",
        "district": "New Orleans Center for Creative Arts",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220003601499",
    },
    {
        "school": "Mary Bethune Elementary Literature/Technology",
        "district": "Orleans Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220117000856",
    },
    {
        "school": "Warren Easton Senior High School",
        "district": "Orleans Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220117000880",
    },
    {
        "school": "Edward Hynes Charter School",
        "district": "Orleans Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220117000907",
    },
    {
        "school": "McDonogh #35 College Preparatory School",
        "district": "Orleans Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220117000939",
    },
    {
        "school": "Youth Study Center",
        "district": "Orleans Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220117001522",
    },
    {
        "school": "Benjamin Franklin Elem. Math and Science",
        "district": "Orleans Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220117001938",
    },
    {
        "school": "Belle Chasse Elementary School",
        "district": "Plaquemines Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220123000366",
    },
    {
        "school": "Belle Chasse High School",
        "district": "Plaquemines Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220123001022",
    },
    {
        "school": "Belle Chasse Middle School",
        "district": "Plaquemines Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220123001023",
    },
    {
        "school": "Boothville-Venice Elementary School",
        "district": "Plaquemines Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220123001024",
    },
    {
        "school": "Phoenix High School",
        "district": "Plaquemines Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220123001026",
    },
    {
        "school": "C.F. Rowley Alternative School",
        "district": "St. Bernard Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141000816",
    },
    {
        "school": "Chalmette High School",
        "district": "St. Bernard Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141001125",
    },
    {
        "school": "J.F. Gauthier School",
        "district": "St. Bernard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141001127",
    },
    {
        "school": "Joseph J. Davies Elementary School",
        "district": "St. Bernard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141001131",
    },
    {
        "school": "N.P. Trist Middle School",
        "district": "St. Bernard Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141001136",
    },
    {
        "school": "W. Smith Jr. Elementary School",
        "district": "St. Bernard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141001533",
    },
    {
        "school": "Ethel Schoeffner Elementary School",
        "district": "St. Charles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144000243",
    },
    {
        "school": "Allemands Elementary School",
        "district": "St. Charles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001137",
    },
    {
        "school": "Destrehan High School",
        "district": "St. Charles Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001139",
    },
    {
        "school": "Hahnville High School",
        "district": "St. Charles Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001141",
    },
    {
        "school": "R.K. Smith Middle School",
        "district": "St. Charles Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001142",
    },
    {
        "school": "Luling Elementary School",
        "district": "St. Charles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001144",
    },
    {
        "school": "J.B. Martin Middle School",
        "district": "St. Charles Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001145",
    },
    {
        "school": "Mimosa Park Elementary School",
        "district": "St. Charles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001146",
    },
    {
        "school": "Norco Elementary School",
        "district": "St. Charles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001148",
    },
    {
        "school": "Albert Cammon Middle School",
        "district": "St. Charles Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001149",
    },
    {
        "school": "St. Rose Elementary School",
        "district": "St. Charles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001150",
    },
    {
        "school": "R.J. Vial Elementary School",
        "district": "St. Charles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001152",
    },
    {
        "school": "Harry M. Hurst Middle School",
        "district": "St. Charles Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001632",
    },
    {
        "school": "Lakewood Elementary School",
        "district": "St. Charles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001633",
    },
    {
        "school": "New Sarpy Elementary School",
        "district": "St. Charles Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220144001987",
    },
    {
        "school": "John L. Ory Communications Magnet Elementary",
        "district": "St. John the Baptist Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220153000427",
    },
    {
        "school": "Garyville/Mt. Airy Math & Science Magnet Schl.",
        "district": "St. John the Baptist Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220153000430",
    },
    {
        "school": "East St. John High School",
        "district": "St. John the Baptist Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220153001488",
    },
    {
        "school": "LaPlace Elementary School",
        "district": "St. John the Baptist Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220153001493",
    },
    {
        "school": "East St. John Preparatory Academy",
        "district": "St. John the Baptist Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220153001495",
    },
    {
        "school": "West St. John High School",
        "district": "St. John the Baptist Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220153001500",
    },
    {
        "school": "West St. John Elementary School (K-7)",
        "district": "St. John the Baptist Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220153001836",
    },
    {
        "school": "Fifth Ward Elementary School",
        "district": "St. John the Baptist Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220153002003",
    },
    {
        "school": "Lake Pontchartrain Elementary School",
        "district": "St. John the Baptist Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220153002004",
    },
    {
        "school": "Cypress Cove Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165000384",
    },
    {
        "school": "Fontainebleau High School",
        "district": "St. Tammany Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165000412",
    },
    {
        "school": "Fontainebleau Junior High School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165000589",
    },
    {
        "school": "Magnolia Trace Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001258",
    },
    {
        "school": "Abita Springs Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001263",
    },
    {
        "school": "W.L. Abney Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001264",
    },
    {
        "school": "Alton Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001265",
    },
    {
        "school": "Bayou Lacombe Middle School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001266",
    },
    {
        "school": "Bonne Ecole Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001267",
    },
    {
        "school": "Boyet Junior High School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001268",
    },
    {
        "school": "Glynn H. Brock Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001269",
    },
    {
        "school": "Carolyn Park Middle School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001271",
    },
    {
        "school": "Chahta-Ima Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001272",
    },
    {
        "school": "Covington Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001273",
    },
    {
        "school": "Covington High School",
        "district": "St. Tammany Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001274",
    },
    {
        "school": "Fifth Ward Junior High School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001277",
    },
    {
        "school": "Florida Avenue Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001278",
    },
    {
        "school": "Folsom Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001279",
    },
    {
        "school": "Folsom Junior High School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001280",
    },
    {
        "school": "Lee Road Junior High School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001281",
    },
    {
        "school": "E. E. Lyon Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001282",
    },
    {
        "school": "Madisonville Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001283",
    },
    {
        "school": "Mandeville Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001284",
    },
    {
        "school": "Mandeville High School",
        "district": "St. Tammany Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001285",
    },
    {
        "school": "Mandeville Middle School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001286",
    },
    {
        "school": "Pearl River High School",
        "district": "St. Tammany Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001287",
    },
    {
        "school": "Pine View Middle School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001289",
    },
    {
        "school": "William Pitcher Junior High School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001290",
    },
    {
        "school": "Salmen High School",
        "district": "St. Tammany Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001292",
    },
    {
        "school": "Sixth Ward Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001293",
    },
    {
        "school": "Slidell High School",
        "district": "St. Tammany Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001294",
    },
    {
        "school": "Slidell Junior High School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001295",
    },
    {
        "school": "Lake Harbor Middle School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001535",
    },
    {
        "school": "Abita Springs Middle School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001565",
    },
    {
        "school": "Clearwood Junior High School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001566",
    },
    {
        "school": "Mandeville Junior High School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001567",
    },
    {
        "school": "Little Oak Middle School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001648",
    },
    {
        "school": "Madisonville Junior High School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001649",
    },
    {
        "school": "Northshore High School",
        "district": "St. Tammany Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001650",
    },
    {
        "school": "St. Tammany Junior High School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001651",
    },
    {
        "school": "Bayou Woods Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001716",
    },
    {
        "school": "Riverside Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001897",
    },
    {
        "school": "Woodlake Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001898",
    },
    {
        "school": "Honey Island Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001949",
    },
    {
        "school": "Whispering Forest Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165001950",
    },
    {
        "school": "Magnet Academy for Cultural Arts",
        "district": "St. Landry Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001685",
    },
    {
        "school": "Arnaudville Elementary School",
        "district": "St. Landry Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156000191",
    },
    {
        "school": "Cankton Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001174",
    },
    {
        "school": "Central Middle School",
        "district": "St. Landry Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001175",
    },
    {
        "school": "East Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001178",
    },
    {
        "school": "Eunice Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001180",
    },
    {
        "school": "Eunice High School",
        "district": "St. Landry Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001181",
    },
    {
        "school": "Eunice Junior High School",
        "district": "St. Landry Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001182",
    },
    {
        "school": "Glendale Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001183",
    },
    {
        "school": "Grand Coteau Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001184",
    },
    {
        "school": "Grand Prairie Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001185",
    },
    {
        "school": "Grolee Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001186",
    },
    {
        "school": "Highland Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001188",
    },
    {
        "school": "Krotz Springs Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001189",
    },
    {
        "school": "Lawtell Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001190",
    },
    {
        "school": "Leonville Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001192",
    },
    {
        "school": "Northeast Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001200",
    },
    {
        "school": "Opelousas Junior High School",
        "district": "St. Landry Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001203",
    },
    {
        "school": "Opelousas Senior High School",
        "district": "St. Landry Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001204",
    },
    {
        "school": "Palmetto Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001205",
    },
    {
        "school": "Park Vista Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001206",
    },
    {
        "school": "Port Barre Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001209",
    },
    {
        "school": "Port Barre High School",
        "district": "St. Landry Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001210",
    },
    {
        "school": "Sunset Elementary School",
        "district": "St. Landry Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001213",
    },
    {
        "school": "Washington Elementary School",
        "district": "St. Landry Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001215",
    },
    {
        "school": "Port Barre Middle School",
        "district": "St. Landry Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001475",
    },
    {
        "school": "Eunice Career & Technical Education Center",
        "district": "St. Landry Parish",
        "level": "High",
        "type": "Career and Technical School",
        "state": "LA",
        "nces_id": "220156001636",
    },
    {
        "school": "Washington Career & Technical Education Center",
        "district": "St. Landry Parish",
        "level": "High",
        "type": "Career and Technical School",
        "state": "LA",
        "nces_id": "220156001642",
    },
    {
        "school": "South Street Elementary School",
        "district": "St. Landry Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001896",
    },
    {
        "school": "North Central High School",
        "district": "St. Landry Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156001989",
    },
    {
        "school": "Beau Chene High School",
        "district": "St. Landry Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156002005",
    },
    {
        "school": "Northwest High School",
        "district": "St. Landry Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156002006",
    },
    {
        "school": "Plaisance Elementary School",
        "district": "St. Landry Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220156002007",
    },
    {
        "school": "Assumption High School",
        "district": "Assumption Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012000048",
    },
    {
        "school": "Belle Rose Middle School",
        "district": "Assumption Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012000050",
    },
    {
        "school": "Belle Rose Primary School",
        "district": "Assumption Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012000051",
    },
    {
        "school": "Labadieville Middle School",
        "district": "Assumption Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012000052",
    },
    {
        "school": "Labadieville Primary School",
        "district": "Assumption Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012000053",
    },
    {
        "school": "Napoleonville Middle School",
        "district": "Assumption Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012000054",
    },
    {
        "school": "Napoleonville Primary School",
        "district": "Assumption Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012000055",
    },
    {
        "school": "Pierre Part Elementary School",
        "district": "Assumption Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012000056",
    },
    {
        "school": "Bayou L'Ourse Primary School",
        "district": "Assumption Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012001696",
    },
    {
        "school": "Jonesboro-Hodge High School",
        "district": "Jackson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220078000555",
    },
    {
        "school": "Quitman High School",
        "district": "Jackson Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220078000556",
    },
    {
        "school": "Jonesboro-Hodge Middle School",
        "district": "Jackson Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220078000557",
    },
    {
        "school": "Jonesboro-Hodge Elementary School",
        "district": "Jackson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220078000558",
    },
    {
        "school": "Weston High School",
        "district": "Jackson Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220078000560",
    },
    {
        "school": "Choudrant High School",
        "district": "Lincoln Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099000742",
    },
    {
        "school": "Cypress Springs Elementary School",
        "district": "Lincoln Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099000743",
    },
    {
        "school": "Dubach School",
        "district": "Lincoln Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099000744",
    },
    {
        "school": "Glen View Elementary School",
        "district": "Lincoln Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099000745",
    },
    {
        "school": "Hillcrest Elementary School",
        "district": "Lincoln Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099000747",
    },
    {
        "school": "I.A. Lewis School",
        "district": "Lincoln Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099000748",
    },
    {
        "school": "Ruston Elementary School",
        "district": "Lincoln Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099000751",
    },
    {
        "school": "Ruston High School",
        "district": "Lincoln Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099000752",
    },
    {
        "school": "Simsboro High School",
        "district": "Lincoln Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099000753",
    },
    {
        "school": "Ruston Junior High School",
        "district": "Lincoln Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099001815",
    },
    {
        "school": "Choudrant Elementary School",
        "district": "Lincoln Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099001983",
    },
    {
        "school": "North DeSoto Middle School 6-8",
        "district": "DeSoto Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220051000275",
    },
    {
        "school": "Logansport High School",
        "district": "DeSoto Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220051000331",
    },
    {
        "school": "Mansfield High School",
        "district": "DeSoto Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220051000334",
    },
    {
        "school": "Stanley High School",
        "district": "DeSoto Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220051000337",
    },
    {
        "school": "Mansfield Elementary School",
        "district": "DeSoto Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220051000623",
    },
    {
        "school": "Mansfield Middle School",
        "district": "DeSoto Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220051000626",
    },
    {
        "school": "North DeSoto High School",
        "district": "DeSoto Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220051001579",
    },
    {
        "school": "North DeSoto Lower Elementary School",
        "district": "DeSoto Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220051001919",
    },
    {
        "school": "Airline High School",
        "district": "Bossier Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000112",
    },
    {
        "school": "Apollo Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000113",
    },
    {
        "school": "Bellaire Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000114",
    },
    {
        "school": "Benton Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000116",
    },
    {
        "school": "Benton High School",
        "district": "Bossier Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000117",
    },
    {
        "school": "Bossier Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000118",
    },
    {
        "school": "Bossier High School",
        "district": "Bossier Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000120",
    },
    {
        "school": "Central Park Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000123",
    },
    {
        "school": "Curtis Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000124",
    },
    {
        "school": "Elm Grove Middle School",
        "district": "Bossier Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000125",
    },
    {
        "school": "Greenacres Middle School",
        "district": "Bossier Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000126",
    },
    {
        "school": "Haughton High School",
        "district": "Bossier Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000127",
    },
    {
        "school": "R. V. Kerr Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000128",
    },
    {
        "school": "Meadowview Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000129",
    },
    {
        "school": "Parkway High School",
        "district": "Bossier Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000130",
    },
    {
        "school": "Plain Dealing High School",
        "district": "Bossier Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000132",
    },
    {
        "school": "Plantation Park Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000133",
    },
    {
        "school": "Platt Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000134",
    },
    {
        "school": "Haughton Middle School",
        "district": "Bossier Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000135",
    },
    {
        "school": "Rusheon Middle School",
        "district": "Bossier Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000137",
    },
    {
        "school": "Sun City Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000138",
    },
    {
        "school": "Waller Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000139",
    },
    {
        "school": "Johnny Gray Jones Youth Shelter & Detention Center",
        "district": "Bossier Parish",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "LA",
        "nces_id": "220027000218",
    },
    {
        "school": "Benton Middle School",
        "district": "Bossier Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027000842",
    },
    {
        "school": "Princeton Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027001079",
    },
    {
        "school": "Cope Middle School",
        "district": "Bossier Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027001573",
    },
    {
        "school": "T.L. Rodes Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027001574",
    },
    {
        "school": "Stockwell Place Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027001870",
    },
    {
        "school": "Bossier PS for Technology & Innovative Learning",
        "district": "Bossier Parish",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "LA",
        "nces_id": "220027001057",
    },
    {
        "school": "Arthur Circle Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000141",
    },
    {
        "school": "Atkins Technology Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000142",
    },
    {
        "school": "Blanchard Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000145",
    },
    {
        "school": "Broadmoor Middle Laboratory School",
        "district": "Caddo Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000146",
    },
    {
        "school": "C.E. Byrd High School",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000147",
    },
    {
        "school": "Caddo Heights Math/Science Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000150",
    },
    {
        "school": "Captain Shreve High School",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000151",
    },
    {
        "school": "Cherokee Park Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000153",
    },
    {
        "school": "Claiborne Fundamental Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000154",
    },
    {
        "school": "Creswell Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000156",
    },
    {
        "school": "Eden Gardens Fundamental Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000157",
    },
    {
        "school": "Caddo Parish Middle Magnet School",
        "district": "Caddo Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000158",
    },
    {
        "school": "Eighty-First Street ECE Center",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000159",
    },
    {
        "school": "Fairfield Magnet School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000160",
    },
    {
        "school": "Forest Hill Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000162",
    },
    {
        "school": "Green Oaks Performing Arts Academy",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000163",
    },
    {
        "school": "Herndon Magnet School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000165",
    },
    {
        "school": "Caddo Middle Career and Technology School",
        "district": "Caddo Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000167",
    },
    {
        "school": "Huntington High School",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000169",
    },
    {
        "school": "Judson Fundamental Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000171",
    },
    {
        "school": "Mooretown Elementary Professional Develop. Ctr.",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000177",
    },
    {
        "school": "Mooringsport Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000178",
    },
    {
        "school": "North Caddo High School",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000179",
    },
    {
        "school": "North Highlands Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000180",
    },
    {
        "school": "Northside Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000181",
    },
    {
        "school": "Northwood High School",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000182",
    },
    {
        "school": "Oak Park Microsociety Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000183",
    },
    {
        "school": "Pine Grove Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000187",
    },
    {
        "school": "Queensborough Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000188",
    },
    {
        "school": "Ridgewood Middle School",
        "district": "Caddo Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000189",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000190",
    },
    {
        "school": "South Highlands Elementary Magnet School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000195",
    },
    {
        "school": "Southern Hills Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000196",
    },
    {
        "school": "Southwood High School",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000197",
    },
    {
        "school": "A.C. Steere Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000198",
    },
    {
        "school": "E.B. Williams Stoner Hill Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000199",
    },
    {
        "school": "Summerfield Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000200",
    },
    {
        "school": "Summer Grove Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000201",
    },
    {
        "school": "Sunset Acres Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000202",
    },
    {
        "school": "Jack P. Timmons Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000203",
    },
    {
        "school": "University Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000204",
    },
    {
        "school": "Walnut Hill Elementary/Middle School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000207",
    },
    {
        "school": "Booker T. Washington New Technology High School",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000208",
    },
    {
        "school": "Werner Park Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000209",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000211",
    },
    {
        "school": "Woodlawn Leadership Academy",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000212",
    },
    {
        "school": "Youree Dr. Middle Advanced Placement Magnet School",
        "district": "Caddo Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030000213",
    },
    {
        "school": "Caddo Career & Technical Center",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Career and Technical School",
        "state": "LA",
        "nces_id": "220030001088",
    },
    {
        "school": "Midway Professional Development Center",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030001510",
    },
    {
        "school": "Caddo Parish Magnet High School",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030001551",
    },
    {
        "school": "Shreve Island Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030001578",
    },
    {
        "school": "Turner Elementary Middle School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030001676",
    },
    {
        "school": "Donnie Bickham Middle School",
        "district": "Caddo Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030001917",
    },
    {
        "school": "Keithville Elementary/Middle School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030001918",
    },
    {
        "school": "Madison Middle School",
        "district": "Madison Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220105000779",
    },
    {
        "school": "Madison High School",
        "district": "Madison Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220105000780",
    },
    {
        "school": "Tallulah Elementary School",
        "district": "Madison Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220105000781",
    },
    {
        "school": "Wright Elementary School",
        "district": "Madison Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220105000785",
    },
    {
        "school": "The Academy of Early Learning at North Parish",
        "district": "Greenfield",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250549002128",
    },
    {
        "school": "Martin Luther King Jr. Charter School of Excellence",
        "district": "Martin Luther King Jr. Charter School of Excellence (Distric",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250008902127",
    },
    {
        "school": "The Springfield Renaissance School an Expeditionary Learning",
        "district": "Springfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002137",
    },
    {
        "school": "Webster School",
        "district": "Everett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250477002118",
    },
    {
        "school": "Westwood Integrated Preschool",
        "district": "Westwood",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251281002115",
    },
    {
        "school": "Wareham Cooperative Alternative School",
        "district": "Wareham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251206002105",
    },
    {
        "school": "Phoenix Charter Academy",
        "district": "Phoenix Charter Academy (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250009002112",
    },
    {
        "school": "Susan B. Anthony Middle School",
        "district": "Revere",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251005002113",
    },
    {
        "school": "Goodrich Academy",
        "district": "Fitchburg",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250489002110",
    },
    {
        "school": "Glenwood Elementary School",
        "district": "Wachusett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188002131",
    },
    {
        "school": "Woodland Academy",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002106",
    },
    {
        "school": "Claremont Academy",
        "district": "Worcester",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002121",
    },
    {
        "school": "Nantucket Elementary",
        "district": "Nantucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250825001278",
    },
    {
        "school": "Cyrus Peirce",
        "district": "Nantucket",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250825001281",
    },
    {
        "school": "Nantucket High",
        "district": "Nantucket",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250825001282",
    },
    {
        "school": "Christa McAuliffe Charter Public School",
        "district": "Christa McAuliffe Charter Public (District)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250006801746",
    },
    {
        "school": "Fuller Middle",
        "district": "Framingham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498000464",
    },
    {
        "school": "Brophy",
        "district": "Framingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498000714",
    },
    {
        "school": "Charlotte A Dunning",
        "district": "Framingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498000716",
    },
    {
        "school": "Hemenway",
        "district": "Framingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498000721",
    },
    {
        "school": "Mary E Stapleton Elementary",
        "district": "Framingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498000726",
    },
    {
        "school": "Barbieri Elementary",
        "district": "Framingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498000727",
    },
    {
        "school": "Miriam F McCarthy School",
        "district": "Framingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498000728",
    },
    {
        "school": "Potter Road",
        "district": "Framingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498000731",
    },
    {
        "school": "Walsh Middle",
        "district": "Framingham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498000733",
    },
    {
        "school": "Woodrow Wilson",
        "district": "Framingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498000734",
    },
    {
        "school": "Cameron Middle School",
        "district": "Framingham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498001530",
    },
    {
        "school": "Framingham High School",
        "district": "Framingham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498002573",
    },
    {
        "school": "Joseph P Keefe Technical High School",
        "district": "South Middlesex Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251106002291",
    },
    {
        "school": "Beechwood Knoll Elementary",
        "district": "Quincy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987000772",
    },
    {
        "school": "Clifford H Marshall Elementary",
        "district": "Quincy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001220",
    },
    {
        "school": "Point Webster Middle",
        "district": "Quincy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001381",
    },
    {
        "school": "Atherton Hough",
        "district": "Quincy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001560",
    },
    {
        "school": "Atlantic Middle",
        "district": "Quincy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001561",
    },
    {
        "school": "Broad Meadows Middle",
        "district": "Quincy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001563",
    },
    {
        "school": "Central Middle",
        "district": "Quincy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001564",
    },
    {
        "school": "Francis W Parker",
        "district": "Quincy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001567",
    },
    {
        "school": "Charles A Bernazzani Elementary",
        "district": "Quincy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001568",
    },
    {
        "school": "Lincoln-Hancock Community School",
        "district": "Quincy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001571",
    },
    {
        "school": "Merrymount",
        "district": "Quincy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001573",
    },
    {
        "school": "Montclair",
        "district": "Quincy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001574",
    },
    {
        "school": "North Quincy High",
        "district": "Quincy",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001577",
    },
    {
        "school": "Quincy High",
        "district": "Quincy",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001579",
    },
    {
        "school": "South West Middle School",
        "district": "Quincy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001581",
    },
    {
        "school": "Snug Harbor Community School",
        "district": "Quincy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001582",
    },
    {
        "school": "Squantum",
        "district": "Quincy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987001583",
    },
    {
        "school": "Wollaston School",
        "district": "Quincy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987002492",
    },
    {
        "school": "Crocker Farm Elementary",
        "district": "Amherst",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250189000038",
    },
    {
        "school": "Fort River Elementary",
        "district": "Amherst",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250189000039",
    },
    {
        "school": "Wildwood Elementary",
        "district": "Amherst",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250189000041",
    },
    {
        "school": "Amherst Regional High",
        "district": "Amherst-Pelham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250192000042",
    },
    {
        "school": "Amherst Regional Middle School",
        "district": "Amherst-Pelham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250192000043",
    },
    {
        "school": "Athol High",
        "district": "Athol-Royalston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250216000074",
    },
    {
        "school": "Athol Community Elementary School",
        "district": "Athol-Royalston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250216000080",
    },
    {
        "school": "Athol-Royalston Middle School",
        "district": "Athol-Royalston",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250216000176",
    },
    {
        "school": "Royalston Community School",
        "district": "Athol-Royalston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250216000931",
    },
    {
        "school": "Cape Cod Lighthouse Charter School",
        "district": "Cape Cod Lighthouse Charter (District)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250002400516",
    },
    {
        "school": "Sturgis Charter Public School",
        "district": "Sturgis Charter Public (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250005801272",
    },
    {
        "school": "Barnstable High",
        "district": "Barnstable",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250231000116",
    },
    {
        "school": "Centerville Elementary",
        "district": "Barnstable",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250231000118",
    },
    {
        "school": "Hyannis West Elementary",
        "district": "Barnstable",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250231000121",
    },
    {
        "school": "West Barnstable Elementary",
        "district": "Barnstable",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250231000125",
    },
    {
        "school": "Bourne High School",
        "district": "Bourne",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250282000348",
    },
    {
        "school": "Bourne Middle School",
        "district": "Bourne",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250282001517",
    },
    {
        "school": "Stony Brook Elementary",
        "district": "Brewster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250297000374",
    },
    {
        "school": "Eddy Elementary",
        "district": "Brewster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250297000841",
    },
    {
        "school": "Cape Cod Region Vocational Technical",
        "district": "Cape Cod Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250331002264",
    },
    {
        "school": "Dennis-Yarmouth Regional High",
        "district": "Dennis-Yarmouth",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250414000558",
    },
    {
        "school": "Ezra H Baker Innovation School",
        "district": "Dennis-Yarmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250414000559",
    },
    {
        "school": "Marguerite E Small Elementary",
        "district": "Dennis-Yarmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250414000561",
    },
    {
        "school": "Mattacheese Middle School",
        "district": "Dennis-Yarmouth",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250414000562",
    },
    {
        "school": "Station Avenue Elementary",
        "district": "Dennis-Yarmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250414000834",
    },
    {
        "school": "Eastham Elementary",
        "district": "Eastham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250453000607",
    },
    {
        "school": "Nauset Regional Middle",
        "district": "Nauset",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250456000609",
    },
    {
        "school": "Nauset Regional High",
        "district": "Nauset",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250456000610",
    },
    {
        "school": "East Falmouth Elementary",
        "district": "Falmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250486000685",
    },
    {
        "school": "Falmouth High",
        "district": "Falmouth",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250486000686",
    },
    {
        "school": "Lawrence",
        "district": "Falmouth",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250486000687",
    },
    {
        "school": "Morse Pond School",
        "district": "Falmouth",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250486000688",
    },
    {
        "school": "Mullen-Hall",
        "district": "Falmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250486000689",
    },
    {
        "school": "North Falmouth Elementary",
        "district": "Falmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250486000690",
    },
    {
        "school": "Teaticket",
        "district": "Falmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250486000691",
    },
    {
        "school": "Mashpee High",
        "district": "Mashpee",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250744000886",
    },
    {
        "school": "Quashnet School",
        "district": "Mashpee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250744001546",
    },
    {
        "school": "Kenneth Coombs School",
        "district": "Mashpee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250744002528",
    },
    {
        "school": "Orleans Elementary",
        "district": "Orleans",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250921001477",
    },
    {
        "school": "Sandwich High",
        "district": "Sandwich",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251047001673",
    },
    {
        "school": "Oak Ridge",
        "district": "Sandwich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251047002535",
    },
    {
        "school": "Truro Central",
        "district": "Truro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251173001930",
    },
    {
        "school": "Upper Cape Cod Vocational Technical",
        "district": "Upper Cape Cod Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251180002296",
    },
    {
        "school": "Wellfleet Elementary",
        "district": "Wellfleet",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251230002031",
    },
    {
        "school": "John William Decas",
        "district": "Wareham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251206001988",
    },
    {
        "school": "Minot Forest",
        "district": "Wareham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251206001989",
    },
    {
        "school": "Wareham Senior High",
        "district": "Wareham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251206001991",
    },
    {
        "school": "Wareham Middle",
        "district": "Wareham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251206002603",
    },
    {
        "school": "Laliberte Elementary School",
        "district": "Bridgewater-Raynham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250303001755",
    },
    {
        "school": "Merrill Elementary School",
        "district": "Bridgewater-Raynham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250303002102",
    },
    {
        "school": "KIPP Academy Lynn Charter School",
        "district": "KIPP Academy Lynn Charter (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250008201845",
    },
    {
        "school": "Hill View Montessori Charter Public School",
        "district": "Hill View Montessori Charter Public (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250008301846",
    },
    {
        "school": "Salem Academy Charter School",
        "district": "Salem Academy Charter (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250008401847",
    },
    {
        "school": "High Plain Elementary",
        "district": "Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250195001676",
    },
    {
        "school": "Wood Hill Middle School",
        "district": "Andover",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250195001678",
    },
    {
        "school": "Greenleaf Academy",
        "district": "Haverhill",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597001698",
    },
    {
        "school": "TEACH",
        "district": "Haverhill",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597001706",
    },
    {
        "school": "South Lawrence East Elementary School",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666001918",
    },
    {
        "school": "Arlington Middle School",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666001945",
    },
    {
        "school": "Village School",
        "district": "Marblehead",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250726001788",
    },
    {
        "school": "Marblehead Veterans Middle School",
        "district": "Marblehead",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250726001789",
    },
    {
        "school": "John E. McCarthy",
        "district": "Peabody",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250936001821",
    },
    {
        "school": "Advanced Math and Science Academy Charter School",
        "district": "Advanced Math and Science Academy Charter (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250008501984",
    },
    {
        "school": "Community Charter School of Cambridge",
        "district": "Community Charter School of Cambridge (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250008601996",
    },
    {
        "school": "Menotomy Preschool",
        "district": "Arlington",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250198001681",
    },
    {
        "school": "Madeline English School",
        "district": "Everett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250477002033",
    },
    {
        "school": "George Keverian School",
        "district": "Everett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250477002038",
    },
    {
        "school": "Hopkinton Pre-School",
        "district": "Hopkinton",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250633002043",
    },
    {
        "school": "Bartlett Community Partnership",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001954",
    },
    {
        "school": "Kathryn P. Stoklosa Middle School",
        "district": "Lowell",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001955",
    },
    {
        "school": "Malden Early Learning Center",
        "district": "Malden",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250717002046",
    },
    {
        "school": "Brooks School",
        "district": "Medford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250756002049",
    },
    {
        "school": "Christopher Columbus",
        "district": "Medford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250756002057",
    },
    {
        "school": "Milton Fuller Roberts",
        "district": "Medford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250756002062",
    },
    {
        "school": "John J. McGlynn Middle School",
        "district": "Medford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250756002063",
    },
    {
        "school": "Early Childhood Center",
        "district": "Melrose",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250762001800",
    },
    {
        "school": "Nissitissit Middle School",
        "district": "North Middlesex",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250879001762",
    },
    {
        "school": "Wood End Elementary School",
        "district": "Reading",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250999001958",
    },
    {
        "school": "Tyngsborough Elementary",
        "district": "Tyngsborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251176001714",
    },
    {
        "school": "Tyngsborough Middle",
        "district": "Tyngsborough",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251176001715",
    },
    {
        "school": "John A. Crisafulli Elementary School",
        "district": "Westford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251266001737",
    },
    {
        "school": "Rita E. Miller Elementary School",
        "district": "Westford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251266001740",
    },
    {
        "school": "Stony Brook School",
        "district": "Westford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251266002080",
    },
    {
        "school": "The Lynch Center",
        "district": "Brookline",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315002027",
    },
    {
        "school": "Helen Keller Elementary",
        "district": "Franklin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250501001694",
    },
    {
        "school": "Annie Sullivan Middle School",
        "district": "Franklin",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250501001785",
    },
    {
        "school": "Sprague Elementary School",
        "district": "Wellesley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251227001733",
    },
    {
        "school": "Maria Weston Chapman Middle School",
        "district": "Weymouth",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284001840",
    },
    {
        "school": "George R Austin Intermediate School",
        "district": "Freetown-Lakeville",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250507001852",
    },
    {
        "school": "Pembroke Community Middle School",
        "district": "Pembroke",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250942001823",
    },
    {
        "school": "Pembroke High School",
        "district": "Pembroke",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250942001824",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Rockland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251017001708",
    },
    {
        "school": "Jenkins Elementary School",
        "district": "Scituate",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251056002068",
    },
    {
        "school": "Brooke Charter School",
        "district": "Brooke Charter School (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250007101747",
    },
    {
        "school": "Excel Academy Charter School",
        "district": "Excel Academy Charter (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250007502084",
    },
    {
        "school": "Helen Y. Davis Leadership Academy Charter Public School",
        "district": "Helen Y. Davis Leadership Academy Charter Public (District)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250007702091",
    },
    {
        "school": "Boston Preparatory Charter Public School",
        "district": "Boston Preparatory Charter Public (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250008001843",
    },
    {
        "school": "Boston Community Leadership Academy",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279001692",
    },
    {
        "school": "Lee Academy",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279001768",
    },
    {
        "school": "Urban Science Academy",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279001898",
    },
    {
        "school": "Community Academy of Science and Health",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279001902",
    },
    {
        "school": "Orchard Gardens",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002006",
    },
    {
        "school": "Lilla G. Frederick Middle School",
        "district": "Boston",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002013",
    },
    {
        "school": "Boston International High School",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002015",
    },
    {
        "school": "Excel High School",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002016",
    },
    {
        "school": "Eugene Wright Science and Technology Academy",
        "district": "Chelsea",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250354001772",
    },
    {
        "school": "Joseph A. Browne School",
        "district": "Chelsea",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250354001776",
    },
    {
        "school": "Beachmont Veterans Memorial School",
        "district": "Revere",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251005001962",
    },
    {
        "school": "Rumney Marsh Academy",
        "district": "Revere",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251005001963",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Revere",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251005001975",
    },
    {
        "school": "Garfield Middle School",
        "district": "Revere",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251005001976",
    },
    {
        "school": "Arthur T. Cummings Elementary School",
        "district": "Winthrop",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251317001841",
    },
    {
        "school": "Berkley Middle School",
        "district": "Berkley",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250252001613",
    },
    {
        "school": "Berkley Community School",
        "district": "Berkley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250252002513",
    },
    {
        "school": "Bristol County Agricultural High",
        "district": "Bristol County Agricultural",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250307000382",
    },
    {
        "school": "Bristol-Plymouth Vocational Technical",
        "district": "Bristol-Plymouth Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250308002262",
    },
    {
        "school": "Dighton Middle School",
        "district": "Dighton-Rehoboth",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250420000400",
    },
    {
        "school": "Dighton-Rehoboth Regional High School",
        "district": "Dighton-Rehoboth",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250420000568",
    },
    {
        "school": "Dighton Elementary",
        "district": "Dighton-Rehoboth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250420002427",
    },
    {
        "school": "Palmer River",
        "district": "Dighton-Rehoboth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250420002428",
    },
    {
        "school": "Dorothy L Beckwith",
        "district": "Dighton-Rehoboth",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250420002430",
    },
    {
        "school": "Roland Green School",
        "district": "Mansfield",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250723001004",
    },
    {
        "school": "Everett W Robinson",
        "district": "Mansfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250723001111",
    },
    {
        "school": "Harold L Qualters Middle",
        "district": "Mansfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250723001112",
    },
    {
        "school": "Mansfield High",
        "district": "Mansfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250723001114",
    },
    {
        "school": "Jordan/Jackson Elementary",
        "district": "Mansfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250723001365",
    },
    {
        "school": "Henri A. Yelle",
        "district": "Norton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250900001209",
    },
    {
        "school": "J C Solmonese",
        "district": "Norton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250900001449",
    },
    {
        "school": "L G Nourse Elementary",
        "district": "Norton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250900001450",
    },
    {
        "school": "Norton High",
        "district": "Norton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250900001451",
    },
    {
        "school": "Norton Middle",
        "district": "Norton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250900001452",
    },
    {
        "school": "Southeast Area",
        "district": "Institutional Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MA",
        "nces_id": "251115000377",
    },
    {
        "school": "Edward F. Leddy Preschool",
        "district": "Taunton",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152000133",
    },
    {
        "school": "East Taunton Elementary",
        "district": "Taunton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152001065",
    },
    {
        "school": "Joseph C Chamberlain",
        "district": "Taunton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152001565",
    },
    {
        "school": "Benjamin Friedman Middle",
        "district": "Taunton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152001662",
    },
    {
        "school": "Edmund Hatch Bennett",
        "district": "Taunton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152001905",
    },
    {
        "school": "Elizabeth Pole",
        "district": "Taunton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152001907",
    },
    {
        "school": "H H Galligan",
        "district": "Taunton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152001908",
    },
    {
        "school": "Hopewell",
        "district": "Taunton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152001909",
    },
    {
        "school": "Joseph H Martin",
        "district": "Taunton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152001911",
    },
    {
        "school": "Taunton High",
        "district": "Taunton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152001915",
    },
    {
        "school": "John F Parker Middle",
        "district": "Taunton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152002416",
    },
    {
        "school": "Marblehead Community Charter Public School",
        "district": "Marblehead Community Charter Public (District)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250003400567",
    },
    {
        "school": "River Valley Charter School",
        "district": "River Valley Charter (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250006201446",
    },
    {
        "school": "Essex Elementary",
        "district": "Manchester Essex Regional",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250006700627",
    },
    {
        "school": "Manchester Essex Regional High School",
        "district": "Manchester Essex Regional",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250006701109",
    },
    {
        "school": "Manchester Memorial Elementary",
        "district": "Manchester Essex Regional",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250006701110",
    },
    {
        "school": "Amesbury Elementary",
        "district": "Amesbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250186000033",
    },
    {
        "school": "Amesbury High",
        "district": "Amesbury",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250186000034",
    },
    {
        "school": "Amesbury Middle",
        "district": "Amesbury",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250186000035",
    },
    {
        "school": "Charles C Cashman Elementary",
        "district": "Amesbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250186000036",
    },
    {
        "school": "Beverly High",
        "district": "Beverly",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250264000164",
    },
    {
        "school": "Beverly Middle School",
        "district": "Beverly",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250264000165",
    },
    {
        "school": "Centerville Elementary",
        "district": "Beverly",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250264000167",
    },
    {
        "school": "Cove Elementary",
        "district": "Beverly",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250264000168",
    },
    {
        "school": "Hannah Elementary",
        "district": "Beverly",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250264000169",
    },
    {
        "school": "North Beverly Elementary",
        "district": "Beverly",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250264000173",
    },
    {
        "school": "Ayers/Ryal Side School",
        "district": "Beverly",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250264000175",
    },
    {
        "school": "Harry Lee Cole",
        "district": "Boxford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250288000357",
    },
    {
        "school": "Spofford Pond",
        "district": "Boxford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250288000358",
    },
    {
        "school": "Danvers High",
        "district": "Danvers",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250399000529",
    },
    {
        "school": "Great Oak",
        "district": "Danvers",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250399000531",
    },
    {
        "school": "Highlands",
        "district": "Danvers",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250399000532",
    },
    {
        "school": "Ivan G Smith",
        "district": "Danvers",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250399000534",
    },
    {
        "school": "Riverside",
        "district": "Danvers",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250399000536",
    },
    {
        "school": "Willis E Thorpe",
        "district": "Danvers",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250399000538",
    },
    {
        "school": "Holten Richmond Middle School",
        "district": "Danvers",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250399002517",
    },
    {
        "school": "Beeman Memorial",
        "district": "Gloucester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250528000770",
    },
    {
        "school": "East Gloucester Elementary",
        "district": "Gloucester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250528000771",
    },
    {
        "school": "Gloucester High",
        "district": "Gloucester",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250528000774",
    },
    {
        "school": "Ralph B O'Maley Middle",
        "district": "Gloucester",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250528000779",
    },
    {
        "school": "Veterans Memorial",
        "district": "Gloucester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250528000780",
    },
    {
        "school": "West Parish",
        "district": "Gloucester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250528000781",
    },
    {
        "school": "Plum Cove School",
        "district": "Gloucester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250528000877",
    },
    {
        "school": "Gloucester PreSchool",
        "district": "Gloucester",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250528002574",
    },
    {
        "school": "Cutler School",
        "district": "Hamilton-Wenham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250567000818",
    },
    {
        "school": "Hamilton-Wenham Regional High",
        "district": "Hamilton-Wenham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250567000820",
    },
    {
        "school": "Winthrop School",
        "district": "Hamilton-Wenham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250567000821",
    },
    {
        "school": "Miles River Middle",
        "district": "Hamilton-Wenham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250567001276",
    },
    {
        "school": "Bessie Buker Elementary",
        "district": "Hamilton-Wenham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250567001459",
    },
    {
        "school": "Ipswich High",
        "district": "Ipswich",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250648000935",
    },
    {
        "school": "Paul F Doyon Memorial",
        "district": "Ipswich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250648000936",
    },
    {
        "school": "Ipswich Middle School",
        "district": "Ipswich",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250648000937",
    },
    {
        "school": "Winthrop",
        "district": "Ipswich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250648000939",
    },
    {
        "school": "Thurgood Marshall Mid",
        "district": "Lynn",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711000301",
    },
    {
        "school": "Aborn",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001061",
    },
    {
        "school": "A Drewicz Elementary",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001062",
    },
    {
        "school": "Breed Middle School",
        "district": "Lynn",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001063",
    },
    {
        "school": "Brickett Elementary",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001064",
    },
    {
        "school": "Capt William G Shoemaker",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001066",
    },
    {
        "school": "Classical High",
        "district": "Lynn",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001067",
    },
    {
        "school": "Cobbet Elementary",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001068",
    },
    {
        "school": "E J Harrington",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001070",
    },
    {
        "school": "Edward A Sisson",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001072",
    },
    {
        "school": "Robert L Ford",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001073",
    },
    {
        "school": "Hood",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001074",
    },
    {
        "school": "Ingalls",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001075",
    },
    {
        "school": "Julia F Callahan",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001077",
    },
    {
        "school": "Lincoln-Thomson",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001079",
    },
    {
        "school": "Lynn English High",
        "district": "Lynn",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001080",
    },
    {
        "school": "Lynn Woods",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001081",
    },
    {
        "school": "Pickering Middle",
        "district": "Lynn",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001083",
    },
    {
        "school": "Sewell-Anderson",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001084",
    },
    {
        "school": "Tracy",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001085",
    },
    {
        "school": "Wm P Connery",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711001087",
    },
    {
        "school": "Lynn Vocational Technical Institute",
        "district": "Lynn",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250711002277",
    },
    {
        "school": "William R Fallon",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711002527",
    },
    {
        "school": "Huckleberry Hill",
        "district": "Lynnfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250714001089",
    },
    {
        "school": "Lynnfield High",
        "district": "Lynnfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250714001090",
    },
    {
        "school": "Lynnfield Middle School",
        "district": "Lynnfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250714001091",
    },
    {
        "school": "Summer Street",
        "district": "Lynnfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250714001093",
    },
    {
        "school": "Dr. Samuel C. Eveleth",
        "district": "Marblehead",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250726001119",
    },
    {
        "school": "Glover",
        "district": "Marblehead",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250726001121",
    },
    {
        "school": "L H Coffin",
        "district": "Marblehead",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250726001122",
    },
    {
        "school": "Marblehead High",
        "district": "Marblehead",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250726001124",
    },
    {
        "school": "Masconomet Regional Middle School",
        "district": "Masconomet",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250741001097",
    },
    {
        "school": "Masconomet Regional High School",
        "district": "Masconomet",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250741001146",
    },
    {
        "school": "Howe-Manning",
        "district": "Middleton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250783001236",
    },
    {
        "school": "Fuller Meadow",
        "district": "Middleton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250783002588",
    },
    {
        "school": "Johnson",
        "district": "Nahant",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250822002394",
    },
    {
        "school": "Francis T Bresnahan Elementary",
        "district": "Newburyport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250858001350",
    },
    {
        "school": "Newburyport High",
        "district": "Newburyport",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250858001354",
    },
    {
        "school": "Rupert A Nock Middle",
        "district": "Newburyport",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250858001355",
    },
    {
        "school": "Center",
        "district": "Peabody",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250936001493",
    },
    {
        "school": "J Henry Higgins Middle",
        "district": "Peabody",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250936001495",
    },
    {
        "school": "John E Burke",
        "district": "Peabody",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250936001496",
    },
    {
        "school": "Captain Samuel Brown",
        "district": "Peabody",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250936001501",
    },
    {
        "school": "South Memorial",
        "district": "Peabody",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250936001502",
    },
    {
        "school": "Thomas Carroll",
        "district": "Peabody",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250936001503",
    },
    {
        "school": "Peabody Veterans Memorial High",
        "district": "Peabody",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250936001504",
    },
    {
        "school": "West Memorial",
        "district": "Peabody",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250936001505",
    },
    {
        "school": "William A Welch Sr",
        "district": "Peabody",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250936001506",
    },
    {
        "school": "Rockport Middle",
        "district": "Rockport",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251020000506",
    },
    {
        "school": "Rockport Elementary",
        "district": "Rockport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251020002533",
    },
    {
        "school": "Rockport High",
        "district": "Rockport",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251020002597",
    },
    {
        "school": "Salem Early Childhood",
        "district": "Salem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251038000127",
    },
    {
        "school": "Saltonstall School",
        "district": "Salem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251038000773",
    },
    {
        "school": "Bates",
        "district": "Salem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251038001653",
    },
    {
        "school": "Carlton",
        "district": "Salem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251038001656",
    },
    {
        "school": "Horace Mann Laboratory",
        "district": "Salem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251038001658",
    },
    {
        "school": "Salem High",
        "district": "Salem",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251038001664",
    },
    {
        "school": "Witchcraft Heights",
        "district": "Salem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251038001668",
    },
    {
        "school": "Collins Middle",
        "district": "Salem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251038002404",
    },
    {
        "school": "Douglas Waybright",
        "district": "Saugus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251050001677",
    },
    {
        "school": "Lynnhurst",
        "district": "Saugus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251050001680",
    },
    {
        "school": "Oaklandvale",
        "district": "Saugus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251050001682",
    },
    {
        "school": "Saugus High",
        "district": "Saugus",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251050001684",
    },
    {
        "school": "Belmonte Saugus Middle",
        "district": "Saugus",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251050001685",
    },
    {
        "school": "Veterans Memorial",
        "district": "Saugus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251050001687",
    },
    {
        "school": "Clarke",
        "district": "Swampscott",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251143001883",
    },
    {
        "school": "Hadley",
        "district": "Swampscott",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251143001884",
    },
    {
        "school": "Stanley",
        "district": "Swampscott",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251143001886",
    },
    {
        "school": "Swampscott High",
        "district": "Swampscott",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251143001887",
    },
    {
        "school": "Swampscott Middle",
        "district": "Swampscott",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251143002562",
    },
    {
        "school": "Proctor Elementary",
        "district": "Topsfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251167001928",
    },
    {
        "school": "Steward Elementary",
        "district": "Topsfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251167001929",
    },
    {
        "school": "Newbury Elementary",
        "district": "Triton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251174001348",
    },
    {
        "school": "Triton Regional Middle School",
        "district": "Triton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251174001470",
    },
    {
        "school": "Pine Grove",
        "district": "Triton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251174001651",
    },
    {
        "school": "Salisbury Elementary",
        "district": "Triton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251174001669",
    },
    {
        "school": "Triton Regional High School",
        "district": "Triton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251174001932",
    },
    {
        "school": "Benjamin Banneker Charter Public School",
        "district": "Benjamin Banneker Charter Public (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250002200514",
    },
    {
        "school": "Francis W. Parker Charter Essential School",
        "district": "Francis W. Parker Charter Essential (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250003800581",
    },
    {
        "school": "Prospect Hill Academy Charter School",
        "district": "Prospect Hill Academy Charter (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250004600819",
    },
    {
        "school": "Mystic Valley Regional Charter School",
        "district": "Mystic Valley Regional Charter (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250005501260",
    },
    {
        "school": "Acton-Boxborough Regional High",
        "district": "Acton-Boxborough",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250171000012",
    },
    {
        "school": "Raymond J Grey Junior High",
        "district": "Acton-Boxborough",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250171000013",
    },
    {
        "school": "Arlington High",
        "district": "Arlington",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250198000053",
    },
    {
        "school": "Brackett",
        "district": "Arlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250198000054",
    },
    {
        "school": "Cyrus E Dallin",
        "district": "Arlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250198000057",
    },
    {
        "school": "Hardy",
        "district": "Arlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250198000058",
    },
    {
        "school": "John A Bishop",
        "district": "Arlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250198000059",
    },
    {
        "school": "M Norcross Stratton",
        "district": "Arlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250198000062",
    },
    {
        "school": "Ottoson Middle",
        "district": "Arlington",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250198000063",
    },
    {
        "school": "Peirce",
        "district": "Arlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250198000065",
    },
    {
        "school": "Thompson",
        "district": "Arlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250198000066",
    },
    {
        "school": "Ashland High",
        "district": "Ashland",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250210000070",
    },
    {
        "school": "David Mindess",
        "district": "Ashland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250210000071",
    },
    {
        "school": "Henry E Warren Elementary",
        "district": "Ashland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250210000072",
    },
    {
        "school": "Ashland Middle",
        "district": "Ashland",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250210000938",
    },
    {
        "school": "William Pittaway Elementary",
        "district": "Ashland",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250210002455",
    },
    {
        "school": "Assabet Valley Vocational High School",
        "district": "Assabet Valley Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250211002257",
    },
    {
        "school": "Bedford High",
        "district": "Bedford",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250240000128",
    },
    {
        "school": "John Glenn Middle",
        "district": "Bedford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250240000130",
    },
    {
        "school": "Lt Elezer Davis",
        "district": "Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250240000131",
    },
    {
        "school": "Lt Job Lane School",
        "district": "Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250240000132",
    },
    {
        "school": "Belmont High",
        "district": "Belmont",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250249000143",
    },
    {
        "school": "Daniel Butler",
        "district": "Belmont",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250249000144",
    },
    {
        "school": "Mary Lee Burbank",
        "district": "Belmont",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250249000146",
    },
    {
        "school": "Roger E Wellington",
        "district": "Belmont",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250249000147",
    },
    {
        "school": "Winn Brook",
        "district": "Belmont",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250249000148",
    },
    {
        "school": "Winthrop L Chenery Middle",
        "district": "Belmont",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250249000149",
    },
    {
        "school": "Edith C Baker",
        "district": "Brookline",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315000416",
    },
    {
        "school": "Heath",
        "district": "Brookline",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315000418",
    },
    {
        "school": "Burlington High",
        "district": "Burlington",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250324000426",
    },
    {
        "school": "Fox Hill",
        "district": "Burlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250324000427",
    },
    {
        "school": "Marshall Simonds Middle",
        "district": "Burlington",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250324000429",
    },
    {
        "school": "Memorial",
        "district": "Burlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250324000431",
    },
    {
        "school": "Pine Glen Elementary",
        "district": "Burlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250324000432",
    },
    {
        "school": "Francis Wyman Elementary",
        "district": "Burlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250324000844",
    },
    {
        "school": "Cambridgeport",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327000020",
    },
    {
        "school": "King Open",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250327000228",
    },
    {
        "school": "Maria L. Baldwin",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327000435",
    },
    {
        "school": "Cambridge Rindge and Latin",
        "district": "Cambridge",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327000436",
    },
    {
        "school": "Graham and Parks",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250327000437",
    },
    {
        "school": "Haggerty",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327000441",
    },
    {
        "school": "John M Tobin",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327000442",
    },
    {
        "school": "Martin Luther King Jr.",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327000443",
    },
    {
        "school": "Kennedy-Longfellow",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327000444",
    },
    {
        "school": "Morse",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327000446",
    },
    {
        "school": "Peabody",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327000447",
    },
    {
        "school": "Fletcher/Maynard Academy",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327001518",
    },
    {
        "school": "Amigos School",
        "district": "Cambridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327001621",
    },
    {
        "school": "Carlisle School",
        "district": "Carlisle",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250333000457",
    },
    {
        "school": "Alcott",
        "district": "Concord",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250384000521",
    },
    {
        "school": "Concord Middle",
        "district": "Concord",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250384000522",
    },
    {
        "school": "Thoreau",
        "district": "Concord",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250384000525",
    },
    {
        "school": "Willard",
        "district": "Concord",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250384000526",
    },
    {
        "school": "Concord Carlisle High",
        "district": "Concord-Carlisle",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250387000527",
    },
    {
        "school": "Sumner G. Whittier School",
        "district": "Everett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250477000631",
    },
    {
        "school": "Everett High",
        "district": "Everett",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250477000634",
    },
    {
        "school": "Lafayette School",
        "district": "Everett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250477001520",
    },
    {
        "school": "Parlin School",
        "district": "Everett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250477001521",
    },
    {
        "school": "Holliston High",
        "district": "Holliston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250624000894",
    },
    {
        "school": "Placentino Elementary",
        "district": "Holliston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250624001172",
    },
    {
        "school": "Miller School",
        "district": "Holliston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250624001302",
    },
    {
        "school": "Robert H. Adams Middle School",
        "district": "Holliston",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250624001304",
    },
    {
        "school": "Hopkinton Middle School",
        "district": "Hopkinton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250633000468",
    },
    {
        "school": "Marathon Elementary School",
        "district": "Hopkinton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250633000918",
    },
    {
        "school": "Elmwood",
        "district": "Hopkinton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250633000919",
    },
    {
        "school": "Hopkinton High",
        "district": "Hopkinton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250633000920",
    },
    {
        "school": "Hopkins Elementary School",
        "district": "Hopkinton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250633001180",
    },
    {
        "school": "C A Farley",
        "district": "Hudson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250639000922",
    },
    {
        "school": "Mulready Elementary",
        "district": "Hudson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250639000924",
    },
    {
        "school": "Forest Avenue Elementary",
        "district": "Hudson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250639000925",
    },
    {
        "school": "Hudson High",
        "district": "Hudson",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250639000926",
    },
    {
        "school": "David J. Quinn Middle School",
        "district": "Hudson",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250639000927",
    },
    {
        "school": "Maria Hastings",
        "district": "Lexington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250684000473",
    },
    {
        "school": "Bowman",
        "district": "Lexington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250684000994",
    },
    {
        "school": "Bridge",
        "district": "Lexington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250684000995",
    },
    {
        "school": "Fiske",
        "district": "Lexington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250684000996",
    },
    {
        "school": "Harrington",
        "district": "Lexington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250684000998",
    },
    {
        "school": "Joseph Estabrook",
        "district": "Lexington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250684001000",
    },
    {
        "school": "Lexington High",
        "district": "Lexington",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250684001001",
    },
    {
        "school": "Jonas Clarke Middle",
        "district": "Lexington",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250684002551",
    },
    {
        "school": "Wm Diamond Middle",
        "district": "Lexington",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250684002552",
    },
    {
        "school": "Hanscom Middle",
        "district": "Lincoln",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250690001008",
    },
    {
        "school": "Hanscom Primary",
        "district": "Lincoln",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250690001009",
    },
    {
        "school": "Lincoln School",
        "district": "Lincoln",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250690001183",
    },
    {
        "school": "Lincoln-Sudbury Regional High",
        "district": "Lincoln-Sudbury",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250693001011",
    },
    {
        "school": "Littleton High School",
        "district": "Littleton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250696001012",
    },
    {
        "school": "Russell St Elementary",
        "district": "Littleton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250696001013",
    },
    {
        "school": "Shaker Lane Elementary",
        "district": "Littleton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250696001014",
    },
    {
        "school": "Littleton Middle School",
        "district": "Littleton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250696001628",
    },
    {
        "school": "Malden High",
        "district": "Malden",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250717001106",
    },
    {
        "school": "Beebe",
        "district": "Malden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250717001344",
    },
    {
        "school": "Ferryway",
        "district": "Malden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250717001345",
    },
    {
        "school": "Forestdale",
        "district": "Malden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250717001351",
    },
    {
        "school": "Linden",
        "district": "Malden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250717001361",
    },
    {
        "school": "Salemwood",
        "district": "Malden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250717001363",
    },
    {
        "school": "Francis J Kane",
        "district": "Marlborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250732001130",
    },
    {
        "school": "Marlborough High",
        "district": "Marlborough",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250732001133",
    },
    {
        "school": "Richer",
        "district": "Marlborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250732001135",
    },
    {
        "school": "Early Childhood Center",
        "district": "Marlborough",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250732001368",
    },
    {
        "school": "Charles Jaworek School",
        "district": "Marlborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250732001631",
    },
    {
        "school": "Fowler School",
        "district": "Maynard",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250750000105",
    },
    {
        "school": "Green Meadow",
        "district": "Maynard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250750001152",
    },
    {
        "school": "Maynard High",
        "district": "Maynard",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250750001153",
    },
    {
        "school": "Medford High",
        "district": "Medford",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250756001176",
    },
    {
        "school": "John J McGlynn Elementary School",
        "district": "Medford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250756001634",
    },
    {
        "school": "Madeleine Dugger Andrews",
        "district": "Medford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250756001638",
    },
    {
        "school": "Curtis-Tufts",
        "district": "Medford",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250756002393",
    },
    {
        "school": "Herbert Clark Hoover",
        "district": "Melrose",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250762001190",
    },
    {
        "school": "Horace Mann",
        "district": "Melrose",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250762001191",
    },
    {
        "school": "Lincoln",
        "district": "Melrose",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250762001192",
    },
    {
        "school": "Melrose High",
        "district": "Melrose",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250762001193",
    },
    {
        "school": "Roosevelt",
        "district": "Melrose",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250762001196",
    },
    {
        "school": "Winthrop",
        "district": "Melrose",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250762001198",
    },
    {
        "school": "Melrose Middle",
        "district": "Melrose",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250762002557",
    },
    {
        "school": "Minuteman Regional High",
        "district": "Minuteman Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250798501264",
    },
    {
        "school": "Bennett-Hemenway",
        "district": "Natick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250834001291",
    },
    {
        "school": "Brown",
        "district": "Natick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250834001292",
    },
    {
        "school": "J F Kennedy Middle School",
        "district": "Natick",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250834001297",
    },
    {
        "school": "Johnson",
        "district": "Natick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250834001298",
    },
    {
        "school": "Lilja Elementary",
        "district": "Natick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250834001299",
    },
    {
        "school": "Memorial",
        "district": "Natick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250834001301",
    },
    {
        "school": "Natick High",
        "district": "Natick",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250834001303",
    },
    {
        "school": "Wilson Middle",
        "district": "Natick",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250834001305",
    },
    {
        "school": "Bigelow Middle",
        "district": "Newton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861000307",
    },
    {
        "school": "Charles E Brown Middle",
        "district": "Newton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861000310",
    },
    {
        "school": "F A Day Middle",
        "district": "Newton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861000314",
    },
    {
        "school": "Oak Hill Middle",
        "district": "Newton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001042",
    },
    {
        "school": "A E Angier",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001356",
    },
    {
        "school": "Bowen",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001358",
    },
    {
        "school": "C C Burr",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001359",
    },
    {
        "school": "Cabot",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001360",
    },
    {
        "school": "Countryside",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001362",
    },
    {
        "school": "Franklin",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001366",
    },
    {
        "school": "Horace Mann",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001367",
    },
    {
        "school": "John Ward",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001369",
    },
    {
        "school": "Lincoln-Eliot",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001370",
    },
    {
        "school": "Mason-Rice",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001371",
    },
    {
        "school": "Memorial Spaulding",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001373",
    },
    {
        "school": "Newton North High",
        "district": "Newton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001374",
    },
    {
        "school": "Newton South High",
        "district": "Newton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001375",
    },
    {
        "school": "Peirce",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001377",
    },
    {
        "school": "Underwood",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001379",
    },
    {
        "school": "Williams",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001382",
    },
    {
        "school": "Zervas",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001383",
    },
    {
        "school": "Newton Early Childhood Center",
        "district": "Newton",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250861001657",
    },
    {
        "school": "Spaulding Memorial",
        "district": "North Middlesex",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250879000621",
    },
    {
        "school": "Ashby Elementary",
        "district": "North Middlesex",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250879001412",
    },
    {
        "school": "North Middlesex Regional",
        "district": "North Middlesex",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250879001415",
    },
    {
        "school": "Hawthorne Brook",
        "district": "North Middlesex",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250879002280",
    },
    {
        "school": "Varnum Brook",
        "district": "North Middlesex",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250879002281",
    },
    {
        "school": "E Ethel Little School",
        "district": "North Reading",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250882000505",
    },
    {
        "school": "J Turner Hood",
        "district": "North Reading",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250882001419",
    },
    {
        "school": "L D Batchelder",
        "district": "North Reading",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250882001420",
    },
    {
        "school": "North Reading High",
        "district": "North Reading",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250882001422",
    },
    {
        "school": "North Reading Middle",
        "district": "North Reading",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250882002592",
    },
    {
        "school": "Northeast Metro Regional Vocational",
        "district": "Northeast Metropolitan Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250896002283",
    },
    {
        "school": "Alice M Barrows",
        "district": "Reading",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250999001604",
    },
    {
        "school": "Arthur W Coolidge Middle",
        "district": "Reading",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250999001605",
    },
    {
        "school": "Birch Meadow",
        "district": "Reading",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250999001606",
    },
    {
        "school": "J Warren Killam",
        "district": "Reading",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250999001608",
    },
    {
        "school": "Joshua Eaton",
        "district": "Reading",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250999001609",
    },
    {
        "school": "Reading Memorial High",
        "district": "Reading",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250999001611",
    },
    {
        "school": "Walter S Parker Middle",
        "district": "Reading",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250999001612",
    },
    {
        "school": "Pine Hill",
        "district": "Sherborn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251071001709",
    },
    {
        "school": "West Somerville Neighborhood",
        "district": "Somerville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251089000891",
    },
    {
        "school": "Arthur D Healey",
        "district": "Somerville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251089001731",
    },
    {
        "school": "Benjamin G Brown",
        "district": "Somerville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251089001732",
    },
    {
        "school": "E Somerville Community",
        "district": "Somerville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251089001736",
    },
    {
        "school": "John F Kennedy",
        "district": "Somerville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251089001738",
    },
    {
        "school": "Albert F. Argenziano School at Lincoln Park",
        "district": "Somerville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251089001739",
    },
    {
        "school": "Somerville High",
        "district": "Somerville",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251089001745",
    },
    {
        "school": "Winter Hill Community",
        "district": "Somerville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251089001749",
    },
    {
        "school": "Next Wave Junior High",
        "district": "Somerville",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "251089002498",
    },
    {
        "school": "Full Circle High School",
        "district": "Somerville",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "251089002499",
    },
    {
        "school": "Capuano Early Childhood Center",
        "district": "Somerville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251089002561",
    },
    {
        "school": "East Area",
        "district": "Institutional Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MA",
        "nces_id": "251115002450",
    },
    {
        "school": "Colonial Park",
        "district": "Stoneham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251122001851",
    },
    {
        "school": "Robin Hood",
        "district": "Stoneham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251122001855",
    },
    {
        "school": "South",
        "district": "Stoneham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251122001856",
    },
    {
        "school": "Stoneham Central Middle School",
        "district": "Stoneham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251122001857",
    },
    {
        "school": "Stoneham High",
        "district": "Stoneham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251122002295",
    },
    {
        "school": "General John Nixon Elementary",
        "district": "Sudbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251134000507",
    },
    {
        "school": "Israel Loring School",
        "district": "Sudbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251134001407",
    },
    {
        "school": "Ephraim Curtis Middle",
        "district": "Sudbury",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251134001872",
    },
    {
        "school": "Josiah Haynes",
        "district": "Sudbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251134001876",
    },
    {
        "school": "Peter Noyes",
        "district": "Sudbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251134001877",
    },
    {
        "school": "Galvin Middle School",
        "district": "Wakefield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251191000776",
    },
    {
        "school": "Dolbeare",
        "district": "Wakefield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251191001941",
    },
    {
        "school": "Woodville School",
        "district": "Wakefield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251191001943",
    },
    {
        "school": "Greenwood",
        "district": "Wakefield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251191001944",
    },
    {
        "school": "Walton",
        "district": "Wakefield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251191001948",
    },
    {
        "school": "Wakefield Memorial High",
        "district": "Wakefield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251191001951",
    },
    {
        "school": "Douglas MacArthur Elementary School",
        "district": "Waltham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251200001967",
    },
    {
        "school": "Henry Whittemore Elementary School",
        "district": "Waltham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251200001969",
    },
    {
        "school": "James Fitzgerald Elementary School",
        "district": "Waltham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251200001970",
    },
    {
        "school": "John F Kennedy Middle",
        "district": "Waltham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251200001971",
    },
    {
        "school": "William F. Stanley Elementary School",
        "district": "Waltham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251200001973",
    },
    {
        "school": "Northeast Elementary School",
        "district": "Waltham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251200001974",
    },
    {
        "school": "John W. McDevitt Middle School",
        "district": "Waltham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251200001977",
    },
    {
        "school": "Thomas R Plympton Elementary School",
        "district": "Waltham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251200001978",
    },
    {
        "school": "Waltham Sr High",
        "district": "Waltham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251200001979",
    },
    {
        "school": "Cunniff",
        "district": "Watertown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251218001998",
    },
    {
        "school": "Hosmer",
        "district": "Watertown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251218002001",
    },
    {
        "school": "James Russell Lowell",
        "district": "Watertown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251218002002",
    },
    {
        "school": "Watertown High",
        "district": "Watertown",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251218002005",
    },
    {
        "school": "Watertown Middle",
        "district": "Watertown",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251218002501",
    },
    {
        "school": "Loker School",
        "district": "Wayland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251221000153",
    },
    {
        "school": "Claypit Hill School",
        "district": "Wayland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251221002007",
    },
    {
        "school": "Happy Hollow School",
        "district": "Wayland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251221002008",
    },
    {
        "school": "Wayland High School",
        "district": "Wayland",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251221002010",
    },
    {
        "school": "Wayland Middle School",
        "district": "Wayland",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251221002502",
    },
    {
        "school": "Field Elementary School",
        "district": "Weston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251275000785",
    },
    {
        "school": "Weston Middle",
        "district": "Weston",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251275000793",
    },
    {
        "school": "Country",
        "district": "Weston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251275002085",
    },
    {
        "school": "Weston High",
        "district": "Weston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251275002087",
    },
    {
        "school": "Woodland",
        "district": "Weston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251275002089",
    },
    {
        "school": "Boutwell",
        "district": "Wilmington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251305000802",
    },
    {
        "school": "North Intermediate",
        "district": "Wilmington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251305001575",
    },
    {
        "school": "West Intermediate",
        "district": "Wilmington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251305001576",
    },
    {
        "school": "Wilmington Middle School",
        "district": "Wilmington",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251305001578",
    },
    {
        "school": "Shawsheen Elementary",
        "district": "Wilmington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251305002153",
    },
    {
        "school": "Wildwood",
        "district": "Wilmington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251305002157",
    },
    {
        "school": "Wilmington High",
        "district": "Wilmington",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251305002158",
    },
    {
        "school": "Woburn Street",
        "district": "Wilmington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251305002159",
    },
    {
        "school": "Ambrose Elementary",
        "district": "Winchester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251311002164",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Winchester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251311002165",
    },
    {
        "school": "Lynch Elementary",
        "district": "Winchester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251311002166",
    },
    {
        "school": "McCall Middle",
        "district": "Winchester",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251311002167",
    },
    {
        "school": "Muraco Elementary",
        "district": "Winchester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251311002168",
    },
    {
        "school": "Vinson-Owen Elementary",
        "district": "Winchester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251311002172",
    },
    {
        "school": "Winchester High School",
        "district": "Winchester",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251311002174",
    },
    {
        "school": "Clyde Reeves",
        "district": "Woburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251320002181",
    },
    {
        "school": "Daniel L Joyce Middle School",
        "district": "Woburn",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251320002182",
    },
    {
        "school": "Hurld-Wyman Elementary School",
        "district": "Woburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251320002183",
    },
    {
        "school": "Goodyear Elementary School",
        "district": "Woburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251320002184",
    },
    {
        "school": "John F Kennedy Middle School",
        "district": "Woburn",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251320002186",
    },
    {
        "school": "Linscott-Rumford",
        "district": "Woburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251320002187",
    },
    {
        "school": "Malcolm White",
        "district": "Woburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251320002188",
    },
    {
        "school": "Mary D Altavesta",
        "district": "Woburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251320002189",
    },
    {
        "school": "Shamrock",
        "district": "Woburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251320002191",
    },
    {
        "school": "Woburn High",
        "district": "Woburn",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251320002193",
    },
    {
        "school": "Benjamin Franklin Classical Charter Public School",
        "district": "Benjamin Franklin Classical Charter Public (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250003000547",
    },
    {
        "school": "Foxborough Regional Charter School",
        "district": "Foxborough Regional Charter (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250005201250",
    },
    {
        "school": "Blue Hills Regional Vocational Technical",
        "district": "Blue Hills Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250274000193",
    },
    {
        "school": "Archie T Morrison",
        "district": "Braintree",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250294000360",
    },
    {
        "school": "Braintree High",
        "district": "Braintree",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250294000361",
    },
    {
        "school": "Donald Ross",
        "district": "Braintree",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250294000363",
    },
    {
        "school": "East Middle School",
        "district": "Braintree",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250294000364",
    },
    {
        "school": "Highlands",
        "district": "Braintree",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250294000365",
    },
    {
        "school": "Mary E Flaherty School",
        "district": "Braintree",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250294000367",
    },
    {
        "school": "Liberty",
        "district": "Braintree",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250294000368",
    },
    {
        "school": "South Middle School",
        "district": "Braintree",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250294000372",
    },
    {
        "school": "Hollis",
        "district": "Braintree",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250294002570",
    },
    {
        "school": "Brookline High",
        "district": "Brookline",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315000415",
    },
    {
        "school": "Coolidge Corner School",
        "district": "Brookline",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315000417",
    },
    {
        "school": "John D Runkle",
        "district": "Brookline",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315000419",
    },
    {
        "school": "Lawrence",
        "district": "Brookline",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315000420",
    },
    {
        "school": "Michael Driscoll",
        "district": "Brookline",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315000421",
    },
    {
        "school": "Pierce",
        "district": "Brookline",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315000422",
    },
    {
        "school": "William H Lincoln",
        "district": "Brookline",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315000423",
    },
    {
        "school": "Canton High",
        "district": "Canton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250330000451",
    },
    {
        "school": "Dean S Luce",
        "district": "Canton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250330000452",
    },
    {
        "school": "John F Kennedy",
        "district": "Canton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250330000454",
    },
    {
        "school": "Lt Peter M Hansen",
        "district": "Canton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250330000455",
    },
    {
        "school": "Wm H Galvin Middle",
        "district": "Canton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250330000456",
    },
    {
        "school": "Cohasset High School",
        "district": "Cohasset",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250378000518",
    },
    {
        "school": "Deer Hill",
        "district": "Cohasset",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250378000519",
    },
    {
        "school": "Joseph Osgood",
        "district": "Cohasset",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250378000520",
    },
    {
        "school": "Early Childhood Center",
        "district": "Dedham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250405000460",
    },
    {
        "school": "Avery",
        "district": "Dedham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250405000546",
    },
    {
        "school": "Dedham High",
        "district": "Dedham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250405000548",
    },
    {
        "school": "Greenlodge",
        "district": "Dedham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250405000550",
    },
    {
        "school": "Dedham Middle School",
        "district": "Dedham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250405000551",
    },
    {
        "school": "Oakdale",
        "district": "Dedham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250405000552",
    },
    {
        "school": "Riverdale",
        "district": "Dedham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250405000554",
    },
    {
        "school": "Chickering",
        "district": "Dover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250426000573",
    },
    {
        "school": "Dover-Sherborn Regional High",
        "district": "Dover-Sherborn",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250429000574",
    },
    {
        "school": "Dover-Sherborn Regional Middle School",
        "district": "Dover-Sherborn",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250429000575",
    },
    {
        "school": "Foxborough High",
        "district": "Foxborough",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250495000708",
    },
    {
        "school": "John J Ahern",
        "district": "Foxborough",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250495000709",
    },
    {
        "school": "Mabelle M Burrell",
        "district": "Foxborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250495000710",
    },
    {
        "school": "Vincent M Igo Elementary",
        "district": "Foxborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250495000724",
    },
    {
        "school": "Charles Taylor Elementary",
        "district": "Foxborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250495000864",
    },
    {
        "school": "Davis Thayer",
        "district": "Franklin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250501000736",
    },
    {
        "school": "Franklin High",
        "district": "Franklin",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250501000737",
    },
    {
        "school": "Horace Mann",
        "district": "Franklin",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250501000738",
    },
    {
        "school": "J F Kennedy Memorial",
        "district": "Franklin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250501000740",
    },
    {
        "school": "Oak Street Elementary",
        "district": "Franklin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250501000741",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Franklin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250501000868",
    },
    {
        "school": "Remington Middle",
        "district": "Franklin",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250501000871",
    },
    {
        "school": "Franklin Early Childhood Development Center",
        "district": "Franklin",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250501000986",
    },
    {
        "school": "Parmenter",
        "district": "Franklin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250501002519",
    },
    {
        "school": "Holbrook Middle High School",
        "district": "Holbrook",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250615000878",
    },
    {
        "school": "John F Kennedy",
        "district": "Holbrook",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250615000880",
    },
    {
        "school": "King Philip Regional High",
        "district": "King Philip",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250651000940",
    },
    {
        "school": "King Philip Middle School",
        "district": "King Philip",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250651000941",
    },
    {
        "school": "Memorial School",
        "district": "Medfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250753000114",
    },
    {
        "school": "Dale Street",
        "district": "Medfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250753001155",
    },
    {
        "school": "Thomas Blake Middle",
        "district": "Medfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250753001156",
    },
    {
        "school": "Medfield Senior High",
        "district": "Medfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250753001157",
    },
    {
        "school": "Ralph Wheelock School",
        "district": "Medfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250753001159",
    },
    {
        "school": "Burke/Memorial Elementary School",
        "district": "Medway",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250759001015",
    },
    {
        "school": "Medway High",
        "district": "Medway",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250759001184",
    },
    {
        "school": "John D Mc Govern Elementary",
        "district": "Medway",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250759001185",
    },
    {
        "school": "Medway Middle",
        "district": "Medway",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250759002483",
    },
    {
        "school": "Clyde F Brown",
        "district": "Millis",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250792001252",
    },
    {
        "school": "Millis Middle",
        "district": "Millis",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250792001254",
    },
    {
        "school": "Millis High School",
        "district": "Millis",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250792001255",
    },
    {
        "school": "Charles S Pierce Middle",
        "district": "Milton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250798001257",
    },
    {
        "school": "Collicot",
        "district": "Milton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250798001259",
    },
    {
        "school": "Glover",
        "district": "Milton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250798001261",
    },
    {
        "school": "Milton High",
        "district": "Milton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250798001262",
    },
    {
        "school": "Tucker",
        "district": "Milton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250798001263",
    },
    {
        "school": "Cunningham School",
        "district": "Milton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250798002485",
    },
    {
        "school": "Newman Elementary",
        "district": "Needham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250837000306",
    },
    {
        "school": "Broadmeadow",
        "district": "Needham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250837001306",
    },
    {
        "school": "Pollard Middle",
        "district": "Needham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250837001308",
    },
    {
        "school": "Sunita L. Williams Elementary",
        "district": "Needham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250837001313",
    },
    {
        "school": "John Eliot",
        "district": "Needham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250837001314",
    },
    {
        "school": "Needham High",
        "district": "Needham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250837001315",
    },
    {
        "school": "William Mitchell",
        "district": "Needham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250837001317",
    },
    {
        "school": "H Olive Day",
        "district": "Norfolk",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250864000317",
    },
    {
        "school": "Freeman-Kennedy School",
        "district": "Norfolk",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250864001384",
    },
    {
        "school": "Norfolk County Agricultural",
        "district": "Norfolk County Agricultural",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250865001386",
    },
    {
        "school": "Balch",
        "district": "Norwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250906001460",
    },
    {
        "school": "Charles J Prescott",
        "district": "Norwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250906001461",
    },
    {
        "school": "Cornelius M Callahan",
        "district": "Norwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250906001462",
    },
    {
        "school": "F A Cleveland",
        "district": "Norwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250906001463",
    },
    {
        "school": "John P Oldham",
        "district": "Norwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250906001465",
    },
    {
        "school": "Norwood High",
        "district": "Norwood",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250906001466",
    },
    {
        "school": "Dr. Philip O. Coakley Middle School",
        "district": "Norwood",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250906001468",
    },
    {
        "school": "George F. Willett",
        "district": "Norwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250906001557",
    },
    {
        "school": "Anna Ware Jackson",
        "district": "Plainville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250969001537",
    },
    {
        "school": "Beatrice H Wood Elementary",
        "district": "Plainville",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250969001538",
    },
    {
        "school": "Randolph Community Middle",
        "district": "Randolph",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250993001392",
    },
    {
        "school": "Elizabeth G Lyons Elementary",
        "district": "Randolph",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250993001590",
    },
    {
        "school": "Margaret L Donovan",
        "district": "Randolph",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250993001592",
    },
    {
        "school": "Martin E Young Elementary",
        "district": "Randolph",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250993001593",
    },
    {
        "school": "Randolph High",
        "district": "Randolph",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250993001596",
    },
    {
        "school": "J F Kennedy Elementary",
        "district": "Randolph",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250993002596",
    },
    {
        "school": "Cottage Street",
        "district": "Sharon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251062001702",
    },
    {
        "school": "East Elementary",
        "district": "Sharon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251062001703",
    },
    {
        "school": "Heights Elementary",
        "district": "Sharon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251062001704",
    },
    {
        "school": "Sharon High",
        "district": "Sharon",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251062001705",
    },
    {
        "school": "Sharon Middle",
        "district": "Sharon",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251062002560",
    },
    {
        "school": "Pappas Rehabilitation Hospital for Children",
        "district": "Institutional Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MA",
        "nces_id": "251115002449",
    },
    {
        "school": "Helen Hansen Elementary",
        "district": "Stoughton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251125001858",
    },
    {
        "school": "Edwin A Jones Early Childhood Center",
        "district": "Stoughton",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251125001860",
    },
    {
        "school": "Joseph H Gibbons",
        "district": "Stoughton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251125001861",
    },
    {
        "school": "Joseph R Dawe Jr Elementary",
        "district": "Stoughton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251125001862",
    },
    {
        "school": "South Elementary",
        "district": "Stoughton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251125001863",
    },
    {
        "school": "Stoughton High",
        "district": "Stoughton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251125001864",
    },
    {
        "school": "O'Donnell Middle School",
        "district": "Stoughton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251125001865",
    },
    {
        "school": "Richard L. Wilkins Elementary School",
        "district": "Stoughton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251125001866",
    },
    {
        "school": "Tri-County Regional Vocational Technical",
        "district": "Tri-County Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251173501931",
    },
    {
        "school": "Elm Street School",
        "district": "Walpole",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251197001235",
    },
    {
        "school": "Bird Middle",
        "district": "Walpole",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251197001959",
    },
    {
        "school": "Fisher",
        "district": "Walpole",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251197001960",
    },
    {
        "school": "Old Post Road",
        "district": "Walpole",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251197001961",
    },
    {
        "school": "Walpole High",
        "district": "Walpole",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251197001964",
    },
    {
        "school": "Eleanor N Johnson Middle",
        "district": "Walpole",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251197001965",
    },
    {
        "school": "Boyden",
        "district": "Walpole",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251197002563",
    },
    {
        "school": "Ernest F Upham",
        "district": "Wellesley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251227002021",
    },
    {
        "school": "Hunnewell",
        "district": "Wellesley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251227002022",
    },
    {
        "school": "John D Hardy",
        "district": "Wellesley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251227002023",
    },
    {
        "school": "Joseph E Fiske",
        "district": "Wellesley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251227002024",
    },
    {
        "school": "Katharine Lee Bates",
        "district": "Wellesley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251227002025",
    },
    {
        "school": "Wellesley Middle",
        "district": "Wellesley",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251227002029",
    },
    {
        "school": "Wellesley Sr High",
        "district": "Wellesley",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251227002030",
    },
    {
        "school": "Schofield",
        "district": "Wellesley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251227002503",
    },
    {
        "school": "Deerfield School",
        "district": "Westwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251281000794",
    },
    {
        "school": "Downey",
        "district": "Westwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251281002096",
    },
    {
        "school": "E W Thurston Middle",
        "district": "Westwood",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251281002097",
    },
    {
        "school": "Martha Jones",
        "district": "Westwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251281002098",
    },
    {
        "school": "Paul Hanlon",
        "district": "Westwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251281002099",
    },
    {
        "school": "Westwood High",
        "district": "Westwood",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251281002100",
    },
    {
        "school": "William E Sheehan",
        "district": "Westwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251281002101",
    },
    {
        "school": "Johnson Early Childhood Center",
        "district": "Weymouth",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284000371",
    },
    {
        "school": "Thomas V Nash",
        "district": "Weymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284000509",
    },
    {
        "school": "Academy Avenue",
        "district": "Weymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284002103",
    },
    {
        "school": "Lawrence W Pingree",
        "district": "Weymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284002114",
    },
    {
        "school": "Ralph Talbot",
        "district": "Weymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284002116",
    },
    {
        "school": "Thomas W. Hamilton Primary School",
        "district": "Weymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284002120",
    },
    {
        "school": "Wessagusset",
        "district": "Weymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284002122",
    },
    {
        "school": "Weymouth High School",
        "district": "Weymouth",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284002123",
    },
    {
        "school": "William Seach",
        "district": "Weymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284002125",
    },
    {
        "school": "Frederick C Murphy",
        "district": "Weymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284002565",
    },
    {
        "school": "Abigail Adams Middle School",
        "district": "Weymouth",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251284002607",
    },
    {
        "school": "Charles E Roderick",
        "district": "Wrentham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251329002254",
    },
    {
        "school": "Delaney",
        "district": "Wrentham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251329002255",
    },
    {
        "school": "South Shore Charter Public School",
        "district": "South Shore Charter Public (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250004000600",
    },
    {
        "school": "Rising Tide Charter Public School",
        "district": "Rising Tide Charter Public (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250005701271",
    },
    {
        "school": "Chandler Elementary",
        "district": "Duxbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250441000593",
    },
    {
        "school": "Duxbury High",
        "district": "Duxbury",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250441000594",
    },
    {
        "school": "Alden School",
        "district": "Duxbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250441000968",
    },
    {
        "school": "Duxbury Middle",
        "district": "Duxbury",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250441000975",
    },
    {
        "school": "Halifax Elementary",
        "district": "Halifax",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250561000815",
    },
    {
        "school": "Cedar Elementary",
        "district": "Hanover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250579000827",
    },
    {
        "school": "Center Elementary",
        "district": "Hanover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250579000828",
    },
    {
        "school": "Hanover High",
        "district": "Hanover",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250579000829",
    },
    {
        "school": "Hanover Middle",
        "district": "Hanover",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250579002548",
    },
    {
        "school": "Hingham High",
        "district": "Hingham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250609000872",
    },
    {
        "school": "Plymouth River",
        "district": "Hingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250609000873",
    },
    {
        "school": "South Elementary",
        "district": "Hingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250609000874",
    },
    {
        "school": "Hingham Middle School",
        "district": "Hingham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250609000875",
    },
    {
        "school": "Wm L Foster Elementary",
        "district": "Hingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250609000876",
    },
    {
        "school": "Hull High",
        "district": "Hull",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250642000930",
    },
    {
        "school": "Lillian M Jacobs",
        "district": "Hull",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250642000932",
    },
    {
        "school": "Memorial Middle",
        "district": "Hull",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250642001307",
    },
    {
        "school": "Kingston Elementary",
        "district": "Kingston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250654000943",
    },
    {
        "school": "Kingston Intermediate",
        "district": "Kingston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250654001531",
    },
    {
        "school": "Eames Way School",
        "district": "Marshfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250735000760",
    },
    {
        "school": "Daniel Webster",
        "district": "Marshfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250735001137",
    },
    {
        "school": "Martinson Elementary",
        "district": "Marshfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250735001139",
    },
    {
        "school": "Gov Edward Winslow",
        "district": "Marshfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250735001140",
    },
    {
        "school": "Marshfield High",
        "district": "Marshfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250735001142",
    },
    {
        "school": "Furnace Brook Middle",
        "district": "Marshfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250735001143",
    },
    {
        "school": "South River",
        "district": "Marshfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250735001144",
    },
    {
        "school": "Grace Farrar Cole",
        "district": "Norwell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250903001454",
    },
    {
        "school": "Norwell High",
        "district": "Norwell",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250903001455",
    },
    {
        "school": "Norwell Middle School",
        "district": "Norwell",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250903001456",
    },
    {
        "school": "William G Vinal",
        "district": "Norwell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250903001458",
    },
    {
        "school": "Bryantville Elementary",
        "district": "Pembroke",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250942001508",
    },
    {
        "school": "Hobomock Elementary",
        "district": "Pembroke",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250942001509",
    },
    {
        "school": "North Pembroke Elementary",
        "district": "Pembroke",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250942001510",
    },
    {
        "school": "Plymouth Early Childhood Center",
        "district": "Plymouth",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972000318",
    },
    {
        "school": "Plymouth North High",
        "district": "Plymouth",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972000320",
    },
    {
        "school": "Plymouth South High",
        "district": "Plymouth",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972000325",
    },
    {
        "school": "Plymouth South Middle",
        "district": "Plymouth",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972001380",
    },
    {
        "school": "Cold Spring",
        "district": "Plymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972001539",
    },
    {
        "school": "Federal Furnace School",
        "district": "Plymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972001540",
    },
    {
        "school": "Hedge",
        "district": "Plymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972001541",
    },
    {
        "school": "Indian Brook",
        "district": "Plymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972001542",
    },
    {
        "school": "Manomet Elementary",
        "district": "Plymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972001543",
    },
    {
        "school": "Nathaniel Morton Elementary",
        "district": "Plymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972001545",
    },
    {
        "school": "South Elementary",
        "district": "Plymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972001547",
    },
    {
        "school": "West Elementary",
        "district": "Plymouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972001548",
    },
    {
        "school": "Plymouth Commun Intermediate",
        "district": "Plymouth",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250972002531",
    },
    {
        "school": "Dennett Elementary",
        "district": "Plympton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250978001551",
    },
    {
        "school": "Memorial Park",
        "district": "Rockland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251017001640",
    },
    {
        "school": "R Stewart Esten",
        "district": "Rockland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251017001641",
    },
    {
        "school": "John W Rogers Middle",
        "district": "Rockland",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251017001642",
    },
    {
        "school": "Rockland Senior High",
        "district": "Rockland",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251017001643",
    },
    {
        "school": "Cushing Elementary",
        "district": "Scituate",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251056001689",
    },
    {
        "school": "Gates Middle School",
        "district": "Scituate",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251056001690",
    },
    {
        "school": "Hatherly Elementary",
        "district": "Scituate",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251056001691",
    },
    {
        "school": "Scituate High School",
        "district": "Scituate",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251056001693",
    },
    {
        "school": "Wampatuck Elementary",
        "district": "Scituate",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251056002289",
    },
    {
        "school": "Silver Lake Regional Middle School",
        "district": "Silver Lake",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251083001721",
    },
    {
        "school": "Silver Lake Regional High",
        "district": "Silver Lake",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251083001722",
    },
    {
        "school": "So Shore Vocational Technical High",
        "district": "South Shore Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251093001756",
    },
    {
        "school": "Academy Of the Pacific Rim Charter Public School",
        "district": "Academy Of the Pacific Rim Charter Public (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250002100511",
    },
    {
        "school": "City on a Hill Charter Public School Circuit Street",
        "district": "City on a Hill Charter Public School Circuit Street (Distric",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250002600530",
    },
    {
        "school": "Neighborhood House Charter School",
        "district": "Neighborhood House Charter (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250002900545",
    },
    {
        "school": "Boston Renaissance Charter Public School",
        "district": "Boston Renaissance Charter Public (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250003900599",
    },
    {
        "school": "Boston Day and Evening Academy Charter School",
        "district": "Boston Day and Evening Academy Charter (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250004901245",
    },
    {
        "school": "Boston Collegiate Charter School",
        "district": "Boston Collegiate Charter (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250005301256",
    },
    {
        "school": "Edward M. Kennedy Academy for Health Careers (Horace Mann Ch",
        "district": "Edward M. Kennedy Academy for Health Careers (Horace Mann Ch",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250005401258",
    },
    {
        "school": "Conservatory Lab Charter School",
        "district": "Conservatory Lab Charter (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250006001439",
    },
    {
        "school": "Roxbury Preparatory Charter School",
        "district": "Roxbury Preparatory Charter (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250006301453",
    },
    {
        "school": "MATCH Charter Public School",
        "district": "MATCH Charter Public School (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250006601586",
    },
    {
        "school": "Codman Academy Charter Public School",
        "district": "Codman Academy Charter Public (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250007001667",
    },
    {
        "school": "Baldwin Early Learning Center",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000011",
    },
    {
        "school": "Beethoven",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000198",
    },
    {
        "school": "Blackstone",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000201",
    },
    {
        "school": "Boston Latin",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000203",
    },
    {
        "school": "Boston Latin Academy",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000204",
    },
    {
        "school": "O'Bryant School Math/Science",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000205",
    },
    {
        "school": "Brighton High",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000208",
    },
    {
        "school": "Carter School",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000210",
    },
    {
        "school": "Charles H Taylor",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000213",
    },
    {
        "school": "Charles Sumner",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000214",
    },
    {
        "school": "Charlestown High",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000215",
    },
    {
        "school": "Clarence R Edwards Middle",
        "district": "Boston",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000216",
    },
    {
        "school": "Snowden International School at Copley",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000217",
    },
    {
        "school": "Curtis Guild",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000218",
    },
    {
        "school": "David A Ellis",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000220",
    },
    {
        "school": "Dearborn",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000222",
    },
    {
        "school": "Dennis C Haley",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000223",
    },
    {
        "school": "Donald Mckay",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000224",
    },
    {
        "school": "East Boston High",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000226",
    },
    {
        "school": "Edward Everett",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000227",
    },
    {
        "school": "Eliot Elementary",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000230",
    },
    {
        "school": "Ellis Mendell",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000232",
    },
    {
        "school": "Franklin D Roosevelt",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000239",
    },
    {
        "school": "George H Conley",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000241",
    },
    {
        "school": "Harvard-Kent",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000244",
    },
    {
        "school": "Henry Grew",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000247",
    },
    {
        "school": "Hugh Roe O'Donnell",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000249",
    },
    {
        "school": "Jackson Mann",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000251",
    },
    {
        "school": "Condon K-8",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000254",
    },
    {
        "school": "James J Chittick",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000255",
    },
    {
        "school": "James Otis",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000257",
    },
    {
        "school": "James P Timilty Middle",
        "district": "Boston",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000258",
    },
    {
        "school": "James W Hennigan",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000259",
    },
    {
        "school": "Jeremiah E Burke High",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000261",
    },
    {
        "school": "John D Philbrick",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000264",
    },
    {
        "school": "John F Kennedy",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000265",
    },
    {
        "school": "UP Academy Holland",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000268",
    },
    {
        "school": "John W McCormack",
        "district": "Boston",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000269",
    },
    {
        "school": "John Winthrop",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000270",
    },
    {
        "school": "Joseph J Hurley",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000272",
    },
    {
        "school": "Joseph Lee",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000273",
    },
    {
        "school": "Joseph P Manning",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000274",
    },
    {
        "school": "Joseph P Tynan",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000275",
    },
    {
        "school": "Josiah Quincy",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000277",
    },
    {
        "school": "Joyce Kilmer",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000278",
    },
    {
        "school": "Madison Park High",
        "district": "Boston",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250279000282",
    },
    {
        "school": "Manassah E Bradley",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000283",
    },
    {
        "school": "Mather",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000289",
    },
    {
        "school": "Maurice J Tobin",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000291",
    },
    {
        "school": "Michael J Perkins",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000292",
    },
    {
        "school": "Mozart",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000294",
    },
    {
        "school": "Nathan Hale",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000295",
    },
    {
        "school": "Oliver Hazard Perry",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000297",
    },
    {
        "school": "Patrick J Kennedy",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000302",
    },
    {
        "school": "Dr. William Henderson Lower",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000303",
    },
    {
        "school": "Paul A Dever",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000304",
    },
    {
        "school": "Phineas Bates",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000308",
    },
    {
        "school": "Rafael Hernandez",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000312",
    },
    {
        "school": "Richard J Murphy",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000315",
    },
    {
        "school": "Roger Clap",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000319",
    },
    {
        "school": "Samuel Adams",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000321",
    },
    {
        "school": "Samuel W Mason",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000322",
    },
    {
        "school": "Sarah Greenwood",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000323",
    },
    {
        "school": "The English High",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000327",
    },
    {
        "school": "Gardner Pilot Academy",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000331",
    },
    {
        "school": "Thomas J Kenny",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000332",
    },
    {
        "school": "Warren-Prescott",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000333",
    },
    {
        "school": "Washington Irving Middle",
        "district": "Boston",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000334",
    },
    {
        "school": "William E Russell",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000337",
    },
    {
        "school": "William Ellery Channing",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000338",
    },
    {
        "school": "William H Ohrenberger",
        "district": "Boston",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000339",
    },
    {
        "school": "William McKinley",
        "district": "Boston",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000342",
    },
    {
        "school": "William Monroe Trotter",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000343",
    },
    {
        "school": "Winship Elementary",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000344",
    },
    {
        "school": "Lyndon",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000692",
    },
    {
        "school": "Young Achievers",
        "district": "Boston",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250279000693",
    },
    {
        "school": "Fenway High School",
        "district": "Boston",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250279000695",
    },
    {
        "school": "Another Course To College",
        "district": "Boston",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250279000698",
    },
    {
        "school": "New Mission High School",
        "district": "Boston",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250279000704",
    },
    {
        "school": "Greater Egleston Community High School",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000837",
    },
    {
        "school": "Mission Hill School",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000946",
    },
    {
        "school": "Dr. William Henderson Upper",
        "district": "Boston",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279000952",
    },
    {
        "school": "Dr. Catherine Ellison-Rosa Parks Early Ed School",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279001115",
    },
    {
        "school": "East Boston Early Childhood Center",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279001118",
    },
    {
        "school": "Haynes Early Education Center",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279001126",
    },
    {
        "school": "Boston Arts Academy",
        "district": "Boston",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250279001128",
    },
    {
        "school": "Quincy Upper School",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279001296",
    },
    {
        "school": "Boston Adult Academy",
        "district": "Boston",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250279001511",
    },
    {
        "school": "Community Academy",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279001617",
    },
    {
        "school": "Horace Mann School for the Deaf",
        "district": "Boston",
        "level": "Other",
        "type": "Special education school",
        "state": "MA",
        "nces_id": "250279002374",
    },
    {
        "school": "Lyon K-8",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002458",
    },
    {
        "school": "ELC - West Zone",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002514",
    },
    {
        "school": "O W Holmes",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002569",
    },
    {
        "school": "Shurtleff Early Childhood",
        "district": "Chelsea",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250354000235",
    },
    {
        "school": "Chelsea High",
        "district": "Chelsea",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250354000482",
    },
    {
        "school": "William A Berkowitz Elementary",
        "district": "Chelsea",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250354000847",
    },
    {
        "school": "Edgar A Hooks Elementary",
        "district": "Chelsea",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250354000855",
    },
    {
        "school": "George F. Kelly Elementary",
        "district": "Chelsea",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250354000858",
    },
    {
        "school": "Frank M Sokolowski Elementary",
        "district": "Chelsea",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250354000859",
    },
    {
        "school": "Clark Avenue School",
        "district": "Chelsea",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250354001158",
    },
    {
        "school": "Abraham Lincoln",
        "district": "Revere",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251005001618",
    },
    {
        "school": "A. C. Whelan Elementary School",
        "district": "Revere",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251005001619",
    },
    {
        "school": "Paul Revere",
        "district": "Revere",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251005001629",
    },
    {
        "school": "Revere High",
        "district": "Revere",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251005001630",
    },
    {
        "school": "Staff Sargent James J. Hill Elementary School",
        "district": "Revere",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251005001633",
    },
    {
        "school": "Seacoast School",
        "district": "Revere",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251005001659",
    },
    {
        "school": "William P. Gorman/Fort Banks Elementary",
        "district": "Winthrop",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251317001665",
    },
    {
        "school": "Winthrop Middle School",
        "district": "Winthrop",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251317002179",
    },
    {
        "school": "Winthrop High School",
        "district": "Winthrop",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251317002180",
    },
    {
        "school": "Brookside",
        "district": "Milford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250786001237",
    },
    {
        "school": "Memorial",
        "district": "Milford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250786001238",
    },
    {
        "school": "Milford High",
        "district": "Milford",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250786001239",
    },
    {
        "school": "Stacy Middle",
        "district": "Milford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250786001240",
    },
    {
        "school": "Woodland",
        "district": "Milford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250786001244",
    },
    {
        "school": "Shining Star Early Childhood Center",
        "district": "Milford",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250786001650",
    },
    {
        "school": "Central Area",
        "district": "Institutional Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MA",
        "nces_id": "251115001428",
    },
    {
        "school": "Raynham Middle School",
        "district": "Bridgewater-Raynham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250303001674",
    },
    {
        "school": "Easton Middle School",
        "district": "Easton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250462000618",
    },
    {
        "school": "Oliver Ames High",
        "district": "Easton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250462000623",
    },
    {
        "school": "Parkview Elementary",
        "district": "Easton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250462000624",
    },
    {
        "school": "Center School",
        "district": "Easton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250462000980",
    },
    {
        "school": "Richardson Olmsted School",
        "district": "Easton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250462000983",
    },
    {
        "school": "Moreau Hall",
        "district": "Easton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250462002381",
    },
    {
        "school": "Southeastern Regional Vocational Technical",
        "district": "Southeastern Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251102002290",
    },
    {
        "school": "Ralph D Butler",
        "district": "Avon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250225000108",
    },
    {
        "school": "Avon Middle High School",
        "district": "Avon",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250225001295",
    },
    {
        "school": "Abington High",
        "district": "Abington",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250165000001",
    },
    {
        "school": "Abington Middle School",
        "district": "Abington",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250165000002",
    },
    {
        "school": "Woodsdale Elementary School",
        "district": "Abington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250165000006",
    },
    {
        "school": "Beaver Brook Elementary",
        "district": "Abington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250165000434",
    },
    {
        "school": "Bridgewater-Raynham Regional",
        "district": "Bridgewater-Raynham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250303000380",
    },
    {
        "school": "Brockton High",
        "district": "Brockton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000385",
    },
    {
        "school": "Brookfield",
        "district": "Brockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000386",
    },
    {
        "school": "Downey",
        "district": "Brockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000387",
    },
    {
        "school": "Dr W Arnone Community School",
        "district": "Brockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000388",
    },
    {
        "school": "East Middle School",
        "district": "Brockton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000389",
    },
    {
        "school": "Edgar B Davis",
        "district": "Brockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000390",
    },
    {
        "school": "Hancock",
        "district": "Brockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000396",
    },
    {
        "school": "Gilmore Elementary School",
        "district": "Brockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000398",
    },
    {
        "school": "John F Kennedy",
        "district": "Brockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000401",
    },
    {
        "school": "North Middle School",
        "district": "Brockton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000404",
    },
    {
        "school": "Oscar F Raymond",
        "district": "Brockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000405",
    },
    {
        "school": "South Middle School",
        "district": "Brockton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000407",
    },
    {
        "school": "West Middle School",
        "district": "Brockton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000410",
    },
    {
        "school": "Frederick Douglass Academy",
        "district": "Brockton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309000966",
    },
    {
        "school": "Louis F Angelo Elementary",
        "district": "Brockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309001132",
    },
    {
        "school": "Huntington Therapeutic Day School",
        "district": "Brockton",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250309002544",
    },
    {
        "school": "Central",
        "district": "East Bridgewater",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250444000596",
    },
    {
        "school": "East Bridgewater JR./SR. High School",
        "district": "East Bridgewater",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250444000597",
    },
    {
        "school": "Gordon W. Mitchell School",
        "district": "East Bridgewater",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250444000976",
    },
    {
        "school": "Apponequet Regional High",
        "district": "Freetown-Lakeville",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250507000746",
    },
    {
        "school": "Freetown-Lakeville Middle School",
        "district": "Freetown-Lakeville",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250507000748",
    },
    {
        "school": "Henry B. Burkland Elementary School",
        "district": "Middleborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250777001223",
    },
    {
        "school": "Middleborough High",
        "district": "Middleborough",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250777001227",
    },
    {
        "school": "John T. Nichols Middle",
        "district": "Middleborough",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250777001378",
    },
    {
        "school": "Spring Street School",
        "district": "West Bridgewater",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251242001663",
    },
    {
        "school": "Howard School",
        "district": "West Bridgewater",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251242002036",
    },
    {
        "school": "Rose L Macdonald",
        "district": "West Bridgewater",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251242002037",
    },
    {
        "school": "West Bridgewater Junior/Senior",
        "district": "West Bridgewater",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251242002039",
    },
    {
        "school": "Louise A Conley",
        "district": "Whitman-Hanson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251293000190",
    },
    {
        "school": "John H Duval",
        "district": "Whitman-Hanson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251293000200",
    },
    {
        "school": "Whitman Middle",
        "district": "Whitman-Hanson",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251293000207",
    },
    {
        "school": "Hanson Middle School",
        "district": "Whitman-Hanson",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251293001286",
    },
    {
        "school": "Indian Head",
        "district": "Whitman-Hanson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251293001497",
    },
    {
        "school": "Whitman Hanson Regional",
        "district": "Whitman-Hanson",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251293002135",
    },
    {
        "school": "Community Day Charter Public School - Prospect",
        "district": "Community Day Charter Public School - Prospect (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250002700535",
    },
    {
        "school": "Lawrence Family Development Charter School",
        "district": "Lawrence Family Development Charter (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250003200553",
    },
    {
        "school": "Andover High",
        "district": "Andover",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250195000045",
    },
    {
        "school": "Bancroft Elementary",
        "district": "Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250195000047",
    },
    {
        "school": "Henry C Sanborn Elementary",
        "district": "Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250195000048",
    },
    {
        "school": "South Elementary",
        "district": "Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250195000050",
    },
    {
        "school": "West Elementary",
        "district": "Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250195000051",
    },
    {
        "school": "Shawsheen School",
        "district": "Andover",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250195002366",
    },
    {
        "school": "Doherty Middle",
        "district": "Andover",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250195002510",
    },
    {
        "school": "Andover West Middle",
        "district": "Andover",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250195002511",
    },
    {
        "school": "Georgetown High School",
        "district": "Georgetown",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250522000764",
    },
    {
        "school": "Penn Brook",
        "district": "Georgetown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250522000765",
    },
    {
        "school": "Perley Elementary",
        "district": "Georgetown",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250522000766",
    },
    {
        "school": "Gr Lawrence Regional Vocational Technical",
        "district": "Greater Lawrence Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250547002267",
    },
    {
        "school": "Moody",
        "district": "Haverhill",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597000056",
    },
    {
        "school": "Golden Hill",
        "district": "Haverhill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597000296",
    },
    {
        "school": "Silver Hill Elementary School",
        "district": "Haverhill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597000299",
    },
    {
        "school": "Consentino Middle School",
        "district": "Haverhill",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597000850",
    },
    {
        "school": "Dr Paul Nettle",
        "district": "Haverhill",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597000852",
    },
    {
        "school": "Haverhill High",
        "district": "Haverhill",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597000856",
    },
    {
        "school": "John G Whittier",
        "district": "Haverhill",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597000857",
    },
    {
        "school": "Tilton",
        "district": "Haverhill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597000866",
    },
    {
        "school": "Walnut Square",
        "district": "Haverhill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597000867",
    },
    {
        "school": "Bradford Elementary",
        "district": "Haverhill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597001168",
    },
    {
        "school": "Pentucket Lake Elementary",
        "district": "Haverhill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597001169",
    },
    {
        "school": "Lawlor Early Childhood Center",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666000471",
    },
    {
        "school": "John Breen School",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666000730",
    },
    {
        "school": "Alexander B Bruce",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666000950",
    },
    {
        "school": "Emily G Wetherbee",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666000955",
    },
    {
        "school": "Francis M Leahy",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666000956",
    },
    {
        "school": "James F Hennessey",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666000958",
    },
    {
        "school": "Gerard A. Guilmette",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666001626",
    },
    {
        "school": "Edward F. Parthum",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666001627",
    },
    {
        "school": "Robert Frost",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002433",
    },
    {
        "school": "John K Tarbox",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002477",
    },
    {
        "school": "Marsh Grammar School",
        "district": "Methuen",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250774001211",
    },
    {
        "school": "Methuen High",
        "district": "Methuen",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250774001213",
    },
    {
        "school": "Donald P Timony Grammar",
        "district": "Methuen",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250774001376",
    },
    {
        "school": "Tenney Grammar School",
        "district": "Methuen",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250774001556",
    },
    {
        "school": "Comprehensive Grammar School",
        "district": "Methuen",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250774002558",
    },
    {
        "school": "Annie L Sargent School",
        "district": "North Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250870000767",
    },
    {
        "school": "Atkinson",
        "district": "North Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250870001393",
    },
    {
        "school": "Franklin",
        "district": "North Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250870001395",
    },
    {
        "school": "Kittredge",
        "district": "North Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250870001396",
    },
    {
        "school": "North Andover High",
        "district": "North Andover",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250870001397",
    },
    {
        "school": "North Andover Middle",
        "district": "North Andover",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250870001398",
    },
    {
        "school": "Thomson",
        "district": "North Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250870001399",
    },
    {
        "school": "Elmer S Bagnall",
        "district": "Pentucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250945000403",
    },
    {
        "school": "Helen R Donaghue School",
        "district": "Pentucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250945000406",
    },
    {
        "school": "Dr John C Page School",
        "district": "Pentucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250945000408",
    },
    {
        "school": "Dr Frederick N Sweetsir",
        "district": "Pentucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250945000414",
    },
    {
        "school": "Pentucket Regional Middle",
        "district": "Pentucket",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250945001512",
    },
    {
        "school": "Pentucket Regional Sr High",
        "district": "Pentucket",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250945001513",
    },
    {
        "school": "Whittier Regional Vocational",
        "district": "Whittier Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251295002300",
    },
    {
        "school": "Innovation Academy Charter School",
        "district": "Innovation Academy Charter (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250002500524",
    },
    {
        "school": "Lowell Middlesex Academy Charter School",
        "district": "Lowell Middlesex Academy Charter (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250003300555",
    },
    {
        "school": "Lowell Community Charter Public School",
        "district": "Lowell Community Charter Public (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250006501585",
    },
    {
        "school": "Billerica Memorial High School",
        "district": "Billerica",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250267000177",
    },
    {
        "school": "Frederick J Dutile",
        "district": "Billerica",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250267000179",
    },
    {
        "school": "Hajjar Elementary",
        "district": "Billerica",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250267000180",
    },
    {
        "school": "John F Kennedy",
        "district": "Billerica",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250267000181",
    },
    {
        "school": "Locke Middle",
        "district": "Billerica",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250267000182",
    },
    {
        "school": "Marshall Middle School",
        "district": "Billerica",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250267000183",
    },
    {
        "school": "Parker",
        "district": "Billerica",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250267000184",
    },
    {
        "school": "Thomas Ditson",
        "district": "Billerica",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250267000186",
    },
    {
        "school": "Byam School",
        "district": "Chelmsford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250351000472",
    },
    {
        "school": "Charles D Harrington",
        "district": "Chelmsford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250351000474",
    },
    {
        "school": "Chelmsford High",
        "district": "Chelmsford",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250351000475",
    },
    {
        "school": "Col Moses Parker School",
        "district": "Chelmsford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250351000476",
    },
    {
        "school": "McCarthy Middle School",
        "district": "Chelmsford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250351000478",
    },
    {
        "school": "South Row",
        "district": "Chelmsford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250351000480",
    },
    {
        "school": "Center Elementary School",
        "district": "Chelmsford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250351001300",
    },
    {
        "school": "Brookside Elementary",
        "district": "Dracut",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250432000578",
    },
    {
        "school": "Dracut Senior High",
        "district": "Dracut",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250432000579",
    },
    {
        "school": "Greenmont Avenue",
        "district": "Dracut",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250432000582",
    },
    {
        "school": "Joseph A Campbell Elementary",
        "district": "Dracut",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250432000583",
    },
    {
        "school": "Justus C. Richardson Middle School",
        "district": "Dracut",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250432001625",
    },
    {
        "school": "Gr Lowell Regional Vocational Technical",
        "district": "Greater Lowell Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250548002268",
    },
    {
        "school": "Groton Dunstable Regional Middle",
        "district": "Groton-Dunstable",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250550000805",
    },
    {
        "school": "Swallow/Union School",
        "district": "Groton-Dunstable",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250550000806",
    },
    {
        "school": "Groton Dunstable Regional",
        "district": "Groton-Dunstable",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250550000807",
    },
    {
        "school": "Florence Roche School",
        "district": "Groton-Dunstable",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250550000808",
    },
    {
        "school": "Boutwell School",
        "district": "Groton-Dunstable",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250550002611",
    },
    {
        "school": "Dr Gertrude Bailey",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702000067",
    },
    {
        "school": "Moody Elementary",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702000068",
    },
    {
        "school": "James Sullivan Middle School",
        "district": "Lowell",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702000073",
    },
    {
        "school": "Dr An Wang School",
        "district": "Lowell",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702000086",
    },
    {
        "school": "S Christa McAuliffe Elementary",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702000088",
    },
    {
        "school": "Charlotte M Murkland Elementary",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702000092",
    },
    {
        "school": "Joseph McAvinnue",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702000477",
    },
    {
        "school": "Abraham Lincoln",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001023",
    },
    {
        "school": "B.F. Butler Middle School",
        "district": "Lowell",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001026",
    },
    {
        "school": "Charles W Morey",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001029",
    },
    {
        "school": "Greenhalge",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001033",
    },
    {
        "school": "Henry J Robinson Middle",
        "district": "Lowell",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001034",
    },
    {
        "school": "James S Daley Middle School",
        "district": "Lowell",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001036",
    },
    {
        "school": "Pyne Arts",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001038",
    },
    {
        "school": "Lowell High",
        "district": "Lowell",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001041",
    },
    {
        "school": "Pawtucketville Memorial",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001044",
    },
    {
        "school": "Peter W Reilly",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001045",
    },
    {
        "school": "John J Shaughnessy",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001048",
    },
    {
        "school": "Washington",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702001051",
    },
    {
        "school": "Nashoba Valley Technical High School",
        "district": "Nashoba Valley Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250832001290",
    },
    {
        "school": "Shawsheen Valley Vocational Technical High School",
        "district": "Shawsheen Valley Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251061501701",
    },
    {
        "school": "John W. Wynn Middle",
        "district": "Tewksbury",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251158000366",
    },
    {
        "school": "John F. Ryan",
        "district": "Tewksbury",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251158001426",
    },
    {
        "school": "Heath-Brook",
        "district": "Tewksbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251158001921",
    },
    {
        "school": "L F Dewing",
        "district": "Tewksbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251158001922",
    },
    {
        "school": "North Street",
        "district": "Tewksbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251158001923",
    },
    {
        "school": "Louise Davy Trahan",
        "district": "Tewksbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251158001924",
    },
    {
        "school": "Tewksbury Memorial High",
        "district": "Tewksbury",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251158001926",
    },
    {
        "school": "Tyngsborough High School",
        "district": "Tyngsborough",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251176001934",
    },
    {
        "school": "Abbot Elementary",
        "district": "Westford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251266000163",
    },
    {
        "school": "Day Elementary",
        "district": "Westford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251266000166",
    },
    {
        "school": "Blanchard Middle",
        "district": "Westford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251266000170",
    },
    {
        "school": "Millennium Elementary",
        "district": "Westford",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251266001572",
    },
    {
        "school": "Col John Robinson",
        "district": "Westford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251266002077",
    },
    {
        "school": "Nabnasset",
        "district": "Westford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251266002078",
    },
    {
        "school": "Westford Academy",
        "district": "Westford",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251266002081",
    },
    {
        "school": "Sippican",
        "district": "Marion",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250729001127",
    },
    {
        "school": "Center",
        "district": "Mattapoisett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250747001148",
    },
    {
        "school": "Old Hammondtown",
        "district": "Mattapoisett",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250747001149",
    },
    {
        "school": "Old Colony Regional Vocational Technical",
        "district": "Old Colony Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250914001471",
    },
    {
        "school": "Old Rochester Regional High",
        "district": "Old Rochester",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250915001472",
    },
    {
        "school": "Old Rochester Regional Jr High",
        "district": "Old Rochester",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250915001473",
    },
    {
        "school": "Rochester Memorial",
        "district": "Rochester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251014001637",
    },
    {
        "school": "Four Rivers Charter Public School",
        "district": "Four Rivers Charter Public (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250007602086",
    },
    {
        "school": "Conway Grammar",
        "district": "Conway",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250390000528",
    },
    {
        "school": "Deerfield Elementary",
        "district": "Deerfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250408000049",
    },
    {
        "school": "Erving Elementary",
        "district": "Erving",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250471000626",
    },
    {
        "school": "Franklin County Technical",
        "district": "Franklin County Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250502000744",
    },
    {
        "school": "Frontier Regional",
        "district": "Frontier",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250510000749",
    },
    {
        "school": "Turners Fall High",
        "district": "Gill-Montague",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250527000768",
    },
    {
        "school": "Gill Elementary",
        "district": "Gill-Montague",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250527002382",
    },
    {
        "school": "Sheffield Elementary School",
        "district": "Gill-Montague",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250527002385",
    },
    {
        "school": "Great Falls Middle",
        "district": "Gill-Montague",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250527002386",
    },
    {
        "school": "Discovery School at Four Corners",
        "district": "Greenfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250549000798",
    },
    {
        "school": "Greenfield Middle",
        "district": "Greenfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250549000800",
    },
    {
        "school": "Greenfield High",
        "district": "Greenfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250549000801",
    },
    {
        "school": "Federal Street School",
        "district": "Greenfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250549002577",
    },
    {
        "school": "Newton School",
        "district": "Greenfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250549002578",
    },
    {
        "school": "Hawlemont Regional",
        "district": "Hawlemont",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250600000869",
    },
    {
        "school": "Leverett Elementary",
        "district": "Leverett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250681000992",
    },
    {
        "school": "Buckland-Shelburne Regional",
        "district": "Mohawk Trail",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250799000424",
    },
    {
        "school": "Colrain Central",
        "district": "Mohawk Trail",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250799000425",
    },
    {
        "school": "Mohawk Trail Regional School",
        "district": "Mohawk Trail",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250799001265",
    },
    {
        "school": "Sanderson Academy",
        "district": "Mohawk Trail",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250799001636",
    },
    {
        "school": "Swift River",
        "district": "New Salem-Wendell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250853001346",
    },
    {
        "school": "Dexter Park",
        "district": "Orange",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250918001475",
    },
    {
        "school": "Fisher Hill",
        "district": "Orange",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250918002593",
    },
    {
        "school": "Pioneer Valley Regional",
        "district": "Pioneer Valley",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250960001515",
    },
    {
        "school": "Bernardston Elementary",
        "district": "Pioneer Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250960002612",
    },
    {
        "school": "Northfield Elementary",
        "district": "Pioneer Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250960002614",
    },
    {
        "school": "Warwick Community School",
        "district": "Pioneer Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250960002615",
    },
    {
        "school": "Ralph C Mahar Regional",
        "district": "Ralph C Mahar",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250990001587",
    },
    {
        "school": "Rowe Elementary",
        "district": "Rowe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251023001649",
    },
    {
        "school": "Shutesbury Elementary",
        "district": "Shutesbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251080001720",
    },
    {
        "school": "Sunderland Elementary",
        "district": "Sunderland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251137001878",
    },
    {
        "school": "Whately Elementary",
        "district": "Whately",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251287002126",
    },
    {
        "school": "Sizer School: A North Central Charter Essential School",
        "district": "Sizer School: A North Central Charter Essential (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250007301750",
    },
    {
        "school": "Lincoln School",
        "district": "Leominster",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250678001947",
    },
    {
        "school": "Sky View Middle School",
        "district": "Leominster",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250678002045",
    },
    {
        "school": "Crocker Elementary",
        "district": "Fitchburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250489000696",
    },
    {
        "school": "Fitchburg High",
        "district": "Fitchburg",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250489000697",
    },
    {
        "school": "Reingold Elementary",
        "district": "Fitchburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250489000702",
    },
    {
        "school": "Memorial Middle School",
        "district": "Fitchburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250489001523",
    },
    {
        "school": "South Street Elementary",
        "district": "Fitchburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250489002469",
    },
    {
        "school": "Elm Street School",
        "district": "Gardner",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250513000750",
    },
    {
        "school": "Gardner High",
        "district": "Gardner",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250513000751",
    },
    {
        "school": "Waterford Street",
        "district": "Gardner",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250513000755",
    },
    {
        "school": "Gardner Middle School",
        "district": "Gardner",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250513002431",
    },
    {
        "school": "Bennett",
        "district": "Leominster",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250678000064",
    },
    {
        "school": "Samoset School",
        "district": "Leominster",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250678000742",
    },
    {
        "school": "Fall Brook",
        "district": "Leominster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250678000981",
    },
    {
        "school": "Johnny Appleseed",
        "district": "Leominster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250678000985",
    },
    {
        "school": "Leominster High School",
        "district": "Leominster",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250678000987",
    },
    {
        "school": "Northwest",
        "district": "Leominster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250678000988",
    },
    {
        "school": "Priest Street",
        "district": "Leominster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250678000990",
    },
    {
        "school": "Center For Technical Education Innovation",
        "district": "Leominster",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250678002272",
    },
    {
        "school": "Montachusett Regional Vocational Technical",
        "district": "Montachusett Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250805002279",
    },
    {
        "school": "James M. Quinn School",
        "district": "Dartmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250402002028",
    },
    {
        "school": "Martha's Vineyard Charter School",
        "district": "Martha's Vineyard Charter (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250003500569",
    },
    {
        "school": "Chilmark Elementary",
        "district": "Up-Island Regional",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250004300508",
    },
    {
        "school": "West Tisbury Elementary",
        "district": "Up-Island Regional",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250004301927",
    },
    {
        "school": "Oak Bluffs Elementary",
        "district": "Oak Bluffs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250465000625",
    },
    {
        "school": "Cuttyhunk Elementary",
        "district": "Gosnold",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250534000725",
    },
    {
        "school": "Martha's Vineyard Regional High",
        "district": "Martha's Vineyard",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250738001145",
    },
    {
        "school": "Edgartown Elementary",
        "district": "Edgartown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250909001469",
    },
    {
        "school": "Tisbury Elementary",
        "district": "Tisbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251257002054",
    },
    {
        "school": "Acushnet Elementary School",
        "district": "Acushnet",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250174000014",
    },
    {
        "school": "Albert F Ford Middle School",
        "district": "Acushnet",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250174000015",
    },
    {
        "school": "Dartmouth High",
        "district": "Dartmouth",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250402000540",
    },
    {
        "school": "Dartmouth Middle",
        "district": "Dartmouth",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250402000541",
    },
    {
        "school": "George H Potter",
        "district": "Dartmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250402000542",
    },
    {
        "school": "Joseph Demello",
        "district": "Dartmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250402000544",
    },
    {
        "school": "East Fairhaven",
        "district": "Fairhaven",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250480000640",
    },
    {
        "school": "Fairhaven High",
        "district": "Fairhaven",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250480000642",
    },
    {
        "school": "Leroy Wood",
        "district": "Fairhaven",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250480000645",
    },
    {
        "school": "Hastings Middle",
        "district": "Fairhaven",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250480002572",
    },
    {
        "school": "Abraham Lincoln",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001318",
    },
    {
        "school": "Betsey B Winslow",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001319",
    },
    {
        "school": "Casimir Pulaski",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001320",
    },
    {
        "school": "Charles S Ashley",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001321",
    },
    {
        "school": "Elizabeth Carter Brooks",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001322",
    },
    {
        "school": "Ellen R Hathaway",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001323",
    },
    {
        "school": "Elwyn G Campbell",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001324",
    },
    {
        "school": "Alfred J Gomes",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001326",
    },
    {
        "school": "Hayden/McFadden",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001327",
    },
    {
        "school": "James B Congdon",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001329",
    },
    {
        "school": "Jireh Swift",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001330",
    },
    {
        "school": "John Avery Parker",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001331",
    },
    {
        "school": "John B Devalles",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001332",
    },
    {
        "school": "Irwin M. Jacobs Elementary School",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001333",
    },
    {
        "school": "Keith Middle School",
        "district": "New Bedford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001334",
    },
    {
        "school": "Carlos Pacheco",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001335",
    },
    {
        "school": "New Bedford High",
        "district": "New Bedford",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001336",
    },
    {
        "school": "Normandin Middle School",
        "district": "New Bedford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001337",
    },
    {
        "school": "Roosevelt Middle School",
        "district": "New Bedford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001339",
    },
    {
        "school": "Sgt Wm H Carney Academy",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001341",
    },
    {
        "school": "Thomas R Rodman",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001342",
    },
    {
        "school": "William H Taylor",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843001343",
    },
    {
        "school": "Trinity Day Academy",
        "district": "New Bedford",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843002590",
    },
    {
        "school": "Gr New Bedford Vocational Technical",
        "district": "Greater New Bedford Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250844002266",
    },
    {
        "school": "Drury High",
        "district": "North Adams",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250867001387",
    },
    {
        "school": "Colegrove Park Elementary",
        "district": "North Adams",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250867001388",
    },
    {
        "school": "Greylock",
        "district": "North Adams",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250867001389",
    },
    {
        "school": "Brayton",
        "district": "North Adams",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250867001390",
    },
    {
        "school": "Charles McCann Vocational Technical",
        "district": "Northern Berkshire Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250895002282",
    },
    {
        "school": "Berkshire Arts and Technology Charter Public School",
        "district": "Berkshire Arts and Technology Charter Public (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250007901842",
    },
    {
        "school": "Muddy Brook Regional Elementary School",
        "district": "Berkshire Hills",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250253001999",
    },
    {
        "school": "Monument Valley Regional Middle School",
        "district": "Berkshire Hills",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250253002000",
    },
    {
        "school": "Hoosac Valley High School",
        "district": "Hoosac Valley Regional",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250178000021",
    },
    {
        "school": "Hoosac Valley Elementary School",
        "district": "Hoosac Valley Regional",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250178000023",
    },
    {
        "school": "Monument Mt Regional High",
        "district": "Berkshire Hills",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250253000154",
    },
    {
        "school": "Becket Washington School",
        "district": "Central Berkshire",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250339000459",
    },
    {
        "school": "Craneville",
        "district": "Central Berkshire",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250339000462",
    },
    {
        "school": "Kittredge",
        "district": "Central Berkshire",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250339000465",
    },
    {
        "school": "Nessacus Regional Middle School",
        "district": "Central Berkshire",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250339000466",
    },
    {
        "school": "Wahconah Regional High",
        "district": "Central Berkshire",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250339000467",
    },
    {
        "school": "Clarksburg Elementary",
        "district": "Clarksburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250372000510",
    },
    {
        "school": "Abbott Memorial",
        "district": "Florida",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250492000706",
    },
    {
        "school": "Hancock Elementary",
        "district": "Hancock",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250576000826",
    },
    {
        "school": "Lee Elementary",
        "district": "Lee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250669000969",
    },
    {
        "school": "Lee Middle/High School",
        "district": "Lee",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250669000970",
    },
    {
        "school": "Lenox Memorial High",
        "district": "Lenox",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250675000978",
    },
    {
        "school": "Morris",
        "district": "Lenox",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250675000979",
    },
    {
        "school": "Mt Greylock Regional High",
        "district": "Mount Greylock",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250816001273",
    },
    {
        "school": "Allendale",
        "district": "Pittsfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963001516",
    },
    {
        "school": "Egremont",
        "district": "Pittsfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963001519",
    },
    {
        "school": "Robert T. Capeless Elementary School",
        "district": "Pittsfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963001522",
    },
    {
        "school": "Morningside Community School",
        "district": "Pittsfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963001524",
    },
    {
        "school": "John T Reid Middle",
        "district": "Pittsfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963001525",
    },
    {
        "school": "Pittsfield High",
        "district": "Pittsfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963001526",
    },
    {
        "school": "Crosby",
        "district": "Pittsfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963001528",
    },
    {
        "school": "Theodore Herberg Middle",
        "district": "Pittsfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963001532",
    },
    {
        "school": "Taconic High",
        "district": "Pittsfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963001534",
    },
    {
        "school": "Silvio O Conte Community",
        "district": "Pittsfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963001535",
    },
    {
        "school": "Williams",
        "district": "Pittsfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963001536",
    },
    {
        "school": "Stearns",
        "district": "Pittsfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250963002489",
    },
    {
        "school": "Richmond Consolidated",
        "district": "Richmond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251008001635",
    },
    {
        "school": "Emma L Miller Elementary School",
        "district": "Savoy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251053001688",
    },
    {
        "school": "Undermountain",
        "district": "Southern Berkshire",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251104000428",
    },
    {
        "school": "Mt Everett Regional",
        "district": "Southern Berkshire",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251104001774",
    },
    {
        "school": "New Marlborough Central",
        "district": "Southern Berkshire",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251104001775",
    },
    {
        "school": "South Egremont",
        "district": "Southern Berkshire",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251104001778",
    },
    {
        "school": "Farmington River Elementary",
        "district": "Farmington River Reg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251332100402",
    },
    {
        "school": "North End Elementary",
        "district": "Fall River",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483001780",
    },
    {
        "school": "Bellingham Memorial School",
        "district": "Bellingham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250246001683",
    },
    {
        "school": "Atlantis Charter School",
        "district": "Atlantis Charter (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250004100601",
    },
    {
        "school": "Attleboro High",
        "district": "Attleboro",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250219000084",
    },
    {
        "school": "Cyril K. Brennan Middle School",
        "district": "Attleboro",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250219000087",
    },
    {
        "school": "Hill-Roberts Elementary School",
        "district": "Attleboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250219000089",
    },
    {
        "school": "Hyman Fine Elementary School",
        "district": "Attleboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250219000090",
    },
    {
        "school": "Robert J. Coelho Middle School",
        "district": "Attleboro",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250219000096",
    },
    {
        "school": "A. Irvin Studley Elementary School",
        "district": "Attleboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250219000097",
    },
    {
        "school": "Thomas Willett Elementary School",
        "district": "Attleboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250219000098",
    },
    {
        "school": "Wamsutta Middle School",
        "district": "Attleboro",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250219000945",
    },
    {
        "school": "Peter Thacher Elementary School",
        "district": "Attleboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250219001294",
    },
    {
        "school": "Early Learning Center",
        "district": "Attleboro",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250219001610",
    },
    {
        "school": "B M C Durfee High",
        "district": "Fall River",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483000649",
    },
    {
        "school": "Talbot Innovation School",
        "district": "Fall River",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483000655",
    },
    {
        "school": "James Tansey",
        "district": "Fall River",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483000665",
    },
    {
        "school": "John J Doran",
        "district": "Fall River",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483000666",
    },
    {
        "school": "Matthew J Kuss Middle",
        "district": "Fall River",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483000671",
    },
    {
        "school": "Morton Middle",
        "district": "Fall River",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483000672",
    },
    {
        "school": "Samuel Watson",
        "district": "Fall River",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483000677",
    },
    {
        "school": "Spencer Borden",
        "district": "Fall River",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483000679",
    },
    {
        "school": "William S Greene",
        "district": "Fall River",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483000684",
    },
    {
        "school": "Diman Regional Vocational Technical High",
        "district": "Greater Fall River Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250548502269",
    },
    {
        "school": "Community",
        "district": "North Attleborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250873001199",
    },
    {
        "school": "North Attleborough Middle",
        "district": "North Attleborough",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250873001207",
    },
    {
        "school": "Amvet Boulevard",
        "district": "North Attleborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250873001401",
    },
    {
        "school": "Falls",
        "district": "North Attleborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250873001402",
    },
    {
        "school": "Joseph W Martin Jr Elementary",
        "district": "North Attleborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250873001404",
    },
    {
        "school": "North Attleboro High",
        "district": "North Attleborough",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250873001405",
    },
    {
        "school": "Roosevelt Avenue",
        "district": "North Attleborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250873001408",
    },
    {
        "school": "North Attleborough Early Learning Center",
        "district": "North Attleborough",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250873001409",
    },
    {
        "school": "George R Martin",
        "district": "Seekonk",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251059001695",
    },
    {
        "school": "Mildred Aitken School",
        "district": "Seekonk",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251059001696",
    },
    {
        "school": "Seekonk High",
        "district": "Seekonk",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251059001699",
    },
    {
        "school": "Dr. Kevin M. Hurley Middle School",
        "district": "Seekonk",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251059001700",
    },
    {
        "school": "Chace Street",
        "district": "Somerset",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251086001723",
    },
    {
        "school": "South",
        "district": "Somerset",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251086001727",
    },
    {
        "school": "North Elementary",
        "district": "Somerset",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251086002536",
    },
    {
        "school": "Somerset Middle School",
        "district": "Somerset",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251086002537",
    },
    {
        "school": "Mark G Hoyle Elementary",
        "district": "Swansea",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251146000129",
    },
    {
        "school": "Elizabeth S Brown",
        "district": "Swansea",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251146001890",
    },
    {
        "school": "Gardner",
        "district": "Swansea",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251146001892",
    },
    {
        "school": "Joseph Case High",
        "district": "Swansea",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251146001893",
    },
    {
        "school": "Joseph Case Jr High",
        "district": "Swansea",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251146001894",
    },
    {
        "school": "Joseph G Luther",
        "district": "Swansea",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251146001895",
    },
    {
        "school": "Alice A Macomber",
        "district": "Westport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251278002090",
    },
    {
        "school": "Westport Elementary",
        "district": "Westport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251278002092",
    },
    {
        "school": "Bellingham High School",
        "district": "Bellingham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250246000139",
    },
    {
        "school": "Stall Brook",
        "district": "Bellingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250246000141",
    },
    {
        "school": "Joseph F DiPietro Elementary School",
        "district": "Bellingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250246000142",
    },
    {
        "school": "Bellingham Early Childhood Center",
        "district": "Bellingham",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250246000670",
    },
    {
        "school": "Keough Memorial Academy",
        "district": "Bellingham",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250246002543",
    },
    {
        "school": "Holyoke Community Charter School",
        "district": "Holyoke Community Charter (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250008701997",
    },
    {
        "school": "Chestnut Hill Community School",
        "district": "Belchertown",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250243001871",
    },
    {
        "school": "Jabish Middle School",
        "district": "Belchertown",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250243001873",
    },
    {
        "school": "Southwick Regional School",
        "district": "Southwick-Tolland-Granville Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250001301782",
    },
    {
        "school": "Woodland School",
        "district": "Southwick-Tolland-Granville Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250001301783",
    },
    {
        "school": "Sabis International Charter School",
        "district": "Sabis International Charter (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250002800537",
    },
    {
        "school": "Barry",
        "district": "Chicopee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000489",
    },
    {
        "school": "Belcher",
        "district": "Chicopee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000490",
    },
    {
        "school": "Bellamy Middle",
        "district": "Chicopee",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000491",
    },
    {
        "school": "Bowe",
        "district": "Chicopee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000492",
    },
    {
        "school": "Bowie",
        "district": "Chicopee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000493",
    },
    {
        "school": "Chicopee Comprehensive High School",
        "district": "Chicopee",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000495",
    },
    {
        "school": "Chicopee High",
        "district": "Chicopee",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000496",
    },
    {
        "school": "Gen John J Stefanik",
        "district": "Chicopee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000500",
    },
    {
        "school": "Lambert-Lavoie",
        "district": "Chicopee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000501",
    },
    {
        "school": "Litwin",
        "district": "Chicopee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000502",
    },
    {
        "school": "Streiber Memorial School",
        "district": "Chicopee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000504",
    },
    {
        "school": "Chicopee Academy",
        "district": "Chicopee",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250366000720",
    },
    {
        "school": "Dupont Middle",
        "district": "Chicopee",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366000722",
    },
    {
        "school": "Fairview Elementary",
        "district": "Chicopee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366002463",
    },
    {
        "school": "Szetela Early Childhood Center",
        "district": "Chicopee",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250366002571",
    },
    {
        "school": "Birchland Park",
        "district": "East Longmeadow",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250450000602",
    },
    {
        "school": "East Longmeadow High",
        "district": "East Longmeadow",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250450000603",
    },
    {
        "school": "Mapleshade",
        "district": "East Longmeadow",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250450000604",
    },
    {
        "school": "Meadow Brook",
        "district": "East Longmeadow",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250450000605",
    },
    {
        "school": "Mountain View",
        "district": "East Longmeadow",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250450000606",
    },
    {
        "school": "Chester Elementary",
        "district": "Gateway",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250516000757",
    },
    {
        "school": "Green Meadows Elementary",
        "district": "Hampden-Wilbraham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250573000822",
    },
    {
        "school": "Minnechaug Regional High",
        "district": "Hampden-Wilbraham",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250573000824",
    },
    {
        "school": "Stony Hill School",
        "district": "Hampden-Wilbraham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250573001464",
    },
    {
        "school": "Mile Tree Elementary",
        "district": "Hampden-Wilbraham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250573001598",
    },
    {
        "school": "Soule Road",
        "district": "Hampden-Wilbraham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250573002139",
    },
    {
        "school": "Wilbraham Middle",
        "district": "Hampden-Wilbraham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250573002141",
    },
    {
        "school": "Holyoke High",
        "district": "Holyoke",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627000900",
    },
    {
        "school": "Kelly Elementary",
        "district": "Holyoke",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627000904",
    },
    {
        "school": "Lt Clayre Sullivan Elementary",
        "district": "Holyoke",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627000907",
    },
    {
        "school": "Lt Elmer J McMahon Elementary",
        "district": "Holyoke",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627000908",
    },
    {
        "school": "Maurice A Donahue Elementary",
        "district": "Holyoke",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627000909",
    },
    {
        "school": "Morgan Full Service Community School",
        "district": "Holyoke",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627000910",
    },
    {
        "school": "Joseph Metcalf School",
        "district": "Holyoke",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627001178",
    },
    {
        "school": "E N White Elementary",
        "district": "Holyoke",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627002581",
    },
    {
        "school": "Williams Middle",
        "district": "Longmeadow",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250699000743",
    },
    {
        "school": "Blueberry Hill",
        "district": "Longmeadow",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250699001016",
    },
    {
        "school": "Center",
        "district": "Longmeadow",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250699001017",
    },
    {
        "school": "Glenbrook Middle",
        "district": "Longmeadow",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250699001019",
    },
    {
        "school": "Longmeadow High",
        "district": "Longmeadow",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250699001020",
    },
    {
        "school": "Wolf Swamp Road",
        "district": "Longmeadow",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250699001022",
    },
    {
        "school": "Paul R Baird Middle",
        "district": "Ludlow",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250705001055",
    },
    {
        "school": "Ludlow Senior High",
        "district": "Ludlow",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250705001056",
    },
    {
        "school": "Veterans Park Elementary",
        "district": "Ludlow",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250705001057",
    },
    {
        "school": "Monson High School",
        "district": "Monson",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250804001269",
    },
    {
        "school": "Palmer High",
        "district": "Palmer",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250930001485",
    },
    {
        "school": "Old Mill Pond",
        "district": "Palmer",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250930002594",
    },
    {
        "school": "Pathfinder Vocational Technical",
        "district": "Pathfinder Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250931002285",
    },
    {
        "school": "Rebecca M Johnson",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113000341",
    },
    {
        "school": "Milton Bradley School",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113000896",
    },
    {
        "school": "Springfield High School of Science and Technology",
        "district": "Springfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113000901",
    },
    {
        "school": "Glickman Elementary",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001562",
    },
    {
        "school": "Alice B Beal Elementary",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001792",
    },
    {
        "school": "Edward P. Boland School",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001794",
    },
    {
        "school": "Arthur T Talmadge",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001795",
    },
    {
        "school": "Brightwood",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001796",
    },
    {
        "school": "Daniel B Brunton",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001799",
    },
    {
        "school": "Elias Brookings",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001801",
    },
    {
        "school": "Frank H Freedman",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001803",
    },
    {
        "school": "Frederick Harris",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001804",
    },
    {
        "school": "Glenwood",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001805",
    },
    {
        "school": "High School Of Commerce",
        "district": "Springfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001806",
    },
    {
        "school": "Hiram L Dorman",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001807",
    },
    {
        "school": "Homer Street",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001808",
    },
    {
        "school": "Alfred G. Zanetti Montessori Magnet School",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001809",
    },
    {
        "school": "Indian Orchard Elementary",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001810",
    },
    {
        "school": "Kensington International School",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001813",
    },
    {
        "school": "Liberty",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001814",
    },
    {
        "school": "Lincoln",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001815",
    },
    {
        "school": "Margaret C Ells",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001817",
    },
    {
        "school": "Mary M Lynch",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001818",
    },
    {
        "school": "Mary O Pottenger",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001819",
    },
    {
        "school": "Mary A. Dryden Veterans Memorial School",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001820",
    },
    {
        "school": "German Gerena Community School",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001822",
    },
    {
        "school": "Samuel Bowles",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001826",
    },
    {
        "school": "Mary M Walsh",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001829",
    },
    {
        "school": "Sumner Avenue",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001830",
    },
    {
        "school": "Thomas M Balliet",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001833",
    },
    {
        "school": "Warner",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001835",
    },
    {
        "school": "Washington",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001836",
    },
    {
        "school": "White Street",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001837",
    },
    {
        "school": "William N. DeBerry",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113001838",
    },
    {
        "school": "Roger L. Putnam Vocational Technical Academy",
        "district": "Springfield",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251113002293",
    },
    {
        "school": "Springfield Central High",
        "district": "Springfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002444",
    },
    {
        "school": "John J Duggan Middle",
        "district": "Springfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002599",
    },
    {
        "school": "Forest Park Middle",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002600",
    },
    {
        "school": "John F Kennedy Middle",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002601",
    },
    {
        "school": "M Marcus Kiley Middle",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002602",
    },
    {
        "school": "Philip G Coburn",
        "district": "West Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251251001242",
    },
    {
        "school": "West Springfield Middle",
        "district": "West Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251251001243",
    },
    {
        "school": "John R Fausey",
        "district": "West Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251251002044",
    },
    {
        "school": "Memorial",
        "district": "West Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251251002047",
    },
    {
        "school": "Mittineague",
        "district": "West Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251251002048",
    },
    {
        "school": "Tatham",
        "district": "West Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251251002050",
    },
    {
        "school": "West Springfield High",
        "district": "West Springfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251251002052",
    },
    {
        "school": "John Ashley",
        "district": "West Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251251002504",
    },
    {
        "school": "Westfield Middle School",
        "district": "Westfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251263001570",
    },
    {
        "school": "Abner Gibbs",
        "district": "Westfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251263002061",
    },
    {
        "school": "Franklin Ave",
        "district": "Westfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251263002064",
    },
    {
        "school": "Highland",
        "district": "Westfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251263002065",
    },
    {
        "school": "Southampton Road",
        "district": "Westfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251263002071",
    },
    {
        "school": "Westfield High",
        "district": "Westfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251263002073",
    },
    {
        "school": "Westfield Technical Academy",
        "district": "Westfield",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251263002074",
    },
    {
        "school": "Fort Meadow Early Childhood Center",
        "district": "Westfield",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251263002452",
    },
    {
        "school": "Munger Hill",
        "district": "Westfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251263002605",
    },
    {
        "school": "Paper Mill",
        "district": "Westfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251263002606",
    },
    {
        "school": "New Hingham Regional Elementary",
        "district": "Chesterfield-Goshen",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250001401275",
    },
    {
        "school": "Hilltown Cooperative Charter Public School",
        "district": "Hilltown Cooperative Charter Public (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250003100549",
    },
    {
        "school": "Pioneer Valley Performing Arts Charter Public School",
        "district": "Pioneer Valley Performing Arts Charter Public (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250004400816",
    },
    {
        "school": "Belchertown High",
        "district": "Belchertown",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250243000134",
    },
    {
        "school": "Cold Spring",
        "district": "Belchertown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250243000136",
    },
    {
        "school": "Swift River Elementary",
        "district": "Belchertown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250243000836",
    },
    {
        "school": "Center School",
        "district": "Easthampton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250459000611",
    },
    {
        "school": "Easthampton High",
        "district": "Easthampton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250459000612",
    },
    {
        "school": "Maple",
        "district": "Easthampton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250459000613",
    },
    {
        "school": "White Brook Middle School",
        "district": "Easthampton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250459000616",
    },
    {
        "school": "Neil A Pepin",
        "district": "Easthampton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250459002466",
    },
    {
        "school": "Gateway Regional High",
        "district": "Gateway",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250516000758",
    },
    {
        "school": "Littleville Elementary School",
        "district": "Gateway",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250516000761",
    },
    {
        "school": "East Meadow",
        "district": "Granby",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250540000789",
    },
    {
        "school": "Granby Jr Sr High School",
        "district": "Granby",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250540000790",
    },
    {
        "school": "Hopkins Academy",
        "district": "Hadley",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250558000813",
    },
    {
        "school": "Hadley Elementary",
        "district": "Hadley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250558000879",
    },
    {
        "school": "Hampshire Regional High",
        "district": "Hampshire",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250574000825",
    },
    {
        "school": "Hatfield Elementary",
        "district": "Hatfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250594000843",
    },
    {
        "school": "Smith Academy",
        "district": "Hatfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250594000845",
    },
    {
        "school": "Bridge Street",
        "district": "Northampton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250885001425",
    },
    {
        "school": "Jackson Street",
        "district": "Northampton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250885001429",
    },
    {
        "school": "John F Kennedy Middle School",
        "district": "Northampton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250885001430",
    },
    {
        "school": "Leeds",
        "district": "Northampton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250885001431",
    },
    {
        "school": "Northampton High",
        "district": "Northampton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250885001432",
    },
    {
        "school": "R. K. Finn Ryan Road",
        "district": "Northampton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250885001433",
    },
    {
        "school": "Smith Vocational and Agricultural High",
        "district": "Northampton-Smith Vocational Agricultural",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250886002314",
    },
    {
        "school": "Pelham Elementary",
        "district": "Pelham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250939001507",
    },
    {
        "school": "Michael E. Smith Middle School",
        "district": "South Hadley",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251092001752",
    },
    {
        "school": "Plains Elementary",
        "district": "South Hadley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251092001753",
    },
    {
        "school": "South Hadley High",
        "district": "South Hadley",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251092001754",
    },
    {
        "school": "Mosier",
        "district": "South Hadley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251092002406",
    },
    {
        "school": "William E Norris",
        "district": "Southampton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251095001758",
    },
    {
        "school": "Stanley M Koziol Elementary School",
        "district": "Ware",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251203001982",
    },
    {
        "school": "Ware Junior/Senior High School",
        "district": "Ware",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251203001983",
    },
    {
        "school": "Ware Middle School",
        "district": "Ware",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251203002538",
    },
    {
        "school": "Westhampton Elementary School",
        "district": "Westhampton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251269002083",
    },
    {
        "school": "Agawam High",
        "district": "Agawam",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250180000024",
    },
    {
        "school": "Agawam Junior High",
        "district": "Agawam",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250180000025",
    },
    {
        "school": "Roberta G. Doering School",
        "district": "Agawam",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250180000026",
    },
    {
        "school": "Benjamin J Phelps",
        "district": "Agawam",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250180000027",
    },
    {
        "school": "Clifford M Granger",
        "district": "Agawam",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250180000028",
    },
    {
        "school": "James Clark School",
        "district": "Agawam",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250180000030",
    },
    {
        "school": "Robinson Park",
        "district": "Agawam",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250180000032",
    },
    {
        "school": "Agawam Early Childhood Center",
        "district": "Agawam",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250180001499",
    },
    {
        "school": "Brimfield Elementary",
        "district": "Brimfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250306000381",
    },
    {
        "school": "Holland Elementary",
        "district": "Holland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250621000889",
    },
    {
        "school": "Wales Elementary",
        "district": "Wales",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251194001956",
    },
    {
        "school": "Quabbin Regional Middle School",
        "district": "Quabbin",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250000102003",
    },
    {
        "school": "East Brookfield Elementary",
        "district": "Spencer-E Brookfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250000201766",
    },
    {
        "school": "Wire Village School",
        "district": "Spencer-E Brookfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250000201859",
    },
    {
        "school": "Park Street School",
        "district": "Hopedale",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250630002041",
    },
    {
        "school": "Lunenburg Primary School",
        "district": "Lunenburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250708001957",
    },
    {
        "school": "Oak Middle School",
        "district": "Shrewsbury",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251077001825",
    },
    {
        "school": "Albert S. Woodward Memorial School",
        "district": "Southborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251098001827",
    },
    {
        "school": "Mill Pond School",
        "district": "Westborough",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251260001734",
    },
    {
        "school": "Center School",
        "district": "Nashoba",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250831000362",
    },
    {
        "school": "Hale",
        "district": "Nashoba",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250831001868",
    },
    {
        "school": "Blackstone Valley",
        "district": "Blackstone Valley Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250271000191",
    },
    {
        "school": "Millville Elementary",
        "district": "Blackstone-Millville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250271500185",
    },
    {
        "school": "Blackstone Millville RHS",
        "district": "Blackstone-Millville",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250271500192",
    },
    {
        "school": "A F Maloney",
        "district": "Blackstone-Millville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250271501078",
    },
    {
        "school": "Frederick W. Hartnett Middle School",
        "district": "Blackstone-Millville",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250271501082",
    },
    {
        "school": "John F Kennedy Elementary",
        "district": "Blackstone-Millville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250271502372",
    },
    {
        "school": "Brookfield Elementary",
        "district": "Brookfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250312000413",
    },
    {
        "school": "Bromfield",
        "district": "Harvard",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250588000838",
    },
    {
        "school": "Hildreth Elementary School",
        "district": "Harvard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250588000839",
    },
    {
        "school": "Hopedale Jr Sr High",
        "district": "Hopedale",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250630000915",
    },
    {
        "school": "Memorial",
        "district": "Hopedale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250630000916",
    },
    {
        "school": "Henry P Clough",
        "district": "Mendon-Upton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250768001200",
    },
    {
        "school": "Nipmuc Regional High",
        "district": "Mendon-Upton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250768001202",
    },
    {
        "school": "Memorial School",
        "district": "Mendon-Upton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250768001277",
    },
    {
        "school": "Miscoe Hill School",
        "district": "Mendon-Upton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250768001279",
    },
    {
        "school": "Luther Burbank Middle School",
        "district": "Nashoba",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250831000947",
    },
    {
        "school": "Mary Rowlandson Elementary",
        "district": "Nashoba",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250831000948",
    },
    {
        "school": "Florence Sawyer School",
        "district": "Nashoba",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250831001102",
    },
    {
        "school": "Nashoba Regional",
        "district": "Nashoba",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250831001289",
    },
    {
        "school": "Petersham Center",
        "district": "Petersham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250954001514",
    },
    {
        "school": "Burgess Elementary",
        "district": "Sturbridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251131001870",
    },
    {
        "school": "Dawson",
        "district": "Wachusett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188000884",
    },
    {
        "school": "Mountview Middle",
        "district": "Wachusett",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188000888",
    },
    {
        "school": "Central Tree Middle",
        "district": "Wachusett",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188001280",
    },
    {
        "school": "Houghton Elementary",
        "district": "Wachusett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188001476",
    },
    {
        "school": "Leroy E.Mayo",
        "district": "Wachusett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188001488",
    },
    {
        "school": "Paxton Center",
        "district": "Wachusett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188001492",
    },
    {
        "school": "Chocksett Middle School",
        "district": "Wachusett",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188001494",
    },
    {
        "school": "Thomas Prince",
        "district": "Wachusett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188001553",
    },
    {
        "school": "Davis Hill Elementary",
        "district": "Wachusett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188001607",
    },
    {
        "school": "Wachusett Regional High",
        "district": "Wachusett",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188001940",
    },
    {
        "school": "Warren Elementary",
        "district": "Quaboag Regional",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251210001993",
    },
    {
        "school": "Quaboag Regional High",
        "district": "Quaboag Regional",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251210001994",
    },
    {
        "school": "West Brookfield Elementary",
        "district": "Quaboag Regional",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251210002040",
    },
    {
        "school": "Oakmont Regional High School",
        "district": "Ashburnham-Westminster",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250204000069",
    },
    {
        "school": "Meetinghouse School",
        "district": "Ashburnham-Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250204000397",
    },
    {
        "school": "Overlook Middle School",
        "district": "Ashburnham-Westminster",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250204000831",
    },
    {
        "school": "Westminster Elementary",
        "district": "Ashburnham-Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250204002367",
    },
    {
        "school": "Briggs Elementary",
        "district": "Ashburnham-Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250204002368",
    },
    {
        "school": "Lunenburg High",
        "district": "Lunenburg",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250708001058",
    },
    {
        "school": "Narragansett Regional High",
        "district": "Narragansett",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250828001285",
    },
    {
        "school": "Phillipston Memorial",
        "district": "Narragansett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250828001287",
    },
    {
        "school": "Templeton Elementary School",
        "district": "Narragansett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250828001288",
    },
    {
        "school": "Narragansett Middle",
        "district": "Narragansett",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250828001467",
    },
    {
        "school": "Toy Town Elementary",
        "district": "Winchendon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251308000804",
    },
    {
        "school": "Memorial",
        "district": "Winchendon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251308002161",
    },
    {
        "school": "Quabbin Regional High School",
        "district": "Quabbin",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250000101558",
    },
    {
        "school": "Hardwick Elementary",
        "district": "Quabbin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250000102398",
    },
    {
        "school": "Hubbardston Center",
        "district": "Quabbin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250000102399",
    },
    {
        "school": "New Braintree Grade",
        "district": "Quabbin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250000102401",
    },
    {
        "school": "Oakham Center",
        "district": "Quabbin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250000102402",
    },
    {
        "school": "Ruggles Lane",
        "district": "Quabbin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250000102403",
    },
    {
        "school": "Knox Trail Middle School",
        "district": "Spencer-E Brookfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250000200639",
    },
    {
        "school": "David Prouty High",
        "district": "Spencer-E Brookfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250000201790",
    },
    {
        "school": "Ma Academy for Math and Science School",
        "district": "Ma Academy for Math and Science",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250003600576",
    },
    {
        "school": "Seven Hills Charter School",
        "district": "Seven Hills Charter Public (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250004500817",
    },
    {
        "school": "Abby Kelley Foster Charter Public School",
        "district": "Abby Kelley Foster Charter Public (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250005101247",
    },
    {
        "school": "Auburn Senior High",
        "district": "Auburn",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250222000100",
    },
    {
        "school": "Bryn Mawr",
        "district": "Auburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250222000101",
    },
    {
        "school": "Pakachoag School",
        "district": "Auburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250222000103",
    },
    {
        "school": "Auburn Middle",
        "district": "Auburn",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250222002567",
    },
    {
        "school": "Tahanto Regional High",
        "district": "Berlin-Boylston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250258000160",
    },
    {
        "school": "Clinton Middle School",
        "district": "Clinton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250375000512",
    },
    {
        "school": "Clinton Senior High",
        "district": "Clinton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250375000513",
    },
    {
        "school": "Clinton Elementary",
        "district": "Clinton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250375002379",
    },
    {
        "school": "Douglas High School",
        "district": "Douglas",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250423000570",
    },
    {
        "school": "Charlton Elementary",
        "district": "Dudley-Charlton Reg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250436000585",
    },
    {
        "school": "Dudley Elementary",
        "district": "Dudley-Charlton Reg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250436000588",
    },
    {
        "school": "Mason Road School",
        "district": "Dudley-Charlton Reg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250436000590",
    },
    {
        "school": "Shepherd Hill Regional High",
        "district": "Dudley-Charlton Reg",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250436000591",
    },
    {
        "school": "Dudley Middle School",
        "district": "Dudley-Charlton Reg",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250436001595",
    },
    {
        "school": "Charlton Middle School",
        "district": "Dudley-Charlton Reg",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250436001597",
    },
    {
        "school": "Heritage School",
        "district": "Dudley-Charlton Reg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250436002518",
    },
    {
        "school": "Grafton High School",
        "district": "Grafton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250537000786",
    },
    {
        "school": "North Grafton Elementary",
        "district": "Grafton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250537000787",
    },
    {
        "school": "South Grafton Elementary",
        "district": "Grafton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250537000788",
    },
    {
        "school": "Grafton Middle",
        "district": "Grafton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250537002520",
    },
    {
        "school": "Millbury Street Elementary School",
        "district": "Grafton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250537002576",
    },
    {
        "school": "Leicester Elementary",
        "district": "Leicester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250672000971",
    },
    {
        "school": "Leicester High",
        "district": "Leicester",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250672000972",
    },
    {
        "school": "Leicester Middle",
        "district": "Leicester",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250672000973",
    },
    {
        "school": "Elmwood Street",
        "district": "Millbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250789001248",
    },
    {
        "school": "Millbury Junior/Senior High",
        "district": "Millbury",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250789001249",
    },
    {
        "school": "Raymond E. Shaw Elementary",
        "district": "Millbury",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250789001251",
    },
    {
        "school": "North Brookfield Elementary",
        "district": "North Brookfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250876001410",
    },
    {
        "school": "North Brookfield High",
        "district": "North Brookfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250876001411",
    },
    {
        "school": "Marion E Zeh",
        "district": "Northborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250888001208",
    },
    {
        "school": "Fannie E Proctor",
        "district": "Northborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250888001436",
    },
    {
        "school": "Lincoln Street",
        "district": "Northborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250888001437",
    },
    {
        "school": "Marguerite E Peaslee",
        "district": "Northborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250888001438",
    },
    {
        "school": "Robert E. Melican Middle School",
        "district": "Northborough",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250888001440",
    },
    {
        "school": "Algonquin Regional High",
        "district": "Northboro-Southboro",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250891001441",
    },
    {
        "school": "Northbridge High",
        "district": "Northbridge",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250894001445",
    },
    {
        "school": "W Edward Balmer",
        "district": "Northbridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250894001447",
    },
    {
        "school": "Northbridge Middle",
        "district": "Northbridge",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250894002591",
    },
    {
        "school": "Alfred M Chaffee",
        "district": "Oxford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250927001479",
    },
    {
        "school": "Clara Barton",
        "district": "Oxford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250927001481",
    },
    {
        "school": "Oxford High",
        "district": "Oxford",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250927001482",
    },
    {
        "school": "Oxford Middle",
        "district": "Oxford",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250927001483",
    },
    {
        "school": "Floral Street School",
        "district": "Shrewsbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251077001047",
    },
    {
        "school": "Parker Road Preschool",
        "district": "Shrewsbury",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251077001559",
    },
    {
        "school": "Calvin Coolidge",
        "district": "Shrewsbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251077001713",
    },
    {
        "school": "Sherwood Middle School",
        "district": "Shrewsbury",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251077001716",
    },
    {
        "school": "Shrewsbury Sr High",
        "district": "Shrewsbury",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251077001717",
    },
    {
        "school": "Spring Street",
        "district": "Shrewsbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251077001718",
    },
    {
        "school": "Walter J Paton",
        "district": "Shrewsbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251077001719",
    },
    {
        "school": "Beal School",
        "district": "Shrewsbury",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251077002496",
    },
    {
        "school": "P Brent Trottier",
        "district": "Southborough",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251098001221",
    },
    {
        "school": "Margaret A Neary",
        "district": "Southborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251098001760",
    },
    {
        "school": "Mary E Finn School",
        "district": "Southborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251098001761",
    },
    {
        "school": "Charlton Street",
        "district": "Southbridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251101001763",
    },
    {
        "school": "Eastford Road",
        "district": "Southbridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251101001764",
    },
    {
        "school": "West Street",
        "district": "Southbridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251101001770",
    },
    {
        "school": "Bay Path Regional Vocational Technical High School",
        "district": "Southern Worcester County Regional Vocational Technical",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251105001779",
    },
    {
        "school": "Sutton Middle School",
        "district": "Sutton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251140001413",
    },
    {
        "school": "Sutton High School",
        "district": "Sutton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251140001414",
    },
    {
        "school": "Sutton Early Learning",
        "district": "Sutton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251140001661",
    },
    {
        "school": "Sutton Elementary",
        "district": "Sutton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251140001879",
    },
    {
        "school": "Tantasqua Regional Jr High",
        "district": "Tantasqua",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251149001899",
    },
    {
        "school": "Tantasqua Regional Sr High",
        "district": "Tantasqua",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251149001900",
    },
    {
        "school": "Tantasqua Regional Vocational",
        "district": "Tantasqua",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251149001901",
    },
    {
        "school": "Taft Early Learning Center",
        "district": "Uxbridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251185001936",
    },
    {
        "school": "Uxbridge High",
        "district": "Uxbridge",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251185001938",
    },
    {
        "school": "Bartlett High School",
        "district": "Webster",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251224002012",
    },
    {
        "school": "Park Avenue Elementary",
        "district": "Webster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251224002018",
    },
    {
        "school": "Major Edwards Elementary",
        "district": "West Boylston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251239002034",
    },
    {
        "school": "West Boylston Junior/Senior High",
        "district": "West Boylston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251239002035",
    },
    {
        "school": "Annie E Fales",
        "district": "Westborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251260002055",
    },
    {
        "school": "J Harding Armstrong",
        "district": "Westborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251260002056",
    },
    {
        "school": "Elsie A Hastings Elementary",
        "district": "Westborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251260002058",
    },
    {
        "school": "Westborough High",
        "district": "Westborough",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251260002059",
    },
    {
        "school": "Sarah W Gibbons Middle",
        "district": "Westborough",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251260002604",
    },
    {
        "school": "University Pk Campus School",
        "district": "Worcester",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323001076",
    },
    {
        "school": "Belmont Street Community",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002197",
    },
    {
        "school": "Burncoat Senior High",
        "district": "Worcester",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002200",
    },
    {
        "school": "Burncoat Street",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002201",
    },
    {
        "school": "Burncoat Middle School",
        "district": "Worcester",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002202",
    },
    {
        "school": "Canterbury",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002203",
    },
    {
        "school": "Chandler Elementary Community",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002204",
    },
    {
        "school": "Clark St Community",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002206",
    },
    {
        "school": "Columbus Park",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002207",
    },
    {
        "school": "Doherty Memorial High",
        "district": "Worcester",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002209",
    },
    {
        "school": "Elm Park Community",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002211",
    },
    {
        "school": "Flagg Street",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002212",
    },
    {
        "school": "Forest Grove Middle",
        "district": "Worcester",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002213",
    },
    {
        "school": "Francis J McGrath Elementary",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002214",
    },
    {
        "school": "Goddard School/Science Technical",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002215",
    },
    {
        "school": "Gates Lane",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002217",
    },
    {
        "school": "Grafton Street",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002219",
    },
    {
        "school": "Sullivan Middle",
        "district": "Worcester",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002223",
    },
    {
        "school": "Heard Street",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002224",
    },
    {
        "school": "Lake View",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002226",
    },
    {
        "school": "Lincoln Street",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002229",
    },
    {
        "school": "May Street",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002231",
    },
    {
        "school": "Midland Street",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002233",
    },
    {
        "school": "Nelson Place",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002236",
    },
    {
        "school": "Norrback Avenue",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002238",
    },
    {
        "school": "North High",
        "district": "Worcester",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002239",
    },
    {
        "school": "Quinsigamond",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002241",
    },
    {
        "school": "Rice Square",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002242",
    },
    {
        "school": "Roosevelt",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002243",
    },
    {
        "school": "South High Community",
        "district": "Worcester",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002244",
    },
    {
        "school": "Worcester Arts Magnet School",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002245",
    },
    {
        "school": "Tatnuck",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002246",
    },
    {
        "school": "Thorndyke Road",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002247",
    },
    {
        "school": "Union Hill School",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002248",
    },
    {
        "school": "Wawecus Road School",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002250",
    },
    {
        "school": "West Tatnuck",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002251",
    },
    {
        "school": "Worcester East Middle",
        "district": "Worcester",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002253",
    },
    {
        "school": "Worcester Technical High",
        "district": "Worcester",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "251323002305",
    },
    {
        "school": "Vernon Hill School",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002422",
    },
    {
        "school": "Chandler Magnet",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002506",
    },
    {
        "school": "Jacob Hiatt Magnet",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002566",
    },
    {
        "school": "City View",
        "district": "Worcester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002610",
    },
    {
        "school": "William A. Diggs Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027001565",
    },
    {
        "school": "Urbana Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001536",
    },
    {
        "school": "Middletown Primary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001566",
    },
    {
        "school": "Dayton Oaks",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001539",
    },
    {
        "school": "Sargent Shriver Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001537",
    },
    {
        "school": "Clarksburg High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001541",
    },
    {
        "school": "Little Bennett Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001543",
    },
    {
        "school": "Great Seneca Creek Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001567",
    },
    {
        "school": "Roscoe R Nix Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001572",
    },
    {
        "school": "Excel Academy Public Charter",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001540",
    },
    {
        "school": "Dr. Henry A. Wise Jr. High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001542",
    },
    {
        "school": "Middleton Valley Academy",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001544",
    },
    {
        "school": "Rosa L. Parks Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001573",
    },
    {
        "school": "Carter G Woodson Elementary",
        "district": "Somerset County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240057001535",
    },
    {
        "school": "The Green School of Baltimore",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001571",
    },
    {
        "school": "Windsor Mill Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001574",
    },
    {
        "school": "Colonel Richardson High School",
        "district": "Caroline County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240018000518",
    },
    {
        "school": "Colonel Richardson Middle School",
        "district": "Caroline County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240018000519",
    },
    {
        "school": "Denton Elementary School",
        "district": "Caroline County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240018000520",
    },
    {
        "school": "Federalsburg Elementary School",
        "district": "Caroline County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240018000521",
    },
    {
        "school": "Greensboro Elementary School",
        "district": "Caroline County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240018000522",
    },
    {
        "school": "North Caroline High School",
        "district": "Caroline County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240018000523",
    },
    {
        "school": "Preston Elementary School",
        "district": "Caroline County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240018000524",
    },
    {
        "school": "Ridgely Elementary School",
        "district": "Caroline County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240018000525",
    },
    {
        "school": "Lockerman Middle School",
        "district": "Caroline County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240018000526",
    },
    {
        "school": "Caroline Career & Technology Center",
        "district": "Caroline County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240018000968",
    },
    {
        "school": "Accident Elementary",
        "district": "Garrett County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036000662",
    },
    {
        "school": "Broad Ford Elementary",
        "district": "Garrett County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036000664",
    },
    {
        "school": "Crellin Elementary",
        "district": "Garrett County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036000665",
    },
    {
        "school": "Friendsville Elementary",
        "district": "Garrett County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036000667",
    },
    {
        "school": "Grantsville Elementary",
        "district": "Garrett County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036000668",
    },
    {
        "school": "Northern Garrett High School",
        "district": "Garrett County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036000671",
    },
    {
        "school": "Route 40 Elementary",
        "district": "Garrett County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036000673",
    },
    {
        "school": "Southern Garrett High School",
        "district": "Garrett County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036000674",
    },
    {
        "school": "Southern Middle School",
        "district": "Garrett County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036000675",
    },
    {
        "school": "Swan Meadow School",
        "district": "Garrett County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036000676",
    },
    {
        "school": "Yough Glades Elementary",
        "district": "Garrett County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036000852",
    },
    {
        "school": "Northern Middle School",
        "district": "Garrett County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240036001351",
    },
    {
        "school": "H. H. Garnett Elementary",
        "district": "Kent County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240045000765",
    },
    {
        "school": "Kent County Middle School",
        "district": "Kent County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240045000766",
    },
    {
        "school": "Kent County High",
        "district": "Kent County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240045000768",
    },
    {
        "school": "Rock Hall Elementary",
        "district": "Kent County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240045000770",
    },
    {
        "school": "Chesapeake Science Point",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001401",
    },
    {
        "school": "Baltimore County Home & Hospital",
        "district": "Baltimore County Public Schools",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012001341",
    },
    {
        "school": "Woodholme Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001405",
    },
    {
        "school": "New Town High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001547",
    },
    {
        "school": "Winters Mill High",
        "district": "Carroll County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021001185",
    },
    {
        "school": "Post Secondary Program",
        "district": "Carroll County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240021001348",
    },
    {
        "school": "PRIDE School",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240021001349",
    },
    {
        "school": "Flexible Student Support",
        "district": "Carroll County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240021001350",
    },
    {
        "school": "Parr's Ridge Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021001414",
    },
    {
        "school": "Gateway School",
        "district": "Carroll County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240021001548",
    },
    {
        "school": "Homewood School",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240042001189",
    },
    {
        "school": "Reservoir High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001200",
    },
    {
        "school": "Marriotts Ridge High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001437",
    },
    {
        "school": "Bellows Spring Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001551",
    },
    {
        "school": "Folly Quarter Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001552",
    },
    {
        "school": "Matapeake Elementary School",
        "district": "Queen Anne's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001557",
    },
    {
        "school": "The Crossroads School",
        "district": "Baltimore City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001291",
    },
    {
        "school": "ConneXions: A  Community Based Arts School",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001302",
    },
    {
        "school": "Digital Harbor High School",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240009001313",
    },
    {
        "school": "Reginald F. Lewis High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001331",
    },
    {
        "school": "National Academy Foundation",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001339",
    },
    {
        "school": "Academy for College and Career Exploration",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001381",
    },
    {
        "school": "Vivien T. Thomas Medical Arts Academy",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240009001385",
    },
    {
        "school": "Augusta Fells Savage Institute of Visual Arts",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001387",
    },
    {
        "school": "City Neighbors Charter School",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001478",
    },
    {
        "school": "Patterson Park Public Charter School",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001480",
    },
    {
        "school": "Southwest Baltimore Charter School",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001527",
    },
    {
        "school": "Coppin Academy",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001530",
    },
    {
        "school": "Renaissance Academy",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001531",
    },
    {
        "school": "Empowerment Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001558",
    },
    {
        "school": "New Era Academy",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001559",
    },
    {
        "school": "Annapolis Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000035",
    },
    {
        "school": "Annapolis Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000036",
    },
    {
        "school": "Annapolis High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000037",
    },
    {
        "school": "Arnold Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000038",
    },
    {
        "school": "Arundel Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000039",
    },
    {
        "school": "Arundel High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000040",
    },
    {
        "school": "Wiley H. Bates Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000041",
    },
    {
        "school": "Chesapeake Bay Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000042",
    },
    {
        "school": "Belle Grove Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000043",
    },
    {
        "school": "Belvedere Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000044",
    },
    {
        "school": "Benfield Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000045",
    },
    {
        "school": "Bodkin Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000046",
    },
    {
        "school": "Broadneck Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000047",
    },
    {
        "school": "Brock Bridge Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000048",
    },
    {
        "school": "Brooklyn Park Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000049",
    },
    {
        "school": "Brooklyn Park Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000050",
    },
    {
        "school": "Cape St. Claire Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000051",
    },
    {
        "school": "Central Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000053",
    },
    {
        "school": "Central Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000054",
    },
    {
        "school": "South River High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000055",
    },
    {
        "school": "Central Special School",
        "district": "Anne Arundel County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240006000056",
    },
    {
        "school": "Chesapeake High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000058",
    },
    {
        "school": "Corkran Middle School",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000059",
    },
    {
        "school": "Crofton Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000060",
    },
    {
        "school": "Crofton Woods Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000061",
    },
    {
        "school": "Davidsonville Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000062",
    },
    {
        "school": "Deale Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000063",
    },
    {
        "school": "Eastport Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000064",
    },
    {
        "school": "Edgewater Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000065",
    },
    {
        "school": "Ferndale Early Education Center",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000066",
    },
    {
        "school": "Folger Mckinsey Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000067",
    },
    {
        "school": "Fort Smallwood Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000068",
    },
    {
        "school": "Four Seasons Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000069",
    },
    {
        "school": "George T. Cromwell Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000071",
    },
    {
        "school": "George Fox Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000072",
    },
    {
        "school": "Georgetown East Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000073",
    },
    {
        "school": "Germantown Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000074",
    },
    {
        "school": "Glen Burnie High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000075",
    },
    {
        "school": "Glen Burnie Park Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000076",
    },
    {
        "school": "Glendale Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000077",
    },
    {
        "school": "Hebron - Harman Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000078",
    },
    {
        "school": "High Point Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000079",
    },
    {
        "school": "Hillsmere Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000080",
    },
    {
        "school": "Hilltop Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000081",
    },
    {
        "school": "Jacobsville Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000082",
    },
    {
        "school": "Jessup Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000083",
    },
    {
        "school": "Jones Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000084",
    },
    {
        "school": "Lake Shore Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000085",
    },
    {
        "school": "Lindale Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000087",
    },
    {
        "school": "Linthicum Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000088",
    },
    {
        "school": "Lothian Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000089",
    },
    {
        "school": "MacArthur Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000090",
    },
    {
        "school": "Magothy River Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000091",
    },
    {
        "school": "Manor View Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000092",
    },
    {
        "school": "Marley Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000093",
    },
    {
        "school": "Marley Glen School",
        "district": "Anne Arundel County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240006000094",
    },
    {
        "school": "Marley Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000095",
    },
    {
        "school": "Maryland City Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000096",
    },
    {
        "school": "Mayo Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000097",
    },
    {
        "school": "Meade Heights Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000098",
    },
    {
        "school": "Meade High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000099",
    },
    {
        "school": "Millersville Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000100",
    },
    {
        "school": "North Glen Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000102",
    },
    {
        "school": "Northeast High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000103",
    },
    {
        "school": "Oak Hill Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000104",
    },
    {
        "school": "Oakwood Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000105",
    },
    {
        "school": "Odenton Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000106",
    },
    {
        "school": "Old Mill Middle North",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000107",
    },
    {
        "school": "Old Mill Middle South",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000108",
    },
    {
        "school": "Old Mill High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000109",
    },
    {
        "school": "Overlook Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000110",
    },
    {
        "school": "Park Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000111",
    },
    {
        "school": "Walter S. Mills - Parole Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000112",
    },
    {
        "school": "Pasadena Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000113",
    },
    {
        "school": "Pershing Hill Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000114",
    },
    {
        "school": "Point Pleasant Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000116",
    },
    {
        "school": "Quarterfield Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000117",
    },
    {
        "school": "Richard Henry Lee Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000118",
    },
    {
        "school": "Ridgeway Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000119",
    },
    {
        "school": "Rippling Woods Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000120",
    },
    {
        "school": "Riviera Beach Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000121",
    },
    {
        "school": "Rolling Knolls Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000122",
    },
    {
        "school": "Severn Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000123",
    },
    {
        "school": "Severn River Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000124",
    },
    {
        "school": "Severna Park Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000125",
    },
    {
        "school": "Severna Park Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000126",
    },
    {
        "school": "Severna Park High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000127",
    },
    {
        "school": "Shady Side Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000128",
    },
    {
        "school": "Solley Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000129",
    },
    {
        "school": "South Shore Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000130",
    },
    {
        "school": "Southern Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000131",
    },
    {
        "school": "Southern High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000132",
    },
    {
        "school": "Southgate Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000133",
    },
    {
        "school": "Sunset Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000134",
    },
    {
        "school": "Traceys Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000135",
    },
    {
        "school": "Tyler Heights Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000136",
    },
    {
        "school": "Van Bokkelen Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000137",
    },
    {
        "school": "Waugh Chapel Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000138",
    },
    {
        "school": "West Annapolis Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000139",
    },
    {
        "school": "West Meade Early Education Center",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000140",
    },
    {
        "school": "Woodside Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000142",
    },
    {
        "school": "Meade Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006000823",
    },
    {
        "school": "Anne Arundel Evening High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240006000899",
    },
    {
        "school": "Center of Applied Technology-North",
        "district": "Anne Arundel County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240006000905",
    },
    {
        "school": "Center of Applied Technology-South",
        "district": "Anne Arundel County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240006000906",
    },
    {
        "school": "Broadneck High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001402",
    },
    {
        "school": "Crofton Middle",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001403",
    },
    {
        "school": "Shipley's Choice Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001421",
    },
    {
        "school": "Ruth Parker Eason School",
        "district": "Anne Arundel County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240006001425",
    },
    {
        "school": "Freetown Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001515",
    },
    {
        "school": "Windsor Farm Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001516",
    },
    {
        "school": "Crofton Meadows Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001517",
    },
    {
        "school": "Piney Orchard Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006002944",
    },
    {
        "school": "North County High",
        "district": "Anne Arundel County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006090441",
    },
    {
        "school": "Campfield Early Childhood Center",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000012",
    },
    {
        "school": "Seven Oaks Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000021",
    },
    {
        "school": "George W. Carver Center for Arts & Technology",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240012000230",
    },
    {
        "school": "Western School of Technology & Env. Science",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240012000248",
    },
    {
        "school": "Arbutus Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000341",
    },
    {
        "school": "Arbutus Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000342",
    },
    {
        "school": "Baltimore Highlands Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000344",
    },
    {
        "school": "Battle Grove Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000345",
    },
    {
        "school": "Battle Monument School",
        "district": "Baltimore County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240012000346",
    },
    {
        "school": "Bear Creek Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000347",
    },
    {
        "school": "Bedford Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000348",
    },
    {
        "school": "Berkshire Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000349",
    },
    {
        "school": "Lutherville Laboratory",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000350",
    },
    {
        "school": "Carney Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000351",
    },
    {
        "school": "Carroll Manor Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000352",
    },
    {
        "school": "Catonsville Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000353",
    },
    {
        "school": "Catonsville Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000354",
    },
    {
        "school": "Catonsville High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000355",
    },
    {
        "school": "Cedarmere Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000356",
    },
    {
        "school": "Chadwick Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000357",
    },
    {
        "school": "Chapel Hill Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000358",
    },
    {
        "school": "Charlesmont Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000359",
    },
    {
        "school": "Chase Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000360",
    },
    {
        "school": "Chatsworth School",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000361",
    },
    {
        "school": "Chesapeake High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000362",
    },
    {
        "school": "Chesapeake Terrace Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000363",
    },
    {
        "school": "Church Lane Elementary Technology",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000364",
    },
    {
        "school": "Cockeysville Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000366",
    },
    {
        "school": "Colgate Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000367",
    },
    {
        "school": "Deep Creek Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000369",
    },
    {
        "school": "Deep Creek Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000370",
    },
    {
        "school": "Deer Park Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000371",
    },
    {
        "school": "Deer Park Middle Magnet School",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000372",
    },
    {
        "school": "Dulaney High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000373",
    },
    {
        "school": "Dumbarton Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000374",
    },
    {
        "school": "Dundalk Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000375",
    },
    {
        "school": "Dundalk Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000376",
    },
    {
        "school": "Dundalk High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000377",
    },
    {
        "school": "Eastern Technical High School",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240012000379",
    },
    {
        "school": "Edgemere Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000381",
    },
    {
        "school": "Edmondson Heights Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000382",
    },
    {
        "school": "Elmwood Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000383",
    },
    {
        "school": "Essex Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000384",
    },
    {
        "school": "Featherbed Lane Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000385",
    },
    {
        "school": "Fifth District Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000386",
    },
    {
        "school": "Fort Garrison Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000387",
    },
    {
        "school": "Franklin Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000388",
    },
    {
        "school": "Franklin Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000389",
    },
    {
        "school": "Franklin High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000390",
    },
    {
        "school": "Fullerton Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000391",
    },
    {
        "school": "Grange Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000395",
    },
    {
        "school": "Gunpowder Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000397",
    },
    {
        "school": "Halethorpe Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000398",
    },
    {
        "school": "Hampton Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000399",
    },
    {
        "school": "Harford Hills Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000400",
    },
    {
        "school": "Hawthorne Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000401",
    },
    {
        "school": "Hebbville Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000402",
    },
    {
        "school": "Hernwood Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000405",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000406",
    },
    {
        "school": "Halstead Academy",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000407",
    },
    {
        "school": "Holabird Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000408",
    },
    {
        "school": "Johnnycake Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000410",
    },
    {
        "school": "Southwest Academy",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000411",
    },
    {
        "school": "Kenwood High IB and Sports Science",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000412",
    },
    {
        "school": "Kingsville Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000413",
    },
    {
        "school": "Lansdowne Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000415",
    },
    {
        "school": "Lansdowne High & Academy of Finance",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000416",
    },
    {
        "school": "Lansdowne Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000417",
    },
    {
        "school": "Loch Raven Technical Academy",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000419",
    },
    {
        "school": "Loch Raven High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000420",
    },
    {
        "school": "Logan Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000421",
    },
    {
        "school": "Mars Estates Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000424",
    },
    {
        "school": "Martin Boulevard Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000425",
    },
    {
        "school": "McCormick Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000426",
    },
    {
        "school": "Middleborough Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000429",
    },
    {
        "school": "Middlesex Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000430",
    },
    {
        "school": "Milbrook Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000431",
    },
    {
        "school": "Milford Mill Academy",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000432",
    },
    {
        "school": "Norwood Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000434",
    },
    {
        "school": "Oakleigh Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000435",
    },
    {
        "school": "Catonsville Center for Alternative Studies",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012000436",
    },
    {
        "school": "Orems Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000437",
    },
    {
        "school": "Overlea High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000438",
    },
    {
        "school": "Owings Mills Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000439",
    },
    {
        "school": "Sudbrook Magnet Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000441",
    },
    {
        "school": "Parkville Middle & Center of Technology",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000442",
    },
    {
        "school": "Parkville High & Center for Math/Science",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000443",
    },
    {
        "school": "Patapsco High & Center for Arts",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000444",
    },
    {
        "school": "Perry Hall Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000445",
    },
    {
        "school": "Perry Hall High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000446",
    },
    {
        "school": "Perry Hall Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000447",
    },
    {
        "school": "Pikesville Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000448",
    },
    {
        "school": "Pikesville High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000449",
    },
    {
        "school": "Pine Grove Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000450",
    },
    {
        "school": "Pine Grove Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000451",
    },
    {
        "school": "Pinewood Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000452",
    },
    {
        "school": "Pleasant Plains Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000453",
    },
    {
        "school": "Pot Spring Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000454",
    },
    {
        "school": "Powhatan Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000455",
    },
    {
        "school": "Prettyboy Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000456",
    },
    {
        "school": "Randallstown Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000457",
    },
    {
        "school": "Randallstown High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000458",
    },
    {
        "school": "Red House Run Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000459",
    },
    {
        "school": "Reisterstown Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000460",
    },
    {
        "school": "Relay Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000461",
    },
    {
        "school": "Riderwood Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000462",
    },
    {
        "school": "Cromwell Valley Elementary Technology",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000463",
    },
    {
        "school": "Riverview Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000464",
    },
    {
        "school": "Rodgers Forge Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000465",
    },
    {
        "school": "Maiden Choice School",
        "district": "Baltimore County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240012000466",
    },
    {
        "school": "Jacksonville Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000467",
    },
    {
        "school": "Sandalwood Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000469",
    },
    {
        "school": "Sandy Plains Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000470",
    },
    {
        "school": "Scotts Branch Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000471",
    },
    {
        "school": "Seneca Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000472",
    },
    {
        "school": "Seventh District Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000473",
    },
    {
        "school": "Shady Spring Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000474",
    },
    {
        "school": "Sparks Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000476",
    },
    {
        "school": "Sparrows Point High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000477",
    },
    {
        "school": "Stemmers Run Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000478",
    },
    {
        "school": "Stoneleigh Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000479",
    },
    {
        "school": "Summit Park Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000481",
    },
    {
        "school": "Sussex Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000482",
    },
    {
        "school": "Ridge Ruxton",
        "district": "Baltimore County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240012000483",
    },
    {
        "school": "Timber Grove Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000484",
    },
    {
        "school": "Towson High Law & Public Policy",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000487",
    },
    {
        "school": "Victory Villa Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000489",
    },
    {
        "school": "Villa Cresta Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000490",
    },
    {
        "school": "Warren Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000491",
    },
    {
        "school": "Wellwood International Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000492",
    },
    {
        "school": "Westowne Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000495",
    },
    {
        "school": "Winand Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000497",
    },
    {
        "school": "Winfield Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000498",
    },
    {
        "school": "Woodbridge Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000499",
    },
    {
        "school": "Woodlawn Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000501",
    },
    {
        "school": "Woodlawn High Center for Pre-Eng. Res.",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000502",
    },
    {
        "school": "Woodmoor Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000503",
    },
    {
        "school": "Meadowood Education Center",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012000777",
    },
    {
        "school": "Rosedale Center",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012000831",
    },
    {
        "school": "Home Assignments-Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012000925",
    },
    {
        "school": "Home Assignments-Secondary",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012000935",
    },
    {
        "school": "Westchester Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012000936",
    },
    {
        "school": "Sollers Point/Southeastern Technical High",
        "district": "Baltimore County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240012000938",
    },
    {
        "school": "New Town Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001159",
    },
    {
        "school": "Glyndon Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001346",
    },
    {
        "school": "Owings Mills High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001347",
    },
    {
        "school": "Glenmar Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001372",
    },
    {
        "school": "Oliver Beach Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001406",
    },
    {
        "school": "Hereford Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001422",
    },
    {
        "school": "Northwest Academy of Health Sciences",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001431",
    },
    {
        "school": "Hereford High",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001432",
    },
    {
        "school": "Timonium Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001433",
    },
    {
        "school": "Ridgely Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001434",
    },
    {
        "school": "White Oak School",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240012001435",
    },
    {
        "school": "General John Stricker Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001438",
    },
    {
        "school": "Golden Ring Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001439",
    },
    {
        "school": "Middle River Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001440",
    },
    {
        "school": "Dogwood Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012002945",
    },
    {
        "school": "Padonia International Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012090440",
    },
    {
        "school": "Joppa View Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012090444",
    },
    {
        "school": "Friendship Valley Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000052",
    },
    {
        "school": "Runnymede Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000368",
    },
    {
        "school": "Carroll Springs School",
        "district": "Carroll County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240021000527",
    },
    {
        "school": "Carrolltowne Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000529",
    },
    {
        "school": "Eldersburg Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000531",
    },
    {
        "school": "Elmer A. Wolfe Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000532",
    },
    {
        "school": "Francis Scott Key High",
        "district": "Carroll County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000533",
    },
    {
        "school": "Freedom District Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000534",
    },
    {
        "school": "Hampstead Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000535",
    },
    {
        "school": "Manchester Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000536",
    },
    {
        "school": "Mechanicsville Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000537",
    },
    {
        "school": "Mount Airy Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000538",
    },
    {
        "school": "North Carroll Middle",
        "district": "Carroll County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000542",
    },
    {
        "school": "Northwest Middle",
        "district": "Carroll County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000543",
    },
    {
        "school": "Robert Moton Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000544",
    },
    {
        "school": "Sandymount Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000545",
    },
    {
        "school": "South Carroll High",
        "district": "Carroll County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000546",
    },
    {
        "school": "Sykesville Middle",
        "district": "Carroll County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000547",
    },
    {
        "school": "Taneytown Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000548",
    },
    {
        "school": "Westminster East Middle",
        "district": "Carroll County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000550",
    },
    {
        "school": "Westminster Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000551",
    },
    {
        "school": "Westminster High",
        "district": "Carroll County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000552",
    },
    {
        "school": "Westminster West Middle",
        "district": "Carroll County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000553",
    },
    {
        "school": "William Winchester Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000554",
    },
    {
        "school": "Winfield Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000555",
    },
    {
        "school": "Oklahoma Road Middle",
        "district": "Carroll County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000835",
    },
    {
        "school": "Linton Springs Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000977",
    },
    {
        "school": "Carroll County Career & Technology Center",
        "district": "Carroll County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240021000979",
    },
    {
        "school": "Cranberry Station Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021001105",
    },
    {
        "school": "Century High",
        "district": "Carroll County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021001161",
    },
    {
        "school": "Liberty High",
        "district": "Carroll County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021001394",
    },
    {
        "school": "Shiloh Middle",
        "district": "Carroll County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021002947",
    },
    {
        "school": "Piney Ridge Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021090466",
    },
    {
        "school": "Spring Garden Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021090467",
    },
    {
        "school": "Abingdon Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000162",
    },
    {
        "school": "Fountain Green Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000394",
    },
    {
        "school": "Church Creek Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000468",
    },
    {
        "school": "Center for Educational Opportunity",
        "district": "Harford County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240039000480",
    },
    {
        "school": "Emmorton Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000485",
    },
    {
        "school": "Aberdeen Middle",
        "district": "Harford County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000678",
    },
    {
        "school": "Aberdeen High",
        "district": "Harford County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000679",
    },
    {
        "school": "Bakerfield Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000680",
    },
    {
        "school": "Bel Air Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000681",
    },
    {
        "school": "Southampton Middle",
        "district": "Harford County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000682",
    },
    {
        "school": "Bel Air High",
        "district": "Harford County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000683",
    },
    {
        "school": "Churchville Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000684",
    },
    {
        "school": "Darlington Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000685",
    },
    {
        "school": "Deerfield Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000686",
    },
    {
        "school": "Dublin Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000687",
    },
    {
        "school": "Edgewood Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000688",
    },
    {
        "school": "Edgewood Middle",
        "district": "Harford County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000689",
    },
    {
        "school": "Edgewood High",
        "district": "Harford County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000690",
    },
    {
        "school": "Fallston High",
        "district": "Harford County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000691",
    },
    {
        "school": "Forest Lakes Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000692",
    },
    {
        "school": "Halls Cross Roads Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000693",
    },
    {
        "school": "Harford Technical High",
        "district": "Harford County Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240039000694",
    },
    {
        "school": "Havre de Grace Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000695",
    },
    {
        "school": "Havre de Grace Middle",
        "district": "Harford County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000696",
    },
    {
        "school": "Havre de Grace High",
        "district": "Harford County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000697",
    },
    {
        "school": "Hickory Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000698",
    },
    {
        "school": "G. Lisby Elementary at Hillsdale",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000700",
    },
    {
        "school": "Homestead/Wakefield Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000701",
    },
    {
        "school": "Jarrettsville Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000702",
    },
    {
        "school": "John Archer School",
        "district": "Harford County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240039000703",
    },
    {
        "school": "Joppatowne Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000704",
    },
    {
        "school": "Joppatowne High",
        "district": "Harford County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000705",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000706",
    },
    {
        "school": "Meadowvale Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000707",
    },
    {
        "school": "Norrisville Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000708",
    },
    {
        "school": "North Harford Middle",
        "district": "Harford County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000709",
    },
    {
        "school": "North Harford High",
        "district": "Harford County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000710",
    },
    {
        "school": "Roye-Williams Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000711",
    },
    {
        "school": "Prospect Mill Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000712",
    },
    {
        "school": "Riverside Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000713",
    },
    {
        "school": "William S. James Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000715",
    },
    {
        "school": "William Paca/Old Post Road Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000716",
    },
    {
        "school": "Youths Benefit Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039000717",
    },
    {
        "school": "Magnolia Middle",
        "district": "Harford County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039001352",
    },
    {
        "school": "C. Milton Wright High",
        "district": "Harford County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039001380",
    },
    {
        "school": "Bel Air Middle",
        "district": "Harford County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039001397",
    },
    {
        "school": "North Harford Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039001443",
    },
    {
        "school": "Forest Hill Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039002948",
    },
    {
        "school": "Ring Factory Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039090447",
    },
    {
        "school": "Fallston Middle School",
        "district": "Harford County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039090475",
    },
    {
        "school": "North Bend Elementary",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039090476",
    },
    {
        "school": "Mount Airy Middle",
        "district": "Carroll County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021000539",
    },
    {
        "school": "Burleigh Manor Middle School",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000173",
    },
    {
        "school": "Forest Ridge Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000177",
    },
    {
        "school": "Rockburn Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000396",
    },
    {
        "school": "Mount View Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000403",
    },
    {
        "school": "Manor Woods Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000488",
    },
    {
        "school": "Elkridge Landing Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000633",
    },
    {
        "school": "Atholton Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000718",
    },
    {
        "school": "Atholton High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000719",
    },
    {
        "school": "Bryant Woods Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000720",
    },
    {
        "school": "Bushy Park Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000721",
    },
    {
        "school": "Centennial High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000722",
    },
    {
        "school": "Centennial Lane Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000723",
    },
    {
        "school": "Clarksville Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000724",
    },
    {
        "school": "Clarksville Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000725",
    },
    {
        "school": "Dunloggin Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000727",
    },
    {
        "school": "Elkridge Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000728",
    },
    {
        "school": "Glenelg High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000731",
    },
    {
        "school": "Glenwood Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000732",
    },
    {
        "school": "Guilford Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000733",
    },
    {
        "school": "Hammond Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000734",
    },
    {
        "school": "Hammond High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000735",
    },
    {
        "school": "Hammond Middle School",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000736",
    },
    {
        "school": "Harpers Choice Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000737",
    },
    {
        "school": "Howard High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000738",
    },
    {
        "school": "Jeffers Hill Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000740",
    },
    {
        "school": "Lisbon Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000741",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000742",
    },
    {
        "school": "Mount Hebron High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000743",
    },
    {
        "school": "Northfield Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000744",
    },
    {
        "school": "Oakland Mills High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000745",
    },
    {
        "school": "Oakland Mills Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000746",
    },
    {
        "school": "Patapsco Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000748",
    },
    {
        "school": "Phelps Luck Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000749",
    },
    {
        "school": "Running Brook Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000751",
    },
    {
        "school": "St. Johns Lane Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000753",
    },
    {
        "school": "Stevens Forest Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000754",
    },
    {
        "school": "Swansfield Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000755",
    },
    {
        "school": "Talbott Springs Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000756",
    },
    {
        "school": "Thunder Hill Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000757",
    },
    {
        "school": "Waterloo Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000758",
    },
    {
        "school": "West Friendship Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000760",
    },
    {
        "school": "Laurel Woods Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000761",
    },
    {
        "school": "Wilde Lake High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000762",
    },
    {
        "school": "Wilde Lake Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000763",
    },
    {
        "school": "Worthington Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000764",
    },
    {
        "school": "Ilchester Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000813",
    },
    {
        "school": "River Hill High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000816",
    },
    {
        "school": "Long Reach High",
        "district": "Howard County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000822",
    },
    {
        "school": "Hollifield Station Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000856",
    },
    {
        "school": "Fulton Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000859",
    },
    {
        "school": "Murray Hill Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042000860",
    },
    {
        "school": "Triadelphia Ridge Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001026",
    },
    {
        "school": "Gorman Crossing Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001032",
    },
    {
        "school": "Lime Kiln Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001115",
    },
    {
        "school": "Bonnie Branch Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001172",
    },
    {
        "school": "Clemens Crossing Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001382",
    },
    {
        "school": "Cedar Lane Special Center",
        "district": "Howard County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240042001415",
    },
    {
        "school": "Ellicott Mills Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001444",
    },
    {
        "school": "Bollman Bridge Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001507",
    },
    {
        "school": "Patuxent Valley Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001522",
    },
    {
        "school": "Applications and Research Laboratory",
        "district": "Howard County Public Schools",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240042002949",
    },
    {
        "school": "Deep Run Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042090448",
    },
    {
        "school": "Waverly Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042090449",
    },
    {
        "school": "Mayfield Woods Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042090477",
    },
    {
        "school": "Pointers Run Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042090478",
    },
    {
        "school": "Bayside Elementary School",
        "district": "Queen Anne's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054000202",
    },
    {
        "school": "Kennard Elementary School",
        "district": "Queen Anne's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001070",
    },
    {
        "school": "Kent Island High School",
        "district": "Queen Anne's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001076",
    },
    {
        "school": "Centreville Middle School",
        "district": "Queen Anne's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001190",
    },
    {
        "school": "Centreville Elementary School",
        "district": "Queen Anne's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001191",
    },
    {
        "school": "Church Hill Elementary School",
        "district": "Queen Anne's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001192",
    },
    {
        "school": "Grasonville Elementary School",
        "district": "Queen Anne's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001193",
    },
    {
        "school": "Kent Island Elementary School",
        "district": "Queen Anne's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001194",
    },
    {
        "school": "Queen Anne's County High School",
        "district": "Queen Anne's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001195",
    },
    {
        "school": "Stevensville Middle School",
        "district": "Queen Anne's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001196",
    },
    {
        "school": "Sudlersville Elementary School",
        "district": "Queen Anne's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001197",
    },
    {
        "school": "Sudlersville Middle School",
        "district": "Queen Anne's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001198",
    },
    {
        "school": "Abbottston Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000143",
    },
    {
        "school": "Alexander Hamilton Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000145",
    },
    {
        "school": "Arlington Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000146",
    },
    {
        "school": "Armistead Gardens Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000147",
    },
    {
        "school": "Arundel Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000148",
    },
    {
        "school": "Dr. Nathan A. Pitts-Ashburton Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000149",
    },
    {
        "school": "Baltimore City College",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000150",
    },
    {
        "school": "Baltimore Polytechnic Institute",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000151",
    },
    {
        "school": "Barclay Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000152",
    },
    {
        "school": "Charles Carroll Barrister Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000153",
    },
    {
        "school": "Bay-Brook Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000154",
    },
    {
        "school": "Beechfield Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000155",
    },
    {
        "school": "Belmont Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000156",
    },
    {
        "school": "Benjamin Franklin High School at Masonville Cove",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000157",
    },
    {
        "school": "Mary Ann Winterling Elementary at Bentalou",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000158",
    },
    {
        "school": "Booker T. Washington Middle",
        "district": "Baltimore City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000160",
    },
    {
        "school": "The Belair-Edison School",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000161",
    },
    {
        "school": "Callaway Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000163",
    },
    {
        "school": "Calverton Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000164",
    },
    {
        "school": "Carver Vocational-Technical High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240009000168",
    },
    {
        "school": "Cecil Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000169",
    },
    {
        "school": "The Historic Cherry Hill Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000171",
    },
    {
        "school": "City Springs Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000175",
    },
    {
        "school": "Claremont School",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240009000176",
    },
    {
        "school": "Collington Square Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000179",
    },
    {
        "school": "Commodore John Rogers Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000180",
    },
    {
        "school": "Cross Country Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000182",
    },
    {
        "school": "Curtis Bay Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000183",
    },
    {
        "school": "Dallas F. Nicholas Sr. Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000184",
    },
    {
        "school": "Dickey Hill Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000186",
    },
    {
        "school": "Dr. Bernard Harris Sr. Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000187",
    },
    {
        "school": "Dr. Martin Luther King Jr. Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000188",
    },
    {
        "school": "Edgecombe Circle Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000192",
    },
    {
        "school": "Edgewood Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000193",
    },
    {
        "school": "Edmondson-Westside High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240009000194",
    },
    {
        "school": "Eutaw-Marshburn Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000196",
    },
    {
        "school": "Fallstaff Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000199",
    },
    {
        "school": "Federal Hill Preparatory Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000201",
    },
    {
        "school": "Forest Park High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000203",
    },
    {
        "school": "Fort Worthington Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000204",
    },
    {
        "school": "Francis Scott Key Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000205",
    },
    {
        "school": "Franklin Square Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000208",
    },
    {
        "school": "Frederick Douglass High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000209",
    },
    {
        "school": "Furley Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000210",
    },
    {
        "school": "Furman Templeton Preparatory Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000211",
    },
    {
        "school": "Gardenville Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000212",
    },
    {
        "school": "Garrett Heights Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000213",
    },
    {
        "school": "Wolfe Street Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000215",
    },
    {
        "school": "George W. F. McMechen High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240009000219",
    },
    {
        "school": "George Washington Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000220",
    },
    {
        "school": "Glenmount Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000222",
    },
    {
        "school": "Govans Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000223",
    },
    {
        "school": "Graceland Park/O'Donnel Heights Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000224",
    },
    {
        "school": "Gwynns Falls Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000229",
    },
    {
        "school": "Hamilton Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000231",
    },
    {
        "school": "Hampden Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000233",
    },
    {
        "school": "Hampstead Hill Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000234",
    },
    {
        "school": "Achievement Academy at Harbor City High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240009000236",
    },
    {
        "school": "Harlem Park Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000239",
    },
    {
        "school": "Hazelwood Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000241",
    },
    {
        "school": "Highlandtown Elementary/Middle #215",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000243",
    },
    {
        "school": "Highlandtown Elementary/Middle #237",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000244",
    },
    {
        "school": "Hilton Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000246",
    },
    {
        "school": "Holabird Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000247",
    },
    {
        "school": "James McHenry Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000253",
    },
    {
        "school": "James Mosher Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000255",
    },
    {
        "school": "Dorothy I. Height Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000256",
    },
    {
        "school": "John Ruhrah Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000257",
    },
    {
        "school": "Johnston Square Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000258",
    },
    {
        "school": "Lockerman Bundy Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000260",
    },
    {
        "school": "Lakeland Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000264",
    },
    {
        "school": "Lakewood Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000265",
    },
    {
        "school": "Leith Walk Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000268",
    },
    {
        "school": "Liberty Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000270",
    },
    {
        "school": "Wildwood Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000273",
    },
    {
        "school": "Margaret Brent Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000276",
    },
    {
        "school": "Mary E. Rodman Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000277",
    },
    {
        "school": "Matthew A. Henson Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000278",
    },
    {
        "school": "Medfield Heights Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000279",
    },
    {
        "school": "Mergenthaler Vocational-Technical High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240009000280",
    },
    {
        "school": "Montebello Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000281",
    },
    {
        "school": "Moravia Park Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000282",
    },
    {
        "school": "Morrell Park Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000284",
    },
    {
        "school": "Mount Royal Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000285",
    },
    {
        "school": "The Mount Washington School",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000286",
    },
    {
        "school": "Northwood Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000293",
    },
    {
        "school": "Patterson High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240009000297",
    },
    {
        "school": "Paul Laurence Dunbar High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000298",
    },
    {
        "school": "Pimlico Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000299",
    },
    {
        "school": "Robert W. Coleman Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000303",
    },
    {
        "school": "Roland Park Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000306",
    },
    {
        "school": "Rosemont Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000307",
    },
    {
        "school": "The Historic Samuel Coleridge-Taylor Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000309",
    },
    {
        "school": "Sarah M. Roach Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000312",
    },
    {
        "school": "Sinclair Lane Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000313",
    },
    {
        "school": "Steuart Hill Academic Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000319",
    },
    {
        "school": "Tench Tilghman Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000320",
    },
    {
        "school": "Thomas Jefferson Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000322",
    },
    {
        "school": "Thomas Johnson Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000323",
    },
    {
        "school": "Violetville Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000326",
    },
    {
        "school": "Walter P. Carter Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000328",
    },
    {
        "school": "Waverly Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000329",
    },
    {
        "school": "Western High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000330",
    },
    {
        "school": "Westport Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000331",
    },
    {
        "school": "William Paca Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000334",
    },
    {
        "school": "Sandtown-Winchester Achievement Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000335",
    },
    {
        "school": "William S. Baer School",
        "district": "Baltimore City Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240009000336",
    },
    {
        "school": "Windsor Hills Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000337",
    },
    {
        "school": "Woodhome Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000339",
    },
    {
        "school": "Yorkwood Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000340",
    },
    {
        "school": "Stadium School",
        "district": "Baltimore City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000571",
    },
    {
        "school": "North Bend Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000602",
    },
    {
        "school": "Midtown Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000883",
    },
    {
        "school": "New Song Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009000884",
    },
    {
        "school": "Eager Street Academy",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240009000885",
    },
    {
        "school": "Harford Heights Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001153",
    },
    {
        "school": "Excel Academy at Francis M. Wood High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240009001343",
    },
    {
        "school": "Maree Garnett Farring Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001363",
    },
    {
        "school": "Lois T. Murray Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240009001364",
    },
    {
        "school": "Sharp-Leadenhall Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240009001369",
    },
    {
        "school": "Calvin M. Rodwell Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001390",
    },
    {
        "school": "Baltimore School for the Arts",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001391",
    },
    {
        "school": "Guilford Elementary/Middle",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001428",
    },
    {
        "school": "Frederick Elementary",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001430",
    },
    {
        "school": "Cambridge-South Dorchester High School",
        "district": "Dorchester County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240030000612",
    },
    {
        "school": "Hurlock Elementary School",
        "district": "Dorchester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240030000614",
    },
    {
        "school": "Maple Elementary School",
        "district": "Dorchester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240030000617",
    },
    {
        "school": "North Dorchester High School",
        "district": "Dorchester County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240030000618",
    },
    {
        "school": "North Dorchester Middle School",
        "district": "Dorchester County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240030000619",
    },
    {
        "school": "Sandy Hill Elementary",
        "district": "Dorchester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240030000621",
    },
    {
        "school": "South Dorchester School",
        "district": "Dorchester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240030000622",
    },
    {
        "school": "Vienna Elementary School",
        "district": "Dorchester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240030000624",
    },
    {
        "school": "Warwick Elementary School",
        "district": "Dorchester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240030000625",
    },
    {
        "school": "Choptank Elementary School",
        "district": "Dorchester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240030000841",
    },
    {
        "school": "Judith P. Hoyer Early Childhood Center",
        "district": "Dorchester County Public Schools",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240030000989",
    },
    {
        "school": "Dorchester County Career and Technology Center",
        "district": "Dorchester County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240030000994",
    },
    {
        "school": "Mace's Lane Middle School",
        "district": "Dorchester County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240030001423",
    },
    {
        "school": "Mt. Savage Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003001546",
    },
    {
        "school": "Allegany High",
        "district": "Allegany County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000001",
    },
    {
        "school": "Beall Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000003",
    },
    {
        "school": "Bel Air Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000005",
    },
    {
        "school": "Braddock Middle",
        "district": "Allegany County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000006",
    },
    {
        "school": "Westmar Middle",
        "district": "Allegany County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000007",
    },
    {
        "school": "Cresaptown Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000010",
    },
    {
        "school": "Flintstone Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000014",
    },
    {
        "school": "Fort Hill High",
        "district": "Allegany County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000015",
    },
    {
        "school": "Frost Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000016",
    },
    {
        "school": "George's Creek Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000017",
    },
    {
        "school": "John Humbird Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000019",
    },
    {
        "school": "Mount Savage Middle",
        "district": "Allegany County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000023",
    },
    {
        "school": "Northeast Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000024",
    },
    {
        "school": "Parkside Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000026",
    },
    {
        "school": "Center for Career & Technical Education",
        "district": "Allegany County Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240003000030",
    },
    {
        "school": "Washington Middle",
        "district": "Allegany County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000031",
    },
    {
        "school": "West Side Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000032",
    },
    {
        "school": "Westernport Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003000033",
    },
    {
        "school": "Cash Valley Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003001338",
    },
    {
        "school": "South Penn Elementary",
        "district": "Allegany County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003001359",
    },
    {
        "school": "Chapel District Elementary",
        "district": "Talbot County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240063001241",
    },
    {
        "school": "Easton High",
        "district": "Talbot County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240063001242",
    },
    {
        "school": "Easton Middle",
        "district": "Talbot County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240063001243",
    },
    {
        "school": "Easton Elementary",
        "district": "Talbot County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240063001244",
    },
    {
        "school": "St. Michaels Elementary",
        "district": "Talbot County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240063001247",
    },
    {
        "school": "St. Michaels Middle/High School",
        "district": "Talbot County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240063001248",
    },
    {
        "school": "Tilghman Elementary",
        "district": "Talbot County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240063001250",
    },
    {
        "school": "White Marsh Elementary",
        "district": "Talbot County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240063001252",
    },
    {
        "school": "Washington County Technical High",
        "district": "Washingtion County Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240066000308",
    },
    {
        "school": "Eastern Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066000418",
    },
    {
        "school": "Paramount Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066000752",
    },
    {
        "school": "Evening High School",
        "district": "Washingtion County Public Schools",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240066001086",
    },
    {
        "school": "Bester Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001253",
    },
    {
        "school": "Boonsboro Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001254",
    },
    {
        "school": "Boonsboro Middle",
        "district": "Washingtion County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001255",
    },
    {
        "school": "Boonsboro High",
        "district": "Washingtion County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001256",
    },
    {
        "school": "Cascade Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001258",
    },
    {
        "school": "Clear Spring Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001259",
    },
    {
        "school": "Clear Spring High",
        "district": "Washingtion County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001260",
    },
    {
        "school": "Clear Spring Middle",
        "district": "Washingtion County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001261",
    },
    {
        "school": "E. Russell Hicks Middle",
        "district": "Washingtion County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001263",
    },
    {
        "school": "Emma K. Doub Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001264",
    },
    {
        "school": "Fountain Rock Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001265",
    },
    {
        "school": "Fountaindale Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001266",
    },
    {
        "school": "Greenbrier Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001268",
    },
    {
        "school": "Hancock Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001269",
    },
    {
        "school": "Hancock Middle Senior High",
        "district": "Washingtion County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001270",
    },
    {
        "school": "Hickory Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001271",
    },
    {
        "school": "Lincolnshire Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001273",
    },
    {
        "school": "Maugansville Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001274",
    },
    {
        "school": "North Hagerstown High",
        "district": "Washingtion County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001275",
    },
    {
        "school": "Northern Middle",
        "district": "Washingtion County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001276",
    },
    {
        "school": "Old Forge Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001277",
    },
    {
        "school": "Pangborn Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001278",
    },
    {
        "school": "Pleasant Valley Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001280",
    },
    {
        "school": "Potomac Heights Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001281",
    },
    {
        "school": "Salem Avenue Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001283",
    },
    {
        "school": "Sharpsburg Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001284",
    },
    {
        "school": "Smithsburg High",
        "district": "Washingtion County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001285",
    },
    {
        "school": "Smithsburg Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001286",
    },
    {
        "school": "Smithsburg Middle",
        "district": "Washingtion County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001287",
    },
    {
        "school": "South Hagerstown High",
        "district": "Washingtion County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001288",
    },
    {
        "school": "Marshall Street School",
        "district": "Washingtion County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240066001289",
    },
    {
        "school": "Springfield Middle",
        "district": "Washingtion County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001290",
    },
    {
        "school": "Western Heights Middle",
        "district": "Washingtion County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001293",
    },
    {
        "school": "Williamsport Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001294",
    },
    {
        "school": "Williamsport High",
        "district": "Washingtion County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001295",
    },
    {
        "school": "Washington County Job Development Center",
        "district": "Washingtion County Public Schools",
        "level": "High",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240066001484",
    },
    {
        "school": "Dr. James A. Forrest Career and Technology Center",
        "district": "St. Mary's County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240060001079",
    },
    {
        "school": "Benjamin Banneker Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001216",
    },
    {
        "school": "Chopticon High",
        "district": "St. Mary's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001218",
    },
    {
        "school": "Dynard Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001219",
    },
    {
        "school": "Esperanza Middle",
        "district": "St. Mary's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001220",
    },
    {
        "school": "Green Holly Elementary School",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001221",
    },
    {
        "school": "Great Mills High",
        "district": "St. Mary's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001224",
    },
    {
        "school": "Greenview Knolls Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001226",
    },
    {
        "school": "Hollywood Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001227",
    },
    {
        "school": "Leonardtown Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001228",
    },
    {
        "school": "Leonardtown Middle",
        "district": "St. Mary's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001229",
    },
    {
        "school": "Lexington Park Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001230",
    },
    {
        "school": "Margaret Brent Middle",
        "district": "St. Mary's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001231",
    },
    {
        "school": "Mechanicsville Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001232",
    },
    {
        "school": "Oakville Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001233",
    },
    {
        "school": "Park Hall Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001234",
    },
    {
        "school": "Piney Point Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001235",
    },
    {
        "school": "Ridge Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001236",
    },
    {
        "school": "Spring Ridge Middle",
        "district": "St. Mary's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001237",
    },
    {
        "school": "Town Creek Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001239",
    },
    {
        "school": "White Marsh Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001240",
    },
    {
        "school": "Leonardtown High",
        "district": "St. Mary's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001356",
    },
    {
        "school": "Lettie Marshall Dent Elem",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001399",
    },
    {
        "school": "George Washington Carver Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001483",
    },
    {
        "school": "Stephen Decatur Middle",
        "district": "Worcester County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072000880",
    },
    {
        "school": "Worcester Technical High School",
        "district": "Worcester County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240072001091",
    },
    {
        "school": "Berlin Intermediate",
        "district": "Worcester County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072001323",
    },
    {
        "school": "Buckingham Elementary",
        "district": "Worcester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072001325",
    },
    {
        "school": "Cedar Chapel Special School",
        "district": "Worcester County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240072001326",
    },
    {
        "school": "Ocean City Elementary",
        "district": "Worcester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072001327",
    },
    {
        "school": "Pocomoke Elementary",
        "district": "Worcester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072001328",
    },
    {
        "school": "Pocomoke Middle",
        "district": "Worcester County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072001329",
    },
    {
        "school": "Pocomoke High",
        "district": "Worcester County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072001330",
    },
    {
        "school": "Snow Hill Elementary",
        "district": "Worcester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072001332",
    },
    {
        "school": "Snow Hill Middle",
        "district": "Worcester County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072001333",
    },
    {
        "school": "Snow Hill High",
        "district": "Worcester County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072001334",
    },
    {
        "school": "Stephen Decatur High",
        "district": "Worcester County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072001335",
    },
    {
        "school": "Showell Elementary",
        "district": "Worcester County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240072001498",
    },
    {
        "school": "Bainbridge Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000556",
    },
    {
        "school": "Bay View Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000557",
    },
    {
        "school": "Bohemia Manor High",
        "district": "Cecil County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000558",
    },
    {
        "school": "Calvert Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000559",
    },
    {
        "school": "Cecil Manor Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000560",
    },
    {
        "school": "Cecilton Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000562",
    },
    {
        "school": "Charlestown Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000563",
    },
    {
        "school": "Cherry Hill Middle",
        "district": "Cecil County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000564",
    },
    {
        "school": "Chesapeake City Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000565",
    },
    {
        "school": "Conowingo Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000566",
    },
    {
        "school": "Elkton Middle",
        "district": "Cecil County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000567",
    },
    {
        "school": "Elkton High",
        "district": "Cecil County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000568",
    },
    {
        "school": "Gilpin Manor Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000569",
    },
    {
        "school": "Holly Hall Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000570",
    },
    {
        "school": "Leeds Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000572",
    },
    {
        "school": "North East Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000573",
    },
    {
        "school": "North East Middle",
        "district": "Cecil County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000574",
    },
    {
        "school": "North East High",
        "district": "Cecil County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000575",
    },
    {
        "school": "Perryville Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000576",
    },
    {
        "school": "Perryville High",
        "district": "Cecil County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000577",
    },
    {
        "school": "Perryville Middle",
        "district": "Cecil County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000578",
    },
    {
        "school": "Rising Sun Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000579",
    },
    {
        "school": "Rising Sun Middle School",
        "district": "Cecil County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000580",
    },
    {
        "school": "Thomson Estates Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000581",
    },
    {
        "school": "Bohemia Manor Middle",
        "district": "Cecil County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024000791",
    },
    {
        "school": "Cecil County School of Technology",
        "district": "Cecil County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240024000984",
    },
    {
        "school": "Kenmore Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024001491",
    },
    {
        "school": "Elk Neck Elementary",
        "district": "Cecil County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024090468",
    },
    {
        "school": "Rising Sun High",
        "district": "Cecil County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240024090469",
    },
    {
        "school": "Somerset 6/7 Intermediate School",
        "district": "Somerset County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240057001377",
    },
    {
        "school": "Somerset County Technical High School",
        "district": "Somerset County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240057001083",
    },
    {
        "school": "Crisfield Academy and High School",
        "district": "Somerset County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240057001201",
    },
    {
        "school": "Deal Island School",
        "district": "Somerset County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240057001202",
    },
    {
        "school": "Ewell School",
        "district": "Somerset County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240057001203",
    },
    {
        "school": "Washington Academy and High School",
        "district": "Somerset County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240057001213",
    },
    {
        "school": "Wicomico County Evening High",
        "district": "Wicomico County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240069001088",
    },
    {
        "school": "Salisbury Middle",
        "district": "Wicomico County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001145",
    },
    {
        "school": "Westside Intermediate",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001149",
    },
    {
        "school": "Fruitland Primary",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001151",
    },
    {
        "school": "Beaver Run School",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001298",
    },
    {
        "school": "Bennett Middle",
        "district": "Wicomico County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001299",
    },
    {
        "school": "Delmar Elementary",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001300",
    },
    {
        "school": "East Salisbury Elementary",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001301",
    },
    {
        "school": "Fruitland Intermediate",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001303",
    },
    {
        "school": "Glen Avenue School",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001304",
    },
    {
        "school": "James M. Bennett High",
        "district": "Wicomico County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001305",
    },
    {
        "school": "Mardela Middle & High",
        "district": "Wicomico County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001306",
    },
    {
        "school": "North Salisbury Elementary",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001307",
    },
    {
        "school": "Northwestern Elementary",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001308",
    },
    {
        "school": "Parkside High",
        "district": "Wicomico County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001309",
    },
    {
        "school": "Pemberton Elementary",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001310",
    },
    {
        "school": "Pinehurst Elementary",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001311",
    },
    {
        "school": "Pittsville Elementary & Middle",
        "district": "Wicomico County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001312",
    },
    {
        "school": "Prince Street School",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001314",
    },
    {
        "school": "Charles H. Chipman Elementary",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001315",
    },
    {
        "school": "West Salisbury",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001317",
    },
    {
        "school": "Westside Primary",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001318",
    },
    {
        "school": "Wicomico Middle",
        "district": "Wicomico County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001319",
    },
    {
        "school": "Wicomico High",
        "district": "Wicomico County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001320",
    },
    {
        "school": "Willards Elementary",
        "district": "Wicomico County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240069001322",
    },
    {
        "school": "Huntingtown High School",
        "district": "Calvert County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015001342",
    },
    {
        "school": "Calvert County Alternative School",
        "district": "Calvert County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240015001344",
    },
    {
        "school": "North Point High School",
        "district": "Charles County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027001416",
    },
    {
        "school": "Monocacy Valley Montessori",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001187",
    },
    {
        "school": "Tuscarora Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001355",
    },
    {
        "school": "Crestwood Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001357",
    },
    {
        "school": "Centerville Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001429",
    },
    {
        "school": "Gov. Thomas Johnson Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001549",
    },
    {
        "school": "Tuscarora High",
        "district": "Frederick County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001550",
    },
    {
        "school": "Newport Mill Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001207",
    },
    {
        "school": "MCPS Transitions School",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240048001365",
    },
    {
        "school": "Northwood High School",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001366",
    },
    {
        "school": "Lakelands Park Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001441",
    },
    {
        "school": "A. Mario Loiederman Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001446",
    },
    {
        "school": "Dodge Park Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001208",
    },
    {
        "school": "G. James Gholson Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001211",
    },
    {
        "school": "Lake Arbor Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001217",
    },
    {
        "school": "Cora L. Rice Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001222",
    },
    {
        "school": "Ernest Everett Just Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001223",
    },
    {
        "school": "Dora Kennedy French Immersion",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001245",
    },
    {
        "school": "Robert Goddard Montessori",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001251",
    },
    {
        "school": "Mary Harris",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001257",
    },
    {
        "school": "Berwyn Heights Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001272",
    },
    {
        "school": "Port Towns Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001368",
    },
    {
        "school": "Suitland Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001453",
    },
    {
        "school": "Whitehall Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001461",
    },
    {
        "school": "William W. Hall Academy",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001462",
    },
    {
        "school": "Prekindergarten Offsites",
        "district": "Prince George's County Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001476",
    },
    {
        "school": "Maya Angelou French Immersion",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001554",
    },
    {
        "school": "Samuel P. Massie Academy",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001555",
    },
    {
        "school": "Panorama Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001556",
    },
    {
        "school": "Plum Point Middle",
        "district": "Calvert County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000027",
    },
    {
        "school": "Patuxent Appeal Elementary Campus",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000504",
    },
    {
        "school": "Beach Elementary",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000505",
    },
    {
        "school": "Calvert Middle",
        "district": "Calvert County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000507",
    },
    {
        "school": "Calvert High",
        "district": "Calvert County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000508",
    },
    {
        "school": "Calvert Country School",
        "district": "Calvert County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240015000509",
    },
    {
        "school": "Huntingtown Elementary",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000511",
    },
    {
        "school": "Mount Harmony Elementary",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000513",
    },
    {
        "school": "Mutual Elementary",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000514",
    },
    {
        "school": "Northern Middle",
        "district": "Calvert County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000515",
    },
    {
        "school": "Northern High",
        "district": "Calvert County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000516",
    },
    {
        "school": "Calvert Elementary",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000517",
    },
    {
        "school": "Patuxent High",
        "district": "Calvert County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000611",
    },
    {
        "school": "St Leonard Elementary",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000778",
    },
    {
        "school": "Windy Hill Elementary",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000790",
    },
    {
        "school": "Career and Technology Academy",
        "district": "Calvert County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240015000962",
    },
    {
        "school": "Windy Hill Middle",
        "district": "Calvert County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015000967",
    },
    {
        "school": "Dowell Elementary",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015001102",
    },
    {
        "school": "Southern Middle",
        "district": "Calvert County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015001392",
    },
    {
        "school": "Sunderland Elementary",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015001505",
    },
    {
        "school": "Mill Creek Middle",
        "district": "Calvert County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015002946",
    },
    {
        "school": "Plum Point Elementary",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015090465",
    },
    {
        "school": "Mary H. Matula Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000141",
    },
    {
        "school": "Westlake High School",
        "district": "Charles County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000144",
    },
    {
        "school": "C. Paul Barnhart Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000380",
    },
    {
        "school": "Arthur Middleton Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000582",
    },
    {
        "school": "Benjamin Stoddert Middle School",
        "district": "Charles County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000583",
    },
    {
        "school": "Dr. Gustavus Brown Elementary",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000584",
    },
    {
        "school": "Dr. Samuel A. Mudd Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000585",
    },
    {
        "school": "Eva Turner Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000586",
    },
    {
        "school": "Gale-Bailey Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000588",
    },
    {
        "school": "General Smallwood Middle School",
        "district": "Charles County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000589",
    },
    {
        "school": "Indian Head Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000591",
    },
    {
        "school": "J. C. Parks Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000592",
    },
    {
        "school": "J. P. Ryon Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000593",
    },
    {
        "school": "Dr. James Craik Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000594",
    },
    {
        "school": "John Hanson Middle School",
        "district": "Charles County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000595",
    },
    {
        "school": "La Plata High School",
        "district": "Charles County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000596",
    },
    {
        "school": "Henry E. Lackey High School",
        "district": "Charles County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000597",
    },
    {
        "school": "Malcolm Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000598",
    },
    {
        "school": "Matthew Henson Middle School",
        "district": "Charles County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000599",
    },
    {
        "school": "Maurice J. McDonough High School",
        "district": "Charles County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000600",
    },
    {
        "school": "Milton M. Somers Middle School",
        "district": "Charles County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000601",
    },
    {
        "school": "Piccowaxen Middle School",
        "district": "Charles County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000604",
    },
    {
        "school": "T. C. Martin Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000606",
    },
    {
        "school": "Thomas Stone High School",
        "district": "Charles County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000607",
    },
    {
        "school": "Walter J. Mitchell Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000609",
    },
    {
        "school": "Dr. Thomas L. Higdon Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000610",
    },
    {
        "school": "Mattawoman Middle School",
        "district": "Charles County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000615",
    },
    {
        "school": "Berry Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027000805",
    },
    {
        "school": "F. B. Gwynn Educational Center",
        "district": "Charles County Public Schools",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240027001162",
    },
    {
        "school": "Robert D. Stethem Educational Center",
        "district": "Charles County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240027001395",
    },
    {
        "school": "Mt Hope/Nanjemoy Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027001492",
    },
    {
        "school": "William B. Wade Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027001519",
    },
    {
        "school": "Twin Ridge Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000159",
    },
    {
        "school": "Windsor Knolls Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000392",
    },
    {
        "school": "Urbana High",
        "district": "Frederick County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000616",
    },
    {
        "school": "Glade Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000620",
    },
    {
        "school": "Brunswick Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000626",
    },
    {
        "school": "Brunswick High",
        "district": "Frederick County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000627",
    },
    {
        "school": "Carroll Manor Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000628",
    },
    {
        "school": "Catoctin High",
        "district": "Frederick County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000629",
    },
    {
        "school": "Emmitsburg Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000631",
    },
    {
        "school": "Frederick High",
        "district": "Frederick County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000632",
    },
    {
        "school": "Gov. Thomas Johnson High",
        "district": "Frederick County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000634",
    },
    {
        "school": "Green Valley Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000635",
    },
    {
        "school": "Lewistown Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000636",
    },
    {
        "school": "Liberty Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000637",
    },
    {
        "school": "Linganore High",
        "district": "Frederick County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000638",
    },
    {
        "school": "Middletown Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000639",
    },
    {
        "school": "Middletown Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000640",
    },
    {
        "school": "Middletown High",
        "district": "Frederick County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000641",
    },
    {
        "school": "Myersville Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000642",
    },
    {
        "school": "New Market Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000643",
    },
    {
        "school": "North Frederick Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000645",
    },
    {
        "school": "Parkway Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000646",
    },
    {
        "school": "Rock Creek",
        "district": "Frederick County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240033000647",
    },
    {
        "school": "Sabillasville Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000648",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000649",
    },
    {
        "school": "Thurmont Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000650",
    },
    {
        "school": "Thurmont Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000651",
    },
    {
        "school": "Urbana Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000652",
    },
    {
        "school": "Valley Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000653",
    },
    {
        "school": "Walkersville Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000654",
    },
    {
        "school": "Walkersville High",
        "district": "Frederick County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000655",
    },
    {
        "school": "Walkersville Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000656",
    },
    {
        "school": "Waverley Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000657",
    },
    {
        "school": "West Frederick Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000658",
    },
    {
        "school": "Wolfsville Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000659",
    },
    {
        "school": "Yellow Springs Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000661",
    },
    {
        "school": "Orchard Grove Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000807",
    },
    {
        "school": "Deer Crossing Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033000847",
    },
    {
        "school": "Frederick County Virtual",
        "district": "Frederick County Public Schools",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240033001007",
    },
    {
        "school": "Frederick County Career & Technology Center",
        "district": "Frederick County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240033001011",
    },
    {
        "school": "Whittier Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001015",
    },
    {
        "school": "Oakdale Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001163",
    },
    {
        "school": "Oakdale Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001165",
    },
    {
        "school": "Thurmont Primary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001166",
    },
    {
        "school": "New Market Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001379",
    },
    {
        "school": "Brunswick Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001409",
    },
    {
        "school": "Heather Ridge",
        "district": "Frederick County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240033001410",
    },
    {
        "school": "Kemptown Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001412",
    },
    {
        "school": "Monocacy Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001413",
    },
    {
        "school": "New Midway/Woodsboro Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001442",
    },
    {
        "school": "Monocacy Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001521",
    },
    {
        "school": "Ballenger Creek Middle",
        "district": "Frederick County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033090446",
    },
    {
        "school": "Ballenger Creek Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033090471",
    },
    {
        "school": "Spring Ridge Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033090472",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033090473",
    },
    {
        "school": "Rosa M. Parks Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000181",
    },
    {
        "school": "Lois P. Rockwell Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000185",
    },
    {
        "school": "Dr. Sally K. Ride Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000191",
    },
    {
        "school": "Thurgood Marshall Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000404",
    },
    {
        "school": "Argyle Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000409",
    },
    {
        "school": "Roberto W. Clemente Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000493",
    },
    {
        "school": "Stephen Knolls School",
        "district": "Montgomery County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240048000496",
    },
    {
        "school": "Forest Oak Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000644",
    },
    {
        "school": "Rocky Hill Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000660",
    },
    {
        "school": "Neelsville Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000759",
    },
    {
        "school": "Albert Einstein High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000773",
    },
    {
        "school": "Ashburton Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000776",
    },
    {
        "school": "Bannockburn Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000779",
    },
    {
        "school": "Bel Pre Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000780",
    },
    {
        "school": "Bells Mill Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000781",
    },
    {
        "school": "Belmont Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000782",
    },
    {
        "school": "Benjamin Banneker Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000783",
    },
    {
        "school": "Bethesda-Chevy Chase High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000784",
    },
    {
        "school": "Bethesda Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000785",
    },
    {
        "school": "Beverly Farms Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000786",
    },
    {
        "school": "Bradley Hills Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000787",
    },
    {
        "school": "JoAnn Leleck at Broad Acres Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000788",
    },
    {
        "school": "Brookhaven Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000789",
    },
    {
        "school": "Brown Station Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000792",
    },
    {
        "school": "Burning Tree Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000793",
    },
    {
        "school": "Burtonsville Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000794",
    },
    {
        "school": "Candlewood Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000796",
    },
    {
        "school": "Cannon Road Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000797",
    },
    {
        "school": "Carderock Springs Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000798",
    },
    {
        "school": "Carl Sandburg Center",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240048000799",
    },
    {
        "school": "Cashell Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000800",
    },
    {
        "school": "Cedar Grove Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000801",
    },
    {
        "school": "Chevy Chase Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000803",
    },
    {
        "school": "Clarksburg Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000804",
    },
    {
        "school": "Col. E. Brooke Lee Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000806",
    },
    {
        "school": "Col. Zadok Magruder High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000808",
    },
    {
        "school": "Cold Spring Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000809",
    },
    {
        "school": "College Gardens Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000810",
    },
    {
        "school": "Cresthaven Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000814",
    },
    {
        "school": "Damascus Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000815",
    },
    {
        "school": "Darnestown Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000817",
    },
    {
        "school": "Diamond Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000818",
    },
    {
        "school": "DuFief Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000819",
    },
    {
        "school": "Earle B. Wood Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000820",
    },
    {
        "school": "East Silver Spring Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000821",
    },
    {
        "school": "Fairland Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000826",
    },
    {
        "school": "Fallsmead Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000827",
    },
    {
        "school": "Farmland Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000828",
    },
    {
        "school": "Fields Road Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000829",
    },
    {
        "school": "Flower Valley Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000830",
    },
    {
        "school": "Forest Knolls Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000832",
    },
    {
        "school": "Fox Chapel Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000834",
    },
    {
        "school": "Gaithersburg Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000836",
    },
    {
        "school": "Gaithersburg Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000837",
    },
    {
        "school": "Gaithersburg High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000838",
    },
    {
        "school": "Galway Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000839",
    },
    {
        "school": "Garrett Park Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000840",
    },
    {
        "school": "Georgian Forest Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000842",
    },
    {
        "school": "Germantown Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000843",
    },
    {
        "school": "Glen Haven Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000844",
    },
    {
        "school": "Glenallan Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000845",
    },
    {
        "school": "Greenwood Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000846",
    },
    {
        "school": "Harmony Hills Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000848",
    },
    {
        "school": "Herbert Hoover Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000849",
    },
    {
        "school": "Highland Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000850",
    },
    {
        "school": "Highland View Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000851",
    },
    {
        "school": "Jackson Road Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000854",
    },
    {
        "school": "John F. Kennedy High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000855",
    },
    {
        "school": "Julius West Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000857",
    },
    {
        "school": "Kemp Mill Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000858",
    },
    {
        "school": "John H. Poole Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000861",
    },
    {
        "school": "Lakewood Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000862",
    },
    {
        "school": "Kingsview Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000863",
    },
    {
        "school": "Laytonsville Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000864",
    },
    {
        "school": "Longview School",
        "district": "Montgomery County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240048000867",
    },
    {
        "school": "Lucy V. Barnsley Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000868",
    },
    {
        "school": "Luxmanor Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000869",
    },
    {
        "school": "Maryvale Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000872",
    },
    {
        "school": "Flora M. Singer Elementary School",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000873",
    },
    {
        "school": "Meadow Hall Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000874",
    },
    {
        "school": "Mill Creek Towne Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000875",
    },
    {
        "school": "Monocacy Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000876",
    },
    {
        "school": "Montgomery Blair High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000877",
    },
    {
        "school": "Montgomery Knolls Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000878",
    },
    {
        "school": "Montgomery Village Middle School",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000879",
    },
    {
        "school": "New Hampshire Estates Elem",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000881",
    },
    {
        "school": "Oak View Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000887",
    },
    {
        "school": "Oakland Terrace Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000888",
    },
    {
        "school": "Olney Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000889",
    },
    {
        "school": "Paint Branch High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000890",
    },
    {
        "school": "Parkland Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000891",
    },
    {
        "school": "Kensington Parkwood Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000892",
    },
    {
        "school": "Pine Crest Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000893",
    },
    {
        "school": "Piney Branch Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000894",
    },
    {
        "school": "Poolesville Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000896",
    },
    {
        "school": "Poolesville High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000897",
    },
    {
        "school": "Potomac Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000898",
    },
    {
        "school": "Redland Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000901",
    },
    {
        "school": "Richard Montgomery High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000902",
    },
    {
        "school": "Ridgeview Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000903",
    },
    {
        "school": "Ritchie Park Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000904",
    },
    {
        "school": "Rock Creek Forest Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000907",
    },
    {
        "school": "Rock View Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000908",
    },
    {
        "school": "Rock Creek Valley Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000909",
    },
    {
        "school": "Rockville High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000912",
    },
    {
        "school": "Rolling Terrace Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000913",
    },
    {
        "school": "Rosemary Hills Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000915",
    },
    {
        "school": "Rosemont Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000916",
    },
    {
        "school": "Seneca Valley High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000918",
    },
    {
        "school": "Seven Locks Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000919",
    },
    {
        "school": "Sherwood Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000920",
    },
    {
        "school": "Sherwood High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000921",
    },
    {
        "school": "Somerset Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000923",
    },
    {
        "school": "South Lake Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000924",
    },
    {
        "school": "Springbrook High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000926",
    },
    {
        "school": "Stedwick Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000927",
    },
    {
        "school": "Stonegate Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000929",
    },
    {
        "school": "Strathmore Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000930",
    },
    {
        "school": "Summit Hall Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000931",
    },
    {
        "school": "Takoma Park Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000932",
    },
    {
        "school": "Takoma Park Middle School",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000933",
    },
    {
        "school": "Thomas S. Wootton High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000934",
    },
    {
        "school": "Travilah Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000937",
    },
    {
        "school": "Twinbrook Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000939",
    },
    {
        "school": "Viers Mill Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000940",
    },
    {
        "school": "Walt Whitman High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000941",
    },
    {
        "school": "Walter Johnson High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000942",
    },
    {
        "school": "Washington Grove Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000943",
    },
    {
        "school": "Watkins Mill Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000944",
    },
    {
        "school": "Wayside Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000945",
    },
    {
        "school": "Weller Road Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000946",
    },
    {
        "school": "Beall Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000947",
    },
    {
        "school": "Westbrook Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000948",
    },
    {
        "school": "Westland Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000949",
    },
    {
        "school": "Westover Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000950",
    },
    {
        "school": "Wheaton High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000951",
    },
    {
        "school": "Wheaton Woods Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000952",
    },
    {
        "school": "Whetstone Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000953",
    },
    {
        "school": "White Oak Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000954",
    },
    {
        "school": "William Tyler Page Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000955",
    },
    {
        "school": "Winston Churchill High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000956",
    },
    {
        "school": "William H. Farquhar Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000957",
    },
    {
        "school": "Wood Acres Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000958",
    },
    {
        "school": "Woodfield Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000959",
    },
    {
        "school": "Woodlin Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000961",
    },
    {
        "school": "Wyngate Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048000963",
    },
    {
        "school": "Northwest High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001040",
    },
    {
        "school": "James Hubert Blake High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001044",
    },
    {
        "school": "Thomas Edison High School of Technology",
        "district": "Montgomery County Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240048001045",
    },
    {
        "school": "North Bethesda Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001118",
    },
    {
        "school": "Sligo Creek Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001122",
    },
    {
        "school": "Shady Grove Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001127",
    },
    {
        "school": "Silver Spring International Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001128",
    },
    {
        "school": "Spark M. Matsunaga Elementary School",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001181",
    },
    {
        "school": "John L Gildner Regional Inst for Children & Adol",
        "district": "Montgomery County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240048001398",
    },
    {
        "school": "Martin Luther King Jr. Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001417",
    },
    {
        "school": "Robert Frost Middle School",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001447",
    },
    {
        "school": "Lake Seneca Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001448",
    },
    {
        "school": "Tilden Middle School",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001450",
    },
    {
        "school": "Alternative Programs",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240048001451",
    },
    {
        "school": "North Chevy Chase Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001452",
    },
    {
        "school": "Flower Hill Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001454",
    },
    {
        "school": "Damascus High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001455",
    },
    {
        "school": "John T. Baker Middle School",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001456",
    },
    {
        "school": "Eastern Middle School",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001457",
    },
    {
        "school": "Sligo Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001458",
    },
    {
        "school": "Rock Terrace School",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240048001460",
    },
    {
        "school": "Clopper Mill Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001494",
    },
    {
        "school": "Waters Landing Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001508",
    },
    {
        "school": "Quince Orchard High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001509",
    },
    {
        "school": "Greencastle Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001510",
    },
    {
        "school": "Goshen Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001511",
    },
    {
        "school": "Strawberry Knoll Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001512",
    },
    {
        "school": "Stone Mill Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001513",
    },
    {
        "school": "Clearspring Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001514",
    },
    {
        "school": "Captain James E. Daly Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001523",
    },
    {
        "school": "Cloverly Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001524",
    },
    {
        "school": "Watkins Mill High",
        "district": "Montgomery County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001525",
    },
    {
        "school": "Cabin John Middle School",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001526",
    },
    {
        "school": "Thomas W. Pyle Middle School",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048009000",
    },
    {
        "school": "Briggs Chaney Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048090450",
    },
    {
        "school": "Brooke Grove Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048090451",
    },
    {
        "school": "Burnt Mills Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048090452",
    },
    {
        "school": "Francis Scott Key Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048090453",
    },
    {
        "school": "Rachel Carson Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048090454",
    },
    {
        "school": "Ronald McNair Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048090455",
    },
    {
        "school": "Sequoyah Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048090456",
    },
    {
        "school": "Judith A. Resnik Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048090479",
    },
    {
        "school": "Dr. Charles R. Drew Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048090480",
    },
    {
        "school": "Yorktown Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000200",
    },
    {
        "school": "Judith P. Hoyer Montessori",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000414",
    },
    {
        "school": "Kingsford Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000500",
    },
    {
        "school": "Cool Spring Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000510",
    },
    {
        "school": "Greenbelt Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000512",
    },
    {
        "school": "Scotchtown Hills Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000714",
    },
    {
        "school": "William Paca Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000729",
    },
    {
        "school": "Annapolis Road Academy",
        "district": "Prince George's County Public Schools",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240051000865",
    },
    {
        "school": "Perrywood Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000866",
    },
    {
        "school": "John Hanson Montessori",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000870",
    },
    {
        "school": "Adelphi Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000965",
    },
    {
        "school": "Allenwood Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000966",
    },
    {
        "school": "Apple Grove Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000969",
    },
    {
        "school": "Ardmore Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000970",
    },
    {
        "school": "Arrowhead Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000971",
    },
    {
        "school": "Avalon Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000972",
    },
    {
        "school": "Baden Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000973",
    },
    {
        "school": "Barnaby Manor Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000974",
    },
    {
        "school": "Beacon Heights Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000975",
    },
    {
        "school": "Beltsville Academy",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000978",
    },
    {
        "school": "Benjamin Tasker Middle School",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000982",
    },
    {
        "school": "Bladensburg Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000985",
    },
    {
        "school": "Bladensburg High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000987",
    },
    {
        "school": "Bond Mill Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000988",
    },
    {
        "school": "Bowie High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000990",
    },
    {
        "school": "Bradbury Heights Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000991",
    },
    {
        "school": "Brandywine Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000992",
    },
    {
        "school": "Buck Lodge Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000993",
    },
    {
        "school": "Calverton Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000995",
    },
    {
        "school": "Capitol Heights Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000997",
    },
    {
        "school": "Carmody Hills Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000998",
    },
    {
        "school": "Carole Highlands Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051000999",
    },
    {
        "school": "Carrollton Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001000",
    },
    {
        "school": "Catherine T. Reed Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001001",
    },
    {
        "school": "Central High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001002",
    },
    {
        "school": "Chapel Forge Early Childhood Center",
        "district": "Prince George's County Public Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240051001003",
    },
    {
        "school": "Charles Carroll Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001004",
    },
    {
        "school": "Cherokee Lane Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001006",
    },
    {
        "school": "Chillum Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001009",
    },
    {
        "school": "Clinton Grove Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001010",
    },
    {
        "school": "Columbia Park Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001012",
    },
    {
        "school": "Concord Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001013",
    },
    {
        "school": "Cooper Lane Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001014",
    },
    {
        "school": "Crossland High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001017",
    },
    {
        "school": "Deerfield Run Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001018",
    },
    {
        "school": "District Heights Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001019",
    },
    {
        "school": "Doswell E. Brooks Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001021",
    },
    {
        "school": "Duval High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001023",
    },
    {
        "school": "Dwight D. Eisenhower Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001024",
    },
    {
        "school": "Eleanor Roosevelt High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001027",
    },
    {
        "school": "Fairmont Heights High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001029",
    },
    {
        "school": "Flintstone Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001030",
    },
    {
        "school": "Forest Heights Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001031",
    },
    {
        "school": "Fort Foote Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001033",
    },
    {
        "school": "Drew Freeman Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001034",
    },
    {
        "school": "Francis T. Evans Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001035",
    },
    {
        "school": "Frederick Douglass High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001036",
    },
    {
        "school": "Friendly High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001038",
    },
    {
        "school": "Fort Washington Forest Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001039",
    },
    {
        "school": "Gaywood Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001041",
    },
    {
        "school": "Glassmanor Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001042",
    },
    {
        "school": "Glenarden Woods Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001043",
    },
    {
        "school": "Green Valley Academy at Edgar Allan Poe",
        "district": "Prince George's County Public Schools",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240051001047",
    },
    {
        "school": "Greenbelt Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001049",
    },
    {
        "school": "Francis Scott Key Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001050",
    },
    {
        "school": "Gwynn Park Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001051",
    },
    {
        "school": "Gwynn Park High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001052",
    },
    {
        "school": "H. W. Wheatley Early Childhood Center",
        "district": "Prince George's County Public Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240051001053",
    },
    {
        "school": "Northwestern Evening/Saturday High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240051001054",
    },
    {
        "school": "Heather Hills Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001056",
    },
    {
        "school": "High Bridge Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001058",
    },
    {
        "school": "High Point High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001059",
    },
    {
        "school": "Hillcrest Heights Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001060",
    },
    {
        "school": "Crossland Evening/Saturday High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240051001062",
    },
    {
        "school": "Hollywood Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001063",
    },
    {
        "school": "Hyattsville Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001064",
    },
    {
        "school": "Hyattsville Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001065",
    },
    {
        "school": "Indian Queen Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001066",
    },
    {
        "school": "Community Based Classrooms",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240051001067",
    },
    {
        "school": "J. Frank Dent Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001068",
    },
    {
        "school": "James H. Harrison Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001069",
    },
    {
        "school": "James McHenry Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001071",
    },
    {
        "school": "James Ryder Randall Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001072",
    },
    {
        "school": "John H. Bayne Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001075",
    },
    {
        "school": "Kenilworth Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001077",
    },
    {
        "school": "Kettering Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001082",
    },
    {
        "school": "Lamont Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001085",
    },
    {
        "school": "Langley Park/McCormick Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001087",
    },
    {
        "school": "Largo High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001089",
    },
    {
        "school": "Laurel Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001090",
    },
    {
        "school": "Laurel High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001092",
    },
    {
        "school": "Lewisdale Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001093",
    },
    {
        "school": "Longfields Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001094",
    },
    {
        "school": "Isaac J. Gourdine Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001095",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001097",
    },
    {
        "school": "Marlton Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001100",
    },
    {
        "school": "Martin Luther King Jr. Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001101",
    },
    {
        "school": "Mattaponi Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001103",
    },
    {
        "school": "Melwood Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001106",
    },
    {
        "school": "Montpelier Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001108",
    },
    {
        "school": "Mt Rainier Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001110",
    },
    {
        "school": "Nicholas Orem Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001112",
    },
    {
        "school": "North Forestville Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001113",
    },
    {
        "school": "Northwestern High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001114",
    },
    {
        "school": "Oaklands Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001117",
    },
    {
        "school": "Overlook Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001119",
    },
    {
        "school": "Oxon Hill Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001121",
    },
    {
        "school": "Oxon Hill High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001123",
    },
    {
        "school": "Paint Branch Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001124",
    },
    {
        "school": "Parkdale High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001126",
    },
    {
        "school": "Patuxent Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001129",
    },
    {
        "school": "Phyllis E. Williams Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001130",
    },
    {
        "school": "Pointer Ridge Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001131",
    },
    {
        "school": "Potomac Landing Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001132",
    },
    {
        "school": "Potomac High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001133",
    },
    {
        "school": "Frances Fuchs Early Childhood Center",
        "district": "Prince George's County Public Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240051001134",
    },
    {
        "school": "Highland Park Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001135",
    },
    {
        "school": "Princeton Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001136",
    },
    {
        "school": "Judge Sylvania W. Woods Sr. Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001137",
    },
    {
        "school": "Ridgecrest Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001138",
    },
    {
        "school": "Cesar Chavez Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001139",
    },
    {
        "school": "Riverdale Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001140",
    },
    {
        "school": "Robert Frost Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001142",
    },
    {
        "school": "Rockledge Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001144",
    },
    {
        "school": "Rogers Heights Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001146",
    },
    {
        "school": "Rose Valley Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001148",
    },
    {
        "school": "Samuel Chase Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001150",
    },
    {
        "school": "Samuel Ogle Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001152",
    },
    {
        "school": "Seabrook Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001154",
    },
    {
        "school": "Seat Pleasant Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001155",
    },
    {
        "school": "Springhill Lake Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001160",
    },
    {
        "school": "Suitland High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001164",
    },
    {
        "school": "Surrattsville High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001167",
    },
    {
        "school": "Tayac Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001170",
    },
    {
        "school": "Templeton Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001171",
    },
    {
        "school": "Thomas G. Pullen School",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001174",
    },
    {
        "school": "Thomas Johnson Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001175",
    },
    {
        "school": "Thomas S. Stone Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001176",
    },
    {
        "school": "Tulip Grove Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001177",
    },
    {
        "school": "University Park Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001178",
    },
    {
        "school": "Valley View Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001179",
    },
    {
        "school": "Waldon Woods Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001180",
    },
    {
        "school": "Rosaryville Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001182",
    },
    {
        "school": "Robert R. Gray Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001183",
    },
    {
        "school": "William Beanes Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001184",
    },
    {
        "school": "William Wirt Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001186",
    },
    {
        "school": "Woodmore Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001188",
    },
    {
        "school": "James E. Duckworth Regional Center",
        "district": "Prince George's County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240051001354",
    },
    {
        "school": "C. Elizabeth Rieg Regional Center",
        "district": "Prince George's County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240051001384",
    },
    {
        "school": "Woodridge Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001386",
    },
    {
        "school": "Margaret Brent Regional Center",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240051001419",
    },
    {
        "school": "Tall Oaks High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240051001424",
    },
    {
        "school": "Croom High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240051001463",
    },
    {
        "school": "Benjamin Stoddert Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001464",
    },
    {
        "school": "Thurgood Marshall Middle School",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001465",
    },
    {
        "school": "Stephen Decatur Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001469",
    },
    {
        "school": "Oxon Hill Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001471",
    },
    {
        "school": "Kettering Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001472",
    },
    {
        "school": "Kenmoor Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001473",
    },
    {
        "school": "Glenn Dale Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001474",
    },
    {
        "school": "James Madison Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001475",
    },
    {
        "school": "Walker Mill Middle",
        "district": "Prince George's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001477",
    },
    {
        "school": "Glenridge Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001495",
    },
    {
        "school": "William Schmidt Environmental Center",
        "district": "Prince George's County Public Schools",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240051002950",
    },
    {
        "school": "Charles Herbert Flowers High",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051002951",
    },
    {
        "school": "Howard B. Owens Science Center",
        "district": "Prince George's County Public Schools",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240051002952",
    },
    {
        "school": "Gladys Noon Spellman Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051090458",
    },
    {
        "school": "Park Avenue Elementary School",
        "district": "Auburn Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230261000626",
    },
    {
        "school": "Paris Elementary School",
        "district": "RSU 17/MSAD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231077000607",
    },
    {
        "school": "Bay Ridge Elementary",
        "district": "Cutler Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230006501020",
    },
    {
        "school": "Fort O'Brien School",
        "district": "Machiasport Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230006700561",
    },
    {
        "school": "Whiting Village School",
        "district": "Whiting Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230006800564",
    },
    {
        "school": "Biddeford Intermediate School",
        "district": "Biddeford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230315000622",
    },
    {
        "school": "Elm Street School-East Machias",
        "district": "East Machias Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230006200560",
    },
    {
        "school": "ME Sch of Science & Mathematics",
        "district": "ME Sch of Science & Mathematics",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230004900293",
    },
    {
        "school": "Dawn F Barnes Elementary Sch",
        "district": "Caswell Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230411000118",
    },
    {
        "school": "Easton Elementary School",
        "district": "Easton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230531000135",
    },
    {
        "school": "Easton Junior-Senior High Sch",
        "district": "Easton Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230531000136",
    },
    {
        "school": "Madawaska Middle/High School",
        "district": "Madawaska Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230780000214",
    },
    {
        "school": "Madawaska Elementary School",
        "district": "Madawaska Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230780000282",
    },
    {
        "school": "Presque Isle Reg Career & Tech Ctr",
        "district": "RSU 79/MSAD 01",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231086000152",
    },
    {
        "school": "Eva Hoyt Zippel School",
        "district": "RSU 79/MSAD 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231086000367",
    },
    {
        "school": "Mapleton Elementary School",
        "district": "RSU 79/MSAD 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231086000369",
    },
    {
        "school": "Pine Street Elementary School",
        "district": "RSU 79/MSAD 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231086000370",
    },
    {
        "school": "Presque Isle High School",
        "district": "RSU 79/MSAD 01",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231086000371",
    },
    {
        "school": "Presque Isle Middle School",
        "district": "RSU 79/MSAD 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231086000372",
    },
    {
        "school": "Fort Fairfield Middle/High School",
        "district": "RSU 86/MSAD 20",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231089000375",
    },
    {
        "school": "Fort Fairfield Elementary School",
        "district": "RSU 86/MSAD 20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231089001052",
    },
    {
        "school": "Van Buren Regional Technology Ctr",
        "district": "RSU 88/MSAD 24",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231101000176",
    },
    {
        "school": "Van Buren District Secondary Sch",
        "district": "RSU 88/MSAD 24",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231101000396",
    },
    {
        "school": "Fort Kent Community High School",
        "district": "MSAD 27",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231110000405",
    },
    {
        "school": "Fort Kent Elementary School",
        "district": "MSAD 27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231110000406",
    },
    {
        "school": "Houlton Southside School",
        "district": "RSU 29/MSAD 29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231116000035",
    },
    {
        "school": "Houlton Junior High School",
        "district": "RSU 29/MSAD 29",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231116000301",
    },
    {
        "school": "Houlton Elementary School",
        "district": "RSU 29/MSAD 29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231116000415",
    },
    {
        "school": "Houlton High School",
        "district": "RSU 29/MSAD 29",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231116000416",
    },
    {
        "school": "St John Valley Technology Center",
        "district": "RSU 33/MSAD 33",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231131000178",
    },
    {
        "school": "Dr Levesque Elementary School",
        "district": "RSU 33/MSAD 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231131000437",
    },
    {
        "school": "Wisdom Middle High School",
        "district": "RSU 33/MSAD 33",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231131000439",
    },
    {
        "school": "Central Aroostook Jr-Sr H S",
        "district": "RSU 42/MSAD 42",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231161000497",
    },
    {
        "school": "Fort Street School",
        "district": "RSU 42/MSAD 42",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231161000499",
    },
    {
        "school": "Washburn District High School",
        "district": "RSU 45/MSAD 45",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231170000514",
    },
    {
        "school": "Washburn District Elem School",
        "district": "RSU 45/MSAD 45",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231170001033",
    },
    {
        "school": "Region Two Sch of Applied Tech",
        "district": "Houlton-Region 2",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231226000215",
    },
    {
        "school": "Woodland Consolidated Sch",
        "district": "Woodland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231401000647",
    },
    {
        "school": "Mill Pond School",
        "district": "RSU 70/MSAD 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476200797",
    },
    {
        "school": "Mt Abram Regional High School",
        "district": "RSU 58/MSAD 58",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231430000686",
    },
    {
        "school": "Strong Elementary School",
        "district": "RSU 58/MSAD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231430000690",
    },
    {
        "school": "Kingfield Elementary School",
        "district": "RSU 58/MSAD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231430000941",
    },
    {
        "school": "Phillips Elementary School",
        "district": "RSU 58/MSAD 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231430001011",
    },
    {
        "school": "Penquis Valley Middle/High School",
        "district": "RSU 41/MSAD 41",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231158000493",
    },
    {
        "school": "Se Do Mo Cha Middle School",
        "district": "RSU 68/MSAD 68",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476100794",
    },
    {
        "school": "Alexander Elementary",
        "district": "Alexander Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230228000975",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Baileyville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230273000044",
    },
    {
        "school": "Woodland Jr-Sr High School",
        "district": "Baileyville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230273000045",
    },
    {
        "school": "Beals Elementary School",
        "district": "Beals Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230295000070",
    },
    {
        "school": "St Croix Regional Technical Center",
        "district": "Calais Public Schools",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "230387000074",
    },
    {
        "school": "Calais Elementary School",
        "district": "Calais Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230387000105",
    },
    {
        "school": "Calais Middle/High School",
        "district": "Calais Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230387000106",
    },
    {
        "school": "Charlotte Elementary School",
        "district": "Charlotte Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230416000119",
    },
    {
        "school": "Shead High School",
        "district": "Eastport Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230536000138",
    },
    {
        "school": "Eastport Elementary School",
        "district": "Eastport Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230536000912",
    },
    {
        "school": "East Range II CSD School",
        "district": "East Range CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230538000139",
    },
    {
        "school": "Jonesboro Elementary School",
        "district": "Jonesboro Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230690000177",
    },
    {
        "school": "Jonesport Elementary School",
        "district": "Jonesport Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230710000917",
    },
    {
        "school": "Machias Memorial High School",
        "district": "Machias Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230771000209",
    },
    {
        "school": "Rose M Gaffney School",
        "district": "Machias Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230771000210",
    },
    {
        "school": "Coastal Wash Cty Inst of Tech",
        "district": "Machias Public Schools",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "230771000981",
    },
    {
        "school": "Jonesport-Beals High School",
        "district": "Moosabec CSD",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230840000920",
    },
    {
        "school": "Pembroke Elementary School",
        "district": "Pembroke Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230956000259",
    },
    {
        "school": "Perry Elementary School",
        "district": "Perry Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230965001006",
    },
    {
        "school": "Princeton Elementary School",
        "district": "Princeton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230999001029",
    },
    {
        "school": "East Grand School",
        "district": "RSU 84/MSAD 14",
        "level": "Other",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231068000344",
    },
    {
        "school": "Lubec Consolidated School",
        "district": "RSU 85/MSAD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231083000365",
    },
    {
        "school": "Daniel W Merritt School",
        "district": "RSU 37/MSAD 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231143000463",
    },
    {
        "school": "Milbridge Elementary School",
        "district": "RSU 37/MSAD 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231143000465",
    },
    {
        "school": "Narraguagus High School",
        "district": "RSU 37/MSAD 37",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231143000466",
    },
    {
        "school": "Harrington Elementary School",
        "district": "RSU 37/MSAD 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231143000928",
    },
    {
        "school": "Wesley Elementary School",
        "district": "Wesley Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231350001048",
    },
    {
        "school": "Connor Consolidated School",
        "district": "Education in Unorganized Terr",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231210000958",
    },
    {
        "school": "Lillian Parks Hussey School",
        "district": "Augusta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230264000040",
    },
    {
        "school": "Sylvio J Gilbert School",
        "district": "Augusta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230264000042",
    },
    {
        "school": "Capital Area Technical Center",
        "district": "Augusta Public Schools",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "230264000057",
    },
    {
        "school": "Farrington School",
        "district": "Augusta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230264001002",
    },
    {
        "school": "Lincoln School",
        "district": "Augusta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230264001003",
    },
    {
        "school": "Mid-Maine Technical Center",
        "district": "Waterville Public Schools",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231335000144",
    },
    {
        "school": "George J Mitchell School",
        "district": "Waterville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231335000604",
    },
    {
        "school": "Albert S Hall School",
        "district": "Waterville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231335000605",
    },
    {
        "school": "Waterville Senior High School",
        "district": "Waterville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231335000606",
    },
    {
        "school": "Waterville Junior High School",
        "district": "Waterville Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231335000934",
    },
    {
        "school": "Kingman Elementary School",
        "district": "Education in Unorganized Terr",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231210000960",
    },
    {
        "school": "Edmunds Consolidated School",
        "district": "Education in Unorganized Terr",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231210000959",
    },
    {
        "school": "Frank I Brown Elementary School",
        "district": "South Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231233000586",
    },
    {
        "school": "James Otis Kaler Elementary School",
        "district": "South Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231233000716",
    },
    {
        "school": "Arthur R. Gould Sch--LCYDC",
        "district": "Arthur R. Gould Sch--LCYDC",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230005000377",
    },
    {
        "school": "Waldo T Skillin Elementary School",
        "district": "South Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231233000033",
    },
    {
        "school": "Daniel F. Mahoney Middle School",
        "district": "South Portland Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231233000574",
    },
    {
        "school": "Dora L Small Elementary School",
        "district": "South Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231233000575",
    },
    {
        "school": "Dyer Elementary School",
        "district": "South Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231233000578",
    },
    {
        "school": "Memorial Middle School",
        "district": "South Portland Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231233000581",
    },
    {
        "school": "South Portland High School",
        "district": "South Portland Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231233000585",
    },
    {
        "school": "Mid-Coast Sch of Tech-Region 8",
        "district": "Rockland-Region 8",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "230718000241",
    },
    {
        "school": "Winthrop High School",
        "district": "Winthrop Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231397000732",
    },
    {
        "school": "Lincolnville Central School",
        "district": "Lincolnville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230745000601",
    },
    {
        "school": "Fayette Central School",
        "district": "Fayette Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230000800455",
    },
    {
        "school": "Laura E Richards School",
        "district": "RSU 11/MSAD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231059000023",
    },
    {
        "school": "River View Community School",
        "district": "RSU 11/MSAD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231059000024",
    },
    {
        "school": "Helen Thompson School",
        "district": "RSU 11/MSAD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231059000300",
    },
    {
        "school": "Gardiner Area High School",
        "district": "RSU 11/MSAD 11",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231059000329",
    },
    {
        "school": "Gardiner Regional Middle School",
        "district": "RSU 11/MSAD 11",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231059000330",
    },
    {
        "school": "Pittston-Randolph Consolidated School",
        "district": "RSU 11/MSAD 11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231059000332",
    },
    {
        "school": "Vassalboro Community School",
        "district": "Vassalboro Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231311001046",
    },
    {
        "school": "Winslow Elementary School",
        "district": "Winslow Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231386000034",
    },
    {
        "school": "Winslow High School",
        "district": "Winslow Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231386000638",
    },
    {
        "school": "Winslow Junior High School",
        "district": "Winslow Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231386000639",
    },
    {
        "school": "Winthrop Grade School",
        "district": "Winthrop Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231397000641",
    },
    {
        "school": "Winthrop Middle School",
        "district": "Winthrop Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231397000643",
    },
    {
        "school": "Islesboro Central School",
        "district": "Islesboro Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230681000171",
    },
    {
        "school": "Monroe Elementary School",
        "district": "RSU 03/MSAD 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231152000471",
    },
    {
        "school": "Morse Memorial School",
        "district": "RSU 03/MSAD 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231152000472",
    },
    {
        "school": "Mt View High School",
        "district": "RSU 03/MSAD 03",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231152000473",
    },
    {
        "school": "Mt View Middle School",
        "district": "RSU 03/MSAD 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231152000474",
    },
    {
        "school": "Mt View Elementary School",
        "district": "RSU 03/MSAD 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231152000475",
    },
    {
        "school": "Troy Central School",
        "district": "RSU 03/MSAD 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231152000476",
    },
    {
        "school": "Unity Elementary School",
        "district": "RSU 03/MSAD 03",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231152000477",
    },
    {
        "school": "Walker Memorial School",
        "district": "RSU 03/MSAD 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231152000478",
    },
    {
        "school": "Waldo County Tech Ctr-Region 7",
        "district": "Waldo-Region 7",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231321000219",
    },
    {
        "school": "Airline Community School",
        "district": "Airline CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230250000007",
    },
    {
        "school": "Conners-Emerson School",
        "district": "Bar Harbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230285000060",
    },
    {
        "school": "Blue Hill Consolidated School",
        "district": "Blue Hill Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230321000079",
    },
    {
        "school": "Brooklin School",
        "district": "Brooklin Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230361000254",
    },
    {
        "school": "Brooksville Elementary School",
        "district": "Brooksville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230364000094",
    },
    {
        "school": "Adams School",
        "district": "Castine Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230408000117",
    },
    {
        "school": "Dedham School",
        "district": "Dedham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230489000125",
    },
    {
        "school": "Deer Isle-Stonington High Sch",
        "district": "Deer Isle-Stonington CSD",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230489500127",
    },
    {
        "school": "Deer Isle-Stonington Elementary Sch",
        "district": "Deer Isle-Stonington CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230489500509",
    },
    {
        "school": "Hancock County Technical Center",
        "district": "Ellsworth Public Schools",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "230550000078",
    },
    {
        "school": "Ellsworth High School",
        "district": "Ellsworth Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230550000270",
    },
    {
        "school": "Hancock Grammar School",
        "district": "Hancock Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230626000166",
    },
    {
        "school": "Lamoine Consolidated School",
        "district": "Lamoine Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230725000186",
    },
    {
        "school": "Frenchboro Elementary School",
        "district": "Frenchboro Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230759000208",
    },
    {
        "school": "Mt Desert Elementary School",
        "district": "Mount Desert Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230849000232",
    },
    {
        "school": "Mt Desert Island High School",
        "district": "Mt Desert CSD",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230850000061",
    },
    {
        "school": "Beech Hill School",
        "district": "Otis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230939000257",
    },
    {
        "school": "Penobscot Elementary School",
        "district": "Penobscot Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230963000260",
    },
    {
        "school": "Swans Island Elementary School",
        "district": "MSAD 76",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231191001056",
    },
    {
        "school": "Sedgwick Elementary School",
        "district": "Sedgwick Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231214001045",
    },
    {
        "school": "Pemetic Elementary School",
        "district": "Southwest Harbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231239000589",
    },
    {
        "school": "Surry Elementary School",
        "district": "Surry Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231275000993",
    },
    {
        "school": "Tremont Consolidated School",
        "district": "Tremont Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231296000594",
    },
    {
        "school": "Trenton Elementary School",
        "district": "Trenton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231298000595",
    },
    {
        "school": "Abraham Lincoln School",
        "district": "Bangor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230282000046",
    },
    {
        "school": "Bangor High School",
        "district": "Bangor Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230282000047",
    },
    {
        "school": "Downeast School",
        "district": "Bangor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230282000049",
    },
    {
        "school": "Fairmount School",
        "district": "Bangor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230282000050",
    },
    {
        "school": "James F. Doughty School",
        "district": "Bangor Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230282000051",
    },
    {
        "school": "Fruit Street School",
        "district": "Bangor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230282000053",
    },
    {
        "school": "William S. Cohen School",
        "district": "Bangor Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230282000054",
    },
    {
        "school": "Vine Street School",
        "district": "Bangor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230282000058",
    },
    {
        "school": "Mary Snow School",
        "district": "Bangor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230282001004",
    },
    {
        "school": "Fourteenth Street School",
        "district": "Bangor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230282001005",
    },
    {
        "school": "Brewer High School",
        "district": "Brewer Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230351000084",
    },
    {
        "school": "Opal Myrick Elementary School",
        "district": "East Millinocket Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230528000133",
    },
    {
        "school": "Schenck High School",
        "district": "East Millinocket Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230528000134",
    },
    {
        "school": "Glenburn Elementary School",
        "district": "Glenburn Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230600000155",
    },
    {
        "school": "Helen S Dunn Elementary School",
        "district": "Greenbush Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230618000165",
    },
    {
        "school": "Patricia A Duran School",
        "district": "Hermon Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230651000168",
    },
    {
        "school": "Hermon Middle School",
        "district": "Hermon Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230651000169",
    },
    {
        "school": "Hermon High School",
        "district": "Hermon Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230651000281",
    },
    {
        "school": "Medway Middle School",
        "district": "Medway Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230816000220",
    },
    {
        "school": "Dr Lewis S Libby School",
        "district": "Milford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230825000222",
    },
    {
        "school": "Granite Street School",
        "district": "Millinocket Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230828000224",
    },
    {
        "school": "Stearns Jr-Sr High School",
        "district": "Millinocket Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230828000227",
    },
    {
        "school": "No Penobscot Tech-Region 3",
        "district": "Lincoln-Region 3",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "230910000233",
    },
    {
        "school": "Center Drive School",
        "district": "Orrington Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230933000255",
    },
    {
        "school": "Suzanne M Smith Elementary School",
        "district": "RSU 87/MSAD 23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231098000353",
    },
    {
        "school": "Caravel Middle School",
        "district": "RSU 87/MSAD 23",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231098000390",
    },
    {
        "school": "Carmel Elementary School",
        "district": "RSU 87/MSAD 23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231098000391",
    },
    {
        "school": "Lee/Winn School",
        "district": "RSU 30/MSAD 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231122000029",
    },
    {
        "school": "Mt Jefferson Jr High School",
        "district": "RSU 30/MSAD 30",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231122000427",
    },
    {
        "school": "Enfield Station Elementary School",
        "district": "RSU 31/MSAD 31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231125000043",
    },
    {
        "school": "Hichborn Middle School",
        "district": "RSU 31/MSAD 31",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231125000431",
    },
    {
        "school": "Penobscot Valley High School",
        "district": "RSU 31/MSAD 31",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231125000432",
    },
    {
        "school": "United Technologies Ctr-Region 4",
        "district": "Bangor-Region 4",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231237000216",
    },
    {
        "school": "Veazie Community School",
        "district": "Veazie Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231314000384",
    },
    {
        "school": "Central High School",
        "district": "RSU 64/MSAD 64",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231444000715",
    },
    {
        "school": "Central Middle School",
        "district": "RSU 64/MSAD 64",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231444000943",
    },
    {
        "school": "Eddington School",
        "district": "RSU 63/MSAD 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231447000720",
    },
    {
        "school": "Holbrook School",
        "district": "RSU 63/MSAD 63",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231447000721",
    },
    {
        "school": "Holden School",
        "district": "RSU 63/MSAD 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231447000722",
    },
    {
        "school": "Tri-County Technical Center",
        "district": "MSAD 46",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231453000179",
    },
    {
        "school": "Dexter Regional High School",
        "district": "MSAD 46",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231453000734",
    },
    {
        "school": "Harpswell Community School",
        "district": "RSU 75/MSAD 75",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476800817",
    },
    {
        "school": "Boothbay Region Elem School",
        "district": "Boothbay-Boothbay Hbr CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230329000080",
    },
    {
        "school": "Boothbay Region High School",
        "district": "Boothbay-Boothbay Hbr CSD",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230329000081",
    },
    {
        "school": "Bristol Consolidated School",
        "district": "Bristol Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230360000090",
    },
    {
        "school": "Edgecomb Eddy School",
        "district": "Edgecomb Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230540000140",
    },
    {
        "school": "Great Salt Bay Community School",
        "district": "Great Salt Bay CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230616000916",
    },
    {
        "school": "Jefferson Village School",
        "district": "Jefferson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230687000175",
    },
    {
        "school": "Monhegan Island School",
        "district": "Monhegan Plt School Dept",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230834000229",
    },
    {
        "school": "Nobleboro Central School",
        "district": "Nobleboro Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230894000237",
    },
    {
        "school": "South Bristol Elementary School",
        "district": "South Bristol Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231230000572",
    },
    {
        "school": "Southport Central School",
        "district": "Southport Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231236000588",
    },
    {
        "school": "Georgetown Central School",
        "district": "Georgetown Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230597000154",
    },
    {
        "school": "West Bath School",
        "district": "West Bath Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231353000615",
    },
    {
        "school": "Mt Ararat Middle School",
        "district": "RSU 75/MSAD 75",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476800055",
    },
    {
        "school": "Bowdoin Central School",
        "district": "RSU 75/MSAD 75",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476800815",
    },
    {
        "school": "Bowdoinham Community School",
        "district": "RSU 75/MSAD 75",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476800816",
    },
    {
        "school": "Mt Ararat High School",
        "district": "RSU 75/MSAD 75",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476800819",
    },
    {
        "school": "Williams-Cone School",
        "district": "RSU 75/MSAD 75",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476800821",
    },
    {
        "school": "Woodside Elementary School",
        "district": "RSU 75/MSAD 75",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476801055",
    },
    {
        "school": "Brunswick Jr High School",
        "district": "Brunswick Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230378000096",
    },
    {
        "school": "Coffin School",
        "district": "Brunswick Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230378000097",
    },
    {
        "school": "Brunswick High School",
        "district": "Brunswick Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230378000268",
    },
    {
        "school": "Maine Region Ten Technical High Sch",
        "district": "Brunswick-Region 10",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "230530000249",
    },
    {
        "school": "Lisbon Community School",
        "district": "Lisbon Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230753000583",
    },
    {
        "school": "Hebron Station School",
        "district": "RSU 17/MSAD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231077000555",
    },
    {
        "school": "Harrison Elementary",
        "district": "RSU 17/MSAD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231077000984",
    },
    {
        "school": "Region 9 Sch of Applied Technology",
        "district": "Rumford-Region 9",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "230911000247",
    },
    {
        "school": "Agnes Gray School",
        "district": "RSU 17/MSAD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231077000354",
    },
    {
        "school": "Oxford Hills Comprehensive H S",
        "district": "RSU 17/MSAD 17",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231077000361",
    },
    {
        "school": "Oxford Hills Middle School",
        "district": "RSU 17/MSAD 17",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231077000362",
    },
    {
        "school": "Waterford Memorial School",
        "district": "RSU 17/MSAD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231077000363",
    },
    {
        "school": "Guy E Rowe School",
        "district": "RSU 17/MSAD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231077000925",
    },
    {
        "school": "Otisfield Community School",
        "district": "RSU 17/MSAD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231077001032",
    },
    {
        "school": "Oxford Elementary School",
        "district": "RSU 17/MSAD 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231077001051",
    },
    {
        "school": "Crescent Park School",
        "district": "RSU 44/MSAD 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231167000506",
    },
    {
        "school": "Telstar High School",
        "district": "RSU 44/MSAD 44",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231167000510",
    },
    {
        "school": "Woodstock School",
        "district": "RSU 44/MSAD 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231167000990",
    },
    {
        "school": "Telstar Middle School",
        "district": "RSU 44/MSAD 44",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231167001010",
    },
    {
        "school": "Oxford Hills Tech - Region 11",
        "district": "Oxford-Region 11",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231232000253",
    },
    {
        "school": "Sacopee Valley High Sch",
        "district": "RSU 55/MSAD 55",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231419000667",
    },
    {
        "school": "Sacopee Valley Elementary School",
        "district": "RSU 55/MSAD 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231419000995",
    },
    {
        "school": "New Suncook School",
        "district": "RSU 72/MSAD 72",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476500807",
    },
    {
        "school": "Denmark Elementary School",
        "district": "RSU 72/MSAD 72",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476501025",
    },
    {
        "school": "East Auburn Community School",
        "district": "Auburn Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230261000012",
    },
    {
        "school": "Edward Little High School",
        "district": "Auburn Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230261000013",
    },
    {
        "school": "Fairview School",
        "district": "Auburn Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230261000014",
    },
    {
        "school": "Sherwood Heights Elementary Sch",
        "district": "Auburn Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230261000018",
    },
    {
        "school": "Walton School",
        "district": "Auburn Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230261000020",
    },
    {
        "school": "Washburn School",
        "district": "Auburn Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230261000021",
    },
    {
        "school": "Auburn Middle School",
        "district": "Auburn Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230261000907",
    },
    {
        "school": "Lewiston Regional Technology Ctr",
        "district": "Lewiston Public Schools",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "230732000091",
    },
    {
        "school": "Farwell Elementary School",
        "district": "Lewiston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230732000187",
    },
    {
        "school": "Lewiston High School",
        "district": "Lewiston Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230732000190",
    },
    {
        "school": "Lewiston Middle School",
        "district": "Lewiston Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230732000191",
    },
    {
        "school": "Montello School",
        "district": "Lewiston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230732000193",
    },
    {
        "school": "Thomas J McMahon Elementary Sch",
        "district": "Lewiston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230732000196",
    },
    {
        "school": "Lisbon High School",
        "district": "Lisbon Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230753000202",
    },
    {
        "school": "Philip W Sugg Middle School",
        "district": "Lisbon Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230753000204",
    },
    {
        "school": "Turner Primary School",
        "district": "RSU 52/MSAD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231416000027",
    },
    {
        "school": "Tripp Middle School",
        "district": "RSU 52/MSAD 52",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231416000656",
    },
    {
        "school": "Greene Central School",
        "district": "RSU 52/MSAD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231416000657",
    },
    {
        "school": "Leavitt Area High School",
        "district": "RSU 52/MSAD 52",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231416000658",
    },
    {
        "school": "Leeds Central School",
        "district": "RSU 52/MSAD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231416000659",
    },
    {
        "school": "Turner Elementary School",
        "district": "RSU 52/MSAD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231416000660",
    },
    {
        "school": "Gorham Middle School",
        "district": "Gorham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230606000688",
    },
    {
        "school": "Casco Bay High School",
        "district": "Portland Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000603",
    },
    {
        "school": "Greely Middle School",
        "district": "RSU 51/MSAD 51",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231424000577",
    },
    {
        "school": "Long Island Elementary School",
        "district": "Long Island Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230000900032",
    },
    {
        "school": "Cape Elizabeth High School",
        "district": "Cape Elizabeth Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230393000108",
    },
    {
        "school": "Cape Elizabeth Middle School",
        "district": "Cape Elizabeth Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230393000109",
    },
    {
        "school": "Pond Cove Elementary",
        "district": "Cape Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230393000110",
    },
    {
        "school": "Falmouth High School",
        "district": "Falmouth Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230567000145",
    },
    {
        "school": "Falmouth Middle School",
        "district": "Falmouth Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230567000914",
    },
    {
        "school": "Gorham High School",
        "district": "Gorham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230606000158",
    },
    {
        "school": "Village Elementary School-Gorham",
        "district": "Gorham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230606000160",
    },
    {
        "school": "Narragansett Elementary School",
        "district": "Gorham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230606000915",
    },
    {
        "school": "Portland Arts & Technology H S",
        "district": "Portland Public Schools",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "230993000130",
    },
    {
        "school": "Cliff Island School",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000267",
    },
    {
        "school": "Deering High School",
        "district": "Portland Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000269",
    },
    {
        "school": "Amanda C Rowe School",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000271",
    },
    {
        "school": "Harrison Lyseth Elem School",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000272",
    },
    {
        "school": "Howard C Reiche Community Sch",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000273",
    },
    {
        "school": "King Middle School",
        "district": "Portland Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000274",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Portland Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000275",
    },
    {
        "school": "Longfellow School-Portland",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000277",
    },
    {
        "school": "Lyman Moore Middle School",
        "district": "Portland Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000278",
    },
    {
        "school": "East End Community School",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000279",
    },
    {
        "school": "Peaks Island School",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000283",
    },
    {
        "school": "Portland High School",
        "district": "Portland Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000284",
    },
    {
        "school": "Riverton School",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993000286",
    },
    {
        "school": "Presumpscot School",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993001007",
    },
    {
        "school": "Blue Point School",
        "district": "Scarborough Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231053000319",
    },
    {
        "school": "Eight Corners Elementary School",
        "district": "Scarborough Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231053000321",
    },
    {
        "school": "Pleasant Hill School",
        "district": "Scarborough Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231053000324",
    },
    {
        "school": "Scarborough High School",
        "district": "Scarborough Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231053000325",
    },
    {
        "school": "Scarborough Middle School",
        "district": "Scarborough Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231053000326",
    },
    {
        "school": "Wentworth School",
        "district": "Scarborough Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231053000923",
    },
    {
        "school": "Gray-New Gloucester High School",
        "district": "RSU 15/MSAD 15",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231071000346",
    },
    {
        "school": "Memorial School",
        "district": "RSU 15/MSAD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231071000347",
    },
    {
        "school": "Russell School",
        "district": "RSU 15/MSAD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231071000348",
    },
    {
        "school": "Burchard A Dunn School",
        "district": "RSU 15/MSAD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231071000420",
    },
    {
        "school": "Gray-New Gloucester Middle School",
        "district": "RSU 15/MSAD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231071001019",
    },
    {
        "school": "Westbrook Regional Technology Ctr",
        "district": "Westbrook Public Schools",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231356000147",
    },
    {
        "school": "Congin School",
        "district": "Westbrook Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231356000616",
    },
    {
        "school": "Oxford-Cumberland Canal School",
        "district": "Westbrook Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231356000618",
    },
    {
        "school": "Saccarappa School",
        "district": "Westbrook Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231356000621",
    },
    {
        "school": "Westbrook High School",
        "district": "Westbrook Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231356000623",
    },
    {
        "school": "Westbrook Middle School",
        "district": "Westbrook Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231356000624",
    },
    {
        "school": "Frank H Harrison Middle School",
        "district": "Yarmouth Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231410000031",
    },
    {
        "school": "William H Rowe School",
        "district": "Yarmouth Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231410000650",
    },
    {
        "school": "Yarmouth Elementary School",
        "district": "Yarmouth Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231410000651",
    },
    {
        "school": "Yarmouth High School",
        "district": "Yarmouth Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231410000652",
    },
    {
        "school": "Songo Locks School",
        "district": "RSU 61/MSAD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231421000052",
    },
    {
        "school": "Lake Region Vocational Center",
        "district": "RSU 61/MSAD 61",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231421000189",
    },
    {
        "school": "Stevens Brook School",
        "district": "RSU 61/MSAD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231421000670",
    },
    {
        "school": "Lake Region High School",
        "district": "RSU 61/MSAD 61",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231421000673",
    },
    {
        "school": "Lake Region Middle School",
        "district": "RSU 61/MSAD 61",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231421000939",
    },
    {
        "school": "Greely High School",
        "district": "RSU 51/MSAD 51",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231424000679",
    },
    {
        "school": "Mabel I Wilson School",
        "district": "RSU 51/MSAD 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231424000681",
    },
    {
        "school": "Greely Middle School 4-5",
        "district": "RSU 51/MSAD 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231424000682",
    },
    {
        "school": "Bonny Eagle High School",
        "district": "RSU 06/MSAD 06",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231179000531",
    },
    {
        "school": "George E Jack School",
        "district": "RSU 06/MSAD 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231179000535",
    },
    {
        "school": "Steep Falls Elementary School",
        "district": "RSU 06/MSAD 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231179000543",
    },
    {
        "school": "Edna Libby Elementary School",
        "district": "RSU 06/MSAD 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231179000930",
    },
    {
        "school": "Acton Elementary School",
        "district": "Acton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230222000001",
    },
    {
        "school": "Biddeford Regional Ctr of Tech",
        "district": "Biddeford Public Schools",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "230315000064",
    },
    {
        "school": "Biddeford High School",
        "district": "Biddeford Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230315000072",
    },
    {
        "school": "John F Kennedy Memorial School",
        "district": "Biddeford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230315000076",
    },
    {
        "school": "Biddeford Middle School",
        "district": "Biddeford Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230315001017",
    },
    {
        "school": "Biddeford Primary School",
        "district": "Biddeford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230315001042",
    },
    {
        "school": "Dayton Consolidated School",
        "district": "Dayton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230486000124",
    },
    {
        "school": "Shapleigh School",
        "district": "Kittery Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230714000182",
    },
    {
        "school": "Horace Mitchell Primary School",
        "district": "Kittery Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230714000183",
    },
    {
        "school": "Robert W Traip Academy",
        "district": "Kittery Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230714000184",
    },
    {
        "school": "C K Burns School",
        "district": "Saco Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231038000306",
    },
    {
        "school": "Governor John Fairfield School",
        "district": "Saco Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231038000307",
    },
    {
        "school": "Saco Middle School",
        "district": "Saco Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231038000308",
    },
    {
        "school": "Young School",
        "district": "Saco Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231038000309",
    },
    {
        "school": "Central School",
        "district": "RSU 35/MSAD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231137000451",
    },
    {
        "school": "Eliot Elementary School",
        "district": "RSU 35/MSAD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231137000452",
    },
    {
        "school": "Marshwood Middle School",
        "district": "RSU 35/MSAD 35",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231137000453",
    },
    {
        "school": "Marshwood Great Works School",
        "district": "RSU 35/MSAD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231137000454",
    },
    {
        "school": "Marshwood High School",
        "district": "RSU 35/MSAD 35",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231137000491",
    },
    {
        "school": "Bonny Eagle Middle School",
        "district": "RSU 06/MSAD 06",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231179000532",
    },
    {
        "school": "H B Emery Jr Memorial School",
        "district": "RSU 06/MSAD 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231179000536",
    },
    {
        "school": "Hollis School",
        "district": "RSU 06/MSAD 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231179000538",
    },
    {
        "school": "Wells Elementary School",
        "district": "Wells-Ogunquit CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231349000611",
    },
    {
        "school": "Wells High School",
        "district": "Wells-Ogunquit CSD",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231349000612",
    },
    {
        "school": "Wells Junior High School",
        "district": "Wells-Ogunquit CSD",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231349000613",
    },
    {
        "school": "York High School",
        "district": "York Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231413000653",
    },
    {
        "school": "York Middle School",
        "district": "York Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231413000654",
    },
    {
        "school": "Village Elementary School-York",
        "district": "York Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231413000655",
    },
    {
        "school": "Coastal Ridge Elementary",
        "district": "York Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231413001049",
    },
    {
        "school": "Massabesic High School",
        "district": "RSU 57/MSAD 57",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231467000775",
    },
    {
        "school": "Shapleigh Memorial School",
        "district": "RSU 57/MSAD 57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231467000778",
    },
    {
        "school": "Waterboro Elementary School",
        "district": "RSU 57/MSAD 57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231467000779",
    },
    {
        "school": "Lyman Elementary School",
        "district": "RSU 57/MSAD 57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231467000951",
    },
    {
        "school": "Alfred Elementary School",
        "district": "RSU 57/MSAD 57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231467000999",
    },
    {
        "school": "Line Elementary",
        "district": "RSU 57/MSAD 57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231467001013",
    },
    {
        "school": "Noble High School",
        "district": "RSU 60/MSAD 60",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231470000512",
    },
    {
        "school": "Lebanon Elementary School",
        "district": "RSU 60/MSAD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231470000781",
    },
    {
        "school": "Noble Middle School",
        "district": "RSU 60/MSAD 60",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231470000783",
    },
    {
        "school": "North Berwick Elementary School",
        "district": "RSU 60/MSAD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231470001001",
    },
    {
        "school": "Vinalhaven School",
        "district": "RSU 08/MSAD 08",
        "level": "Other",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231185000731",
    },
    {
        "school": "Camden Hills Regional H S",
        "district": "Five Town CSD",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230005300504",
    },
    {
        "school": "Appleton Village School",
        "district": "Appleton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230251000906",
    },
    {
        "school": "Hope Elementary School",
        "district": "Hope Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230661000980",
    },
    {
        "school": "Isle au Haut Rural School",
        "district": "Isle Au Haut Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230678000170",
    },
    {
        "school": "Camden-Rockport Middle School",
        "district": "RSU 28/MSAD 28",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231113000412",
    },
    {
        "school": "Camden-Rockport Elementary School",
        "district": "RSU 28/MSAD 28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231113000413",
    },
    {
        "school": "Friendship Village School",
        "district": "RSU 40/MSAD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231155000482",
    },
    {
        "school": "Prescott Memorial School",
        "district": "RSU 40/MSAD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231155000485",
    },
    {
        "school": "Union Elementary",
        "district": "RSU 40/MSAD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231155000486",
    },
    {
        "school": "Warren Community School",
        "district": "RSU 40/MSAD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231155000508",
    },
    {
        "school": "North Haven Community School",
        "district": "RSU 07/MSAD 07",
        "level": "Other",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231182000544",
    },
    {
        "school": "Matinicus Elementary School",
        "district": "RSU 65/MSAD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231441000713",
    },
    {
        "school": "Medomak Valley High School",
        "district": "RSU 40/MSAD 40",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231155000483",
    },
    {
        "school": "Miller School",
        "district": "RSU 40/MSAD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231155000484",
    },
    {
        "school": "Sanford Regional Technical Center",
        "district": "Sanford Public Schools",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231050000137",
    },
    {
        "school": "Lafayette School",
        "district": "Sanford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231050000313",
    },
    {
        "school": "Sanford High School",
        "district": "Sanford Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231050000316",
    },
    {
        "school": "Sanford Jr High School",
        "district": "Sanford Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231050000317",
    },
    {
        "school": "Carl J Lamb School",
        "district": "Sanford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231050001030",
    },
    {
        "school": "Madison Elementary School",
        "district": "RSU 59/MSAD 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231456000567",
    },
    {
        "school": "SAD #53 Alternative Education",
        "district": "RSU 53/MSAD 53",
        "level": "High",
        "type": "Special education school",
        "state": "ME",
        "nces_id": "231461000620",
    },
    {
        "school": "Carrabec Community School",
        "district": "RSU 74/MSAD 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476700541",
    },
    {
        "school": "Albion Elementary School",
        "district": "RSU 49/MSAD 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231433000691",
    },
    {
        "school": "Clinton Elementary School",
        "district": "RSU 49/MSAD 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231433000698",
    },
    {
        "school": "Benton Elementary School",
        "district": "RSU 49/MSAD 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231433001037",
    },
    {
        "school": "Harmony Elementary",
        "district": "Harmony Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230633000167",
    },
    {
        "school": "Forest Hills Consolidated School",
        "district": "RSU 82/MSAD 12",
        "level": "Other",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231062000337",
    },
    {
        "school": "Lawrence High School",
        "district": "RSU 49/MSAD 49",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231433000695",
    },
    {
        "school": "Lawrence Jr High School",
        "district": "RSU 49/MSAD 49",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231433000696",
    },
    {
        "school": "Fairfield Primary School",
        "district": "RSU 49/MSAD 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231433000997",
    },
    {
        "school": "Madison Area Memorial H S",
        "district": "RSU 59/MSAD 59",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231456000998",
    },
    {
        "school": "Madison Junior High School",
        "district": "RSU 59/MSAD 59",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231456001012",
    },
    {
        "school": "Somerset Career & Technical Center",
        "district": "RSU 54/MSAD 54",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231459000185",
    },
    {
        "school": "Canaan Elementary School",
        "district": "RSU 54/MSAD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231459000746",
    },
    {
        "school": "Margaret Chase Smith Sch - Skowhegan",
        "district": "RSU 54/MSAD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231459000751",
    },
    {
        "school": "North Elementary School",
        "district": "RSU 54/MSAD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231459000753",
    },
    {
        "school": "Skowhegan Area High School",
        "district": "RSU 54/MSAD 54",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231459000755",
    },
    {
        "school": "Skowhegan Area Middle School",
        "district": "RSU 54/MSAD 54",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231459000756",
    },
    {
        "school": "Bloomfield Elementary School",
        "district": "RSU 54/MSAD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231459000948",
    },
    {
        "school": "Manson Park School",
        "district": "RSU 53/MSAD 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231461000760",
    },
    {
        "school": "Vickery School",
        "district": "RSU 53/MSAD 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231461000763",
    },
    {
        "school": "Warsaw Middle School",
        "district": "RSU 53/MSAD 53",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231461000764",
    },
    {
        "school": "Garret Schenck School",
        "district": "RSU 74/MSAD 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476700812",
    },
    {
        "school": "Carrabec High School",
        "district": "RSU 74/MSAD 74",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476700954",
    },
    {
        "school": "Solon Elementary School",
        "district": "RSU 74/MSAD 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476700955",
    },
    {
        "school": "Bay City Adult EducationCTP",
        "district": "Bay City School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260426002049",
    },
    {
        "school": "Niles Comm Schools Adult Education",
        "district": "Niles Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262556002056",
    },
    {
        "school": "Accelerated Learning Academy",
        "district": "Flint School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261452002043",
    },
    {
        "school": "Special Services  North",
        "district": "Genesee ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268040002023",
    },
    {
        "school": "Ashley Middle School",
        "district": "Ashley Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260348001954",
    },
    {
        "school": "Webberville Middle School",
        "district": "Webberville Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263573007489",
    },
    {
        "school": "Kalamazoo RESA West CampusYoung Adult Program",
        "district": "Kalamazoo RESA",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268060002030",
    },
    {
        "school": "Duncan Lake Transitions Program",
        "district": "Caledonia Community Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260762007473",
    },
    {
        "school": "Forest Hills Transition Center",
        "district": "Forest Hills Public Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261461007486",
    },
    {
        "school": "Rockford Special Services R1TS",
        "district": "Rockford Public Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263003002031",
    },
    {
        "school": "Michener Elementary School",
        "district": "Adrian Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260195001963",
    },
    {
        "school": "Prairie Elementary School",
        "district": "Adrian Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260195001965",
    },
    {
        "school": "Adrian Community High School",
        "district": "Adrian Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260195002061",
    },
    {
        "school": "St Ignace Juvenile Detention Facility",
        "district": "St. Ignace Area Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260001202058",
    },
    {
        "school": "Sequoyah Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957007482",
    },
    {
        "school": "LAnse CreuseMount Clemens Center for Lifelong Learning",
        "district": "L'Anse Creuse Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187002057",
    },
    {
        "school": "Warren Woods Adult Education",
        "district": "Warren Woods Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263522002059",
    },
    {
        "school": "Academic and Career Education Academy",
        "district": "Academic and Career Education Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260033004509",
    },
    {
        "school": "Grant Learning Center",
        "district": "Grant Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261650002052",
    },
    {
        "school": "Farmington Central High School",
        "district": "Farmington Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261407004371",
    },
    {
        "school": "Huron Valley Adult Education",
        "district": "Huron Valley Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261899002042",
    },
    {
        "school": "Community Ed Resource Center",
        "district": "Lake Orion Community Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262073002034",
    },
    {
        "school": "Churchill Community Ed Center",
        "district": "Royal Oak Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263030002040",
    },
    {
        "school": "Juvenile Detention Center",
        "district": "Ottawa Area ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268090002039",
    },
    {
        "school": "Harrison Center",
        "district": "Port Huron Area School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262883002036",
    },
    {
        "school": "Sturgis Schools Adult Education Center",
        "district": "Sturgis Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263309002037",
    },
    {
        "school": "Barrows Adult Education",
        "district": "Three Rivers Community Schools",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263384002066",
    },
    {
        "school": "Marvin L Winans Academy  Elementary",
        "district": "Marvin L. Winans Academy of Performing Arts",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260016901951",
    },
    {
        "school": "Taylor Exemplar Academy",
        "district": "Taylor Exemplar Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260033101955",
    },
    {
        "school": "David Ellis Academy West",
        "district": "David Ellis Academy West",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260033307495",
    },
    {
        "school": "Cambridge Alternative High School",
        "district": "Garden City Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261554002045",
    },
    {
        "school": "Rosedale Elementary",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184001958",
    },
    {
        "school": "Starkweather Academy  Fiegel",
        "district": "Plymouth-Canton Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262856002047",
    },
    {
        "school": "Inverness Academy",
        "district": "Cheboygan Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260891001614",
    },
    {
        "school": "Farwell Timberland Alternative High School",
        "district": "Farwell Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261410001782",
    },
    {
        "school": "Hillside Elementary School",
        "district": "Harrison Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261782001710",
    },
    {
        "school": "Gogebic Co Community Education",
        "district": "Ironwood Area Schools of Gogebic County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261947001791",
    },
    {
        "school": "ISDLocal Center Programs",
        "district": "Montcalm Area ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268083001619",
    },
    {
        "school": "Houghton Lake Community Education",
        "district": "Houghton Lake Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261860001615",
    },
    {
        "school": "CarsonvillePort Sanilac Learning Center",
        "district": "Carsonville-Port Sanilac School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260816001828",
    },
    {
        "school": "Transition Center",
        "district": "Cass City Public Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260840001914",
    },
    {
        "school": "Alcona Community High School",
        "district": "Alcona Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260216003955",
    },
    {
        "school": "Alcona Elementary School",
        "district": "Alcona Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260216007445",
    },
    {
        "school": "Superior Central School",
        "district": "Superior Central School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001906583",
    },
    {
        "school": "AuTrainOnota Public School",
        "district": "AuTrain-Onota Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260366004061",
    },
    {
        "school": "Burt Township School",
        "district": "Burt Township School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260747004328",
    },
    {
        "school": "William G Mather Elementary School",
        "district": "Munising Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262481006139",
    },
    {
        "school": "Munising High and Middle School",
        "district": "Munising Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262481006140",
    },
    {
        "school": "Alba School",
        "district": "Alba Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260204003949",
    },
    {
        "school": "Bellaire MiddleHigh School",
        "district": "Bellaire Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260462004147",
    },
    {
        "school": "John R Rodger Elementary School",
        "district": "Bellaire Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260462004148",
    },
    {
        "school": "Central Lake Public Schools",
        "district": "Central Lake Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260861004410",
    },
    {
        "school": "Elk Rapids High School",
        "district": "Elk Rapids Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261305005002",
    },
    {
        "school": "Cherryland Middle School",
        "district": "Elk Rapids Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261305005003",
    },
    {
        "school": "Lakeland Elementary School",
        "district": "Elk Rapids Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261305005004",
    },
    {
        "school": "Ellsworth Community School",
        "district": "Ellsworth Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261311005011",
    },
    {
        "school": "Mancelona Elementary School",
        "district": "Mancelona Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262235005948",
    },
    {
        "school": "Mancelona High School",
        "district": "Mancelona Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262235005949",
    },
    {
        "school": "Mancelona Middle School",
        "district": "Mancelona Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262235005950",
    },
    {
        "school": "Au GresSims Elementary School",
        "district": "Au Gres-Sims School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260360004058",
    },
    {
        "school": "Au GresSims High School",
        "district": "Au Gres-Sims School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260360004059",
    },
    {
        "school": "StandishSterling Central Elementary School",
        "district": "Standish-Sterling Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263294006845",
    },
    {
        "school": "StandishSterling Central JrSr High School",
        "district": "Standish-Sterling Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263294006846",
    },
    {
        "school": "Sterling Elementary School",
        "district": "Standish-Sterling Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263294006847",
    },
    {
        "school": "LAnse Area School",
        "district": "L'Anse Area Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001805923",
    },
    {
        "school": "Arvon Township School",
        "district": "Arvon Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260327004045",
    },
    {
        "school": "Baraga School",
        "district": "Baraga Area Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260399004084",
    },
    {
        "school": "Concord Academy  Boyne",
        "district": "Concord Academy - Boyne",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260006900485",
    },
    {
        "school": "Charlevoix Montessori Academy for the Arts",
        "district": "Charlevoix Montessori Academy for the Arts",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260007000486",
    },
    {
        "school": "Beaver Island Community School",
        "district": "Beaver Island Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260435004123",
    },
    {
        "school": "MorganShaw School",
        "district": "Boyne City Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260650000818",
    },
    {
        "school": "Boyne City High School",
        "district": "Boyne City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260650004252",
    },
    {
        "school": "Boyne City Elementary School",
        "district": "Boyne City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260650004253",
    },
    {
        "school": "Boyne City Middle School",
        "district": "Boyne City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260650004254",
    },
    {
        "school": "Boyne Falls Public School",
        "district": "Boyne Falls Public School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260651004255",
    },
    {
        "school": "Charlevoix Middle High School",
        "district": "Charlevoix Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260873004419",
    },
    {
        "school": "Charlevoix Elementary School",
        "district": "Charlevoix Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260873004421",
    },
    {
        "school": "East Jordan Elementary School",
        "district": "East Jordan Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261256004968",
    },
    {
        "school": "East Jordan MiddleHigh School",
        "district": "East Jordan Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261256004969",
    },
    {
        "school": "CharEm Special Education Schools",
        "district": "Charlevoix-Emmet ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268024000811",
    },
    {
        "school": "Cheboygan Area High School",
        "district": "Cheboygan Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260891004432",
    },
    {
        "school": "East Elementary School",
        "district": "Cheboygan Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260891004433",
    },
    {
        "school": "Cheboygan Intermediate School",
        "district": "Cheboygan Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260891004436",
    },
    {
        "school": "Inland Lakes Elementary School",
        "district": "Inland Lakes Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261917005598",
    },
    {
        "school": "Inland Lakes Secondary School",
        "district": "Inland Lakes Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261917005599",
    },
    {
        "school": "Wolverine Elementary School",
        "district": "Wolverine Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263648007237",
    },
    {
        "school": "Wolverine MiddleHigh School",
        "district": "Wolverine Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263648007238",
    },
    {
        "school": "COP ESD Programs",
        "district": "Cheb-Otsego-Presque Isle ESD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268026001274",
    },
    {
        "school": "Clare Pioneer High School",
        "district": "Clare Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260975000123",
    },
    {
        "school": "Clare Primary School",
        "district": "Clare Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260975004464",
    },
    {
        "school": "Clare High School",
        "district": "Clare Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260975004465",
    },
    {
        "school": "Clare Middle School",
        "district": "Clare Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260975004466",
    },
    {
        "school": "Farwell Elementary School",
        "district": "Farwell Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261410005057",
    },
    {
        "school": "Farwell High School",
        "district": "Farwell Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261410005058",
    },
    {
        "school": "Farwell Middle School",
        "district": "Farwell Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261410005060",
    },
    {
        "school": "Harrison Alternative Education",
        "district": "Harrison Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261782000105",
    },
    {
        "school": "Harrison Community High School",
        "district": "Harrison Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261782005444",
    },
    {
        "school": "Harrison Middle School",
        "district": "Harrison Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261782005446",
    },
    {
        "school": "Robert M Larson Elementary School",
        "district": "Harrison Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261782005447",
    },
    {
        "school": "ClareGladwin Area School",
        "district": "Clare-Gladwin Regional Education Service District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268030000493",
    },
    {
        "school": "Grayling Elementary School",
        "district": "Crawford AuSable Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261103004560",
    },
    {
        "school": "Grayling High School",
        "district": "Crawford AuSable Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261103004561",
    },
    {
        "school": "Grayling Middle School",
        "district": "Crawford AuSable Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261103004562",
    },
    {
        "school": "Concord Academy  Petoskey",
        "district": "Concord Academy - Petoskey",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260007400502",
    },
    {
        "school": "Blackbird Elementary School",
        "district": "Harbor Springs School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261770000087",
    },
    {
        "school": "Harbor Springs High School",
        "district": "Harbor Springs School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261770005432",
    },
    {
        "school": "Shay Elementary School",
        "district": "Harbor Springs School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261770005434",
    },
    {
        "school": "Harbor Springs Middle School",
        "district": "Harbor Springs School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261770007687",
    },
    {
        "school": "Alanson Public School",
        "district": "Alanson Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262181005875",
    },
    {
        "school": "Mackinaw City K12 School",
        "district": "Mackinaw City Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262226005939",
    },
    {
        "school": "Pellston Elementary School",
        "district": "Pellston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262772006355",
    },
    {
        "school": "Pellston MiddleHigh School",
        "district": "Pellston Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262772006356",
    },
    {
        "school": "Petoskey Montessori Elem School",
        "district": "Public Schools of Petoskey",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262793000829",
    },
    {
        "school": "Lincoln School",
        "district": "Public Schools of Petoskey",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262793006370",
    },
    {
        "school": "Ottawa Elementary School",
        "district": "Public Schools of Petoskey",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262793006371",
    },
    {
        "school": "Petoskey High School",
        "district": "Public Schools of Petoskey",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262793006372",
    },
    {
        "school": "Petoskey Middle School",
        "district": "Public Schools of Petoskey",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262793006373",
    },
    {
        "school": "Sheridan School",
        "district": "Public Schools of Petoskey",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262793006374",
    },
    {
        "school": "Central Elementary School",
        "district": "Public Schools of Petoskey",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262793007688",
    },
    {
        "school": "Beaverton JuniorSenior High School",
        "district": "Beaverton Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260444004125",
    },
    {
        "school": "Beaverton Elementary School",
        "district": "Beaverton Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260444004126",
    },
    {
        "school": "Gladwin Community Alternative HS",
        "district": "Gladwin Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261599000518",
    },
    {
        "school": "Gladwin Junior High School",
        "district": "Gladwin Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261599005249",
    },
    {
        "school": "Gladwin Elementary School",
        "district": "Gladwin Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261599005250",
    },
    {
        "school": "Gladwin Intermediate School",
        "district": "Gladwin Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261599005251",
    },
    {
        "school": "Gladwin High School",
        "district": "Gladwin Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261599007485",
    },
    {
        "school": "AD Johnston JrSr High School",
        "district": "Bessemer Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000603854",
    },
    {
        "school": "Washington School",
        "district": "Bessemer Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000603855",
    },
    {
        "school": "Luther L Wright K12 School",
        "district": "Ironwood Area Schools of Gogebic County",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261947005612",
    },
    {
        "school": "WakefieldMarenisco School",
        "district": "Wakefield-Marenisco School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263501007067",
    },
    {
        "school": "Watersmeet Township School",
        "district": "Watersmeet Township School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263534007153",
    },
    {
        "school": "Mill Creek Elementary School",
        "district": "Elk Rapids Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261305007651",
    },
    {
        "school": "Hillsdale Preparatory School",
        "district": "Hillsdale Preparatory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260014300844",
    },
    {
        "school": "Will Carleton Charter School Academy",
        "district": "Will Carleton Charter School Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260018201057",
    },
    {
        "school": "CamdenFrontier K12 School",
        "district": "Camden-Frontier School",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260771004355",
    },
    {
        "school": "Davis Middle School",
        "district": "Hillsdale Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261839005505",
    },
    {
        "school": "Hillsdale High School",
        "district": "Hillsdale Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261839005507",
    },
    {
        "school": "Jonesville Middle School",
        "district": "Jonesville Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261992001307",
    },
    {
        "school": "Jonesville High School",
        "district": "Jonesville Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261992005650",
    },
    {
        "school": "Williams Elementary School",
        "district": "Jonesville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261992005651",
    },
    {
        "school": "Jonesville Pathways",
        "district": "Jonesville Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261992005652",
    },
    {
        "school": "Litchfield High School",
        "district": "Litchfield Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262175005873",
    },
    {
        "school": "Litchfield Elementary School",
        "district": "Litchfield Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262175005874",
    },
    {
        "school": "North AdamsJerome MiddleHigh School",
        "district": "North Adams-Jerome Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262565006211",
    },
    {
        "school": "North AdamsJerome Elem School",
        "district": "North Adams-Jerome Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262565006212",
    },
    {
        "school": "Pittsford Area High School",
        "district": "Pittsford Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262850006398",
    },
    {
        "school": "Pittsford Area Elem School",
        "district": "Pittsford Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262850006399",
    },
    {
        "school": "Reading High School",
        "district": "Reading Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262940006520",
    },
    {
        "school": "Reynolds Elementary School",
        "district": "Reading Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262940006521",
    },
    {
        "school": "Waldron Area Schools",
        "district": "Waldron Area Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263504007069",
    },
    {
        "school": "Greenfield School",
        "district": "Hillsdale ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268048000840",
    },
    {
        "school": "Hillsdale Workforce DevTech Center",
        "district": "Hillsdale ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268048001302",
    },
    {
        "school": "Harbor Beach Middle School",
        "district": "Harbor Beach Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000700848",
    },
    {
        "school": "Harbor Beach Community High School",
        "district": "Harbor Beach Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000703856",
    },
    {
        "school": "Harbor Beach Elementary School",
        "district": "Harbor Beach Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000703857",
    },
    {
        "school": "Adams Elementary School",
        "district": "Sigel Township S/D #3F",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001003860",
    },
    {
        "school": "Eccles School",
        "district": "Sigel Township S/D #4F",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001103861",
    },
    {
        "school": "Bad Axe High School",
        "district": "Bad Axe Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001703918",
    },
    {
        "school": "Bad Axe Middle School",
        "district": "Bad Axe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001703919",
    },
    {
        "school": "Bad Axe Elementary School",
        "district": "Bad Axe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001703920",
    },
    {
        "school": "Caseville School K12",
        "district": "Caseville Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260828004388",
    },
    {
        "school": "Church School",
        "district": "Church School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260963004463",
    },
    {
        "school": "Big Burning School",
        "district": "Colfax Township S/D #1F",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261023004513",
    },
    {
        "school": "Laker Elementary",
        "district": "Elkton-Pigeon-Bay Port Laker Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261309001474",
    },
    {
        "school": "Laker High School",
        "district": "Elkton-Pigeon-Bay Port Laker Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261309005007",
    },
    {
        "school": "Laker Junior High School",
        "district": "Elkton-Pigeon-Bay Port Laker Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261309005008",
    },
    {
        "school": "North Huron School",
        "district": "North Huron School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262578006233",
    },
    {
        "school": "OwendaleGagetown Elementary School",
        "district": "Owendale-Gagetown Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262718006326",
    },
    {
        "school": "OwendaleGagetown JrSr High School",
        "district": "Owendale-Gagetown Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262718006327",
    },
    {
        "school": "Ubly Community Elementary School",
        "district": "Ubly Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263438006980",
    },
    {
        "school": "Ubly Community High School",
        "district": "Ubly Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263438006981",
    },
    {
        "school": "UnionvilleSebewaing Middle School",
        "district": "Unionville-Sebewaing Area S.D.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263444006986",
    },
    {
        "school": "UnionvilleSebewaing High School",
        "district": "Unionville-Sebewaing Area S.D.",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263444006987",
    },
    {
        "school": "UnionvilleSebewaing Elem School",
        "district": "Unionville-Sebewaing Area S.D.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263444006988",
    },
    {
        "school": "Verona Mills School",
        "district": "Verona Township S/D #1F",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263486007058",
    },
    {
        "school": "Huron Learning Center",
        "district": "Huron ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268050000140",
    },
    {
        "school": "Huron Area Technical Center",
        "district": "Huron ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268050000847",
    },
    {
        "school": "Hale Area School",
        "district": "Hale Area Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261737005412",
    },
    {
        "school": "Oscoda Area High School",
        "district": "Oscoda Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262697006312",
    },
    {
        "school": "Tawas Area High School",
        "district": "Tawas Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263351006885",
    },
    {
        "school": "Tawas Area Middle School",
        "district": "Tawas Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263351006886",
    },
    {
        "school": "Clara B Bolen Elementary School",
        "district": "Tawas Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263351006887",
    },
    {
        "school": "WhittemorePrescott JrSr High School",
        "district": "Whittemore-Prescott Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263639007223",
    },
    {
        "school": "Iosco RESA Special Education",
        "district": "Iosco RESA",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268056001351",
    },
    {
        "school": "Forest Park School",
        "district": "Forest Park School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261119004569",
    },
    {
        "school": "West Iron County Middle School",
        "district": "West Iron County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263291000148",
    },
    {
        "school": "West Iron County High School",
        "district": "West Iron County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263291006842",
    },
    {
        "school": "Stambaugh Elementary School",
        "district": "West Iron County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263291006843",
    },
    {
        "school": "Montabella Elementary",
        "district": "Montabella Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261296004993",
    },
    {
        "school": "Baldwin Senior High School",
        "district": "Baldwin Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260381004068",
    },
    {
        "school": "Baldwin Junior High School",
        "district": "Baldwin Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260381004070",
    },
    {
        "school": "Baldwin Elementary School",
        "district": "Baldwin Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260381004071",
    },
    {
        "school": "Newberry Area School",
        "district": "Tahquamenon Area Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262535006195",
    },
    {
        "school": "LaSalle High School",
        "district": "St. Ignace Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001203862",
    },
    {
        "school": "St Ignace ElementaryMiddle School",
        "district": "St. Ignace Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001207696",
    },
    {
        "school": "Bois Blanc Pines School",
        "district": "Bois Blanc Pines School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260630004251",
    },
    {
        "school": "Cedarville School",
        "district": "Les Cheneaux Community Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262142005850",
    },
    {
        "school": "Mackinac Island School",
        "district": "Mackinac Island Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262223005938",
    },
    {
        "school": "Gros Cap School",
        "district": "Moran Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262454006106",
    },
    {
        "school": "Casman Alternative Academy",
        "district": "Casman Alternative Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260015200931",
    },
    {
        "school": "Bear Lake High School",
        "district": "Bear Lake Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260432004118",
    },
    {
        "school": "Bear Lake Elementary School",
        "district": "Bear Lake Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260432004120",
    },
    {
        "school": "Brethren Middle School",
        "district": "Kaleva Norman Dickson School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262001001147",
    },
    {
        "school": "Brethren High School",
        "district": "Kaleva Norman Dickson School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262001005681",
    },
    {
        "school": "Thomas Jefferson Elem School",
        "district": "Manistee Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262241005954",
    },
    {
        "school": "John F Kennedy Elem School",
        "district": "Manistee Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262241005955",
    },
    {
        "school": "Manistee Middle High School",
        "district": "Manistee Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262241005957",
    },
    {
        "school": "Onekama Consolidated Schools",
        "district": "Onekama Consolidated Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262649006294",
    },
    {
        "school": "Manistee ISD Center Programs",
        "district": "Manistee ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268074001380",
    },
    {
        "school": "Foster School",
        "district": "Ludington Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262220005930",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Ludington Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262220005931",
    },
    {
        "school": "Lakeview Elementary School",
        "district": "Ludington Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262220005932",
    },
    {
        "school": "Ludington High School",
        "district": "Ludington Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262220005933",
    },
    {
        "school": "OJ DeJonge Middle School",
        "district": "Ludington Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262220005934",
    },
    {
        "school": "Mason County Central MS",
        "district": "Mason County Central Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262313006002",
    },
    {
        "school": "Mason County Central HS",
        "district": "Mason County Central Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262313006003",
    },
    {
        "school": "Scottville Elementary School",
        "district": "Mason County Central Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262313006005",
    },
    {
        "school": "Mason County Eastern Elem Sch",
        "district": "Mason County Eastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262316006007",
    },
    {
        "school": "Mason County Eastern Junior HighHigh School",
        "district": "Mason County Eastern Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262316006008",
    },
    {
        "school": "Developmental Classrooms",
        "district": "West Shore Educational Service District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268075501385",
    },
    {
        "school": "Carson CityCrystal Upper ElementaryMiddle School",
        "district": "Carson City-Crystal Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260813000654",
    },
    {
        "school": "Carson City Elementary School",
        "district": "Carson City-Crystal Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260813004382",
    },
    {
        "school": "Carson CityCrystal High School",
        "district": "Carson City-Crystal Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260813004383",
    },
    {
        "school": "Central Montcalm Upper Elem School",
        "district": "Central Montcalm Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260864001391",
    },
    {
        "school": "Central Montcalm High School",
        "district": "Central Montcalm Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260864004412",
    },
    {
        "school": "Central Montcalm Middle School",
        "district": "Central Montcalm Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260864004413",
    },
    {
        "school": "Central Montcalm Elementary School",
        "district": "Central Montcalm Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260864004415",
    },
    {
        "school": "Montabella JuniorSenior High",
        "district": "Montabella Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261296004994",
    },
    {
        "school": "Lakeview Middle School",
        "district": "Lakeview Community Schools (Montcalm)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262091005761",
    },
    {
        "school": "Lakeview Elementary School",
        "district": "Lakeview Community Schools (Montcalm)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262091005762",
    },
    {
        "school": "Lakeview High School",
        "district": "Lakeview Community Schools (Montcalm)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262091005764",
    },
    {
        "school": "Vestaburg Community High School",
        "district": "Vestaburg Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263492007059",
    },
    {
        "school": "Vestaburg Community Elem School",
        "district": "Vestaburg Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263492007060",
    },
    {
        "school": "Montcalm Area Career Center",
        "district": "Montcalm Area ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268083000223",
    },
    {
        "school": "Seiter Education Service Center",
        "district": "Montcalm Area ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268083000653",
    },
    {
        "school": "Atlanta Community Schools",
        "district": "Atlanta Community Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260357004057",
    },
    {
        "school": "Hillman Elementary School",
        "district": "Hillman Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261836000947",
    },
    {
        "school": "Hillman Community JrSr High School",
        "district": "Hillman Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261836005503",
    },
    {
        "school": "Lewiston Elementary School",
        "district": "Johannesburg-Lewiston Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261989005648",
    },
    {
        "school": "Hart High School",
        "district": "Hart Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261786005450",
    },
    {
        "school": "Hart Middle School",
        "district": "Hart Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261786005451",
    },
    {
        "school": "Spitler Elementary School",
        "district": "Hart Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261786005452",
    },
    {
        "school": "Pentwater Public School",
        "district": "Pentwater Public School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262784006363",
    },
    {
        "school": "New Era Elementary School",
        "district": "Shelby Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263132006735",
    },
    {
        "school": "Shelby High School",
        "district": "Shelby Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263132006736",
    },
    {
        "school": "Shelby Middle School",
        "district": "Shelby Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263132006737",
    },
    {
        "school": "Thomas Read Elementary School",
        "district": "Shelby Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263132006738",
    },
    {
        "school": "Walkerville Public School",
        "district": "Walkerville Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263513007070",
    },
    {
        "school": "Surline Middle School",
        "district": "West Branch-Rose City Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263585007184",
    },
    {
        "school": "Ogemaw Heights High School",
        "district": "West Branch-Rose City Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263585007185",
    },
    {
        "school": "Surline Elementary School",
        "district": "West Branch-Rose City Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263585007186",
    },
    {
        "school": "WhittemorePrescott Area Elementary",
        "district": "Whittemore-Prescott Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263639000050",
    },
    {
        "school": "EwenTrout Creek Consolidated School",
        "district": "Ewen-Trout Creek Consolidated School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001403877",
    },
    {
        "school": "Ontonagon Area School",
        "district": "Ontonagon Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262655006301",
    },
    {
        "school": "GogebicOntonagon ISD Special Education",
        "district": "Gogebic-Ontonagon ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268042001342",
    },
    {
        "school": "Evart Middle School",
        "district": "Evart Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261356000974",
    },
    {
        "school": "Evart Elementary School",
        "district": "Evart Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261356005029",
    },
    {
        "school": "Evart High School",
        "district": "Evart Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261356005030",
    },
    {
        "school": "Marion High School",
        "district": "Marion Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262280005976",
    },
    {
        "school": "Marion Elementary School",
        "district": "Marion Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262280005977",
    },
    {
        "school": "Pine River Area Middle School",
        "district": "Pine River Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262820001277",
    },
    {
        "school": "Pine River Area High School",
        "district": "Pine River Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262820006393",
    },
    {
        "school": "Pine River Area Elementary School",
        "district": "Pine River Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262820006394",
    },
    {
        "school": "GT Norman Elementary School",
        "district": "Reed City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262949006533",
    },
    {
        "school": "Reed City High School",
        "district": "Reed City Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262949006534",
    },
    {
        "school": "Reed City Middle School",
        "district": "Reed City Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262949006535",
    },
    {
        "school": "Fairview  School",
        "district": "Fairview Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261056004524",
    },
    {
        "school": "MioAuSable Elementary School",
        "district": "Mio-AuSable Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262400006079",
    },
    {
        "school": "MioAuSable High School",
        "district": "Mio-AuSable Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262400006080",
    },
    {
        "school": "Gaylord Intermediate School",
        "district": "Gaylord Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261573000251",
    },
    {
        "school": "Gaylord Middle School",
        "district": "Gaylord Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261573005224",
    },
    {
        "school": "Gaylord High SchoolVoc Bldg",
        "district": "Gaylord Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261573005225",
    },
    {
        "school": "North Ohio Elementary School",
        "district": "Gaylord Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261573005227",
    },
    {
        "school": "South Maple Elementary School",
        "district": "Gaylord Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261573005228",
    },
    {
        "school": "JohannesburgLewiston High School",
        "district": "Johannesburg-Lewiston Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261989005647",
    },
    {
        "school": "JohannesburgLewiston ElementaryMiddle School",
        "district": "Johannesburg-Lewiston Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261989005649",
    },
    {
        "school": "Vanderbilt Area School",
        "district": "Vanderbilt Area Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263462007040",
    },
    {
        "school": "Presque Isle Academy",
        "district": "Presque Isle Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260026901409",
    },
    {
        "school": "Onaway Middle School",
        "district": "Onaway Area Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262640001170",
    },
    {
        "school": "Onaway Elementary School",
        "district": "Onaway Area Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262640006288",
    },
    {
        "school": "Onaway Senior High School",
        "district": "Onaway Area Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262640006289",
    },
    {
        "school": "Posen Consolidated High School",
        "district": "Posen Consolidated School District No. 9",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262913006501",
    },
    {
        "school": "Posen Elementary School",
        "district": "Posen Consolidated School District No. 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262913006502",
    },
    {
        "school": "Rogers City High School",
        "district": "Rogers City Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263006006594",
    },
    {
        "school": "Rogers City Elementary School",
        "district": "Rogers City Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263006006595",
    },
    {
        "school": "Roscommon Elementary School",
        "district": "Roscommon Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261583005231",
    },
    {
        "school": "Roscommon High School",
        "district": "Roscommon Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261583005233",
    },
    {
        "school": "Roscommon Middle School",
        "district": "Roscommon Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261583005234",
    },
    {
        "school": "Collins Lower Elementary School",
        "district": "Houghton Lake Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261860005544",
    },
    {
        "school": "Houghton Lake JrSr High School",
        "district": "Houghton Lake Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261860005545",
    },
    {
        "school": "Collins Upper Elementary School",
        "district": "Houghton Lake Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261860005548",
    },
    {
        "school": "COOR Special Educational Center",
        "district": "C.O.O.R. ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268092000257",
    },
    {
        "school": "Brown City Alternative HS",
        "district": "Brown City Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260704000269",
    },
    {
        "school": "Brown City High School",
        "district": "Brown City Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260704004301",
    },
    {
        "school": "Brown City Elementary School",
        "district": "Brown City Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260704004303",
    },
    {
        "school": "CarsonvillePort Sanilac Elementary School",
        "district": "Carsonville-Port Sanilac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260816004386",
    },
    {
        "school": "CarsonvillePort Sanilac HS",
        "district": "Carsonville-Port Sanilac School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260816004387",
    },
    {
        "school": "CroswellLexington High School",
        "district": "Croswell-Lexington Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261114004565",
    },
    {
        "school": "Frostick School",
        "district": "Croswell-Lexington Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261114004566",
    },
    {
        "school": "Meyer Elementary School",
        "district": "Croswell-Lexington Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261114004567",
    },
    {
        "school": "CroswellLexington Middle School",
        "district": "Croswell-Lexington Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261114004568",
    },
    {
        "school": "Deckerville Elementary School",
        "district": "Deckerville Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261170004627",
    },
    {
        "school": "Deckerville Community High School",
        "district": "Deckerville Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261170004628",
    },
    {
        "school": "Marlette Elementary",
        "district": "Marlette Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262286005979",
    },
    {
        "school": "Marlette JrSr High School",
        "district": "Marlette Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262286005980",
    },
    {
        "school": "Peck JrSr High School",
        "district": "Peck Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262769006354",
    },
    {
        "school": "Peck Community Elem School",
        "district": "Peck Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262769007690",
    },
    {
        "school": "Sandusky JuniorSenior High School",
        "district": "Sandusky Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263084006714",
    },
    {
        "school": "Sanilac Career Center",
        "district": "Sanilac ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268096500725",
    },
    {
        "school": "Sanilac ISD Special Education Services",
        "district": "Sanilac ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268096501413",
    },
    {
        "school": "Manistique Alternative Ed Center",
        "district": "Manistique Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262247000992",
    },
    {
        "school": "Manistique Middle and High School",
        "district": "Manistique Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262247005963",
    },
    {
        "school": "Emerald Elementary School",
        "district": "Manistique Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262247005964",
    },
    {
        "school": "AkronFairgrove Elem School",
        "district": "Akron-Fairgrove Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260201003945",
    },
    {
        "school": "AkronFairgrove JrSr High School",
        "district": "Akron-Fairgrove Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260201003946",
    },
    {
        "school": "Caro Alternative High School",
        "district": "Caro Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260804000994",
    },
    {
        "school": "Schall Elementary School",
        "district": "Caro Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260804004375",
    },
    {
        "school": "Caro High School",
        "district": "Caro Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260804004376",
    },
    {
        "school": "McComb Elementary School",
        "district": "Caro Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260804004377",
    },
    {
        "school": "Caro Middle School",
        "district": "Caro Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260804004378",
    },
    {
        "school": "Cass City Elementary",
        "district": "Cass City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260840004390",
    },
    {
        "school": "Cass City Jr and Sr High School",
        "district": "Cass City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260840004391",
    },
    {
        "school": "Kingston High School",
        "district": "Kingston Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262040005724",
    },
    {
        "school": "Kingston Elementary School",
        "district": "Kingston Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262040005725",
    },
    {
        "school": "Mayville High School",
        "district": "Mayville Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262328006013",
    },
    {
        "school": "Mayville Elementary School",
        "district": "Mayville Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262328006014",
    },
    {
        "school": "Mayville Middle School",
        "district": "Mayville Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262328006015",
    },
    {
        "school": "Millington High School",
        "district": "Millington Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262391006075",
    },
    {
        "school": "Kirk Elementary School",
        "district": "Millington Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262391006076",
    },
    {
        "school": "Reese High School",
        "district": "Reese Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262952006536",
    },
    {
        "school": "Reese Elementary School",
        "district": "Reese Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262952006537",
    },
    {
        "school": "Reese Middle School",
        "district": "Reese Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262952006538",
    },
    {
        "school": "Pioneer Work and Learn Center",
        "district": "Vassar Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263471000275",
    },
    {
        "school": "Central School",
        "district": "Vassar Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263471007054",
    },
    {
        "school": "Vassar Senior High School",
        "district": "Vassar Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263471007056",
    },
    {
        "school": "Highland Pines School",
        "district": "Tuscola ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268098000274",
    },
    {
        "school": "Tuscola Technology Center",
        "district": "Tuscola ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268098000727",
    },
    {
        "school": "Addison High School",
        "district": "Addison Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260192003923",
    },
    {
        "school": "Adrian High School",
        "district": "Adrian Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260195003927",
    },
    {
        "school": "Alexander Elementary School",
        "district": "Adrian Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260195003929",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Adrian Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260195003932",
    },
    {
        "school": "Springbrook Middle School",
        "district": "Adrian Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260195003936",
    },
    {
        "school": "Blissfield High School",
        "district": "Blissfield Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260600004229",
    },
    {
        "school": "Blissfield Elementary",
        "district": "Blissfield Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260600004230",
    },
    {
        "school": "Blissfield Middle School",
        "district": "Blissfield Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260600004231",
    },
    {
        "school": "Clinton Elementary School",
        "district": "Clinton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261005004488",
    },
    {
        "school": "Clinton Middle School",
        "district": "Clinton Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261005004489",
    },
    {
        "school": "Clinton High School",
        "district": "Clinton Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261005004490",
    },
    {
        "school": "Hudson Middle School",
        "district": "Hudson Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261881000060",
    },
    {
        "school": "Hudson Area JRSR High School",
        "district": "Hudson Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261881005556",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Hudson Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261881005557",
    },
    {
        "school": "Madison Elementary School",
        "district": "Madison School District (Lenawee)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262232005946",
    },
    {
        "school": "Madison High School",
        "district": "Madison School District (Lenawee)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262232005947",
    },
    {
        "school": "Madison Middle School",
        "district": "Madison School District (Lenawee)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262232007551",
    },
    {
        "school": "Morenci Elementary School",
        "district": "Morenci Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262457006108",
    },
    {
        "school": "Morenci Middle and High School",
        "district": "Morenci Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262457006109",
    },
    {
        "school": "Onsted Elementary",
        "district": "Onsted Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262652001139",
    },
    {
        "school": "Onsted Community High School",
        "district": "Onsted Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262652006295",
    },
    {
        "school": "Onsted Middle School",
        "district": "Onsted Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262652006297",
    },
    {
        "school": "Sand Creek High School",
        "district": "Sand Creek Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263078006711",
    },
    {
        "school": "Ruth McGregor Elementary School",
        "district": "Sand Creek Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263078006712",
    },
    {
        "school": "Tecumseh South Early Learning Center",
        "district": "Tecumseh Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263372006916",
    },
    {
        "school": "Tecumseh North Early Learning Center",
        "district": "Tecumseh Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263372006917",
    },
    {
        "school": "Tecumseh High School",
        "district": "Tecumseh Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263372006918",
    },
    {
        "school": "Milton C Porter Ed Center",
        "district": "Lenawee ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268068000606",
    },
    {
        "school": "LISD TECH Center",
        "district": "Lenawee ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268068000607",
    },
    {
        "school": "Outlook Academy",
        "district": "Outlook Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260027401489",
    },
    {
        "school": "Pearl AlternativeAdult Education School",
        "district": "Fennville Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261423001571",
    },
    {
        "school": "Otsego West Campus High School",
        "district": "Otsego Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262706001733",
    },
    {
        "school": "Allegan Alternative High School",
        "district": "Allegan Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260222000110",
    },
    {
        "school": "LE White Middle School",
        "district": "Allegan Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260222003965",
    },
    {
        "school": "Allegan High School",
        "district": "Allegan Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260222003966",
    },
    {
        "school": "Dawson Elementary School",
        "district": "Allegan Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260222003967",
    },
    {
        "school": "North Ward Elementary School",
        "district": "Allegan Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260222003968",
    },
    {
        "school": "West Ward Elementary School",
        "district": "Allegan Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260222003969",
    },
    {
        "school": "Pine Trails Elementary School",
        "district": "Allegan Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260222003970",
    },
    {
        "school": "Fennville Public High School",
        "district": "Fennville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261423005062",
    },
    {
        "school": "Fennville Middle School",
        "district": "Fennville Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261423007529",
    },
    {
        "school": "Fennville Elementary School",
        "district": "Fennville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261423007666",
    },
    {
        "school": "Glenn Public School",
        "district": "Glenn Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261551005210",
    },
    {
        "school": "Hamilton Middle School",
        "district": "Hamilton Community Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261740001319",
    },
    {
        "school": "Hamilton Elementary School",
        "district": "Hamilton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261740005415",
    },
    {
        "school": "Hamilton High School",
        "district": "Hamilton Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261740005416",
    },
    {
        "school": "Blue Star Elementary School",
        "district": "Hamilton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261740005417",
    },
    {
        "school": "Sandyview Elementary School",
        "district": "Hamilton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261740005418",
    },
    {
        "school": "Bentheim Elementary School",
        "district": "Hamilton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261740005419",
    },
    {
        "school": "Hopkins Middle School",
        "district": "Hopkins Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261857001222",
    },
    {
        "school": "Hopkins Elementary School",
        "district": "Hopkins Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261857005541",
    },
    {
        "school": "Hopkins High School",
        "district": "Hopkins Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261857005542",
    },
    {
        "school": "Sycamore Elementary School",
        "district": "Hopkins Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261857005543",
    },
    {
        "school": "Martin High School",
        "district": "Martin Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262298005986",
    },
    {
        "school": "Robert D Brandon Elem School",
        "district": "Martin Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262298005987",
    },
    {
        "school": "Dix Street Elementary School",
        "district": "Otsego Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262706006316",
    },
    {
        "school": "Otsego Middle School",
        "district": "Otsego Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262706006317",
    },
    {
        "school": "Washington Street Elementary School",
        "district": "Otsego Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262706006318",
    },
    {
        "school": "Otsego High School",
        "district": "Otsego Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262706006319",
    },
    {
        "school": "Renaissance High School",
        "district": "Plainwell Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262853000793",
    },
    {
        "school": "Gilkey Elementary School",
        "district": "Plainwell Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262853006401",
    },
    {
        "school": "Plainwell High School",
        "district": "Plainwell Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262853006402",
    },
    {
        "school": "Starr Elementary School",
        "district": "Plainwell Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262853006403",
    },
    {
        "school": "Plainwell Middle School",
        "district": "Plainwell Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262853006404",
    },
    {
        "school": "Saugatuck Middle School",
        "district": "Saugatuck Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263096001318",
    },
    {
        "school": "Douglas Elementary School",
        "district": "Saugatuck Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263096006719",
    },
    {
        "school": "Saugatuck High School",
        "district": "Saugatuck Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263096006720",
    },
    {
        "school": "Wayland Union Middle School",
        "district": "Wayland Union Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263555000447",
    },
    {
        "school": "Bessie B Baker School",
        "district": "Wayland Union Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263555007165",
    },
    {
        "school": "Dorr School",
        "district": "Wayland Union Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263555007166",
    },
    {
        "school": "RJ Steeby School",
        "district": "Wayland Union Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263555007168",
    },
    {
        "school": "Wayland High School",
        "district": "Wayland Union Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263555007169",
    },
    {
        "school": "Pine Street Elementary",
        "district": "Wayland Union Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263555007171",
    },
    {
        "school": "Hillside Learning  Behavior Center",
        "district": "Allegan Area Educational Service Agency",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268010000108",
    },
    {
        "school": "Allegan County Area Technical and Education Center",
        "district": "Allegan Area Educational Service Agency",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268010000445",
    },
    {
        "school": "STAR Family Literacy",
        "district": "Allegan Area Educational Service Agency",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268010001097",
    },
    {
        "school": "Alamo Elementary School",
        "district": "Otsego Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262706000015",
    },
    {
        "school": "Cooper Elementary School",
        "district": "Plainwell Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262853006400",
    },
    {
        "school": "Fulton Alternative Education",
        "district": "Fulton Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261542001617",
    },
    {
        "school": "Hillcrest Elementary School",
        "district": "Alma Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260264003977",
    },
    {
        "school": "Pine Avenue Elementary School",
        "district": "Alma Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260264003978",
    },
    {
        "school": "Alma Senior High School",
        "district": "Alma Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260264003980",
    },
    {
        "school": "Donald L Pavlik  Middle School",
        "district": "Alma Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260264003981",
    },
    {
        "school": "Luce Road Elementary School",
        "district": "Alma Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260264007508",
    },
    {
        "school": "Ashley High School",
        "district": "Ashley Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260348004046",
    },
    {
        "school": "Ashley Elementary School",
        "district": "Ashley Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260348004047",
    },
    {
        "school": "Breckenridge High School",
        "district": "Breckenridge Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260663004263",
    },
    {
        "school": "Breckenridge Elementary School",
        "district": "Breckenridge Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260663004264",
    },
    {
        "school": "Fulton Middle School",
        "district": "Fulton Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261542000532",
    },
    {
        "school": "Fulton High School",
        "district": "Fulton Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261542005202",
    },
    {
        "school": "Fulton Elementary School",
        "district": "Fulton Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261542005203",
    },
    {
        "school": "Ithaca High School",
        "district": "Ithaca Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261958005620",
    },
    {
        "school": "North Elementary School",
        "district": "Ithaca Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261958005621",
    },
    {
        "school": "South Elementary School",
        "district": "Ithaca Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261958005622",
    },
    {
        "school": "Carrie Knause Early Childhood Learning Center",
        "district": "St. Louis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263288006836",
    },
    {
        "school": "St Louis High School",
        "district": "St. Louis Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263288006837",
    },
    {
        "school": "Eugene M Nikkari Elementary",
        "district": "St. Louis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263288006839",
    },
    {
        "school": "TS Nurnberger Middle School",
        "district": "St. Louis Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263288006840",
    },
    {
        "school": "GIRESD Center Programs",
        "district": "Gratiot-Isabella RESD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268046000529",
    },
    {
        "school": "OxBow ACES AcademyAlternative",
        "district": "Alpena Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260273001594",
    },
    {
        "school": "Alpena High School",
        "district": "Alpena Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260273003984",
    },
    {
        "school": "Ella M White School",
        "district": "Alpena Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260273003985",
    },
    {
        "school": "Hinks School",
        "district": "Alpena Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260273003986",
    },
    {
        "school": "Lincoln Community School",
        "district": "Alpena Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260273003987",
    },
    {
        "school": "Sanborn School",
        "district": "Alpena Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260273003992",
    },
    {
        "school": "Wilson Community School",
        "district": "Alpena Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260273003993",
    },
    {
        "school": "Thunder Bay Junior High School",
        "district": "Alpena Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260273003995",
    },
    {
        "school": "Besser Elementary School",
        "district": "Alpena Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260273007409",
    },
    {
        "school": "Pied Piper School",
        "district": "Alpena-Montmorency-Alcona ESD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268012000111",
    },
    {
        "school": "Clayton H Symons Elementary School",
        "district": "Milan Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262385001504",
    },
    {
        "school": "Fortis Academy",
        "district": "Fortis Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260031401765",
    },
    {
        "school": "Multicultural Academy",
        "district": "Multicultural Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260031501766",
    },
    {
        "school": "Childs Elementary School",
        "district": "Lincoln Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262157001479",
    },
    {
        "school": "LocalBased SpecEd Programs",
        "district": "Washtenaw ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268099001620",
    },
    {
        "school": "Washtenaw County Youth Center  Educational Programs",
        "district": "Washtenaw ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268099001807",
    },
    {
        "school": "Milan High School",
        "district": "Milan Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262385006072",
    },
    {
        "school": "Honey Creek Community School",
        "district": "Honey Creek Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260012100740",
    },
    {
        "school": "Central Academy",
        "district": "Central Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260016301004",
    },
    {
        "school": "Washtenaw Technical Middle College",
        "district": "Washtenaw Technical Middle College",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260016401005",
    },
    {
        "school": "Ann Arbor Learning Community",
        "district": "Ann Arbor Learning Community",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260022201181",
    },
    {
        "school": "South Arbor Charter Academy",
        "district": "South Arbor Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260022301182",
    },
    {
        "school": "Pathways To Success Academic Campus",
        "district": "Ann Arbor Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260282001180",
    },
    {
        "school": "Lakewood Elementary School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282001418",
    },
    {
        "school": "Abbot School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004004",
    },
    {
        "school": "Angell School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004005",
    },
    {
        "school": "Ann Arbor Open at Mack School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004006",
    },
    {
        "school": "Burns Park Elementary School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004008",
    },
    {
        "school": "Carpenter School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004009",
    },
    {
        "school": "Dicken Elementary School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004010",
    },
    {
        "school": "Eberwhite School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004012",
    },
    {
        "school": "Forsythe Middle School",
        "district": "Ann Arbor Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004013",
    },
    {
        "school": "Haisley Elementary School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004014",
    },
    {
        "school": "John Allen School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004015",
    },
    {
        "school": "Uriah H Lawton School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004017",
    },
    {
        "school": "Bach Elementary School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004018",
    },
    {
        "school": "Mary D Mitchell School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004019",
    },
    {
        "school": "Ann Arbor STEAM at Northside School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004021",
    },
    {
        "school": "Pattengill School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004022",
    },
    {
        "school": "Pittsfield School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004023",
    },
    {
        "school": "Slauson Middle School",
        "district": "Ann Arbor Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004024",
    },
    {
        "school": "Tappan Middle School",
        "district": "Ann Arbor Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004026",
    },
    {
        "school": "Thurston Elementary School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004027",
    },
    {
        "school": "Wines Elementary School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004028",
    },
    {
        "school": "Pioneer High School",
        "district": "Ann Arbor Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004029",
    },
    {
        "school": "Scarlett Middle School",
        "district": "Ann Arbor Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004031",
    },
    {
        "school": "Huron High School",
        "district": "Ann Arbor Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004032",
    },
    {
        "school": "Community High School",
        "district": "Ann Arbor Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004033",
    },
    {
        "school": "Martin Luther King Elem School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004034",
    },
    {
        "school": "Clague Middle School",
        "district": "Ann Arbor Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004035",
    },
    {
        "school": "Clifford E Bryant Comm School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004036",
    },
    {
        "school": "Logan Elementary School",
        "district": "Ann Arbor Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282004038",
    },
    {
        "school": "Chelsea High School",
        "district": "Chelsea School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260894004437",
    },
    {
        "school": "Beach Middle School",
        "district": "Chelsea School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260894004438",
    },
    {
        "school": "North Creek Elementary School",
        "district": "Chelsea School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260894004439",
    },
    {
        "school": "South Meadows Elementary School",
        "district": "Chelsea School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260894004440",
    },
    {
        "school": "Mill Creek Middle School",
        "district": "Dexter Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261203000738",
    },
    {
        "school": "Wylie Elementary School",
        "district": "Dexter Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261203004914",
    },
    {
        "school": "Dexter High School",
        "district": "Dexter Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261203004916",
    },
    {
        "school": "Creekside Intermediate School",
        "district": "Dexter Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261203004917",
    },
    {
        "school": "Brick Elementary School",
        "district": "Lincoln Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262157005854",
    },
    {
        "school": "Lincoln Senior High School",
        "district": "Lincoln Consolidated School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262157005855",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Lincoln Consolidated School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262157005856",
    },
    {
        "school": "Manchester JuniorSenior High School",
        "district": "Manchester Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262238005952",
    },
    {
        "school": "Luther C Klager Elem School",
        "district": "Manchester Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262238005953",
    },
    {
        "school": "Paddock Elementary School",
        "district": "Milan Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262385006073",
    },
    {
        "school": "Milan Middle School",
        "district": "Milan Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262385006074",
    },
    {
        "school": "Woodland Meadows Elementary School",
        "district": "Saline Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263066001002",
    },
    {
        "school": "Heritage School",
        "district": "Saline Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263066001003",
    },
    {
        "school": "Harvest Elementary School",
        "district": "Saline Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263066001466",
    },
    {
        "school": "Saline Middle School",
        "district": "Saline Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263066006707",
    },
    {
        "school": "Saline High School",
        "district": "Saline Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263066006709",
    },
    {
        "school": "Pleasant Ridge Elementary School",
        "district": "Saline Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263066007724",
    },
    {
        "school": "Whitmore Lake Elementary School",
        "district": "Whitmore Lake Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263633000020",
    },
    {
        "school": "Whitmore Lake High School",
        "district": "Whitmore Lake Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263633007221",
    },
    {
        "school": "Erickson Elementary",
        "district": "Ypsilanti Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263663007281",
    },
    {
        "school": "Estabrook Elementary",
        "district": "Ypsilanti Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263663007282",
    },
    {
        "school": "Perry Early Learning Center",
        "district": "Ypsilanti Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263663007283",
    },
    {
        "school": "High Point School",
        "district": "Washtenaw ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268099000733",
    },
    {
        "school": "Young Adult Programs",
        "district": "Washtenaw ISD",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268099000997",
    },
    {
        "school": "Bishop Elementary School",
        "district": "Lincoln Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262157001000",
    },
    {
        "school": "Ann J Kellogg School",
        "district": "Battle Creek Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000501683",
    },
    {
        "school": "Lamora Park School",
        "district": "Battle Creek Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000501684",
    },
    {
        "school": "Battle Creek Area Learning Center",
        "district": "Battle Creek Area Learning Center",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260027501616",
    },
    {
        "school": "Marshall Opportunity High School",
        "district": "Marshall Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262297001536",
    },
    {
        "school": "Walters Elementary",
        "district": "Marshall Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262297001537",
    },
    {
        "school": "Battle Creek MathSci Center",
        "district": "Battle Creek Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000500477",
    },
    {
        "school": "WK Kellogg Preparatory High School",
        "district": "Battle Creek Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000500807",
    },
    {
        "school": "Battle Creek Central High School",
        "district": "Battle Creek Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000503830",
    },
    {
        "school": "Dudley School",
        "district": "Battle Creek Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000503832",
    },
    {
        "school": "Post Franklin School",
        "district": "Battle Creek Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000503833",
    },
    {
        "school": "Northwestern Middle School",
        "district": "Battle Creek Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000503839",
    },
    {
        "school": "Springfield Middle School",
        "district": "Battle Creek Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000503844",
    },
    {
        "school": "Valley View Elementary School",
        "district": "Battle Creek Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000503847",
    },
    {
        "school": "Verona Elementary School",
        "district": "Battle Creek Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000503848",
    },
    {
        "school": "Arbor Academy",
        "district": "Arbor Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260018101053",
    },
    {
        "school": "Endeavor Charter Academy",
        "district": "Endeavor Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260019201100",
    },
    {
        "school": "Marshall Academy",
        "district": "Marshall Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260025001225",
    },
    {
        "school": "Athens JuniorSenor High School",
        "district": "Athens Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260351004048",
    },
    {
        "school": "East Leroy Elementary School",
        "district": "Athens Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260351004050",
    },
    {
        "school": "Beadle Lake Elementary School",
        "district": "Harper Creek Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261773005435",
    },
    {
        "school": "Harper Creek Middle School",
        "district": "Harper Creek Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261773005436",
    },
    {
        "school": "Harper Creek High School",
        "district": "Harper Creek Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261773005437",
    },
    {
        "school": "Sonoma Elementary",
        "district": "Harper Creek Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261773005438",
    },
    {
        "school": "Wattles Park Elementary School",
        "district": "Harper Creek Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261773005439",
    },
    {
        "school": "Homer Community High School",
        "district": "Homer Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261854005538",
    },
    {
        "school": "Lillian Fletcher Elem School",
        "district": "Homer Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261854005539",
    },
    {
        "school": "Homer Middle School",
        "district": "Homer Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261854005540",
    },
    {
        "school": "Lakeview High School",
        "district": "Lakeview Sch. District (Calhoun)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262085005749",
    },
    {
        "school": "Minges Brook School",
        "district": "Lakeview Sch. District (Calhoun)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262085005750",
    },
    {
        "school": "Prairieview School",
        "district": "Lakeview Sch. District (Calhoun)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262085005751",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Lakeview Sch. District (Calhoun)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262085005752",
    },
    {
        "school": "Westlake Elementary School",
        "district": "Lakeview Sch. District (Calhoun)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262085005753",
    },
    {
        "school": "Lakeview Middle School",
        "district": "Lakeview Sch. District (Calhoun)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262085005754",
    },
    {
        "school": "Mar Lee School",
        "district": "Mar Lee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262283007663",
    },
    {
        "school": "Gordon Elementary School",
        "district": "Marshall Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262297005981",
    },
    {
        "school": "Hughes Elementary School",
        "district": "Marshall Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262297005982",
    },
    {
        "school": "Marshall Middle School",
        "district": "Marshall Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262297005983",
    },
    {
        "school": "Marshall High School",
        "district": "Marshall Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262297005985",
    },
    {
        "school": "Pennfield Dunlap Elementary",
        "district": "Pennfield Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262781006358",
    },
    {
        "school": "Pennfield Middle School",
        "district": "Pennfield Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262781006359",
    },
    {
        "school": "North Pennfield Elementary",
        "district": "Pennfield Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262781006360",
    },
    {
        "school": "Pennfield Purdy School",
        "district": "Pennfield Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262781006361",
    },
    {
        "school": "Pennfield Senior High School",
        "district": "Pennfield Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262781006362",
    },
    {
        "school": "Tekonsha Schools",
        "district": "Tekonsha Community Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263375006922",
    },
    {
        "school": "Doris Klaussen Dev Center",
        "district": "Calhoun Intermediate School District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268020000118",
    },
    {
        "school": "LLCArenac Campus",
        "district": "Bay-Arenac ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268050401325",
    },
    {
        "school": "BayArenac Community High School",
        "district": "Bay-Arenac Community High School",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260006700463",
    },
    {
        "school": "State Street Academy",
        "district": "State Street Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260026401327",
    },
    {
        "school": "Bangor Central School",
        "district": "Bangor Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260390004075",
    },
    {
        "school": "Christa McAuliffe Middle School",
        "district": "Bangor Township Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260390004077",
    },
    {
        "school": "Bangor Lincoln School",
        "district": "Bangor Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260390004078",
    },
    {
        "school": "Bangor West Central School",
        "district": "Bangor Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260390004080",
    },
    {
        "school": "John Glenn High School",
        "district": "Bangor Township Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260390004081",
    },
    {
        "school": "Bay City Eastern High School",
        "district": "Bay City School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260426000800",
    },
    {
        "school": "Auburn Elementary School",
        "district": "Bay City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004093",
    },
    {
        "school": "Bay City Central High School",
        "district": "Bay City School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004094",
    },
    {
        "school": "Hampton Elementary School",
        "district": "Bay City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004097",
    },
    {
        "school": "Linsday Elementary School",
        "district": "Bay City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004100",
    },
    {
        "school": "Mackensen Elementary School",
        "district": "Bay City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004101",
    },
    {
        "school": "Western Middle School",
        "district": "Bay City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004102",
    },
    {
        "school": "Handy Middle School",
        "district": "Bay City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004105",
    },
    {
        "school": "Washington Elementary School",
        "district": "Bay City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004106",
    },
    {
        "school": "McAlearSawden Elem School",
        "district": "Bay City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004112",
    },
    {
        "school": "Bay City Western High School",
        "district": "Bay City School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004113",
    },
    {
        "school": "Kolb Elementary School",
        "district": "Bay City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004114",
    },
    {
        "school": "MacGregor Elementary School",
        "district": "Bay City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260426004115",
    },
    {
        "school": "Garber High School",
        "district": "Essexville-Hampton Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261353005024",
    },
    {
        "school": "Verellen Elementary School",
        "district": "Essexville-Hampton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261353005026",
    },
    {
        "school": "WR Bush Elementary School",
        "district": "Essexville-Hampton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261353005027",
    },
    {
        "school": "Cramer Junior High School",
        "district": "Essexville-Hampton Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261353005028",
    },
    {
        "school": "Linwood Elementary School",
        "district": "Pinconning Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262817006389",
    },
    {
        "school": "Pinconning High School",
        "district": "Pinconning Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262817006391",
    },
    {
        "school": "Pinconning Central Elementary School",
        "district": "Pinconning Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262817006392",
    },
    {
        "school": "Pinconning Middle School",
        "district": "Pinconning Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262817007747",
    },
    {
        "school": "Detention Center",
        "district": "Bay-Arenac ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268050400454",
    },
    {
        "school": "LLCBay Campus",
        "district": "Bay-Arenac ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268050401324",
    },
    {
        "school": "Crossroads Charter Academy 712",
        "district": "Crossroads Charter Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260018601543",
    },
    {
        "school": "Muskegon River Youth Home",
        "district": "Mecosta-Osceola ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268077001559",
    },
    {
        "school": "Pineview Homes",
        "district": "Mecosta-Osceola ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268077001569",
    },
    {
        "school": "Weidman Elementary School",
        "district": "Chippewa Hills School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260956004448",
    },
    {
        "school": "Crossroads Charter Academy K6",
        "district": "Crossroads Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260018601073",
    },
    {
        "school": "Big Rapids Virtual School",
        "district": "Big Rapids Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260578000643",
    },
    {
        "school": "Big Rapids Middle School",
        "district": "Big Rapids Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260578004204",
    },
    {
        "school": "Big Rapids High School",
        "district": "Big Rapids Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260578004205",
    },
    {
        "school": "Brookside Elementary School",
        "district": "Big Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260578004206",
    },
    {
        "school": "Riverview Elementary School",
        "district": "Big Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260578004209",
    },
    {
        "school": "Mosaic School",
        "district": "Chippewa Hills School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260956000938",
    },
    {
        "school": "Mecosta Elementary School",
        "district": "Chippewa Hills School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260956004447",
    },
    {
        "school": "Chippewa Hills Intermediate School",
        "district": "Chippewa Hills School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260956004449",
    },
    {
        "school": "Barryton Elementary School",
        "district": "Chippewa Hills School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260956004451",
    },
    {
        "school": "Chippewa Hills High School",
        "district": "Chippewa Hills School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260956004452",
    },
    {
        "school": "Morley Stanwood Middle School",
        "district": "Morley Stanwood Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262460000939",
    },
    {
        "school": "Morley Stanwood Elementary School",
        "district": "Morley Stanwood Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262460006110",
    },
    {
        "school": "Morley Stanwood High School",
        "district": "Morley Stanwood Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262460006111",
    },
    {
        "school": "MecostaOsceola Education Center",
        "district": "Mecosta-Osceola ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268077000641",
    },
    {
        "school": "MecostaOsceola Career Center",
        "district": "Mecosta-Osceola ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268077000642",
    },
    {
        "school": "Lake City Elementary School",
        "district": "Lake City Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262061000940",
    },
    {
        "school": "Lake City Middle School",
        "district": "Lake City Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262061007748",
    },
    {
        "school": "Lake City High School",
        "district": "Lake City Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262061007749",
    },
    {
        "school": "McBain High School",
        "district": "McBain Rural Agricultural Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262331006016",
    },
    {
        "school": "McBain Elementary School",
        "district": "McBain Rural Agricultural Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262331006017",
    },
    {
        "school": "Buckley Community Schools",
        "district": "Buckley Community Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260717004313",
    },
    {
        "school": "Mackinaw Trail Middle School",
        "district": "Cadillac Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260759001220",
    },
    {
        "school": "Cadillac Junior High School",
        "district": "Cadillac Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260759004339",
    },
    {
        "school": "Cadillac Senior High School",
        "district": "Cadillac Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260759004340",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Cadillac Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260759004341",
    },
    {
        "school": "Kenwood Elementary School",
        "district": "Cadillac Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260759004342",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Cadillac Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260759004343",
    },
    {
        "school": "Forest View Elementary School",
        "district": "Cadillac Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260759004345",
    },
    {
        "school": "Cadillac Innovation High School",
        "district": "Cadillac Area Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260759007733",
    },
    {
        "school": "Manton Consolidated Middle School",
        "district": "Manton Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262250000791",
    },
    {
        "school": "Manton Consolidated High School",
        "district": "Manton Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262250005966",
    },
    {
        "school": "Manton Consolidated Elem School",
        "district": "Manton Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262250005967",
    },
    {
        "school": "Floyd M Jewett Elem School",
        "district": "Mesick Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262367006043",
    },
    {
        "school": "Mesick Consolidated JrSr High School",
        "district": "Mesick Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262367006044",
    },
    {
        "school": "WexfordMissaukee ISD Career Center",
        "district": "Wexford-Missaukee ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268000001048",
    },
    {
        "school": "WexfordMissaukee ISD Special Education",
        "district": "Wexford-Missaukee ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268000001449",
    },
    {
        "school": "Pansophia Academy",
        "district": "Pansophia Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260006800474",
    },
    {
        "school": "Anderson Elementary School",
        "district": "Bronson Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260696004293",
    },
    {
        "school": "Bronson JrSr High School",
        "district": "Bronson Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260696004294",
    },
    {
        "school": "Ryan Elementary School",
        "district": "Bronson Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260696004295",
    },
    {
        "school": "Coldwater High School",
        "district": "Coldwater Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261014004502",
    },
    {
        "school": "Larsen Elementary School",
        "district": "Coldwater Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261014004503",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Coldwater Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261014004505",
    },
    {
        "school": "Lakeland Elementary School",
        "district": "Coldwater Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261014004506",
    },
    {
        "school": "Legg Middle School",
        "district": "Coldwater Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261014004508",
    },
    {
        "school": "Jennings Elementary School",
        "district": "Quincy Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262925006510",
    },
    {
        "school": "Quincy High School",
        "district": "Quincy Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262925006511",
    },
    {
        "school": "Quincy Middle School",
        "district": "Quincy Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262925006512",
    },
    {
        "school": "Waldron Learning Center",
        "district": "Branch ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268018000472",
    },
    {
        "school": "Branch Area Careers Center",
        "district": "Branch ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268018000473",
    },
    {
        "school": "Union City Middle School",
        "district": "Union City Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263441006982",
    },
    {
        "school": "Union City High School",
        "district": "Union City Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263441006983",
    },
    {
        "school": "Union City Elementary School",
        "district": "Union City Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263441006984",
    },
    {
        "school": "Almont Middle School",
        "district": "Almont Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260267001839",
    },
    {
        "school": "Quest High School",
        "district": "North Branch Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262568001770",
    },
    {
        "school": "Ruahmah J Hutchings Elementary",
        "district": "Howell Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261872001524",
    },
    {
        "school": "Conner Creek Academy East  Michigan Collegiate",
        "district": "Conner Creek Academy East",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021001494",
    },
    {
        "school": "Merritt Academy",
        "district": "Merritt Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260028101598",
    },
    {
        "school": "Mt Clemens Montessori Academy",
        "district": "Mt. Clemens Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260028301646",
    },
    {
        "school": "Academy of Warren",
        "district": "Academy of Warren",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260030801884",
    },
    {
        "school": "Prevail Academy",
        "district": "Prevail Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260031001754",
    },
    {
        "school": "Lighthouse Elementary School",
        "district": "Anchor Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260279001490",
    },
    {
        "school": "Chippewa Valley Adult and Mohegan Alt Educ",
        "district": "Chippewa Valley Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260957001803",
    },
    {
        "school": "Continuing Education Center",
        "district": "Clintondale Community Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261008001881",
    },
    {
        "school": "Dooley Center",
        "district": "Fraser Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261482001753",
    },
    {
        "school": "Seminole Academy",
        "district": "Mount Clemens Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262469001673",
    },
    {
        "school": "New Haven Elementary School",
        "district": "New Haven Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262523001751",
    },
    {
        "school": "North Lake High School",
        "district": "Lake Shore Public Schools (Macomb)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263267001612",
    },
    {
        "school": "Beacon Tree Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447001840",
    },
    {
        "school": "Career Preparation Center",
        "district": "Warren Consolidated Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "263519001586",
    },
    {
        "school": "Detroit Community Schools  Elementary",
        "district": "Detroit Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260017001934",
    },
    {
        "school": "Bradford Academy",
        "district": "Bradford Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260028401644",
    },
    {
        "school": "Life Skills Center of Pontiac",
        "district": "Life Skills Center of Pontiac",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260029201723",
    },
    {
        "school": "Great Oaks Academy",
        "district": "Great Oaks Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260029401725",
    },
    {
        "school": "Crescent Academy Middle School",
        "district": "Crescent Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260029501726",
    },
    {
        "school": "Laurus Academy",
        "district": "Laurus Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260029601728",
    },
    {
        "school": "Renaissance Alternative High School",
        "district": "Clarkston Community School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260990001554",
    },
    {
        "school": "CASA",
        "district": "Ferndale Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261428001898",
    },
    {
        "school": "University High School",
        "district": "Ferndale Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261428001901",
    },
    {
        "school": "Hazel Park Junior High School",
        "district": "Hazel Park School District of the City of",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261803001691",
    },
    {
        "school": "Webb Elementary School",
        "district": "Hazel Park School District of the City of",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261803001697",
    },
    {
        "school": "Keller Elementary",
        "district": "Royal Oak Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263030002068",
    },
    {
        "school": "Royal Oak Middle School",
        "district": "Royal Oak Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263030002069",
    },
    {
        "school": "Addams Elementary and ECC",
        "district": "Royal Oak Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263030002070",
    },
    {
        "school": "Centennial Middle School",
        "district": "South Lyon Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225001599",
    },
    {
        "school": "Sharon J Hardy Elementary School",
        "district": "South Lyon Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225001687",
    },
    {
        "school": "South Lyon East High School",
        "district": "South Lyon Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225001837",
    },
    {
        "school": "Troy Center for Transition",
        "district": "Troy School District",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263426001729",
    },
    {
        "school": "Waterford Durant High School",
        "district": "Waterford School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263531001512",
    },
    {
        "school": "St Clair County Intervention Academy",
        "district": "St. Clair County Intervention Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260031601767",
    },
    {
        "school": "Cesar Chavez High School",
        "district": "Cesar Chavez Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260013901488",
    },
    {
        "school": "Academy for Business and Technology Elementary",
        "district": "Academy for Business and Technology",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260016601667",
    },
    {
        "school": "Oakland International Academy  Elementary",
        "district": "Oakland International Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021701660",
    },
    {
        "school": "Voyageur College Prep",
        "district": "Voyageur Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260022701485",
    },
    {
        "school": "Old Redford Academy  High",
        "district": "Old Redford Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260024201699",
    },
    {
        "school": "Joy Preparatory Academy",
        "district": "Joy Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260024401663",
    },
    {
        "school": "Trillium Academy",
        "district": "Trillium Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260027701477",
    },
    {
        "school": "Detroit Merit Charter Academy",
        "district": "Detroit Merit Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260027801484",
    },
    {
        "school": "Hamtramck Academy",
        "district": "Hamtramck Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260028701656",
    },
    {
        "school": "Keystone Academy",
        "district": "Keystone Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260028901655",
    },
    {
        "school": "Riverside Academy",
        "district": "Riverside Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260029101650",
    },
    {
        "school": "Riverside Academy  West Campus",
        "district": "Riverside Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260029101941",
    },
    {
        "school": "Frontier International Academy",
        "district": "Frontier International Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260030101945",
    },
    {
        "school": "Detroit Enterprise Academy",
        "district": "Detroit Enterprise Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260030201738",
    },
    {
        "school": "Hanley International Academy",
        "district": "Hanley International Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260030501944",
    },
    {
        "school": "Bridge Academy East",
        "district": "Bridge Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260030601706",
    },
    {
        "school": "Detroit Premier Academy",
        "district": "Detroit Premier Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260030701943",
    },
    {
        "school": "American Montessori Academy Elementary",
        "district": "American Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260031201763",
    },
    {
        "school": "Covenant House Academy Detroit  Central Site",
        "district": "Covenant House Academy Detroit",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260032201949",
    },
    {
        "school": "Salina Elementary P  3",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160001500",
    },
    {
        "school": "McCollough Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160001739",
    },
    {
        "school": "Unis Middle School",
        "district": "Dearborn City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160001740",
    },
    {
        "school": "Geer Park Elementary",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160001818",
    },
    {
        "school": "Tomlinson Middle School",
        "district": "Westwood Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261164001735",
    },
    {
        "school": "Allendale Elementary School",
        "district": "Melvindale-North Allen Park Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262346001838",
    },
    {
        "school": "Ridge Wood Elementary School",
        "district": "Northville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262598001505",
    },
    {
        "school": "Workman Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856001929",
    },
    {
        "school": "B Beck Education Center",
        "district": "Redford Union Schools District No. 1",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262946001566",
    },
    {
        "school": "Romulus Adult Education Alternative",
        "district": "Romulus Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263012001647",
    },
    {
        "school": "Asher School",
        "district": "Southgate Community School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263234001932",
    },
    {
        "school": "Kensington Woods Schools",
        "district": "Kensington Woods Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260009900612",
    },
    {
        "school": "Charyl Stockwell Academy",
        "district": "Charyl Stockwell Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260010000613",
    },
    {
        "school": "Brighton High School",
        "district": "Brighton Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260687004283",
    },
    {
        "school": "Scranton Middle School",
        "district": "Brighton Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260687004284",
    },
    {
        "school": "Hawkins Elementary School",
        "district": "Brighton Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260687004285",
    },
    {
        "school": "Spencer Road Elementary School",
        "district": "Brighton Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260687004288",
    },
    {
        "school": "Hornung Elementary School",
        "district": "Brighton Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260687004289",
    },
    {
        "school": "Hilton Road Elementary School",
        "district": "Brighton Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260687007677",
    },
    {
        "school": "Natalie Kreeger Elementary School",
        "district": "Fowlerville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261473000013",
    },
    {
        "school": "Fowlerville Junior High School",
        "district": "Fowlerville Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261473001140",
    },
    {
        "school": "HT Smith Elementary School",
        "district": "Fowlerville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261473005169",
    },
    {
        "school": "Fowlerville High School",
        "district": "Fowlerville Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261473005170",
    },
    {
        "school": "Legacy High School",
        "district": "Hartland Consolidated Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261791000090",
    },
    {
        "school": "Hartland MS at Ore Creek",
        "district": "Hartland Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261791001066",
    },
    {
        "school": "Creekside Elementary School",
        "district": "Hartland Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261791001470",
    },
    {
        "school": "Hartland Round Elementary School",
        "district": "Hartland Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261791005457",
    },
    {
        "school": "Hartland High School",
        "district": "Hartland Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261791005458",
    },
    {
        "school": "Hartland Village Elementary School",
        "district": "Hartland Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261791005459",
    },
    {
        "school": "Hartland Farms Intermediate School",
        "district": "Hartland Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261791005461",
    },
    {
        "school": "Hartland Lakes Elementary School",
        "district": "Hartland Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261791005462",
    },
    {
        "school": "Challenger Elementary School",
        "district": "Howell Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261872000042",
    },
    {
        "school": "Voyager Elementary School",
        "district": "Howell Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261872001067",
    },
    {
        "school": "Parker Middle School",
        "district": "Howell Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261872005549",
    },
    {
        "school": "Howell High School",
        "district": "Howell Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261872005550",
    },
    {
        "school": "Northwest Elementary School",
        "district": "Howell Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261872005551",
    },
    {
        "school": "Three Fires Elementary",
        "district": "Howell Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261872005552",
    },
    {
        "school": "Southwest Elementary School",
        "district": "Howell Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261872005554",
    },
    {
        "school": "Highlander Way Middle School",
        "district": "Howell Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261872005555",
    },
    {
        "school": "Farley Hill Elementary School",
        "district": "Pinckney Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262814000012",
    },
    {
        "school": "Pathfinder School",
        "district": "Pinckney Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262814001141",
    },
    {
        "school": "Country Elementary School",
        "district": "Pinckney Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262814006382",
    },
    {
        "school": "Pinckney  Community High School",
        "district": "Pinckney Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262814006385",
    },
    {
        "school": "Navigator Upper Elementary School",
        "district": "Pinckney Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262814006387",
    },
    {
        "school": "Pathway School",
        "district": "Livingston ESA",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268070000188",
    },
    {
        "school": "Chatfield School",
        "district": "Chatfield School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260015100915",
    },
    {
        "school": "Orchard Primary School",
        "district": "Almont Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260267001137",
    },
    {
        "school": "Almont High School",
        "district": "Almont Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260267003982",
    },
    {
        "school": "Dryden High School",
        "district": "Dryden Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261224004926",
    },
    {
        "school": "Dryden  Elementary School",
        "district": "Dryden Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261224004927",
    },
    {
        "school": "Venture High School",
        "district": "Imlay City Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261910000053",
    },
    {
        "school": "Imlay City Middle School",
        "district": "Imlay City Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261910000186",
    },
    {
        "school": "Imlay City High School",
        "district": "Imlay City Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261910005589",
    },
    {
        "school": "Weston Elementary School",
        "district": "Imlay City Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261910005590",
    },
    {
        "school": "Borland Elementary School",
        "district": "Imlay City Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261910005591",
    },
    {
        "school": "Mayfield Elementary School",
        "district": "Lapeer Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262118005836",
    },
    {
        "school": "Turrill Elementary School",
        "district": "Lapeer Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262118005837",
    },
    {
        "school": "Elva Lynch Elementary School",
        "district": "Lapeer Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262118005838",
    },
    {
        "school": "Lapeer High School",
        "district": "Lapeer Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262118005840",
    },
    {
        "school": "CK Schickler Elementary School",
        "district": "Lapeer Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262118005841",
    },
    {
        "school": "Emma Murphy Elementary School",
        "district": "Lapeer Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262118005842",
    },
    {
        "school": "Center for Innovation",
        "district": "Lapeer Community Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262118007659",
    },
    {
        "school": "North Branch High School",
        "district": "North Branch Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262568006213",
    },
    {
        "school": "North Branch Elementary School",
        "district": "North Branch Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262568006215",
    },
    {
        "school": "Ruth Fox Middle School",
        "district": "North Branch Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262568006216",
    },
    {
        "school": "Lapeer Co Education and Technology  Center",
        "district": "Lapeer ISD",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268066000914",
    },
    {
        "school": "William A Brummer Elementary School",
        "district": "South Lyon Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225001245",
    },
    {
        "school": "Macomb Academy",
        "district": "Macomb Academy",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260010100637",
    },
    {
        "school": "Conner Creek Academy East  Elementary",
        "district": "Conner Creek Academy East",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021001144",
    },
    {
        "school": "Huron Academy Grades K2",
        "district": "Huron Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021101145",
    },
    {
        "school": "Global Preparatory Academy",
        "district": "Global Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021201146",
    },
    {
        "school": "Arts Academy in the Woods",
        "district": "Arts Academy in the Woods",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260027301308",
    },
    {
        "school": "Anchor Bay Middle School North",
        "district": "Anchor Bay School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260279000196",
    },
    {
        "school": "Sugarbush Elementary School",
        "district": "Anchor Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260279000197",
    },
    {
        "school": "Great Oaks Elementary School",
        "district": "Anchor Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260279000198",
    },
    {
        "school": "Compass Pointe",
        "district": "Anchor Bay School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260279000922",
    },
    {
        "school": "Anchor Bay Middle School South",
        "district": "Anchor Bay School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260279001142",
    },
    {
        "school": "Ashley Elementary School",
        "district": "Anchor Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260279003998",
    },
    {
        "school": "Dean A Naldrett School",
        "district": "Anchor Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260279003999",
    },
    {
        "school": "Lottie M Schmidt Elem School",
        "district": "Anchor Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260279004001",
    },
    {
        "school": "Orville C Krause Elementary School",
        "district": "Armada Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260324001375",
    },
    {
        "school": "Armada High School",
        "district": "Armada Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260324004042",
    },
    {
        "school": "Armada Middle School",
        "district": "Armada Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260324004044",
    },
    {
        "school": "Center Line High School",
        "district": "Center Line Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260858004404",
    },
    {
        "school": "Crothers Elementary School",
        "district": "Center Line Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260858004405",
    },
    {
        "school": "Mark C Roose Elementary School",
        "district": "Center Line Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260858004407",
    },
    {
        "school": "May V Peck Elementary School",
        "district": "Center Line Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260858004408",
    },
    {
        "school": "Wolfe Middle School",
        "district": "Center Line Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260858004409",
    },
    {
        "school": "Seneca Middle School",
        "district": "Chippewa Valley Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957000199",
    },
    {
        "school": "Cherokee Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957000200",
    },
    {
        "school": "Dakota High School",
        "district": "Chippewa Valley Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957000623",
    },
    {
        "school": "Cheyenne Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957001070",
    },
    {
        "school": "Shawnee Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957001309",
    },
    {
        "school": "Fox Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957004453",
    },
    {
        "school": "Chippewa Valley High School",
        "district": "Chippewa Valley Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957004454",
    },
    {
        "school": "Clinton Valley Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957004455",
    },
    {
        "school": "Wyandot Middle School",
        "district": "Chippewa Valley Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957004456",
    },
    {
        "school": "Iroquois Middle School",
        "district": "Chippewa Valley Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957004457",
    },
    {
        "school": "Ojibwa Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957004458",
    },
    {
        "school": "Ottawa Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957004459",
    },
    {
        "school": "Algonquin Middle School",
        "district": "Chippewa Valley Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957004460",
    },
    {
        "school": "Huron Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957004461",
    },
    {
        "school": "Miami Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957004462",
    },
    {
        "school": "Mohawk Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957007450",
    },
    {
        "school": "Erie Elementary School",
        "district": "Chippewa Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957007514",
    },
    {
        "school": "Clintondale High School",
        "district": "Clintondale Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261008004491",
    },
    {
        "school": "Charles C McGlinnen School",
        "district": "Clintondale Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261008004493",
    },
    {
        "school": "Clintondale Middle School",
        "district": "Clintondale Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261008004494",
    },
    {
        "school": "Rainbow Elementary School",
        "district": "Clintondale Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261008004495",
    },
    {
        "school": "Robbie Hall Parker School",
        "district": "Clintondale Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261008004496",
    },
    {
        "school": "Bellview  Elementary School",
        "district": "Eastpointe Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261245004948",
    },
    {
        "school": "Eastpointe High School",
        "district": "Eastpointe Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261245004950",
    },
    {
        "school": "Eastpointe Middle School",
        "district": "Eastpointe Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261245004953",
    },
    {
        "school": "Pleasantview  Elementary School",
        "district": "Eastpointe Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261245004955",
    },
    {
        "school": "Fitzgerald Senior High School",
        "district": "Fitzgerald Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261446005082",
    },
    {
        "school": "Mound Park Elementary School",
        "district": "Fitzgerald Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261446005083",
    },
    {
        "school": "Westview Elementary School",
        "district": "Fitzgerald Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261446005085",
    },
    {
        "school": "PD Chatterton Middle School",
        "district": "Fitzgerald Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261446005086",
    },
    {
        "school": "Salk Elementary School",
        "district": "Fraser Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261482005177",
    },
    {
        "school": "Eisenhower Elementary School",
        "district": "Fraser Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261482005178",
    },
    {
        "school": "Fraser High School",
        "district": "Fraser Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261482005179",
    },
    {
        "school": "Mark Twain Elementary School",
        "district": "Fraser Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261482005180",
    },
    {
        "school": "Ralph Waldo Emerson Elem School",
        "district": "Fraser Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261482005181",
    },
    {
        "school": "Thomas A Edison Elem School",
        "district": "Fraser Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261482005183",
    },
    {
        "school": "Walt Disney Elementary School",
        "district": "Fraser Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261482005184",
    },
    {
        "school": "Richards Middle School",
        "district": "Fraser Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261482005185",
    },
    {
        "school": "Ardmore Elementary School",
        "district": "Lakeview Public Schools (Macomb)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262088005755",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Lakeview Public Schools (Macomb)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262088005756",
    },
    {
        "school": "Greenwood Elementary School",
        "district": "Lakeview Public Schools (Macomb)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262088005757",
    },
    {
        "school": "Harmon Elementary School",
        "district": "Lakeview Public Schools (Macomb)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262088005758",
    },
    {
        "school": "Lakeview High School",
        "district": "Lakeview Public Schools (Macomb)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262088005759",
    },
    {
        "school": "Princeton Elementary School",
        "district": "Lakeview Public Schools (Macomb)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262088005760",
    },
    {
        "school": "Macomb County Juvenile Justice Center School",
        "district": "L'Anse Creuse Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262187000202",
    },
    {
        "school": "South River Elementary School",
        "district": "L'Anse Creuse Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187000627",
    },
    {
        "school": "Frederick V Pankow Center",
        "district": "L'Anse Creuse Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "262187000628",
    },
    {
        "school": "Francis A Higgins Elem School",
        "district": "L'Anse Creuse Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187000630",
    },
    {
        "school": "LAnse Creuse Middle School  East",
        "district": "L'Anse Creuse Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187001236",
    },
    {
        "school": "Joseph M Carkenord Elementary School",
        "district": "L'Anse Creuse Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187001379",
    },
    {
        "school": "Atwood Elementary School",
        "district": "L'Anse Creuse Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187005908",
    },
    {
        "school": "LAnse Creuse Middle School  North",
        "district": "L'Anse Creuse Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187005910",
    },
    {
        "school": "LAnse Creuse Middle School  South",
        "district": "L'Anse Creuse Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187005911",
    },
    {
        "school": "LAnse Creuse High School",
        "district": "L'Anse Creuse Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187005912",
    },
    {
        "school": "Marie C Graham Elem School",
        "district": "L'Anse Creuse Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187005913",
    },
    {
        "school": "Green Elementary School",
        "district": "L'Anse Creuse Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187005915",
    },
    {
        "school": "Emma V Lobbestael Elem School",
        "district": "L'Anse Creuse Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187005917",
    },
    {
        "school": "LAnse Creuse High School  North",
        "district": "L'Anse Creuse Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187005918",
    },
    {
        "school": "Tenniswood Elementary School",
        "district": "L'Anse Creuse Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187005919",
    },
    {
        "school": "Donald J Yacks Elem School",
        "district": "L'Anse Creuse Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187005921",
    },
    {
        "school": "LAnse Creuse Middle School  Central",
        "district": "L'Anse Creuse Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262187007736",
    },
    {
        "school": "Memphis JuniorSenior High School",
        "district": "Memphis Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262349006025",
    },
    {
        "school": "Mount Clemens High School",
        "district": "Mount Clemens Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262469006118",
    },
    {
        "school": "Mount Clemens Middle School",
        "district": "Mount Clemens Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262469007557",
    },
    {
        "school": "New Haven High School",
        "district": "New Haven Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262523006184",
    },
    {
        "school": "Richmond Middle School",
        "district": "Richmond Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262967000051",
    },
    {
        "school": "Richmond Community High School",
        "district": "Richmond Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262967006549",
    },
    {
        "school": "Will L Lee School",
        "district": "Richmond Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262967006550",
    },
    {
        "school": "Hevel Elementary",
        "district": "Romeo Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263009001310",
    },
    {
        "school": "Indian Hills Elementary School",
        "district": "Romeo Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263009006596",
    },
    {
        "school": "Romeo High School",
        "district": "Romeo Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263009006597",
    },
    {
        "school": "Romeo Middle School",
        "district": "Romeo Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263009006598",
    },
    {
        "school": "Washington Elementary School",
        "district": "Romeo Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263009006599",
    },
    {
        "school": "Amanda Moore Elementary School",
        "district": "Romeo Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263009006600",
    },
    {
        "school": "Powell Middle School",
        "district": "Romeo Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263009006601",
    },
    {
        "school": "Dort Elementary School",
        "district": "Roseville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263021006615",
    },
    {
        "school": "John R Kment Elementary School",
        "district": "Roseville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263021006616",
    },
    {
        "school": "Eastland Middle School",
        "district": "Roseville Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263021006617",
    },
    {
        "school": "Fountain Elementary School",
        "district": "Roseville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263021006619",
    },
    {
        "school": "Huron Park Elementary School",
        "district": "Roseville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263021006621",
    },
    {
        "school": "Kaiser Elementary School",
        "district": "Roseville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263021006622",
    },
    {
        "school": "Lucile S Patton Elem School",
        "district": "Roseville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263021006624",
    },
    {
        "school": "Roseville Middle School",
        "district": "Roseville Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263021006627",
    },
    {
        "school": "Roseville High School",
        "district": "Roseville Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263021006628",
    },
    {
        "school": "Avalon Elementary School",
        "district": "South Lake Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263222000205",
    },
    {
        "school": "Koepsell Elementary School",
        "district": "South Lake Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263222000633",
    },
    {
        "school": "Elmwood Elementary School",
        "district": "South Lake Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263222006748",
    },
    {
        "school": "South Lake Middle School",
        "district": "South Lake Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263222006749",
    },
    {
        "school": "South Lake High School",
        "district": "South Lake Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263222006751",
    },
    {
        "school": "Rodgers Elementary School",
        "district": "Lake Shore Public Schools (Macomb)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263267006814",
    },
    {
        "school": "Lake Shore High School",
        "district": "Lake Shore Public Schools (Macomb)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263267006815",
    },
    {
        "school": "Masonic Heights Elementary School",
        "district": "Lake Shore Public Schools (Macomb)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263267006816",
    },
    {
        "school": "Violet Elementary School",
        "district": "Lake Shore Public Schools (Macomb)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263267006818",
    },
    {
        "school": "Kennedy Middle School",
        "district": "Lake Shore Public Schools (Macomb)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263267006819",
    },
    {
        "school": "Beck Centennial Elem School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447000927",
    },
    {
        "school": "Richard J Duncan Elementary",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447001311",
    },
    {
        "school": "Burr Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447006990",
    },
    {
        "school": "Dresden Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447006991",
    },
    {
        "school": "Schwarzkoff Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447006992",
    },
    {
        "school": "Eppler Junior High School",
        "district": "Utica Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447006993",
    },
    {
        "school": "Flickinger Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447006995",
    },
    {
        "school": "Jack Harvey Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447006996",
    },
    {
        "school": "Morgan Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447006997",
    },
    {
        "school": "Frank Jeannette Jr High School",
        "district": "Utica Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447006998",
    },
    {
        "school": "Plumbrook Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447006999",
    },
    {
        "school": "Shelby Junior High School",
        "district": "Utica Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007001",
    },
    {
        "school": "Browning Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007002",
    },
    {
        "school": "Bemis Junior High School",
        "district": "Utica Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007003",
    },
    {
        "school": "Switzer Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007004",
    },
    {
        "school": "Utica High School",
        "district": "Utica Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007005",
    },
    {
        "school": "West Utica Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007006",
    },
    {
        "school": "Wiley Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007007",
    },
    {
        "school": "Adlai Stevenson High School",
        "district": "Utica Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007009",
    },
    {
        "school": "Issac Monfort Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007011",
    },
    {
        "school": "Bruce Collins Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007014",
    },
    {
        "school": "Davis Junior High School",
        "district": "Utica Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007015",
    },
    {
        "school": "Crissman Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007017",
    },
    {
        "school": "Eisenhower High School",
        "district": "Utica Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007018",
    },
    {
        "school": "Roberts Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007019",
    },
    {
        "school": "Oakbrook Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007020",
    },
    {
        "school": "Dekeyser Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007021",
    },
    {
        "school": "Malow Junior High School",
        "district": "Utica Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007022",
    },
    {
        "school": "Graebner Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007023",
    },
    {
        "school": "Havel Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007024",
    },
    {
        "school": "Henry Ford II High School",
        "district": "Utica Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007025",
    },
    {
        "school": "Heritage Junior High School",
        "district": "Utica Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007026",
    },
    {
        "school": "Schuchard Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007027",
    },
    {
        "school": "Floyd Ebeling Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007028",
    },
    {
        "school": "Messmore Elementary School",
        "district": "Utica Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007437",
    },
    {
        "school": "Lincoln High School",
        "district": "Van Dyke Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263468007048",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Van Dyke Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263468007049",
    },
    {
        "school": "Marjorie Carlson Elementary School",
        "district": "Van Dyke Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263468007050",
    },
    {
        "school": "McKinley Elementary School",
        "district": "Van Dyke Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263468007052",
    },
    {
        "school": "Warren Consolidated Community High School",
        "district": "Warren Consolidated Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263519000929",
    },
    {
        "school": "Warren Mott High School",
        "district": "Warren Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007088",
    },
    {
        "school": "Cousino Senior High School",
        "district": "Warren Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007089",
    },
    {
        "school": "Cromie Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007090",
    },
    {
        "school": "Green Acres Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007093",
    },
    {
        "school": "Black Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007095",
    },
    {
        "school": "Wilde Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007096",
    },
    {
        "school": "Lean Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007099",
    },
    {
        "school": "Siersma Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007100",
    },
    {
        "school": "Wilkerson Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007103",
    },
    {
        "school": "Carter Middle School",
        "district": "Warren Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007106",
    },
    {
        "school": "Beer Middle School",
        "district": "Warren Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007107",
    },
    {
        "school": "Grissom Middle School",
        "district": "Warren Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007108",
    },
    {
        "school": "Willow Woods Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007109",
    },
    {
        "school": "Harwood Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007110",
    },
    {
        "school": "Sterling Heights Senior HS",
        "district": "Warren Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007112",
    },
    {
        "school": "Carleton Middle School",
        "district": "Warren Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007114",
    },
    {
        "school": "Holden Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007115",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007119",
    },
    {
        "school": "Warren Woods Enterprise HS",
        "district": "Warren Woods Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263522000636",
    },
    {
        "school": "Warren Woods Middle School",
        "district": "Warren Woods Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263522007120",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Warren Woods Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263522007121",
    },
    {
        "school": "Briarwood Elementary School",
        "district": "Warren Woods Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263522007122",
    },
    {
        "school": "Pinewood Elementary School",
        "district": "Warren Woods Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263522007123",
    },
    {
        "school": "Warren Woods Tower High School",
        "district": "Warren Woods Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263522007124",
    },
    {
        "school": "Rockwell Middle School",
        "district": "Macomb ISD",
        "level": "Middle",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268072000615",
    },
    {
        "school": "Maple Lane School",
        "district": "Macomb ISD",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268072000616",
    },
    {
        "school": "Glen H Peters School",
        "district": "Macomb ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268072000617",
    },
    {
        "school": "Lutz School for Work Experience",
        "district": "Macomb ISD",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268072000618",
    },
    {
        "school": "Keith Bovenschen School",
        "district": "Macomb ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268072000619",
    },
    {
        "school": "Neil E Reid High School",
        "district": "Macomb ISD",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268072000620",
    },
    {
        "school": "Bozymowski Center",
        "district": "Macomb ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268072000621",
    },
    {
        "school": "Macomb MIPP Center",
        "district": "Macomb ISD",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268072001370",
    },
    {
        "school": "AGBU AlexMarie Manoogian School",
        "district": "AGBU Alex-Marie Manoogian School",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260010600688",
    },
    {
        "school": "Pontiac Academy for Excellence",
        "district": "Pontiac Academy for Excellence",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260015600970",
    },
    {
        "school": "Great Lakes Academy",
        "district": "Great Lakes Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260015700971",
    },
    {
        "school": "Chandler Park Academy  Elementary",
        "district": "Chandler Park Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260016801441",
    },
    {
        "school": "Dr Joseph F Pollack Academic Center of Excellence",
        "district": "Dr. Joseph F. Pollack Academic Center of Excellence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021501164",
    },
    {
        "school": "Holly Academy",
        "district": "Holly Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021601165",
    },
    {
        "school": "Oakland International Academy  K1",
        "district": "Oakland International Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021701166",
    },
    {
        "school": "Walton Charter Academy",
        "district": "Walton Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260025401247",
    },
    {
        "school": "Arts and Technology Academy of Pontiac",
        "district": "Arts and Technology Academy of Pontiac",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260026701403",
    },
    {
        "school": "Avondale Middle School",
        "district": "Avondale School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260369000231",
    },
    {
        "school": "Avondale Academy",
        "district": "Avondale School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260369000667",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Avondale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260369001158",
    },
    {
        "school": "Auburn Elementary School",
        "district": "Avondale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260369004062",
    },
    {
        "school": "R Grant Graham Elem School",
        "district": "Avondale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260369004066",
    },
    {
        "school": "Avondale High School",
        "district": "Avondale School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260369004067",
    },
    {
        "school": "Deerfield Elementary School",
        "district": "Avondale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260369007667",
    },
    {
        "school": "Anderson Middle School",
        "district": "Berkley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260501004186",
    },
    {
        "school": "Berkley High School",
        "district": "Berkley School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260501004187",
    },
    {
        "school": "Burton Elementary School",
        "district": "Berkley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260501004188",
    },
    {
        "school": "Rogers Elementary School",
        "district": "Berkley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260501004189",
    },
    {
        "school": "Angell Elementary School",
        "district": "Berkley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260501004190",
    },
    {
        "school": "Norup International School",
        "district": "Berkley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260501004191",
    },
    {
        "school": "Pattengill Elementary School",
        "district": "Berkley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260501004193",
    },
    {
        "school": "Berkshire Middle School",
        "district": "Birmingham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004213",
    },
    {
        "school": "Beverly Elementary School",
        "district": "Birmingham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004214",
    },
    {
        "school": "Birmingham Covington School",
        "district": "Birmingham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004215",
    },
    {
        "school": "Derby Middle School",
        "district": "Birmingham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004216",
    },
    {
        "school": "Ernest W Seaholm High School",
        "district": "Birmingham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004217",
    },
    {
        "school": "Greenfield Elementary School",
        "district": "Birmingham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004218",
    },
    {
        "school": "Harlan Elementary School",
        "district": "Birmingham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004219",
    },
    {
        "school": "Pembroke Elementary School",
        "district": "Birmingham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004222",
    },
    {
        "school": "Pierce Elementary School",
        "district": "Birmingham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004223",
    },
    {
        "school": "Quarton Elementary",
        "district": "Birmingham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004224",
    },
    {
        "school": "Wylie E Groves High School",
        "district": "Birmingham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004226",
    },
    {
        "school": "Bingham Farms Elementary School",
        "district": "Birmingham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004227",
    },
    {
        "school": "West Maple Elementary School",
        "district": "Birmingham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260585004228",
    },
    {
        "school": "Conant Elementary School",
        "district": "Bloomfield Hills Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260609004233",
    },
    {
        "school": "West Hills Middle School",
        "district": "Bloomfield Hills Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260609004234",
    },
    {
        "school": "East Hills Middle School",
        "district": "Bloomfield Hills Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260609004236",
    },
    {
        "school": "Eastover Elementary School",
        "district": "Bloomfield Hills Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260609004237",
    },
    {
        "school": "Way Elementary School",
        "district": "Bloomfield Hills Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260609004240",
    },
    {
        "school": "Wing Lake Developmental Center",
        "district": "Bloomfield Hills Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260609004241",
    },
    {
        "school": "Bloomfield Hills Middle School",
        "district": "Bloomfield Hills Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260609004242",
    },
    {
        "school": "Lone Pine Elementary School",
        "district": "Bloomfield Hills Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260609004244",
    },
    {
        "school": "Fox Hills Center",
        "district": "Bloomfield Hills Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260609007668",
    },
    {
        "school": "Brandon High School",
        "district": "Brandon School District in the Counties of Oakland and Lapee",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260657004257",
    },
    {
        "school": "Oakwood Elementary School",
        "district": "Brandon School District in the Counties of Oakland and Lapee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260657004258",
    },
    {
        "school": "Brandon Middle School",
        "district": "Brandon School District in the Counties of Oakland and Lapee",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260657004259",
    },
    {
        "school": "HarveySwanson Elementary School",
        "district": "Brandon School District in the Counties of Oakland and Lapee",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260657004260",
    },
    {
        "school": "Springfield Plains Elem School",
        "district": "Clarkston Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260990000233",
    },
    {
        "school": "Student Support Services",
        "district": "Clarkston Community School District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260990000678",
    },
    {
        "school": "Independence Elementary School",
        "district": "Clarkston Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260990001160",
    },
    {
        "school": "Andersonville Elementary School",
        "district": "Clarkston Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260990004471",
    },
    {
        "school": "Bailey Lake Elementary  School",
        "district": "Clarkston Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260990004472",
    },
    {
        "school": "Clarkston Elementary School",
        "district": "Clarkston Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260990004473",
    },
    {
        "school": "Clarkston Junior High School",
        "district": "Clarkston Community School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260990004474",
    },
    {
        "school": "Clarkston High School",
        "district": "Clarkston Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260990004475",
    },
    {
        "school": "Pine Knob Elementary School",
        "district": "Clarkston Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260990004476",
    },
    {
        "school": "North Sashabaw Elementary School",
        "district": "Clarkston Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260990004478",
    },
    {
        "school": "Sashabaw Middle School",
        "district": "Clarkston Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260990004479",
    },
    {
        "school": "Clawson High School",
        "district": "Clawson Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260993004481",
    },
    {
        "school": "Clawson Middle School",
        "district": "Clawson Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260993004482",
    },
    {
        "school": "Kenwood Elementary School",
        "district": "Clawson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260993004483",
    },
    {
        "school": "Paul A Schalm School",
        "district": "Clawson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260993004484",
    },
    {
        "school": "Beechview Elementary School",
        "district": "Farmington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005033",
    },
    {
        "school": "East Middle School",
        "district": "Farmington Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005036",
    },
    {
        "school": "Visions Unlimited",
        "district": "Farmington Public School District",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261407005038",
    },
    {
        "school": "Farmington High School",
        "district": "Farmington Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005039",
    },
    {
        "school": "Gill Elementary School",
        "district": "Farmington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005041",
    },
    {
        "school": "Kenbrook Elementary School",
        "district": "Farmington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005042",
    },
    {
        "school": "JA Lanigan Elementary School",
        "district": "Farmington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005043",
    },
    {
        "school": "Longacre Elementary School",
        "district": "Farmington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005044",
    },
    {
        "school": "North Farmington High School",
        "district": "Farmington Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005045",
    },
    {
        "school": "Power Middle School",
        "district": "Farmington Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005051",
    },
    {
        "school": "Forest Elementary School",
        "district": "Farmington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005052",
    },
    {
        "school": "Wood Creek Elementary School",
        "district": "Farmington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005053",
    },
    {
        "school": "Warner Middle School",
        "district": "Farmington Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407005055",
    },
    {
        "school": "Hillside Elementary School",
        "district": "Farmington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407007669",
    },
    {
        "school": "Ferndale Middle School",
        "district": "Ferndale Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261428001282",
    },
    {
        "school": "Ferndale High School",
        "district": "Ferndale Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261428005072",
    },
    {
        "school": "Ferndale Upper Elementary Campus",
        "district": "Ferndale Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261428005075",
    },
    {
        "school": "Ferndale Lower Elementary Campus",
        "district": "Ferndale Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261428005076",
    },
    {
        "school": "Advantage Alternative Program",
        "district": "Hazel Park School District of the City of",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261803000962",
    },
    {
        "school": "Hazel Park High School",
        "district": "Hazel Park School District of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261803005475",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Hazel Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261803005477",
    },
    {
        "school": "Jardon Vocational School",
        "district": "Hazel Park School District of the City of",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261803005480",
    },
    {
        "school": "Edison",
        "district": "Hazel Park School District of the City of",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261803005482",
    },
    {
        "school": "United Oaks Elementary School",
        "district": "Hazel Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261803005483",
    },
    {
        "school": "Rose Pioneer Elementary School",
        "district": "Holly Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261845000966",
    },
    {
        "school": "Karl Richter Campus",
        "district": "Holly Area School District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261845001161",
    },
    {
        "school": "Davisburg Elementary School",
        "district": "Holly Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261845005521",
    },
    {
        "school": "Holly High School",
        "district": "Holly Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261845005522",
    },
    {
        "school": "Holly Elementary School",
        "district": "Holly Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261845005523",
    },
    {
        "school": "Patterson Elementary School",
        "district": "Holly Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261845005524",
    },
    {
        "school": "Holly Middle School",
        "district": "Holly Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261845005525",
    },
    {
        "school": "Country Oaks Elementary School",
        "district": "Huron Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899000101",
    },
    {
        "school": "Oak Valley Middle School",
        "district": "Huron Valley Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899000238",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Huron Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899001079",
    },
    {
        "school": "Harbor High School",
        "district": "Huron Valley Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261899001398",
    },
    {
        "school": "Milford High School",
        "district": "Huron Valley Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899005574",
    },
    {
        "school": "Johnson Elementary School",
        "district": "Huron Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899005575",
    },
    {
        "school": "Muir Middle School",
        "district": "Huron Valley Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899005576",
    },
    {
        "school": "Oxbow Elementary School",
        "district": "Huron Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899005578",
    },
    {
        "school": "Kurtz Elementary School",
        "district": "Huron Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899005580",
    },
    {
        "school": "Highland Elementary School",
        "district": "Huron Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899005581",
    },
    {
        "school": "Lakewood Elementary School",
        "district": "Huron Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899005582",
    },
    {
        "school": "Spring Mills Elementary School",
        "district": "Huron Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899005583",
    },
    {
        "school": "Lakeland High School",
        "district": "Huron Valley Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899005584",
    },
    {
        "school": "White Lake Middle School",
        "district": "Huron Valley Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261899005585",
    },
    {
        "school": "Carpenter Elem School",
        "district": "Lake Orion Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262073000684",
    },
    {
        "school": "Orion Oaks Elementary School",
        "district": "Lake Orion Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262073001080",
    },
    {
        "school": "Paint Creek Elementary School",
        "district": "Lake Orion Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262073001244",
    },
    {
        "school": "Oakview Middle School",
        "district": "Lake Orion Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262073001283",
    },
    {
        "school": "Blanche Sims Elementary School",
        "district": "Lake Orion Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262073005735",
    },
    {
        "school": "Scripps Middle School",
        "district": "Lake Orion Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262073005738",
    },
    {
        "school": "Lake Orion Community High School",
        "district": "Lake Orion Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262073005739",
    },
    {
        "school": "Webber School",
        "district": "Lake Orion Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262073005740",
    },
    {
        "school": "Stadium Drive Elementary School",
        "district": "Lake Orion Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262073005742",
    },
    {
        "school": "Waldon Middle School",
        "district": "Lake Orion Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262073005743",
    },
    {
        "school": "Edmonson Elementary School",
        "district": "Lamphere Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262112005778",
    },
    {
        "school": "Hiller Elementary School",
        "district": "Lamphere Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262112005779",
    },
    {
        "school": "Page Middle School",
        "district": "Lamphere Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262112005780",
    },
    {
        "school": "Lamphere High School",
        "district": "Lamphere Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262112005781",
    },
    {
        "school": "Lessenger Elementary School",
        "district": "Lamphere Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262112005782",
    },
    {
        "school": "Simonds Elementary School",
        "district": "Lamphere Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262112005784",
    },
    {
        "school": "Lamphere Center",
        "district": "Lamphere Public Schools",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262112007673",
    },
    {
        "school": "Madison Preparatory High School",
        "district": "Madison District Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262229001280",
    },
    {
        "school": "Madison High School",
        "district": "Madison District Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262229005943",
    },
    {
        "school": "Wilkinson Middle School",
        "district": "Madison District Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262229005945",
    },
    {
        "school": "Thornton Creek Elementary School",
        "district": "Northville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262598000294",
    },
    {
        "school": "Hillside Middle School",
        "district": "Northville Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262598001266",
    },
    {
        "school": "Amerman Elementary School",
        "district": "Northville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262598006244",
    },
    {
        "school": "Cooke School",
        "district": "Northville Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262598007714",
    },
    {
        "school": "Deerfield Elementary School",
        "district": "Novi Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262613001243",
    },
    {
        "school": "Novi Woods Elementary School",
        "district": "Novi Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262613006261",
    },
    {
        "school": "Orchard Hills Elementary School",
        "district": "Novi Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262613006262",
    },
    {
        "school": "Novi High School",
        "district": "Novi Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262613006263",
    },
    {
        "school": "Novi Middle School",
        "district": "Novi Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262613006264",
    },
    {
        "school": "Village Oaks Elementary School",
        "district": "Novi Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262613006265",
    },
    {
        "school": "Novi Meadows School",
        "district": "Novi Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262613006266",
    },
    {
        "school": "Parkview Elementary School",
        "district": "Novi Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262613007562",
    },
    {
        "school": "Key Elementary School",
        "district": "Oak Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262619000240",
    },
    {
        "school": "Einstein Elementary School",
        "district": "Oak Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262619006267",
    },
    {
        "school": "Oak Park Preparatory Academy",
        "district": "Oak Park School District of the City of",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262619006268",
    },
    {
        "school": "Oak Park High School",
        "district": "Oak Park School District of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262619006271",
    },
    {
        "school": "Pepper Elementary School",
        "district": "Oak Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262619006272",
    },
    {
        "school": "Oxford Elementary School",
        "district": "Oxford Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262724000232",
    },
    {
        "school": "Lakeville Elementary School",
        "district": "Oxford Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262724001159",
    },
    {
        "school": "Clear Lake Elementary School",
        "district": "Oxford Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262724006335",
    },
    {
        "school": "Daniel Axford Elementary School",
        "district": "Oxford Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262724006336",
    },
    {
        "school": "Leonard Elementary School",
        "district": "Oxford Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262724006337",
    },
    {
        "school": "Oxford High School",
        "district": "Oxford Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262724006338",
    },
    {
        "school": "Oxford Middle School",
        "district": "Oxford Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262724006340",
    },
    {
        "school": "Whitman Elementary School",
        "district": "Pontiac City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262874000662",
    },
    {
        "school": "Kennedy Center",
        "district": "Pontiac City School District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262874001156",
    },
    {
        "school": "Alcott School",
        "district": "Pontiac City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262874006426",
    },
    {
        "school": "Herrington School",
        "district": "Pontiac City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262874006434",
    },
    {
        "school": "Pontiac Middle School",
        "district": "Pontiac City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262874006435",
    },
    {
        "school": "Pontiac High School",
        "district": "Pontiac City School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262874006444",
    },
    {
        "school": "Owen Elementary School",
        "district": "Pontiac City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262874006445",
    },
    {
        "school": "Rogers School",
        "district": "Pontiac City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262874006452",
    },
    {
        "school": "Hamlin Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994000241",
    },
    {
        "school": "Hart Middle School",
        "district": "Rochester Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994000242",
    },
    {
        "school": "Hampton Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994000243",
    },
    {
        "school": "Delta Kelly Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994001285",
    },
    {
        "school": "Stoney Creek High School",
        "district": "Rochester Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994001286",
    },
    {
        "school": "Baldwin Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006567",
    },
    {
        "school": "Brooklands Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006568",
    },
    {
        "school": "Brewster Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006569",
    },
    {
        "school": "McGregor Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006570",
    },
    {
        "school": "Meadow Brook Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006571",
    },
    {
        "school": "North Hill Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006572",
    },
    {
        "school": "Rochester High School",
        "district": "Rochester Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006573",
    },
    {
        "school": "West Middle School",
        "district": "Rochester Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006574",
    },
    {
        "school": "Long Meadow Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006575",
    },
    {
        "school": "Rochester Adams High School",
        "district": "Rochester Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006577",
    },
    {
        "school": "University Hills Elem School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006578",
    },
    {
        "school": "Reuther Middle School",
        "district": "Rochester Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006579",
    },
    {
        "school": "Van Hoosen Middle School",
        "district": "Rochester Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006580",
    },
    {
        "school": "John M Schultz Educational Campus",
        "district": "Rochester Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994006581",
    },
    {
        "school": "Hugger Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994007575",
    },
    {
        "school": "Musson Elementary School",
        "district": "Rochester Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262994007576",
    },
    {
        "school": "HamiltonParsons Elementary School",
        "district": "Romeo Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263009006602",
    },
    {
        "school": "Royal Oak High School",
        "district": "Royal Oak Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263030006637",
    },
    {
        "school": "Northwood Elementary School",
        "district": "Royal Oak Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263030006642",
    },
    {
        "school": "Oak Ridge Elementary School",
        "district": "Royal Oak Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263030006643",
    },
    {
        "school": "Oakland Elementary School",
        "district": "Royal Oak Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263030006644",
    },
    {
        "school": "Alfred E Upton Elementary School",
        "district": "Royal Oak Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263030006647",
    },
    {
        "school": "Kent Lake Elementary School",
        "district": "South Lyon Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225001401",
    },
    {
        "school": "Ann L Dolsen Elementary School",
        "district": "South Lyon Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225006752",
    },
    {
        "school": "Sayre Elementary School",
        "district": "South Lyon Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225006754",
    },
    {
        "school": "South Lyon High School",
        "district": "South Lyon Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225006755",
    },
    {
        "school": "Frank E Bartlett School",
        "district": "South Lyon Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225006756",
    },
    {
        "school": "Millennium  Middle School",
        "district": "South Lyon Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225007671",
    },
    {
        "school": "Southfield Regional Academic Campus",
        "district": "Southfield Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263231000666",
    },
    {
        "school": "Adlai Stevenson Elementary School",
        "district": "Southfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263231006771",
    },
    {
        "school": "Glenn W Levey Middle School",
        "district": "Southfield Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263231006775",
    },
    {
        "school": "MacArthur K8 University Academy",
        "district": "Southfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263231006778",
    },
    {
        "school": "Vandenberg Elementary School",
        "district": "Southfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263231006782",
    },
    {
        "school": "Morris Adler Elementary School",
        "district": "Southfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263231006784",
    },
    {
        "school": "McIntyre Elementary School",
        "district": "Southfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263231006786",
    },
    {
        "school": "Troy College and Career High School",
        "district": "Troy School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263426000675",
    },
    {
        "school": "Baker Middle School",
        "district": "Troy School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006962",
    },
    {
        "school": "Leonard Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006963",
    },
    {
        "school": "Morse Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006964",
    },
    {
        "school": "Hamilton Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006965",
    },
    {
        "school": "Troy High School",
        "district": "Troy School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006966",
    },
    {
        "school": "Troy Union Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006967",
    },
    {
        "school": "Hill Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006968",
    },
    {
        "school": "Smith Middle School",
        "district": "Troy School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006969",
    },
    {
        "school": "Wattles Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006970",
    },
    {
        "school": "Schroeder Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006971",
    },
    {
        "school": "Costello Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006972",
    },
    {
        "school": "Martell Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006973",
    },
    {
        "school": "Larson Middle School",
        "district": "Troy School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006974",
    },
    {
        "school": "Boulan Park Middle School",
        "district": "Troy School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006975",
    },
    {
        "school": "Athens High School",
        "district": "Troy School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006976",
    },
    {
        "school": "Wass Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006977",
    },
    {
        "school": "Bemis Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006978",
    },
    {
        "school": "Barnard Elementary School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263426006979",
    },
    {
        "school": "Walled Lake Schools Special Services",
        "district": "Walled Lake Consolidated Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263516000968",
    },
    {
        "school": "Meadowbrook Elementary School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516000969",
    },
    {
        "school": "Walnut Creek Middle School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516001081",
    },
    {
        "school": "Sarah G Banks Middle School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516001082",
    },
    {
        "school": "Walled Lake Northern High School",
        "district": "Walled Lake Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516001289",
    },
    {
        "school": "Clifford H Smart Middle School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007072",
    },
    {
        "school": "Commerce Elementary School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007073",
    },
    {
        "school": "Mary Helen Guest Elementary School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007074",
    },
    {
        "school": "Dublin Elementary",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007075",
    },
    {
        "school": "Glengary Elementary School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007076",
    },
    {
        "school": "Keith Elementary School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007077",
    },
    {
        "school": "Oakley Park Elementary School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007078",
    },
    {
        "school": "James R Geisler Middle School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007080",
    },
    {
        "school": "Walled Lake Central High School",
        "district": "Walled Lake Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007081",
    },
    {
        "school": "Walled Lake Elementary School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007082",
    },
    {
        "school": "Wixom Elementary School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007083",
    },
    {
        "school": "Walled Lake Western High School",
        "district": "Walled Lake Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007084",
    },
    {
        "school": "Loon Lake Elementary School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007085",
    },
    {
        "school": "Hickory Woods Elementary School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007674",
    },
    {
        "school": "Pleasant Lake Elementary School",
        "district": "Walled Lake Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263516007675",
    },
    {
        "school": "Susick Elementary School",
        "district": "Warren Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519007101",
    },
    {
        "school": "Donelson Hills Elementary School",
        "district": "Waterford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007127",
    },
    {
        "school": "Houghton Elementary School",
        "district": "Waterford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007128",
    },
    {
        "school": "Pierce Middle School",
        "district": "Waterford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007135",
    },
    {
        "school": "Haviland Elementary School",
        "district": "Waterford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007136",
    },
    {
        "school": "Childrens Village School",
        "district": "Waterford School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007137",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Waterford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007138",
    },
    {
        "school": "Schoolcraft Elementary School",
        "district": "Waterford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007139",
    },
    {
        "school": "Mason Middle School",
        "district": "Waterford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007140",
    },
    {
        "school": "Kingsley Montgomery School",
        "district": "Waterford School District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263531007141",
    },
    {
        "school": "Cooley Elementary School",
        "district": "Waterford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007142",
    },
    {
        "school": "Waterford Kettering High School",
        "district": "Waterford School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007143",
    },
    {
        "school": "Beaumont Elementary School",
        "district": "Waterford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007146",
    },
    {
        "school": "Knudsen Elementary School",
        "district": "Waterford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007149",
    },
    {
        "school": "Waterford Mott High School",
        "district": "Waterford School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531007150",
    },
    {
        "school": "Gretchko Elementary School",
        "district": "West Bloomfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263582000676",
    },
    {
        "school": "Sheiko Elementary School",
        "district": "West Bloomfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263582007176",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "West Bloomfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263582007177",
    },
    {
        "school": "Orchard Lake Middle School",
        "district": "West Bloomfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263582007179",
    },
    {
        "school": "Doherty Elementary School",
        "district": "West Bloomfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263582007180",
    },
    {
        "school": "West Bloomfield High School",
        "district": "West Bloomfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263582007181",
    },
    {
        "school": "Abbott Middle School",
        "district": "West Bloomfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263582007182",
    },
    {
        "school": "Scotch Elementary School",
        "district": "West Bloomfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263582007586",
    },
    {
        "school": "Oakland Schools Technical CampusSE",
        "district": "Oakland Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268088001154",
    },
    {
        "school": "Oakland Schools Technical CampusNE",
        "district": "Oakland Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268088001240",
    },
    {
        "school": "Oakland Schools Technical CampusNW",
        "district": "Oakland Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268088001241",
    },
    {
        "school": "Oakland Schools Technical CampusSW",
        "district": "Oakland Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268088001242",
    },
    {
        "school": "Landmark Academy",
        "district": "Landmark Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260022001176",
    },
    {
        "school": "Algonac JuniorSenior High School",
        "district": "Algonac Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260219003960",
    },
    {
        "school": "Francois Maconce Elem School",
        "district": "Anchor Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260279001069",
    },
    {
        "school": "Anchor Bay High School",
        "district": "Anchor Bay School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260279003997",
    },
    {
        "school": "Capac Elementary School",
        "district": "Capac Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260780004357",
    },
    {
        "school": "Capac High School",
        "district": "Capac Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260780004358",
    },
    {
        "school": "Riverview East High School",
        "district": "East China School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261242001412",
    },
    {
        "school": "Pine River Elementary School",
        "district": "East China School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261242004937",
    },
    {
        "school": "Belle River Elementary School",
        "district": "East China School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261242004938",
    },
    {
        "school": "Gearing Elementary School",
        "district": "East China School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261242004939",
    },
    {
        "school": "Marine City Middle School",
        "district": "East China School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261242004940",
    },
    {
        "school": "Marine City High School",
        "district": "East China School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261242004941",
    },
    {
        "school": "Palms Elementary School",
        "district": "East China School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261242004942",
    },
    {
        "school": "St Clair High School",
        "district": "East China School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261242004943",
    },
    {
        "school": "St Clair Middle School",
        "district": "East China School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261242004944",
    },
    {
        "school": "Morton Elementary School",
        "district": "Marysville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262304000719",
    },
    {
        "school": "Marysville Middle School",
        "district": "Marysville Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262304005988",
    },
    {
        "school": "Marysville High School",
        "district": "Marysville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262304005989",
    },
    {
        "school": "Washington Elementary School",
        "district": "Marysville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262304005990",
    },
    {
        "school": "Gardens Elementary School",
        "district": "Marysville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262304005991",
    },
    {
        "school": "Memphis Elementary School",
        "district": "Memphis Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262349006026",
    },
    {
        "school": "Literacy Academy at Cleveland Elementary",
        "district": "Port Huron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006462",
    },
    {
        "school": "Fort Gratiot Middle School",
        "district": "Port Huron Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006463",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Port Huron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006464",
    },
    {
        "school": "H D Crull Elementary School",
        "district": "Port Huron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006467",
    },
    {
        "school": "Keewahdin Elementary School",
        "district": "Port Huron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006468",
    },
    {
        "school": "Michigamme Elementary School",
        "district": "Port Huron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006471",
    },
    {
        "school": "Port Huron Northern High School",
        "district": "Port Huron Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006473",
    },
    {
        "school": "Central Middle School",
        "district": "Port Huron Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006474",
    },
    {
        "school": "Port Huron High School",
        "district": "Port Huron Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006475",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Port Huron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006476",
    },
    {
        "school": "Edison Elementary School",
        "district": "Port Huron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006478",
    },
    {
        "school": "Holland Woods Middle School",
        "district": "Port Huron Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006479",
    },
    {
        "school": "STEAM Academy at Woodrow Wilson Elementary",
        "district": "Port Huron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006480",
    },
    {
        "school": "Indian Woods Elementary School",
        "district": "Port Huron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262883006481",
    },
    {
        "school": "Phoenix Alternative School",
        "district": "Yale Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263660000045",
    },
    {
        "school": "Avoca Elementary School",
        "district": "Yale Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263660007272",
    },
    {
        "school": "John F FarrellEmmett Elementary School",
        "district": "Yale Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263660007273",
    },
    {
        "school": "Yale Elementary School",
        "district": "Yale Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263660007274",
    },
    {
        "school": "Yale Senior High School",
        "district": "Yale Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263660007275",
    },
    {
        "school": "Yale Junior High School",
        "district": "Yale Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263660007276",
    },
    {
        "school": "Woodland Developmental Center",
        "district": "St. Clair County RESA",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268094000264",
    },
    {
        "school": "Technical Education Center",
        "district": "St. Clair County RESA",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268094000717",
    },
    {
        "school": "Salem Elementary School",
        "district": "South Lyon Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225006753",
    },
    {
        "school": "Rawsonville Elementary School",
        "district": "Van Buren Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263456007034",
    },
    {
        "school": "Tinkham Alternative Education",
        "district": "Wayne-Westland Community School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260001500767",
    },
    {
        "school": "Adams Upper Elementary School",
        "district": "Wayne-Westland Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503879",
    },
    {
        "school": "Albert Schweitzer Elementary School",
        "district": "Wayne-Westland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503880",
    },
    {
        "school": "Alexander Hamilton Elementary School",
        "district": "Wayne-Westland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503881",
    },
    {
        "school": "Benjamin Franklin Middle School",
        "district": "Wayne-Westland Community School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503882",
    },
    {
        "school": "David Hicks School",
        "district": "Wayne-Westland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503885",
    },
    {
        "school": "Eugene B Elliott Elem School",
        "district": "Wayne-Westland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503886",
    },
    {
        "school": "John Glenn High School",
        "district": "Wayne-Westland Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503890",
    },
    {
        "school": "John Marshall Upper Elementary School",
        "district": "Wayne-Westland Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503891",
    },
    {
        "school": "RooseveltMcGrath Elem School",
        "district": "Wayne-Westland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503896",
    },
    {
        "school": "TaftGalloway Elementary School",
        "district": "Wayne-Westland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503899",
    },
    {
        "school": "Thomas A Edison Elem School",
        "district": "Wayne-Westland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503900",
    },
    {
        "school": "WalkerWinter Elementary School",
        "district": "Wayne-Westland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503902",
    },
    {
        "school": "Wayne Memorial High School",
        "district": "Wayne-Westland Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503903",
    },
    {
        "school": "Adlai Stevenson Middle School",
        "district": "Wayne-Westland Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503905",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Wayne-Westland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503906",
    },
    {
        "school": "Wildwood Elementary School",
        "district": "Wayne-Westland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503907",
    },
    {
        "school": "PD Graham Elementary School",
        "district": "Wayne-Westland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001503908",
    },
    {
        "school": "Crestwood High School",
        "district": "Crestwood School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001603912",
    },
    {
        "school": "Hillcrest Elementary School",
        "district": "Crestwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001603913",
    },
    {
        "school": "Kinloch Elementary School",
        "district": "Crestwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001603914",
    },
    {
        "school": "Riverside Middle School",
        "district": "Crestwood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001603915",
    },
    {
        "school": "Highview Elementary School",
        "district": "Crestwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001607444",
    },
    {
        "school": "Plymouth Educational Center",
        "district": "Plymouth Educational Center Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260012500775",
    },
    {
        "school": "Martin Luther King Jr Education Center Academy",
        "district": "Martin Luther King Jr. Education Center Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260013100781",
    },
    {
        "school": "Eaton Academy",
        "district": "Eaton Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260013600786",
    },
    {
        "school": "Summit Academy",
        "district": "Summit Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260013700787",
    },
    {
        "school": "Cesar Chavez Academy Elementary",
        "district": "Cesar Chavez Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260013900789",
    },
    {
        "school": "Cesar Chavez Middle School",
        "district": "Cesar Chavez Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260013901033",
    },
    {
        "school": "Commonwealth Community Development Academy",
        "district": "Commonwealth Community Development Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260014001192",
    },
    {
        "school": "Academy for Business and Technology High School",
        "district": "Academy for Business and Technology",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260016601035",
    },
    {
        "school": "Chandler Park Academy  Middle School",
        "district": "Chandler Park Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260016801037",
    },
    {
        "school": "Detroit Community Schools  High School",
        "district": "Detroit Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260017001039",
    },
    {
        "school": "Henry Ford Academy",
        "district": "Henry Ford Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260017101040",
    },
    {
        "school": "The Dearborn Academy",
        "district": "The Dearborn Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260017301042",
    },
    {
        "school": "Detroit Academy of Arts and Sciences",
        "district": "Detroit Academy of Arts and Sciences",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260017401043",
    },
    {
        "school": "Detroit Academy of Arts and Sciences Middle School",
        "district": "Detroit Academy of Arts and Sciences",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260017401442",
    },
    {
        "school": "Dove Academy of Detroit",
        "district": "Dove Academy of Detroit",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260017501044",
    },
    {
        "school": "Barack Obama Leadership Academy",
        "district": "Barack Obama Leadership Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260017801047",
    },
    {
        "school": "George Crockett Academy",
        "district": "George Crockett Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260022401194",
    },
    {
        "school": "Summit Academy North High School",
        "district": "Summit Academy North",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260022501195",
    },
    {
        "school": "Summit Academy North Middle School",
        "district": "Summit Academy North",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260022501443",
    },
    {
        "school": "Summit Academy North Elementary School",
        "district": "Summit Academy North",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260022501444",
    },
    {
        "school": "Voyageur Academy",
        "district": "Voyageur Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260022701197",
    },
    {
        "school": "Star International Academy",
        "district": "Star International Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260022801198",
    },
    {
        "school": "Hope Academy",
        "district": "Hope Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260022901199",
    },
    {
        "school": "Weston Preparatory Academy",
        "district": "Weston Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260023001200",
    },
    {
        "school": "Detroit Edison Public School Academy",
        "district": "Detroit Edison Public School Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260023201202",
    },
    {
        "school": "David Ellis Academy",
        "district": "David Ellis Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260023401204",
    },
    {
        "school": "Universal Academy",
        "district": "Universal Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260023701207",
    },
    {
        "school": "Detroit Service Learning Academy Campus",
        "district": "Detroit Service Learning Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260023901209",
    },
    {
        "school": "Old Redford Academy  Elementary",
        "district": "Old Redford Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260024201212",
    },
    {
        "school": "Hope of Detroit Academy  Elementary",
        "district": "Hope of Detroit Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260024301213",
    },
    {
        "school": "West Village Academy",
        "district": "West Village Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260024501215",
    },
    {
        "school": "Metro Charter Academy",
        "district": "Metro Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260026201272",
    },
    {
        "school": "Canton Charter Academy",
        "district": "Canton Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260026301273",
    },
    {
        "school": "Creative Montessori Academy",
        "district": "Creative Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260027001445",
    },
    {
        "school": "Warrendale Charter Academy",
        "district": "Warrendale Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260027101446",
    },
    {
        "school": "Bennie Elementary School",
        "district": "Allen Park Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260252000005",
    },
    {
        "school": "Allen Park Community School",
        "district": "Allen Park Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260252001018",
    },
    {
        "school": "Allen Park High School",
        "district": "Allen Park Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260252003971",
    },
    {
        "school": "Arno Elementary School",
        "district": "Allen Park Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260252003972",
    },
    {
        "school": "Lindemann Elementary School",
        "district": "Allen Park Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260252003973",
    },
    {
        "school": "Allen Park Middle School",
        "district": "Allen Park Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260252003974",
    },
    {
        "school": "Ethel C Bobcean Elem School",
        "district": "Flat Rock Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260708004304",
    },
    {
        "school": "Flat Rock Community High School",
        "district": "Flat Rock Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260708004305",
    },
    {
        "school": "Thomas Simpson Middle School",
        "district": "Flat Rock Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260708004306",
    },
    {
        "school": "John M Barnes Elem School",
        "district": "Flat Rock Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260708004307",
    },
    {
        "school": "Botsford Elementary School",
        "district": "Clarenceville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260984004467",
    },
    {
        "school": "Clarenceville Middle School",
        "district": "Clarenceville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260984004468",
    },
    {
        "school": "Clarenceville High School",
        "district": "Clarenceville School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260984004469",
    },
    {
        "school": "Grandview Elementary School",
        "district": "Clarenceville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260984004470",
    },
    {
        "school": "Iris Becker Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160000104",
    },
    {
        "school": "Woodworth Middle School",
        "district": "Dearborn City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160000290",
    },
    {
        "school": "Lowrey Middle School",
        "district": "Dearborn City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160000291",
    },
    {
        "school": "Miller Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160000756",
    },
    {
        "school": "Bryant Middle School",
        "district": "Dearborn City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004585",
    },
    {
        "school": "Charles A Lindbergh Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004586",
    },
    {
        "school": "Dearborn High School",
        "district": "Dearborn City School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004587",
    },
    {
        "school": "Snow Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004588",
    },
    {
        "school": "Duvall Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004589",
    },
    {
        "school": "Edsel Ford High School",
        "district": "Dearborn City School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004590",
    },
    {
        "school": "Fordson High School",
        "district": "Dearborn City School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004591",
    },
    {
        "school": "Henry Ford Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004592",
    },
    {
        "school": "Haigh Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004593",
    },
    {
        "school": "Howard Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004594",
    },
    {
        "school": "Maples Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004595",
    },
    {
        "school": "McDonald Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004596",
    },
    {
        "school": "Smith Middle School",
        "district": "Dearborn City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004597",
    },
    {
        "school": "Oakman Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004598",
    },
    {
        "school": "River Oaks Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004599",
    },
    {
        "school": "Salina Intermediate 4  8",
        "district": "Dearborn City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004600",
    },
    {
        "school": "Stout Middle School",
        "district": "Dearborn City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004601",
    },
    {
        "school": "WhitmoreBolles Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004602",
    },
    {
        "school": "William Ford Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004603",
    },
    {
        "school": "Nowlin Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004604",
    },
    {
        "school": "Lowrey Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004606",
    },
    {
        "school": "Long Elementary School",
        "district": "Dearborn City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004607",
    },
    {
        "school": "Howe Trainable Center and Montessori",
        "district": "Dearborn City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160004612",
    },
    {
        "school": "Bedford School",
        "district": "Dearborn Heights School District #7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261161004615",
    },
    {
        "school": "Oakley W Best Middle School",
        "district": "Dearborn Heights School District #7",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261161004616",
    },
    {
        "school": "Pardee School",
        "district": "Dearborn Heights School District #7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261161004617",
    },
    {
        "school": "Annapolis High School",
        "district": "Dearborn Heights School District #7",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261161004618",
    },
    {
        "school": "Polk Elementary School",
        "district": "Dearborn Heights School District #7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261161004619",
    },
    {
        "school": "Daly School",
        "district": "Westwood Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261164004620",
    },
    {
        "school": "Robichaud Senior High School",
        "district": "Westwood Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261164004621",
    },
    {
        "school": "Thorne Elementary School",
        "district": "Westwood Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261164004623",
    },
    {
        "school": "Ecorse Community High School",
        "district": "Ecorse Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261293004988",
    },
    {
        "school": "Ralph J Bunche Academy",
        "district": "Ecorse Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261293004990",
    },
    {
        "school": "GrandPort Elementary Academy",
        "district": "Ecorse Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261293004991",
    },
    {
        "school": "Garden City High School",
        "district": "Garden City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261554005213",
    },
    {
        "school": "Garden City Middle School",
        "district": "Garden City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261554005217",
    },
    {
        "school": "Burger Development Center",
        "district": "Garden City Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261554005219",
    },
    {
        "school": "Frank E Weiss Elem School",
        "district": "Gibraltar School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261587001435",
    },
    {
        "school": "Oscar A Carlson High School",
        "district": "Gibraltar School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261587005236",
    },
    {
        "school": "Chapman Elementary School",
        "district": "Gibraltar School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261587005237",
    },
    {
        "school": "Parsons Elementary School",
        "district": "Gibraltar School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261587005238",
    },
    {
        "school": "Hunter Elementary School",
        "district": "Gibraltar School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261587005239",
    },
    {
        "school": "Shumate Middle School",
        "district": "Gibraltar School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261587005241",
    },
    {
        "school": "Grosse Ile Middle School",
        "district": "Grosse Ile Township Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261722005400",
    },
    {
        "school": "Grosse Ile High School",
        "district": "Grosse Ile Township Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261722005401",
    },
    {
        "school": "Parke Lane Elementary School",
        "district": "Grosse Ile Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261722005402",
    },
    {
        "school": "Meridian Elementary School",
        "district": "Grosse Ile Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261722005403",
    },
    {
        "school": "Early Childhood Elementary School",
        "district": "Hamtramck School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261752001430",
    },
    {
        "school": "Dickinson West Elementary School",
        "district": "Hamtramck School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261752005420",
    },
    {
        "school": "Hamtramck High School",
        "district": "Hamtramck School District of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261752005421",
    },
    {
        "school": "Holbrook School",
        "district": "Hamtramck School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261752005422",
    },
    {
        "school": "Kosciuszko School",
        "district": "Hamtramck School District of the City of",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261752005423",
    },
    {
        "school": "Dickinson East Elementary School",
        "district": "Hamtramck School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261752007713",
    },
    {
        "school": "Beacon Elementary School",
        "district": "Harper Woods The School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261776005440",
    },
    {
        "school": "Harper Woods High School",
        "district": "Harper Woods The School District of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261776005441",
    },
    {
        "school": "Tyrone Elementary School",
        "district": "Harper Woods The School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261776005442",
    },
    {
        "school": "Huron High School",
        "district": "Huron School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261893005567",
    },
    {
        "school": "Brown Elementary School",
        "district": "Huron School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261893005568",
    },
    {
        "school": "Carl T Renton Jr High School",
        "district": "Huron School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261893005569",
    },
    {
        "school": "William D Miller Elem School",
        "district": "Huron School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261893005570",
    },
    {
        "school": "Lincoln Park Middle School",
        "district": "Lincoln Park School District of the City of",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262160001186",
    },
    {
        "school": "Earl F Carr School",
        "district": "Lincoln Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262160005858",
    },
    {
        "school": "Hoover School",
        "district": "Lincoln Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262160005860",
    },
    {
        "school": "James Foote School",
        "district": "Lincoln Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262160005862",
    },
    {
        "school": "Keppen School",
        "district": "Lincoln Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262160005863",
    },
    {
        "school": "Lafayette School",
        "district": "Lincoln Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262160005864",
    },
    {
        "school": "Lincoln Park High School",
        "district": "Lincoln Park School District of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262160005866",
    },
    {
        "school": "Max Paun School",
        "district": "Lincoln Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262160005867",
    },
    {
        "school": "Raupp School",
        "district": "Lincoln Park School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262160005868",
    },
    {
        "school": "Jackson Center",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184000762",
    },
    {
        "school": "NW Wayne Trainable Center",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262184000763",
    },
    {
        "school": "Livonia Career Technical Center",
        "district": "Livonia Public Schools School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "262184000764",
    },
    {
        "school": "Stevenson High School",
        "district": "Livonia Public Schools School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005877",
    },
    {
        "school": "Cleveland Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005878",
    },
    {
        "school": "Coolidge Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005879",
    },
    {
        "school": "Cooper Upper Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005880",
    },
    {
        "school": "Emerson Middle School",
        "district": "Livonia Public Schools School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005881",
    },
    {
        "school": "Franklin High School",
        "district": "Livonia Public Schools School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005882",
    },
    {
        "school": "Grant Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005884",
    },
    {
        "school": "Hayes Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005885",
    },
    {
        "school": "Holmes Middle School",
        "district": "Livonia Public Schools School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005886",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005887",
    },
    {
        "school": "Kennedy Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005889",
    },
    {
        "school": "Johnson Upper Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005890",
    },
    {
        "school": "Randolph Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005896",
    },
    {
        "school": "Riley Upper Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005897",
    },
    {
        "school": "Frost Middle School",
        "district": "Livonia Public Schools School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005898",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005899",
    },
    {
        "school": "Churchill High School",
        "district": "Livonia Public Schools School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005903",
    },
    {
        "school": "Buchanan Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184005905",
    },
    {
        "school": "Webster Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184007549",
    },
    {
        "school": "Julian O Strong Middle School",
        "district": "Melvindale-North Allen Park Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262346006020",
    },
    {
        "school": "Melvindale High School",
        "district": "Melvindale-North Allen Park Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262346006021",
    },
    {
        "school": "Rogers Early Elementary School",
        "district": "Melvindale-North Allen Park Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262346007556",
    },
    {
        "school": "Brownell Middle School",
        "district": "Grosse Pointe Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006217",
    },
    {
        "school": "Ferry Elementary School",
        "district": "Grosse Pointe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006218",
    },
    {
        "school": "George Defer Elementary School",
        "district": "Grosse Pointe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006219",
    },
    {
        "school": "Grosse Pointe South High School",
        "district": "Grosse Pointe Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006220",
    },
    {
        "school": "Kerby Elementary School",
        "district": "Grosse Pointe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006221",
    },
    {
        "school": "Lewis Maire Elementary School",
        "district": "Grosse Pointe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006222",
    },
    {
        "school": "Stevens T Mason Elementary School",
        "district": "Grosse Pointe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006223",
    },
    {
        "school": "John Monteith Elementary School",
        "district": "Grosse Pointe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006224",
    },
    {
        "school": "Parcells Middle School",
        "district": "Grosse Pointe Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006225",
    },
    {
        "school": "Richard Elementary School",
        "district": "Grosse Pointe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006226",
    },
    {
        "school": "Pierce Middle School",
        "district": "Grosse Pointe Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006227",
    },
    {
        "school": "Robert Trombly Elementary School",
        "district": "Grosse Pointe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006228",
    },
    {
        "school": "Charles A Poupard Elem School",
        "district": "Grosse Pointe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006229",
    },
    {
        "school": "Grosse Pointe North High School",
        "district": "Grosse Pointe Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262574006230",
    },
    {
        "school": "Northville High School",
        "district": "Northville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262598006245",
    },
    {
        "school": "Meads Mill Middle School",
        "district": "Northville Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262598006248",
    },
    {
        "school": "Silver Springs Elementary School",
        "district": "Northville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262598006249",
    },
    {
        "school": "Winchester Elementary School",
        "district": "Northville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262598006250",
    },
    {
        "school": "Moraine Elementary School",
        "district": "Northville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262598007560",
    },
    {
        "school": "Bentley Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856000292",
    },
    {
        "school": "Tonda Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856000293",
    },
    {
        "school": "Discovery Middle School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856000765",
    },
    {
        "school": "Dodson Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856001431",
    },
    {
        "school": "Plymouth High School",
        "district": "Plymouth-Canton Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856001464",
    },
    {
        "school": "Bird Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006406",
    },
    {
        "school": "Farrand Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006407",
    },
    {
        "school": "Gallimore Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006408",
    },
    {
        "school": "West Middle School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006410",
    },
    {
        "school": "East Middle School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006411",
    },
    {
        "school": "Smith Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006413",
    },
    {
        "school": "Pioneer Middle School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006415",
    },
    {
        "school": "Isbister Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006416",
    },
    {
        "school": "Salem High School",
        "district": "Plymouth-Canton Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006419",
    },
    {
        "school": "Miller Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006420",
    },
    {
        "school": "Canton High School",
        "district": "Plymouth-Canton Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006421",
    },
    {
        "school": "Eriksson Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006422",
    },
    {
        "school": "Field Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006423",
    },
    {
        "school": "Hulsing Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856006424",
    },
    {
        "school": "Hoben Elementary School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856007568",
    },
    {
        "school": "MacGowan School",
        "district": "Redford Union Schools District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262946006524",
    },
    {
        "school": "Redford Union High School",
        "district": "Redford Union Schools District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262946006525",
    },
    {
        "school": "Hilbert Middle School",
        "district": "Redford Union Schools District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262946006529",
    },
    {
        "school": "Ann Visger K5 Preparatory Academy",
        "district": "River Rouge School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262976006552",
    },
    {
        "school": "River Rouge High School",
        "district": "River Rouge School District of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262976006555",
    },
    {
        "school": "Huntington Elementary School",
        "district": "Riverview Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262991006562",
    },
    {
        "school": "Memorial Elementary School",
        "district": "Riverview Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262991006563",
    },
    {
        "school": "Riverview Community High School",
        "district": "Riverview Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262991006564",
    },
    {
        "school": "Seitz Middle School",
        "district": "Riverview Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262991006565",
    },
    {
        "school": "Forest Elementary School",
        "district": "Riverview Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262991007574",
    },
    {
        "school": "Romulus Elementary School",
        "district": "Romulus Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263012001433",
    },
    {
        "school": "Romulus Senior High School",
        "district": "Romulus Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263012006606",
    },
    {
        "school": "Wick Elementary School",
        "district": "Romulus Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263012006609",
    },
    {
        "school": "Romulus Middle School",
        "district": "Romulus Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263012006610",
    },
    {
        "school": "Barth Elementary School",
        "district": "Romulus Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263012006611",
    },
    {
        "school": "Hale Creek Elementary School",
        "district": "Romulus Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263012006612",
    },
    {
        "school": "Vandenberg Elementary School",
        "district": "South Redford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263228006758",
    },
    {
        "school": "Fisher Elementary School",
        "district": "South Redford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263228006759",
    },
    {
        "school": "Jane Addams Elementary School",
        "district": "South Redford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263228006760",
    },
    {
        "school": "John D Pierce Middle School",
        "district": "South Redford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263228006761",
    },
    {
        "school": "Lee M Thurston High School",
        "district": "South Redford School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263228006762",
    },
    {
        "school": "Thomas Jefferson Elem School",
        "district": "South Redford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263228006763",
    },
    {
        "school": "Allen Elementary School",
        "district": "Southgate Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263234000295",
    },
    {
        "school": "Beacon Day Treatment Center",
        "district": "Southgate Community School District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263234001188",
    },
    {
        "school": "Grogan Elementary School",
        "district": "Southgate Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263234006789",
    },
    {
        "school": "Davidson Middle School",
        "district": "Southgate Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263234006790",
    },
    {
        "school": "Fordline Elementary School",
        "district": "Southgate Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263234006791",
    },
    {
        "school": "Southgate Anderson High School",
        "district": "Southgate Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263234006793",
    },
    {
        "school": "Shelters Elementary School",
        "district": "Southgate Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263234006795",
    },
    {
        "school": "Blair Moody Elementary School",
        "district": "Taylor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263354006889",
    },
    {
        "school": "Clarence Randall Elem School",
        "district": "Taylor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263354006891",
    },
    {
        "school": "Eureka Heights Elementary School",
        "district": "Taylor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263354006892",
    },
    {
        "school": "Holland Elementary School",
        "district": "Taylor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263354006898",
    },
    {
        "school": "Kinyon Elementary School",
        "district": "Taylor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263354006900",
    },
    {
        "school": "Robert J West Middle School",
        "district": "Taylor School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263354006903",
    },
    {
        "school": "Hoover Middle School",
        "district": "Taylor School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263354006904",
    },
    {
        "school": "Taylor Parks Elementary School",
        "district": "Taylor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263354006906",
    },
    {
        "school": "Bernice McDowell Elem School",
        "district": "Taylor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263354006908",
    },
    {
        "school": "Myers Elementary School",
        "district": "Taylor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263354006909",
    },
    {
        "school": "Taylor High School",
        "district": "Taylor School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263354006910",
    },
    {
        "school": "Taylor Career and Technical Center",
        "district": "Taylor School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "263354007581",
    },
    {
        "school": "Jesse L Anderson Elementary School",
        "district": "Trenton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263390006953",
    },
    {
        "school": "Richard C Hedke Elem School",
        "district": "Trenton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263390006954",
    },
    {
        "school": "Trenton High School",
        "district": "Trenton Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263390006956",
    },
    {
        "school": "Boyd W Arthurs Middle School",
        "district": "Trenton Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263390006957",
    },
    {
        "school": "Owen Intermediate School",
        "district": "Van Buren Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263456007029",
    },
    {
        "school": "Belleville High School",
        "district": "Van Buren Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263456007030",
    },
    {
        "school": "Edgemont Elementary School",
        "district": "Van Buren Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263456007031",
    },
    {
        "school": "McBride Middle School",
        "district": "Van Buren Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263456007035",
    },
    {
        "school": "Tyler Road Elementary School",
        "district": "Van Buren Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263456007037",
    },
    {
        "school": "Savage Road Elementary School",
        "district": "Van Buren Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263456007038",
    },
    {
        "school": "Special Education Building",
        "district": "Woodhaven-Brownstown School District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263648500771",
    },
    {
        "school": "Patrick Henry Middle School",
        "district": "Woodhaven-Brownstown School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263648501092",
    },
    {
        "school": "Bates Elementary School",
        "district": "Woodhaven-Brownstown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263648507239",
    },
    {
        "school": "Yake Elementary School",
        "district": "Woodhaven-Brownstown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263648507241",
    },
    {
        "school": "Woodhaven High School",
        "district": "Woodhaven-Brownstown School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263648507242",
    },
    {
        "school": "Gudith Elementary School",
        "district": "Woodhaven-Brownstown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263648507243",
    },
    {
        "school": "Erving Elementary School",
        "district": "Woodhaven-Brownstown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263648507244",
    },
    {
        "school": "Wegienka Elementary School",
        "district": "Woodhaven-Brownstown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263648507246",
    },
    {
        "school": "Brownstown Middle School",
        "district": "Woodhaven-Brownstown School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263648507715",
    },
    {
        "school": "The Lincoln Center",
        "district": "Wyandotte School District of the City of",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263654001265",
    },
    {
        "school": "Jo Brighton Skills Center",
        "district": "Wyandotte School District of the City of",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263654007247",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Wyandotte School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263654007248",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Wyandotte School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263654007249",
    },
    {
        "school": "Monroe Elementary School",
        "district": "Wyandotte School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263654007251",
    },
    {
        "school": "Roosevelt High School",
        "district": "Wyandotte School District of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263654007252",
    },
    {
        "school": "Washington Elementary School",
        "district": "Wyandotte School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263654007254",
    },
    {
        "school": "Woodrow Wilson School",
        "district": "Wyandotte School District of the City of",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263654007255",
    },
    {
        "school": "Madison School",
        "district": "Wyandotte School District of the City of",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263654007256",
    },
    {
        "school": "Cameron Elementary School",
        "district": "Gladstone Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261597001668",
    },
    {
        "school": "James T Jones Elementary School",
        "district": "Gladstone Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261597001669",
    },
    {
        "school": "Big Bay De Noc School",
        "district": "Big Bay De Noc School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260569004202",
    },
    {
        "school": "Escanaba Area Public High School",
        "district": "Escanaba Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261350005014",
    },
    {
        "school": "Escanaba Upper Elementary",
        "district": "Escanaba Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261350005015",
    },
    {
        "school": "Lemmer Elementary School",
        "district": "Escanaba Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261350005017",
    },
    {
        "school": "Soo Hill Elementary School",
        "district": "Escanaba Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261350005018",
    },
    {
        "school": "Webster Elementary School",
        "district": "Escanaba Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261350005020",
    },
    {
        "school": "Gladstone Area Middle School",
        "district": "Gladstone Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261597005244",
    },
    {
        "school": "Gladstone Area High School",
        "district": "Gladstone Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261597005245",
    },
    {
        "school": "Mid Peninsula School",
        "district": "Mid Peninsula School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262383001054",
    },
    {
        "school": "TriTownship School",
        "district": "Rapid River Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262934006514",
    },
    {
        "school": "Learning Center",
        "district": "Delta-Schoolcraft ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268034000126",
    },
    {
        "school": "DeltaSchoolcraft Area Center",
        "district": "Delta-Schoolcraft ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268034000497",
    },
    {
        "school": "Michigan School for the Deaf",
        "district": "Michigan School for the Deaf",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260028001809",
    },
    {
        "school": "Richfield Public School Academy",
        "district": "Richfield Public School Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260028601654",
    },
    {
        "school": "Madison Academy ElementaryMiddle School",
        "district": "Madison Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260031701771",
    },
    {
        "school": "Flushing Early Childhood Center",
        "district": "Flushing Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261455001861",
    },
    {
        "school": "Lillian G Mason Elementary School",
        "district": "Grand Blanc Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635001515",
    },
    {
        "school": "Grand Blanc Middle School East",
        "district": "Grand Blanc Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635001835",
    },
    {
        "school": "Grand Blanc Middle School West",
        "district": "Grand Blanc Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635001836",
    },
    {
        "school": "Brendel Elementary School",
        "district": "Grand Blanc Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635001859",
    },
    {
        "school": "Lake Fenton Middle School",
        "district": "Lake Fenton Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262067001826",
    },
    {
        "school": "Hyatt Elementary",
        "district": "Linden Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262169001685",
    },
    {
        "school": "Montrose Alternative Education Center",
        "district": "Montrose Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262442001827",
    },
    {
        "school": "Woodland Park Academy",
        "district": "Woodland Park Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260007600517",
    },
    {
        "school": "Grand Blanc Academy",
        "district": "Grand Blanc Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260019301102",
    },
    {
        "school": "Northridge Academy",
        "district": "Northridge Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260019401103",
    },
    {
        "school": "International Academy of Flint K12",
        "district": "International Academy of Flint",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260019501104",
    },
    {
        "school": "Linden Charter Academy",
        "district": "Linden Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260019701106",
    },
    {
        "school": "Burton Glen Charter Academy",
        "district": "Burton Glen Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260025101229",
    },
    {
        "school": "Atherton Jr  Sr High School",
        "district": "Atherton Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260354004051",
    },
    {
        "school": "Atherton Elementary School",
        "district": "Atherton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260354004052",
    },
    {
        "school": "Atherton Vern Van Y Educational Center",
        "district": "Atherton Community Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260354004053",
    },
    {
        "school": "Beecher High School",
        "district": "Beecher Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260450004133",
    },
    {
        "school": "Dailey Elementary School",
        "district": "Beecher Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260450004136",
    },
    {
        "school": "Bendle High School",
        "district": "Bendle Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260474004152",
    },
    {
        "school": "South Bendle Elementary School",
        "district": "Bendle Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260474004155",
    },
    {
        "school": "Bendle Middle School",
        "district": "Bendle Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260474004156",
    },
    {
        "school": "West Bendle Elementary School",
        "district": "Bendle Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260474004157",
    },
    {
        "school": "Barhitte Elementary School",
        "district": "Bentley Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260480004158",
    },
    {
        "school": "Bentley Senior High School",
        "district": "Bentley Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260480004160",
    },
    {
        "school": "The Learning Community",
        "district": "Carman-Ainsworth Community Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260789000513",
    },
    {
        "school": "CarmanAinsworth Middle School",
        "district": "Carman-Ainsworth Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260789004361",
    },
    {
        "school": "Dye Elementary School",
        "district": "Carman-Ainsworth Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260789004363",
    },
    {
        "school": "Gladys Dillon Elementary School",
        "district": "Carman-Ainsworth Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260789004366",
    },
    {
        "school": "Randels Elementary School",
        "district": "Carman-Ainsworth Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260789004369",
    },
    {
        "school": "Rankin Elementary School",
        "district": "Carman-Ainsworth Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260789004370",
    },
    {
        "school": "CarmanAinsworth High School",
        "district": "Carman-Ainsworth Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260789004373",
    },
    {
        "school": "AC Edgerton Elementary School",
        "district": "Clio Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261011004497",
    },
    {
        "school": "Clio Area High School",
        "district": "Clio Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261011004498",
    },
    {
        "school": "George A Lacure Elem School",
        "district": "Clio Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261011004499",
    },
    {
        "school": "George R Carter Middle School",
        "district": "Clio Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261011004500",
    },
    {
        "school": "Glen Garner Elementary School",
        "district": "Clio Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261011004501",
    },
    {
        "school": "Davison Alternative Education",
        "district": "Davison Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261143000135",
    },
    {
        "school": "Hahn Intermediate School",
        "district": "Davison Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261143001055",
    },
    {
        "school": "Davison High School",
        "district": "Davison Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261143004574",
    },
    {
        "school": "Davison Middle School",
        "district": "Davison Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261143004575",
    },
    {
        "school": "Hill Elementary School",
        "district": "Davison Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261143004576",
    },
    {
        "school": "Siple Elementary School",
        "district": "Davison Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261143004577",
    },
    {
        "school": "Gates Elementary School",
        "district": "Davison Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261143004578",
    },
    {
        "school": "Thomson Elementary School",
        "district": "Davison Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261143004579",
    },
    {
        "school": "Central Elementary School",
        "district": "Davison Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261143004580",
    },
    {
        "school": "Ellen St Campus",
        "district": "Fenton Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261425001339",
    },
    {
        "school": "TomekEastern Elem School",
        "district": "Fenton Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261425005064",
    },
    {
        "school": "Andrew G Schmidt Middle School",
        "district": "Fenton Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261425005065",
    },
    {
        "school": "North Road Elementary School",
        "district": "Fenton Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261425005066",
    },
    {
        "school": "State Road Elementary School",
        "district": "Fenton Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261425005067",
    },
    {
        "school": "Fenton Senior High School",
        "district": "Fenton Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261425005068",
    },
    {
        "school": "Durant Tuuri Mott School",
        "district": "Flint School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261452005099",
    },
    {
        "school": "Eisenhower School",
        "district": "Flint School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261452005100",
    },
    {
        "school": "Freeman School",
        "district": "Flint School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261452005101",
    },
    {
        "school": "Neithercut Elementary School",
        "district": "Flint School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261452005112",
    },
    {
        "school": "Pierce School",
        "district": "Flint School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261452005115",
    },
    {
        "school": "Potter School",
        "district": "Flint School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261452005117",
    },
    {
        "school": "DoyleRyder School",
        "district": "Flint School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261452005118",
    },
    {
        "school": "Southwestern Classical Academy",
        "district": "Flint School District of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261452005122",
    },
    {
        "school": "Central Elementary School",
        "district": "Flushing Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261455005143",
    },
    {
        "school": "Elms Elementary School",
        "district": "Flushing Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261455005144",
    },
    {
        "school": "Flushing High School",
        "district": "Flushing Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261455005145",
    },
    {
        "school": "Flushing Middle School",
        "district": "Flushing Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261455005146",
    },
    {
        "school": "Seymour Elementary School",
        "district": "Flushing Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261455005147",
    },
    {
        "school": "Springview Elementary School",
        "district": "Flushing Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261455005148",
    },
    {
        "school": "Genesee High School",
        "district": "Genesee School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261575005229",
    },
    {
        "school": "Haas Elementary School",
        "district": "Genesee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261575005230",
    },
    {
        "school": "Oaktree Elementary School",
        "district": "Goodrich Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261632000511",
    },
    {
        "school": "Goodrich High School",
        "district": "Goodrich Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261632005267",
    },
    {
        "school": "Reid Elementary School",
        "district": "Goodrich Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261632005268",
    },
    {
        "school": "Goodrich Middle School",
        "district": "Goodrich Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261632005269",
    },
    {
        "school": "Perry PreKindergarten",
        "district": "Grand Blanc Community Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635000133",
    },
    {
        "school": "Cook Elementary School",
        "district": "Grand Blanc Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635000134",
    },
    {
        "school": "Anderson Elementary School",
        "district": "Grand Blanc Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635000509",
    },
    {
        "school": "Perry Innovation Center",
        "district": "Grand Blanc Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635001469",
    },
    {
        "school": "Grand Blanc Community High School",
        "district": "Grand Blanc Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635005272",
    },
    {
        "school": "Indian Hill Elementary School",
        "district": "Grand Blanc Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635005273",
    },
    {
        "school": "Myers Elementary School",
        "district": "Grand Blanc Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635005274",
    },
    {
        "school": "McGrath Elementary School",
        "district": "Grand Blanc Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635005276",
    },
    {
        "school": "Reid Elementary School",
        "district": "Grand Blanc Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261635007533",
    },
    {
        "school": "Kate Dowdall Elementary School",
        "district": "Kearsley Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262007005690",
    },
    {
        "school": "Leota Fiedler Elementary School",
        "district": "Kearsley Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262007005691",
    },
    {
        "school": "Kearsley High School",
        "district": "Kearsley Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262007005692",
    },
    {
        "school": "Armstrong Middle School",
        "district": "Kearsley Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262007005693",
    },
    {
        "school": "Weston Elementary School",
        "district": "Kearsley Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262007007547",
    },
    {
        "school": "Lake Fenton High School",
        "district": "Lake Fenton Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262067005730",
    },
    {
        "school": "West Shore Elementary School",
        "district": "Lake Fenton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262067005731",
    },
    {
        "school": "Torrey Hill Intermediate School",
        "district": "Lake Fenton Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262067005732",
    },
    {
        "school": "LakeVille High School",
        "district": "LakeVille Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262094005766",
    },
    {
        "school": "LakeVille Middle School",
        "district": "LakeVille Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262094005768",
    },
    {
        "school": "Linden Elementary School",
        "district": "Linden Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262169005869",
    },
    {
        "school": "Linden High School",
        "district": "Linden Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262169005870",
    },
    {
        "school": "Linden Middle School",
        "district": "Linden Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262169005871",
    },
    {
        "school": "Central Elementary School",
        "district": "Linden Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262169005872",
    },
    {
        "school": "Carter Elementary School",
        "district": "Montrose Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262442006103",
    },
    {
        "school": "HillMcCloy High School",
        "district": "Montrose Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262442006104",
    },
    {
        "school": "KuehnHaven Middle School",
        "district": "Montrose Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262442006105",
    },
    {
        "school": "Moore Elementary School",
        "district": "Mt. Morris Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262472006123",
    },
    {
        "school": "Montague Elementary School",
        "district": "Mt. Morris Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262472006124",
    },
    {
        "school": "Mt Morris Education and Community Center",
        "district": "Mt. Morris Consolidated Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262472006125",
    },
    {
        "school": "Mt Morris Middle School",
        "district": "Mt. Morris Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262472006126",
    },
    {
        "school": "Pinehurst Early Elementary",
        "district": "Mt. Morris Consolidated Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262472006127",
    },
    {
        "school": "EA Johnson Memorial HS",
        "district": "Mt. Morris Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262472006128",
    },
    {
        "school": "Swartz Creek Virtual Learning Center",
        "district": "Swartz Creek Community Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263342000836",
    },
    {
        "school": "Gaines Elementary School",
        "district": "Swartz Creek Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263342006877",
    },
    {
        "school": "Morrish Elementary School",
        "district": "Swartz Creek Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263342006879",
    },
    {
        "school": "Swartz Creek Middle School",
        "district": "Swartz Creek Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263342006880",
    },
    {
        "school": "Swartz Creek High School",
        "district": "Swartz Creek Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263342006881",
    },
    {
        "school": "Syring Elementary School",
        "district": "Swartz Creek Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263342006882",
    },
    {
        "school": "Elms Road Elementary School",
        "district": "Swartz Creek Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263342006883",
    },
    {
        "school": "Dieck Elementary School",
        "district": "Swartz Creek Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263342006884",
    },
    {
        "school": "Hamady Middle School",
        "district": "Westwood Heights Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263597007202",
    },
    {
        "school": "Colonel Donald McMonagle Elementary School",
        "district": "Westwood Heights Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263597007204",
    },
    {
        "school": "Hamady Community High School",
        "district": "Westwood Heights Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263597007205",
    },
    {
        "school": "Marion D Crouse Instr Center",
        "district": "Genesee ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268040000130",
    },
    {
        "school": "Elmer A Knopf Learning Center",
        "district": "Genesee ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268040000131",
    },
    {
        "school": "Special Education ServicesSouth",
        "district": "Genesee ISD",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268040001228",
    },
    {
        "school": "Columbiaville Elementary School",
        "district": "LakeVille Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262094005765",
    },
    {
        "school": "Countryside Elementary School",
        "district": "Byron Center Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260756001549",
    },
    {
        "school": "Duncan Lake Middle School",
        "district": "Caledonia Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260762001759",
    },
    {
        "school": "Duncan Lake Early Childhood Center",
        "district": "Caledonia Community Schools",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260762001824",
    },
    {
        "school": "Red Hawk Elementary",
        "district": "Cedar Springs Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260852001820",
    },
    {
        "school": "Knapp Forest Elementary School",
        "district": "Forest Hills Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461001550",
    },
    {
        "school": "Eastern Middle School",
        "district": "Forest Hills Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461001661",
    },
    {
        "school": "Eastern High School",
        "district": "Forest Hills Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461001662",
    },
    {
        "school": "Home Education Site",
        "district": "Grand Rapids Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261644001547",
    },
    {
        "school": "East Leonard Elementary",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644001604",
    },
    {
        "school": "CA Frost Environmental Science Academy Middle High School",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644001634",
    },
    {
        "school": "Congress Elementary",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644001636",
    },
    {
        "school": "Southwest Community Campus School",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644001643",
    },
    {
        "school": "Kent City Middle School",
        "district": "Kent City Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262031001757",
    },
    {
        "school": "Crossroads Alternative High School",
        "district": "Kentwood Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262034001583",
    },
    {
        "school": "Discovery Elementary",
        "district": "Kentwood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034001874",
    },
    {
        "school": "Murray Lake Elementary",
        "district": "Lowell Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262205001690",
    },
    {
        "school": "Northview Next Career Center",
        "district": "Northview Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262595001565",
    },
    {
        "school": "Rockford Spanish Immersion",
        "district": "Rockford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003001876",
    },
    {
        "school": "Flat River Academy",
        "district": "Flat River Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260014501652",
    },
    {
        "school": "Hesperia Community Education",
        "district": "Hesperia Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261827001896",
    },
    {
        "school": "White Cloud Elementary School",
        "district": "White Cloud Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263606001545",
    },
    {
        "school": "DK Academy",
        "district": "Delton Kellogg Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261191000112",
    },
    {
        "school": "DeltonKellogg High School",
        "district": "Delton Kellogg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261191004631",
    },
    {
        "school": "Delton Kellogg Elem School",
        "district": "Delton Kellogg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261191004632",
    },
    {
        "school": "DeltonKellogg Middle School",
        "district": "Delton Kellogg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261191004633",
    },
    {
        "school": "Learning Center",
        "district": "Thornapple Kellogg School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263381000113",
    },
    {
        "school": "McFall Elementary School",
        "district": "Thornapple Kellogg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263381006923",
    },
    {
        "school": "Thornapple Kellogg High School",
        "district": "Thornapple Kellogg School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263381006924",
    },
    {
        "school": "Lee Elementary School",
        "district": "Thornapple Kellogg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263381006925",
    },
    {
        "school": "Thornapple Kellogg Middle School",
        "district": "Thornapple Kellogg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263381006926",
    },
    {
        "school": "Page Elementary School",
        "district": "Thornapple Kellogg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263381007583",
    },
    {
        "school": "Barry ISD Special Education",
        "district": "Barry ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268014001323",
    },
    {
        "school": "Woodview Elementary School",
        "district": "Belding Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260453000854",
    },
    {
        "school": "Belding High School",
        "district": "Belding Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260453004142",
    },
    {
        "school": "Ellis Elementary School",
        "district": "Belding Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260453004143",
    },
    {
        "school": "Belding Middle School",
        "district": "Belding Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260453004146",
    },
    {
        "school": "Coon School",
        "district": "Berlin Township S/D #3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260510004196",
    },
    {
        "school": "Haynor School",
        "district": "Easton Township S/D #6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261266004980",
    },
    {
        "school": "Emerson School",
        "district": "Ionia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261925000852",
    },
    {
        "school": "Douglas R Welch High School",
        "district": "Ionia Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261925001313",
    },
    {
        "school": "AA Rather School",
        "district": "Ionia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261925005600",
    },
    {
        "school": "Ionia High School",
        "district": "Ionia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261925005601",
    },
    {
        "school": "Jefferson School",
        "district": "Ionia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261925005602",
    },
    {
        "school": "Twin Rivers Elementary School",
        "district": "Ionia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261925005603",
    },
    {
        "school": "RB Boyce Elementary School",
        "district": "Ionia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261925005604",
    },
    {
        "school": "Ionia Middle School",
        "district": "Ionia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261925005605",
    },
    {
        "school": "North LeValley Elem School",
        "district": "Ionia Township S/D #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261929005606",
    },
    {
        "school": "Portland High School",
        "district": "Portland Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262912006497",
    },
    {
        "school": "Oakwood Elementary School",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262912006498",
    },
    {
        "school": "Portland Middle School",
        "district": "Portland Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262912006499",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262912006500",
    },
    {
        "school": "Saranac JrSr High School",
        "district": "Saranac Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263093006717",
    },
    {
        "school": "Saranac Elementary School",
        "district": "Saranac Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263093007648",
    },
    {
        "school": "Freedom Acres School",
        "district": "Ionia ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268054000548",
    },
    {
        "school": "Lincoln Heights Elem School",
        "district": "Greenville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261716005399",
    },
    {
        "school": "Baldwin Heights School",
        "district": "Greenville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261716005392",
    },
    {
        "school": "Cedar Crest Elementary School",
        "district": "Greenville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261716005393",
    },
    {
        "school": "Greenville Middle School",
        "district": "Greenville Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261716005394",
    },
    {
        "school": "Greenville Senior High School",
        "district": "Greenville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261716005395",
    },
    {
        "school": "Walnut Hills Elementary School",
        "district": "Greenville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261716005397",
    },
    {
        "school": "Big Jackson Public School",
        "district": "Big Jackson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260010500661",
    },
    {
        "school": "Pathfinder Elementary School",
        "district": "Fremont Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261515000955",
    },
    {
        "school": "Quest High School",
        "district": "Fremont Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261515005192",
    },
    {
        "school": "Daisy Brook Elementary School",
        "district": "Fremont Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261515005193",
    },
    {
        "school": "Fremont High School",
        "district": "Fremont Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261515005194",
    },
    {
        "school": "Fremont Middle School",
        "district": "Fremont Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261515005195",
    },
    {
        "school": "Grant Elementary School",
        "district": "Grant Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261650005385",
    },
    {
        "school": "Grant Middle School",
        "district": "Grant Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261650005386",
    },
    {
        "school": "Grant High School",
        "district": "Grant Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261650005387",
    },
    {
        "school": "Grant Primary Center",
        "district": "Grant Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261650005388",
    },
    {
        "school": "Patricia St Clair Elementary School",
        "district": "Hesperia Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261827005490",
    },
    {
        "school": "Hesperia High School",
        "district": "Hesperia Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261827005491",
    },
    {
        "school": "David C Outwin Middle School",
        "district": "Hesperia Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261827007697",
    },
    {
        "school": "Newaygo High School",
        "district": "Newaygo Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262532006190",
    },
    {
        "school": "Newaygo Middle School",
        "district": "Newaygo Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262532006192",
    },
    {
        "school": "Newaygo Elementary School",
        "district": "Newaygo Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262532007698",
    },
    {
        "school": "White Cloud Junior High School",
        "district": "White Cloud Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263606000044",
    },
    {
        "school": "White Cloud High School",
        "district": "White Cloud Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263606007207",
    },
    {
        "school": "Newaygo County Career Tech Center",
        "district": "Newaygo County RESA",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268086000952",
    },
    {
        "school": "Education and Activity Center",
        "district": "Newaygo County RESA",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268086001279",
    },
    {
        "school": "New Branches Charter Academy",
        "district": "New Branches Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260009000594",
    },
    {
        "school": "West MI Academy of Environmental Science",
        "district": "West MI Academy of Environmental Science",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260009200596",
    },
    {
        "school": "Excel Charter Academy",
        "district": "Excel Charter Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260009300597",
    },
    {
        "school": "Byron Center Charter School",
        "district": "Byron Center Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260009600600",
    },
    {
        "school": "Vista Charter Academy",
        "district": "Vista Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260009700601",
    },
    {
        "school": "Vanguard Charter Academy",
        "district": "Vanguard Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260009800602",
    },
    {
        "school": "Knapp Charter Academy",
        "district": "Knapp Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260014800909",
    },
    {
        "school": "Walker Charter Academy",
        "district": "Walker Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260014900910",
    },
    {
        "school": "Cross Creek Charter Academy",
        "district": "Cross Creek Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260015000911",
    },
    {
        "school": "William C Abney Academy Elementary",
        "district": "William C. Abney Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260018501065",
    },
    {
        "school": "Creative Technologies Academy",
        "district": "Creative Technologies Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260020701134",
    },
    {
        "school": "Ridge Park Charter Academy",
        "district": "Ridge Park Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260020801135",
    },
    {
        "school": "Chandler Woods Charter Academy",
        "district": "Chandler Woods Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260020901136",
    },
    {
        "school": "Grand Rapids Child Discovery Center",
        "district": "Grand Rapids Child Discovery Center",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260025201235",
    },
    {
        "school": "Robert L Nickels Intermediate School",
        "district": "Byron Center Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260756001129",
    },
    {
        "school": "Byron Center High School",
        "district": "Byron Center Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260756004332",
    },
    {
        "school": "Brown Elementary School",
        "district": "Byron Center Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260756004333",
    },
    {
        "school": "Byron Center West Middle School",
        "district": "Byron Center Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260756004334",
    },
    {
        "school": "Marshall Elementary School",
        "district": "Byron Center Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260756004335",
    },
    {
        "school": "Emmons Lake Elementary School",
        "district": "Caledonia Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260762001130",
    },
    {
        "school": "Caledonia High School",
        "district": "Caledonia Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260762004346",
    },
    {
        "school": "Caledonia Elementary School",
        "district": "Caledonia Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260762004347",
    },
    {
        "school": "Kraft Meadows Middle School",
        "district": "Caledonia Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260762004348",
    },
    {
        "school": "Dutton Elementary School",
        "district": "Caledonia Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260762004349",
    },
    {
        "school": "Kettle Lake Elementary School",
        "district": "Caledonia Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260762004350",
    },
    {
        "school": "New Beginnings Alternative High School",
        "district": "Cedar Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260852000585",
    },
    {
        "school": "Cedar Trails Elementary School",
        "district": "Cedar Springs Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260852000898",
    },
    {
        "school": "Cedar Springs Middle School",
        "district": "Cedar Springs Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260852004399",
    },
    {
        "school": "Cedar Springs High School",
        "district": "Cedar Springs Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260852004400",
    },
    {
        "school": "Mill Creek Middle School",
        "district": "Comstock Park Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261062000586",
    },
    {
        "school": "Pine Island Elementary",
        "district": "Comstock Park Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261062001064",
    },
    {
        "school": "Comstock Park High School",
        "district": "Comstock Park Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261062004532",
    },
    {
        "school": "Stoney Creek Elementary",
        "district": "Comstock Park Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261062004534",
    },
    {
        "school": "Breton Downs School",
        "district": "East Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261248004959",
    },
    {
        "school": "East Grand Rapids Middle School",
        "district": "East Grand Rapids Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261248004960",
    },
    {
        "school": "East Grand Rapids High School",
        "district": "East Grand Rapids Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261248004961",
    },
    {
        "school": "Lakeside School",
        "district": "East Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261248004962",
    },
    {
        "school": "Wealthy School",
        "district": "East Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261248004963",
    },
    {
        "school": "Meadow Brook Elementary School",
        "district": "Forest Hills Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461000057",
    },
    {
        "school": "Northern Trails 56 School",
        "district": "Forest Hills Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461000900",
    },
    {
        "school": "Central Woodlands 56 School",
        "district": "Forest Hills Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461000901",
    },
    {
        "school": "Ada Vista Elementary School",
        "district": "Forest Hills Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461001312",
    },
    {
        "school": "Goodwillie Environmental School",
        "district": "Forest Hills Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461001366",
    },
    {
        "school": "Ada Elementary School",
        "district": "Forest Hills Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461005152",
    },
    {
        "school": "Collins Elementary School",
        "district": "Forest Hills Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461005153",
    },
    {
        "school": "Central Middle School",
        "district": "Forest Hills Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461005154",
    },
    {
        "school": "Central High School",
        "district": "Forest Hills Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461005155",
    },
    {
        "school": "Orchard View Elementary School",
        "district": "Forest Hills Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461005156",
    },
    {
        "school": "Thornapple Elementary School",
        "district": "Forest Hills Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461005157",
    },
    {
        "school": "Northern High School",
        "district": "Forest Hills Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461005158",
    },
    {
        "school": "Pine Ridge Elementary School",
        "district": "Forest Hills Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461005159",
    },
    {
        "school": "Northern Hills Middle School",
        "district": "Forest Hills Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261461005160",
    },
    {
        "school": "Lee Middle School",
        "district": "Godfrey-Lee Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261608000587",
    },
    {
        "school": "East Lee Campus",
        "district": "Godfrey-Lee Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261608000588",
    },
    {
        "school": "GodfreyLee Early Childhood Ctr",
        "district": "Godfrey-Lee Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261608001131",
    },
    {
        "school": "Godfrey Elementary School",
        "district": "Godfrey-Lee Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261608005258",
    },
    {
        "school": "Lee High School",
        "district": "Godfrey-Lee Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261608005260",
    },
    {
        "school": "Godwin Heights Learning Center",
        "district": "Godwin Heights Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261611000897",
    },
    {
        "school": "Godwin Heights Senior High School",
        "district": "Godwin Heights Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261611005261",
    },
    {
        "school": "North Godwin Elementary School",
        "district": "Godwin Heights Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261611005262",
    },
    {
        "school": "Godwin Heights Middle School",
        "district": "Godwin Heights Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261611005265",
    },
    {
        "school": "West Godwin Elementary School",
        "district": "Godwin Heights Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261611005266",
    },
    {
        "school": "Burton Middle School",
        "district": "Grand Rapids Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644000563",
    },
    {
        "school": "Bethany Based School",
        "district": "Grand Rapids Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261644000878",
    },
    {
        "school": "Grand Rapids Montessori Academy",
        "district": "Grand Rapids Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644000881",
    },
    {
        "school": "Southeast Career Pathways",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261644000885",
    },
    {
        "school": "Blandford Nature Center",
        "district": "Grand Rapids Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644000892",
    },
    {
        "school": "John Ball Park Zoo School",
        "district": "Grand Rapids Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644000893",
    },
    {
        "school": "Shared Time",
        "district": "Grand Rapids Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644001362",
    },
    {
        "school": "Newcomers Community School",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261644001364",
    },
    {
        "school": "Coit Creative Arts Academy",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644001453",
    },
    {
        "school": "Brookside Elementary",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005303",
    },
    {
        "school": "Buchanan Elementary",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005304",
    },
    {
        "school": "Dickinson Academy",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005314",
    },
    {
        "school": "Cesar E Chavez Elementary",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005319",
    },
    {
        "school": "Martin Luther King Leadership Academy",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005320",
    },
    {
        "school": "KenOSha Park Elementary",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005324",
    },
    {
        "school": "Kent Hills Elementary",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005326",
    },
    {
        "school": "Palmer School",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005336",
    },
    {
        "school": "Ottawa Hills High School",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005338",
    },
    {
        "school": "Riverside Middle School",
        "district": "Grand Rapids Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005340",
    },
    {
        "school": "Shawmut Hills School",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005341",
    },
    {
        "school": "Sibley School",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005344",
    },
    {
        "school": "Union High School",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005350",
    },
    {
        "school": "Westwood Middle School",
        "district": "Grand Rapids Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005354",
    },
    {
        "school": "City MiddleHigh",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005355",
    },
    {
        "school": "Burton Elementary",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644005358",
    },
    {
        "school": "North Park Montessori Academy",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644007746",
    },
    {
        "school": "Grandville Century Park Learning Center",
        "district": "Grandville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261647001367",
    },
    {
        "school": "Grandville Central Elementary School",
        "district": "Grandville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261647005377",
    },
    {
        "school": "Grandville Cummings Elementary School",
        "district": "Grandville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261647005378",
    },
    {
        "school": "Grandville East Elementary School",
        "district": "Grandville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261647005379",
    },
    {
        "school": "Grandville Middle School",
        "district": "Grandville Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261647005380",
    },
    {
        "school": "Grandville High School",
        "district": "Grandville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261647005381",
    },
    {
        "school": "Grandville South Elementary School",
        "district": "Grandville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261647005382",
    },
    {
        "school": "Grandville West Elementary School",
        "district": "Grandville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261647005383",
    },
    {
        "school": "Grandville Grand View Elementary School",
        "district": "Grandville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261647007681",
    },
    {
        "school": "East Kelloggsville School",
        "district": "Kelloggsville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262016005695",
    },
    {
        "school": "Kelloggsville Middle School",
        "district": "Kelloggsville Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262016005696",
    },
    {
        "school": "Kelloggsville High School",
        "district": "Kelloggsville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262016005697",
    },
    {
        "school": "Southeast Kelloggsville School",
        "district": "Kelloggsville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262016005698",
    },
    {
        "school": "West Kelloggsville School",
        "district": "Kelloggsville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262016005700",
    },
    {
        "school": "Kenowa Hills Central Elementary School",
        "district": "Kenowa Hills Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262028001132",
    },
    {
        "school": "Kenowa Hills High School",
        "district": "Kenowa Hills Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262028005702",
    },
    {
        "school": "Zinser Elementary School",
        "district": "Kenowa Hills Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262028005705",
    },
    {
        "school": "Kenowa Hills Middle School",
        "district": "Kenowa Hills Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262028005706",
    },
    {
        "school": "Alpine Elementary School",
        "district": "Kenowa Hills Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262028005707",
    },
    {
        "school": "Kent City High School",
        "district": "Kent City Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262031005708",
    },
    {
        "school": "Kent City Elementary School",
        "district": "Kent City Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262031005711",
    },
    {
        "school": "Explorer Elementary",
        "district": "Kentwood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034000099",
    },
    {
        "school": "East Kentwood Freshman Campus",
        "district": "Kentwood Public Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034000591",
    },
    {
        "school": "Endeavor Elementary",
        "district": "Kentwood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034000592",
    },
    {
        "school": "Bowen Elementary",
        "district": "Kentwood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034005713",
    },
    {
        "school": "Brookwood Elementary",
        "district": "Kentwood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034005714",
    },
    {
        "school": "Glenwood Elementary",
        "district": "Kentwood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034005715",
    },
    {
        "school": "Crestwood Middle School",
        "district": "Kentwood Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034005716",
    },
    {
        "school": "Meadowlawn Elementary",
        "district": "Kentwood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034005717",
    },
    {
        "school": "Southwood Elementary",
        "district": "Kentwood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034005718",
    },
    {
        "school": "Townline Elementary",
        "district": "Kentwood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034005719",
    },
    {
        "school": "Valleywood Middle School",
        "district": "Kentwood Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034005720",
    },
    {
        "school": "East Kentwood High School",
        "district": "Kentwood Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034005721",
    },
    {
        "school": "Challenger Elementary",
        "district": "Kentwood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034007682",
    },
    {
        "school": "Pinewood Middle School",
        "district": "Kentwood Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262034007683",
    },
    {
        "school": "Cherry Creek Elementary School",
        "district": "Lowell Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262205000593",
    },
    {
        "school": "Alto Elementary School",
        "district": "Lowell Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262205005925",
    },
    {
        "school": "Lowell Senior High School",
        "district": "Lowell Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262205005926",
    },
    {
        "school": "Bushnell Elementary School",
        "district": "Lowell Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262205005927",
    },
    {
        "school": "Unity Alternative School",
        "district": "Lowell Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262205005928",
    },
    {
        "school": "Lowell Middle School",
        "district": "Lowell Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262205005929",
    },
    {
        "school": "East Oakview Elementary School",
        "district": "Northview Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262595006238",
    },
    {
        "school": "North Oakview Elementary School",
        "district": "Northview Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262595006239",
    },
    {
        "school": "Northview High School",
        "district": "Northview Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262595006240",
    },
    {
        "school": "Crossroads Middle School",
        "district": "Northview Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262595006241",
    },
    {
        "school": "West Oakview Elementary School",
        "district": "Northview Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262595006242",
    },
    {
        "school": "Highlands School",
        "district": "Northview Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262595006243",
    },
    {
        "school": "River Valley Academy",
        "district": "Rockford Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263003000905",
    },
    {
        "school": "Meadow Ridge Elementary School",
        "district": "Rockford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003001133",
    },
    {
        "school": "East Rockford Middle School",
        "district": "Rockford Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003001234",
    },
    {
        "school": "Belmont Elementary School",
        "district": "Rockford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003006584",
    },
    {
        "school": "Crestwood Elementary School",
        "district": "Rockford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003006585",
    },
    {
        "school": "Lakes Elementary School",
        "district": "Rockford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003006586",
    },
    {
        "school": "Parkside Elementary School",
        "district": "Rockford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003006587",
    },
    {
        "school": "Rockford High School",
        "district": "Rockford Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003006588",
    },
    {
        "school": "Valley View Elementary School",
        "district": "Rockford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003006589",
    },
    {
        "school": "Cannonsburg Elementary School",
        "district": "Rockford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003006590",
    },
    {
        "school": "North Rockford Middle School",
        "district": "Rockford Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003006591",
    },
    {
        "school": "Rockford HS Freshman Center",
        "district": "Rockford Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003006592",
    },
    {
        "school": "Roguewood Elementary School",
        "district": "Rockford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263003007691",
    },
    {
        "school": "Sparta Senior High School",
        "district": "Sparta Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263237006798",
    },
    {
        "school": "Sparta Middle School",
        "district": "Sparta Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263237006800",
    },
    {
        "school": "Ridgeview Elementary School",
        "district": "Sparta Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263237007686",
    },
    {
        "school": "Sand Lake Elementary School",
        "district": "Tri County Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263393006960",
    },
    {
        "school": "Gladiola Elementary School",
        "district": "Wyoming Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263657007259",
    },
    {
        "school": "Wyoming Intermediate",
        "district": "Wyoming Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263657007260",
    },
    {
        "school": "Wyoming Junior High",
        "district": "Wyoming Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263657007261",
    },
    {
        "school": "Parkview Elementary School",
        "district": "Wyoming Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263657007262",
    },
    {
        "school": "Wyoming High School",
        "district": "Wyoming Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263657007264",
    },
    {
        "school": "Oriole Park Elementary School",
        "district": "Wyoming Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263657007266",
    },
    {
        "school": "West Elementary School",
        "district": "Wyoming Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263657007268",
    },
    {
        "school": "Kent Career Tech Center",
        "district": "Kent ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268062000562",
    },
    {
        "school": "Tri County Middle School",
        "district": "Tri County Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263393006958",
    },
    {
        "school": "MacNaughton School",
        "district": "Tri County Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263393006959",
    },
    {
        "school": "Tri County Senior High School",
        "district": "Tri County Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263393006961",
    },
    {
        "school": "Star Elementary School",
        "district": "Hastings Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261797000796",
    },
    {
        "school": "Northeastern Elementary School",
        "district": "Hastings Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261797005468",
    },
    {
        "school": "Central Elementary School",
        "district": "Hastings Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261797005469",
    },
    {
        "school": "Hastings Middle School",
        "district": "Hastings Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261797005470",
    },
    {
        "school": "Southeastern Elementary School",
        "district": "Hastings Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261797005472",
    },
    {
        "school": "Hastings High School",
        "district": "Hastings Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261797005473",
    },
    {
        "school": "Lakewood Middle School",
        "district": "Lakewood Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262098000552",
    },
    {
        "school": "Lakewood High School",
        "district": "Lakewood Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262098005774",
    },
    {
        "school": "Lakewood Elementary School",
        "district": "Lakewood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262098005776",
    },
    {
        "school": "New Options High School",
        "district": "Allendale Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260255001572",
    },
    {
        "school": "Holland Heights",
        "district": "Holland City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261842001628",
    },
    {
        "school": "Georgetown Elementary School",
        "district": "Hudsonville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884001907",
    },
    {
        "school": "Jenison Public Schools Early Childhood Center",
        "district": "Jenison Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261983001756",
    },
    {
        "school": "Venture Academy",
        "district": "Zeeland Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263666001546",
    },
    {
        "school": "Quincy Elementary School",
        "district": "Zeeland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263666001692",
    },
    {
        "school": "Walden Green Montessori",
        "district": "Walden Green Montessori",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260011200703",
    },
    {
        "school": "West MI Academy of Arts and Academics",
        "district": "West MI Academy of Arts and Academics",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260011300704",
    },
    {
        "school": "Black River Public School MiddleHigh",
        "district": "Black River Public School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260011400705",
    },
    {
        "school": "Vanderbilt Charter Academy",
        "district": "Vanderbilt Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260011500706",
    },
    {
        "school": "Eagle Crest Charter Academy",
        "district": "Eagle Crest Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260015900979",
    },
    {
        "school": "Allendale Middle School",
        "district": "Allendale Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260255000255",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Allendale Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260255003975",
    },
    {
        "school": "Allendale High School",
        "district": "Allendale Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260255003976",
    },
    {
        "school": "Coopersville West Early Childhood Center",
        "district": "Coopersville Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261083004545",
    },
    {
        "school": "Coopersville High School",
        "district": "Coopersville Area Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261083004546",
    },
    {
        "school": "Coopersville Middle School",
        "district": "Coopersville Area Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261083004547",
    },
    {
        "school": "Coopersville South Elementary School",
        "district": "Coopersville Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261083007661",
    },
    {
        "school": "Lakeshore Middle School",
        "district": "Grand Haven Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261638000977",
    },
    {
        "school": "Central High School",
        "district": "Grand Haven Area Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261638005278",
    },
    {
        "school": "Ferry School",
        "district": "Grand Haven Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261638005279",
    },
    {
        "school": "White Pines Intermediate School",
        "district": "Grand Haven Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261638005281",
    },
    {
        "school": "Grand Haven High School",
        "district": "Grand Haven Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261638005282",
    },
    {
        "school": "Mary A White School",
        "district": "Grand Haven Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261638005283",
    },
    {
        "school": "Peach Plains School",
        "district": "Grand Haven Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261638005284",
    },
    {
        "school": "Robinson School",
        "district": "Grand Haven Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261638005285",
    },
    {
        "school": "Rosy Mound School",
        "district": "Grand Haven Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261638005286",
    },
    {
        "school": "Griffin Elementary School",
        "district": "Grand Haven Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261638005288",
    },
    {
        "school": "Lake Hills Elementary School",
        "district": "Grand Haven Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261638005289",
    },
    {
        "school": "Holland Middle School",
        "district": "Holland City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261842000026",
    },
    {
        "school": "Holland High School",
        "district": "Holland City School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261842005512",
    },
    {
        "school": "Baldwin Street Middle School",
        "district": "Hudsonville Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884000700",
    },
    {
        "school": "Riley Street Middle School",
        "district": "Hudsonville Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884001250",
    },
    {
        "school": "Alward Elementary School",
        "district": "Hudsonville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884005559",
    },
    {
        "school": "Bauer Elementary School",
        "district": "Hudsonville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884005560",
    },
    {
        "school": "Forest Grove Elementary School",
        "district": "Hudsonville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884005561",
    },
    {
        "school": "Hudsonville Freshman Building",
        "district": "Hudsonville Public School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884005562",
    },
    {
        "school": "Hudsonville High School",
        "district": "Hudsonville Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884005563",
    },
    {
        "school": "Park Elemementary School",
        "district": "Hudsonville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884005564",
    },
    {
        "school": "Jamestown Upper Elementary School",
        "district": "Hudsonville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884005565",
    },
    {
        "school": "South Elementary School",
        "district": "Hudsonville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884005566",
    },
    {
        "school": "Jenison Junior High School",
        "district": "Jenison Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261983000978",
    },
    {
        "school": "Bauerwood School",
        "district": "Jenison Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261983005639",
    },
    {
        "school": "Bursley School",
        "district": "Jenison Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261983005640",
    },
    {
        "school": "Sandy Hill School",
        "district": "Jenison Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261983005643",
    },
    {
        "school": "Pinewood School",
        "district": "Jenison Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261983005644",
    },
    {
        "school": "Jenison High School",
        "district": "Jenison Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261983005645",
    },
    {
        "school": "Rosewood School",
        "district": "Jenison Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261983005646",
    },
    {
        "school": "Spring Lake Middle School",
        "district": "Spring Lake Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263255001251",
    },
    {
        "school": "Spring Lake Intermediate School",
        "district": "Spring Lake Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263255001252",
    },
    {
        "school": "Spring Lake Alternative Education",
        "district": "Spring Lake Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263255001461",
    },
    {
        "school": "Holmes Elementary School",
        "district": "Spring Lake Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263255006804",
    },
    {
        "school": "Jeffers Elementary School",
        "district": "Spring Lake Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263255006805",
    },
    {
        "school": "Spring Lake High School",
        "district": "Spring Lake Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263255006806",
    },
    {
        "school": "Lakeshore Elementary School",
        "district": "West Ottawa Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591000102",
    },
    {
        "school": "Great Lakes Elementary School",
        "district": "West Ottawa Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591001085",
    },
    {
        "school": "Harbor Lights Middle School",
        "district": "West Ottawa Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591001169",
    },
    {
        "school": "Lakewood Elementary School",
        "district": "West Ottawa Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591007188",
    },
    {
        "school": "North Holland Elementary School",
        "district": "West Ottawa Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591007189",
    },
    {
        "school": "Sheldon Woods Elementary School",
        "district": "West Ottawa Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591007191",
    },
    {
        "school": "Waukazoo Elementary School",
        "district": "West Ottawa Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591007193",
    },
    {
        "school": "West Ottawa High School Campus",
        "district": "West Ottawa Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591007194",
    },
    {
        "school": "Woodside Elementary School",
        "district": "West Ottawa Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591007195",
    },
    {
        "school": "Macatawa Bay Middle School",
        "district": "West Ottawa Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591007196",
    },
    {
        "school": "Pine Creek Elementary School",
        "district": "West Ottawa Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591007660",
    },
    {
        "school": "Woodbridge Elementary School",
        "district": "Zeeland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263666000701",
    },
    {
        "school": "Cityside Middle School",
        "district": "Zeeland Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263666000702",
    },
    {
        "school": "Zeeland West High School",
        "district": "Zeeland Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263666001316",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Zeeland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263666007291",
    },
    {
        "school": "New Groningen School",
        "district": "Zeeland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263666007292",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Zeeland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263666007293",
    },
    {
        "school": "Creekside Middle School",
        "district": "Zeeland Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263666007295",
    },
    {
        "school": "Zeeland East High School",
        "district": "Zeeland Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263666007296",
    },
    {
        "school": "Ottawa Area Center",
        "district": "Ottawa Area ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268090000252",
    },
    {
        "school": "Sheldon Pines School",
        "district": "Ottawa Area ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268090000253",
    },
    {
        "school": "CHSHorizons School",
        "district": "Public Schools of Calumet Laurium & Keweenaw",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260769001863",
    },
    {
        "school": "Jeffers High School",
        "district": "Adams Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260189003921",
    },
    {
        "school": "South Range Elementary School",
        "district": "Adams Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260189003922",
    },
    {
        "school": "Calumet High School",
        "district": "Public Schools of Calumet Laurium & Keweenaw",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260769004352",
    },
    {
        "school": "CLK Elementary School",
        "district": "Public Schools of Calumet Laurium & Keweenaw",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260769004353",
    },
    {
        "school": "Washington Middle School",
        "district": "Public Schools of Calumet Laurium & Keweenaw",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260769004354",
    },
    {
        "school": "Chassell K12 School",
        "district": "Chassell Township School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260888004428",
    },
    {
        "school": "Elm River Township School",
        "district": "Elm River Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261314005012",
    },
    {
        "school": "Hancock MiddleHigh School",
        "district": "Hancock Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261755005426",
    },
    {
        "school": "Barkell Elementary School",
        "district": "Hancock Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261755007544",
    },
    {
        "school": "Lake LindenHubbell Schools",
        "district": "Lake Linden-Hubbell School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262070005734",
    },
    {
        "school": "Dollar BayTamarack City Area K12 School",
        "district": "Dollar Bay-Tamarack City Area  K-12 School",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262694006308",
    },
    {
        "school": "Houghton Middle School",
        "district": "Houghton-Portage Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262889000846",
    },
    {
        "school": "Houghton Central High School",
        "district": "Houghton-Portage Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262889006482",
    },
    {
        "school": "Houghton Elementary School",
        "district": "Houghton-Portage Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262889006483",
    },
    {
        "school": "EB Holman Elementary School",
        "district": "Stanton Township Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263297006849",
    },
    {
        "school": "Copper Country Learning Center",
        "district": "Copper Country ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268050500139",
    },
    {
        "school": "Career and Technical Education",
        "district": "Copper Country ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268050501346",
    },
    {
        "school": "Grant Township School",
        "district": "Grant Township S/D #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261656005389",
    },
    {
        "school": "Norway Elementary School",
        "district": "Norway-Vulcan Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262604001854",
    },
    {
        "school": "Vulcan Middle School",
        "district": "Norway-Vulcan Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262604001855",
    },
    {
        "school": "Kingsford High School",
        "district": "Breitung Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260672004267",
    },
    {
        "school": "Kingsford Middle School",
        "district": "Breitung Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260672004268",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Breitung Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260672007511",
    },
    {
        "school": "IMK Community Education",
        "district": "Iron Mountain Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261941001227",
    },
    {
        "school": "Central Middle School",
        "district": "Iron Mountain Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261941005610",
    },
    {
        "school": "Iron Mountain High School",
        "district": "Iron Mountain Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261941005611",
    },
    {
        "school": "North Elementary School",
        "district": "Iron Mountain Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261941007700",
    },
    {
        "school": "Norway High School",
        "district": "Norway-Vulcan Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262604006257",
    },
    {
        "school": "North Dickinson School",
        "district": "North Dickinson County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263048006704",
    },
    {
        "school": "DickinsonIron Tech Ed Center",
        "district": "Dickinson-Iron ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268036000498",
    },
    {
        "school": "DickinsonIron Special Education",
        "district": "Dickinson-Iron ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268036001336",
    },
    {
        "school": "Grass Lake Middle School",
        "district": "Grass Lake Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261683001648",
    },
    {
        "school": "Ackerson Lake Community Education",
        "district": "Napoleon Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262496001591",
    },
    {
        "school": "Parma Elementary School",
        "district": "Western School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263594000558",
    },
    {
        "school": "Da Vinci Institute 712",
        "district": "Da Vinci Institute",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260008800559",
    },
    {
        "school": "Da Vinci Institute K6",
        "district": "Da Vinci Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260008801118",
    },
    {
        "school": "Paragon Charter Academy",
        "district": "Paragon Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260020401119",
    },
    {
        "school": "Columbia Alternative Education",
        "district": "Columbia School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260699001117",
    },
    {
        "school": "Columbia Elementary School",
        "district": "Columbia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260699004296",
    },
    {
        "school": "Columbia Upper Elementary School",
        "district": "Columbia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260699004297",
    },
    {
        "school": "Columbia Central High School",
        "district": "Columbia School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260699004300",
    },
    {
        "school": "Concord Elementary School",
        "district": "Concord Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261065004537",
    },
    {
        "school": "Concord High School",
        "district": "Concord Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261065004538",
    },
    {
        "school": "Concord Middle School",
        "district": "Concord Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261065004539",
    },
    {
        "school": "East Jackson Elementary",
        "district": "East Jackson Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261254004964",
    },
    {
        "school": "East Jackson Secondary School",
        "district": "East Jackson Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261254004967",
    },
    {
        "school": "George Long Elementary School",
        "district": "Grass Lake Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261683005390",
    },
    {
        "school": "Grass Lake High School",
        "district": "Grass Lake Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261683005391",
    },
    {
        "school": "HanoverHorton Elementary School",
        "district": "Hanover-Horton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261764000153",
    },
    {
        "school": "HanoverHorton Middle School",
        "district": "Hanover-Horton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261764000867",
    },
    {
        "school": "HanoverHorton High School",
        "district": "Hanover-Horton School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261764005429",
    },
    {
        "school": "TA Wilson School",
        "district": "Jackson Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261962000871",
    },
    {
        "school": "Bennett School",
        "district": "Jackson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261962005624",
    },
    {
        "school": "Cascades School",
        "district": "Jackson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261962005625",
    },
    {
        "school": "Frost Elementary School",
        "district": "Jackson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261962005626",
    },
    {
        "school": "Hunt Elementary School",
        "district": "Jackson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261962005628",
    },
    {
        "school": "Jackson High School",
        "district": "Jackson Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261962005629",
    },
    {
        "school": "Middle School at Parkside",
        "district": "Jackson Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261962005631",
    },
    {
        "school": "Sharp Park Academy",
        "district": "Jackson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261962005632",
    },
    {
        "school": "Northeast Elementary School",
        "district": "Jackson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261962005634",
    },
    {
        "school": "Dibble Elementary School",
        "district": "Jackson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261962007459",
    },
    {
        "school": "Arnold Elementary School",
        "district": "Michigan Center School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262379006045",
    },
    {
        "school": "Michigan Center JrSr High School",
        "district": "Michigan Center School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262379006047",
    },
    {
        "school": "Keicher Elementary School",
        "district": "Michigan Center School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262379006049",
    },
    {
        "school": "Ezra Eby Elementary School",
        "district": "Napoleon Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262496006173",
    },
    {
        "school": "Napoleon High School",
        "district": "Napoleon Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262496006174",
    },
    {
        "school": "Napoleon Middle School",
        "district": "Napoleon Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262496006175",
    },
    {
        "school": "Northwest Alternative High School",
        "district": "Northwest Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262601000870",
    },
    {
        "school": "Northwest Kidder Middle School",
        "district": "Northwest Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262601006253",
    },
    {
        "school": "Northwest Early Elementary School",
        "district": "Northwest Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262601006254",
    },
    {
        "school": "Northwest High School",
        "district": "Northwest Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262601006255",
    },
    {
        "school": "Northwest Elementary School",
        "district": "Northwest Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262601006256",
    },
    {
        "school": "Springport Elementary School",
        "district": "Springport Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263261006807",
    },
    {
        "school": "Springport High School",
        "district": "Springport Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263261006808",
    },
    {
        "school": "Springport Middle School",
        "district": "Springport Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263261006809",
    },
    {
        "school": "Townsend Elementary School",
        "district": "Vandercook Lake Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263465007041",
    },
    {
        "school": "Vandercook Lake High School",
        "district": "Vandercook Lake Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263465007043",
    },
    {
        "school": "Bean Elementary School",
        "district": "Western School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263594007197",
    },
    {
        "school": "Warner Elementary School",
        "district": "Western School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263594007199",
    },
    {
        "school": "Western High School",
        "district": "Western School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263594007200",
    },
    {
        "school": "Western Middle School",
        "district": "Western School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263594007201",
    },
    {
        "school": "Woodville Community Center",
        "district": "Western School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263594007587",
    },
    {
        "school": "Lyle A Torrant Center",
        "district": "Jackson ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268058000863",
    },
    {
        "school": "Youth Home Jackson ISD",
        "district": "Jackson ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268058000864",
    },
    {
        "school": "Jackson Area Career Center",
        "district": "Jackson ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268058000865",
    },
    {
        "school": "Barclay Hills Education Center",
        "district": "Parchment School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262742001590",
    },
    {
        "school": "Portage Community High School",
        "district": "Portage Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262895001602",
    },
    {
        "school": "Lawton Accelerated Academic Center",
        "district": "Lawton Community School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262124001915",
    },
    {
        "school": "Cedar Street Community and Family Center",
        "district": "Paw Paw Public School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262766001916",
    },
    {
        "school": "North Shore Elementary",
        "district": "South Haven Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263230001817",
    },
    {
        "school": "Bangor Career Academy",
        "district": "Bangor Public Schools (Van Buren)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260387007447",
    },
    {
        "school": "Pullman Elementary School",
        "district": "Bloomingdale Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260627004250",
    },
    {
        "school": "Baseline Middle School",
        "district": "South Haven Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263230000022",
    },
    {
        "school": "Oakland Academy",
        "district": "Oakland Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260018401062",
    },
    {
        "school": "Paramount Charter Academy",
        "district": "Paramount Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260020601123",
    },
    {
        "school": "ClimaxScotts High School",
        "district": "Climax-Scotts Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261002004485",
    },
    {
        "school": "ClimaxScotts Elementary School",
        "district": "Climax-Scotts Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261002004486",
    },
    {
        "school": "Comstock Compass High School",
        "district": "Comstock Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261059000157",
    },
    {
        "school": "Comstock High School",
        "district": "Comstock Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261059004525",
    },
    {
        "school": "Comstock Elementary School",
        "district": "Comstock Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261059004527",
    },
    {
        "school": "Comstock Middle School",
        "district": "Comstock Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261059004531",
    },
    {
        "school": "GalesburgAugusta Primary School",
        "district": "Galesburg-Augusta Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261545005204",
    },
    {
        "school": "GalesburgAugusta High School",
        "district": "Galesburg-Augusta Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261545005205",
    },
    {
        "school": "GalesburgAugusta Middle School",
        "district": "Galesburg-Augusta Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261545005207",
    },
    {
        "school": "Gull Lake Middle School",
        "district": "Gull Lake Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261725005405",
    },
    {
        "school": "Gull Lake High School",
        "district": "Gull Lake Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261725005406",
    },
    {
        "school": "Kellogg Elementary School",
        "district": "Gull Lake Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261725005407",
    },
    {
        "school": "Richland Elementary School",
        "district": "Gull Lake Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261725005408",
    },
    {
        "school": "Thomas M Ryan  Intermediate School",
        "district": "Gull Lake Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261725005409",
    },
    {
        "school": "Phoenix Alternative High School",
        "district": "Kalamazoo Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261995000047",
    },
    {
        "school": "Kalamazoo Area Math and Science Center",
        "district": "Kalamazoo Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995000156",
    },
    {
        "school": "Transition Services",
        "district": "Kalamazoo Public Schools",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261995000875",
    },
    {
        "school": "Arcadia Elementary School",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005653",
    },
    {
        "school": "Prairie Ridge Elementary School",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005655",
    },
    {
        "school": "Edison Environmental Science Academy",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005656",
    },
    {
        "school": "Greenwood Elementary School",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005657",
    },
    {
        "school": "Hillside Middle School",
        "district": "Kalamazoo Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005658",
    },
    {
        "school": "Indian Prairie Elementary School",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005659",
    },
    {
        "school": "Lincoln International Studies School",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005662",
    },
    {
        "school": "Loy Norrix High School",
        "district": "Kalamazoo Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005663",
    },
    {
        "school": "Milwood Elementary School",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005664",
    },
    {
        "school": "Milwood Magnet School",
        "district": "Kalamazoo Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005665",
    },
    {
        "school": "Northeastern Elementary School",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005666",
    },
    {
        "school": "Northglade Montessori School",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005667",
    },
    {
        "school": "Woods Lake ElementaryA Magnet Center For The Arts",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005669",
    },
    {
        "school": "ParkwoodUpjohn Elementary School",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005670",
    },
    {
        "school": "Maple Street Magnet School for the Arts",
        "district": "Kalamazoo Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005671",
    },
    {
        "school": "Spring Valley Center for Exploration",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005672",
    },
    {
        "school": "Washington Writers Academy",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005673",
    },
    {
        "school": "KingWestwood Elementary School",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005674",
    },
    {
        "school": "Winchell Elementary School",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005675",
    },
    {
        "school": "Woodward School for Technology and Research",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005676",
    },
    {
        "school": "Kalamazoo Central High School",
        "district": "Kalamazoo Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995005677",
    },
    {
        "school": "Parchment High School",
        "district": "Parchment School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262742006342",
    },
    {
        "school": "Parchment Middle School",
        "district": "Parchment School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262742006343",
    },
    {
        "school": "Parchment Northwood Elem School",
        "district": "Parchment School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262742006344",
    },
    {
        "school": "Parchment North Elem School",
        "district": "Parchment School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262742006345",
    },
    {
        "school": "Parchment Central Elem School",
        "district": "Parchment School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262742006348",
    },
    {
        "school": "Moorsbridge Elementary School",
        "district": "Portage Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895000161",
    },
    {
        "school": "Amberly Elementary School",
        "district": "Portage Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895006484",
    },
    {
        "school": "Angling Road Elementary School",
        "district": "Portage Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895006485",
    },
    {
        "school": "Central Elementary School",
        "district": "Portage Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895006486",
    },
    {
        "school": "Haverhill Elementary School",
        "district": "Portage Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895006487",
    },
    {
        "school": "Lake Center Elementary School",
        "district": "Portage Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895006488",
    },
    {
        "school": "Portage Central Middle School",
        "district": "Portage Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895006490",
    },
    {
        "school": "Portage Central High School",
        "district": "Portage Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895006491",
    },
    {
        "school": "Portage North Middle School",
        "district": "Portage Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895006492",
    },
    {
        "school": "Portage Northern High School",
        "district": "Portage Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895006493",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Portage Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895006495",
    },
    {
        "school": "Portage West Middle School",
        "district": "Portage Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895006496",
    },
    {
        "school": "Schoolcraft Elementary School",
        "district": "Schoolcraft Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263102001121",
    },
    {
        "school": "Schoolcraft High School",
        "district": "Schoolcraft Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263102006732",
    },
    {
        "school": "Schoolcraft Middle School",
        "district": "Schoolcraft Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263102006733",
    },
    {
        "school": "Vicksburg Middle School",
        "district": "Vicksburg Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263495007061",
    },
    {
        "school": "Indian Lake Elementary School",
        "district": "Vicksburg Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263495007062",
    },
    {
        "school": "Sunset Lake Elementary School",
        "district": "Vicksburg Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263495007063",
    },
    {
        "school": "Tobey Elementary School",
        "district": "Vicksburg Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263495007064",
    },
    {
        "school": "Vicksburg High School",
        "district": "Vicksburg Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263495007065",
    },
    {
        "school": "Valley Center School",
        "district": "Kalamazoo RESA",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268060000873",
    },
    {
        "school": "Youth Center School",
        "district": "Kalamazoo RESA",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268060000874",
    },
    {
        "school": "South Walnut Elementary School",
        "district": "Bangor Public Schools (Van Buren)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260387000730",
    },
    {
        "school": "Bangor High School",
        "district": "Bangor Public Schools (Van Buren)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260387004072",
    },
    {
        "school": "Bangor Middle School",
        "district": "Bangor Public Schools (Van Buren)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260387004073",
    },
    {
        "school": "Wood School  Bangor Twp 8",
        "district": "Bangor Township S/D #8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260396004083",
    },
    {
        "school": "Bloomingdale Middle and High School",
        "district": "Bloomingdale Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260627004247",
    },
    {
        "school": "Bloomingdale Elementary School",
        "district": "Bloomingdale Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260627004248",
    },
    {
        "school": "Covert Elementary School",
        "district": "Covert Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261098004555",
    },
    {
        "school": "Covert High School",
        "district": "Covert Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261098004556",
    },
    {
        "school": "Covert Middle School",
        "district": "Covert Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261098007452",
    },
    {
        "school": "Decatur Jr Sr High School",
        "district": "Decatur Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261167004624",
    },
    {
        "school": "Davis Elementary School",
        "district": "Decatur Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261167004625",
    },
    {
        "school": "Gobles Elementary School",
        "district": "Gobles Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261605005255",
    },
    {
        "school": "Gobles High School",
        "district": "Gobles Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261605005256",
    },
    {
        "school": "Hartford High School",
        "district": "Hartford Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261788005453",
    },
    {
        "school": "Hartford Middle School",
        "district": "Hartford Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261788005456",
    },
    {
        "school": "Lawrence Elementary School",
        "district": "Lawrence Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262121005844",
    },
    {
        "school": "Lawrence JrSr High School",
        "district": "Lawrence Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262121005845",
    },
    {
        "school": "Lawton Elementary School",
        "district": "Lawton Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262124005846",
    },
    {
        "school": "Lawton High School",
        "district": "Lawton Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262124005847",
    },
    {
        "school": "Lawton Middle School",
        "district": "Lawton Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262124005848",
    },
    {
        "school": "Mattawan Early Elem School",
        "district": "Mattawan Consolidated School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262325006010",
    },
    {
        "school": "Mattawan High School",
        "district": "Mattawan Consolidated School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262325006011",
    },
    {
        "school": "Mattawan Middle School",
        "district": "Mattawan Consolidated School",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262325006012",
    },
    {
        "school": "Mattawan Later Elem School",
        "district": "Mattawan Consolidated School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262325007706",
    },
    {
        "school": "Paw Paw Later Elementary",
        "district": "Paw Paw Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262766001315",
    },
    {
        "school": "Paw Paw Early Elementary School",
        "district": "Paw Paw Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262766006349",
    },
    {
        "school": "Paw Paw Middle School",
        "district": "Paw Paw Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262766006351",
    },
    {
        "school": "Paw Paw High School",
        "district": "Paw Paw Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262766006352",
    },
    {
        "school": "Lincoln School",
        "district": "South Haven Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263230006768",
    },
    {
        "school": "Maple Grove Elementary School",
        "district": "South Haven Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263230006769",
    },
    {
        "school": "South Haven High School",
        "district": "South Haven Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263230006770",
    },
    {
        "school": "Van Buren Tech",
        "district": "Van Buren ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268098500728",
    },
    {
        "school": "Bert Goens Learning Center",
        "district": "Van Buren ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268098500729",
    },
    {
        "school": "Maple Valley Pathways High School",
        "district": "Maple Valley Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262262001595",
    },
    {
        "school": "Wilson Center",
        "district": "St. Johns Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263282001813",
    },
    {
        "school": "Greyhound Central Performance Academy",
        "district": "Eaton Rapids Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261269001856",
    },
    {
        "school": "Eaton RESA  Meadowview Offsite",
        "district": "Eaton RESA",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268038001521",
    },
    {
        "school": "Holt Junior High School",
        "district": "Holt Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261848001651",
    },
    {
        "school": "Riddle Elementary",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115001866",
    },
    {
        "school": "Okemos Public MontessoriCentral",
        "district": "Okemos Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262628001681",
    },
    {
        "school": "Heritage School",
        "district": "Stockbridge Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263303001542",
    },
    {
        "school": "Fuller Street Elementary School",
        "district": "Maple Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262262005968",
    },
    {
        "school": "Bath High School",
        "district": "Bath Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260417004090",
    },
    {
        "school": "Bath Elementary School",
        "district": "Bath Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260417004091",
    },
    {
        "school": "Bath Middle School",
        "district": "Bath Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260417004092",
    },
    {
        "school": "Herbison Woods Elementary School",
        "district": "DeWitt Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261155001226",
    },
    {
        "school": "DeWitt High School",
        "district": "DeWitt Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261155004582",
    },
    {
        "school": "David Scott Elementary School",
        "district": "DeWitt Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261155004583",
    },
    {
        "school": "DeWitt Middle School",
        "district": "DeWitt Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261155004584",
    },
    {
        "school": "Schavey Road Elementary School",
        "district": "DeWitt Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261155007518",
    },
    {
        "school": "Waldron Elementary and Middle School",
        "district": "Fowler Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261470005167",
    },
    {
        "school": "Fowler High School",
        "district": "Fowler Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261470005168",
    },
    {
        "school": "Wacousta Elementary School",
        "district": "Grand Ledge Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261641005296",
    },
    {
        "school": "OvidElsie Comm EdAlt HS",
        "district": "Ovid-Elsie Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262715000820",
    },
    {
        "school": "EE Knight Elementary School",
        "district": "Ovid-Elsie Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262715006320",
    },
    {
        "school": "OvidElsie Middle School",
        "district": "Ovid-Elsie Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262715006323",
    },
    {
        "school": "OvidElsie High School",
        "district": "Ovid-Elsie Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262715006325",
    },
    {
        "school": "PewamoWestphalia MiddleHigh School",
        "district": "Pewamo-Westphalia Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262796006378",
    },
    {
        "school": "Eureka School",
        "district": "St. Johns Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263282006823",
    },
    {
        "school": "Gateway Elementary School",
        "district": "St. Johns Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263282006824",
    },
    {
        "school": "St Johns Middle School",
        "district": "St. Johns Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263282006825",
    },
    {
        "school": "Oakview Elementary School",
        "district": "St. Johns Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263282006826",
    },
    {
        "school": "St Johns High School",
        "district": "St. Johns Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263282006827",
    },
    {
        "school": "Riley Elementary School",
        "district": "St. Johns Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263282006829",
    },
    {
        "school": "Clinton County Education Center",
        "district": "Clinton County RESA",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268032000125",
    },
    {
        "school": "Island City Academy",
        "district": "Island City Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260007300501",
    },
    {
        "school": "Bellevue Elementary School",
        "district": "Bellevue Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260465004149",
    },
    {
        "school": "Bellevue JrSr High School",
        "district": "Bellevue Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260465004150",
    },
    {
        "school": "Charlotte Senior High School",
        "district": "Charlotte Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260877004422",
    },
    {
        "school": "Charlotte Middle School",
        "district": "Charlotte Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260877004423",
    },
    {
        "school": "Washington Elementary School",
        "district": "Charlotte Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260877004426",
    },
    {
        "school": "Parkview Elementary School",
        "district": "Charlotte Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260877004427",
    },
    {
        "school": "Greyhound Intermediate School",
        "district": "Eaton Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261269000824",
    },
    {
        "school": "Eaton Rapids High School",
        "district": "Eaton Rapids Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261269004981",
    },
    {
        "school": "Lockwood Elementary School",
        "district": "Eaton Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261269004984",
    },
    {
        "school": "Eaton Rapids Middle School",
        "district": "Eaton Rapids Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261269004985",
    },
    {
        "school": "Willow Ridge Elementary School",
        "district": "Grand Ledge Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261641000500",
    },
    {
        "school": "Delta Center Elementary School",
        "district": "Grand Ledge Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261641005291",
    },
    {
        "school": "Grand Ledge High School",
        "district": "Grand Ledge Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261641005293",
    },
    {
        "school": "Leon W Hayes Middle School",
        "district": "Grand Ledge Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261641005297",
    },
    {
        "school": "Dimondale Elementary School",
        "district": "Holt Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261848005527",
    },
    {
        "school": "Maple Valley JrSr High School",
        "district": "Maple Valley Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262262005970",
    },
    {
        "school": "Olivet High School",
        "district": "Olivet Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262637006285",
    },
    {
        "school": "Olivet Middle School",
        "district": "Olivet Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262637006286",
    },
    {
        "school": "Fern Persons Elementary School",
        "district": "Olivet Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262637007433",
    },
    {
        "school": "Strange School",
        "district": "Oneida Township S/D #3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262643006291",
    },
    {
        "school": "Potterville Middle School",
        "district": "Potterville Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262916001304",
    },
    {
        "school": "Potterville Elementary School",
        "district": "Potterville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262916006503",
    },
    {
        "school": "Potterville High School",
        "district": "Potterville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262916006504",
    },
    {
        "school": "Waverly Senior High School",
        "district": "Waverly Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263552007160",
    },
    {
        "school": "Winans Elementary School",
        "district": "Waverly Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263552007161",
    },
    {
        "school": "Elmwood Elementary School",
        "district": "Waverly Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263552007163",
    },
    {
        "school": "Waverly Middle School",
        "district": "Waverly Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263552007164",
    },
    {
        "school": "Eaton RESA  Meadowview Onsite",
        "district": "Eaton RESA",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268038001337",
    },
    {
        "school": "Cole Academy",
        "district": "Cole Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260007900543",
    },
    {
        "school": "MidMichigan Leadership Academy",
        "district": "Mid-Michigan Leadership Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260008200546",
    },
    {
        "school": "White Pine Academy",
        "district": "White Pine Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260020001111",
    },
    {
        "school": "Windemere Park Charter Academy",
        "district": "Windemere Park Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260020301114",
    },
    {
        "school": "Dansville Elementary School",
        "district": "Dansville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261140004571",
    },
    {
        "school": "Dansville High School",
        "district": "Dansville Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261140004572",
    },
    {
        "school": "Dansville Middle School",
        "district": "Dansville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261140004573",
    },
    {
        "school": "East Lansing High School",
        "district": "East Lansing School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261260004971",
    },
    {
        "school": "Glencairn School",
        "district": "East Lansing School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261260004972",
    },
    {
        "school": "Pinecrest School",
        "district": "East Lansing School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261260004973",
    },
    {
        "school": "Whitehills Elementary School",
        "district": "East Lansing School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261260004976",
    },
    {
        "school": "Marble School",
        "district": "East Lansing School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261260004977",
    },
    {
        "school": "Donley Elementary School",
        "district": "East Lansing School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261260004978",
    },
    {
        "school": "MacDonald Middle School",
        "district": "East Lansing School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261260004979",
    },
    {
        "school": "Murphy Elementary School",
        "district": "Haslett Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261794005463",
    },
    {
        "school": "Haslett Middle School",
        "district": "Haslett Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261794005464",
    },
    {
        "school": "Vera Ralya Elementary School",
        "district": "Haslett Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261794005465",
    },
    {
        "school": "Wilkshire School",
        "district": "Haslett Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261794005466",
    },
    {
        "school": "Haslett High School",
        "district": "Haslett Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261794005467",
    },
    {
        "school": "Horizon Elementary School",
        "district": "Holt Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261848000092",
    },
    {
        "school": "Washington Woods Middle School",
        "district": "Holt Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261848000095",
    },
    {
        "school": "Elliott Elementary School",
        "district": "Holt Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261848005528",
    },
    {
        "school": "Holt Senior High School",
        "district": "Holt Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261848005530",
    },
    {
        "school": "Sycamore Elementary School",
        "district": "Holt Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261848005532",
    },
    {
        "school": "Wilcox Elementary School",
        "district": "Holt Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261848005533",
    },
    {
        "school": "Hope Middle School",
        "district": "Holt Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261848005534",
    },
    {
        "school": "Beekman Center",
        "district": "Lansing Public School District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262115000043",
    },
    {
        "school": "Cavanaugh School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005789",
    },
    {
        "school": "Cumberland School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005791",
    },
    {
        "school": "Eastern High School",
        "district": "Lansing Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005792",
    },
    {
        "school": "Everett High School",
        "district": "Lansing Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005794",
    },
    {
        "school": "Forest View School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005796",
    },
    {
        "school": "Forrest G Averill School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005797",
    },
    {
        "school": "Gier Park School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005798",
    },
    {
        "school": "JW Sexton High School",
        "district": "Lansing Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005803",
    },
    {
        "school": "Kendon School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005804",
    },
    {
        "school": "Lyons School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005806",
    },
    {
        "school": "Post Oak School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005813",
    },
    {
        "school": "Reo School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005814",
    },
    {
        "school": "Willow School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005820",
    },
    {
        "school": "Wexford Montessori Magnet School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005821",
    },
    {
        "school": "North School",
        "district": "Lansing Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115005828",
    },
    {
        "school": "Leslie Middle School",
        "district": "Leslie Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262145005851",
    },
    {
        "school": "Leslie High School",
        "district": "Leslie Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262145005852",
    },
    {
        "school": "Woodworth Elementary School",
        "district": "Leslie Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262145005853",
    },
    {
        "school": "Alaiedon Elementary School",
        "district": "Mason Public Schools (Ingham)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262307005992",
    },
    {
        "school": "Mason High School",
        "district": "Mason Public Schools (Ingham)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262307005994",
    },
    {
        "school": "North Aurelius Elementary School",
        "district": "Mason Public Schools (Ingham)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262307005995",
    },
    {
        "school": "Steele Street Elementary School",
        "district": "Mason Public Schools (Ingham)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262307005996",
    },
    {
        "school": "Mason Middle School",
        "district": "Mason Public Schools (Ingham)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262307005997",
    },
    {
        "school": "Bennett Woods Elementary School",
        "district": "Okemos Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262628000541",
    },
    {
        "school": "Chippewa Middle School",
        "district": "Okemos Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262628000542",
    },
    {
        "school": "Cornell Elementary School",
        "district": "Okemos Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262628006280",
    },
    {
        "school": "Okemos High School",
        "district": "Okemos Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262628006282",
    },
    {
        "school": "Kinawa School",
        "district": "Okemos Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262628006284",
    },
    {
        "school": "Hiawatha Elementary School",
        "district": "Okemos Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262628007563",
    },
    {
        "school": "Emma Smith Elementary School",
        "district": "Stockbridge Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263303006855",
    },
    {
        "school": "Stockbridge JrSr High School",
        "district": "Stockbridge Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263303006858",
    },
    {
        "school": "East Intermediate School",
        "district": "Waverly Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263552000088",
    },
    {
        "school": "Meryl S Colt Elementary School",
        "district": "Waverly Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263552007158",
    },
    {
        "school": "Webberville Elementary School",
        "district": "Webberville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263573007172",
    },
    {
        "school": "Webberville High School",
        "district": "Webberville Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263573007173",
    },
    {
        "school": "Williamston Discovery Elementary School",
        "district": "Williamston Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263642001058",
    },
    {
        "school": "Williamston Middle School",
        "district": "Williamston Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263642007227",
    },
    {
        "school": "Williamston Explorer Elementary School",
        "district": "Williamston Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263642007228",
    },
    {
        "school": "Williamston High School",
        "district": "Williamston Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263642007718",
    },
    {
        "school": "Wilson Talent Center",
        "district": "Ingham ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268052000534",
    },
    {
        "school": "Heartwood School",
        "district": "Ingham ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268052000535",
    },
    {
        "school": "Malcolm Williams School",
        "district": "Ingham ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268052000536",
    },
    {
        "school": "SLCEvergreen",
        "district": "Ingham ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268052000849",
    },
    {
        "school": "St Vincent Home",
        "district": "Ingham ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268052001110",
    },
    {
        "school": "PewamoWestphalia Elementary School",
        "district": "Pewamo-Westphalia Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262796006376",
    },
    {
        "school": "Leonard Elementary School",
        "district": "Ovid-Elsie Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262715006324",
    },
    {
        "school": "Central Elementary School",
        "district": "Menominee Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262355001774",
    },
    {
        "school": "Blesch Intermediate School",
        "district": "Menominee Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262355001775",
    },
    {
        "school": "Nah Tah Wahsh Public School Academy",
        "district": "Nah Tah Wahsh Public School Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260010300646",
    },
    {
        "school": "Bark RiverHarris JrSr High School",
        "district": "Bark River-Harris School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260402004088",
    },
    {
        "school": "Bark RiverHarris Elementary School",
        "district": "Bark River-Harris School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260402004089",
    },
    {
        "school": "CarneyNadeau Public School",
        "district": "Carney-Nadeau Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260801004374",
    },
    {
        "school": "Menominee Jr High School",
        "district": "Menominee Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262355006031",
    },
    {
        "school": "Menominee High School",
        "district": "Menominee Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262355006032",
    },
    {
        "school": "North Central Elementary School",
        "district": "North Central Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262922000645",
    },
    {
        "school": "North Central Area Senior High School",
        "district": "North Central Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262922006506",
    },
    {
        "school": "Stephenson MiddleHigh School",
        "district": "Stephenson Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263300006852",
    },
    {
        "school": "Stephenson Elementary School",
        "district": "Stephenson Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263300006853",
    },
    {
        "school": "Menominee ISD Special Education",
        "district": "Menominee ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268079001386",
    },
    {
        "school": "Vandenboom Alternative High School",
        "district": "Marquette Area Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260001301885",
    },
    {
        "school": "Cherry Creek Elementary School",
        "district": "Marquette Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001300209",
    },
    {
        "school": "Superior Hills Elementary School",
        "district": "Marquette Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001303867",
    },
    {
        "school": "Marquette Senior High School",
        "district": "Marquette Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001303869",
    },
    {
        "school": "Sandy Knoll School",
        "district": "Marquette Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001303871",
    },
    {
        "school": "Bothwell Middle School",
        "district": "Marquette Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001303875",
    },
    {
        "school": "North Star Academy",
        "district": "North Star Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260015300934",
    },
    {
        "school": "Gwinn MiddleHigh School",
        "district": "Gwinn Area Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261469005162",
    },
    {
        "school": "KI Sawyer Elementary School",
        "district": "Gwinn Area Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261469005163",
    },
    {
        "school": "Birchview School",
        "district": "Ishpeming Public School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261953005616",
    },
    {
        "school": "Ishpeming Middle School",
        "district": "Ishpeming Public School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261953005617",
    },
    {
        "school": "Ishpeming High School",
        "district": "Ishpeming Public School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261953005619",
    },
    {
        "school": "Negaunee Middle School",
        "district": "Negaunee Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262502006177",
    },
    {
        "school": "Lakeview School",
        "district": "Negaunee Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262502006178",
    },
    {
        "school": "Negaunee High School",
        "district": "Negaunee Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262502006179",
    },
    {
        "school": "Aspen Ridge Elementary School",
        "district": "NICE Community School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262540000932",
    },
    {
        "school": "Westwood High School",
        "district": "NICE Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262540006202",
    },
    {
        "school": "Powell Twp Elementary School",
        "district": "Powell Township Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262919006505",
    },
    {
        "school": "RepublicMichigamme School",
        "district": "Republic-Michigamme Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262958006548",
    },
    {
        "school": "Wells Township School",
        "district": "Wells Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263579007174",
    },
    {
        "school": "MarquetteAlger Administrative Unit",
        "district": "Marquette-Alger RESA",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268075001382",
    },
    {
        "school": "Windover High School",
        "district": "Windover High School",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260002000213",
    },
    {
        "school": "Bullock Creek High School",
        "district": "Bullock Creek School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260732004320",
    },
    {
        "school": "Bullock Creek Elementary School",
        "district": "Bullock Creek School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260732004321",
    },
    {
        "school": "Floyd School",
        "district": "Bullock Creek School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260732004322",
    },
    {
        "school": "Pine River Elementary School",
        "district": "Bullock Creek School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260732004323",
    },
    {
        "school": "Bullock Creek Middle School",
        "district": "Bullock Creek School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260732004325",
    },
    {
        "school": "Coleman Elementary School",
        "district": "Coleman Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261020004510",
    },
    {
        "school": "Coleman JuniorSenior High School",
        "district": "Coleman Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261020004511",
    },
    {
        "school": "Meridian Elementary School",
        "district": "Meridian Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262358006035",
    },
    {
        "school": "Meridian Junior High School",
        "district": "Meridian Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262358006036",
    },
    {
        "school": "Adams Elementary School",
        "district": "Midland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262382006050",
    },
    {
        "school": "Chestnut Hill School",
        "district": "Midland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262382006053",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Midland Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262382006057",
    },
    {
        "school": "Midland High School",
        "district": "Midland Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262382006060",
    },
    {
        "school": "Northeast Middle School",
        "district": "Midland Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262382006062",
    },
    {
        "school": "Plymouth Elementary School",
        "district": "Midland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262382006064",
    },
    {
        "school": "Siebert School",
        "district": "Midland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262382006065",
    },
    {
        "school": "HH Dow High School",
        "district": "Midland Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262382006068",
    },
    {
        "school": "Woodcrest Elementary School",
        "district": "Midland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262382006069",
    },
    {
        "school": "MCESA and Sugnet School Classroom Programs",
        "district": "Midland County Educational Service Agency",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268080001387",
    },
    {
        "school": "Triumph Academy",
        "district": "Triumph Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260031101760",
    },
    {
        "school": "Monroe County Transition Center",
        "district": "Monroe ISD",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268082001621",
    },
    {
        "school": "New Bedford Academy",
        "district": "New Bedford Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021301149",
    },
    {
        "school": "Airport Senior High School",
        "district": "Airport Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260198003939",
    },
    {
        "school": "Fred W Ritter Elementary School",
        "district": "Airport Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260198003940",
    },
    {
        "school": "Loren Eyler Elementary School",
        "district": "Airport Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260198003942",
    },
    {
        "school": "Joseph C Sterling Elem School",
        "district": "Airport Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260198003943",
    },
    {
        "school": "Wagar 78 Middle School",
        "district": "Airport Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260198003944",
    },
    {
        "school": "Monroe Road Elementary School",
        "district": "Bedford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260447001388",
    },
    {
        "school": "Bedford Senior High School",
        "district": "Bedford Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260447004128",
    },
    {
        "school": "Douglas Road Elementary School",
        "district": "Bedford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260447004129",
    },
    {
        "school": "Jackman Road Elementary School",
        "district": "Bedford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260447004130",
    },
    {
        "school": "Bedford Junior High School",
        "district": "Bedford Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260447004132",
    },
    {
        "school": "Riverside Academy",
        "district": "Dundee Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261230001389",
    },
    {
        "school": "Dundee Elementary School",
        "district": "Dundee Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261230004928",
    },
    {
        "school": "Dundee Community High School",
        "district": "Dundee Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261230004929",
    },
    {
        "school": "Dundee Middle School",
        "district": "Dundee Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261230004930",
    },
    {
        "school": "Ida Elementary School",
        "district": "Ida Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261905005586",
    },
    {
        "school": "Ida High School",
        "district": "Ida Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261905005587",
    },
    {
        "school": "Ida Middle School",
        "district": "Ida Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261905005588",
    },
    {
        "school": "Sodt Elementary School",
        "district": "Jefferson Schools (Monroe)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261980005635",
    },
    {
        "school": "Jefferson High School",
        "district": "Jefferson Schools (Monroe)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261980005636",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Jefferson Schools (Monroe)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261980005637",
    },
    {
        "school": "North Elementary School",
        "district": "Jefferson Schools (Monroe)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261980007740",
    },
    {
        "school": "Mason Central School",
        "district": "Mason Consolidated Schools (Monroe)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262310005998",
    },
    {
        "school": "Mason Middle School",
        "district": "Mason Consolidated Schools (Monroe)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262310005999",
    },
    {
        "school": "Mason Senior High School",
        "district": "Mason Consolidated Schools (Monroe)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262310006001",
    },
    {
        "school": "Orchard Center High School",
        "district": "Monroe Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262415000652",
    },
    {
        "school": "Custer Elementary School",
        "district": "Monroe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262415006090",
    },
    {
        "school": "Arborwood Elementary School",
        "district": "Monroe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262415006091",
    },
    {
        "school": "Manor Elementary School",
        "district": "Monroe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262415006093",
    },
    {
        "school": "Monroe Middle School",
        "district": "Monroe Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262415006094",
    },
    {
        "school": "Raisinville School",
        "district": "Monroe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262415006095",
    },
    {
        "school": "Waterloo Elementary School",
        "district": "Monroe Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262415006098",
    },
    {
        "school": "Monroe High School",
        "district": "Monroe Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262415006099",
    },
    {
        "school": "Summerfield JuniorSenior High School",
        "district": "Summerfield Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263312006868",
    },
    {
        "school": "Summerfield Elementary School",
        "district": "Summerfield Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263312006870",
    },
    {
        "school": "Whiteford High School",
        "district": "Whiteford Agricultural School District of the Counties of Le",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263627007215",
    },
    {
        "school": "Whiteford Elementary School",
        "district": "Whiteford Agricultural School District of the Counties of Le",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263627007216",
    },
    {
        "school": "Whiteford Middle School",
        "district": "Whiteford Agricultural School District of the Counties of Le",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263627007441",
    },
    {
        "school": "Monroe County Education Center",
        "district": "Monroe ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268082000651",
    },
    {
        "school": "Monroe County Youth Center",
        "district": "Monroe ISD",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268082000941",
    },
    {
        "school": "Mt Pleasant Community Education",
        "district": "Mt. Pleasant City School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262475001600",
    },
    {
        "school": "Renaissance Public School Academy",
        "district": "Renaissance Public School Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260008700557",
    },
    {
        "school": "Beal City Elementary School",
        "district": "Beal City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260429004117",
    },
    {
        "school": "Beal City High School",
        "district": "Beal City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260429007510",
    },
    {
        "school": "Kinney School",
        "district": "Mt. Pleasant City School District",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262475000062",
    },
    {
        "school": "Fancher School",
        "district": "Mt. Pleasant City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262475006130",
    },
    {
        "school": "Ganiard School",
        "district": "Mt. Pleasant City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262475006131",
    },
    {
        "school": "Mary McGuire School",
        "district": "Mt. Pleasant City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262475006133",
    },
    {
        "school": "Mt Pleasant Middle School",
        "district": "Mt. Pleasant City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262475006134",
    },
    {
        "school": "Mt Pleasant Senior High School",
        "district": "Mt. Pleasant City School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262475006135",
    },
    {
        "school": "Pullen Elementary School",
        "district": "Mt. Pleasant City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262475006136",
    },
    {
        "school": "Vowles School",
        "district": "Mt. Pleasant City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262475006138",
    },
    {
        "school": "WAY  Oasis",
        "district": "Mt. Pleasant City School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262475007729",
    },
    {
        "school": "Odyssey MiddleHigh School",
        "district": "Shepherd Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263138000151",
    },
    {
        "school": "Shepherd  Elementary School",
        "district": "Shepherd Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263138006740",
    },
    {
        "school": "Shepherd  High School",
        "district": "Shepherd Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263138006741",
    },
    {
        "school": "Winn Elementary School",
        "district": "Shepherd Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263138006743",
    },
    {
        "school": "Shepherd Middle School",
        "district": "Shepherd Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263138007436",
    },
    {
        "school": "Three Oaks Public School Academy",
        "district": "Three Oaks Public School Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260028801653",
    },
    {
        "school": "Fruitport Alternative High School",
        "district": "Fruitport Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261539001794",
    },
    {
        "school": "Orchard View Community Education",
        "district": "Orchard View Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262676001893",
    },
    {
        "school": "White Lake Area Community Education",
        "district": "Whitehall District Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263630001894",
    },
    {
        "school": "Timberland Academy",
        "district": "Timberland Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021401153",
    },
    {
        "school": "Edgewood Elementary School",
        "district": "Fruitport Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261539005198",
    },
    {
        "school": "Fruitport High School",
        "district": "Fruitport Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261539005199",
    },
    {
        "school": "Fruitport Middle School",
        "district": "Fruitport Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261539005200",
    },
    {
        "school": "Shettler School",
        "district": "Fruitport Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261539005201",
    },
    {
        "school": "Beach Elementary School",
        "district": "Fruitport Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261539007455",
    },
    {
        "school": "Holton Middle School",
        "district": "Holton Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261851001393",
    },
    {
        "school": "Holton Elementary School",
        "district": "Holton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261851005535",
    },
    {
        "school": "Holton High School",
        "district": "Holton Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261851005536",
    },
    {
        "school": "Campbell Elementary School",
        "district": "Mona Shores Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262412006081",
    },
    {
        "school": "Churchill Elementary School",
        "district": "Mona Shores Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262412006082",
    },
    {
        "school": "Ross Park Elementary School",
        "district": "Mona Shores Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262412006083",
    },
    {
        "school": "Lincoln Park Elementary School",
        "district": "Mona Shores Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262412006084",
    },
    {
        "school": "Mona Shores High School",
        "district": "Mona Shores Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262412006085",
    },
    {
        "school": "Mona Shores Middle School",
        "district": "Mona Shores Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262412006086",
    },
    {
        "school": "Montague High School",
        "district": "Montague Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262418006100",
    },
    {
        "school": "Nellie B Chisholm Middle School",
        "district": "Montague Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262418006101",
    },
    {
        "school": "Oehrli Elementary School",
        "district": "Montague Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262418006102",
    },
    {
        "school": "Marquette Elementary School",
        "district": "Muskegon Public Schools of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262484006148",
    },
    {
        "school": "Moon Elementary School",
        "district": "Muskegon Public Schools of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262484006151",
    },
    {
        "school": "Muskegon High School",
        "district": "Muskegon Public Schools of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262484006152",
    },
    {
        "school": "Nelson Elementary School",
        "district": "Muskegon Public Schools of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262484006153",
    },
    {
        "school": "Oakview Elementary School",
        "district": "Muskegon Public Schools of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262484006155",
    },
    {
        "school": "North Muskegon Middle School",
        "district": "North Muskegon Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262580001152",
    },
    {
        "school": "North Muskegon High School",
        "district": "North Muskegon Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262580006235",
    },
    {
        "school": "North Muskegon Elementary School",
        "district": "North Muskegon Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262580006236",
    },
    {
        "school": "Oakridge Upper Elementary School",
        "district": "Oakridge Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262622006275",
    },
    {
        "school": "Oakridge High School",
        "district": "Oakridge Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262622006276",
    },
    {
        "school": "Oakridge Middle School",
        "district": "Oakridge Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262622006277",
    },
    {
        "school": "Oakridge Lower Elementary School",
        "district": "Oakridge Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262622006278",
    },
    {
        "school": "Orchard View Middle School",
        "district": "Orchard View Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262676006303",
    },
    {
        "school": "Orchard View High School",
        "district": "Orchard View Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262676006304",
    },
    {
        "school": "Orchard View Early Elementary",
        "district": "Orchard View Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262676007564",
    },
    {
        "school": "Beechnau Elementary School",
        "district": "Ravenna Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262937006515",
    },
    {
        "school": "Ravenna High School",
        "district": "Ravenna Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262937006516",
    },
    {
        "school": "Ravenna Middle School",
        "district": "Ravenna Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262937006517",
    },
    {
        "school": "ReethsPuffer Intermediate Sch",
        "district": "Reeths-Puffer Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262954001076",
    },
    {
        "school": "Central Elementary School",
        "district": "Reeths-Puffer Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262954006539",
    },
    {
        "school": "ReethsPuffer Middle School",
        "district": "Reeths-Puffer Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262954006540",
    },
    {
        "school": "ReethsPuffer Elementary School",
        "district": "Reeths-Puffer Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262954006543",
    },
    {
        "school": "ReethsPuffer High School",
        "district": "Reeths-Puffer Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262954006544",
    },
    {
        "school": "Twin Lake School",
        "district": "Reeths-Puffer Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262954006545",
    },
    {
        "school": "Shoreline Elementary School",
        "district": "Whitehall District Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263630000230",
    },
    {
        "school": "Whitehall Ealy Elem School",
        "district": "Whitehall District Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263630007217",
    },
    {
        "school": "Whitehall Middle School",
        "district": "Whitehall District Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263630007218",
    },
    {
        "school": "Whitehall Senior High School",
        "district": "Whitehall District Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263630007219",
    },
    {
        "school": "Wesley School",
        "district": "Muskegon Area ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268085000656",
    },
    {
        "school": "Countryside Academy  Elementary",
        "district": "Countryside Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260014201700",
    },
    {
        "school": "Mildred C Wells Preparatory Academy",
        "district": "Mildred C. Wells Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260029701848",
    },
    {
        "school": "Berrien Springs Discovery Academy",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543001563",
    },
    {
        "school": "Countryside Academy  MiddleHigh School",
        "district": "Countryside Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260014200804",
    },
    {
        "school": "Benton Harbor Charter School Academy",
        "district": "Benton Harbor Charter School Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260019101099",
    },
    {
        "school": "Benton Harbor High School",
        "district": "Benton Harbor Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260483004162",
    },
    {
        "school": "Fair Plain East Elementary",
        "district": "Benton Harbor Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260483004170",
    },
    {
        "school": "Arts  Communications Academy at Fair Plain",
        "district": "Benton Harbor Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260483004173",
    },
    {
        "school": "International Academy at Hull",
        "district": "Benton Harbor Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260483004175",
    },
    {
        "school": "Berrien Springs Middle School",
        "district": "Berrien Springs Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260543004198",
    },
    {
        "school": "Berrien Springs High School",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260543004199",
    },
    {
        "school": "Mars Elementary School",
        "district": "Berrien Springs Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260543004200",
    },
    {
        "school": "Sylvester Elementary School",
        "district": "Berrien Springs Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260543004201",
    },
    {
        "school": "Brandywine Innovation Academy",
        "district": "Brandywine Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260660000469",
    },
    {
        "school": "Merritt Elementary School",
        "district": "Brandywine Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260660000470",
    },
    {
        "school": "Brandywine Middle School",
        "district": "Brandywine Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260660001329",
    },
    {
        "school": "Brandywine Elementary School",
        "district": "Brandywine Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260660004261",
    },
    {
        "school": "Brandywine Senior High School",
        "district": "Brandywine Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260660004262",
    },
    {
        "school": "Bridgman Elementary School",
        "district": "Bridgman Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260684004280",
    },
    {
        "school": "Bridgman High School",
        "district": "Bridgman Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260684004281",
    },
    {
        "school": "FC Reed Middle School",
        "district": "Bridgman Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260684004282",
    },
    {
        "school": "Buchanan High School",
        "district": "Buchanan Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260714004308",
    },
    {
        "school": "Moccasin Elementary School",
        "district": "Buchanan Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260714004310",
    },
    {
        "school": "Ottawa Elementary School",
        "district": "Buchanan Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260714004311",
    },
    {
        "school": "Buchanan Middle School",
        "district": "Buchanan Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260714004312",
    },
    {
        "school": "Coloma Elementary School",
        "district": "Coloma Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261038004514",
    },
    {
        "school": "Coloma High School",
        "district": "Coloma Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261038004515",
    },
    {
        "school": "Coloma Junior High School",
        "district": "Coloma Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261038004516",
    },
    {
        "school": "Coloma Intermediate School",
        "district": "Coloma Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261038004518",
    },
    {
        "school": "Eau Claire High School",
        "district": "Eau Claire Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261281004986",
    },
    {
        "school": "Lybrook Elementary School",
        "district": "Eau Claire Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261281004987",
    },
    {
        "school": "Riverside School",
        "district": "Hagar Township S/D #6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261734005411",
    },
    {
        "school": "Hollywood Elementary School",
        "district": "Lakeshore School District (Berrien)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262082005744",
    },
    {
        "school": "Lakeshore High School",
        "district": "Lakeshore School District (Berrien)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262082005745",
    },
    {
        "school": "Lakeshore Middle School",
        "district": "Lakeshore School District (Berrien)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262082005746",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Lakeshore School District (Berrien)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262082005747",
    },
    {
        "school": "Stewart Elementary School",
        "district": "Lakeshore School District (Berrien)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262082005748",
    },
    {
        "school": "New Buffalo Middle School",
        "district": "New Buffalo Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262514000803",
    },
    {
        "school": "New Buffalo Senior High School",
        "district": "New Buffalo Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262514006181",
    },
    {
        "school": "New Buffalo Elementary School",
        "district": "New Buffalo Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262514006182",
    },
    {
        "school": "Niles Cedar Lane",
        "district": "Niles Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262556000116",
    },
    {
        "school": "Ballard Elementary School",
        "district": "Niles Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262556006203",
    },
    {
        "school": "Niles Senior High School",
        "district": "Niles Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262556006206",
    },
    {
        "school": "Ring Lardner Middle School",
        "district": "Niles Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262556006208",
    },
    {
        "school": "Southside Special Educ School",
        "district": "Niles Community Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262556006209",
    },
    {
        "school": "Northside Child Development Center",
        "district": "Niles Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262556007431",
    },
    {
        "school": "Chikaming Elementary School",
        "district": "River Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262979006557",
    },
    {
        "school": "River Valley MiddleHigh School",
        "district": "River Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262979006559",
    },
    {
        "school": "Three Oaks Elementary School",
        "district": "River Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262979006560",
    },
    {
        "school": "River School",
        "district": "Sodus Township S/D #5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263207006746",
    },
    {
        "school": "Brown School",
        "district": "St. Joseph Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263285006830",
    },
    {
        "school": "Clarke School",
        "district": "St. Joseph Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263285006831",
    },
    {
        "school": "Lincoln School",
        "district": "St. Joseph Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263285006833",
    },
    {
        "school": "St Joseph High School",
        "district": "St. Joseph Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263285006834",
    },
    {
        "school": "Upton Middle School",
        "district": "St. Joseph Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263285006835",
    },
    {
        "school": "Watervliet Middle School",
        "district": "Watervliet School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263546001051",
    },
    {
        "school": "North Elementary School",
        "district": "Watervliet School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263546007155",
    },
    {
        "school": "Watervliet Senior High School",
        "district": "Watervliet School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263546007156",
    },
    {
        "school": "South Elementary School",
        "district": "Watervliet School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263546007157",
    },
    {
        "school": "Berrien County Juvenile Center",
        "district": "Berrien RESA",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268016000464",
    },
    {
        "school": "Lighthouse Education Center",
        "district": "Berrien RESA",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268016000465",
    },
    {
        "school": "Blossomland Learning Center",
        "district": "Berrien RESA",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268016000466",
    },
    {
        "school": "HowardEllis Elementary School",
        "district": "Niles Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262556006205",
    },
    {
        "school": "Lincoln Alternative High School",
        "district": "Owosso Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262721001832",
    },
    {
        "school": "Byron Area High School",
        "district": "Byron Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260753004329",
    },
    {
        "school": "Byron Area Elementary School",
        "district": "Byron Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260753004330",
    },
    {
        "school": "Byron Area Middle School",
        "district": "Byron Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260753004331",
    },
    {
        "school": "Corunna Middle School",
        "district": "Corunna Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261086004549",
    },
    {
        "school": "Elsa Meyer Elementary School",
        "district": "Corunna Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261086004550",
    },
    {
        "school": "Corunna High School",
        "district": "Corunna Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261086004554",
    },
    {
        "school": "Bertha Neal School",
        "district": "Durand Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261233004932",
    },
    {
        "school": "Durand Area High School",
        "district": "Durand Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261233004934",
    },
    {
        "school": "Durand Middle School",
        "district": "Durand Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261233004935",
    },
    {
        "school": "Robert Kerr School",
        "district": "Durand Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261233004936",
    },
    {
        "school": "Laingsburg Elementary School",
        "district": "Laingsburg Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262055005726",
    },
    {
        "school": "Laingsburg High School",
        "district": "Laingsburg Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262055005727",
    },
    {
        "school": "Laingsburg Middle School",
        "district": "Laingsburg Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262055005728",
    },
    {
        "school": "Morrice Area Elementary School",
        "district": "Morrice Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262463006113",
    },
    {
        "school": "Morrice Area High School",
        "district": "Morrice Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262463006114",
    },
    {
        "school": "New Lothrop High School",
        "district": "New Lothrop Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262529006186",
    },
    {
        "school": "New Lothrop Elementary School",
        "district": "New Lothrop Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262529006187",
    },
    {
        "school": "Bryant School",
        "district": "Owosso Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262721006328",
    },
    {
        "school": "Central School",
        "district": "Owosso Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262721006329",
    },
    {
        "school": "Emerson School",
        "district": "Owosso Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262721006330",
    },
    {
        "school": "Owosso Middle School",
        "district": "Owosso Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262721006331",
    },
    {
        "school": "Owosso High School",
        "district": "Owosso Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262721006332",
    },
    {
        "school": "Perry Elementary",
        "district": "Perry Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262790006364",
    },
    {
        "school": "Perry High School",
        "district": "Perry Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262790006365",
    },
    {
        "school": "Perry Middle School",
        "district": "Perry Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262790006369",
    },
    {
        "school": "Shiawassee RESD  Student Learning Center  West",
        "district": "Shiawassee Regional ESD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268097500726",
    },
    {
        "school": "Saginaw Learn to Earn Academy",
        "district": "Saginaw Learn to Earn Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260031801911",
    },
    {
        "school": "Martin G Atkins Elementary School",
        "district": "Bridgeport-Spaulding Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260678001834",
    },
    {
        "school": "Omni High School",
        "district": "Carrollton Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260807001816",
    },
    {
        "school": "Hemlock Alternative Education",
        "district": "Hemlock Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261818001908",
    },
    {
        "school": "Ruben Daniels Community SchoolETC",
        "district": "Saginaw School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263039001682",
    },
    {
        "school": "Mackinaw High School",
        "district": "Saginaw Township Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263045001580",
    },
    {
        "school": "St Charles Elementary School",
        "district": "St. Charles Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263264001909",
    },
    {
        "school": "Swan Valley Adult and Alternative Education",
        "district": "Swan Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263341001910",
    },
    {
        "school": "Saginaw Preparatory Academy",
        "district": "Saginaw Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260016100986",
    },
    {
        "school": "Francis Reh PSA",
        "district": "Francis Reh PSA",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021801174",
    },
    {
        "school": "North Saginaw Charter Academy",
        "district": "North Saginaw Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021901175",
    },
    {
        "school": "Birch Run High School",
        "district": "Birch Run Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260582004210",
    },
    {
        "school": "North Elementary School",
        "district": "Birch Run Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260582004211",
    },
    {
        "school": "Marshall Greene Middle School",
        "district": "Birch Run Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260582004212",
    },
    {
        "school": "Bridgeport High School",
        "district": "Bridgeport-Spaulding Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260678004274",
    },
    {
        "school": "Thomas White School",
        "district": "Bridgeport-Spaulding Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260678004276",
    },
    {
        "school": "BridgeportSpaulding Middle SchoolSchrah",
        "district": "Bridgeport-Spaulding Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260678004279",
    },
    {
        "school": "Carrollton Middle School",
        "district": "Carrollton Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260807000711",
    },
    {
        "school": "Carrollton High School",
        "district": "Carrollton Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260807004379",
    },
    {
        "school": "Carrollton Elementary School",
        "district": "Carrollton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260807004380",
    },
    {
        "school": "Chesaning Union High School",
        "district": "Chesaning Union Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260915004444",
    },
    {
        "school": "Big Rock Elementary School",
        "district": "Chesaning Union Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260915004445",
    },
    {
        "school": "Chesaning Middle School",
        "district": "Chesaning Union Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260915004446",
    },
    {
        "school": "Frankenmuth High School",
        "district": "Frankenmuth School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261476005172",
    },
    {
        "school": "Lorenz C List School",
        "district": "Frankenmuth School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261476005173",
    },
    {
        "school": "EF Rittmueller Middle School",
        "district": "Frankenmuth School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261476005174",
    },
    {
        "school": "Freeland Learning Center",
        "district": "Freeland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261506000984",
    },
    {
        "school": "Freeland Middle SchoolHigh School",
        "district": "Freeland Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261506005188",
    },
    {
        "school": "Freeland Elementary School",
        "district": "Freeland Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261506005189",
    },
    {
        "school": "Hemlock Elementary School",
        "district": "Hemlock Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261818005486",
    },
    {
        "school": "Hemlock High School",
        "district": "Hemlock Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261818005487",
    },
    {
        "school": "KC Ling Elementary School",
        "district": "Hemlock Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261818005488",
    },
    {
        "school": "Hemlock Middle School",
        "district": "Hemlock Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261818005489",
    },
    {
        "school": "Merrill High School",
        "district": "Merrill Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262361006040",
    },
    {
        "school": "Merrill Elementary School",
        "district": "Merrill Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262361006041",
    },
    {
        "school": "Merrill Middle School",
        "district": "Merrill Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262361006042",
    },
    {
        "school": "Career Opportunities Center",
        "district": "Saginaw School District of the City of",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "263039000709",
    },
    {
        "school": "Saginaw Arts and Sciences Academy",
        "district": "Saginaw School District of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039001171",
    },
    {
        "school": "Arthur Hill High School",
        "district": "Saginaw School District of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006656",
    },
    {
        "school": "Chester F Miller School",
        "district": "Saginaw School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006658",
    },
    {
        "school": "Handley School",
        "district": "Saginaw School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006662",
    },
    {
        "school": "Herig School",
        "district": "Saginaw School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006664",
    },
    {
        "school": "Jessie Loomis School",
        "district": "Saginaw School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006667",
    },
    {
        "school": "Jessie Rouse School",
        "district": "Saginaw School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006668",
    },
    {
        "school": "Kempton Elementary School",
        "district": "Saginaw School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006670",
    },
    {
        "school": "Merrill Park Elementary School",
        "district": "Saginaw School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006673",
    },
    {
        "school": "Saginaw High School",
        "district": "Saginaw School District of the City of",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006677",
    },
    {
        "school": "Thompson Middle School",
        "district": "Saginaw School District of the City of",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006679",
    },
    {
        "school": "Stone School",
        "district": "Saginaw School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006680",
    },
    {
        "school": "Zilwaukee K8 School",
        "district": "Saginaw School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039006683",
    },
    {
        "school": "White Pine Middle School",
        "district": "Saginaw Township Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263045006694",
    },
    {
        "school": "Hemmeter Elementary School",
        "district": "Saginaw Township Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263045006695",
    },
    {
        "school": "Weiss Elementary School",
        "district": "Saginaw Township Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263045006698",
    },
    {
        "school": "Westdale Elementary School",
        "district": "Saginaw Township Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263045006699",
    },
    {
        "school": "Arrowwood Elementary School",
        "district": "Saginaw Township Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263045006700",
    },
    {
        "school": "Heritage High School",
        "district": "Saginaw Township Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263045006701",
    },
    {
        "school": "Sherwood Elementary School",
        "district": "Saginaw Township Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263045006702",
    },
    {
        "school": "St Charles Community MiddleHigh School",
        "district": "St. Charles Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263264006812",
    },
    {
        "school": "Shields Elementary School",
        "district": "Swan Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263341000263",
    },
    {
        "school": "Swan Valley Middle School",
        "district": "Swan Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263341006874",
    },
    {
        "school": "Robert B Havens Elem School",
        "district": "Swan Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263341006875",
    },
    {
        "school": "Swan Valley High School",
        "district": "Swan Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263341006876",
    },
    {
        "school": "MG Millet Learning Center",
        "district": "Saginaw ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268093000069",
    },
    {
        "school": "Saginaw County Juvenile Center",
        "district": "Saginaw ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268093000258",
    },
    {
        "school": "Michael J McGivney",
        "district": "Saginaw ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268093001254",
    },
    {
        "school": "Saginaw ISD Transitions Center",
        "district": "Saginaw ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268093001410",
    },
    {
        "school": "Ojibwe Charter School",
        "district": "Ojibwe Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260028501657",
    },
    {
        "school": "Joseph K Lumsden Bahweting Anishnabe Academy",
        "district": "Joseph K. Lumsden Bahweting Anishnabe Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260007100492",
    },
    {
        "school": "Brimley Area School",
        "district": "Brimley Area Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260690004291",
    },
    {
        "school": "DeTour High School",
        "district": "DeTour Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261197004634",
    },
    {
        "school": "Drummond Island Elem School",
        "district": "DeTour Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261197004636",
    },
    {
        "school": "Pickford Public Schools",
        "district": "Pickford Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262802006380",
    },
    {
        "school": "Rudyard Area Schools",
        "district": "Rudyard Area Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263036006654",
    },
    {
        "school": "Lincoln School",
        "district": "Sault Ste. Marie Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263099006723",
    },
    {
        "school": "Sault Area Middle School",
        "district": "Sault Ste. Marie Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263099006724",
    },
    {
        "school": "Washington Elementary School",
        "district": "Sault Ste. Marie Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263099006727",
    },
    {
        "school": "Sault Area High School",
        "district": "Sault Ste. Marie Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263099006728",
    },
    {
        "school": "Malcolm High School",
        "district": "Sault Ste. Marie Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263099006730",
    },
    {
        "school": "Whitefish Township School",
        "district": "Whitefish Township Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263624007214",
    },
    {
        "school": "EUPISD Learning Center",
        "district": "Eastern Upper Peninsula ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268028001472",
    },
    {
        "school": "North Pointe Center",
        "district": "Lewis Cass ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268022001535",
    },
    {
        "school": "Cassopolis Alternative Ed",
        "district": "Cassopolis Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260843000809",
    },
    {
        "school": "Ross Beatty High School",
        "district": "Cassopolis Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260843004397",
    },
    {
        "school": "Sam Adams Elementary School",
        "district": "Cassopolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260843004398",
    },
    {
        "school": "Edwardsburg Intermediate School",
        "district": "Edwardsburg Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261299001331",
    },
    {
        "school": "Eagle Lake Elementary School",
        "district": "Edwardsburg Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261299004998",
    },
    {
        "school": "Edwardsburg Primary School",
        "district": "Edwardsburg Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261299004999",
    },
    {
        "school": "Edwardsburg Middle School",
        "district": "Edwardsburg Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261299005000",
    },
    {
        "school": "Edwardsburg High School",
        "district": "Edwardsburg Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261299005001",
    },
    {
        "school": "Volinia Outcome Base School",
        "district": "Marcellus Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262274000121",
    },
    {
        "school": "Marcellus Elementary School",
        "district": "Marcellus Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262274005972",
    },
    {
        "school": "Marcellus High School",
        "district": "Marcellus Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262274005973",
    },
    {
        "school": "Brookside Learning Center",
        "district": "Lewis Cass ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268022000479",
    },
    {
        "school": "Dowagiac Middle School",
        "district": "Dowagiac Union School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261215004918",
    },
    {
        "school": "Justus Gage Elementary School",
        "district": "Dowagiac Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261215004919",
    },
    {
        "school": "Pathfinders Alternative Ed",
        "district": "Dowagiac Union School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261215004920",
    },
    {
        "school": "Patrick Hamilton Elementary",
        "district": "Dowagiac Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261215004921",
    },
    {
        "school": "Union High School",
        "district": "Dowagiac Union School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261215004924",
    },
    {
        "school": "Kincheloe Elementary School",
        "district": "Dowagiac Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261215004925",
    },
    {
        "school": "Sister Lakes Elementary School",
        "district": "Dowagiac Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261215004923",
    },
    {
        "school": "Burr Oak Elementary School",
        "district": "Burr Oak Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260741004326",
    },
    {
        "school": "Burr Oak High School",
        "district": "Burr Oak Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260741004327",
    },
    {
        "school": "Covered Bridge School",
        "district": "Centreville Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260867000991",
    },
    {
        "school": "Centreville Jr Sr High School",
        "district": "Centreville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260867004417",
    },
    {
        "school": "Centreville Elementary School",
        "district": "Centreville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260867004418",
    },
    {
        "school": "Colon Elementary School",
        "district": "Colon Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261041004520",
    },
    {
        "school": "Colon High School",
        "district": "Colon Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261041004521",
    },
    {
        "school": "Leonidas School",
        "district": "Colon Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261041004522",
    },
    {
        "school": "Constantine High School",
        "district": "Constantine Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261075004540",
    },
    {
        "school": "Constantine Middle School",
        "district": "Constantine Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261075004541",
    },
    {
        "school": "Eastside Elementary School",
        "district": "Constantine Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261075004542",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Constantine Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261075004543",
    },
    {
        "school": "Mendon MiddleHigh School",
        "district": "Mendon Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262352006027",
    },
    {
        "school": "Mendon Elementary School",
        "district": "Mendon Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262352006028",
    },
    {
        "school": "Nottawa Community School",
        "district": "Nottawa Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262610006260",
    },
    {
        "school": "Eastwood School",
        "district": "Sturgis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263309000267",
    },
    {
        "school": "Sturgis Middle School",
        "district": "Sturgis Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263309006860",
    },
    {
        "school": "Congress School",
        "district": "Sturgis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263309006861",
    },
    {
        "school": "Sturgis High School",
        "district": "Sturgis Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263309006864",
    },
    {
        "school": "Wall School",
        "district": "Sturgis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263309006865",
    },
    {
        "school": "Wenzel School",
        "district": "Sturgis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263309006866",
    },
    {
        "school": "Andrews Elementary School",
        "district": "Three Rivers Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263384006927",
    },
    {
        "school": "Ruth Hoppin School",
        "district": "Three Rivers Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263384006929",
    },
    {
        "school": "Three Rivers High School",
        "district": "Three Rivers Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263384006930",
    },
    {
        "school": "Norton Elementary School",
        "district": "Three Rivers Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263384006931",
    },
    {
        "school": "Park Elementary School",
        "district": "Three Rivers Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263384006932",
    },
    {
        "school": "Three Rivers Middle School",
        "district": "Three Rivers Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263384006933",
    },
    {
        "school": "White Pigeon JrSr High School",
        "district": "White Pigeon Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263612007210",
    },
    {
        "school": "Central Elementary School",
        "district": "White Pigeon Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263612007211",
    },
    {
        "school": "Pathfinder Educational Center",
        "district": "St. Joseph County ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268096000990",
    },
    {
        "school": "TCAPS Montessori School",
        "district": "Traverse City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387001719",
    },
    {
        "school": "Life Skills Center",
        "district": "Traverse Bay Area ISD",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268044001584",
    },
    {
        "school": "Benzie Central Middle School",
        "district": "Benzie County Central Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260495000801",
    },
    {
        "school": "Lake Ann Elementary School",
        "district": "Benzie County Central Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260495001328",
    },
    {
        "school": "Benzie Central Sr High School",
        "district": "Benzie County Central Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260495004182",
    },
    {
        "school": "Crystal Lake Elementary School",
        "district": "Benzie County Central Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260495004183",
    },
    {
        "school": "Frankfort Elementary School",
        "district": "Frankfort-Elberta Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261479005175",
    },
    {
        "school": "Frankfort High School",
        "district": "Frankfort-Elberta Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261479005176",
    },
    {
        "school": "Woodland School",
        "district": "Woodland School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260007800528",
    },
    {
        "school": "Grand Traverse Academy",
        "district": "Grand Traverse Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260026501343",
    },
    {
        "school": "Fife Lake Elementary School",
        "district": "Forest Area Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261457005150",
    },
    {
        "school": "Kingsley Area High School",
        "district": "Kingsley Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262038005722",
    },
    {
        "school": "Kingsley Area Elementary School",
        "district": "Kingsley Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262038005723",
    },
    {
        "school": "Kingsley Area Middle School",
        "district": "Kingsley Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262038007655",
    },
    {
        "school": "East Middle School",
        "district": "Traverse City Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387000001",
    },
    {
        "school": "West Senior High",
        "district": "Traverse City Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387000838",
    },
    {
        "school": "Traverse City High School",
        "district": "Traverse City Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387001230",
    },
    {
        "school": "Central Grade School",
        "district": "Traverse City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387006937",
    },
    {
        "school": "Cherry Knoll Elementary School",
        "district": "Traverse City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387006938",
    },
    {
        "school": "Eastern Elementary School",
        "district": "Traverse City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387006940",
    },
    {
        "school": "Long Lake Elementary School",
        "district": "Traverse City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387006943",
    },
    {
        "school": "West Middle School",
        "district": "Traverse City Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387006948",
    },
    {
        "school": "Central High School",
        "district": "Traverse City Area Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387006949",
    },
    {
        "school": "Traverse Heights Elem School",
        "district": "Traverse City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387006950",
    },
    {
        "school": "Willow Hill Elementary School",
        "district": "Traverse City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387006951",
    },
    {
        "school": "Silver Lake Elementary School",
        "district": "Traverse City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387007469",
    },
    {
        "school": "Courtade Elementary School",
        "district": "Traverse City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387007652",
    },
    {
        "school": "Westwoods Elementary School",
        "district": "Traverse City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387007653",
    },
    {
        "school": "Blair Elementary School",
        "district": "Traverse City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263387007654",
    },
    {
        "school": "TBA Career Tech Center",
        "district": "Traverse Bay Area ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268044000522",
    },
    {
        "school": "New Campus Center",
        "district": "Traverse Bay Area ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268044000523",
    },
    {
        "school": "Crawford School",
        "district": "Excelsior Township S/D #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261368005031",
    },
    {
        "school": "Forest Area Middle School",
        "district": "Forest Area Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261457000097",
    },
    {
        "school": "Forest Area High School",
        "district": "Forest Area Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261457005151",
    },
    {
        "school": "Cherry Street Intermediate School",
        "district": "Kalkaska Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262005005684",
    },
    {
        "school": "Kalkaska High School",
        "district": "Kalkaska Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262005005685",
    },
    {
        "school": "Rapid City Elementary School",
        "district": "Kalkaska Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262005005686",
    },
    {
        "school": "Kalkaska Middle School",
        "district": "Kalkaska Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262005005687",
    },
    {
        "school": "Birch Street Elementary School",
        "district": "Kalkaska Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262005005688",
    },
    {
        "school": "Glen Lake Community School",
        "district": "Glen Lake Community Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261602005253",
    },
    {
        "school": "Leland Public School",
        "district": "Leland Public School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262139005849",
    },
    {
        "school": "Northport Public School",
        "district": "Northport Public School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262592006237",
    },
    {
        "school": "Suttons Bay Senior High School",
        "district": "Suttons Bay Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263336006871",
    },
    {
        "school": "Suttons Bay Elementary School",
        "district": "Suttons Bay Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263336006872",
    },
    {
        "school": "Betsie Valley School",
        "district": "Benzie County Central Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260495007449",
    },
    {
        "school": "CLARKFIELD CHARTER SCHOOL",
        "district": "CLARKFIELD CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270029003726",
    },
    {
        "school": "MINISINAAKWAANG LEADERSHIP ACADEMY",
        "district": "MINISINAAKWAANG LEADERSHIP ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270030003730",
    },
    {
        "school": "COMPASS ON-LINE",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318003665",
    },
    {
        "school": "CALC TRANSITION",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270810003712",
    },
    {
        "school": "CENTRAL FREEDOM SCHOOL",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271878003678",
    },
    {
        "school": "CAAEP EXTENDED DAY PROGRAM",
        "district": "CLOQUET PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270942003690",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL EDUCATION",
        "district": "WACONIA PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274146003709",
    },
    {
        "school": "FAIRVIEW DAY TREATMENT CENTER",
        "district": "CHISAGO LAKES SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270001703682",
    },
    {
        "school": "INTENSIVE INTERAGENCY PROGRAM",
        "district": "Lake Agassiz Education Cooperative",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004003643",
    },
    {
        "school": "SUN TRANSITION",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002503688",
    },
    {
        "school": "VET",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002503698",
    },
    {
        "school": "Minnesota Connections Academy",
        "district": "MINNESOTA TRANSITIONS CHARTER SCH",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011703694",
    },
    {
        "school": "Bloomington ECSE",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270579003652",
    },
    {
        "school": "BLOOMINGTON SHARED TIME",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270579003658",
    },
    {
        "school": "BLOOMINGTON TRANSITION CENTER",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270579003706",
    },
    {
        "school": "EAGLE HEIGHTS SPANISH IMMERSION",
        "district": "EDEN PRAIRIE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271422003620",
    },
    {
        "school": "CENTRAL MIDDLE ALTERNATIVE (CMAP)",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274216003740",
    },
    {
        "school": "EAST MIDDLE ALTERNATIVE (EMAP)",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274216003743",
    },
    {
        "school": "ISANTI MIDDLE SCHOOL",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270741003629",
    },
    {
        "school": "MINNESOTA CENTER",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270741003634",
    },
    {
        "school": "CAMBRIDGE PRIMARY SCHOOL",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270741003638",
    },
    {
        "school": "SCHOOL FOR ALL SEASONS",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270741003651",
    },
    {
        "school": "CAMBRIDGE INTERMEDIATE SCHOOL",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270741003657",
    },
    {
        "school": "CAMBRIDGE MIDDLE SCHOOL",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270741003671",
    },
    {
        "school": "ISANTI PRIMARY SCHOOL",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270741003686",
    },
    {
        "school": "ISANTI INTERMEDIATE SCHOOL",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270741003705",
    },
    {
        "school": "NASHWAUK-KEEWATIN ALP",
        "district": "NASHWAUK-KEEWATIN SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272331003702",
    },
    {
        "school": "RTR HIGH SCHOOL",
        "district": "RTR PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270029403692",
    },
    {
        "school": "RTR MIDDLE SCHOOL",
        "district": "RTR PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270029403644",
    },
    {
        "school": "MARSHALL MIDDLE SCHOOL",
        "district": "MARSHALL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271894003715",
    },
    {
        "school": "HOWARD LAKE WAVERLY WINSTED ECSE",
        "district": "HOWARD LAKE-WAVERLY-WINSTED",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270012303695",
    },
    {
        "school": "HUTCHINSON NIGHT ALT LEARNING CTR",
        "district": "HUTCHINSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271497003632",
    },
    {
        "school": "POSITIVE APPROACH TO LEARNING",
        "district": "SOUTHERN PLAINS EDUCATION COOP.",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004603691",
    },
    {
        "school": "ACGC ELEMENTARY GRADES 5 AND 6",
        "district": "A.C.G.C. PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010603647",
    },
    {
        "school": "EARLY CHILDHOOD YEAR ROUND",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273180003680",
    },
    {
        "school": "LEAF RIVER ACADEMY",
        "district": "Freshwater Education District",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270001403675",
    },
    {
        "school": "IQ ACADEMY MINNESOTA",
        "district": "FERGUS FALLS PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271188003645",
    },
    {
        "school": "RTR ELEMENTARY SCHOOL",
        "district": "RTR PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270029403679",
    },
    {
        "school": "GLACIAL HILLS ELEMENTARY",
        "district": "GLACIAL HILLS ELEMENTARY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270029303628",
    },
    {
        "school": "Hmong College Prep Academy MS",
        "district": "HMONG COLLEGE PREP ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034203700",
    },
    {
        "school": "JORDAN EARLY CHILDHOOD",
        "district": "JORDAN PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271575003664",
    },
    {
        "school": "EAGLE VIEW",
        "district": "NEW PRAGUE AREA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272343003641",
    },
    {
        "school": "CENTRAL EDUCATION CAMPUS",
        "district": "NEW PRAGUE AREA SCHOOLS",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272343003677",
    },
    {
        "school": "TWIN OAKS MIDDLE SCHOOL",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273006003626",
    },
    {
        "school": "JEFFERS POND ELEMENTARY",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273006003711",
    },
    {
        "school": "FAIRVIEW PROGRAM",
        "district": "Elk River School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271137003660",
    },
    {
        "school": "PLAINVIEW-ELGIN-MILLVILLE HIGH",
        "district": "PLAINVIEW-ELGIN-MILLVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028703631",
    },
    {
        "school": "PLAINVIEW-ELGIN-MILLVILLE 4-6",
        "district": "PLAINVIEW-ELGIN-MILLVILLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028703667",
    },
    {
        "school": "PLAINVIEW-ELGIN-MILLVILLE PK-3",
        "district": "PLAINVIEW-ELGIN-MILLVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028703701",
    },
    {
        "school": "PLAINVIEW-ELGIN-MILLVILLE JUNIOR",
        "district": "PLAINVIEW-ELGIN-MILLVILLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028703714",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL EDUCATION",
        "district": "Freshwater Education District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270001403670",
    },
    {
        "school": "ARIS",
        "district": "NORTHEAST METRO 916",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270226403646",
    },
    {
        "school": "ONEKA ELEMENTARY SCHOOL",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236003699",
    },
    {
        "school": "HVED ECSE",
        "district": "HIAWATHA VALLEY ED. DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270005503650",
    },
    {
        "school": "MN RIVER VALLEY ALC-SUMMER",
        "district": "MN RIVER VALLEY EDUCATION DISTRICT",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270005803298",
    },
    {
        "school": "BIRCH GROVE COMMUNITY SCHOOL",
        "district": "BIRCH GROVE COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270025503313",
    },
    {
        "school": "GREAT EXPECTATIONS",
        "district": "GREAT EXPECTATIONS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270033904177",
    },
    {
        "school": "NORTHERN LIGHTS COMMUNITY SCHOOL",
        "district": "NORTHERN LIGHTS COMMUNITY SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270025603314",
    },
    {
        "school": "NAYTAHWAUSH COMMUNITY SCHOOL",
        "district": "NAYTAHWAUSH COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270027503580",
    },
    {
        "school": "SUN Program",
        "district": "MID STATE EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007303304",
    },
    {
        "school": "MID STATE ED DIST STEPS TRANS. PROG",
        "district": "MID STATE EDUCATION DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007303305",
    },
    {
        "school": "WIN-Elementary School",
        "district": "MID STATE EDUCATION DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007303604",
    },
    {
        "school": "Minnewaska Area Intermediate School",
        "district": "MINNEWASKA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001903535",
    },
    {
        "school": "MINNEWASKA AREA ELEMENTARY",
        "district": "MINNEWASKA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001903536",
    },
    {
        "school": "MINNEWASKA SECONDARY ALTERNATIVE PG",
        "district": "MINNEWASKA SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270001903537",
    },
    {
        "school": "MINNEWASKA EARLY CHILDHOOD SP.ED.",
        "district": "MINNEWASKA SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270001903538",
    },
    {
        "school": "Minnewaska Area WIN Academy",
        "district": "MINNEWASKA SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270001903600",
    },
    {
        "school": "Pinnacle Programs Southwestern Yout",
        "district": "LUVERNE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271833004162",
    },
    {
        "school": "GREEN ISLE COMMUNITY SCHOOL",
        "district": "GREEN ISLE COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270025403312",
    },
    {
        "school": "EDVISIONS OFF CAMPUS SCHOOL",
        "district": "EDVISIONS OFF CAMPUS SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270026103319",
    },
    {
        "school": "HEARTLAND GIRLS RANCH",
        "district": "BENSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270447004182",
    },
    {
        "school": "WHITE PINE ACADEMY",
        "district": "Freshwater Education District",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270001403297",
    },
    {
        "school": "TEAM ACADEMY",
        "district": "TEAM ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270024103341",
    },
    {
        "school": "YELLOW MEDICINE EAST HIGH SCHOOL",
        "district": "YELLOW MEDICINE EAST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009903539",
    },
    {
        "school": "AITKIN SECONDARY SCHOOL",
        "district": "AITKIN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270276000057",
    },
    {
        "school": "RIPPLESIDE ELEMENTARY",
        "district": "AITKIN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270276000059",
    },
    {
        "school": "AITKIN ALTERNATIVE LEARNING PROGRAM",
        "district": "AITKIN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270276002789",
    },
    {
        "school": "HILL CITY ELEMENTARY",
        "district": "HILL CITY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271401000723",
    },
    {
        "school": "HILL CITY SENIOR HIGH",
        "district": "HILL CITY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271401000724",
    },
    {
        "school": "MCGREGOR ELEMENTARY",
        "district": "MCGREGOR PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271917000903",
    },
    {
        "school": "MCGREGOR SECONDARY",
        "district": "MCGREGOR PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271917000904",
    },
    {
        "school": "MCGREGOR AREA LEARNING PROGRAM",
        "district": "MCGREGOR PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271917003432",
    },
    {
        "school": "Lake Agassiz Education Cooperative",
        "district": "Lake Agassiz Education Cooperative",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004002355",
    },
    {
        "school": "LAKE PARK AUDUBON ELEMENTARY",
        "district": "LAKE PARK AUDUBON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270016200142",
    },
    {
        "school": "LAKE PARK AUDUBON SECONDARY",
        "district": "LAKE PARK AUDUBON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270016200812",
    },
    {
        "school": "Detroit Lakes Alternative Program",
        "district": "DETROIT LAKES PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271023000294",
    },
    {
        "school": "DETROIT LAKES SENIOR HIGH",
        "district": "DETROIT LAKES PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271023000442",
    },
    {
        "school": "DETROIT LAKES MIDDLE",
        "district": "DETROIT LAKES PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271023000443",
    },
    {
        "school": "ROSSMAN ELEMENTARY",
        "district": "DETROIT LAKES PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271023000445",
    },
    {
        "school": "ROOSEVELT ELEMENTARY",
        "district": "DETROIT LAKES PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271023002268",
    },
    {
        "school": "DETROIT LAKES MIDDLE ALC",
        "district": "DETROIT LAKES PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271023003061",
    },
    {
        "school": "DETROIT LAKES AREA LEARNING CENTER",
        "district": "DETROIT LAKES PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271023003062",
    },
    {
        "school": "FRAZEE SECONDARY",
        "district": "FRAZEE-VERGAS PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271236000606",
    },
    {
        "school": "FRAZEE ELEMENTARY",
        "district": "FRAZEE-VERGAS PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271236000607",
    },
    {
        "school": "PINE POINT ELEMENTARY",
        "district": "PINE POINT PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272896000034",
    },
    {
        "school": "OGEMA ELEMENTARY",
        "district": "WAUBUN-OGEMA-WHITE EARTH PUBLIC SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274212001754",
    },
    {
        "school": "CLINTON-GRACEVILLE-BEARDSLEY EL.",
        "district": "CLINTON-GRACEVILLE-BEARDSLEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270015000378",
    },
    {
        "school": "CLINTON-GRACEVILLE-BEARDSLEY SR.",
        "district": "CLINTON-GRACEVILLE-BEARDSLEY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270015000652",
    },
    {
        "school": "Lismore Colony School",
        "district": "CLINTON-GRACEVILLE-BEARDSLEY",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270015003019",
    },
    {
        "school": "MN RIVER VALLEY ALC-SEATBASED",
        "district": "MN RIVER VALLEY EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270005802245",
    },
    {
        "school": "MACCRAY SENIOR HIGH",
        "district": "MACCRAY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009100365",
    },
    {
        "school": "MACCRAY WEST ELEMENTARY",
        "district": "MACCRAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009100898",
    },
    {
        "school": "MONTEVIDEO MIDDLE",
        "district": "MONTEVIDEO PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272132001071",
    },
    {
        "school": "MONTEVIDEO SENIOR HIGH",
        "district": "MONTEVIDEO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272132001072",
    },
    {
        "school": "RAMSEY ELEMENTARY",
        "district": "MONTEVIDEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272132001073",
    },
    {
        "school": "SANFORD EDUCATION CENTER",
        "district": "MONTEVIDEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272132001074",
    },
    {
        "school": "CLEARBROOK-GONVICK ELEMENTARY",
        "district": "CLEARBROOK-GONVICK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010303467",
    },
    {
        "school": "CLEARBROOK-GONVICK SECONDARY",
        "district": "CLEARBROOK-GONVICK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010303468",
    },
    {
        "school": "BAGLEY ELEMENTARY",
        "district": "BAGLEY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270357000164",
    },
    {
        "school": "BAGLEY SECONDARY",
        "district": "BAGLEY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270357000165",
    },
    {
        "school": "COOK COUNTY SENIOR HIGH",
        "district": "COOK COUNTY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271311000656",
    },
    {
        "school": "SAWTOOTH MOUNTAIN ELEMENTARY",
        "district": "COOK COUNTY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271311000658",
    },
    {
        "school": "COOK COUNTY ALTERNATIVE",
        "district": "COOK COUNTY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271311002511",
    },
    {
        "school": "COOK COUNTY MIDDLE",
        "district": "COOK COUNTY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271311002635",
    },
    {
        "school": "RED ROCK CENTRAL ELEMENTARY",
        "district": "RED ROCK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270013201419",
    },
    {
        "school": "WESTBROOK-WALNUT GROVE SECONDARY",
        "district": "WESTBROOK-WALNUT GROVE SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018301782",
    },
    {
        "school": "MOUNTAIN LAKE ELEMENTARY",
        "district": "MOUNTAIN LAKE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272301001134",
    },
    {
        "school": "MOUNTAIN LAKE SECONDARY",
        "district": "MOUNTAIN LAKE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272301001135",
    },
    {
        "school": "WINDOM SENIOR HIGH",
        "district": "WINDOM PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274278001815",
    },
    {
        "school": "WINFAIR ELEMENTARY",
        "district": "WINDOM PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274278001816",
    },
    {
        "school": "WINDOM MIDDLE",
        "district": "WINDOM PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274278003068",
    },
    {
        "school": "WEST CENTRAL AREA S. EL.",
        "district": "WEST CENTRAL AREA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010400731",
    },
    {
        "school": "UNITED SOUTH CENTRAL ELEMENTARY",
        "district": "UNITED SOUTH CENTRAL SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000501769",
    },
    {
        "school": "UNITED SOUTH CENTRAL HIGH SCHOOL",
        "district": "UNITED SOUTH CENTRAL SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000501770",
    },
    {
        "school": "BLUE EARTH AREA ELEMENTARY",
        "district": "BLUE EARTH AREA PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270013000241",
    },
    {
        "school": "BLUE EARTH AREA MIDDLE",
        "district": "BLUE EARTH AREA PUBLIC SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270013002497",
    },
    {
        "school": "BLUE EARTH AREA SECONDARY",
        "district": "BLUE EARTH AREA PUBLIC SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270013002498",
    },
    {
        "school": "Kingsland Elementary School",
        "district": "KINGSLAND PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000701468",
    },
    {
        "school": "Kingsland Junior/Senior High School",
        "district": "KINGSLAND PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000701469",
    },
    {
        "school": "FILLMORE CENTRAL SENIOR HIGH",
        "district": "FILLMORE CENTRAL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010000691",
    },
    {
        "school": "FILLMORE CENTRAL ELEMENTARY",
        "district": "FILLMORE CENTRAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010001269",
    },
    {
        "school": "LANESBORO ELEMENTARY",
        "district": "LANESBORO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271791000823",
    },
    {
        "school": "LANESBORO SECONDARY",
        "district": "LANESBORO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271791000824",
    },
    {
        "school": "MABEL-CANTON ELEMENTARY",
        "district": "MABEL-CANTON PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271854000857",
    },
    {
        "school": "MABEL-CANTON SECONDARY",
        "district": "MABEL-CANTON PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271854000858",
    },
    {
        "school": "RUSHFORD-PETERSON MIDDLE",
        "district": "RUSHFORD-PETERSON PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272829001249",
    },
    {
        "school": "RUSHFORD-PETERSON ELEMENTARY",
        "district": "RUSHFORD-PETERSON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272829001407",
    },
    {
        "school": "RUSHFORD-PETERSON SENIOR HIGH",
        "district": "RUSHFORD-PETERSON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272829001408",
    },
    {
        "school": "WEST CENTRAL AREA N. EL.",
        "district": "WEST CENTRAL AREA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010400513",
    },
    {
        "school": "WEST CENTRAL AREA SECONDARY",
        "district": "WEST CENTRAL AREA",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010402566",
    },
    {
        "school": "ASHBY ELEMENTARY",
        "district": "ASHBY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270330000136",
    },
    {
        "school": "ASHBY SECONDARY",
        "district": "ASHBY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270330000137",
    },
    {
        "school": "HERMAN ELEMENTARY",
        "district": "HERMAN-NORCROSS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271389000713",
    },
    {
        "school": "HERMAN SECONDARY",
        "district": "HERMAN-NORCROSS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271389000714",
    },
    {
        "school": "LAPORTE ELEMENTARY",
        "district": "LAPORTE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271794000825",
    },
    {
        "school": "LAPORTE SECONDARY",
        "district": "LAPORTE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271794000826",
    },
    {
        "school": "NEVIS ELEMENTARY",
        "district": "NEVIS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272337001139",
    },
    {
        "school": "NEVIS SECONDARY",
        "district": "NEVIS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272337001140",
    },
    {
        "school": "NEVIS AREA LEARNING PROGRAM",
        "district": "NEVIS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272337003072",
    },
    {
        "school": "HEADWATERS EDUC LEARNING PROGRAM",
        "district": "PARK RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272808000864",
    },
    {
        "school": "PARK RAPIDS AREA CENTURY ELEMENTARY",
        "district": "PARK RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272808001233",
    },
    {
        "school": "PARK RAPIDS SENIOR HIGH",
        "district": "PARK RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272808001235",
    },
    {
        "school": "PARK RAPIDS AREA CENTURY MIDDLE",
        "district": "PARK RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272808001236",
    },
    {
        "school": "MARBLE EARLY CHILDHOOD CENTER",
        "district": "GREENWAY PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270948000391",
    },
    {
        "school": "VANDYKE ELEMENTARY",
        "district": "GREENWAY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270948000394",
    },
    {
        "school": "GREENWAY MIDDLE",
        "district": "GREENWAY PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270948002785",
    },
    {
        "school": "GREENWAY SENIOR HIGH",
        "district": "GREENWAY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270948002786",
    },
    {
        "school": "DEER RIVER SECONDARY",
        "district": "DEER RIVER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271014000433",
    },
    {
        "school": "KING ELEMENTARY",
        "district": "DEER RIVER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271014000434",
    },
    {
        "school": "COHASSET ELEMENTARY",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271317000661",
    },
    {
        "school": "FOREST LAKE ELEMENTARY",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271317000662",
    },
    {
        "school": "GRAND RAPIDS EARLY CHILDHOOD CENTER",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271317000874",
    },
    {
        "school": "BIGFORK ELEMENTARY",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271317000882",
    },
    {
        "school": "MURPHY ELEMENTARY",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271317000907",
    },
    {
        "school": "SOUTHWEST ELEMENTARY",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271317000915",
    },
    {
        "school": "BIGFORK SECONDARY",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271317000934",
    },
    {
        "school": "GRAND RAPIDS SENIOR HIGH",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271317000935",
    },
    {
        "school": "ROBERT J. ELKINGTON MIDDLE SCHOOL",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271317000939",
    },
    {
        "school": "MIDDLE AREA LEARNING CENTER",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271317000940",
    },
    {
        "school": "GRAND RAPIDS AREA LEARNING CENTER",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271317002332",
    },
    {
        "school": "ITASKIN EDUCATION CENTER",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271317003073",
    },
    {
        "school": "Keewatin-Nashwauk Elementary School",
        "district": "NASHWAUK-KEEWATIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272331001136",
    },
    {
        "school": "NASHWAUK SECONDARY",
        "district": "NASHWAUK-KEEWATIN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272331001138",
    },
    {
        "school": "JACKSON COUNTY CENTRAL SENIOR HIGH",
        "district": "JACKSON COUNTY CENTRAL SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270023100773",
    },
    {
        "school": "RIVERSIDE ELEMENTARY",
        "district": "JACKSON COUNTY CENTRAL SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270023100774",
    },
    {
        "school": "PLEASANTVIEW ELEMENTARY",
        "district": "JACKSON COUNTY CENTRAL SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270023100814",
    },
    {
        "school": "JACKSON COUNTY CENTRAL MIDDLE",
        "district": "JACKSON COUNTY CENTRAL SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270023102042",
    },
    {
        "school": "HERON LAKE-OKABENA ELEMENTARY",
        "district": "HERON LAKE-OKABENA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271393000015",
    },
    {
        "school": "HERON LAKE-OKABENA SECONDARY",
        "district": "HERON LAKE-OKABENA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271393000017",
    },
    {
        "school": "MORA SECONDARY",
        "district": "MORA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272148000944",
    },
    {
        "school": "MORA ALTERNATIVE LEARNING CENTER",
        "district": "MORA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272148000946",
    },
    {
        "school": "Mora Elementary School",
        "district": "MORA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272148001097",
    },
    {
        "school": "OGILVIE ELEMENTARY",
        "district": "OGILVIE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272397001188",
    },
    {
        "school": "OGILVIE SECONDARY",
        "district": "OGILVIE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272397001189",
    },
    {
        "school": "MACCRAY EAST ELEMENTARY",
        "district": "MACCRAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009101288",
    },
    {
        "school": "A.C.G.C. ELEMENTARY",
        "district": "A.C.G.C. PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010602568",
    },
    {
        "school": "LANCASTER ELEMENTARY",
        "district": "LANCASTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271788000821",
    },
    {
        "school": "LANCASTER SECONDARY",
        "district": "LANCASTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271788000822",
    },
    {
        "school": "KARLSTAD ELEMENTARY",
        "district": "TRI-COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279144602313",
    },
    {
        "school": "TRI-COUNTY SECONDARY",
        "district": "TRI-COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279144602314",
    },
    {
        "school": "KITTSON CENTRAL SECONDARY",
        "district": "KITTSON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279144702316",
    },
    {
        "school": "KITTSON CENTRAL ELEMENTARY",
        "district": "KITTSON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279144702469",
    },
    {
        "school": "FALLS ELEMENTARY",
        "district": "INTERNATIONAL FALLS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271500000759",
    },
    {
        "school": "FALLS SECONDARY",
        "district": "INTERNATIONAL FALLS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271500000761",
    },
    {
        "school": "LITTLEFORK-BIG FALLS ELEMENTARY",
        "district": "LITTLEFORK-BIG FALLS SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271827000847",
    },
    {
        "school": "LITTLEFORK-BIG FALLS SECONDARY",
        "district": "LITTLEFORK-BIG FALLS SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271827000848",
    },
    {
        "school": "INDUS SECONDARY",
        "district": "SOUTH KOOCHICHING SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273270001413",
    },
    {
        "school": "NORTHOME SECONDARY",
        "district": "SOUTH KOOCHICHING SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273270001416",
    },
    {
        "school": "INDUS ELEMENTARY",
        "district": "SOUTH KOOCHICHING SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273270001945",
    },
    {
        "school": "NORTHOME ELEMENTARY",
        "district": "SOUTH KOOCHICHING SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273270001946",
    },
    {
        "school": "LAC QUI PARLE VALLEY SECONDARY",
        "district": "LAC QUI PARLE VALLEY SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012502260",
    },
    {
        "school": "MADISON-MARIETTA-NASSAU ELEMENTARY",
        "district": "LAC QUI PARLE VALLEY SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012503017",
    },
    {
        "school": "STEVENS ELEMENTARY",
        "district": "DAWSON-BOYD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271009000429",
    },
    {
        "school": "DAWSON-BOYD SECONDARY",
        "district": "DAWSON-BOYD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271009000430",
    },
    {
        "school": "LAKE OF THE WOODS ELEMENTARY",
        "district": "LAKE OF THE WOODS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271757000808",
    },
    {
        "school": "LAKE OF THE WOODS SECONDARY",
        "district": "LAKE OF THE WOODS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271757000809",
    },
    {
        "school": "WATERVILLE ELEMENTARY",
        "district": "WATERVILLE-ELYSIAN-MORRISTOWN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001301752",
    },
    {
        "school": "WATERVILLE-ELYSIAN-MORRISTOWN SR.",
        "district": "WATERVILLE-ELYSIAN-MORRISTOWN",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001301753",
    },
    {
        "school": "CLEVELAND ELEMENTARY",
        "district": "CLEVELAND PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270933000374",
    },
    {
        "school": "CLEVELAND SECONDARY",
        "district": "CLEVELAND PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270933000375",
    },
    {
        "school": "PARK ELEMENTARY",
        "district": "LE SUEUR-HENDERSON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271807000045",
    },
    {
        "school": "LE SUEUR-HENDERSON HIGH SCHOOL",
        "district": "LE SUEUR-HENDERSON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271807000047",
    },
    {
        "school": "AREA ADULT LEARNING COOPERATIVE",
        "district": "LE SUEUR-HENDERSON SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271807002695",
    },
    {
        "school": "HEARTLAND ELEMENTARY",
        "district": "PIPESTONE AREA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010803015",
    },
    {
        "school": "HENDRICKS ELEMENTARY",
        "district": "HENDRICKS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271368000707",
    },
    {
        "school": "LAKE BENTON ELEMENTARY",
        "district": "LAKE BENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271746000801",
    },
    {
        "school": "LAKE BENTON SECONDARY",
        "district": "LAKE BENTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271746000802",
    },
    {
        "school": "MAHNOMEN ELEMENTARY",
        "district": "MAHNOMEN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271866000865",
    },
    {
        "school": "MAHNOMEN SECONDARY",
        "district": "MAHNOMEN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271866000866",
    },
    {
        "school": "MAHNOMEN AREA LEARNING CENTER",
        "district": "MAHNOMEN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271866002333",
    },
    {
        "school": "WAUBUN ELEMENTARY",
        "district": "WAUBUN-OGEMA-WHITE EARTH PUBLIC SCH",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274212001755",
    },
    {
        "school": "WAUBUN SECONDARY",
        "district": "WAUBUN-OGEMA-WHITE EARTH PUBLIC SCH",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274212001756",
    },
    {
        "school": "WAUBUN AREA LEARNING PROGRAM",
        "district": "WAUBUN-OGEMA-WHITE EARTH PUBLIC SCH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274212003460",
    },
    {
        "school": "WARREN ELEMENTARY",
        "district": "WARREN-ALVARADO-OSLO SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002401742",
    },
    {
        "school": "WARREN-ALVARADO-OSLO SECONDARY",
        "district": "WARREN-ALVARADO-OSLO SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002401743",
    },
    {
        "school": "NW REGION INTERDISTRICT COUNCIL",
        "district": "NW REGION INTERDISTRICT COUNCIL",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270003902354",
    },
    {
        "school": "ARGYLE ELEMENTARY",
        "district": "STEPHEN-ARGYLE CENTRAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012700131",
    },
    {
        "school": "STEPHEN SENIOR HIGH",
        "district": "STEPHEN-ARGYLE CENTRAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012701648",
    },
    {
        "school": "GRYGLA ELEMENTARY",
        "district": "GRYGLA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271892000896",
    },
    {
        "school": "GRYGLA SECONDARY",
        "district": "GRYGLA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271892000897",
    },
    {
        "school": "MARSHALL COUNTY CENTRAL HIGH",
        "district": "MARSHALL COUNTY CENTRAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272355001157",
    },
    {
        "school": "NEWFOLDEN ELEMENTARY",
        "district": "MARSHALL COUNTY CENTRAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272355001158",
    },
    {
        "school": "VIKING ELEMENTARY",
        "district": "MARSHALL COUNTY CENTRAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272355001159",
    },
    {
        "school": "A.C.G.C. SECONDARY",
        "district": "A.C.G.C. PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010602570",
    },
    {
        "school": "EDEN VALLEY ELEMENTARY",
        "district": "EDEN VALLEY-WATKINS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271119000501",
    },
    {
        "school": "EDEN VALLEY SECONDARY",
        "district": "EDEN VALLEY-WATKINS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271119000502",
    },
    {
        "school": "WATKINS ELEMENTARY",
        "district": "EDEN VALLEY-WATKINS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271119002657",
    },
    {
        "school": "LAKE RIPLEY ELEMENTARY",
        "district": "LITCHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271821000837",
    },
    {
        "school": "LITCHFIELD MIDDLE SCHOOL",
        "district": "LITCHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271821000838",
    },
    {
        "school": "LITCHFIELD SENIOR HIGH",
        "district": "LITCHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271821000839",
    },
    {
        "school": "LITCHFIELD AREA LEARNING PROGRAM",
        "district": "LITCHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271821003075",
    },
    {
        "school": "ISLE ELEMENTARY",
        "district": "ISLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271551000769",
    },
    {
        "school": "ISLE SECONDARY",
        "district": "ISLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271551000770",
    },
    {
        "school": "ISLE AREA LEARNING CENTER",
        "district": "ISLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271551002819",
    },
    {
        "school": "MILACA ELEMENTARY",
        "district": "MILACA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272067000923",
    },
    {
        "school": "MILACA SECONDARY HIGH",
        "district": "MILACA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272067000924",
    },
    {
        "school": "MILACA AREA LEARNING CENTER",
        "district": "MILACA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272067002562",
    },
    {
        "school": "MILLE LACS ACADEMY (NEXUS)",
        "district": "ONAMIA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272505000957",
    },
    {
        "school": "KOKESH AREA LEARNING CENTER",
        "district": "ONAMIA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272505000959",
    },
    {
        "school": "Onamia Primary School",
        "district": "ONAMIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272505001195",
    },
    {
        "school": "Onamia High School",
        "district": "ONAMIA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272505001196",
    },
    {
        "school": "Princeton Intermediate School",
        "district": "PRINCETON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273003001271",
    },
    {
        "school": "Princeton Middle School",
        "district": "PRINCETON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273003001272",
    },
    {
        "school": "Princeton High School",
        "district": "PRINCETON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273003001273",
    },
    {
        "school": "Princeton Primary School",
        "district": "PRINCETON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273003001274",
    },
    {
        "school": "LINCOLN ELEMENTARY",
        "district": "LITTLE FALLS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271824000960",
    },
    {
        "school": "LINDBERGH ELEMENTARY",
        "district": "LITTLE FALLS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271824000961",
    },
    {
        "school": "KNIGHT ELEMENTARY",
        "district": "LITTLE FALLS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271824000962",
    },
    {
        "school": "COMMUNITY MIDDLE",
        "district": "LITTLE FALLS PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271824000963",
    },
    {
        "school": "LITTLE FALLS SENIOR HIGH",
        "district": "LITTLE FALLS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271824000964",
    },
    {
        "school": "LITTLE FALLS CONTINUING EDUCATION",
        "district": "LITTLE FALLS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271824002780",
    },
    {
        "school": "PIONEER ELEMENTARY",
        "district": "PIERZ PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272832001251",
    },
    {
        "school": "HEALY SECONDARY",
        "district": "PIERZ PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272832001252",
    },
    {
        "school": "PIERZ ALTERNATIVE PROGRAM",
        "district": "PIERZ PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272832002530",
    },
    {
        "school": "ROYALTON ELEMENTARY",
        "district": "ROYALTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273252001403",
    },
    {
        "school": "ROYALTON HIGH SCHOOL",
        "district": "ROYALTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273252001404",
    },
    {
        "school": "MOTLEY-STAPLES MIDDLE SCHOOL",
        "district": "STAPLES-MOTLEY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273390002468",
    },
    {
        "school": "SWANVILLE ELEMENTARY",
        "district": "SWANVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273828001670",
    },
    {
        "school": "SWANVILLE SECONDARY",
        "district": "SWANVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273828001671",
    },
    {
        "school": "MOLLY CREEK AREA LEARNING CENTER",
        "district": "SWANVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273828002532",
    },
    {
        "school": "UPSALA ELEMENTARY",
        "district": "UPSALA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274086001708",
    },
    {
        "school": "UPSALA SECONDARY",
        "district": "UPSALA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274086001709",
    },
    {
        "school": "MURRAY CO. CENTRAL ELEMENTARY",
        "district": "MURRAY COUNTY CENTRAL SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009001448",
    },
    {
        "school": "MURRAY COUNTY CENTRAL SECONDARY",
        "district": "MURRAY COUNTY CENTRAL SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009001449",
    },
    {
        "school": "FULDA ELEMENTARY",
        "district": "FULDA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271248000617",
    },
    {
        "school": "FULDA SECONDARY",
        "district": "FULDA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271248000618",
    },
    {
        "school": "NORMAN COUNTY EAST ELEMENTARY",
        "district": "NORMAN COUNTY EAST SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010100622",
    },
    {
        "school": "NORMAN COUNTY EAST SECONDARY",
        "district": "NORMAN COUNTY EAST SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010101695",
    },
    {
        "school": "ADA ELEMENTARY",
        "district": "ADA-BORUP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012600050",
    },
    {
        "school": "ADA-BORUP SECONDARY",
        "district": "ADA-BORUP PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012600051",
    },
    {
        "school": "ADA-BORUP AREA LEARNING PROGRAM",
        "district": "ADA-BORUP PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270012603018",
    },
    {
        "school": "Norman County West Elementary",
        "district": "NORMAN COUNTY WEST SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279144802317",
    },
    {
        "school": "GOODRIDGE ELEMENTARY",
        "district": "GOODRIDGE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271302000649",
    },
    {
        "school": "GOODRIDGE SECONDARY",
        "district": "GOODRIDGE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271302000650",
    },
    {
        "school": "FRANKLIN MIDDLE",
        "district": "THIEF RIVER FALLS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273885001674",
    },
    {
        "school": "LINCOLN SENIOR HIGH",
        "district": "THIEF RIVER FALLS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273885001676",
    },
    {
        "school": "NORTHWEST AREA LEARNING CENTER",
        "district": "THIEF RIVER FALLS SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273885002290",
    },
    {
        "school": "CHALLENGER ELEMENTARY",
        "district": "THIEF RIVER FALLS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273885002451",
    },
    {
        "school": "EAST CENTRAL ELEMENTARY",
        "district": "EAST CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271108500157",
    },
    {
        "school": "EAST CENTRAL SENIOR SECONDARY",
        "district": "EAST CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271108500189",
    },
    {
        "school": "CROSSROADS AREA LEARNING CENTER",
        "district": "EAST CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271108500222",
    },
    {
        "school": "FINLAYSON ELEMENTARY",
        "district": "HINCKLEY-FINLAYSON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271407000585",
    },
    {
        "school": "HINCKLEY ELEMENTARY",
        "district": "HINCKLEY-FINLAYSON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271407000728",
    },
    {
        "school": "HINCKLEY-FINLAYSON SECONDARY",
        "district": "HINCKLEY-FINLAYSON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271407000729",
    },
    {
        "school": "PINE CITY AREA LEARNING CENTER",
        "district": "PINE CITY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272838001025",
    },
    {
        "school": "PINE CITY ELEMENTARY",
        "district": "PINE CITY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272838001255",
    },
    {
        "school": "PINE CITY SECONDARY",
        "district": "PINE CITY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272838001256",
    },
    {
        "school": "WILLOW RIVER ELEMENTARY",
        "district": "WILLOW RIVER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274275001811",
    },
    {
        "school": "WILLOW RIVER SECONDARY",
        "district": "WILLOW RIVER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274275001812",
    },
    {
        "school": "BROWN ELEMENTARY",
        "district": "PIPESTONE AREA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010801261",
    },
    {
        "school": "HILL ELEMENTARY",
        "district": "PIPESTONE AREA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010801262",
    },
    {
        "school": "PIPESTONE SENIOR HIGH",
        "district": "PIPESTONE AREA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010801263",
    },
    {
        "school": "PIPESTONE MIDDLE",
        "district": "PIPESTONE AREA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010801264",
    },
    {
        "school": "EDGERTON ELEMENTARY",
        "district": "EDGERTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271122000503",
    },
    {
        "school": "EDGERTON SECONDARY",
        "district": "EDGERTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271122000504",
    },
    {
        "school": "MINNEWASKA SECONDARY",
        "district": "MINNEWASKA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001902298",
    },
    {
        "school": "PINE TO PRAIRIE COOP. CTR.",
        "district": "PINE TO PRAIRIE COOPERATIVE CTR.",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MN",
        "nces_id": "270003802353",
    },
    {
        "school": "LAFAYETTE SECONDARY",
        "district": "RED LAKE FALLS PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273045001290",
    },
    {
        "school": "J.A. HUGHES ELEMENTARY",
        "district": "RED LAKE FALLS PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273045001291",
    },
    {
        "school": "CEDAR MOUNTAIN SECONDARY",
        "district": "CEDAR MOUNTAIN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011001099",
    },
    {
        "school": "RED ROCK CENTRAL SECONDARY",
        "district": "RED ROCK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270013200820",
    },
    {
        "school": "REDWOOD VALLEY SENIOR HIGH",
        "district": "REDWOOD AREA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018201304",
    },
    {
        "school": "REEDE GRAY ELEMENTARY",
        "district": "REDWOOD AREA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018201305",
    },
    {
        "school": "REDWOOD VALLEY MIDDLE",
        "district": "REDWOOD AREA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018202301",
    },
    {
        "school": "REDWOOD VALLEY ALTERNATIVE",
        "district": "REDWOOD AREA SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270018202576",
    },
    {
        "school": "WALNUT GROVE ELEMENTARY",
        "district": "WESTBROOK-WALNUT GROVE SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018301738",
    },
    {
        "school": "MILROY ELEMENTARY",
        "district": "MILROY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272121000927",
    },
    {
        "school": "WABASSO ELEMENTARY",
        "district": "WABASSO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274143001727",
    },
    {
        "school": "WABASSO SECONDARY",
        "district": "WABASSO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274143001728",
    },
    {
        "school": "BUFFALO LAKE-HECTOR ELEMENTARY",
        "district": "BUFFALO LK-HECTOR-STEWART PUBLIC SC",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002300288",
    },
    {
        "school": "BUFFALO LAKE-HECTOR SECONDARY",
        "district": "BUFFALO LK-HECTOR-STEWART PUBLIC SC",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002300704",
    },
    {
        "school": "CEDAR MOUNTAIN ELEMENTARY",
        "district": "CEDAR MOUNTAIN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011001098",
    },
    {
        "school": "RENVILLE COUNTY WEST SENIOR HIGH",
        "district": "RENVILLE COUNTY WEST SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270016301310",
    },
    {
        "school": "RENVILLE COUNTY WEST ELEMENTARY",
        "district": "RENVILLE COUNTY WEST SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270016301417",
    },
    {
        "school": "BOLD-BIRD ISLAND ELEMENTARY",
        "district": "BIRD ISLAND-OLIVIA-LAKE LILLIAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270566000144",
    },
    {
        "school": "BOLD Senior High School",
        "district": "BIRD ISLAND-OLIVIA-LAKE LILLIAN",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270566000147",
    },
    {
        "school": "GFW Intermediate School (Grade 4-6)",
        "district": "G.F.W.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271258000043",
    },
    {
        "school": "MORRISTOWN ELEMENTARY",
        "district": "WATERVILLE-ELYSIAN-MORRISTOWN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001301103",
    },
    {
        "school": "WATERVILLE-ELYSIAN-MORRISTOWN JR.",
        "district": "WATERVILLE-ELYSIAN-MORRISTOWN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001301104",
    },
    {
        "school": "HILLS-BEAVER CREEK ELEMENTARY",
        "district": "HILLS-BEAVER CREEK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271404000726",
    },
    {
        "school": "HILLS-BEAVER CREEK SECONDARY",
        "district": "HILLS-BEAVER CREEK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271404000727",
    },
    {
        "school": "LUVERNE ELEMENTARY",
        "district": "LUVERNE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271833000851",
    },
    {
        "school": "LUVERNE SENIOR HIGH",
        "district": "LUVERNE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271833000852",
    },
    {
        "school": "LUVERNE MIDDLE",
        "district": "LUVERNE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271833002471",
    },
    {
        "school": "GREENBUSH ELEMENTARY",
        "district": "GREENBUSH-MIDDLE RIVER SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010700920",
    },
    {
        "school": "Greenbush-Middle River Secondary",
        "district": "GREENBUSH-MIDDLE RIVER SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010700921",
    },
    {
        "school": "BADGER ELEMENTARY",
        "district": "BADGER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270354000162",
    },
    {
        "school": "BADGER SECONDARY",
        "district": "BADGER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270354000163",
    },
    {
        "school": "ROSEAU ELEMENTARY",
        "district": "ROSEAU PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273225001370",
    },
    {
        "school": "ROSEAU SECONDARY",
        "district": "ROSEAU PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273225001371",
    },
    {
        "school": "WARROAD ELEMENTARY",
        "district": "WARROAD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274185001744",
    },
    {
        "school": "WARROAD HIGH SCHOOL",
        "district": "WARROAD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274185001745",
    },
    {
        "school": "ANGLE INLET ELEMENTARY",
        "district": "WARROAD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274185002456",
    },
    {
        "school": "MINNESOTA NEW COUNTRY SCHOOL",
        "district": "MINNESOTA NEW COUNTRY SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009202487",
    },
    {
        "school": "SIBLEY EAST-ARLINGTON SENIOR HIGH",
        "district": "SIBLEY EAST SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010200134",
    },
    {
        "school": "SIBLEY EAST-GAYLORD ELEMENTARY",
        "district": "SIBLEY EAST SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010200624",
    },
    {
        "school": "Sibley East Middle School",
        "district": "SIBLEY EAST SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010200625",
    },
    {
        "school": "GFW Primary School (PreK-3)",
        "district": "G.F.W.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271258000042",
    },
    {
        "school": "GFW Junior/Sr High School (7-12)",
        "district": "G.F.W.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271258000044",
    },
    {
        "school": "HILLTOP ELEMENTARY",
        "district": "LE SUEUR-HENDERSON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271807000046",
    },
    {
        "school": "NRHEG ELEMENTARY",
        "district": "NRHEG SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270008900523",
    },
    {
        "school": "MIDWEST SPECIAL EDUCATION COOP.",
        "district": "MIDWEST SPECIAL EDUCATION COOP.",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004102356",
    },
    {
        "school": "CHOKIO-ALBERTA SECONDARY",
        "district": "CHOKIO-ALBERTA PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270894000361",
    },
    {
        "school": "CHOKIO-ALBERTA ELEMENTARY",
        "district": "CHOKIO-ALBERTA PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270894000362",
    },
    {
        "school": "HANCOCK ELEMENTARY",
        "district": "HANCOCK PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271338000688",
    },
    {
        "school": "HANCOCK SEC.",
        "district": "HANCOCK PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271338000689",
    },
    {
        "school": "APPLETON ELEMENTARY",
        "district": "LAC QUI PARLE VALLEY SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012500129",
    },
    {
        "school": "BENSON SECONDARY",
        "district": "BENSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270447000199",
    },
    {
        "school": "NORTHSIDE ELEMENTARY",
        "district": "BENSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270447000201",
    },
    {
        "school": "BENSON AREA LEARNING CENTER",
        "district": "BENSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270447002232",
    },
    {
        "school": "KERKHOVEN SECONDARY",
        "district": "KERKHOVEN-MURDOCK-SUNBURG",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271712000023",
    },
    {
        "school": "MURDOCK ELEMENTARY",
        "district": "KERKHOVEN-MURDOCK-SUNBURG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271712001890",
    },
    {
        "school": "Freshwater Education District ALC",
        "district": "Freshwater Education District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270001402222",
    },
    {
        "school": "LONG PRAIRIE-GREY EAGLE ELEMENTARY",
        "district": "LONG PRAIRIE-GREY EAGLE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010900680",
    },
    {
        "school": "LONG PRAIRIE-GREY SECONDARY SCHOOL",
        "district": "LONG PRAIRIE-GREY EAGLE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010900850",
    },
    {
        "school": "BERTHA ELEMENTARY",
        "district": "BERTHA-HEWITT PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270543000203",
    },
    {
        "school": "BERTHA SECONDARY",
        "district": "BERTHA-HEWITT PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270543000204",
    },
    {
        "school": "BROWERVILLE ELEMENTARY",
        "district": "BROWERVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270630000277",
    },
    {
        "school": "BROWERVILLE SECONDARY",
        "district": "BROWERVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270630000278",
    },
    {
        "school": "Staples-Motley Elementary",
        "district": "STAPLES-MOTLEY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273390001643",
    },
    {
        "school": "STAPLES-MOTLEY SENIOR HIGH",
        "district": "STAPLES-MOTLEY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273390001644",
    },
    {
        "school": "BROWNS VALLEY ELEMENTARY",
        "district": "Browns Valley Public School Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270711000279",
    },
    {
        "school": "BROWNS VALLEY MIDDLE",
        "district": "Browns Valley Public School Dist",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270711000280",
    },
    {
        "school": "PEARSON ELEMENTARY",
        "district": "WHEATON AREA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274233001783",
    },
    {
        "school": "WHEATON SECONDARY",
        "district": "WHEATON AREA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274233001784",
    },
    {
        "school": "WADENA-DEER CREEK ELEMENTARY",
        "district": "WADENA-DEER CREEK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002200431",
    },
    {
        "school": "WADENA-DEER CREEK SENIOR HIGH",
        "district": "WADENA-DEER CREEK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002201733",
    },
    {
        "school": "MENAHGA HIGH SCHOOL",
        "district": "MENAHGA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272058000916",
    },
    {
        "school": "MENAHGA ELEMENTARY",
        "district": "MENAHGA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272058000917",
    },
    {
        "school": "SEBEKA ELEMENTARY",
        "district": "SEBEKA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273297001435",
    },
    {
        "school": "SEBEKA SECONDARY",
        "district": "SEBEKA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273297001436",
    },
    {
        "school": "VERNDALE ELEMENTARY",
        "district": "VERNDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274092001712",
    },
    {
        "school": "VERNDALE SECONDARY",
        "district": "VERNDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274092001713",
    },
    {
        "school": "NRHEG SECONDARY",
        "district": "NRHEG SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270008901148",
    },
    {
        "school": "Waseca Area Learning Center",
        "district": "WASECA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274188001720",
    },
    {
        "school": "WASECA INTERMEDIATE SCHOOL",
        "district": "WASECA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274188001746",
    },
    {
        "school": "HARTLEY ELEMENTARY",
        "district": "WASECA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274188001747",
    },
    {
        "school": "WASECA SENIOR HIGH",
        "district": "WASECA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274188001749",
    },
    {
        "school": "WASECA JUNIOR HIGH",
        "district": "WASECA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274188002683",
    },
    {
        "school": "BUTTERFIELD ELEMENTARY",
        "district": "BUTTERFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270732000304",
    },
    {
        "school": "BUTTERFIELD SECONDARY",
        "district": "BUTTERFIELD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270732000305",
    },
    {
        "school": "MADELIA ELEMENTARY",
        "district": "MADELIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271857000859",
    },
    {
        "school": "MADELIA SECONDARY",
        "district": "MADELIA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271857000860",
    },
    {
        "school": "St. James Middle/High School",
        "district": "ST. JAMES PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273360001505",
    },
    {
        "school": "ST. JAMES NORTHSIDE ELEMENTARY",
        "district": "ST. JAMES PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273360001506",
    },
    {
        "school": "BERT RANEY ELEMENTARY SCHOOL",
        "district": "YELLOW MEDICINE EAST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009900676",
    },
    {
        "school": "E.C.H.O. CHARTER SCHOOL",
        "district": "E.C.H.O. CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270013902718",
    },
    {
        "school": "CANBY ELEMENTARY",
        "district": "CANBY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270747000321",
    },
    {
        "school": "CANBY SECONDARY",
        "district": "CANBY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270747000322",
    },
    {
        "school": "Wm. M. Kelley Secondary",
        "district": "LAKE SUPERIOR PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274074001697",
    },
    {
        "school": "WILLIAM KELLEY ELEMENTARY",
        "district": "LAKE SUPERIOR PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274074001698",
    },
    {
        "school": "MINNEHAHA ELEMENTARY",
        "district": "LAKE SUPERIOR PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274074001699",
    },
    {
        "school": "TWO HARBORS SECONDARY",
        "district": "LAKE SUPERIOR PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274074001701",
    },
    {
        "school": "SOLO",
        "district": "LAKE SUPERIOR PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274074002528",
    },
    {
        "school": "Brookside Early Childhood Sp Ed",
        "district": "ALBERT LEA PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270297003501",
    },
    {
        "school": "GLENVILLE EMMONS ELEMENTARY",
        "district": "GLENVILLE-EMMONS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270014800634",
    },
    {
        "school": "GLENVILLE-EMMONS SECONDARY",
        "district": "GLENVILLE-EMMONS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270014800635",
    },
    {
        "school": "ALBERT LEA SENIOR HIGH",
        "district": "ALBERT LEA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270297000068",
    },
    {
        "school": "HALVERSON ELEMENTARY",
        "district": "ALBERT LEA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270297000070",
    },
    {
        "school": "HAWTHORNE ELEMENTARY",
        "district": "ALBERT LEA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270297000071",
    },
    {
        "school": "LAKEVIEW ELEMENTARY",
        "district": "ALBERT LEA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270297000074",
    },
    {
        "school": "SIBLEY ELEMENTARY",
        "district": "ALBERT LEA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270297000077",
    },
    {
        "school": "SOUTHWEST MIDDLE",
        "district": "ALBERT LEA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270297000078",
    },
    {
        "school": "ALBERT LEA AREA LEARNING CENTER",
        "district": "ALBERT LEA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270297002228",
    },
    {
        "school": "ALDEN-CONGER ELEMENTARY",
        "district": "ALDEN-CONGER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270303000079",
    },
    {
        "school": "ALDEN-CONGER SECONDARY",
        "district": "ALDEN-CONGER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270303000080",
    },
    {
        "school": "EARLY EDUCATION CENTER",
        "district": "ALEXANDRIA PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270306003516",
    },
    {
        "school": "RUNESTONE REGIONAL LEARNING CENTER",
        "district": "RUNESTONE AREA ED. DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270001602224",
    },
    {
        "school": "CARLOS ELEMENTARY",
        "district": "ALEXANDRIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270306000082",
    },
    {
        "school": "DISCOVERY MIDDLE SCHOOL",
        "district": "ALEXANDRIA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270306000083",
    },
    {
        "school": "GARFIELD ELEMENTARY",
        "district": "ALEXANDRIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270306000084",
    },
    {
        "school": "ALEXANDRIA AREA HIGH SCHOOL",
        "district": "ALEXANDRIA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270306000085",
    },
    {
        "school": "LINCOLN ELEMENTARY",
        "district": "ALEXANDRIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270306000086",
    },
    {
        "school": "MILTONA ELEMENTARY",
        "district": "ALEXANDRIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270306000087",
    },
    {
        "school": "WOODLAND ELEMENTARY SCHOOL",
        "district": "ALEXANDRIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270306000088",
    },
    {
        "school": "VOYAGER ELEMENTARY",
        "district": "ALEXANDRIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270306002229",
    },
    {
        "school": "OSAKIS ELEMENTARY",
        "district": "OSAKIS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272514001203",
    },
    {
        "school": "OSAKIS SECONDARY",
        "district": "OSAKIS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272514001204",
    },
    {
        "school": "MIDDLE LEVEL LEARNING CENTER",
        "district": "RUNESTONE AREA ED. DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270001602751",
    },
    {
        "school": "AUSTIN AREA LEARNING CNTR. - SUMMER",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270345003190",
    },
    {
        "school": "NEW DOMINION ACADEMY",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270345003192",
    },
    {
        "school": "AUSTIN COMMUNITY LEARNING CENTER",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270345003525",
    },
    {
        "school": "GRAND MEADOW SENIOR HIGH",
        "district": "GRAND MEADOW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271314004160",
    },
    {
        "school": "SOUTHLAND SENIOR HIGH",
        "district": "SOUTHLAND PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270272000052",
    },
    {
        "school": "SOUTHLAND ELEMENTARY",
        "district": "SOUTHLAND PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270272000053",
    },
    {
        "school": "SOUTHLAND MIDDLE",
        "district": "SOUTHLAND PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270272000054",
    },
    {
        "school": "AUSTIN SENIOR HIGH",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270345000148",
    },
    {
        "school": "BANFIELD ELEMENTARY",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270345000149",
    },
    {
        "school": "ELLIS MIDDLE",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270345000150",
    },
    {
        "school": "NEVELN ELEMENTARY",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270345000153",
    },
    {
        "school": "SUMNER ELEMENTARY",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270345000156",
    },
    {
        "school": "WOODSON KINDERGARTEN CENTER",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270345000968",
    },
    {
        "school": "SOUTHGATE ELEMENTARY",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270345002230",
    },
    {
        "school": "AUSTIN AREA LEARNING CENTER",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270345002231",
    },
    {
        "school": "GRAND MEADOW ELEMENTARY",
        "district": "GRAND MEADOW PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271314000659",
    },
    {
        "school": "GRAND MEADOW MIDDLE",
        "district": "GRAND MEADOW PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271314000660",
    },
    {
        "school": "LEROY ELEMENTARY",
        "district": "LEROY-OSTRANDER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271806000831",
    },
    {
        "school": "LEROY SECONDARY",
        "district": "LEROY-OSTRANDER PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271806000832",
    },
    {
        "school": "LYLE ELEMENTARY",
        "district": "LYLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271836000853",
    },
    {
        "school": "LYLE SECONDARY",
        "district": "LYLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271836000854",
    },
    {
        "school": "TREKNORTH HIGH SCHOOL",
        "district": "TREKNORTH HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034504166",
    },
    {
        "school": "VOYAGEURS EXPEDITIONARY SCHOOL",
        "district": "VOYAGEURS EXPEDITIONARY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034604167",
    },
    {
        "school": "BEMIDJI MIDDLE ALP",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270444003269",
    },
    {
        "school": "BEMIDJI SENIOR LUMBERJACK ALC",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270444004159",
    },
    {
        "school": "Lakeside Learning Center",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270444004194",
    },
    {
        "school": "RED LAKE EARLY CHILDHOOD CENTER",
        "district": "RED LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273051003303",
    },
    {
        "school": "NORTH COUNTRY VOC. COOP. CTR.",
        "district": "NORTH COUNTRY VOC. COOP. CTR.",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "MN",
        "nces_id": "270003102344",
    },
    {
        "school": "BEMIDJI REGIONAL INTERDIST. COUNCIL",
        "district": "BEMIDJI REGIONAL INTERDIST. COUNCIL",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270005102371",
    },
    {
        "school": "SCHOOLCRAFT LEARNING COMMUNITY CHTR",
        "district": "SCHOOLCRAFT LEARNING COMMUNITY CHTR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270022503464",
    },
    {
        "school": "BEMIDJI SENIOR HIGH",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270444000190",
    },
    {
        "school": "CENTRAL ELEMENTARY",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270444000191",
    },
    {
        "school": "LINCOLN ELEMENTARY",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270444000192",
    },
    {
        "school": "HORACE MAY ELEMENTARY",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270444000193",
    },
    {
        "school": "NORTHERN ELEMENTARY",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270444000194",
    },
    {
        "school": "J.W. SMITH ELEMENTARY",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270444000196",
    },
    {
        "school": "SOLWAY ELEMENTARY",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270444000197",
    },
    {
        "school": "FIRST CITY SCHOOL",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270444000313",
    },
    {
        "school": "BEMIDJI MIDDLE",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270444002031",
    },
    {
        "school": "BEMIDJI AREA LEARNING CENTER",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270444002331",
    },
    {
        "school": "BLACKDUCK ELEMENTARY",
        "district": "BLACKDUCK PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270573000212",
    },
    {
        "school": "BLACKDUCK SECONDARY",
        "district": "BLACKDUCK PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270573000213",
    },
    {
        "school": "KELLIHER ELEMENTARY",
        "district": "KELLIHER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271701000786",
    },
    {
        "school": "KELLIHER SECONDARY",
        "district": "KELLIHER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271701000787",
    },
    {
        "school": "RED LAKE ALTERNATIVE LEARNING",
        "district": "RED LAKE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273051000325",
    },
    {
        "school": "PONEMAH ELEMENTARY",
        "district": "RED LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273051001301",
    },
    {
        "school": "RED LAKE ELEMENTARY",
        "district": "RED LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273051001302",
    },
    {
        "school": "RED LAKE SECONDARY",
        "district": "RED LAKE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273051001303",
    },
    {
        "school": "RED LAKE MIDDLE SCHOOL",
        "district": "RED LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273051002427",
    },
    {
        "school": "RED LAKE MIDDLE LEVEL ALC",
        "district": "RED LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273051002793",
    },
    {
        "school": "CASS LAKE-BENA MIDDLE SCHOOL",
        "district": "CASS LAKE-BENA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270807003181",
    },
    {
        "school": "LITTLE SAND",
        "district": "NORTHLAND COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273087003507",
    },
    {
        "school": "FORESTVIEW MIDDLE",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270609004196",
    },
    {
        "school": "PILLAGER AREA CHARTER SCHOOL",
        "district": "PILLAGER AREA CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270019103144",
    },
    {
        "school": "W.H.A. ELEMENTARY",
        "district": "WALKER-HACKENSACK-AKELEY SCHL. DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270291001736",
    },
    {
        "school": "WALKER-HACKENSACK-AKELEY SEC.",
        "district": "WALKER-HACKENSACK-AKELEY SCHL. DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270291001737",
    },
    {
        "school": "W. H. A.  Alternative Program",
        "district": "WALKER-HACKENSACK-AKELEY SCHL. DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270291002428",
    },
    {
        "school": "CASS LAKE-BENA ELEMENTARY",
        "district": "CASS LAKE-BENA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270807000330",
    },
    {
        "school": "CASS LAKE-BENA SECONDARY",
        "district": "CASS LAKE-BENA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270807000331",
    },
    {
        "school": "CASS LAKE-BENA AREA LRNG. CNTR.",
        "district": "CASS LAKE-BENA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270807002234",
    },
    {
        "school": "PILLAGER ELEMENTARY",
        "district": "PILLAGER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272835001253",
    },
    {
        "school": "PILLAGER SENIOR HIGH SCHOOL",
        "district": "PILLAGER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272835001254",
    },
    {
        "school": "PINE RIVER-BACKUS ELEMENTARY",
        "district": "PINE RIVER-BACKUS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272897000039",
    },
    {
        "school": "PINE RIVER-BACKUS HIGH SCHOOL",
        "district": "PINE RIVER-BACKUS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272897000041",
    },
    {
        "school": "PINE RIVER-BACKUS AREA LEARNING CTR",
        "district": "PINE RIVER-BACKUS SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272897002692",
    },
    {
        "school": "PINE RIVER-BACKUS MIDLEVEL ALC",
        "district": "PINE RIVER-BACKUS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272897003011",
    },
    {
        "school": "PRB PEQUOT LAKES MIDLEVEL ALC",
        "district": "PINE RIVER-BACKUS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272897003013",
    },
    {
        "school": "Northland Elementary",
        "district": "NORTHLAND COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273087001307",
    },
    {
        "school": "NORTHLAND SECONDARY",
        "district": "NORTHLAND COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273087001308",
    },
    {
        "school": "CROSSLAKE COMMUNITY CHARTER SCHOOL",
        "district": "CROSSLAKE COMMUNITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270021803475",
    },
    {
        "school": "BAXTER ELEMENTARY",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270609000248",
    },
    {
        "school": "BRAINERD SENIOR HIGH",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270609000249",
    },
    {
        "school": "GARFIELD ELEMENTARY",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270609000252",
    },
    {
        "school": "HARRISON ELEMENTARY",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270609000254",
    },
    {
        "school": "LOWELL ELEMENTARY",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270609000256",
    },
    {
        "school": "NISSWA ELEMENTARY",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270609000257",
    },
    {
        "school": "RIVERSIDE ELEMENTARY",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270609000259",
    },
    {
        "school": "LINCOLN EDUCATION CENTER",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270609000468",
    },
    {
        "school": "ISD 181 LEARNING CENTER",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270609001874",
    },
    {
        "school": "BRAINERD EARLY CHILDHOOD SP. ED.",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270609002430",
    },
    {
        "school": "MIDDLE LEVEL ALTERNATIVE PROGRAM",
        "district": "BRAINERD PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270609002982",
    },
    {
        "school": "CUYUNA RANGE ELEMENTARY",
        "district": "CROSBY-IRONTON PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270975000291",
    },
    {
        "school": "CROSBY-IRONTON SECONDARY",
        "district": "CROSBY-IRONTON PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270975000417",
    },
    {
        "school": "EAGLE VIEW ELEMENTARY",
        "district": "PEQUOT LAKES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272820001244",
    },
    {
        "school": "PEQUOT LAKES SENIOR HIGH",
        "district": "PEQUOT LAKES PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272820001245",
    },
    {
        "school": "PEQUOT LAKES MIDDLE",
        "district": "PEQUOT LAKES PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272820003069",
    },
    {
        "school": "MASH-KA-WISEN",
        "district": "CARLTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270759003605",
    },
    {
        "school": "NORTHEAST SERVICE COOPERATIVE OLL",
        "district": "REGION 3 - NORTHEAST SERVICE COOP",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270008403592",
    },
    {
        "school": "NORTH SHORE COMMUNITY SCHOOL",
        "district": "NORTH SHORE COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270020801700",
    },
    {
        "school": "HARBOR CITY INTERNATIONAL CHARTER",
        "district": "HARBOR CITY INTERNATIONAL CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270020903270",
    },
    {
        "school": "NORTHLAND LEARNING CENTER 040",
        "district": "NORTHLAND LEARNING CENTER",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270022403583",
    },
    {
        "school": "NORTHLAND LEARNING CENTER 050",
        "district": "NORTHLAND LEARNING CENTER",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270022403584",
    },
    {
        "school": "NORTHLAND LEARNING CENTER 060",
        "district": "NORTHLAND LEARNING CENTER",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270022403619",
    },
    {
        "school": "EAST RANGE ACADEMY OF TECH-SCIENCE",
        "district": "EAST RANGE ACADEMY OF TECH-SCIENCE",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270029103722",
    },
    {
        "school": "BARNUM ELEMENTARY",
        "district": "BARNUM PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270369000171",
    },
    {
        "school": "BARNUM SECONDARY",
        "district": "BARNUM PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270369000172",
    },
    {
        "school": "CARLTON SECONDARY",
        "district": "CARLTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270759000327",
    },
    {
        "school": "SOUTH TERRACE ELEMENTARY",
        "district": "CARLTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270759000328",
    },
    {
        "school": "CHURCHILL ELEMENTARY",
        "district": "CLOQUET PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270942000380",
    },
    {
        "school": "CLOQUET MIDDLE",
        "district": "CLOQUET PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270942000381",
    },
    {
        "school": "CLOQUET SENIOR",
        "district": "CLOQUET PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270942000382",
    },
    {
        "school": "WASHINGTON ELEMENTARY",
        "district": "CLOQUET PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270942000384",
    },
    {
        "school": "CLOQUET AREA ALT. ED. PROGRAMS",
        "district": "CLOQUET PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270942002236",
    },
    {
        "school": "CLOQUET EARLY CHILDHOOD EDUCATION",
        "district": "CLOQUET PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270942003063",
    },
    {
        "school": "SHARED TIME",
        "district": "CLOQUET PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270942003064",
    },
    {
        "school": "CROMWELL-WRIGHT SECONDARY",
        "district": "CROMWELL-WRIGHT PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270969000409",
    },
    {
        "school": "CROMWELL-WRIGHT ELEMENTARY",
        "district": "CROMWELL-WRIGHT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270969000410",
    },
    {
        "school": "MOOSE LAKE ELEMENTARY",
        "district": "MOOSE LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272145001093",
    },
    {
        "school": "MOOSE LAKE SECONDARY",
        "district": "MOOSE LAKE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272145001094",
    },
    {
        "school": "LINCOLN SECONDARY",
        "district": "ESKO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273888001681",
    },
    {
        "school": "WINTERQUIST ELEMENTARY",
        "district": "ESKO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273888001683",
    },
    {
        "school": "WRENSHALL ELEMENTARY",
        "district": "WRENSHALL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274419001842",
    },
    {
        "school": "WRENSHALL SECONDARY",
        "district": "WRENSHALL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274419001843",
    },
    {
        "school": "Bethany Crisis Shelter",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271104001595",
    },
    {
        "school": "MERRITT ELEMENTARY",
        "district": "MOUNTAIN IRON-BUHL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000101610",
    },
    {
        "school": "MOUNTAIN IRON-BUHL SECONDARY",
        "district": "MOUNTAIN IRON-BUHL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000101613",
    },
    {
        "school": "BABBITT ELEMENTARY",
        "district": "ST. LOUIS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000800158",
    },
    {
        "school": "NORTHEAST RANGE SECONDARY",
        "district": "ST. LOUIS COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000800159",
    },
    {
        "school": "CHERRY ELEMENTARY",
        "district": "ST. LOUIS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000801513",
    },
    {
        "school": "CHERRY SECONDARY",
        "district": "ST. LOUIS COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000801514",
    },
    {
        "school": "TOWER-SOUDAN ELEMENTARY",
        "district": "ST. LOUIS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000801684",
    },
    {
        "school": "EVELETH-GILBERT SENIOR HIGH",
        "district": "EVELETH-GILBERT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002100539",
    },
    {
        "school": "FRANKLIN ELEMENTARY",
        "district": "EVELETH-GILBERT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002100540",
    },
    {
        "school": "EVELETH-GILBERT JUNIOR HIGH",
        "district": "EVELETH-GILBERT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002100628",
    },
    {
        "school": "NELLE SHEAN ELEMENTARY",
        "district": "EVELETH-GILBERT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002100629",
    },
    {
        "school": "EAST RANGE SEC. TECHNICAL CENTER",
        "district": "EAST RANGE SEC. TECHNICAL CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MN",
        "nces_id": "270003402348",
    },
    {
        "school": "NORTH STAR ACADEMY",
        "district": "DULUTH PUBLIC SCHOOLS ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270013302711",
    },
    {
        "school": "RALEIGH PRIMARY/EL ACADEMY",
        "district": "DULUTH PUBLIC SCHOOLS ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270013303031",
    },
    {
        "school": "NORTHLAND LEARNING CENTER 020",
        "district": "NORTHLAND LEARNING CENTER",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270022403476",
    },
    {
        "school": "NORTHLAND LEARNING CENTER 010",
        "district": "NORTHLAND LEARNING CENTER",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270022403477",
    },
    {
        "school": "CHISHOLM ELEMENTARY",
        "district": "CHISHOLM PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270891000356",
    },
    {
        "school": "CHISHOLM SECONDARY",
        "district": "CHISHOLM PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270891000357",
    },
    {
        "school": "VAUGHAN ELEMENTARY",
        "district": "CHISHOLM PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270891000360",
    },
    {
        "school": "CONGDON ELEMENTARY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000459",
    },
    {
        "school": "DENFELD HIGH SCHOOL",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000460",
    },
    {
        "school": "EAST HIGH SCHOOL",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000461",
    },
    {
        "school": "HOMECROFT ELEMENTARY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000466",
    },
    {
        "school": "LAKEWOOD ELEMENTARY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000471",
    },
    {
        "school": "LESTER PARK ELEMENTARY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000472",
    },
    {
        "school": "LOWELL ELEMENTARY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000475",
    },
    {
        "school": "LAURA MACARTHUR ELEMENTARY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000476",
    },
    {
        "school": "MYERS-WILKINS ELEMENTARY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000479",
    },
    {
        "school": "PIEDMONT ELEMENTARY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000482",
    },
    {
        "school": "STOWE ELEMENTARY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000485",
    },
    {
        "school": "ORDEAN EAST MIDDLE SCHOOL",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104000489",
    },
    {
        "school": "MERRITT CREEK ACADEMY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271104001562",
    },
    {
        "school": "CHESTER CREEK ACADEMY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271104001574",
    },
    {
        "school": "Rockridge Academy",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271104001577",
    },
    {
        "school": "Arrowhead Academy",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271104001589",
    },
    {
        "school": "SUPERIOR ACADEMY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271104001600",
    },
    {
        "school": "LAKESIDE ACADEMY",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271104001602",
    },
    {
        "school": "DULUTH AREA LEARNING CENTER",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271104002237",
    },
    {
        "school": "SPECIAL ED. N.P.",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271104002554",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL EDUCATION",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271104002555",
    },
    {
        "school": "LINCOLN PARK MIDDLE SCHOOL",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104002788",
    },
    {
        "school": "WASHINGTON ELEMENTARY",
        "district": "ELY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271152000529",
    },
    {
        "school": "MEMORIAL HIGH SCHOOL",
        "district": "ELY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271152000530",
    },
    {
        "school": "FLOODWOOD ELEMENTARY",
        "district": "FLOODWOOD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271221000588",
    },
    {
        "school": "FLOODWOOD SECONDARY",
        "district": "FLOODWOOD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271221000589",
    },
    {
        "school": "HERMANTOWN ELEMENTARY",
        "district": "HERMANTOWN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271392000715",
    },
    {
        "school": "HERMANTOWN SENIOR HIGH",
        "district": "HERMANTOWN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271392000716",
    },
    {
        "school": "HERMANTOWN MIDDLE",
        "district": "HERMANTOWN PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271392002143",
    },
    {
        "school": "HERMANTOWN EARLY CHILDHOOD",
        "district": "HERMANTOWN PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271392002677",
    },
    {
        "school": "GREENHAVEN ELEMENTARY",
        "district": "HIBBING PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271398001520",
    },
    {
        "school": "WASHINGTON ELEMENTARY",
        "district": "HIBBING PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271398001528",
    },
    {
        "school": "LINCOLN ELEMENTARY",
        "district": "HIBBING PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271398001529",
    },
    {
        "school": "HIBBING HIGH",
        "district": "HIBBING PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271398001539",
    },
    {
        "school": "MESABI AREA LEARNING CENTER",
        "district": "HIBBING PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271398001547",
    },
    {
        "school": "PROCTOR SENIOR HIGH",
        "district": "PROCTOR PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273009001551",
    },
    {
        "school": "A.I. JEDLICKA MIDDLE SCHOOL",
        "district": "PROCTOR PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273009001552",
    },
    {
        "school": "BAY VIEW ELEMENTARY",
        "district": "PROCTOR PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273009001557",
    },
    {
        "school": "PIKE LAKE ELEMENTARY",
        "district": "PROCTOR PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273009001559",
    },
    {
        "school": "N.E. REGIONAL CORRECTION CNTR.",
        "district": "PROCTOR PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273009001561",
    },
    {
        "school": "NETT LAKE ELEMENTARY",
        "district": "NETT LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273372001508",
    },
    {
        "school": "ROOSEVELT ELEMENTARY",
        "district": "VIRGINIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274104001716",
    },
    {
        "school": "VIRGINIA SECONDARY",
        "district": "VIRGINIA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274104001718",
    },
    {
        "school": "PARKVIEW ELEMENTARY",
        "district": "VIRGINIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274104002552",
    },
    {
        "school": "MESABI EAST ELEMENTARY",
        "district": "MESABI EAST SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279145002323",
    },
    {
        "school": "MESABI EAST SECONDARY",
        "district": "MESABI EAST SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279145002326",
    },
    {
        "school": "WINNEBAGO",
        "district": "SOUTHERN PLAINS EDUCATION COOP.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270004602958",
    },
    {
        "school": "SOUTHERN PLAINS EDUCATION COOP.",
        "district": "SOUTHERN PLAINS EDUCATION COOP.",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004602365",
    },
    {
        "school": "SOUTHERN PLAINS AREA LEARNING CNTR.",
        "district": "SOUTHERN PLAINS EDUCATION COOP.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270004602369",
    },
    {
        "school": "FAIRMONT JR./SR. HIGH SCHOOL",
        "district": "FAIRMONT AREA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012400553",
    },
    {
        "school": "FAIRMONT ELEMENTARY SCHOOL",
        "district": "FAIRMONT AREA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012400554",
    },
    {
        "school": "Granada Huntley East Chain Elem Sch",
        "district": "Granada Huntley East Chain",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271304000152",
    },
    {
        "school": "Granada Huntley East Chain High Sch",
        "district": "Granada Huntley East Chain",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271304000155",
    },
    {
        "school": "SHERBURN ELEMENTARY",
        "district": "MARTIN COUNTY WEST SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271896000067",
    },
    {
        "school": "TRIMONT ELEMENTARY",
        "district": "MARTIN COUNTY WEST SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271896000072",
    },
    {
        "school": "WELCOME ELEMENTARY",
        "district": "MARTIN COUNTY WEST SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271896000073",
    },
    {
        "school": "MARTIN COUNTY WEST SENIOR HIGH",
        "district": "MARTIN COUNTY WEST SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271896000075",
    },
    {
        "school": "MARTIN COUNTY WEST JUNIOR HIGH",
        "district": "MARTIN COUNTY WEST SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271896000076",
    },
    {
        "school": "TRUMAN ELEMENTARY",
        "district": "TRUMAN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274068001692",
    },
    {
        "school": "TRUMAN SECONDARY",
        "district": "TRUMAN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274068001693",
    },
    {
        "school": "PROBSTFIELD CENTER FOR EDUCATION",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272142003508",
    },
    {
        "school": "Robert Asp Elementary",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272142003509",
    },
    {
        "school": "ELLEN HOPKINS ELEMENTARY",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272142003510",
    },
    {
        "school": "S.G.REINERTSEN ELEMENTARY",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272142003511",
    },
    {
        "school": "HORIZON MIDDLE SCHOOL",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272142003512",
    },
    {
        "school": "BARNESVILLE ELEMENTARY",
        "district": "BARNESVILLE PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270366000169",
    },
    {
        "school": "BARNESVILLE SECONDARY",
        "district": "BARNESVILLE PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270366000170",
    },
    {
        "school": "DILWORTH ELEMENTARY",
        "district": "DILWORTH-GLYNDON-FELTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271026000447",
    },
    {
        "school": "DILWORTH-GLYNDON-FELTON MIDDLE SCH",
        "district": "DILWORTH-GLYNDON-FELTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271026000448",
    },
    {
        "school": "DILWORTH-GLYNDON-FELTON SENIOR HIGH",
        "district": "DILWORTH-GLYNDON-FELTON",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271026000642",
    },
    {
        "school": "GLYNDON-FELTON ELEMENTARY",
        "district": "DILWORTH-GLYNDON-FELTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271026002690",
    },
    {
        "school": "HAWLEY ELEMENTARY",
        "district": "HAWLEY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271356000698",
    },
    {
        "school": "HAWLEY SECONDARY",
        "district": "HAWLEY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271356000699",
    },
    {
        "school": "SPRING PRAIRIE ELEMENTARY",
        "district": "HAWLEY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271356002240",
    },
    {
        "school": "West Central Academy-S",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272142000413",
    },
    {
        "school": "Red River Area Learning Center",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272142000462",
    },
    {
        "school": "CLAY COUNTY OUTREACH CENTER",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272142000463",
    },
    {
        "school": "MOORHEAD HIGH SCHOOL",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272142001084",
    },
    {
        "school": "West Central Academy-N",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272142002799",
    },
    {
        "school": "ULEN-HITTERDAL ELEMENTARY",
        "district": "ULEN-HITTERDAL PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274081001704",
    },
    {
        "school": "ULEN-HITTERDAL SECONDARY",
        "district": "ULEN-HITTERDAL PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274081001705",
    },
    {
        "school": "PRAIRIE CREEK COMMUNITY SCHOOL",
        "district": "PRAIRIE CREEK COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270021203273",
    },
    {
        "school": "ARCADIA CHARTER SCHOOL",
        "district": "ARCADIA CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270035504151",
    },
    {
        "school": "FARIBAULT DAY SCHOOL ALC",
        "district": "FARIBAULT PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271176003372",
    },
    {
        "school": "SECONDARY AREA LEARNING CNTR SUMMER",
        "district": "FARIBAULT PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271176004206",
    },
    {
        "school": "MN ACADEMY FOR THE DEAF",
        "district": "MINNESOTA STATE ACADEMIES",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270012902409",
    },
    {
        "school": "MN ACADEMY FOR THE BLIND",
        "district": "MINNESOTA STATE ACADEMIES",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270012903056",
    },
    {
        "school": "NERSTRAND CHARTER SCHOOL",
        "district": "NERSTRAND CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270017903047",
    },
    {
        "school": "DISCOVERY PUBLIC SCHOOL FARIBAULT",
        "district": "DISCOVERY PUBLIC SCHOOL FARIBAULT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270019203145",
    },
    {
        "school": "FARIBAULT MIDDLE",
        "district": "FARIBAULT PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271176000557",
    },
    {
        "school": "FARIBAULT SENIOR HIGH",
        "district": "FARIBAULT PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271176000558",
    },
    {
        "school": "JEFFERSON ELEMENTARY",
        "district": "FARIBAULT PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271176000561",
    },
    {
        "school": "LINCOLN ELEMENTARY",
        "district": "FARIBAULT PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271176000562",
    },
    {
        "school": "FARIBAULT AREA LEARNING CENTER",
        "district": "FARIBAULT PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271176001497",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL EDUCATION",
        "district": "FARIBAULT PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271176001498",
    },
    {
        "school": "ROOSEVELT ELEMENTARY",
        "district": "FARIBAULT PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271176002675",
    },
    {
        "school": "GREENVALE PARK ELEMENTARY",
        "district": "NORTHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272388001180",
    },
    {
        "school": "NORTHFIELD MIDDLE",
        "district": "NORTHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272388001182",
    },
    {
        "school": "NORTHFIELD SENIOR HIGH",
        "district": "NORTHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272388001183",
    },
    {
        "school": "SIBLEY ELEMENTARY",
        "district": "NORTHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272388001184",
    },
    {
        "school": "LONGFELLOW ELEMENTARY",
        "district": "NORTHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272388001499",
    },
    {
        "school": "NORTHFIELD AREA LEARNING CENTER",
        "district": "NORTHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272388001501",
    },
    {
        "school": "BRIDGEWATER ELEMENTARY",
        "district": "NORTHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272388002841",
    },
    {
        "school": "BATTLE LAKE ELEMENTARY",
        "district": "BATTLE LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270375000175",
    },
    {
        "school": "BATTLE LAKE SECONDARY",
        "district": "BATTLE LAKE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270375000176",
    },
    {
        "school": "ADAMS ELEMENTARY",
        "district": "FERGUS FALLS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271188000571",
    },
    {
        "school": "CLEVELAND ELEMENTARY",
        "district": "FERGUS FALLS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271188000574",
    },
    {
        "school": "Kennedy High School",
        "district": "FERGUS FALLS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271188000578",
    },
    {
        "school": "MCKINLEY ELEMENTARY",
        "district": "FERGUS FALLS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271188000581",
    },
    {
        "school": "FERGUS FALLS AREA LEARNING CENTER",
        "district": "FERGUS FALLS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271188001021",
    },
    {
        "school": "HENNING ELEMENTARY",
        "district": "HENNING PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271386000711",
    },
    {
        "school": "HENNING SECONDARY",
        "district": "HENNING PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271386000712",
    },
    {
        "school": "NEW YORK MILLS ELEMENTARY",
        "district": "NEW YORK MILLS PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272352001024",
    },
    {
        "school": "NEW YORK MILLS SECONDARY",
        "district": "NEW YORK MILLS PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272352001156",
    },
    {
        "school": "PARKERS PRAIRIE ELEMENTARY",
        "district": "PARKERS PRAIRIE PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272811001237",
    },
    {
        "school": "PARKERS PRAIRIE SECONDARY",
        "district": "PARKERS PRAIRIE PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272811001238",
    },
    {
        "school": "VIKING ELEMENTARY SCHOOL",
        "district": "PELICAN RAPIDS PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272817001242",
    },
    {
        "school": "PELICAN RAPIDS SECONDARY",
        "district": "PELICAN RAPIDS PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272817001243",
    },
    {
        "school": "PERHAM AREA LEARNING CENTER",
        "district": "PERHAM-DENT PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272823001023",
    },
    {
        "school": "HEART OF THE LAKE ELEMENTARY",
        "district": "PERHAM-DENT PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272823001247",
    },
    {
        "school": "PERHAM SENIOR HIGH",
        "district": "PERHAM-DENT PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272823001248",
    },
    {
        "school": "PRAIRIE WIND MIDDLE",
        "district": "PERHAM-DENT PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272823002535",
    },
    {
        "school": "UNDERWOOD ELEMENTARY",
        "district": "UNDERWOOD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274083001706",
    },
    {
        "school": "UNDERWOOD SECONDARY",
        "district": "UNDERWOOD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274083001707",
    },
    {
        "school": "LAKES COUNTRY YOUTH EDUC SVCS",
        "district": "REGION 4-LAKES COUNTRY SERVICE COOP",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270008302417",
    },
    {
        "school": "CROOKSTON PRE-K PROGRAM",
        "district": "CROOKSTON PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270972003493",
    },
    {
        "school": "CLIMAX SECONDARY",
        "district": "CLIMAX-SHELLY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270936000376",
    },
    {
        "school": "CLIMAX ELEMENTARY",
        "district": "CLIMAX-SHELLY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270936000377",
    },
    {
        "school": "CROOKSTON SECONDARY",
        "district": "CROOKSTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270972000412",
    },
    {
        "school": "HIGHLAND ELEMENTARY",
        "district": "CROOKSTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270972000414",
    },
    {
        "school": "WASHINGTON ELEMENTARY",
        "district": "CROOKSTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270972000416",
    },
    {
        "school": "NEW PATHS AREA LEARNING CENTER",
        "district": "CROOKSTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270972001029",
    },
    {
        "school": "NORTHERN LIGHTS ACADEMY",
        "district": "CROOKSTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270972001030",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "EAST GRAND FORKS PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271113000494",
    },
    {
        "school": "SOUTH POINT ELEMENTARY",
        "district": "EAST GRAND FORKS PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271113000495",
    },
    {
        "school": "EAST GRAND FORKS SENIOR HIGH",
        "district": "EAST GRAND FORKS PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271113000496",
    },
    {
        "school": "NEW HEIGHTS ELEMENTARY",
        "district": "EAST GRAND FORKS PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271113000497",
    },
    {
        "school": "FERTILE-BELTRAMI ELEMENTARY",
        "district": "FERTILE-BELTRAMI SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271191000582",
    },
    {
        "school": "FERTILE-BELTRAMI SECONDARY",
        "district": "FERTILE-BELTRAMI SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271191000583",
    },
    {
        "school": "FISHER SECONDARY",
        "district": "FISHER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271218000586",
    },
    {
        "school": "FISHER ELEMENTARY",
        "district": "FISHER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271218000587",
    },
    {
        "school": "FOSSTON SECONDARY",
        "district": "FOSSTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271230000602",
    },
    {
        "school": "MAGELSSEN ELEMENTARY",
        "district": "FOSSTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271230000603",
    },
    {
        "school": "WIN-E-MAC ELEMENTARY",
        "district": "WIN-E-MAC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279144902320",
    },
    {
        "school": "WIN-E-MAC SECONDARY",
        "district": "WIN-E-MAC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279144902322",
    },
    {
        "school": "NEW CENTURY ACADEMY",
        "district": "NEW CENTURY ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270021403275",
    },
    {
        "school": "NEW DISCOVERIES MONTESSORI ACADEMY",
        "district": "NEW DISCOVERIES MONTESSORI ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270027703616",
    },
    {
        "school": "CORNERSTONE",
        "district": "HUTCHINSON PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271497003189",
    },
    {
        "school": "HUTCHINSON MIDDLE SCHOOL A.L.C.",
        "district": "HUTCHINSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271497003522",
    },
    {
        "school": "HUTCHINSON TRANSITION ASSISTANCE PG",
        "district": "HUTCHINSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271497003524",
    },
    {
        "school": "GLENCOE-SILVER LAKE SENIOR HIGH",
        "district": "GLENCOE-SILVER LAKE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012800630",
    },
    {
        "school": "Lincoln Elementary",
        "district": "GLENCOE-SILVER LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012800632",
    },
    {
        "school": "LAKESIDE ELEMENTARY",
        "district": "GLENCOE-SILVER LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012801444",
    },
    {
        "school": "GSL Junior High School",
        "district": "GLENCOE-SILVER LAKE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012801445",
    },
    {
        "school": "LESTER PRAIRIE ELEMENTARY",
        "district": "LESTER PRAIRIE PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270264000048",
    },
    {
        "school": "LESTER PRAIRIE SECONDARY",
        "district": "LESTER PRAIRIE PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270264000049",
    },
    {
        "school": "HUTCHINSON PARK ELEMENTARY",
        "district": "HUTCHINSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271497000754",
    },
    {
        "school": "HUTCHINSON MIDDLE",
        "district": "HUTCHINSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271497000755",
    },
    {
        "school": "HUTCHINSON SENIOR HIGH",
        "district": "HUTCHINSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271497000756",
    },
    {
        "school": "CROW RIVER AREA LEARNING CENTER",
        "district": "HUTCHINSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271497000955",
    },
    {
        "school": "HUTCHINSON WEST ELEMENTARY",
        "district": "HUTCHINSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271497002198",
    },
    {
        "school": "CALEDONIA SENIOR HIGH",
        "district": "CALEDONIA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270738003188",
    },
    {
        "school": "MINNESOTA VIRTUAL ACADEMY",
        "district": "HOUSTON PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271428003187",
    },
    {
        "school": "LA CRESCENT MONTESSORI & STEM ACAD",
        "district": "LA CRESCENT MONTESSORI & STEM SCHOO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270017803046",
    },
    {
        "school": "RIDGEWAY COMMUNITY SCHOOL",
        "district": "RIDGEWAY COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270019403147",
    },
    {
        "school": "CALEDONIA ELEMENTARY",
        "district": "CALEDONIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270738000309",
    },
    {
        "school": "CALEDONIA MIDDLE",
        "district": "CALEDONIA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270738000310",
    },
    {
        "school": "HOUSTON ELEMENTARY",
        "district": "HOUSTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271428000748",
    },
    {
        "school": "HOUSTON SECONDARY",
        "district": "HOUSTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271428000749",
    },
    {
        "school": "SUMMIT LEARNING PROGRAM",
        "district": "HOUSTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271428002993",
    },
    {
        "school": "LA CRESCENT-HOKAH ELEMENTARY",
        "district": "LA CRESCENT-HOKAH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271725000799",
    },
    {
        "school": "LA CRESCENT SENIOR HIGH",
        "district": "LA CRESCENT-HOKAH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271725000800",
    },
    {
        "school": "SPRING GROVE ELEMENTARY",
        "district": "SPRING GROVE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273330001458",
    },
    {
        "school": "SPRING GROVE SECONDARY",
        "district": "SPRING GROVE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273330001459",
    },
    {
        "school": "ST. PETER ALC",
        "district": "ST. PETER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273387003194",
    },
    {
        "school": "MAPLE RIVER WEST ELEMENTARY",
        "district": "MAPLE RIVER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000600092",
    },
    {
        "school": "Maple River Secondary",
        "district": "MAPLE RIVER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000600888",
    },
    {
        "school": "MAPLE RIVER EAST ELEMENTARY",
        "district": "MAPLE RIVER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000601069",
    },
    {
        "school": "KATO PUBLIC CHARTER SCHOOL",
        "district": "KATO PUBLIC CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270022603471",
    },
    {
        "school": "Central High Area Learning Center",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271878000337",
    },
    {
        "school": "LIFE LINES ADULT CONNECTION",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271878000347",
    },
    {
        "school": "EAGLE LAKE ELEMENTARY",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878000872",
    },
    {
        "school": "FRANKLIN ELEMENTARY",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878000873",
    },
    {
        "school": "JEFFERSON ELEMENTARY",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878000876",
    },
    {
        "school": "KENNEDY ELEMENTARY",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878000877",
    },
    {
        "school": "MANKATO EAST SENIOR HIGH",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878000879",
    },
    {
        "school": "MANKATO WEST SENIOR HIGH",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878000880",
    },
    {
        "school": "ROOSEVELT ELEMENTARY",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878000883",
    },
    {
        "school": "WASHINGTON ELEMENTARY",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878000884",
    },
    {
        "school": "Prairie Winds Middle School",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878002045",
    },
    {
        "school": "Dakota Meadows Middle School",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878002046",
    },
    {
        "school": "BRIDGES COMMUNITY ELEMENTARY",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878002977",
    },
    {
        "school": "ST. CLAIR ELEMENTARY",
        "district": "ST. CLAIR PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273348001477",
    },
    {
        "school": "ST. CLAIR SECONDARY",
        "district": "ST. CLAIR PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273348001478",
    },
    {
        "school": "Lk Crystal Wellcome Memorial El",
        "district": "LAKE CRYSTAL-WELLCOME MEMORIAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279144502308",
    },
    {
        "school": "LK CRYSTAL-WELLCOME MEMORIAL SEC.",
        "district": "LAKE CRYSTAL-WELLCOME MEMORIAL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279144502312",
    },
    {
        "school": "JANESVILLE-WALDORF-PEMBERTON EL.EM.",
        "district": "JANESVILLE-WALDORF-PEMBERTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279145102327",
    },
    {
        "school": "MINNESOTA VALLEY SCHOOL",
        "district": "MN VALLEY EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270006302389",
    },
    {
        "school": "MN VALLEY ED. DIST. EARLY CHILDHOOD",
        "district": "MN VALLEY EDUCATION DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270006302493",
    },
    {
        "school": "LAFAYETTE PUBLIC CHARTER SCHOOL",
        "district": "LAFAYETTE PUBLIC CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270017403042",
    },
    {
        "school": "HOOVER ELEMENTARY",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878000875",
    },
    {
        "school": "MONROE ELEMENTARY",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878000881",
    },
    {
        "school": "SPECIAL EDUCATION",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271878002173",
    },
    {
        "school": "NICOLLET ELEMENTARY SCHOOL",
        "district": "NICOLLET PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272358001160",
    },
    {
        "school": "NICOLLET SENIOR HIGH SCHOOL",
        "district": "NICOLLET PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272358001161",
    },
    {
        "school": "HOFFMAN LEARNING CENTER",
        "district": "ST. PETER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273387000973",
    },
    {
        "school": "North Elementary School",
        "district": "ST. PETER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273387001638",
    },
    {
        "school": "South Elementary Center",
        "district": "ST. PETER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273387001639",
    },
    {
        "school": "St. Peter High School",
        "district": "ST. PETER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273387001641",
    },
    {
        "school": "St. Peter Middle School",
        "district": "ST. PETER PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273387002533",
    },
    {
        "school": "JANESVILLE-WALDORF-PEMBERTON SEC",
        "district": "JANESVILLE-WALDORF-PEMBERTON",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279145102330",
    },
    {
        "school": "SWWC ELC - Windom",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270008604168",
    },
    {
        "school": "Red Rock Ridge Area Learning Center",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270008604169",
    },
    {
        "school": "LAKEVIEW ELEMENTARY",
        "district": "LAKEVIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270008800407",
    },
    {
        "school": "LAKEVIEW SECONDARY",
        "district": "LAKEVIEW SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270008800408",
    },
    {
        "school": "LYND ELEMENTARY",
        "district": "LYND PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271839000856",
    },
    {
        "school": "PARK SIDE ELEMENTARY",
        "district": "MARSHALL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271894000891",
    },
    {
        "school": "MARSHALL HIGH SCHOOL",
        "district": "MARSHALL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271894000892",
    },
    {
        "school": "WEST SIDE ELEMENTARY",
        "district": "MARSHALL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271894000894",
    },
    {
        "school": "MATEC",
        "district": "MARSHALL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271894002816",
    },
    {
        "school": "MINNEOTA ELEMENTARY",
        "district": "MINNEOTA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272127001067",
    },
    {
        "school": "MINNEOTA SECONDARY",
        "district": "MINNEOTA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272127001068",
    },
    {
        "school": "LAURA JEFFREY ACADEMY CHARTER",
        "district": "LAURA JEFFREY ACADEMY CHARTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270029203713",
    },
    {
        "school": "OAK CREST ELEMENTARY",
        "district": "BELLE PLAINE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270405003718",
    },
    {
        "school": "Shakopee East Middle School",
        "district": "SHAKOPEE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273300003717",
    },
    {
        "school": "FIELDSTONE ELEMENTARY SCHOOL",
        "district": "ST. MICHAEL-ALBERTVILLE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273379003673",
    },
    {
        "school": "WATERTOWN-MAYER ELEMENTARY SCHOOL",
        "district": "Watertown-Mayer Public School Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274191003674",
    },
    {
        "school": "MN CORRECTIONAL FACILITY-LINO LAKES",
        "district": "MINNESOTA DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270027203324",
    },
    {
        "school": "PALADIN CAREER AND TECH HIGH SCHOOL",
        "district": "PALADIN CAREER AND TECH HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034304133",
    },
    {
        "school": "ANDOVER HIGH SCHOOL",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318003170",
    },
    {
        "school": "SECONDARY TECHNICAL ED PROG S.T.E.P",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MN",
        "nces_id": "270318003171",
    },
    {
        "school": "BLUE HERON ELEMENTARY",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270810003172",
    },
    {
        "school": "MCF-MOOSE LAKE/WILLOW RIVER",
        "district": "MINNESOTA DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270027203328",
    },
    {
        "school": "PIONEER RIDGE MIDDLE SCHOOL",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819003180",
    },
    {
        "school": "VICTORIA ELEMENTARY",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819003506",
    },
    {
        "school": "Watertown-Mayer Cmty Learning Cntr",
        "district": "Watertown-Mayer Public School Dist",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274191003623",
    },
    {
        "school": "TRIO WOLF CREEK DISTANCE LEARNING",
        "district": "TRIO WOLF CREEK DISTANCE LEARNING",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270023502689",
    },
    {
        "school": "MN CORRECTIONAL FACILITY-RUSH CITY",
        "district": "MINNESOTA DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270027203326",
    },
    {
        "school": "SUNRISE RIVER ELEMENTARY",
        "district": "NORTH BRANCH PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272382003514",
    },
    {
        "school": "ACADEMIC ARTS HIGH SCHOOL",
        "district": "ACADEMIC ARTS HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036104105",
    },
    {
        "school": "BES TRANSITION PROGRAM",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270729003513",
    },
    {
        "school": "MEADOWVIEW ELEMENTARY",
        "district": "FARMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271182003183",
    },
    {
        "school": "ATHENEUM ELEMENTARY",
        "district": "INVER GROVE HEIGHTS SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271503003184",
    },
    {
        "school": "LAKEVILLE SOUTH HIGH",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778003515",
    },
    {
        "school": "LAKEVILLE EARLY CHILDHOOD PROGRAM",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271778004179",
    },
    {
        "school": "MCF-Red Wing Maginnis High School",
        "district": "MINNESOTA DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270027203330",
    },
    {
        "school": "VECTOR BASIC",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002503211",
    },
    {
        "school": "VECTOR LOW INCIDENCE",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002503212",
    },
    {
        "school": "OPTIONS MID/ELEM EBD",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002503213",
    },
    {
        "school": "PHASE",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002503223",
    },
    {
        "school": "SUN",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002503226",
    },
    {
        "school": "STRIVE SECONDARY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002503229",
    },
    {
        "school": "STRIVE TRANSITION",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002503232",
    },
    {
        "school": "CIP",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002503234",
    },
    {
        "school": "ALC EDEN PRAIRIE HS-IS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503242",
    },
    {
        "school": "ALC RICHFIELD HS-IS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503245",
    },
    {
        "school": "SECA - IS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503253",
    },
    {
        "school": "ALC Richefield - Success at 15",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503255",
    },
    {
        "school": "SAFE",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002503542",
    },
    {
        "school": "EPSILON",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503548",
    },
    {
        "school": "OMEGON",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503549",
    },
    {
        "school": "277 WESTONKA AREA LEARNING ACADEMY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503554",
    },
    {
        "school": "ALC WESTONKA - IS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503555",
    },
    {
        "school": "283-ST. LOUIS PARK ALC",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503561",
    },
    {
        "school": "283 ST LOUIS PK INDEPENDENT STUDY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503562",
    },
    {
        "school": "ALC - EDEN PRAIRIE HS - IS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503594",
    },
    {
        "school": "NSO - Independent Study",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503597",
    },
    {
        "school": "INTERSECT",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002504137",
    },
    {
        "school": "FOCUS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002504138",
    },
    {
        "school": "OFF CAMPUS CTE",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002504189",
    },
    {
        "school": "Northern Star Online",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002504190",
    },
    {
        "school": "MTS HIGH SCHOOL",
        "district": "MINNESOTA TRANSITIONS CHARTER SCH",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011703262",
    },
    {
        "school": "Minnesota Virtual Schools",
        "district": "MINNESOTA TRANSITIONS CHARTER SCH",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011703264",
    },
    {
        "school": "MTS PEASE ACADEMY",
        "district": "MINNESOTA TRANSITIONS CHARTER SCH",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011703336",
    },
    {
        "school": "BANAADIR ACADEMY",
        "district": "MINNESOTA TRANSITIONS CHARTER SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011703566",
    },
    {
        "school": "SAGE ACADEMY CHARTER SCHOOL",
        "district": "SAGE ACADEMY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270021103272",
    },
    {
        "school": "WATERSHED HIGH SCHOOL",
        "district": "WATERSHED HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270021303274",
    },
    {
        "school": "PARTNERSHIP ACADEMY INC.",
        "district": "PARTNERSHIP ACADEMY INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270023703278",
    },
    {
        "school": "PRAIRIE SEEDS EL SCHOOL ACADEMY",
        "district": "PRAIRIE SEEDS ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270024003340",
    },
    {
        "school": "METRO SCHOOLS CHARTER",
        "district": "METRO SCHOOLS CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270024503573",
    },
    {
        "school": "NEW MILLENIUM ACADEMY CHARTER SCH",
        "district": "NEW MILLENNIUM ACADEMY CHARTER SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270025303311",
    },
    {
        "school": "MINNESOTA ONLINE HIGH SCHOOL",
        "district": "MINNESOTA ONLINE HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270026003318",
    },
    {
        "school": "Midway Star Academy",
        "district": "Midway Star Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270026303320",
    },
    {
        "school": "LOVEWORKS ACADEMY FOR ARTS",
        "district": "LOVEWORKS ACADEMY FOR ARTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270027303575",
    },
    {
        "school": "SPECTRUM HIGH SCHOOL",
        "district": "SPECTRUM HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270027603615",
    },
    {
        "school": "SOUTHSIDE FAMILY CHARTER SCHOOL",
        "district": "SOUTHSIDE FAMILY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270027803617",
    },
    {
        "school": "HIAWATHA LEADERSHIP ACAD-MORRIS PK",
        "district": "HIAWATHA ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028803725",
    },
    {
        "school": "STONEBRIDGE WORLD SCHOOL",
        "district": "STONEBRIDGE WORLD SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028903731",
    },
    {
        "school": "NOBLE ACADEMY",
        "district": "NOBLE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270029503727",
    },
    {
        "school": "INTERNATIONAL SPANISH LANGUAGE ACAD",
        "district": "INTERNATIONAL SPANISH LANGUAGE ACAD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270029603736",
    },
    {
        "school": "LINCOLN INTERNATIONAL SCHOOL",
        "district": "LINCOLN INTERNATIONAL SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270029903733",
    },
    {
        "school": "DOWNTOWN CAMPUS",
        "district": "MINNESOTA INTERNSHIP CENTER",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034103568",
    },
    {
        "school": "SOAR Campus",
        "district": "MINNESOTA INTERNSHIP CENTER",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034103572",
    },
    {
        "school": "RONDO CAMPUS",
        "district": "MINNESOTA INTERNSHIP CENTER",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034104164",
    },
    {
        "school": "UNITY CAMPUS",
        "district": "MINNESOTA INTERNSHIP CENTER",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034104165",
    },
    {
        "school": "HMONG COLLEGE PREP ACADEMY HS",
        "district": "HMONG COLLEGE PREP ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034204092",
    },
    {
        "school": "PIM Arts High School",
        "district": "PIM Arts High School",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034904096",
    },
    {
        "school": "AUGSBURG FAIRVIEW ACADEMY",
        "district": "AUGSBURG FAIRVIEW ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270035004097",
    },
    {
        "school": "Spero Academy",
        "district": "Spero Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270035204099",
    },
    {
        "school": "Kaleidoscope Charter Elementary Sch",
        "district": "KALEIDOSCOPE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036004104",
    },
    {
        "school": "UBAH MEDICAL ACADEMY CHARTER SCHOOL",
        "district": "UBAH MEDICAL ACADEMY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036304107",
    },
    {
        "school": "EAGLE RIDGE ACADEMY CHARTER SCHOOL",
        "district": "EAGLE RIDGE ACADEMY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036404108",
    },
    {
        "school": "BEACON ACADEMY",
        "district": "BEACON ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036604110",
    },
    {
        "school": "Beacon ALP",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270579003518",
    },
    {
        "school": "HASSAN ELEMENTARY",
        "district": "Elk River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137003534",
    },
    {
        "school": "ROGERS SENIOR HIGH",
        "district": "Elk River School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137004161",
    },
    {
        "school": "TRANSITION PLUS",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271426003606",
    },
    {
        "school": "ANISHINABE ACADEMY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004172",
    },
    {
        "school": "MINNEAPOLIS ON LINE LEARNING",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004188",
    },
    {
        "school": "WOODLAND ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520003186",
    },
    {
        "school": "ARBOR VIEW ECH. SPECIAL ED.",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272520003504",
    },
    {
        "school": "ACHIEVE",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272520003593",
    },
    {
        "school": "ROBBINSDALE TRANSITION CENTER",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273178003519",
    },
    {
        "school": "ST. ANTHONY VILLAGE ALTERNATIVE",
        "district": "ST. ANTHONY-NEW BRIGHTON SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273342003497",
    },
    {
        "school": "IS THE ALTERNATIVE PROGRAM (TAP)",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274216003520",
    },
    {
        "school": "THE ALTERNATIVE PROGRAM (TAP)",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274216003521",
    },
    {
        "school": "Community of Peace Academy High Sch",
        "district": "COMMUNITY OF PEACE ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011504163",
    },
    {
        "school": "ST. PAUL CITY MIDDLE SCHOOL",
        "district": "ST. PAUL CITY SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270014204150",
    },
    {
        "school": "TWIN CITIES ACADEMY",
        "district": "TWIN CITIES ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270024603307",
    },
    {
        "school": "ROCHESTER MATH AND SCIENCE ACADEMY",
        "district": "ROCHESTER MATH AND SCIENCE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270024703308",
    },
    {
        "school": "TWIN CITIES GERMAN IMMERSION CHRTR",
        "district": "TWIN CITIES GERMAN IMMERSION CHTR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270026203578",
    },
    {
        "school": "YINGHUA ACADEMY",
        "district": "YINGHUA ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028103611",
    },
    {
        "school": "SEVEN HILLS PREPARATORY ACADEMY",
        "district": "SEVEN HILLS PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028403614",
    },
    {
        "school": "NOVA CLASSICAL ACADEMY LOWER SCHOOL",
        "district": "NOVA CLASSICAL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270033704175",
    },
    {
        "school": "GREAT RIVER SCHOOL",
        "district": "GREAT RIVER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034404093",
    },
    {
        "school": "ST PAUL CONSERVATORY PERFORMING ART",
        "district": "ST PAUL CONSERVATORY PERFORMING ART",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270035104098",
    },
    {
        "school": "URBAN ACADEMY CHARTER SCHOOL",
        "district": "URBAN ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270035304173",
    },
    {
        "school": "A/O PROGRAM",
        "district": "NORTHEAST METRO 916",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270226403259",
    },
    {
        "school": "WELS SOUTH",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270226403565",
    },
    {
        "school": "PROJECT RETURN",
        "district": "NORTHEAST METRO 916",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270226404132",
    },
    {
        "school": "Quora High School",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270226404149",
    },
    {
        "school": "NETS",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272295003494",
    },
    {
        "school": "REACH TRANSITION",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272295004127",
    },
    {
        "school": "HARMONY LEARNING CENTER",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272385003374",
    },
    {
        "school": "The Next Step",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272385003375",
    },
    {
        "school": "ALC SECONDARY EXTENDED PROGRAMS",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384003163",
    },
    {
        "school": "WHITE BEAR LAKE NORTH CAMPUS ALC",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274236003160",
    },
    {
        "school": "CENTRAL AREA LEARNING CENTER",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274236003161",
    },
    {
        "school": "SUNRISE PARK AREA LEARNING CENTER",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274236003162",
    },
    {
        "school": "WHITE BEAR TRANSITION PLUS PROGRAM",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274236003377",
    },
    {
        "school": "AREA LEARNING CENTER SUMMER",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274236003528",
    },
    {
        "school": "MN CORRECTIONAL FACILITY-FARIBAULT",
        "district": "MINNESOTA DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270027203323",
    },
    {
        "school": "MN CORRECTIONAL FACILITY-SHAKOPEE",
        "district": "MINNESOTA DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270027203331",
    },
    {
        "school": "JORDAN MIDDLE",
        "district": "JORDAN PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271575004144",
    },
    {
        "school": "RED OAK ELEMENTARY",
        "district": "SHAKOPEE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273300003166",
    },
    {
        "school": "EAGLE CREEK ELEMENTARY SCHOOL",
        "district": "SHAKOPEE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273300003719",
    },
    {
        "school": "MN CORRECTIONAL FACILITY-ST. CLOUD",
        "district": "MINNESOTA DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270027203329",
    },
    {
        "school": "BECKER ALTERNATIVE LEARNING PROGRAM",
        "district": "BECKER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270387003533",
    },
    {
        "school": "LIBERTY ELEMENTARY",
        "district": "BIG LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270546004180",
    },
    {
        "school": "ZIMMERMAN MIDDLE",
        "district": "Elk River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137003360",
    },
    {
        "school": "ZIMMERMAN HIGH SCHOOL",
        "district": "Elk River School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137003361",
    },
    {
        "school": "IVAN SAND COMMUNITY SCHOOL- IS",
        "district": "Elk River School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271137003364",
    },
    {
        "school": "IVAN SAND AFTER SCHOOL CREDIT RECOV",
        "district": "Elk River School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271137003365",
    },
    {
        "school": "IVAN SAND COMMUNITY SCHOOL SUMMER",
        "district": "Elk River School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271137003366",
    },
    {
        "school": "TWIN LAKES ELEMENTARY",
        "district": "Elk River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137003689",
    },
    {
        "school": "WESTWOOD ELEMENTARY",
        "district": "Elk River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137004141",
    },
    {
        "school": "ISD 728 FOCUS/JOURNEY",
        "district": "Elk River School District",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271137004142",
    },
    {
        "school": "Handke Center- EC Special Education",
        "district": "Elk River School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271137004181",
    },
    {
        "school": "ELK RIVER DISTRICT SHARED TIME PROG",
        "district": "Elk River School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271137004209",
    },
    {
        "school": "MCF - OAK PARK HEIGHTS",
        "district": "MINNESOTA DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270027203325",
    },
    {
        "school": "MN CORRECTIONAL FACILITY-STILLWATER",
        "district": "MINNESOTA DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270027203327",
    },
    {
        "school": "COMMUNITY SCHOOL OF EXCELLENCE",
        "district": "COMMUNITY SCHOOL OF EXCELLENCE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270030403728",
    },
    {
        "school": "Lakes International Language Acad",
        "district": "LAKES INTERNATIONAL LANGUAGE ACADEM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270035804102",
    },
    {
        "school": "ST. CROIX PREPARATORY ACADEMY LOWER",
        "district": "ST. CROIX PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036204106",
    },
    {
        "school": "CAREER & TECHNICAL CENTER",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MN",
        "nces_id": "270226403348",
    },
    {
        "school": "STEP",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271227003355",
    },
    {
        "school": "COTTAGE GROVE ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381003169",
    },
    {
        "school": "LIBERTY RIDGE ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381003198",
    },
    {
        "school": "WCJC",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273819004184",
    },
    {
        "school": "Howard Lake-Waverly-Winsted Middle",
        "district": "HOWARD LAKE-WAVERLY-WINSTED",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012303350",
    },
    {
        "school": "SWAN RIVER MONTESSORI CHARTER SCH",
        "district": "SWAN RIVER MONTESSORI CHARTER SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270024903309",
    },
    {
        "school": "NORTHWINDS ELEMENTARY",
        "district": "BUFFALO-HANOVER-MONTROSE PUBLIC SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270720004186",
    },
    {
        "school": "PRAIRIE HOUSE SCHOOL",
        "district": "MONTICELLO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272139003358",
    },
    {
        "school": "BIG WOODS ELEMENTARY",
        "district": "ST. MICHAEL-ALBERTVILLE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273379004187",
    },
    {
        "school": "PACT CHARTER SCHOOL",
        "district": "PACT CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009302488",
    },
    {
        "school": "PACT CHARTER SECONDARY",
        "district": "PACT CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009303030",
    },
    {
        "school": "NORTHWEST PASSAGE HIGH SCHOOL",
        "district": "NORTHWEST PASSAGE HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270017303041",
    },
    {
        "school": "ANTHONY LOUIS HOUSE",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270318000002",
    },
    {
        "school": "RIVER TRAIL LEARNING CTR @ LO JACOB",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270318000005",
    },
    {
        "school": "PATHWAYS",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270318000006",
    },
    {
        "school": "Anoka-Hennepin Regn HS Summer Prog",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270318000008",
    },
    {
        "school": "ADAMS ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000095",
    },
    {
        "school": "ANOKA HIGH SCHOOL",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000096",
    },
    {
        "school": "BLAINE HIGH SCHOOL",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000097",
    },
    {
        "school": "COON RAPIDS MIDDLE SCHOOL",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000099",
    },
    {
        "school": "COON RAPIDS HIGH SCHOOL",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000100",
    },
    {
        "school": "CROOKED LAKE ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000101",
    },
    {
        "school": "EISENHOWER ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000103",
    },
    {
        "school": "FRANKLIN ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000105",
    },
    {
        "school": "HAMILTON ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000106",
    },
    {
        "school": "Hoover Elementary BioMed Sci Egng",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000107",
    },
    {
        "school": "JEFFERSON ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000110",
    },
    {
        "school": "JOHNSVILLE ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000111",
    },
    {
        "school": "LINCOLN ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000112",
    },
    {
        "school": "MADISON ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000113",
    },
    {
        "school": "MCKINLEY ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000114",
    },
    {
        "school": "MISSISSIPPI ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000115",
    },
    {
        "school": "ANOKA MIDDLE SCHOOL FOR THE ARTS",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000117",
    },
    {
        "school": "MORRIS BYE ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000118",
    },
    {
        "school": "NORTHDALE MIDDLE",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000119",
    },
    {
        "school": "RAMSEY ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000120",
    },
    {
        "school": "ROOSEVELT MIDDLE",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000122",
    },
    {
        "school": "SAND CREEK ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000123",
    },
    {
        "school": "UNIVERSITY ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000126",
    },
    {
        "school": "WILSON ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000128",
    },
    {
        "school": "Anoka-Hennepin Regional High School",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270318002029",
    },
    {
        "school": "EARLY CHILDHOOD/SPECIAL EDUCATION",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270318002168",
    },
    {
        "school": "ANDOVER ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318002203",
    },
    {
        "school": "OAK VIEW MIDDLE",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318002501",
    },
    {
        "school": "ANOKA-HENNEPIN SPECIALTY PROGRAM",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270318002503",
    },
    {
        "school": "BRIDGES",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270318002630",
    },
    {
        "school": "COMPASS-BELL CENTER",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270318002974",
    },
    {
        "school": "Anoka-Hennepin Regn Night School",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270318003057",
    },
    {
        "school": "RUM RIVER ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318003058",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270810000009",
    },
    {
        "school": "RICE LAKE ELEMENTARY",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270810000022",
    },
    {
        "school": "CENTENNIAL ELEMENTARY",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270810000332",
    },
    {
        "school": "CENTENNIAL HIGH SCHOOL",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270810000334",
    },
    {
        "school": "CENTERVILLE ELEMENTARY",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270810000335",
    },
    {
        "school": "GOLDEN LAKE ELEMENTARY",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270810000336",
    },
    {
        "school": "CENTENNIAL AREA LEARNING CENTER",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270810002753",
    },
    {
        "school": "CENTENNIAL MIDDLE",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270810002784",
    },
    {
        "school": "EARLY CHILDHOOD",
        "district": "COLUMBIA HEIGHTS PUBLIC SCHOOL DIST",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270951000011",
    },
    {
        "school": "COLUMBIA ACADEMY",
        "district": "COLUMBIA HEIGHTS PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270951000395",
    },
    {
        "school": "COLUMBIA HEIGHTS SENIOR HIGH",
        "district": "COLUMBIA HEIGHTS PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270951000396",
    },
    {
        "school": "HIGHLAND ELEMENTARY",
        "district": "COLUMBIA HEIGHTS PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270951000398",
    },
    {
        "school": "NORTH PARK ELEMENTARY",
        "district": "COLUMBIA HEIGHTS PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270951000400",
    },
    {
        "school": "VALLEY VIEW ELEMENTARY",
        "district": "COLUMBIA HEIGHTS PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270951000402",
    },
    {
        "school": "COLUMBUS ELEMENTARY",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271227000593",
    },
    {
        "school": "LINO LAKES ELEMENTARY",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271227000597",
    },
    {
        "school": "LINWOOD ELEMENTARY",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271227000598",
    },
    {
        "school": "FRIDLEY MIDDLE",
        "district": "FRIDLEY PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271242000610",
    },
    {
        "school": "FRIDLEY SENIOR HIGH",
        "district": "FRIDLEY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271242000611",
    },
    {
        "school": "HAYES ELEMENTARY",
        "district": "FRIDLEY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271242000612",
    },
    {
        "school": "STEVENSON ELEMENTARY",
        "district": "FRIDLEY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271242000614",
    },
    {
        "school": "TRANSITIONS SCHOOL",
        "district": "FRIDLEY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271242002631",
    },
    {
        "school": "FRIDLEY MOORE LK AREA LEARNING CTR",
        "district": "FRIDLEY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271242002632",
    },
    {
        "school": "FRIDLEY MIDDLE AREA LEARNING CENTER",
        "district": "FRIDLEY PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271242003427",
    },
    {
        "school": "EARLY EDUCATION",
        "district": "SPRING LAKE PARK PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273333000290",
    },
    {
        "school": "NORTHPOINT ELEMENTARY",
        "district": "SPRING LAKE PARK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273333001461",
    },
    {
        "school": "Park Terrace Elementary",
        "district": "SPRING LAKE PARK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273333001462",
    },
    {
        "school": "SPRING LAKE PARK SENIOR HIGH",
        "district": "SPRING LAKE PARK PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273333001464",
    },
    {
        "school": "Westwood Intermediate & Middle Sch",
        "district": "SPRING LAKE PARK PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273333001466",
    },
    {
        "school": "WOODCREST EL. SPANISH IMMERSION",
        "district": "SPRING LAKE PARK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273333001467",
    },
    {
        "school": "DISTANCE LEARNING INDEP STUDY",
        "district": "SPRING LAKE PARK PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273333003451",
    },
    {
        "school": "ST. FRANCIS HIGH",
        "district": "St. Francis Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273354000012",
    },
    {
        "school": "ST. FRANCIS MIDDLE",
        "district": "St. Francis Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273354000013",
    },
    {
        "school": "TRANSITION 15",
        "district": "St. Francis Area Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273354000014",
    },
    {
        "school": "ECSE@ ISD 15 LIFELONG LEARNING",
        "district": "St. Francis Area Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273354000229",
    },
    {
        "school": "ST. FRANCIS ELEMENTARY",
        "district": "St. Francis Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273354000230",
    },
    {
        "school": "Cedar Creek Elementary School",
        "district": "St. Francis Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273354000233",
    },
    {
        "school": "East Bethel Elementary School",
        "district": "St. Francis Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273354000258",
    },
    {
        "school": "WORLD LEARNER CHARTER SCHOOL",
        "district": "WORLD LEARNER CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011602606",
    },
    {
        "school": "CHANHASSEN ELEMENTARY",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819000342",
    },
    {
        "school": "CHASKA HIGH SCHOOL",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819000343",
    },
    {
        "school": "CHASKA MIDDLE SCHOOL EAST",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819000345",
    },
    {
        "school": "EAST UNION ELEMENTARY",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819000346",
    },
    {
        "school": "Kinder Academy",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819000393",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL EDUCATION",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270819000397",
    },
    {
        "school": "JONATHAN ELEMENTARY",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819002294",
    },
    {
        "school": "BLUFF CREEK ELEMENTARY",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819002509",
    },
    {
        "school": "CHASKA MIDDLE SCHOOL WEST",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819002798",
    },
    {
        "school": "CLOVER RIDGE ELEMENTARY",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819003067",
    },
    {
        "school": "MINNETONKA WEST MIDDLE",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271167002194",
    },
    {
        "school": "CENTRAL SENIOR HIGH",
        "district": "CENTRAL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272391001186",
    },
    {
        "school": "CENTRAL ELEMENTARY",
        "district": "CENTRAL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272391001187",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "CENTRAL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272391002507",
    },
    {
        "school": "Waconia High School",
        "district": "WACONIA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274146000358",
    },
    {
        "school": "SOUTHVIEW ELEMENTARY",
        "district": "WACONIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274146000363",
    },
    {
        "school": "BAYVIEW ELEMENTARY",
        "district": "WACONIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274146003065",
    },
    {
        "school": "Waconia Middle School",
        "district": "WACONIA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274146003066",
    },
    {
        "school": "WATERTOWN-MAYER MIDDLE",
        "district": "Watertown-Mayer Public School Dist",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274191000024",
    },
    {
        "school": "WATERTOWN MAYER HIGH",
        "district": "Watertown-Mayer Public School Dist",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274191001750",
    },
    {
        "school": "CHISAGO LAKES MIDDLE",
        "district": "CHISAGO LAKES SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001700351",
    },
    {
        "school": "CHISAGO LAKES EL.",
        "district": "CHISAGO LAKES SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001700352",
    },
    {
        "school": "CHISAGO LAKES SENIOR HIGH",
        "district": "CHISAGO LAKES SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001700353",
    },
    {
        "school": "TAYLORS FALLS ELEMENTARY",
        "district": "CHISAGO LAKES SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001701672",
    },
    {
        "school": "LAKESIDE EL.",
        "district": "CHISAGO LAKES SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001701673",
    },
    {
        "school": "CHISAGO LAKES FAMILY CENTER",
        "district": "CHISAGO LAKES SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270001702855",
    },
    {
        "school": "WYOMING ELEMENTARY",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271227000601",
    },
    {
        "school": "NORTH BRANCH LAB SCHOOL ALC",
        "district": "NORTH BRANCH PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272382000401",
    },
    {
        "school": "NORTH BRANCH SENIOR HIGH",
        "district": "NORTH BRANCH PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272382001162",
    },
    {
        "school": "NORTH BRANCH EARLY CHILDHOOD",
        "district": "NORTH BRANCH PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272382001163",
    },
    {
        "school": "NORTH BRANCH MIDDLE",
        "district": "NORTH BRANCH PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272382001164",
    },
    {
        "school": "DISTANCE LEARNING PROGRAM",
        "district": "NORTH BRANCH PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272382002633",
    },
    {
        "school": "C.E. JACOBSON ELEMENTARY",
        "district": "RUSH CITY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273255001405",
    },
    {
        "school": "RUSH CITY SECONDARY",
        "district": "RUSH CITY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273255001406",
    },
    {
        "school": "917 TRANSITIONAL EDUCATION SERV ALT",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002602111",
    },
    {
        "school": "917 INTRA-DAKOTA EDUCATIONAL ALT",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002602121",
    },
    {
        "school": "DEAF/HARD OF HEARING",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002602124",
    },
    {
        "school": "917 PACES",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002602125",
    },
    {
        "school": "DAKOTA CTY. ALC",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002602155",
    },
    {
        "school": "RIVERSIDE SCHOOL",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002602600",
    },
    {
        "school": "BURNSVILLE HIGH SCHOOL",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729000292",
    },
    {
        "school": "WILLIAM BYRNE ELEMENTARY",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729000293",
    },
    {
        "school": "JOHN METCALF MIDDLE SCHOOL",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729000295",
    },
    {
        "school": "EDWARD NEILL ELEMENTARY",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729000296",
    },
    {
        "school": "JOSEPH NICOLLET MIDDLE SCHOOL",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729000297",
    },
    {
        "school": "GIDEON POND ELEMENTARY",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729000298",
    },
    {
        "school": "RAHN ELEMENTARY",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729000299",
    },
    {
        "school": "SIOUX TRAIL ELEMENTARY",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729000301",
    },
    {
        "school": "SKY OAKS ELEMENTARY",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729000302",
    },
    {
        "school": "VISTA VIEW ELEMENTARY",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729000303",
    },
    {
        "school": "Burnsville Sr High Extended Day Pro",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270729000474",
    },
    {
        "school": "BURNSVILLE ALTERNATIVE HIGH SCHOOL",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270729000481",
    },
    {
        "school": "EARLY EDUCATION PROGRAM & SERVICES",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270729002171",
    },
    {
        "school": "LEARNERS CENTER",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270729002431",
    },
    {
        "school": "BURNSVILLE AREA LEARNING CENTER",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270729002640",
    },
    {
        "school": "FARMINGTON HIGH SCHOOL",
        "district": "FARMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271182000568",
    },
    {
        "school": "FARMINGTON ELEMENTARY",
        "district": "FARMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271182000569",
    },
    {
        "school": "LEVI P. DODGE MIDDLE SCHOOL",
        "district": "FARMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271182000570",
    },
    {
        "school": "AKIN ROAD ELEMENTARY",
        "district": "FARMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271182002205",
    },
    {
        "school": "NORTH TRAIL ELEMENTARY",
        "district": "FARMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271182002642",
    },
    {
        "school": "DAKOTA PRAIRIE AREA LEARNING CENTER",
        "district": "FARMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271182002803",
    },
    {
        "school": "ROBERT BOECKMAN MIDDLE SCHOOL",
        "district": "FARMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271182002983",
    },
    {
        "school": "HARBOR EDUCATIONAL PROGRAM",
        "district": "HASTINGS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271353000559",
    },
    {
        "school": "HASTINGS EARLY CHILD SPECIAL ED.",
        "district": "HASTINGS PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271353000565",
    },
    {
        "school": "SPECIAL SERVICES",
        "district": "HASTINGS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271353000566",
    },
    {
        "school": "HASTINGS MIDDLE SCHOOL",
        "district": "HASTINGS PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271353000693",
    },
    {
        "school": "HASTINGS HIGH SCHOOL",
        "district": "HASTINGS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271353000694",
    },
    {
        "school": "KENNEDY ELEMENTARY",
        "district": "HASTINGS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271353000695",
    },
    {
        "school": "PINECREST ELEMENTARY",
        "district": "HASTINGS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271353000696",
    },
    {
        "school": "CHRISTA MCAULIFFE ELEMENTARY",
        "district": "HASTINGS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271353002239",
    },
    {
        "school": "HASTINGS ALTERNATIVE CENTER",
        "district": "HASTINGS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271353002754",
    },
    {
        "school": "SIMLEY ALTERNATIVE PROGRAM",
        "district": "INVER GROVE HEIGHTS SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271503000538",
    },
    {
        "school": "PINE BEND ELEMENTARY",
        "district": "INVER GROVE HEIGHTS SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271503000547",
    },
    {
        "school": "IGH EARLY CHILDHOOD PROGRAM",
        "district": "INVER GROVE HEIGHTS SCHOOLS",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271503000556",
    },
    {
        "school": "HILLTOP ELEMENTARY",
        "district": "INVER GROVE HEIGHTS SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271503000763",
    },
    {
        "school": "INVER GROVE HEIGHTS MIDDLE",
        "district": "INVER GROVE HEIGHTS SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271503000765",
    },
    {
        "school": "SALEM HILLS ELEMENTARY",
        "district": "INVER GROVE HEIGHTS SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271503000766",
    },
    {
        "school": "SIMLEY SENIOR HIGH",
        "district": "INVER GROVE HEIGHTS SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271503000767",
    },
    {
        "school": "CHERRY VIEW ELEMENTARY",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778000025",
    },
    {
        "school": "KENWOOD TRAIL MIDDLE SCHOOL",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778000483",
    },
    {
        "school": "KENNEDY ELEMENTARY",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778000815",
    },
    {
        "school": "LAKEVILLE NORTH HIGH",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778000817",
    },
    {
        "school": "IMPACT ACADEMY AT ORCHARD LAKE EL",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778000818",
    },
    {
        "school": "HUDDLESTON ELEMENTARY",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778002043",
    },
    {
        "school": "LAKE MARION ELEMENTARY",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778002273",
    },
    {
        "school": "MCGUIRE MIDDLE",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778002435",
    },
    {
        "school": "LAKEVIEW ELEMENTARY",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778002436",
    },
    {
        "school": "EASTVIEW ELEMENTARY",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778002643",
    },
    {
        "school": "LAKEVILLE AREA LEARNING CENTER",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271778002804",
    },
    {
        "school": "CENTURY MIDDLE SCHOOL",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778002984",
    },
    {
        "school": "OAK HILLS ELEMENTARY",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778002985",
    },
    {
        "school": "RANDOLPH ELEMENTARY",
        "district": "RANDOLPH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273015001286",
    },
    {
        "school": "RANDOLPH SECONDARY",
        "district": "RANDOLPH PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273015001287",
    },
    {
        "school": "DAKOTA HILLS MIDDLE",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239000484",
    },
    {
        "school": "EAGAN SENIOR HIGH",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239000488",
    },
    {
        "school": "ROSEMOUNT AREA LEARNING CENTER",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273239000500",
    },
    {
        "school": "DEERWOOD ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239000511",
    },
    {
        "school": "GLACIER HILLS SCHOOL - ARTS/SCIENCE",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239000512",
    },
    {
        "school": "COOPERATIVE AREA LEARNING PRG.",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273239000519",
    },
    {
        "school": "APPLE VALLEY SENIOR HIGH",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001373",
    },
    {
        "school": "Cedar Park Elementary STEM School",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001374",
    },
    {
        "school": "DIAMOND PATH EL SCH OF INTL STUDIES",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001375",
    },
    {
        "school": "GREENLEAF ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001376",
    },
    {
        "school": "NORTHVIEW ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001377",
    },
    {
        "school": "PARKVIEW ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001378",
    },
    {
        "school": "ROSEMOUNT SENIOR HIGH",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001379",
    },
    {
        "school": "ROSEMOUNT ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001380",
    },
    {
        "school": "ROSEMOUNT MIDDLE",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001381",
    },
    {
        "school": "SOUTHVIEW ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001382",
    },
    {
        "school": "VALLEY MIDDLE",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001383",
    },
    {
        "school": "WESTVIEW ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001384",
    },
    {
        "school": "ECHO PARK LEADERSHIP ENGINEER/TECH",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001942",
    },
    {
        "school": "SCOTT HIGHLANDS MIDDLE",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001943",
    },
    {
        "school": "THOMAS LAKE ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239001944",
    },
    {
        "school": "HIGHLAND ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239002185",
    },
    {
        "school": "WOODLAND ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239002216",
    },
    {
        "school": "PINEWOOD EL.",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239002282",
    },
    {
        "school": "SHANNON PARK ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239002283",
    },
    {
        "school": "OAK RIDGE LEADERSHIPENVIRON/HEALTH",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239002302",
    },
    {
        "school": "BLACK HAWK MIDDLE",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239002437",
    },
    {
        "school": "TRANSITION PLUS",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273239002513",
    },
    {
        "school": "ABE DIPLOMA PROGRAM",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273239002514",
    },
    {
        "school": "SCHOOL OF ENVIRONMENTAL STUDIES",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239002515",
    },
    {
        "school": "DAKOTA RIDGE SCHOOL",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273239002517",
    },
    {
        "school": "DAKOTA VALLEY LEARNING CENTER",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273239002518",
    },
    {
        "school": "RED PINE ELEMENTARY",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239002519",
    },
    {
        "school": "FALCON RIDGE MIDDLE",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239002644",
    },
    {
        "school": "EASTVIEW SENIOR HIGH",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239002645",
    },
    {
        "school": "LINCOLN CENTER ELEMENTARY",
        "district": "South St. Paul Public School Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273327001453",
    },
    {
        "school": "SOUTH ST. PAUL SECONDARY",
        "district": "South St. Paul Public School Dist",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273327001456",
    },
    {
        "school": "KAPOSIA EDUCATION CENTER ELEMENTARY",
        "district": "South St. Paul Public School Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273327001457",
    },
    {
        "school": "S ST. PAUL COMMUNITY LRNG. CNTR.",
        "district": "South St. Paul Public School Dist",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273327002334",
    },
    {
        "school": "Early Learning Resource Center",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274227000531",
    },
    {
        "school": "GARLOUGH ENVIRONMENTAL MAGNET",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274227001773",
    },
    {
        "school": "HERITAGE E-STEM MAGNET SCHOOL",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274227001774",
    },
    {
        "school": "MORELAND ART/HEALTH SCIENCE MAGNET",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274227001776",
    },
    {
        "school": "PILOT KNOB STEM MAGNET SCHOOL",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274227001778",
    },
    {
        "school": "HENRY SIBLEY HIGH SCHOOL",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274227001779",
    },
    {
        "school": "SOMERSET ELEMENTARY",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274227001780",
    },
    {
        "school": "MENDOTA ELEMENTARY",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274227002202",
    },
    {
        "school": "FRIENDLY HILLS MIDDLE",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274227002646",
    },
    {
        "school": "W ST. PAUL AREA LEARNING CNTR.",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274227002805",
    },
    {
        "school": "DISTRICT SERVICE CENTER",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002502584",
    },
    {
        "school": "HENNEPIN TECHNICAL PATHWAYS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MN",
        "nces_id": "270002502765",
    },
    {
        "school": "SOUTH EDUCATION CENTER ACADEMY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002502871",
    },
    {
        "school": "270 HOPKINS ALTERNATIVE",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002502875",
    },
    {
        "school": "270 HOPKINS IS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503114",
    },
    {
        "school": "270 HOPKINS WEST JR HIGH ALC",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503396",
    },
    {
        "school": "270 HOPKINS NORTH JR HIGH ALC",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503397",
    },
    {
        "school": "CEDAR RIVERSIDE COMMUNITY SCHOOL",
        "district": "CEDAR RIVERSIDE COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002702340",
    },
    {
        "school": "ATHLOS LEADERSHIP ACADEMY",
        "district": "ATHLOS LEADERSHIP ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009601892",
    },
    {
        "school": "MINNESOTA TRANSITIONS CHARTER ELEM",
        "district": "MINNESOTA TRANSITIONS CHARTER SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011702607",
    },
    {
        "school": "SOJOURNER TRUTH ACADEMY",
        "district": "SOJOURNER TRUTH ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270015902954",
    },
    {
        "school": "EL COLEGIO CHARTER SCHOOL",
        "district": "EL COLEGIO CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018103049",
    },
    {
        "school": "EXCELL ACADEMY CHARTER",
        "district": "EXCELL ACADEMY CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018403137",
    },
    {
        "school": "MN INTERNATIONAL MIDDLE CHR SCHOOL",
        "district": "Twin Cities International Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018903142",
    },
    {
        "school": "FRIENDSHIP ACDMY OF FINE ARTS CHTR.",
        "district": "FRIENDSHIP ACDMY OF FINE ARTS CHTR.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270019003143",
    },
    {
        "school": "AURORA CHARTER SCHOOL",
        "district": "AURORA CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270022003473",
    },
    {
        "school": "CHAMPLIN PARK HIGH SCHOOL",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000021",
    },
    {
        "school": "DAYTON ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000102",
    },
    {
        "school": "EVERGREEN PARK ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000104",
    },
    {
        "school": "JACKSON MIDDLE",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000108",
    },
    {
        "school": "MONROE ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318000116",
    },
    {
        "school": "OXBOW CREEK ELEMENTARY",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318002193",
    },
    {
        "school": "Anoka-Hennepin Tech High School",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270318002629",
    },
    {
        "school": "INDIAN MOUNDS ELEMENTARY",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000218",
    },
    {
        "school": "JEFFERSON SENIOR HIGH",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000219",
    },
    {
        "school": "KENNEDY SENIOR HIGH",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000220",
    },
    {
        "school": "OAK GROVE ELEMENTARY",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000223",
    },
    {
        "school": "NORMANDALE HILLS ELEMENTARY",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000225",
    },
    {
        "school": "OAK GROVE MIDDLE",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000226",
    },
    {
        "school": "OLSON ELEMENTARY",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000227",
    },
    {
        "school": "OLSON MIDDLE",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000228",
    },
    {
        "school": "POPLAR BRIDGE ELEMENTARY",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000232",
    },
    {
        "school": "RIDGEVIEW ELEMENTARY",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000234",
    },
    {
        "school": "VALLEY VIEW ELEMENTARY",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000238",
    },
    {
        "school": "WESTWOOD ELEMENTARY",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000240",
    },
    {
        "school": "VALLEY VIEW MIDDLE",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000638",
    },
    {
        "school": "WASHBURN ELEMENTARY",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579000640",
    },
    {
        "school": "HILLCREST ELEMENTARY",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270579002292",
    },
    {
        "school": "Brooklyn Center High School",
        "district": "BROOKLYN CENTER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270624000273",
    },
    {
        "school": "EARLE BROWN ELEMENTARY",
        "district": "BROOKLYN CENTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270624000274",
    },
    {
        "school": "CONCORD ELEMENTARY",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271125000505",
    },
    {
        "school": "CORNELIA ELEMENTARY",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271125000506",
    },
    {
        "school": "COUNTRYSIDE ELEMENTARY",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271125000507",
    },
    {
        "school": "CREEK VALLEY ELEMENTARY",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271125000508",
    },
    {
        "school": "EDINA SENIOR HIGH",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271125000510",
    },
    {
        "school": "SOUTH VIEW MIDDLE",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271125000686",
    },
    {
        "school": "NORMANDALE ELEMENTARY",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271125000709",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL ED",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271125000725",
    },
    {
        "school": "VALLEY VIEW MIDDLE",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271125002035",
    },
    {
        "school": "HIGHLANDS ELEMENTARY",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271125002269",
    },
    {
        "school": "SPECIAL ED-NON PUBLIC",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271125002649",
    },
    {
        "school": "ROGERS ELEMENTARY",
        "district": "Elk River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137000521",
    },
    {
        "school": "ROGERS MIDDLE SCHOOL",
        "district": "Elk River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137002844",
    },
    {
        "school": "CLEAR SPRINGS ELEMENTARY",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271167000541",
    },
    {
        "school": "DEEPHAVEN ELEMENTARY",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271167000542",
    },
    {
        "school": "EXCELSIOR ELEMENTARY",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271167000543",
    },
    {
        "school": "GROVELAND ELEMENTARY",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271167000544",
    },
    {
        "school": "MINNETONKA EAST MIDDLE",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271167000545",
    },
    {
        "school": "MINNETONKA SENIOR HIGH",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271167000546",
    },
    {
        "school": "MINNEWASHTA ELEMENTARY",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271167000548",
    },
    {
        "school": "SCENIC HEIGHTS ELEMENTARY",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271167000549",
    },
    {
        "school": "DEEPHAVEN EDUCATION CENTER",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271167000738",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL  ED.",
        "district": "EDEN PRAIRIE PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271422000651",
    },
    {
        "school": "CENTRAL MIDDLE SCHOOL",
        "district": "EDEN PRAIRIE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271422000734",
    },
    {
        "school": "EDEN PRAIRIE SENIOR HIGH",
        "district": "EDEN PRAIRIE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271422000735",
    },
    {
        "school": "FOREST HILLS ELEMENTARY",
        "district": "EDEN PRAIRIE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271422000736",
    },
    {
        "school": "PRAIRIE VIEW ELEMENTARY",
        "district": "EDEN PRAIRIE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271422000737",
    },
    {
        "school": "EDEN LAKE ELEMENTARY",
        "district": "EDEN PRAIRIE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271422002197",
    },
    {
        "school": "CEDAR RIDGE ELEMENTARY",
        "district": "EDEN PRAIRIE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271422002241",
    },
    {
        "school": "Oak Point Elementary",
        "district": "EDEN PRAIRIE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271422002271",
    },
    {
        "school": "HOPKINS SENIOR HIGH",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271426000613",
    },
    {
        "school": "HOPKINS NORTH JUNIOR HIGH",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271426000615",
    },
    {
        "school": "HOPKINS WEST JUNIOR HIGH",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271426000616",
    },
    {
        "school": "GATEWOOD ELEMENTARY",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271426001880",
    },
    {
        "school": "GLEN LAKE ELEMENTARY",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271426001881",
    },
    {
        "school": "MEADOWBROOK ELEMENTARY",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271426001884",
    },
    {
        "school": "ALICE SMITH ELEMENTARY",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271426001886",
    },
    {
        "school": "L.H. TANGLEN ELEMENTARY",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271426001887",
    },
    {
        "school": "EISENHOWER ELEMENTARY",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271426002206",
    },
    {
        "school": "HARLEY HOPKINS FAMILY CENTER",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271426002647",
    },
    {
        "school": "ANDERSEN COMMUNITY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000932",
    },
    {
        "school": "ANTHONY MIDDLE SCHOOL",
        "district": "Minneapolis Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000936",
    },
    {
        "school": "ANWATIN MIDDLE COM & SPANISH D I",
        "district": "Minneapolis Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000937",
    },
    {
        "school": "ARMATAGE ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000938",
    },
    {
        "school": "BANCROFT ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000941",
    },
    {
        "school": "BARTON OPEN ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000942",
    },
    {
        "school": "BETHUNE ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000943",
    },
    {
        "school": "BURROUGHS ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000945",
    },
    {
        "school": "EDISON SENIOR HIGH",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000958",
    },
    {
        "school": "Field Community",
        "district": "Minneapolis Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000965",
    },
    {
        "school": "LAKE HARRIET UPPER SCHOOL",
        "district": "Minneapolis Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000969",
    },
    {
        "school": "HALE ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000970",
    },
    {
        "school": "HENRY SENIOR HIGH",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000977",
    },
    {
        "school": "HIAWATHA ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000978",
    },
    {
        "school": "JEFFERSON ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000986",
    },
    {
        "school": "Lake Nokomis Comm-Keewaydin Campus",
        "district": "Minneapolis Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000988",
    },
    {
        "school": "KENNY ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000989",
    },
    {
        "school": "KENWOOD ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000991",
    },
    {
        "school": "LYNDALE ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124000999",
    },
    {
        "school": "NORTHEAST MIDDLE",
        "district": "Minneapolis Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001008",
    },
    {
        "school": "JENNY LIND ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001014",
    },
    {
        "school": "ROOSEVELT SENIOR HIGH",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001026",
    },
    {
        "school": "SANFORD MIDDLE",
        "district": "Minneapolis Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001028",
    },
    {
        "school": "SEWARD ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001031",
    },
    {
        "school": "SOUTH SENIOR HIGH",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001035",
    },
    {
        "school": "SOUTHWEST SENIOR HIGH",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001037",
    },
    {
        "school": "WAITE PARK ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001054",
    },
    {
        "school": "WASHBURN SENIOR HIGH",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001055",
    },
    {
        "school": "Lake Nokomis Comm-Wenonah Campus",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001057",
    },
    {
        "school": "LAKE HARRIET LOWER ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001861",
    },
    {
        "school": "WINDOM SCHOOL",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001865",
    },
    {
        "school": "FOLWELL ARTS MAGNET",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001866",
    },
    {
        "school": "DOWLING ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001868",
    },
    {
        "school": "ECSE",
        "district": "Minneapolis Public School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272124001870",
    },
    {
        "school": "BRYN MAWR ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001878",
    },
    {
        "school": "GREEN CENTRAL PARK ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001879",
    },
    {
        "school": "EMERSON ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001882",
    },
    {
        "school": "BASIC SKILLS-4",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001896",
    },
    {
        "school": "MERC",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001898",
    },
    {
        "school": "LORING-NICOLLET HIGH",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001899",
    },
    {
        "school": "PLYMOUTH YOUTH CENTER",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001901",
    },
    {
        "school": "CENTER SCHOOL",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001903",
    },
    {
        "school": "MENLO PARK ACADEMY",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001908",
    },
    {
        "school": "TRANSITION PLUS SERVICES",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272124001914",
    },
    {
        "school": "HARRISON EDUCATION CENTER",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272124001915",
    },
    {
        "school": "LORING ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124001920",
    },
    {
        "school": "ALC EXTENDED DAY",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001922",
    },
    {
        "school": "MPLS H.S. Alternative Program",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001924",
    },
    {
        "school": "STADIUM VIEW",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001933",
    },
    {
        "school": "MPS METRO HA",
        "district": "Minneapolis Public School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001935",
    },
    {
        "school": "MPS METRO SJ",
        "district": "Minneapolis Public School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001936",
    },
    {
        "school": "MPS METRO C",
        "district": "Minneapolis Public School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124001948",
    },
    {
        "school": "MARCY OPEN ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124002144",
    },
    {
        "school": "NORTHROP ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124002177",
    },
    {
        "school": "SHERIDAN ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124002178",
    },
    {
        "school": "PILLSBURY ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124002296",
    },
    {
        "school": "SULLIVAN ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124002297",
    },
    {
        "school": "Lucy Laney @ Cleveland Park Elem",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124002476",
    },
    {
        "school": "HALL INTERNATIONAL",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124002580",
    },
    {
        "school": "OLSON MIDDLE",
        "district": "Minneapolis Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124002581",
    },
    {
        "school": "EARLY CHILDHOOD ASSESSMENT/SPECIAL",
        "district": "Minneapolis Public School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272124002582",
    },
    {
        "school": "NELLIE STONE JOHNSON ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124002699",
    },
    {
        "school": "WHITTIER INTERNATIONAL",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124002700",
    },
    {
        "school": "RONALD MCDONALD HOUSE",
        "district": "Minneapolis Public School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124002860",
    },
    {
        "school": "AMERICAN INDIAN OIC",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124002862",
    },
    {
        "school": "RIVER BEND EDUCATIONAL CENTER",
        "district": "Minneapolis Public School District",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272124003022",
    },
    {
        "school": "Longfellow Alternative",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124003106",
    },
    {
        "school": "WELLSTONE INTERNATIONAL HIGH",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124003107",
    },
    {
        "school": "PRATT ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124003434",
    },
    {
        "school": "GRANDVIEW MIDDLE SCHOOL",
        "district": "WESTONKA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272292001109",
    },
    {
        "school": "HILLTOP PRIMARY SCHOOL",
        "district": "WESTONKA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272292001110",
    },
    {
        "school": "MOUND WESTONKA HIGH SCHOOL",
        "district": "WESTONKA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272292001112",
    },
    {
        "school": "SHIRLEY HILLS PRIMARY SCHOOL",
        "district": "WESTONKA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272292001113",
    },
    {
        "school": "WESTONKA SP ED ECFE",
        "district": "WESTONKA PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272292002992",
    },
    {
        "school": "ORONO SENIOR HIGH",
        "district": "ORONO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272508001198",
    },
    {
        "school": "ORONO MIDDLE",
        "district": "ORONO PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272508001199",
    },
    {
        "school": "SCHUMANN ELEMENTARY",
        "district": "ORONO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272508001200",
    },
    {
        "school": "ORONO DISCOVERY CENTER",
        "district": "ORONO PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272508002277",
    },
    {
        "school": "ORONO INTERMEDIATE ELEMENTARY",
        "district": "ORONO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272508003444",
    },
    {
        "school": "Early Childhood Special Education",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272520000742",
    },
    {
        "school": "BIRCH GROVE SCHOOL FOR THE ARTS",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001207",
    },
    {
        "school": "Brooklyn Middle STEAM School",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001208",
    },
    {
        "school": "CEDAR ISLAND ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001209",
    },
    {
        "school": "CREST VIEW ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001210",
    },
    {
        "school": "Weaver Lake Science Math & Tech Sch",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001211",
    },
    {
        "school": "FAIR OAKS ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001212",
    },
    {
        "school": "GARDEN CITY ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001213",
    },
    {
        "school": "North View Middle School",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001214",
    },
    {
        "school": "Osseo Middle School",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001217",
    },
    {
        "school": "OSSEO SENIOR HIGH",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001218",
    },
    {
        "school": "PALMER LAKE ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001219",
    },
    {
        "school": "PARK BROOK ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001220",
    },
    {
        "school": "PARK CENTER IB WORLD SCHOOL",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001221",
    },
    {
        "school": "Zanewood Community School STEAM",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001224",
    },
    {
        "school": "ELM CREEK ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001939",
    },
    {
        "school": "RICE LAKE ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520001940",
    },
    {
        "school": "EDINBROOK ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520002211",
    },
    {
        "school": "FERNBROOK ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520002212",
    },
    {
        "school": "Maple Grove Middle School",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520002278",
    },
    {
        "school": "OAK VIEW ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520002299",
    },
    {
        "school": "RUSH CREEK ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520002522",
    },
    {
        "school": "BASSWOOD ELEMENTARY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520002523",
    },
    {
        "school": "MAPLE GROVE SENIOR HIGH",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272520002651",
    },
    {
        "school": "OSSEO SECONDARY TRANSITION CENTER",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272520002809",
    },
    {
        "school": "OSSEO AREA LEARNING CENTER",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272520003445",
    },
    {
        "school": "CENTRAL EDUCATION CENTER",
        "district": "RICHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273175000744",
    },
    {
        "school": "CENTENNIAL ELEMENTARY",
        "district": "RICHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273175001311",
    },
    {
        "school": "RICHFIELD STEM SCHOOL",
        "district": "RICHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273175001312",
    },
    {
        "school": "RICHFIELD SENIOR HIGH",
        "district": "RICHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273175001315",
    },
    {
        "school": "SHERIDAN HILLS ELEMENTARY",
        "district": "RICHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273175001316",
    },
    {
        "school": "RICHFIELD MIDDLE",
        "district": "RICHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273175001317",
    },
    {
        "school": "SECONDARY SPECIAL EDUCATION",
        "district": "RICHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273175002652",
    },
    {
        "school": "ROBBINSDALE SPANISH IMMERSION EL.",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178000747",
    },
    {
        "school": "PHOENIX SCHOOL",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273178000791",
    },
    {
        "school": "ROBBINSDALE ARMSTRONG SENIOR HIGH",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178001318",
    },
    {
        "school": "ROBBINSDALE COOPER SENIOR HIGH",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178001319",
    },
    {
        "school": "FOREST ELEMENTARY",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178001321",
    },
    {
        "school": "LAKEVIEW ELEMENTARY",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178001323",
    },
    {
        "school": "MEADOW LAKE ELEMENTARY",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178001326",
    },
    {
        "school": "NEILL ELEMENTARY",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178001327",
    },
    {
        "school": "NOBLE ELEMENTARY",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178001329",
    },
    {
        "school": "NORTHPORT ELEMENTARY",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178001330",
    },
    {
        "school": "PLYMOUTH MIDDLE",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178001333",
    },
    {
        "school": "SONNESYN ELEMENTARY",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178001337",
    },
    {
        "school": "ZACHARY LANE ELEMENTARY",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178001339",
    },
    {
        "school": "ROBBINSDALE MIDDLE",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178002184",
    },
    {
        "school": "Robbinsdale Shared Time Program",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273178002440",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL EDUCATION",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273178002441",
    },
    {
        "school": "ROCKFORD ELEMENTARY ARTS MAGNET SCH",
        "district": "ROCKFORD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273207001367",
    },
    {
        "school": "ROCKFORD SECONDARY",
        "district": "ROCKFORD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273207001368",
    },
    {
        "school": "ST. ANTHONY VILLAGE SENIOR HIGH",
        "district": "ST. ANTHONY-NEW BRIGHTON SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273342001473",
    },
    {
        "school": "WILSHIRE PARK ELEMENTARY",
        "district": "ST. ANTHONY-NEW BRIGHTON SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273342001474",
    },
    {
        "school": "ST. ANTHONY MIDDLE",
        "district": "ST. ANTHONY-NEW BRIGHTON SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273342001949",
    },
    {
        "school": "ST. LOUIS PARK SPECIAL ED. PROGRAM",
        "district": "ST. LOUIS PARK PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273378000833",
    },
    {
        "school": "AQUILA ELEMENTARY",
        "district": "ST. LOUIS PARK PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273378001525",
    },
    {
        "school": "PETER HOBART ELEMENTARY",
        "district": "ST. LOUIS PARK PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273378001530",
    },
    {
        "school": "SUSAN LINDGREN ELEMENTARY",
        "district": "ST. LOUIS PARK PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273378001531",
    },
    {
        "school": "ST. LOUIS PARK SENIOR HIGH",
        "district": "ST. LOUIS PARK PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273378001532",
    },
    {
        "school": "ST. LOUIS PARK MIDDLE SCHOOL",
        "district": "ST. LOUIS PARK PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273378001533",
    },
    {
        "school": "SPECIAL ED.",
        "district": "ST. LOUIS PARK PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273378002442",
    },
    {
        "school": "PARK SPANISH IMMERSION ELEMENTARY",
        "district": "ST. LOUIS PARK PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273378002653",
    },
    {
        "school": "BIRCHVIEW ELEMENTARY",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216001759",
    },
    {
        "school": "GREENWOOD ELEMENTARY",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216001760",
    },
    {
        "school": "OAKWOOD ELEMENTARY",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216001761",
    },
    {
        "school": "WAYZATA EAST MIDDLE",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216001762",
    },
    {
        "school": "SUNSET HILL ELEMENTARY",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216001763",
    },
    {
        "school": "WAYZATA WEST MIDDLE",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216001764",
    },
    {
        "school": "WAYZATA HIGH",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216001765",
    },
    {
        "school": "PLYMOUTH CREEK ELEMENTARY",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216002247",
    },
    {
        "school": "GLEASON LAKE ELEMENTARY",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216002248",
    },
    {
        "school": "KIMBERLY LANE ELEMENTARY",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216002307",
    },
    {
        "school": "WAYZATA CENTRAL MIDDLE",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216002654",
    },
    {
        "school": "PERPICH CENTER FOR ARTS EDUCATION",
        "district": "PERPICH CENTER FOR ARTS EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "279145602410",
    },
    {
        "school": "BRAHAM ELEMENTARY",
        "district": "BRAHAM PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270606000245",
    },
    {
        "school": "BRAHAM AREA SECONDARY",
        "district": "BRAHAM PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270606000247",
    },
    {
        "school": "CAMBRIDGE-ISANTI HIGH SCHOOL",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270741000316",
    },
    {
        "school": "WINSTED ELEMENTARY",
        "district": "HOWARD LAKE-WAVERLY-WINSTED",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012300908",
    },
    {
        "school": "DASSEL ELEMENTARY",
        "district": "DASSEL-COKATO PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271006000427",
    },
    {
        "school": "METRO DEAF SCHOOL",
        "district": "METRO DEAF SCHOOL",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002802341",
    },
    {
        "school": "Community of Peace Academy Elem",
        "district": "COMMUNITY OF PEACE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011502605",
    },
    {
        "school": "ACHIEVE LANGUAGE ACADEMY",
        "district": "ACHIEVE LANGUAGE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011802608",
    },
    {
        "school": "CYBER VILLAGE ACADEMY",
        "district": "CYBER VILLAGE ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270013802717",
    },
    {
        "school": "HIGHER GROUND ACADEMY",
        "district": "HIGHER GROUND ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270014002719",
    },
    {
        "school": "ST. PAUL CITY PRIMARY SCHOOL",
        "district": "ST. PAUL CITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270014202721",
    },
    {
        "school": "JENNINGS EXPERIENTIAL HIGH SCHOOL",
        "district": "JENNINGS COMMUNITY SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270015202947",
    },
    {
        "school": "LIFE PREP",
        "district": "LIFE PREP",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270015602951",
    },
    {
        "school": "FACE TO FACE ACADEMY",
        "district": "FACE TO FACE ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270015702952",
    },
    {
        "school": "HIGH SCHOOL FOR RECORDING ARTS",
        "district": "HIGH SCHOOL FOR RECORDING ARTS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270016002955",
    },
    {
        "school": "Academia Cesar Chavez Chtr School",
        "district": "ACADEMIA CESAR CHAVEZ CHARTER SCH.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018503138",
    },
    {
        "school": "AFSA HIGH SCHOOL",
        "district": "AFSA HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018603139",
    },
    {
        "school": "AVALON SCHOOL",
        "district": "AVALON SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018703140",
    },
    {
        "school": "BLUESKY CHARTER SCHOOL",
        "district": "BLUESKY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270019303146",
    },
    {
        "school": "HOPE COMMUNITY ACADEMY",
        "district": "HOPE COMMUNITY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270023003482",
    },
    {
        "school": "BELLAIRE EDUCATION CENTER",
        "district": "NORTHEAST METRO 916",
        "level": "Middle",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270226402064",
    },
    {
        "school": "South Campus Education Center",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270226402108",
    },
    {
        "school": "EAST VIEW ACADEMY",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270226402265",
    },
    {
        "school": "WELS NORTH",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270226402483",
    },
    {
        "school": "CITY ACADEMY",
        "district": "CITY ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270895500016",
    },
    {
        "school": "SPEECH PROGRAM - SP ED PROGRAM",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272295001033",
    },
    {
        "school": "ECSE PROGRAM",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272295001036",
    },
    {
        "school": "MOUNDS VIEW ADULT EDUCATION",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272295001038",
    },
    {
        "school": "MOUNDS VIEW ALC",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272295001039",
    },
    {
        "school": "EDGEWOOD MIDDLE SCHOOL",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295001041",
    },
    {
        "school": "BIRTH TO TWO ECSE",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272295001042",
    },
    {
        "school": "BEL AIR ELEMENTARY",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295001114",
    },
    {
        "school": "CHIPPEWA MIDDLE SCHOOL",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295001115",
    },
    {
        "school": "HIGHVIEW MIDDLE SCHOOL",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295001117",
    },
    {
        "school": "IRONDALE SENIOR HIGH",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295001118",
    },
    {
        "school": "ISLAND LAKE ELEMENTARY",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295001119",
    },
    {
        "school": "MOUNDS VIEW SENIOR HIGH",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295001121",
    },
    {
        "school": "Pinewood Elementary",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295001124",
    },
    {
        "school": "SUNNYSIDE ELEMENTARY",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295001128",
    },
    {
        "school": "Turtle Lake Elementary",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295001129",
    },
    {
        "school": "Valentine Hills Elementary",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295001130",
    },
    {
        "school": "SHARED TIME PROGRAM",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272295002536",
    },
    {
        "school": "Career and Life Trans Prg Tin Lake",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272295002664",
    },
    {
        "school": "HIGH SCHOOL SUMMER PROGRAM",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272295002745",
    },
    {
        "school": "MOUNDS VIEW BRIDGES PROGRAM",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272295002998",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL EDUCATION",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272385001043",
    },
    {
        "school": "622 ALTERNATIVE MIDDLE/HIGH SCHOOL",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272385001044",
    },
    {
        "school": "CARVER ELEMENTARY",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385001166",
    },
    {
        "school": "COWERN ELEMENTARY",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385001168",
    },
    {
        "school": "JOHN GLENN MIDDLE",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385001170",
    },
    {
        "school": "NORTH SENIOR HIGH",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385001174",
    },
    {
        "school": "RICHARDSON ELEMENTARY",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385001176",
    },
    {
        "school": "WEAVER ELEMENTARY",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385001178",
    },
    {
        "school": "WEBSTER ELEMENTARY",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385001179",
    },
    {
        "school": "Maplewood Middle School",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385002199",
    },
    {
        "school": "FAIRVIEW DUAL PROGRAM",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272385002537",
    },
    {
        "school": "ROSEVILLE ADULT HIGH SCHOOL",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273243001045",
    },
    {
        "school": "PARKVIEW CENTER SCHOOL",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273243001046",
    },
    {
        "school": "ROSEVILLE AREA SENIOR HIGH",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273243001385",
    },
    {
        "school": "BRIMHALL ELEMENTARY",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273243001386",
    },
    {
        "school": "CENTRAL PARK ELEMENTARY",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273243001388",
    },
    {
        "school": "EDGERTON ELEMENTARY",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273243001389",
    },
    {
        "school": "LITTLE CANADA ELEMENTARY",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273243001394",
    },
    {
        "school": "WILLIAMS ELEMENTARY",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273243001398",
    },
    {
        "school": "FALCON HEIGHTS ELEMENTARY",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273243002186",
    },
    {
        "school": "ROSEVILLE AREA MIDDLE",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273243002667",
    },
    {
        "school": "FAIRVIEW PROGRAM",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273243002668",
    },
    {
        "school": "MIDDLE SCHOOL AREA LEARNING CENTER",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273243002830",
    },
    {
        "school": "A. G. A. P. E. TEEN PARENT",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384001052",
    },
    {
        "school": "HOME/HOSPITAL INSTRUCTION",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384001053",
    },
    {
        "school": "EARLY CHILDHOOD INTERVENTION SERV",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384001062",
    },
    {
        "school": "ADAMS MAGNET ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001133",
    },
    {
        "school": "EXPO FOR EXCELLENCE ELEMENTARY SCH",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001167",
    },
    {
        "school": "FARNSWORTH AEROSPACE LOWER",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001172",
    },
    {
        "school": "JJ HILL MONTESSORI",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001173",
    },
    {
        "school": "NOKOMIS MONTESSORI NORTH CAMPUS",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001194",
    },
    {
        "school": "FOCUS BEYOND",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384001229",
    },
    {
        "school": "UNITED HOSPITAL ADOLESCENT PROGRAM",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384001331",
    },
    {
        "school": "JUVENILE SERVICE CENTER",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384001334",
    },
    {
        "school": "EARLY EDUCATION BEN MAYS/RONDO",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384001360",
    },
    {
        "school": "GORDON PARKS HIGH SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384001415",
    },
    {
        "school": "ALC EVENING HIGH SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384001463",
    },
    {
        "school": "GUADALUPE ALTERNATIVE PROGRAMS",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384001489",
    },
    {
        "school": "BATTLE CREEK ELEMENTARY SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001555",
    },
    {
        "school": "BATTLE CREEK MIDDLE",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001556",
    },
    {
        "school": "CENTRAL SENIOR HIGH",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001564",
    },
    {
        "school": "CHELSEA HEIGHTS ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001565",
    },
    {
        "school": "CHEROKEE HEIGHTS ELEMENTARY SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001566",
    },
    {
        "school": "FARNSWORTH AEROSPACE UPPER",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001567",
    },
    {
        "school": "COMO PARK ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001568",
    },
    {
        "school": "DAYTONS BLUFF ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001571",
    },
    {
        "school": "BRUCE F VENTO ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001575",
    },
    {
        "school": "EASTERN HEIGHTS ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001576",
    },
    {
        "school": "FROST LAKE ELEMENTARY SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001581",
    },
    {
        "school": "GALTIER ELEMENTARY SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001582",
    },
    {
        "school": "GROVELAND PARK ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001583",
    },
    {
        "school": "HAMLINE ELEMENTARY SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001584",
    },
    {
        "school": "HARDING SENIOR HIGH",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001585",
    },
    {
        "school": "THE HEIGHTS COMMUNITY SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001587",
    },
    {
        "school": "HIGHLAND PARK ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001590",
    },
    {
        "school": "HIGHLAND PARK MIDDLE SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001591",
    },
    {
        "school": "HIGHLAND PARK SENIOR HIGH",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001592",
    },
    {
        "school": "HIGHWOOD HILLS ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001593",
    },
    {
        "school": "CAPITOL HILL MAGNET/RONDO",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001594",
    },
    {
        "school": "HUMBOLDT HIGH SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001598",
    },
    {
        "school": "JACKSON PREPARATORY ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001601",
    },
    {
        "school": "JOHNSON SENIOR HIGH",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001603",
    },
    {
        "school": "HORACE MANN SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001607",
    },
    {
        "school": "MAXFIELD ELEMENTARY SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001609",
    },
    {
        "school": "MISSISSIPPI CREATIVE ARTS ELEM",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001611",
    },
    {
        "school": "Global Arts Plus Upper",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001612",
    },
    {
        "school": "PHALEN LAKE HMONG STUDIES MAGNET",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001619",
    },
    {
        "school": "RAMSEY MIDDLE SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001621",
    },
    {
        "school": "RANDOLPH HEIGHTS ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001622",
    },
    {
        "school": "RIVERVIEW WEST SCHOOL OF EXCELLENCE",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001623",
    },
    {
        "school": "ST. ANTHONY PARK ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001628",
    },
    {
        "school": "OBAMA SERVICE LEARNING ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001634",
    },
    {
        "school": "BENJAMIN E MAYS MAGNET",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001952",
    },
    {
        "school": "COMO PARK SENIOR HIGH",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001955",
    },
    {
        "school": "MURRAY MIDDLE SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384001969",
    },
    {
        "school": "BRIDGE VIEW SPECIAL EDUCATION",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384002189",
    },
    {
        "school": "AMERICAN INDIAN MAGNET SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384002303",
    },
    {
        "school": "PAUL & SHEILA WELLSTONE ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384002454",
    },
    {
        "school": "LEAP HIGH SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384002455",
    },
    {
        "school": "Global Arts Plus Lower",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384002540",
    },
    {
        "school": "ECSE INCLUSION",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384002546",
    },
    {
        "school": "RESIDENT STUDENT/OUT OF STATE",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384002549",
    },
    {
        "school": "FOUR SEASONS ELEMENTARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384002671",
    },
    {
        "school": "L'ETOILE DU NORD FRENCH IMMERSION U",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384002672",
    },
    {
        "school": "CROSSROADS MONTESSORI",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384002999",
    },
    {
        "school": "CROSSROADS SCIENCE PROGRAM",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384003000",
    },
    {
        "school": "SHARED TIME NONPUBLIC",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384003087",
    },
    {
        "school": "John A. Johnson Achievement Plus El",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384003454",
    },
    {
        "school": "EARLY ED JOHN A. JOHNSON",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384003456",
    },
    {
        "school": "JOURNEYS SECONDARY SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384003457",
    },
    {
        "school": "NORMANDY PARK EDUCATION CENTER",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274236001048",
    },
    {
        "school": "SUNRISE PARK MIDDLE",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236001049",
    },
    {
        "school": "OTTER LAKE ELEMENTARY",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236001050",
    },
    {
        "school": "WHITE BEAR AREA LEARNING CENTER",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274236001051",
    },
    {
        "school": "BIRCH LAKE ELEMENTARY",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236001786",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236001787",
    },
    {
        "school": "LAKEAIRES ELEMENTARY",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236001790",
    },
    {
        "school": "LINCOLN ELEMENTARY",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236001791",
    },
    {
        "school": "VADNAIS HEIGHTS ELEMENTARY",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236001795",
    },
    {
        "school": "WHITE BEAR NORTH CAMPUS SENIOR",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236001797",
    },
    {
        "school": "WILLOW LANE ELEMENTARY",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236001798",
    },
    {
        "school": "WHITE BEAR SOUTH CAMPUS SENIOR",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236002148",
    },
    {
        "school": "MATOSKA INTERNATIONAL",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236002191",
    },
    {
        "school": "WHITE BEAR LAKE DISTRICT CENTER",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274236002452",
    },
    {
        "school": "LAURENTIAN ENVIRONMENTAL CENTER",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272295002828",
    },
    {
        "school": "CHATFIELD ELEMENTARY",
        "district": "BELLE PLAINE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270405000183",
    },
    {
        "school": "BELLE PLAINE SENIOR HIGH",
        "district": "BELLE PLAINE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270405000184",
    },
    {
        "school": "EARLY CHILDHOOD PROGRAM",
        "district": "BELLE PLAINE PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270405001616",
    },
    {
        "school": "BELLE PLAINE JUNIOR HIGH",
        "district": "BELLE PLAINE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270405002169",
    },
    {
        "school": "M.W. SAVAGE ELEMENTARY",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729000300",
    },
    {
        "school": "HIDDEN VALLEY ELEMENTARY",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729002233",
    },
    {
        "school": "EAGLE RIDGE MIDDLE SCHOOL",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729002639",
    },
    {
        "school": "HARRIET BISHOP ELEMENTARY",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729002641",
    },
    {
        "school": "Jordan High School",
        "district": "JORDAN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271575001625",
    },
    {
        "school": "JORDAN ELEMENTARY",
        "district": "JORDAN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271575001630",
    },
    {
        "school": "FALCON RIDGE",
        "district": "NEW PRAGUE AREA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272343001144",
    },
    {
        "school": "NEW PRAGUE MIDDLE SCHOOL",
        "district": "NEW PRAGUE AREA SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272343001145",
    },
    {
        "school": "NEW PRAGUE SENIOR HIGH",
        "district": "NEW PRAGUE AREA SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272343001146",
    },
    {
        "school": "RAVEN STREAM ELEMENTARY",
        "district": "NEW PRAGUE AREA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272343002842",
    },
    {
        "school": "FIVE HAWKS EL.",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273006001275",
    },
    {
        "school": "HIDDEN OAKS MIDDLE SCHOOL",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273006001276",
    },
    {
        "school": "PRIOR LAKE HIGH SCHOOL",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273006001277",
    },
    {
        "school": "WESTWOOD EL.",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273006001278",
    },
    {
        "school": "GRAINWOOD EL.",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273006002280",
    },
    {
        "school": "GLENDALE EL.",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273006002679",
    },
    {
        "school": "EDGEWOOD ELEMENTARY",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273006003449",
    },
    {
        "school": "SUN PATH ELEMENTARY",
        "district": "SHAKOPEE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273300001437",
    },
    {
        "school": "Shakopee West Middle School",
        "district": "SHAKOPEE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273300001439",
    },
    {
        "school": "Shakopee High School",
        "district": "SHAKOPEE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273300001440",
    },
    {
        "school": "SWEENEY ELEMENTARY",
        "district": "SHAKOPEE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273300001441",
    },
    {
        "school": "CENTRAL FAMILY CENTER",
        "district": "SHAKOPEE PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273300003002",
    },
    {
        "school": "BECKER INTERMEDIATE ELEMENTARY",
        "district": "BECKER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270387000179",
    },
    {
        "school": "BECKER SENIOR HIGH",
        "district": "BECKER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270387000180",
    },
    {
        "school": "BECKER MIDDLE",
        "district": "BECKER PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270387002556",
    },
    {
        "school": "BECKER PRIMARY",
        "district": "BECKER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270387003092",
    },
    {
        "school": "INDEPENDENCE ELEMENTARY",
        "district": "BIG LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270546000205",
    },
    {
        "school": "BIG LAKE SENIOR HIGH",
        "district": "BIG LAKE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270546000206",
    },
    {
        "school": "BIG LAKE MIDDLE SCHOOL",
        "district": "BIG LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270546002462",
    },
    {
        "school": "MEADOWVALE ELEMENTARY",
        "district": "Elk River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137000030",
    },
    {
        "school": "VANDENBERGE MIDDLE SCHOOL",
        "district": "Elk River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137000517",
    },
    {
        "school": "ELK RIVER SENIOR HIGH",
        "district": "Elk River School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137000518",
    },
    {
        "school": "PARKER ELEMENTARY",
        "district": "Elk River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137000520",
    },
    {
        "school": "ZIMMERMAN ELEMENTARY",
        "district": "Elk River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137000522",
    },
    {
        "school": "LINCOLN ELEMENTARY",
        "district": "Elk River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137001635",
    },
    {
        "school": "SALK MIDDLE SCHOOL",
        "district": "Elk River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137002038",
    },
    {
        "school": "IVAN SAND COMMUNITY HIGH SCHOOL",
        "district": "Elk River School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271137002238",
    },
    {
        "school": "MATH AND SCIENCE ACADEMY",
        "district": "MATH AND SCIENCE ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270016703035",
    },
    {
        "school": "North Lakes Academy Middle School",
        "district": "NORTH LAKES ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270017703045",
    },
    {
        "school": "Forest Lake Area Middle School",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271227000592",
    },
    {
        "school": "FOREST LAKE ELEMENTARY",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271227000594",
    },
    {
        "school": "Forest Lake Area High School",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271227000595",
    },
    {
        "school": "FOREST VIEW ELEMENTARY",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271227000596",
    },
    {
        "school": "SCANDIA ELEMENTARY",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271227000599",
    },
    {
        "school": "Forest Lake Area Community School",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271227001725",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL EDUCATION",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271227001726",
    },
    {
        "school": "O.H. ANDERSON ELEMENTARY",
        "district": "MAHTOMEDI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271875000868",
    },
    {
        "school": "MAHTOMEDI MIDDLE",
        "district": "MAHTOMEDI PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271875000869",
    },
    {
        "school": "MAHTOMEDI SENIOR HIGH",
        "district": "MAHTOMEDI PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271875000870",
    },
    {
        "school": "WILDWOOD ELEMENTARY",
        "district": "MAHTOMEDI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271875000871",
    },
    {
        "school": "MAHTOMEDI PRESCHOOL",
        "district": "MAHTOMEDI PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271875001775",
    },
    {
        "school": "NEW HEIGHTS SCHOOL INC.",
        "district": "NEW HEIGHTS SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272338000020",
    },
    {
        "school": "EAGLE POINT ELEMENTARY",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385001169",
    },
    {
        "school": "OAKDALE ELEMENTARY",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385001175",
    },
    {
        "school": "TARTAN SENIOR HIGH",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385001177",
    },
    {
        "school": "CASTLE ELEMENTARY",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385002182",
    },
    {
        "school": "SKYVIEW COMMUNITY ELEMENTARY",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385002665",
    },
    {
        "school": "SKYVIEW COMMUNITY MIDDLE",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385002666",
    },
    {
        "school": "ARMSTRONG ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381001537",
    },
    {
        "school": "CRESTVIEW ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381001538",
    },
    {
        "school": "HILLSIDE ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381001540",
    },
    {
        "school": "NEWPORT ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381001541",
    },
    {
        "school": "OLTMAN MIDDLE SCHOOL",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381001542",
    },
    {
        "school": "Park High School",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381001543",
    },
    {
        "school": "PINE HILL ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381001544",
    },
    {
        "school": "PULLMAN ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381001545",
    },
    {
        "school": "ROYAL OAKS ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381001546",
    },
    {
        "school": "WOODBURY ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381001548",
    },
    {
        "school": "Woodbury High School",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381001550",
    },
    {
        "school": "SOUTH WASHINGTON ALTERNATIVE HS",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273381001777",
    },
    {
        "school": "Ages 3-5 Early Childhood Special Ed",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273381001792",
    },
    {
        "school": "ACCESS",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273381001793",
    },
    {
        "school": "WOODBURY MIDDLE SCHOOL",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381002219",
    },
    {
        "school": "GORDON BAILEY ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381002304",
    },
    {
        "school": "GREY CLOUD ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381002305",
    },
    {
        "school": "MIDDLETON ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381002306",
    },
    {
        "school": "COTTAGE GROVE MIDDLE SCHOOL",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381002465",
    },
    {
        "school": "LAKE MIDDLE SCHOOL",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381002466",
    },
    {
        "school": "RED ROCK ELEMENTARY",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381003103",
    },
    {
        "school": "AFTON-LAKELAND ELEMENTARY",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273819001654",
    },
    {
        "school": "ANDERSEN ELEMENTARY",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273819001655",
    },
    {
        "school": "LAKE ELMO ELEMENTARY",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273819001656",
    },
    {
        "school": "LILY LAKE ELEMENTARY",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273819001657",
    },
    {
        "school": "Oak-Land Middle School",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273819001660",
    },
    {
        "school": "Stillwater Middle School",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273819001661",
    },
    {
        "school": "STILLWATER AREA HIGH SCHOOL",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273819001662",
    },
    {
        "school": "STONEBRIDGE ELEMENTARY",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273819001663",
    },
    {
        "school": "STILLWATER DIST. SPECIAL SERVICES",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273819001799",
    },
    {
        "school": "STILLWATER SPECIAL SERVICES-ECSE",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273819001810",
    },
    {
        "school": "ST CROIX VALLEY AREA LEARNING CNTR.",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273819002685",
    },
    {
        "school": "RUTHERFORD ELEMENTARY",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273819003004",
    },
    {
        "school": "WRIGHT TECHNICAL CENTER",
        "district": "WRIGHT TECHNICAL CENTER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MN",
        "nces_id": "270003602350",
    },
    {
        "school": "WRIGHT TECHNICAL CENTER ALC",
        "district": "WRIGHT TECHNICAL CENTER",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270003602351",
    },
    {
        "school": "WRIGHT TECHNICAL CENTER ALC MIDDLE",
        "district": "WRIGHT TECHNICAL CENTER",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270003602956",
    },
    {
        "school": "EASTERN WRIGHT PROGRAM",
        "district": "MEEKER AND WRIGHT SPECIAL EDUCATION",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004502732",
    },
    {
        "school": "WESTSIDE ALTERNATIVE PROGRAM",
        "district": "MEEKER AND WRIGHT SPECIAL EDUCATION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270004502733",
    },
    {
        "school": "MEEKER-WRIGHT EARLY CHILDHOOD SP ED",
        "district": "MEEKER AND WRIGHT SPECIAL EDUCATION",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004502960",
    },
    {
        "school": "CORNERSTONES PROGRAM",
        "district": "MEEKER AND WRIGHT SPECIAL EDUCATION",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004502961",
    },
    {
        "school": "VILLAGE RANCH ALTERNATIVE PROGRAM",
        "district": "MEEKER AND WRIGHT SPECIAL EDUCATION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270004502964",
    },
    {
        "school": "HOWARD LAKE-WAVERLY-WINSTED SEC.",
        "district": "HOWARD LAKE-WAVERLY-WINSTED",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012300751",
    },
    {
        "school": "HUMPHREY ELEMENTARY",
        "district": "HOWARD LAKE-WAVERLY-WINSTED",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012302697",
    },
    {
        "school": "ANNANDALE MIDDLE SCHOOL",
        "district": "ANNANDALE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270315000093",
    },
    {
        "school": "ANNANDALE ELEMENTARY SCHOOL",
        "district": "ANNANDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270315000094",
    },
    {
        "school": "ANNANDALE SENIOR HIGH",
        "district": "ANNANDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270315001825",
    },
    {
        "school": "PARKSIDE ELEMENTARY",
        "district": "BUFFALO-HANOVER-MONTROSE PUBLIC SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270720000283",
    },
    {
        "school": "BUFFALO COMMUNITY MIDDLE",
        "district": "BUFFALO-HANOVER-MONTROSE PUBLIC SCH",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270720000284",
    },
    {
        "school": "BUFFALO SENIOR HIGH",
        "district": "BUFFALO-HANOVER-MONTROSE PUBLIC SCH",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270720000285",
    },
    {
        "school": "HANOVER ELEMENTARY",
        "district": "BUFFALO-HANOVER-MONTROSE PUBLIC SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270720000286",
    },
    {
        "school": "Montrose Elementary School of Innov",
        "district": "BUFFALO-HANOVER-MONTROSE PUBLIC SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270720000287",
    },
    {
        "school": "Tatanka Elementary STEM School",
        "district": "BUFFALO-HANOVER-MONTROSE PUBLIC SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270720001875",
    },
    {
        "school": "DISCOVERY ELEMENTARY",
        "district": "BUFFALO-HANOVER-MONTROSE PUBLIC SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270720002686",
    },
    {
        "school": "BUFFALO EARLY CHILD. SP. ED PROGRAM",
        "district": "BUFFALO-HANOVER-MONTROSE PUBLIC SCH",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270720002852",
    },
    {
        "school": "PHOENIX LEARNING CENTER",
        "district": "BUFFALO-HANOVER-MONTROSE PUBLIC SCH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270720002853",
    },
    {
        "school": "COKATO ELEMENTARY",
        "district": "DASSEL-COKATO PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271006000426",
    },
    {
        "school": "DASSEL-COKATO SENIOR HIGH",
        "district": "DASSEL-COKATO PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271006000428",
    },
    {
        "school": "DASSEL-COKATO MIDDLE",
        "district": "DASSEL-COKATO PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271006002267",
    },
    {
        "school": "DASSEL-COKATO ALTERNATIVE CTR.",
        "district": "DASSEL-COKATO PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271006002658",
    },
    {
        "school": "DELANO ELEMENTARY",
        "district": "DELANO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271017000436",
    },
    {
        "school": "Delano Intermediate School",
        "district": "DELANO PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271017000437",
    },
    {
        "school": "Delano High School",
        "district": "DELANO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271017000438",
    },
    {
        "school": "OTSEGO ELEMENTARY",
        "district": "Elk River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137002557",
    },
    {
        "school": "MAPLE LAKE ELEMENTARY",
        "district": "MAPLE LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271881000885",
    },
    {
        "school": "MAPLE LAKE SECONDARY",
        "district": "MAPLE LAKE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271881000886",
    },
    {
        "school": "PINEWOOD ELEMENTARY",
        "district": "MONTICELLO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272139001078",
    },
    {
        "school": "MONTICELLO SENIOR HIGH",
        "district": "MONTICELLO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272139001079",
    },
    {
        "school": "MONTICELLO ALTERNATIVE PROGRAM",
        "district": "MONTICELLO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272139001834",
    },
    {
        "school": "LITTLE MOUNTAIN ELEMENTARY",
        "district": "MONTICELLO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272139001837",
    },
    {
        "school": "MONTICELLO MIDDLE",
        "district": "MONTICELLO PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272139002209",
    },
    {
        "school": "ROCKFORD MIDDLE",
        "district": "ROCKFORD PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273207001941",
    },
    {
        "school": "ST. MICHAEL ELEMENTARY",
        "district": "ST. MICHAEL-ALBERTVILLE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273379000032",
    },
    {
        "school": "ALBERTVILLE PRIMARY",
        "district": "ST. MICHAEL-ALBERTVILLE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273379001534",
    },
    {
        "school": "ST. MICHAEL-ALBERTVILLE SENIOR HIGH",
        "district": "ST. MICHAEL-ALBERTVILLE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273379001535",
    },
    {
        "school": "ST. MICHAEL-ALBERTVILLE MIDDLE EAST",
        "district": "ST. MICHAEL-ALBERTVILLE SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273379001536",
    },
    {
        "school": "KNIGHTS ACADEMY",
        "district": "ST. MICHAEL-ALBERTVILLE SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273379003105",
    },
    {
        "school": "COMFREY ELEMENTARY",
        "district": "COMFREY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270954000403",
    },
    {
        "school": "COMFREY SECONDARY",
        "district": "COMFREY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270954000404",
    },
    {
        "school": "JEFFERSON ELEMENTARY",
        "district": "NEW ULM PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272349001150",
    },
    {
        "school": "NEW ULM HIGH SCHOOL",
        "district": "NEW ULM PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272349001153",
    },
    {
        "school": "WASHINGTON ELEMENTARY",
        "district": "NEW ULM PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272349001154",
    },
    {
        "school": "SLEEPY EYE ELEMENTARY",
        "district": "SLEEPY EYE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273321001450",
    },
    {
        "school": "SLEEPY EYE SEC.",
        "district": "SLEEPY EYE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273321001451",
    },
    {
        "school": "SPRINGFIELD ELEMENTARY",
        "district": "SPRINGFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273339001470",
    },
    {
        "school": "SPRINGFIELD SECONDARY",
        "district": "SPRINGFIELD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273339001471",
    },
    {
        "school": "RIVER BEND AREA LEARNING CENTER",
        "district": "RIVER BEND EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279135302494",
    },
    {
        "school": "RIVER BEND EARLY CHILDHOOD PROG.",
        "district": "RIVER BEND EDUCATION DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279135302496",
    },
    {
        "school": "BLOOMING PRAIRIE ELEMENTARY",
        "district": "BLOOMING PRAIRIE PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270576000214",
    },
    {
        "school": "BLOOMING PRAIRIE SECONDARY",
        "district": "BLOOMING PRAIRIE PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270576000215",
    },
    {
        "school": "MEDFORD ELEMENTARY",
        "district": "MEDFORD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271932000909",
    },
    {
        "school": "MEDFORD SECONDARY",
        "district": "MEDFORD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271932000910",
    },
    {
        "school": "LINCOLN ELEMENTARY",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272805001225",
    },
    {
        "school": "MCKINLEY ELEMENTARY",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272805001226",
    },
    {
        "school": "Owatonna Middle School",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272805001227",
    },
    {
        "school": "OWATONNA SENIOR HIGH",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272805001228",
    },
    {
        "school": "WASHINGTON ELEMENTARY",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272805001230",
    },
    {
        "school": "WILSON ELEMENTARY",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272805001231",
    },
    {
        "school": "OWATONNA ECSE",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272805002681",
    },
    {
        "school": "OWATONNA ALC 9-12",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272805002846",
    },
    {
        "school": "OWATONNA SUMMER SCHOOL 9-12",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272805003096",
    },
    {
        "school": "OWATONNA ALC 6-8",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272805003100",
    },
    {
        "school": "PINE ISLAND MIDDLE",
        "district": "Pine Island Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272895004143",
    },
    {
        "school": "CANNON FALLS ELEMENTARY",
        "district": "CANNON FALLS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270750000323",
    },
    {
        "school": "CANNON FALLS SECONDARY",
        "district": "CANNON FALLS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270750000324",
    },
    {
        "school": "GOODHUE ELEMENTARY",
        "district": "GOODHUE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271290000647",
    },
    {
        "school": "GOODHUE SECONDARY",
        "district": "GOODHUE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271290000648",
    },
    {
        "school": "KENYON-WANAMINGO ELEMENTARY",
        "district": "KENYON-WANAMINGO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271710000792",
    },
    {
        "school": "KENYON-WANAMINGO SENIOR HIGH",
        "district": "KENYON-WANAMINGO SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271710000793",
    },
    {
        "school": "KENYON-WANAMINGO MIDDLE",
        "district": "KENYON-WANAMINGO SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271710001741",
    },
    {
        "school": "PINE ISLAND ELEMENTARY",
        "district": "Pine Island Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272895001257",
    },
    {
        "school": "PINE ISLAND SECONDARY",
        "district": "Pine Island Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272895001258",
    },
    {
        "school": "COLVILL FAMILY EDUCATION CENTER",
        "district": "RED WING PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273048000575",
    },
    {
        "school": "Burnside Elementary",
        "district": "RED WING PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273048001292",
    },
    {
        "school": "RED WING SENIOR HIGH",
        "district": "RED WING PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273048001293",
    },
    {
        "school": "SUNNYSIDE ELEMENTARY",
        "district": "RED WING PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273048001297",
    },
    {
        "school": "TWIN BLUFF MIDDLE SCHOOL",
        "district": "RED WING PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273048001298",
    },
    {
        "school": "REACH PROGRAMS",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279144302399",
    },
    {
        "school": "Early Childhood Assessment",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273180003196",
    },
    {
        "school": "HAYFIELD ELEMENTARY",
        "district": "HAYFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271359000701",
    },
    {
        "school": "HAYFIELD SECONDARY",
        "district": "HAYFIELD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271359000702",
    },
    {
        "school": "KASSON-MANTORVILLE ELEMENTARY",
        "district": "KASSON-MANTORVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271698000783",
    },
    {
        "school": "KASSON-MANTORVILLE SENIOR HIGH",
        "district": "KASSON-MANTORVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271698000784",
    },
    {
        "school": "KASSON-MANTORVILLE MIDDLE SCHOOL",
        "district": "KASSON-MANTORVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271698002243",
    },
    {
        "school": "TRITON MIDDLE SCHOOL",
        "district": "TRITON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274066500035",
    },
    {
        "school": "TRITON ELEMENTARY",
        "district": "TRITON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274066500036",
    },
    {
        "school": "TRITON HIGH SCHOOL",
        "district": "TRITON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274066500038",
    },
    {
        "school": "ZUMBROTA-MAZEPPA ELEMENTARY SCHOOL",
        "district": "ZUMBROTA-MAZEPPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274573500200",
    },
    {
        "school": "ZUMBROTA-MAZEPPA SENIOR HIGH",
        "district": "ZUMBROTA-MAZEPPA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274573500209",
    },
    {
        "school": "BLUFF VIEW ELEMENTARY",
        "district": "LAKE CITY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271752000803",
    },
    {
        "school": "LINCOLN SECONDARY",
        "district": "LAKE CITY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271752000804",
    },
    {
        "school": "WABASHA-KELLOGG SECONDARY",
        "district": "WABASHA-KELLOGG PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274106001722",
    },
    {
        "school": "WABASHA-KELLOGG ELEMENTARY",
        "district": "WABASHA-KELLOGG PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274106001723",
    },
    {
        "school": "ZUMBROTA-MAZEPPA MIDDLE SCHOOL",
        "district": "ZUMBROTA-MAZEPPA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274573500221",
    },
    {
        "school": "ZUMBRO AREA LEARNING CENTER",
        "district": "ZUMBRO EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270005402492",
    },
    {
        "school": "ZUMBRO ED. DIST. FUTURES/CHOICE",
        "district": "ZUMBRO EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270005402500",
    },
    {
        "school": "CHATFIELD ELEMENTARY SCHOOL",
        "district": "CHATFIELD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270822000349",
    },
    {
        "school": "ZUMBRO EDUCATION DISTRICT",
        "district": "ZUMBRO EDUCATION DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270005402376",
    },
    {
        "school": "Rosa Parks Charter High School",
        "district": "Rosa Parks Charter High School",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018003048",
    },
    {
        "school": "Byron Intermediate School",
        "district": "BYRON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270735000306",
    },
    {
        "school": "BYRON SENIOR HIGH SCHOOL",
        "district": "BYRON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270735000307",
    },
    {
        "school": "BYRON MIDDLE SCHOOL",
        "district": "BYRON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270735000981",
    },
    {
        "school": "CHATFIELD SECONDARY",
        "district": "CHATFIELD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270822000348",
    },
    {
        "school": "DOVER-EYOTA HIGH SCHOOL",
        "district": "DOVER-EYOTA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271101000452",
    },
    {
        "school": "DOVER-EYOTA ELEMENTARY",
        "district": "DOVER-EYOTA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271101000453",
    },
    {
        "school": "BAMBER VALLEY ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180000982",
    },
    {
        "school": "BISHOP ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180000984",
    },
    {
        "school": "ROCHESTER PHOENIX ACADEMY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273180000985",
    },
    {
        "school": "CHURCHILL ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180000987",
    },
    {
        "school": "ELTON HILLS ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180000990",
    },
    {
        "school": "FOLWELL ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180000992",
    },
    {
        "school": "FRANKLIN ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180000993",
    },
    {
        "school": "MONTESSORI AT FRANKLIN",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180000994",
    },
    {
        "school": "GAGE ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180000996",
    },
    {
        "school": "HOOVER ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001001",
    },
    {
        "school": "JEFFERSON ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001004",
    },
    {
        "school": "LINCOLN K-8 CHOICE ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001005",
    },
    {
        "school": "LONGFELLOW CHOICE ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001006",
    },
    {
        "school": "PINEWOOD ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001009",
    },
    {
        "school": "SUNSET TERRACE ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001010",
    },
    {
        "school": "WASHINGTON ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001011",
    },
    {
        "school": "EARLY CHILDHOOD INTERVENTION",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273180001012",
    },
    {
        "school": "CARE & TREATMENT HOSPITAL/HOMEBOUND",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273180001013",
    },
    {
        "school": "JOHN MARSHALL SENIOR HIGH",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001015",
    },
    {
        "school": "MAYO SENIOR HIGH",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001016",
    },
    {
        "school": "JOHN ADAMS MIDDLE",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001018",
    },
    {
        "school": "WILLOW CREEK MIDDLE",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001019",
    },
    {
        "school": "KELLOGG MIDDLE",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180001020",
    },
    {
        "school": "FRIEDELL MIDDLE",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180002449",
    },
    {
        "school": "CENTURY SENIOR HIGH",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180002660",
    },
    {
        "school": "Rochester Academy-Idp Living(RAIL)",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273180002661",
    },
    {
        "school": "CARE & TREATMENT JDC/VON WALD",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273180002823",
    },
    {
        "school": "RIVERSIDE CENTRAL ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180003077",
    },
    {
        "school": "Rochester Alternative Learning Cntr",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273180003078",
    },
    {
        "school": "ALC SUMMER CREDIT RECOVERY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273180003079",
    },
    {
        "school": "BONNER ELEMENTARY",
        "district": "STEWARTVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273816001651",
    },
    {
        "school": "Bear Cave Intermediate School",
        "district": "STEWARTVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273816001652",
    },
    {
        "school": "STEWARTVILLE SENIOR HIGH",
        "district": "STEWARTVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273816001653",
    },
    {
        "school": "STEWARTVILLE MIDDLE",
        "district": "STEWARTVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273816002822",
    },
    {
        "school": "SAUK RAPIDS ECFE",
        "district": "SAUK RAPIDS-RICE PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273288004195",
    },
    {
        "school": "MELROSE MIDDLE",
        "district": "MELROSE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272055003367",
    },
    {
        "school": "OAK RIDGE ELEMENTARY",
        "district": "SARTELL-ST. STEPHEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273282004210",
    },
    {
        "school": "ST. CLOUD GROUP HOME",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273351003368",
    },
    {
        "school": "ST. CLOUD HOSPITAL PROGRAMS NON-RES",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273351003369",
    },
    {
        "school": "BEACON PROGRAM W CENTRAL ED. DIST.",
        "district": "WEST CENTRAL EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279145503591",
    },
    {
        "school": "CENTRAL MN. ALC - SAUK RAPIDS",
        "district": "CENTRAL MINNESOTA JT. POWERS DIST.",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270014302723",
    },
    {
        "school": "CENTRAL MN AREA LEARN CNTR - FOLEY",
        "district": "CENTRAL MINNESOTA JT. POWERS DIST.",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270014302743",
    },
    {
        "school": "FOLEY ELEMENTARY",
        "district": "FOLEY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271224000590",
    },
    {
        "school": "FOLEY SENIOR HIGH",
        "district": "FOLEY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271224000591",
    },
    {
        "school": "FOLEY INTERMEDIATE ELEMENTARY",
        "district": "FOLEY PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271224002270",
    },
    {
        "school": "MISSISSIPPI HEIGHTS ELEMENTARY",
        "district": "SAUK RAPIDS-RICE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273288001430",
    },
    {
        "school": "PLEASANT VIEW ELEMENTARY",
        "district": "SAUK RAPIDS-RICE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273288001431",
    },
    {
        "school": "RICE ELEMENTARY",
        "district": "SAUK RAPIDS-RICE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273288001433",
    },
    {
        "school": "SAUK RAPIDS-RICE SENIOR HIGH",
        "district": "SAUK RAPIDS-RICE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273288001434",
    },
    {
        "school": "SAUK RAPIDS-RICE MIDDLE SCHOOL",
        "district": "SAUK RAPIDS-RICE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273288002246",
    },
    {
        "school": "LINCOLN ELEMENTARY",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351001486",
    },
    {
        "school": "CLEARVIEW ELEMENTARY",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351001481",
    },
    {
        "school": "TALAHI COMMUNITY ELEMENTARY",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351002286",
    },
    {
        "school": "Benton-Stearns Education District",
        "district": "Benton-Stearns Education District",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007102403",
    },
    {
        "school": "BELGRADE-BROOTEN-ELROSA ELEMENTARY",
        "district": "BELGRADE-BROOTEN-ELROSA SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010500182",
    },
    {
        "school": "BELGRADE-BROOTEN-ELROSA SEC.",
        "district": "BELGRADE-BROOTEN-ELROSA SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010502567",
    },
    {
        "school": "CENTRAL MN ALC HOLDINGFORD",
        "district": "CENTRAL MINNESOTA JT. POWERS DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270014302740",
    },
    {
        "school": "CENTRAL MN ALC KIMBALL",
        "district": "CENTRAL MINNESOTA JT. POWERS DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270014302741",
    },
    {
        "school": "CENTRAL MN ALC SARTELL",
        "district": "CENTRAL MINNESOTA JT. POWERS DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270014302742",
    },
    {
        "school": "ST CLOUD EXTENDED DAY PROGRAM",
        "district": "CENTRAL MINNESOTA JT. POWERS DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270014303050",
    },
    {
        "school": "CENTRAL MINNESOTA JT. POWERS DIST.",
        "district": "CENTRAL MINNESOTA JT. POWERS DIST.",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270014303148",
    },
    {
        "school": "ALBANY ELEMENTARY",
        "district": "ALBANY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270293000062",
    },
    {
        "school": "Albany Area Middle School",
        "district": "ALBANY PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270293000063",
    },
    {
        "school": "Albany Area High School",
        "district": "ALBANY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270293000064",
    },
    {
        "school": "AVON ELEMENTARY",
        "district": "ALBANY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270293000065",
    },
    {
        "school": "COLD SPRING ELEMENTARY",
        "district": "ROCORI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270944000385",
    },
    {
        "school": "RICHMOND ELEMENTARY",
        "district": "ROCORI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270944000386",
    },
    {
        "school": "ROCKVILLE ELEMENTARY",
        "district": "ROCORI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270944000387",
    },
    {
        "school": "ROCORI SENIOR HIGH",
        "district": "ROCORI PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270944000388",
    },
    {
        "school": "ROCORI MIDDLE",
        "district": "ROCORI PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270944001682",
    },
    {
        "school": "HOLDINGFORD ELEMENTARY",
        "district": "HOLDINGFORD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271419000732",
    },
    {
        "school": "HOLDINGFORD SECONDARY",
        "district": "HOLDINGFORD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271419000733",
    },
    {
        "school": "KIMBALL ELEMENTARY",
        "district": "KIMBALL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271722000796",
    },
    {
        "school": "KIMBALL SECONDARY",
        "district": "KIMBALL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271722000797",
    },
    {
        "school": "MELROSE ELEMENTARY",
        "district": "MELROSE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272055000911",
    },
    {
        "school": "MELROSE SECONDARY",
        "district": "MELROSE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272055000913",
    },
    {
        "school": "PAYNESVILLE AREA HIGH SCHOOL",
        "district": "PAYNESVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272814001239",
    },
    {
        "school": "PAYNESVILLE ELEMENTARY",
        "district": "PAYNESVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272814001240",
    },
    {
        "school": "PAYNESVILLE MIDDLE",
        "district": "PAYNESVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272814001241",
    },
    {
        "school": "SARTELL SENIOR HIGH",
        "district": "SARTELL-ST. STEPHEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273282001424",
    },
    {
        "school": "SARTELL MIDDLE",
        "district": "SARTELL-ST. STEPHEN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273282001675",
    },
    {
        "school": "PINE MEADOW ELEMENTARY",
        "district": "SARTELL-ST. STEPHEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273282002187",
    },
    {
        "school": "SAUK CENTRE ELEMENTARY",
        "district": "SAUK CENTRE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273285001427",
    },
    {
        "school": "SAUK CENTRE SECONDARY",
        "district": "SAUK CENTRE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273285001429",
    },
    {
        "school": "APOLLO SENIOR HIGH",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351001479",
    },
    {
        "school": "KENNEDY COMMUNITY SCHOOL",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351001485",
    },
    {
        "school": "MADISON ELEMENTARY",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351001487",
    },
    {
        "school": "SOUTH JUNIOR HIGH",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351001492",
    },
    {
        "school": "TECHNICAL SENIOR HIGH",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351001494",
    },
    {
        "school": "WESTWOOD ELEMENTARY",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351001496",
    },
    {
        "school": "SPECIAL EDUCATION FACILITIES",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273351001636",
    },
    {
        "school": "EC Sp Ed at Quarryview Ed Center",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273351001637",
    },
    {
        "school": "RIVERWOODS SCHOOL NON-RESIDENTIAL",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273351001640",
    },
    {
        "school": "NORTH JUNIOR HIGH",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351002188",
    },
    {
        "school": "OAK HILL COMMUNITY ELEMENTARY",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351002285",
    },
    {
        "school": "DISCOVERY COMMUNITY ELEMENTARY",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273351002287",
    },
    {
        "school": "St. Cloud Area Learning Center",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273351003003",
    },
    {
        "school": "WEST CENTRAL AREA LEARNING CENTER",
        "district": "WEST CENTRAL EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279145502388",
    },
    {
        "school": "BRECKENRIDGE SENIOR HIGH",
        "district": "BRECKENRIDGE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270615000265",
    },
    {
        "school": "BRECKENRIDGE ELEMENTARY",
        "district": "BRECKENRIDGE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270615000266",
    },
    {
        "school": "BRECKENRIDGE MIDDLE",
        "district": "BRECKENRIDGE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270615003005",
    },
    {
        "school": "CAMPBELL-TINTAH ELEMENTARY",
        "district": "CAMPBELL-TINTAH PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270745000319",
    },
    {
        "school": "CAMPBELL-TINTAH SECONDARY",
        "district": "CAMPBELL-TINTAH PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270745000320",
    },
    {
        "school": "ROTHSAY SECONDARY",
        "district": "ROTHSAY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273246001399",
    },
    {
        "school": "ROTHSAY ELEMENTARY",
        "district": "ROTHSAY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273246001400",
    },
    {
        "school": "NEW LONDON-SPICER MIDDLE",
        "district": "NEW LONDON-SPICER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272340000948",
    },
    {
        "school": "PRAIRIE WOODS ELEMENTARY",
        "district": "NEW LONDON-SPICER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272340001141",
    },
    {
        "school": "NEW LONDON-SPICER SR.",
        "district": "NEW LONDON-SPICER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272340001142",
    },
    {
        "school": "NEW LONDON ALTERNATIVE SCHOOL",
        "district": "NEW LONDON-SPICER SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272340002766",
    },
    {
        "school": "LAKEVIEW SCHOOL",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274272000949",
    },
    {
        "school": "WILLMAR AREA LEARNING CENTER",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274272000950",
    },
    {
        "school": "JEFFERSON LEARNING CENTER",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274272001807",
    },
    {
        "school": "WILLMAR MIDDLE SCHOOL",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274272001808",
    },
    {
        "school": "WILLMAR SENIOR HIGH",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274272001809",
    },
    {
        "school": "ROOSEVELT ELEMENTARY",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274272002221",
    },
    {
        "school": "KENNEDY ELEMENTARY",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274272002445",
    },
    {
        "school": "RIVERWAY SECONDARY",
        "district": "Riverway Learning Community Charter",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270022103136",
    },
    {
        "school": "Riverway Learning Community Charter",
        "district": "Riverway Learning Community Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270022103478",
    },
    {
        "school": "BLUFFVIEW MONTESSORI",
        "district": "BLUFFVIEW MONTESSORI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270585000018",
    },
    {
        "school": "Lewiston-Altura Intermediate El",
        "district": "Lewiston-Altura Public School Dist",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271809000834",
    },
    {
        "school": "LEWISTON-ALTURA ELEMENTARY",
        "district": "Lewiston-Altura Public School Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271809000835",
    },
    {
        "school": "LEWISTON-ALTURA SECONDARY",
        "district": "Lewiston-Altura Public School Dist",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271809000836",
    },
    {
        "school": "ST. CHARLES ELEMENTARY",
        "district": "ST. CHARLES PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273345001475",
    },
    {
        "school": "ST. CHARLES SECONDARY",
        "district": "ST. CHARLES PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273345001476",
    },
    {
        "school": "GOODVIEW ELEMENTARY",
        "district": "WINONA AREA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274407001821",
    },
    {
        "school": "JEFFERSON ELEMENTARY",
        "district": "WINONA AREA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274407001822",
    },
    {
        "school": "WINONA EARLY CHILDHOOD SPECIAL ED.",
        "district": "WINONA AREA PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274407001823",
    },
    {
        "school": "WASHINGTON-KOSCIUSKO ELEMENTARY",
        "district": "WINONA AREA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274407001829",
    },
    {
        "school": "WINONA MIDDLE",
        "district": "WINONA AREA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274407001830",
    },
    {
        "school": "WINONA SENIOR HIGH",
        "district": "WINONA AREA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274407001831",
    },
    {
        "school": "WINONA AREA LEARNING CENTER",
        "district": "WINONA AREA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274407002249",
    },
    {
        "school": "RIVER VALLEY ACADEMY ALC",
        "district": "HIAWATHA VALLEY ED. DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270005503149",
    },
    {
        "school": "ADRIAN ELEMENTARY",
        "district": "ADRIAN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270273000055",
    },
    {
        "school": "ADRIAN SECONDARY",
        "district": "ADRIAN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270273000056",
    },
    {
        "school": "ADRIAN MIDDLE",
        "district": "ADRIAN PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270273003076",
    },
    {
        "school": "ELLSWORTH ELEMENTARY",
        "district": "ELLSWORTH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271146000525",
    },
    {
        "school": "ELLSWORTH SECONDARY",
        "district": "ELLSWORTH PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271146000526",
    },
    {
        "school": "EARLY CHILDHOOD",
        "district": "WORTHINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274416000980",
    },
    {
        "school": "PRAIRIE ELEMENTARY",
        "district": "WORTHINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274416001836",
    },
    {
        "school": "WORTHINGTON MIDDLE",
        "district": "WORTHINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274416001840",
    },
    {
        "school": "WORTHINGTON SENIOR HIGH",
        "district": "WORTHINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274416001841",
    },
    {
        "school": "Learning Center",
        "district": "WORTHINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274416002335",
    },
    {
        "school": "WOMEN'S EAST REGION TRTMT CTR",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002876",
    },
    {
        "school": "WOMEN E. RECEP/DIAG COR C/ACAD",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002887",
    },
    {
        "school": "WOMEN E. RECEP/DIAG COR C/DIAG",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002890",
    },
    {
        "school": "WESTERN RECEPT/DIAG CORR CENTR",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002877",
    },
    {
        "school": "WESTERN REGION TREATMENT CENTR",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002894",
    },
    {
        "school": "CREMER THERAPEUTIC COMM CENTER",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002900",
    },
    {
        "school": "FULTON RECEPTION AND DIAG CTR",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002904",
    },
    {
        "school": "EAST CARTER CO. R-II MIDDLE",
        "district": "EAST CARTER CO. R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291110002916",
    },
    {
        "school": "BRIDLE RIDGE ELEMENTARY",
        "district": "RAYMORE-PECULIAR R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292373002889",
    },
    {
        "school": "CREEKMOOR ELEM.",
        "district": "RAYMORE-PECULIAR R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292373002913",
    },
    {
        "school": "PLEASANT HILL INTERMEDIATE",
        "district": "PLEASANT HILL R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292533002897",
    },
    {
        "school": "KEARNEY MIDDLE",
        "district": "KEARNEY R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291645002872",
    },
    {
        "school": "WARREN HILLS ELEM.",
        "district": "LIBERTY 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854002902",
    },
    {
        "school": "BOONVILLE TREATMENT CENTER",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002883",
    },
    {
        "school": "BOONVILLE CORRECTIONAL CENTER",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002896",
    },
    {
        "school": "SHADY DELL EARLY CHILDHOOD CTR",
        "district": "SPRINGFIELD R-XII",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886002905",
    },
    {
        "school": "WILLARD INTERMEDIATE NORTH",
        "district": "WILLARD R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293201002879",
    },
    {
        "school": "KC INTERNATIONAL-WALLACE",
        "district": "KC INTERNATIONAL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290001302751",
    },
    {
        "school": "HOGAN PREPARATORY ACADEMY",
        "district": "HOGAN PREPARATORY ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290001402743",
    },
    {
        "school": "GORDON PARKS ELEM.",
        "district": "GORDON PARKS ELEM.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290001502752",
    },
    {
        "school": "GENESIS SCHOOL INC.",
        "district": "GENESIS SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290001602746",
    },
    {
        "school": "ACADEMIE LAFAYETTE-OAK",
        "district": "ACADEMIE LAFAYETTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290001702753",
    },
    {
        "school": "SCUOLA VITA NUOVA CHARTER",
        "district": "SCUOLA VITA NUOVA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290001902754",
    },
    {
        "school": "BROOKSIDE CHARTER ELEMENTARY",
        "district": "BROOKSIDE CHARTER SCH.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002402838",
    },
    {
        "school": "ALLEN VILLAGE ELEMENTARY",
        "district": "ALLEN VILLAGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002502748",
    },
    {
        "school": "UNIVERSITY ACADEMY-UPPER",
        "district": "UNIVERSITY ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002702808",
    },
    {
        "school": "UNIVERSITY ACADEMY-MIDDLE",
        "district": "UNIVERSITY ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002702914",
    },
    {
        "school": "UNIVERSITY ACADEMY-LOWER",
        "district": "UNIVERSITY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002702915",
    },
    {
        "school": "LEE A. TOLBERT COM. ACADEMY",
        "district": "LEE A. TOLBERT COM. ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002802749",
    },
    {
        "school": "GUADALUPE CENTERS HIGH SCHOOL",
        "district": "GUADALUPE CENTERS SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002902741",
    },
    {
        "school": "SOUTHEAST CORRECTIONAL CENTER",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002881",
    },
    {
        "school": "MARYVILLE TREATMENT CENTER",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002910",
    },
    {
        "school": "WOOD ELEM.",
        "district": "WAYNESVILLE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293144002874",
    },
    {
        "school": "FREEDOM ELEM.",
        "district": "WAYNESVILLE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293144002898",
    },
    {
        "school": "PEINE RIDGE ELEM.",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165002903",
    },
    {
        "school": "EAST RECEP/DIAG CORR CENT/ACAD",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002880",
    },
    {
        "school": "EAST RECEP/DIAG CORR CENT/DIAG",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002886",
    },
    {
        "school": "FARMINGTON CORRECTIONAL CENTER",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002907",
    },
    {
        "school": "FARMINGTON TREATMENT CENTER",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002909",
    },
    {
        "school": "MISSOURI EASTERN CORR CENTER",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002893",
    },
    {
        "school": "SOUTH CENTRAL CORRECTIONAL CTR",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002901",
    },
    {
        "school": "OZARK CORRECTIONAL CENTER",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002911",
    },
    {
        "school": "CARNAHAN SCH. OF THE FUTURE",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002873",
    },
    {
        "school": "TRANSPORTATION AND LAW",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002875",
    },
    {
        "school": "YEATMAN-LIDDELL MIDDLE SCHOOL",
        "district": "ST. LOUIS CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002878",
    },
    {
        "school": "SKYLINE MIDDLE",
        "district": "HICKORY CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291432002794",
    },
    {
        "school": "PUXICO JR. HIGH",
        "district": "PUXICO R-VIII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292565002871",
    },
    {
        "school": "GREENVILLE JR. HIGH",
        "district": "GREENVILLE R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291338003035",
    },
    {
        "school": "OZARK REGIONAL JUVENILE DET CT",
        "district": "MOUNTAIN GROVE R-III",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292151002618",
    },
    {
        "school": "FAIRFAX ELEM.",
        "district": "FAIRFAX R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291176000432",
    },
    {
        "school": "FAIRFAX HIGH",
        "district": "FAIRFAX R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291176000433",
    },
    {
        "school": "ROCK PORT ELEM.",
        "district": "ROCK PORT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292679001612",
    },
    {
        "school": "ROCK PORT HIGH",
        "district": "ROCK PORT R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292679001613",
    },
    {
        "school": "TARKIO ELEM.",
        "district": "TARKIO R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292994002066",
    },
    {
        "school": "TARKIO HIGH",
        "district": "TARKIO R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292994002067",
    },
    {
        "school": "EUNICE THOMAS ELEM.",
        "district": "CASSVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290817000217",
    },
    {
        "school": "CASSVILLE HIGH",
        "district": "CASSVILLE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290817000219",
    },
    {
        "school": "CASSVILLE MIDDLE",
        "district": "CASSVILLE R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290817002425",
    },
    {
        "school": "CASSVILLE INTERMEDIATE",
        "district": "CASSVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290817002718",
    },
    {
        "school": "EXETER ELEM.",
        "district": "EXETER R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291167000426",
    },
    {
        "school": "EXETER HIGH",
        "district": "EXETER R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291167000427",
    },
    {
        "school": "MONETT MIDDLE",
        "district": "MONETT R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292112000183",
    },
    {
        "school": "MONETT ELEM.",
        "district": "MONETT R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292112001160",
    },
    {
        "school": "SCOTT REGIONAL TECH CENTER",
        "district": "MONETT R-I",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292112001161",
    },
    {
        "school": "MONETT HIGH",
        "district": "MONETT R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292112001162",
    },
    {
        "school": "PURDY ELEM.",
        "district": "PURDY R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292562001501",
    },
    {
        "school": "PURDY HIGH",
        "district": "PURDY R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292562001502",
    },
    {
        "school": "SHELL KNOB ELEM.",
        "district": "SHELL KNOB 78",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292820001735",
    },
    {
        "school": "SOUTHWEST ELEM.",
        "district": "SOUTHWEST R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292871001773",
    },
    {
        "school": "SOUTHWEST HIGH",
        "district": "SOUTHWEST R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292871001774",
    },
    {
        "school": "SOUTHWEST MIDDLE",
        "district": "SOUTHWEST R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292871002801",
    },
    {
        "school": "WHEATON ELEM.",
        "district": "WHEATON R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293195002236",
    },
    {
        "school": "WHEATON HIGH",
        "district": "WHEATON R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293195002237",
    },
    {
        "school": "GOLDEN CITY ELEM.",
        "district": "GOLDEN CITY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291293000541",
    },
    {
        "school": "GOLDEN CITY HIGH",
        "district": "GOLDEN CITY R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291293000542",
    },
    {
        "school": "LAMAR ELEM.",
        "district": "LAMAR R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291785000953",
    },
    {
        "school": "LAMAR HIGH",
        "district": "LAMAR R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291785000954",
    },
    {
        "school": "LAMAR CAREERTECHNICAL CENTER",
        "district": "LAMAR R-I",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291785000955",
    },
    {
        "school": "LAMAR MIDDLE",
        "district": "LAMAR R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291785002467",
    },
    {
        "school": "EAST ELEM.",
        "district": "LAMAR R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291785002720",
    },
    {
        "school": "LIBERAL ELEM.",
        "district": "LIBERAL R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291851001002",
    },
    {
        "school": "LIBERAL HIGH",
        "district": "LIBERAL R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291851001003",
    },
    {
        "school": "LIBERAL MIDDLE",
        "district": "LIBERAL R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291851002719",
    },
    {
        "school": "COLE CAMP ELEM.",
        "district": "COLE CAMP R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290990000292",
    },
    {
        "school": "COLE CAMP HIGH",
        "district": "COLE CAMP R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290990000293",
    },
    {
        "school": "COLE CAMP MIDDLE",
        "district": "COLE CAMP R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290990001389",
    },
    {
        "school": "LINCOLN ELEM.",
        "district": "LINCOLN R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291867001015",
    },
    {
        "school": "LINCOLN HIGH",
        "district": "LINCOLN R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291867001016",
    },
    {
        "school": "WARSAW HIGH",
        "district": "WARSAW R-IX",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293107002152",
    },
    {
        "school": "NORTH ELEM.",
        "district": "WARSAW R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293107002153",
    },
    {
        "school": "SOUTH ELEM.",
        "district": "WARSAW R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293107002154",
    },
    {
        "school": "JOHN BOISE MIDDLE",
        "district": "WARSAW R-IX",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293107002650",
    },
    {
        "school": "DOGWOOD ELEMENTARY",
        "district": "CAMDENTON R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290699000171",
    },
    {
        "school": "HURRICANE DECK ELEMENTARY",
        "district": "CAMDENTON R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290699000172",
    },
    {
        "school": "CAMDENTON MIDDLE",
        "district": "CAMDENTON R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290699000173",
    },
    {
        "school": "OSAGE BEACH ELEMENTARY",
        "district": "CAMDENTON R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290699000174",
    },
    {
        "school": "CAMDENTON HIGH",
        "district": "CAMDENTON R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290699000175",
    },
    {
        "school": "JUVENILE JUSTICE CENTER",
        "district": "CAMDENTON R-III",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290699001953",
    },
    {
        "school": "LAKE CAREER  TECHNICAL CENTER",
        "district": "CAMDENTON R-III",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290699002273",
    },
    {
        "school": "OAK RIDGE INTERMEDIATE",
        "district": "CAMDENTON R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290699002580",
    },
    {
        "school": "CLIMAX SPRINGS ELEM.",
        "district": "CLIMAX SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290981000283",
    },
    {
        "school": "CLIMAX SPRINGS HIGH",
        "district": "CLIMAX SPRINGS R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290981000284",
    },
    {
        "school": "MACKS CREEK ELEM.",
        "district": "MACKS CREEK R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291938001048",
    },
    {
        "school": "MACKS CREEK HIGH",
        "district": "MACKS CREEK R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291938001049",
    },
    {
        "school": "STOUTLAND ELEMENTARY",
        "district": "STOUTLAND R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292958002045",
    },
    {
        "school": "STOUTLAND HIGH",
        "district": "STOUTLAND R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292958002046",
    },
    {
        "school": "BOSWORTH ELEM.",
        "district": "BOSWORTH R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290561000106",
    },
    {
        "school": "BOSWORTH HIGH",
        "district": "BOSWORTH R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290561000107",
    },
    {
        "school": "CARROLLTON SENIOR HIGH",
        "district": "CARROLLTON R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290738000202",
    },
    {
        "school": "MIDDLE SCHOOL",
        "district": "CARROLLTON R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290738000311",
    },
    {
        "school": "CARROLLTON AREA CAREER CENTER",
        "district": "CARROLLTON R-VII",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290738002368",
    },
    {
        "school": "HALE ELEM.",
        "district": "HALE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291350000573",
    },
    {
        "school": "HALE HIGH",
        "district": "HALE R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291350000574",
    },
    {
        "school": "NORBORNE ELEM.",
        "district": "NORBORNE R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292262001237",
    },
    {
        "school": "NORBORNE HIGH",
        "district": "NORBORNE R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292262001238",
    },
    {
        "school": "TINA-AVALON ELEM.",
        "district": "TINA-AVALON R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293030002070",
    },
    {
        "school": "TINA-AVALON HIGH",
        "district": "TINA-AVALON R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293030002071",
    },
    {
        "school": "EAST CARTER CO. R-II ELEM.",
        "district": "EAST CARTER CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291110000380",
    },
    {
        "school": "EAST CARTER CO. R-II HIGH",
        "district": "EAST CARTER CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291110000383",
    },
    {
        "school": "VAN BUREN HIGH",
        "district": "VAN BUREN R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293075002121",
    },
    {
        "school": "VAN BUREN ELEM.",
        "district": "VAN BUREN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293075002122",
    },
    {
        "school": "EL DORADO SPRINGS HIGH",
        "district": "EL DORADO SPRINGS R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291131000398",
    },
    {
        "school": "EL DORADO SPRINGS ELEM.",
        "district": "EL DORADO SPRINGS R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291131000400",
    },
    {
        "school": "EL DORADO SPRINGS MIDDLE",
        "district": "EL DORADO SPRINGS R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291131002660",
    },
    {
        "school": "STOCKTON MIDDLE",
        "district": "STOCKTON R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292952000089",
    },
    {
        "school": "STOCKTON ELEM.",
        "district": "STOCKTON R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292952002043",
    },
    {
        "school": "STOCKTON HIGH",
        "district": "STOCKTON R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292952002044",
    },
    {
        "school": "BRUNSWICK ELEM.",
        "district": "BRUNSWICK R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290603000144",
    },
    {
        "school": "BRUNSWICK HIGH",
        "district": "BRUNSWICK R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290603000145",
    },
    {
        "school": "KEYTESVILLE ELEM.",
        "district": "KEYTESVILLE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291653000904",
    },
    {
        "school": "KEYTESVILLE HIGH",
        "district": "KEYTESVILLE R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291653000905",
    },
    {
        "school": "NORTHWESTERN ELEM.",
        "district": "NORTHWESTERN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292292001310",
    },
    {
        "school": "NORTHWESTERN HIGH",
        "district": "NORTHWESTERN R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292292001311",
    },
    {
        "school": "SALISBURY ELEM.",
        "district": "SALISBURY R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292752001683",
    },
    {
        "school": "SALISBURY HIGH",
        "district": "SALISBURY R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292752001685",
    },
    {
        "school": "BLACKWATER ELEM.",
        "district": "BLACKWATER R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290519000069",
    },
    {
        "school": "BOONSLICK TECHNICAL EDUC. CTR.",
        "district": "BOONVILLE R-I",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290558000101",
    },
    {
        "school": "HANNAH COLE PRIMARY",
        "district": "BOONVILLE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290558000102",
    },
    {
        "school": "DAVID BARTON ELEM.",
        "district": "BOONVILLE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290558000103",
    },
    {
        "school": "BOONVILLE HIGH",
        "district": "BOONVILLE R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290558000104",
    },
    {
        "school": "LAURA SPEED ELLIOTT MIDDLE",
        "district": "BOONVILLE R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290558000105",
    },
    {
        "school": "BUNCETON ELEM.",
        "district": "COOPER CO. R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290615000153",
    },
    {
        "school": "BUNCETON HIGH",
        "district": "COOPER CO. R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290615000154",
    },
    {
        "school": "OTTERVILLE ELEM.",
        "district": "OTTERVILLE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292331001341",
    },
    {
        "school": "OTTERVILLE HIGH",
        "district": "OTTERVILLE R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292331001342",
    },
    {
        "school": "PILOT GROVE ELEM.",
        "district": "PILOT GROVE C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292517001447",
    },
    {
        "school": "PILOT GROVE HIGH",
        "district": "PILOT GROVE C-4",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292517001448",
    },
    {
        "school": "PRAIRIE HOME ELEM.",
        "district": "PRAIRIE HOME R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292553001499",
    },
    {
        "school": "PRAIRIE HOME HIGH",
        "district": "PRAIRIE HOME R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292553001500",
    },
    {
        "school": "DADEVILLE ELEM.",
        "district": "DADEVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291044000344",
    },
    {
        "school": "DADEVILLE SR. HIGH",
        "district": "DADEVILLE R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291044000345",
    },
    {
        "school": "EVERTON ELEM.",
        "district": "EVERTON R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291158000412",
    },
    {
        "school": "EVERTON HIGH",
        "district": "EVERTON R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291158000413",
    },
    {
        "school": "GREENFIELD ELEM.",
        "district": "GREENFIELD R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291332000565",
    },
    {
        "school": "GREENFIELD HIGH",
        "district": "GREENFIELD R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291332000566",
    },
    {
        "school": "LOCKWOOD ELEM.",
        "district": "LOCKWOOD R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291914001032",
    },
    {
        "school": "LOCKWOOD HIGH",
        "district": "LOCKWOOD R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291914001033",
    },
    {
        "school": "COVEL D. SEARCY ELEM.",
        "district": "GALLATIN R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291266000529",
    },
    {
        "school": "GALLATIN HIGH",
        "district": "GALLATIN R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291266000530",
    },
    {
        "school": "NORTH DAVIESS ELEM.",
        "district": "NORTH DAVIESS R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291563000740",
    },
    {
        "school": "NORTH DAVIESS HIGH",
        "district": "NORTH DAVIESS R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291563000741",
    },
    {
        "school": "PATTONSBURG ELEM.",
        "district": "PATTONSBURG R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292367001409",
    },
    {
        "school": "PATTONSBURG HIGH",
        "district": "PATTONSBURG R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292367001410",
    },
    {
        "school": "TRI-COUNTY ELEM.",
        "district": "TRI-COUNTY R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293039002081",
    },
    {
        "school": "TRI-COUNTY HIGH",
        "district": "TRI-COUNTY R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293039002082",
    },
    {
        "school": "WINSTON ELEM.",
        "district": "WINSTON R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293225002261",
    },
    {
        "school": "WINSTON HIGH",
        "district": "WINSTON R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293225002262",
    },
    {
        "school": "NORTH WOOD ELEM.",
        "district": "NORTH WOOD R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291065000359",
    },
    {
        "school": "DENT-PHELPS ELEM.",
        "district": "DENT-PHELPS R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291071000360",
    },
    {
        "school": "GREEN FOREST ELEM.",
        "district": "GREEN FOREST R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291326000562",
    },
    {
        "school": "OAK HILL ELEM.",
        "district": "OAK HILL R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292304001319",
    },
    {
        "school": "SALEM UPPER ELEM.",
        "district": "SALEM R-80",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292709001676",
    },
    {
        "school": "SALEM MIDDLE SCHOOL",
        "district": "SALEM R-80",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292709001677",
    },
    {
        "school": "SALEM SR. HIGH",
        "district": "SALEM R-80",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292709001678",
    },
    {
        "school": "WM. H. LYNCH ELEM.",
        "district": "SALEM R-80",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292709001679",
    },
    {
        "school": "AVA ELEM.",
        "district": "AVA R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290405000034",
    },
    {
        "school": "AVA HIGH",
        "district": "AVA R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290405000036",
    },
    {
        "school": "AVA MIDDLE",
        "district": "AVA R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290405002548",
    },
    {
        "school": "SKYLINE ELEM.",
        "district": "SKYLINE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291101000376",
    },
    {
        "school": "PLAINVIEW ELEM.",
        "district": "PLAINVIEW R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291104000377",
    },
    {
        "school": "MARIES CO. MIDDLE",
        "district": "MARIES CO. R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000102547",
    },
    {
        "school": "HERMANN ELEM.",
        "district": "GASCONADE CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291428000644",
    },
    {
        "school": "HERMANN HIGH",
        "district": "GASCONADE CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291428000646",
    },
    {
        "school": "HERMANN MIDDLE",
        "district": "GASCONADE CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291428002464",
    },
    {
        "school": "ALBANY HIGH",
        "district": "ALBANY R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290297000010",
    },
    {
        "school": "VIRGINIA E. GEORGE ELEM.",
        "district": "ALBANY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290297000011",
    },
    {
        "school": "ALBANY MIDDLE",
        "district": "ALBANY R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290297001478",
    },
    {
        "school": "KING CITY ELEM.",
        "district": "KING CITY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291659000906",
    },
    {
        "school": "KING CITY HIGH",
        "district": "KING CITY R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291659000907",
    },
    {
        "school": "STANBERRY ELEM.",
        "district": "STANBERRY R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292934002029",
    },
    {
        "school": "STANBERRY HIGH",
        "district": "STANBERRY R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292934002030",
    },
    {
        "school": "GRUNDY CO. HIGH",
        "district": "GRUNDY CO. R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291269000532",
    },
    {
        "school": "PLEASANT VIEW ELEM.",
        "district": "PLEASANT VIEW R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291344000571",
    },
    {
        "school": "LAREDO ELEM.",
        "district": "LAREDO R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291791000958",
    },
    {
        "school": "SPICKARD ELEM.",
        "district": "SPICKARD R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292877001777",
    },
    {
        "school": "RISSLER ELEM.",
        "district": "TRENTON R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293036002079",
    },
    {
        "school": "TRENTON SR. HIGH",
        "district": "TRENTON R-IX",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293036002080",
    },
    {
        "school": "TRENTON MIDDLE",
        "district": "TRENTON R-IX",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293036002573",
    },
    {
        "school": "SOUTH HARRISON EARLY CHILD CTR",
        "district": "SOUTH HARRISON CO. R-II",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000200922",
    },
    {
        "school": "SOUTH HARRISON ELEM.",
        "district": "SOUTH HARRISON CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000201641",
    },
    {
        "school": "SOUTH HARRISON HIGH",
        "district": "SOUTH HARRISON CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000201642",
    },
    {
        "school": "NORTH CENTRAL CAREER CTR.",
        "district": "SOUTH HARRISON CO. R-II",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290000202400",
    },
    {
        "school": "CAINSVILLE ELEM.",
        "district": "CAINSVILLE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290645000163",
    },
    {
        "school": "CAINSVILLE HIGH",
        "district": "CAINSVILLE R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290645000164",
    },
    {
        "school": "GILMAN CITY ELEM.",
        "district": "GILMAN CITY R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291287000537",
    },
    {
        "school": "GILMAN CITY HIGH",
        "district": "GILMAN CITY R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291287000538",
    },
    {
        "school": "NORTH HARRISON ELEM.",
        "district": "NORTH HARRISON R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292277001256",
    },
    {
        "school": "NORTH HARRISON HIGH",
        "district": "NORTH HARRISON R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292277001257",
    },
    {
        "school": "RIDGEWAY ELEM.",
        "district": "RIDGEWAY R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292649001558",
    },
    {
        "school": "RIDGEWAY HIGH",
        "district": "RIDGEWAY R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292649001559",
    },
    {
        "school": "CALHOUN ELEM.",
        "district": "CALHOUN R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290648000165",
    },
    {
        "school": "CALHOUN HIGH",
        "district": "CALHOUN R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290648000166",
    },
    {
        "school": "CLINTON TECHNICAL SCH.",
        "district": "CLINTON",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290986000285",
    },
    {
        "school": "CLINTON SR. HIGH",
        "district": "CLINTON",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290986000286",
    },
    {
        "school": "CLINTON MIDDLE",
        "district": "CLINTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290986000288",
    },
    {
        "school": "HENRY ELEM.",
        "district": "CLINTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290986000289",
    },
    {
        "school": "DAVIS ELEM.",
        "district": "DAVIS R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291047000346",
    },
    {
        "school": "LEESVILLE ELEM.",
        "district": "LEESVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291833000985",
    },
    {
        "school": "MONTROSE ELEM.",
        "district": "MONTROSE R-XIV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292136001174",
    },
    {
        "school": "MONTROSE HIGH",
        "district": "MONTROSE R-XIV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292136001175",
    },
    {
        "school": "SHAWNEE ELEM.",
        "district": "SHAWNEE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292808001723",
    },
    {
        "school": "WINDSOR ELEM.",
        "district": "HENRY CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293211002254",
    },
    {
        "school": "WINDSOR HIGH",
        "district": "HENRY CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293211002255",
    },
    {
        "school": "HERMITAGE ELEM.",
        "district": "HERMITAGE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291431000648",
    },
    {
        "school": "HERMITAGE HIGH",
        "district": "HERMITAGE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291431000649",
    },
    {
        "school": "HERMITAGE MIDDLE",
        "district": "HERMITAGE R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291431001964",
    },
    {
        "school": "SKYLINE ELEM.",
        "district": "HICKORY CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291432002371",
    },
    {
        "school": "SKYLINE HIGH",
        "district": "HICKORY CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291432002372",
    },
    {
        "school": "WEAUBLEAU ELEM.",
        "district": "WEAUBLEAU R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293146002180",
    },
    {
        "school": "WEAUBLEAU HIGH",
        "district": "WEAUBLEAU R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293146002181",
    },
    {
        "school": "WHEATLAND ELEM.",
        "district": "WHEATLAND R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293192002234",
    },
    {
        "school": "WHEATLAND HIGH",
        "district": "WHEATLAND R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293192002235",
    },
    {
        "school": "CRAIG ELEM.",
        "district": "CRAIG R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291026000330",
    },
    {
        "school": "CRAIG HIGH",
        "district": "CRAIG R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291026000331",
    },
    {
        "school": "MOUND CITY ELEM.",
        "district": "MOUND CITY R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292148001179",
    },
    {
        "school": "MOUND CITY HIGH",
        "district": "MOUND CITY R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292148001180",
    },
    {
        "school": "SOUTH HOLT ELEM.",
        "district": "SOUTH HOLT CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292319001333",
    },
    {
        "school": "SOUTH HOLT HIGH",
        "district": "SOUTH HOLT CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292319001334",
    },
    {
        "school": "ARCADIA VALLEY CAREER TECH CTR",
        "district": "ARCADIA VALLEY R-II",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290315000020",
    },
    {
        "school": "ARCADIA VALLEY ELEM.",
        "district": "ARCADIA VALLEY R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290315000021",
    },
    {
        "school": "ARCADIA VALLEY HIGH",
        "district": "ARCADIA VALLEY R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290315000022",
    },
    {
        "school": "ARCADIA VALLEY MIDDLE",
        "district": "ARCADIA VALLEY R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290315000023",
    },
    {
        "school": "BELLEVIEW ELEM.",
        "district": "BELLEVIEW R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290459000050",
    },
    {
        "school": "Viburnum High",
        "district": "IRON CO. C-4",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291551000729",
    },
    {
        "school": "Viburnum Elementary",
        "district": "IRON CO. C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291551000730",
    },
    {
        "school": "SOUTH IRON ELEM.",
        "district": "SOUTH IRON CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292847001758",
    },
    {
        "school": "SOUTH IRON HIGH",
        "district": "SOUTH IRON CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292847001759",
    },
    {
        "school": "KNOX CO. ELEM.",
        "district": "KNOX CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291128000392",
    },
    {
        "school": "KNOX CO. HIGH",
        "district": "KNOX CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291128000397",
    },
    {
        "school": "AURORA HIGH",
        "district": "AURORA R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290402000031",
    },
    {
        "school": "PATE EARLY CHILDHOOD CTR.",
        "district": "AURORA R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290402000032",
    },
    {
        "school": "ROBINSON ELEM.",
        "district": "AURORA R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290402000033",
    },
    {
        "school": "AURORA JR. HIGH",
        "district": "AURORA R-VIII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290402001517",
    },
    {
        "school": "MARIONVILLE ELEM.",
        "district": "MARIONVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292031001076",
    },
    {
        "school": "MARIONVILLE HIGH",
        "district": "MARIONVILLE R-IX",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292031001077",
    },
    {
        "school": "CENTRAL ELEM.",
        "district": "MILLER R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292100001146",
    },
    {
        "school": "MILLER HIGH",
        "district": "MILLER R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292100001148",
    },
    {
        "school": "MONETT INTERMEDIATE",
        "district": "MONETT R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292112001595",
    },
    {
        "school": "MT. VERNON ELEM.",
        "district": "MT. VERNON R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292160001188",
    },
    {
        "school": "MT. VERNON HIGH",
        "district": "MT. VERNON R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292160001189",
    },
    {
        "school": "MT. VERNON MIDDLE",
        "district": "MT. VERNON R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292160001988",
    },
    {
        "school": "CENTRAL ELEM.",
        "district": "PIERCE CITY R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292511001440",
    },
    {
        "school": "PIERCE CITY HIGH",
        "district": "PIERCE CITY R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292511001441",
    },
    {
        "school": "PIERCE CITY MIDDLE",
        "district": "PIERCE CITY R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292511001987",
    },
    {
        "school": "VERONA ELEM.",
        "district": "VERONA R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293081002127",
    },
    {
        "school": "VERONA HIGH",
        "district": "VERONA R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293081002128",
    },
    {
        "school": "LINN CO AREA CAREER  TECH CTR",
        "district": "BROOKFIELD R-III",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290594000136",
    },
    {
        "school": "BROOKFIELD ELEM.",
        "district": "BROOKFIELD R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290594000137",
    },
    {
        "school": "BROOKFIELD HIGH",
        "district": "BROOKFIELD R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290594000139",
    },
    {
        "school": "BROOKFIELD MIDDLE",
        "district": "BROOKFIELD R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290594002272",
    },
    {
        "school": "LINN CO. ELEM.",
        "district": "LINN CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290600000142",
    },
    {
        "school": "LINN CO. HIGH",
        "district": "LINN CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290600000143",
    },
    {
        "school": "BUCKLIN ELEM.",
        "district": "BUCKLIN R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290609000146",
    },
    {
        "school": "BUCKLIN HIGH",
        "district": "BUCKLIN R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290609000147",
    },
    {
        "school": "MARCELINE HIGH",
        "district": "MARCELINE R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292005001070",
    },
    {
        "school": "WALT DISNEY ELEM.",
        "district": "MARCELINE R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292005001071",
    },
    {
        "school": "MARCELINE MIDDLE",
        "district": "MARCELINE R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292005002503",
    },
    {
        "school": "MEADVILLE ELEM.",
        "district": "MEADVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292064001107",
    },
    {
        "school": "MEADVILLE HIGH",
        "district": "MEADVILLE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292064001108",
    },
    {
        "school": "GRAND RIVER TECHNICAL SCH.",
        "district": "CHILLICOTHE R-II",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290876000258",
    },
    {
        "school": "DEWEY ELEMENTARY",
        "district": "CHILLICOTHE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290876000259",
    },
    {
        "school": "CHILLICOTHE ELEM",
        "district": "CHILLICOTHE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290876000261",
    },
    {
        "school": "FIELD ELEM.",
        "district": "CHILLICOTHE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290876000262",
    },
    {
        "school": "CHILLICOTHE HIGH",
        "district": "CHILLICOTHE R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290876000264",
    },
    {
        "school": "CHILLICOTHE MIDDLE",
        "district": "CHILLICOTHE R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290876002815",
    },
    {
        "school": "LIVINGSTON CO. ELEM.",
        "district": "LIVINGSTON CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290879000265",
    },
    {
        "school": "SOUTHWEST LIVINGSTON CO R-1 EL",
        "district": "SOUTHWEST LIVINGSTON CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292868001771",
    },
    {
        "school": "SOUTHWEST LIVINGSTON CO R-1 HS",
        "district": "SOUTHWEST LIVINGSTON CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292868001772",
    },
    {
        "school": "ATLANTA ELEM.",
        "district": "ATLANTA C-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290348000029",
    },
    {
        "school": "ATLANTA HIGH",
        "district": "ATLANTA C-3",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290348000030",
    },
    {
        "school": "BEVIER ELEM.",
        "district": "BEVIER C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290498000062",
    },
    {
        "school": "BEVIER HIGH",
        "district": "BEVIER C-4",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290498000063",
    },
    {
        "school": "CALLAO ELEM.",
        "district": "CALLAO C-8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290654000169",
    },
    {
        "school": "LA PLATA ELEM.",
        "district": "LA PLATA R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291695000938",
    },
    {
        "school": "LA PLATA HIGH",
        "district": "LA PLATA R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291695000939",
    },
    {
        "school": "FAMILY LITERACY CTR.",
        "district": "MACON CO. R-I",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291941000567",
    },
    {
        "school": "MACON ELEM.",
        "district": "MACON CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291941001050",
    },
    {
        "school": "MACON AREA VOC. SCH.",
        "district": "MACON CO. R-I",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291941001051",
    },
    {
        "school": "MACON MIDDLE",
        "district": "MACON CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291941001052",
    },
    {
        "school": "MACON SR. HIGH",
        "district": "MACON CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291941001053",
    },
    {
        "school": "MACON CO. ELEM.",
        "district": "MACON CO. R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292188001220",
    },
    {
        "school": "MACON CO. HIGH",
        "district": "MACON CO. R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292188001221",
    },
    {
        "school": "FREDERICKTOWN ELEM.",
        "district": "FREDERICKTOWN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291254000513",
    },
    {
        "school": "FREDERICKTOWN HIGH",
        "district": "FREDERICKTOWN R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291254000516",
    },
    {
        "school": "KELLY A BURLISON MIDDLE SCHOOL",
        "district": "FREDERICKTOWN R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291254002523",
    },
    {
        "school": "FREDERICKTOWN INTERMEDIATE",
        "district": "FREDERICKTOWN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291254002524",
    },
    {
        "school": "MARQUAND ELEM.",
        "district": "MARQUAND-ZION R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292037001079",
    },
    {
        "school": "MARQUAND-ZION HIGH",
        "district": "MARQUAND-ZION R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292037001080",
    },
    {
        "school": "BELLE ELEM.",
        "district": "MARIES CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000100048",
    },
    {
        "school": "BELLE HIGH",
        "district": "MARIES CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000100049",
    },
    {
        "school": "VIENNA ELEM.",
        "district": "MARIES CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293087002133",
    },
    {
        "school": "VIENNA HIGH",
        "district": "MARIES CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293087002134",
    },
    {
        "school": "NORTH MERCER ELEM.",
        "district": "NORTH MERCER CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292075001128",
    },
    {
        "school": "MERCER HIGH",
        "district": "NORTH MERCER CO. R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292075001129",
    },
    {
        "school": "PRINCETON R-V ELEM.",
        "district": "PRINCETON R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292559002299",
    },
    {
        "school": "PRINCETON R-V JR.-SR. HIGH",
        "district": "PRINCETON R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292559002300",
    },
    {
        "school": "ELDON MIDDLE",
        "district": "ELDON R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291134000138",
    },
    {
        "school": "ELDON HIGH",
        "district": "ELDON R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291134000402",
    },
    {
        "school": "SOUTH ELEM.",
        "district": "ELDON R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291134000403",
    },
    {
        "school": "ELDON CAREER CTR.",
        "district": "ELDON R-I",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291134000404",
    },
    {
        "school": "ELDON UPPER ELEM.",
        "district": "ELDON R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291134002411",
    },
    {
        "school": "IBERIA ELEM.",
        "district": "IBERIA R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291542000702",
    },
    {
        "school": "IBERIA HIGH",
        "district": "IBERIA R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291542000703",
    },
    {
        "school": "OSAGE MIDDLE",
        "district": "SCHOOL OF THE OSAGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292763001020",
    },
    {
        "school": "HERITAGE ELEMENTARY",
        "district": "SCHOOL OF THE OSAGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292763001696",
    },
    {
        "school": "OSAGE HIGH",
        "district": "SCHOOL OF THE OSAGE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292763001697",
    },
    {
        "school": "OSAGE UPPER ELEM.",
        "district": "SCHOOL OF THE OSAGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292763002479",
    },
    {
        "school": "ST. ELIZABETH ELEM.",
        "district": "ST. ELIZABETH R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292913001866",
    },
    {
        "school": "ST. ELIZABETH HIGH",
        "district": "ST. ELIZABETH R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292913001867",
    },
    {
        "school": "MILLER CO. ELEM.",
        "district": "MILLER CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293051002091",
    },
    {
        "school": "TUSCUMBIA HIGH",
        "district": "MILLER CO. R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293051002092",
    },
    {
        "school": "CHARLESTON HIGH",
        "district": "CHARLESTON R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290867000254",
    },
    {
        "school": "WARREN E. HEARNES ELEM.",
        "district": "CHARLESTON R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290867000255",
    },
    {
        "school": "CHARLESTON MIDDLE",
        "district": "CHARLESTON R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290867001780",
    },
    {
        "school": "A. J. MARTIN ELEM.",
        "district": "EAST PRAIRIE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291122000385",
    },
    {
        "school": "R. A. DOYLE ELEM.",
        "district": "EAST PRAIRIE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291122000387",
    },
    {
        "school": "EAST PRAIRIE HIGH",
        "district": "EAST PRAIRIE R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291122000388",
    },
    {
        "school": "EAST PRAIRIE JR. HIGH",
        "district": "EAST PRAIRIE R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291122002757",
    },
    {
        "school": "Holliday Elementary",
        "district": "HOLLIDAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291452000682",
    },
    {
        "school": "MADISON ELEM.",
        "district": "MADISON C-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291984001054",
    },
    {
        "school": "MADISON HIGH",
        "district": "MADISON C-3",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291984001055",
    },
    {
        "school": "MIDDLE GROVE ELEM.",
        "district": "MIDDLE GROVE C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292088001141",
    },
    {
        "school": "MONROE CITY ELEM.",
        "district": "MONROE CITY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292121001165",
    },
    {
        "school": "MONROE CITY R-I HIGH",
        "district": "MONROE CITY R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292121001167",
    },
    {
        "school": "MONROE CITY MIDDLE",
        "district": "MONROE CITY R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292121001799",
    },
    {
        "school": "PARIS ELEM.",
        "district": "PARIS R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292353001363",
    },
    {
        "school": "PARIS HIGH",
        "district": "PARIS R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292353001365",
    },
    {
        "school": "PARIS JR. HIGH",
        "district": "PARIS R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292353002440",
    },
    {
        "school": "MONTGOMERY CO. HIGH",
        "district": "MONTGOMERY CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292133001169",
    },
    {
        "school": "JONESBURG ELEM.",
        "district": "MONTGOMERY CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292133001170",
    },
    {
        "school": "MONTGOMERY CO. MIDDLE",
        "district": "MONTGOMERY CO. R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292133001171",
    },
    {
        "school": "MONTGOMERY CITY ELEM.",
        "district": "MONTGOMERY CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292133001172",
    },
    {
        "school": "WELLSVILLE-MIDDLETOWN HS",
        "district": "WELLSVILLE MIDDLETOWN R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293162002204",
    },
    {
        "school": "WELLSVILLE-MIDDLETOWN ELEM.",
        "district": "WELLSVILLE MIDDLETOWN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293162002206",
    },
    {
        "school": "MORGAN CO. R-I ELEM.",
        "district": "MORGAN CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292961002047",
    },
    {
        "school": "MORGAN CO. R-I HIGH",
        "district": "MORGAN CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292961002048",
    },
    {
        "school": "MORGAN CO. ELEM.",
        "district": "MORGAN CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293084002129",
    },
    {
        "school": "MORGAN CO. HIGH",
        "district": "MORGAN CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293084002131",
    },
    {
        "school": "MORGAN CO. SOUTH ELEM.",
        "district": "MORGAN CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293084002132",
    },
    {
        "school": "MORGAN CO. MIDDLE",
        "district": "MORGAN CO. R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293084002542",
    },
    {
        "school": "PORTAGEVILLE HIGH",
        "district": "PORTAGEVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000302458",
    },
    {
        "school": "PORTAGEVILLE ELEM.",
        "district": "PORTAGEVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000302459",
    },
    {
        "school": "LILBOURN ELEM.",
        "district": "NEW MADRID CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000401482",
    },
    {
        "school": "NEW MADRID ELEM.",
        "district": "NEW MADRID CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000401484",
    },
    {
        "school": "MATTHEWS ELEM.",
        "district": "NEW MADRID CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000401486",
    },
    {
        "school": "CENTRAL HIGH",
        "district": "NEW MADRID CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000401488",
    },
    {
        "school": "NEW MADRID R-I TECH SKILLS CTR",
        "district": "NEW MADRID CO. R-I",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290000401492",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "NEW MADRID CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000401991",
    },
    {
        "school": "GIDEON ELEM.",
        "district": "GIDEON 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291278000534",
    },
    {
        "school": "GIDEON HIGH",
        "district": "GIDEON 37",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291278000535",
    },
    {
        "school": "RISCO ELEM.",
        "district": "RISCO R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292661001563",
    },
    {
        "school": "RISCO HIGH",
        "district": "RISCO R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292661001564",
    },
    {
        "school": "Alton Elementary",
        "district": "ALTON R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290306000015",
    },
    {
        "school": "Alton High",
        "district": "ALTON R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290306000016",
    },
    {
        "school": "COUCH ELEM.",
        "district": "COUCH R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291020000327",
    },
    {
        "school": "COUCH HIGH",
        "district": "COUCH R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291020000328",
    },
    {
        "school": "KOSHKONONG ELEM.",
        "district": "OREGON-HOWELL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291686000934",
    },
    {
        "school": "KOSHKONONG HIGH",
        "district": "OREGON-HOWELL R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291686000935",
    },
    {
        "school": "THAYER ELEM.",
        "district": "THAYER R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293027002068",
    },
    {
        "school": "THAYER SR. HIGH",
        "district": "THAYER R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293027002069",
    },
    {
        "school": "BAKERSFIELD ELEM.",
        "district": "BAKERSFIELD R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290414000039",
    },
    {
        "school": "BAKERSFIELD HIGH",
        "district": "BAKERSFIELD R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290414000040",
    },
    {
        "school": "DORA ELEM.",
        "district": "DORA R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291095000374",
    },
    {
        "school": "DORA HIGH",
        "district": "DORA R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291095000375",
    },
    {
        "school": "GAINESVILLE ELEM.",
        "district": "GAINESVILLE R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291260000525",
    },
    {
        "school": "GAINESVILLE HIGH",
        "district": "GAINESVILLE R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291260000526",
    },
    {
        "school": "THORNFIELD ELEM.",
        "district": "THORNFIELD R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292337001348",
    },
    {
        "school": "LUTIE ELEM.",
        "district": "LUTIE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292340001349",
    },
    {
        "school": "LUTIE HIGH",
        "district": "LUTIE R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292340002565",
    },
    {
        "school": "DELTA C-7 ELEM.",
        "district": "DELTA C-7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290573000119",
    },
    {
        "school": "DELTA C-7 HIGH",
        "district": "DELTA C-7",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290573000120",
    },
    {
        "school": "CARUTHERSVILLE HIGH",
        "district": "CARUTHERSVILLE 18",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290747000214",
    },
    {
        "school": "CARUTHERSVILLE ELEMENTARY",
        "district": "CARUTHERSVILLE 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290747000216",
    },
    {
        "school": "CARUTHERSVILLE MIDDLE",
        "district": "CARUTHERSVILLE 18",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290747001023",
    },
    {
        "school": "COOTER ELEM.",
        "district": "COOTER R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291014000325",
    },
    {
        "school": "COOTER HIGH",
        "district": "COOTER R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291014000326",
    },
    {
        "school": "HAYTI HIGH",
        "district": "HAYTI R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291380000611",
    },
    {
        "school": "MATHIS ELEMENTARY",
        "district": "HAYTI R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291380000612",
    },
    {
        "school": "ROSS ELEM.",
        "district": "NORTH PEMISCOT CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292376001429",
    },
    {
        "school": "NORTH PEMISCOT SR. HIGH",
        "district": "NORTH PEMISCOT CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292376001431",
    },
    {
        "school": "DIAGNOSTIC CTR.",
        "district": "PEMISCOT CO. SPEC. SCH. DIST.",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292378002380",
    },
    {
        "school": "PEMISCOT CO CAREER  TECH CTR",
        "district": "PEMISCOT CO. SPEC. SCH. DIST.",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292378002381",
    },
    {
        "school": "OAK VIEW LEARNING CTR.",
        "district": "PEMISCOT CO. SPEC. SCH. DIST.",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292378002382",
    },
    {
        "school": "PEMISCOT CO. R-III ELEM.",
        "district": "PEMISCOT CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292379001436",
    },
    {
        "school": "SOUTH PEMISCOT HIGH",
        "district": "SOUTH PEMISCOT CO. R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292853001764",
    },
    {
        "school": "SOUTH PEMISCOT ELEM.",
        "district": "SOUTH PEMISCOT CO. R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292853002670",
    },
    {
        "school": "ALTENBURG ELEM.",
        "district": "ALTENBURG 48",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290304000014",
    },
    {
        "school": "PERRY CO. MIDDLE",
        "district": "PERRY CO. 32",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292453001845",
    },
    {
        "school": "PERRYVILLE AREA CAR  TECH CTR",
        "district": "PERRY CO. 32",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292453002385",
    },
    {
        "school": "PERRYVILLE ELEM.",
        "district": "PERRY CO. 32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292453002386",
    },
    {
        "school": "PERRYVILLE SR. HIGH",
        "district": "PERRY CO. 32",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292453002387",
    },
    {
        "school": "BONCL Elem.",
        "district": "BONCL R-X",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290540000094",
    },
    {
        "school": "BOWLING GREEN ELEM.",
        "district": "BOWLING GREEN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290566000112",
    },
    {
        "school": "FRANKFORD ELEM.",
        "district": "BOWLING GREEN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290566000114",
    },
    {
        "school": "BOWLING GREEN HIGH",
        "district": "BOWLING GREEN R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290566000115",
    },
    {
        "school": "BOWLING GREEN MIDDLE",
        "district": "BOWLING GREEN R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290566000601",
    },
    {
        "school": "LOUISIANA MIDDLE",
        "district": "LOUISIANA R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291926001041",
    },
    {
        "school": "LOUISIANA ELEM.",
        "district": "LOUISIANA R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291926001042",
    },
    {
        "school": "LOUISIANA HIGH",
        "district": "LOUISIANA R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291926001043",
    },
    {
        "school": "PIKE/LINCOLN TECHNICAL CTR.",
        "district": "PIKE CO. R-III",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292514001442",
    },
    {
        "school": "CLOPTON ELEM.",
        "district": "PIKE CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292514001444",
    },
    {
        "school": "CLOPTON HIGH",
        "district": "PIKE CO. R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292514001445",
    },
    {
        "school": "PUTNAM CO. HIGH",
        "district": "PUTNAM CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292564001503",
    },
    {
        "school": "PUTNAM CO. ELEM.",
        "district": "PUTNAM CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292564001505",
    },
    {
        "school": "PUTNAM CO. MIDDLE",
        "district": "PUTNAM CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292564001847",
    },
    {
        "school": "BUNKER ELEM.",
        "district": "BUNKER R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290617000155",
    },
    {
        "school": "BUNKER HIGH",
        "district": "BUNKER R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290617000156",
    },
    {
        "school": "CENTERVILLE ELEM.",
        "district": "CENTERVILLE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290834000232",
    },
    {
        "school": "LESTERVILLE ELEM.",
        "district": "LESTERVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291845000990",
    },
    {
        "school": "LESTERVILLE HIGH",
        "district": "LESTERVILLE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291845000991",
    },
    {
        "school": "LESTERVILLE RANCH CAMPUS",
        "district": "LESTERVILLE R-IV",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291845002667",
    },
    {
        "school": "ELLINGTON ELEMENTARY",
        "district": "SOUTHERN REYNOLDS CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292859001767",
    },
    {
        "school": "ELLINGTON HIGH SCHOOL",
        "district": "SOUTHERN REYNOLDS CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292859001768",
    },
    {
        "school": "CURRENT RIVER CAREER CENTER",
        "district": "DONIPHAN R-I",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291092000370",
    },
    {
        "school": "DONIPHAN ELEM.",
        "district": "DONIPHAN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291092000371",
    },
    {
        "school": "DONIPHAN HIGH",
        "district": "DONIPHAN R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291092000373",
    },
    {
        "school": "DONIPHAN MIDDLE",
        "district": "DONIPHAN R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291092002586",
    },
    {
        "school": "NAYLOR ELEM.",
        "district": "NAYLOR R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292172001197",
    },
    {
        "school": "NAYLOR HIGH",
        "district": "NAYLOR R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292172001198",
    },
    {
        "school": "RIPLEY CO. ELEM.",
        "district": "RIPLEY CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292655001560",
    },
    {
        "school": "RIPLEY CO. ELEM.",
        "district": "RIPLEY CO. R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292658001561",
    },
    {
        "school": "APPLETON CITY ELEM.",
        "district": "APPLETON CITY R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290312000017",
    },
    {
        "school": "APPLETON CITY HIGH",
        "district": "APPLETON CITY R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290312000019",
    },
    {
        "school": "LAKELAND HIGH",
        "district": "LAKELAND R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291052000352",
    },
    {
        "school": "LAKELAND ELEM.",
        "district": "LAKELAND R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291052002520",
    },
    {
        "school": "OSCEOLA ELEM.",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292327001339",
    },
    {
        "school": "OSCEOLA JR.-SR. HIGH",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292327001340",
    },
    {
        "school": "Roscoe Elementary",
        "district": "ROSCOE C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292694001637",
    },
    {
        "school": "BLOOMSDALE ELEM.",
        "district": "STE. GENEVIEVE CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292937002031",
    },
    {
        "school": "STE. GENEVIEVE MIDDLE",
        "district": "STE. GENEVIEVE CO. R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292937002032",
    },
    {
        "school": "STE. GENEVIEVE SR. HIGH",
        "district": "STE. GENEVIEVE CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292937002033",
    },
    {
        "school": "STE. GENEVIEVE ELEM.",
        "district": "STE. GENEVIEVE CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292937002034",
    },
    {
        "school": "SCOTLAND CO. ELEM.",
        "district": "SCOTLAND CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292070001126",
    },
    {
        "school": "SCOTLAND CO. HIGH",
        "district": "SCOTLAND CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292070001127",
    },
    {
        "school": "EMINENCE ELEM.",
        "district": "EMINENCE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291145000408",
    },
    {
        "school": "EMINENCE HIGH",
        "district": "EMINENCE R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291145000409",
    },
    {
        "school": "WINONA ELEM.",
        "district": "WINONA R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293222002259",
    },
    {
        "school": "WINONA HIGH",
        "district": "WINONA R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293222002260",
    },
    {
        "school": "CLARENCE ELEM.",
        "district": "SHELBY CO. R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292811001724",
    },
    {
        "school": "SHELBINA ELEM.",
        "district": "SHELBY CO. R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292811001726",
    },
    {
        "school": "SOUTH SHELBY HIGH",
        "district": "SHELBY CO. R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292811001728",
    },
    {
        "school": "NORTH SHELBY HIGH",
        "district": "NORTH SHELBY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292814001731",
    },
    {
        "school": "NORTH SHELBY ELEM.",
        "district": "NORTH SHELBY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292814001732",
    },
    {
        "school": "ADVANCE ELEM.",
        "district": "ADVANCE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290288000003",
    },
    {
        "school": "ADVANCE HIGH",
        "district": "ADVANCE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290288000004",
    },
    {
        "school": "BELL CITY ELEM.",
        "district": "BELL CITY R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290453000046",
    },
    {
        "school": "BELL CITY HIGH",
        "district": "BELL CITY R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290453000047",
    },
    {
        "school": "BERNIE ELEM.",
        "district": "BERNIE R-XIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290495000060",
    },
    {
        "school": "BERNIE HIGH",
        "district": "BERNIE R-XIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290495000061",
    },
    {
        "school": "BLOOMFIELD ELEM.",
        "district": "BLOOMFIELD R-XIV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290525000072",
    },
    {
        "school": "BLOOMFIELD HIGH",
        "district": "BLOOMFIELD R-XIV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290525000073",
    },
    {
        "school": "JUVENILE CTR.",
        "district": "BLOOMFIELD R-XIV",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290525002578",
    },
    {
        "school": "CENTRAL ELEM.",
        "district": "DEXTER R-XI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291077000361",
    },
    {
        "school": "T. S. HILL MIDDLE",
        "district": "DEXTER R-XI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291077000362",
    },
    {
        "school": "DEXTER HIGH",
        "district": "DEXTER R-XI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291077000363",
    },
    {
        "school": "SOUTHWEST ELEM.",
        "district": "DEXTER R-XI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291077000364",
    },
    {
        "school": "PUXICO ELEM.",
        "district": "PUXICO R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292565001507",
    },
    {
        "school": "PUXICO HIGH",
        "district": "PUXICO R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292565001508",
    },
    {
        "school": "MINGO PUXICO TECHNICAL HIGH",
        "district": "PUXICO R-VIII",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292565002704",
    },
    {
        "school": "RICHLAND HIGH",
        "district": "RICHLAND R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292640001548",
    },
    {
        "school": "RICHLAND ELEM.",
        "district": "RICHLAND R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292640002443",
    },
    {
        "school": "GRUNDY CO. ELEM.",
        "district": "GRUNDY CO. R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291269000531",
    },
    {
        "school": "GREEN CITY ELEM.",
        "district": "GREEN CITY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291323000560",
    },
    {
        "school": "GREEN CITY HIGH",
        "district": "GREEN CITY R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291323000561",
    },
    {
        "school": "MILAN ELEM.",
        "district": "MILAN C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292094001143",
    },
    {
        "school": "MILAN HIGH",
        "district": "MILAN C-2",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292094001144",
    },
    {
        "school": "NEWTOWN-HARRIS ELEM.",
        "district": "NEWTOWN-HARRIS R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292247001230",
    },
    {
        "school": "NEWTOWN-HARRIS HIGH",
        "district": "NEWTOWN-HARRIS R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292247001231",
    },
    {
        "school": "CABOOL ELEM.",
        "district": "CABOOL R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290643000160",
    },
    {
        "school": "CABOOL HIGH",
        "district": "CABOOL R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290643000161",
    },
    {
        "school": "CABOOL MIDDLE",
        "district": "CABOOL R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290643002424",
    },
    {
        "school": "HOUSTON MIDDLE",
        "district": "HOUSTON R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291484000453",
    },
    {
        "school": "HOUSTON ELEM.",
        "district": "HOUSTON R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291484000685",
    },
    {
        "school": "EXCEPTIONAL CHILD COOP.",
        "district": "HOUSTON R-I",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "291484000686",
    },
    {
        "school": "HOUSTON HIGH",
        "district": "HOUSTON R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291484000688",
    },
    {
        "school": "LICKING ELEM.",
        "district": "LICKING R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291860001013",
    },
    {
        "school": "LICKING HIGH",
        "district": "LICKING R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291860001014",
    },
    {
        "school": "PLATO ELEM.",
        "district": "PLATO R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292521001449",
    },
    {
        "school": "PLATO HIGH",
        "district": "PLATO R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292521001450",
    },
    {
        "school": "RAYMONDVILLE ELEM.",
        "district": "RAYMONDVILLE R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292604001514",
    },
    {
        "school": "SUCCESS ELEM.",
        "district": "SUCCESS R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292973002054",
    },
    {
        "school": "SUMMERSVILLE ELEM.",
        "district": "SUMMERSVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292981002058",
    },
    {
        "school": "SUMMERSVILLE HIGH",
        "district": "SUMMERSVILLE R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292981002059",
    },
    {
        "school": "BRONAUGH ELEM.",
        "district": "BRONAUGH R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290591000134",
    },
    {
        "school": "BRONAUGH HIGH",
        "district": "BRONAUGH R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290591000135",
    },
    {
        "school": "TRUMAN ELEM.",
        "district": "NEVADA R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292184001122",
    },
    {
        "school": "BENTON ELEM.",
        "district": "NEVADA R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292184001211",
    },
    {
        "school": "BRYAN ELEM.",
        "district": "NEVADA R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292184001212",
    },
    {
        "school": "NEVADA HIGH",
        "district": "NEVADA R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292184001214",
    },
    {
        "school": "NEVADA MIDDLE",
        "district": "NEVADA R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292184001216",
    },
    {
        "school": "NEVADA REGIONAL TECH.-CTR.",
        "district": "NEVADA R-V",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292184001217",
    },
    {
        "school": "HEARTLAND R-V SCH.",
        "district": "NEVADA R-V",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292184002707",
    },
    {
        "school": "NORTHEAST VERNON CO. R-I ELEM.",
        "district": "NORTHEAST VERNON CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292760001694",
    },
    {
        "school": "NORTHEAST VERNON CO. R-I HIGH",
        "district": "NORTHEAST VERNON CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292760001695",
    },
    {
        "school": "SHELDON ELEM.",
        "district": "SHELDON R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292817001733",
    },
    {
        "school": "SHELDON HIGH",
        "district": "SHELDON R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292817001734",
    },
    {
        "school": "CLEARWATER HIGH",
        "district": "CLEARWATER R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290975000277",
    },
    {
        "school": "CLEARWATER ELEMENTARY",
        "district": "CLEARWATER R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290975000280",
    },
    {
        "school": "CLEARWATER MIDDLE",
        "district": "CLEARWATER R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290975001904",
    },
    {
        "school": "GREENVILLE ELEM.",
        "district": "GREENVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291338000568",
    },
    {
        "school": "GREENVILLE HIGH",
        "district": "GREENVILLE R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291338000569",
    },
    {
        "school": "WILLIAMSVILLE ELEM.",
        "district": "GREENVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291338000570",
    },
    {
        "school": "WORTH CO. ELEMENTARY",
        "district": "WORTH CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293230002263",
    },
    {
        "school": "WORTH CO. HIGH",
        "district": "WORTH CO. R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293230002264",
    },
    {
        "school": "HARTVILLE ELEM.",
        "district": "HARTVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291377000606",
    },
    {
        "school": "GROVESPRING ELEM.",
        "district": "HARTVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291377000607",
    },
    {
        "school": "HARTVILLE HIGH",
        "district": "HARTVILLE R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291377000608",
    },
    {
        "school": "MANES ELEM.",
        "district": "MANES R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291995001061",
    },
    {
        "school": "WILDER ELEM.",
        "district": "MANSFIELD R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291998001062",
    },
    {
        "school": "MANSFIELD HIGH",
        "district": "MANSFIELD R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291998001063",
    },
    {
        "school": "MANSFIELD JR. HIGH",
        "district": "MANSFIELD R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291998002560",
    },
    {
        "school": "MOUNTAIN GROVE ELEM.",
        "district": "MOUNTAIN GROVE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292151001181",
    },
    {
        "school": "MOUNTAIN GROVE HIGH",
        "district": "MOUNTAIN GROVE R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292151001182",
    },
    {
        "school": "OZARK MOUNTAIN TECHNICAL CTR.",
        "district": "MOUNTAIN GROVE R-III",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292151001183",
    },
    {
        "school": "MOUNTAIN GROVE MIDDLE",
        "district": "MOUNTAIN GROVE R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292151002619",
    },
    {
        "school": "NORWOOD ELEM.",
        "district": "NORWOOD R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292295001312",
    },
    {
        "school": "NORWOOD HIGH",
        "district": "NORWOOD R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292295001313",
    },
    {
        "school": "GERALD ELEM.",
        "district": "GASCONADE CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292334001343",
    },
    {
        "school": "OWENSVILLE HIGH",
        "district": "GASCONADE CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292334001347",
    },
    {
        "school": "OWENSVILLE MIDDLE",
        "district": "GASCONADE CO. R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292334001477",
    },
    {
        "school": "REEDS SPRING ELEM.",
        "district": "REEDS SPRING R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292616003034",
    },
    {
        "school": "BUCHANAN INTERMEDIATE",
        "district": "BRANSON R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290576002851",
    },
    {
        "school": "BLUE EYE ELEM.",
        "district": "BLUE EYE R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290528000075",
    },
    {
        "school": "BLUE EYE HIGH",
        "district": "BLUE EYE R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290528000076",
    },
    {
        "school": "BLUE EYE MIDDLE",
        "district": "BLUE EYE R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290528001900",
    },
    {
        "school": "CRANE ELEM.",
        "district": "CRANE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291029000332",
    },
    {
        "school": "CRANE HIGH",
        "district": "CRANE R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291029000333",
    },
    {
        "school": "GALENA-ABESVILLE ELEM.",
        "district": "GALENA R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291263000527",
    },
    {
        "school": "GALENA HIGH",
        "district": "GALENA R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291263000528",
    },
    {
        "school": "HURLEY ELEM.",
        "district": "HURLEY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291539000700",
    },
    {
        "school": "HURLEY HIGH",
        "district": "HURLEY R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291539000701",
    },
    {
        "school": "REEDS SPRING MIDDLE",
        "district": "REEDS SPRING R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292616000786",
    },
    {
        "school": "GIBSON TECHNICAL CTR.",
        "district": "REEDS SPRING R-IV",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292616001533",
    },
    {
        "school": "REEDS SPRING PRIMARY",
        "district": "REEDS SPRING R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292616001534",
    },
    {
        "school": "REEDS SPRING HIGH",
        "district": "REEDS SPRING R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292616001536",
    },
    {
        "school": "REEDS SPRING INTERMEDIATE",
        "district": "REEDS SPRING R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292616002150",
    },
    {
        "school": "NEW HORIZONS ALTERNATIVE",
        "district": "REEDS SPRING R-IV",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292616002823",
    },
    {
        "school": "BRADLEYVILLE ELEM.",
        "district": "BRADLEYVILLE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290570000117",
    },
    {
        "school": "BRADLEYVILLE HIGH",
        "district": "BRADLEYVILLE R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290570000118",
    },
    {
        "school": "BRANSON HIGH",
        "district": "BRANSON R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290576000122",
    },
    {
        "school": "BRANSON JR. HIGH",
        "district": "BRANSON R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290576000123",
    },
    {
        "school": "CEDAR RIDGE ELEMENTARY",
        "district": "BRANSON R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290576002462",
    },
    {
        "school": "CEDAR RIDGE PRIMARY",
        "district": "BRANSON R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290576002706",
    },
    {
        "school": "FORSYTH ELEM.",
        "district": "FORSYTH R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291224000486",
    },
    {
        "school": "FORSYTH HIGH",
        "district": "FORSYTH R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291224000487",
    },
    {
        "school": "FORSYTH MIDDLE",
        "district": "FORSYTH R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291224000789",
    },
    {
        "school": "HOLLISTER ELEM.",
        "district": "HOLLISTER R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291455000683",
    },
    {
        "school": "HOLLISTER HIGH",
        "district": "HOLLISTER R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291455000684",
    },
    {
        "school": "HOLLISTER MIDDLE",
        "district": "HOLLISTER R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291455001120",
    },
    {
        "school": "KIRBYVILLE ELEM.",
        "district": "KIRBYVILLE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291671000911",
    },
    {
        "school": "KIRBYVILLE MIDDLE",
        "district": "KIRBYVILLE R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291671002824",
    },
    {
        "school": "MARK TWAIN ELEM.",
        "district": "MARK TWAIN R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292034001078",
    },
    {
        "school": "TANEYVILLE ELEM.",
        "district": "TANEYVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292991002065",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "CAPE GIRARDEAU 63",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290712002798",
    },
    {
        "school": "LEOPOLD ELEM.",
        "district": "LEOPOLD R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291842000988",
    },
    {
        "school": "LEOPOLD HIGH",
        "district": "LEOPOLD R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291842000989",
    },
    {
        "school": "WOODLAND ELEM.",
        "district": "WOODLAND R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291935001045",
    },
    {
        "school": "WOODLAND HIGH",
        "district": "WOODLAND R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291935001046",
    },
    {
        "school": "MEADOW HEIGHTS HIGH",
        "district": "MEADOW HEIGHTS R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292364001406",
    },
    {
        "school": "MEADOW HEIGHTS ELEM.",
        "district": "MEADOW HEIGHTS R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292364001407",
    },
    {
        "school": "ZALMA ELEM.",
        "district": "ZALMA R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293249002269",
    },
    {
        "school": "ZALMA HIGH",
        "district": "ZALMA R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293249002270",
    },
    {
        "school": "ALMA SCHRADER ELEM.",
        "district": "CAPE GIRARDEAU 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290712000184",
    },
    {
        "school": "CENTRAL JR. HIGH",
        "district": "CAPE GIRARDEAU 63",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290712000185",
    },
    {
        "school": "CENTRAL HIGH",
        "district": "CAPE GIRARDEAU 63",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290712000186",
    },
    {
        "school": "FRANKLIN ELEM.",
        "district": "CAPE GIRARDEAU 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290712000187",
    },
    {
        "school": "CLIPPARD ELEM.",
        "district": "CAPE GIRARDEAU 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290712000188",
    },
    {
        "school": "JEFFERSON ELEM.",
        "district": "CAPE GIRARDEAU 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290712000189",
    },
    {
        "school": "CAPE GIRARDEAU CAR  TECH CTR.",
        "district": "CAPE GIRARDEAU 63",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290712000192",
    },
    {
        "school": "BLANCHARD ELEM.",
        "district": "CAPE GIRARDEAU 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290712002722",
    },
    {
        "school": "NELL HOLCOMB ELEM.",
        "district": "NELL HOLCOMB R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290732000194",
    },
    {
        "school": "DELTA ELEM.",
        "district": "DELTA R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291062000357",
    },
    {
        "school": "DELTA HIGH",
        "district": "DELTA R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291062000358",
    },
    {
        "school": "ORCHARD DRIVE ELEM.",
        "district": "JACKSON R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291560000732",
    },
    {
        "school": "GORDONVILLE ATTENDANCE CTR",
        "district": "JACKSON R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291560000733",
    },
    {
        "school": "MILLERSVILLE ATTENDANCE CTR.",
        "district": "JACKSON R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291560000735",
    },
    {
        "school": "NORTH ELEM.",
        "district": "JACKSON R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291560000736",
    },
    {
        "school": "RUSSELL HAWKINS JR. HIGH",
        "district": "JACKSON R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291560000737",
    },
    {
        "school": "JACKSON SR. HIGH",
        "district": "JACKSON R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291560000738",
    },
    {
        "school": "WEST LANE ELEM.",
        "district": "JACKSON R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291560000739",
    },
    {
        "school": "JACKSON MIDDLE",
        "district": "JACKSON R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291560001428",
    },
    {
        "school": "SOUTH ELEM.",
        "district": "JACKSON R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291560002248",
    },
    {
        "school": "OAK RIDGE ELEM.",
        "district": "OAK RIDGE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292307001320",
    },
    {
        "school": "OAK RIDGE HIGH",
        "district": "OAK RIDGE R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292307001321",
    },
    {
        "school": "MARY PAXTON KEELEY ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100002770",
    },
    {
        "school": "LAURENCE J. DALY ELEM.",
        "district": "FAYETTE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291199000446",
    },
    {
        "school": "FAYETTE HIGH",
        "district": "FAYETTE R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291199000448",
    },
    {
        "school": "WM. N. CLARK MIDDLE",
        "district": "FAYETTE R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291199002590",
    },
    {
        "school": "GLASGOW ELEMENTARY.",
        "district": "GLASGOW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291290000539",
    },
    {
        "school": "GLASGOW HIGH",
        "district": "GLASGOW",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291290000540",
    },
    {
        "school": "New Franklin Elementary",
        "district": "NEW FRANKLIN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292194001222",
    },
    {
        "school": "New Franklin Middle-High",
        "district": "NEW FRANKLIN R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292194001223",
    },
    {
        "school": "COLUMBIA AREA CAREER CTR.",
        "district": "COLUMBIA 93",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290100000297",
    },
    {
        "school": "BLUE RIDGE ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000298",
    },
    {
        "school": "ROCK BRIDGE SR. HIGH",
        "district": "COLUMBIA 93",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000299",
    },
    {
        "school": "DAVID H. HICKMAN HIGH",
        "district": "COLUMBIA 93",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000300",
    },
    {
        "school": "FAIRVIEW ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000303",
    },
    {
        "school": "JEFFERSON MIDDLE SCHOOL",
        "district": "COLUMBIA 93",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000304",
    },
    {
        "school": "JOHN RIDGEWAY ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000305",
    },
    {
        "school": "PARKADE ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000307",
    },
    {
        "school": "Locust St Expressive Arts Elem",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000308",
    },
    {
        "school": "ROCK BRIDGE ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000309",
    },
    {
        "school": "RUSSELL BLVD. ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000310",
    },
    {
        "school": "SHEPARD BLVD. ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000312",
    },
    {
        "school": "THOMAS BENTON ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000313",
    },
    {
        "school": "TWO MILE PRAIRIE ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000314",
    },
    {
        "school": "ULYSSES S. GRANT ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000315",
    },
    {
        "school": "WEST BLVD. ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000316",
    },
    {
        "school": "WEST MIDDLE SCHOOL",
        "district": "COLUMBIA 93",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000317",
    },
    {
        "school": "ANN HAWKINS GENTRY MIDDLE",
        "district": "COLUMBIA 93",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100000841",
    },
    {
        "school": "MIDWAY HEIGHTS ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100001142",
    },
    {
        "school": "OAKLAND MIDDLE SCHOOL",
        "district": "COLUMBIA 93",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100001402",
    },
    {
        "school": "SMITHTON MIDDLE",
        "district": "COLUMBIA 93",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100001408",
    },
    {
        "school": "Center for Gifted Education",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100001598",
    },
    {
        "school": "JOHN B. LANGE MIDDLE",
        "district": "COLUMBIA 93",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100001946",
    },
    {
        "school": "CEDAR RIDGE ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100002279",
    },
    {
        "school": "NEW HAVEN ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100002280",
    },
    {
        "school": "FREDERICK DOUGLASS HIGH",
        "district": "COLUMBIA 93",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290100002281",
    },
    {
        "school": "MILL CREEK ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100002546",
    },
    {
        "school": "JUVENILE JUSTICE CTR.",
        "district": "COLUMBIA 93",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290100002577",
    },
    {
        "school": "DERBY RIDGE ELEM.",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100002665",
    },
    {
        "school": "CHANCE ELEM.",
        "district": "CENTRALIA R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290840000242",
    },
    {
        "school": "CHESTER BOREN MIDDLE",
        "district": "CENTRALIA R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290840000243",
    },
    {
        "school": "CENTRALIA HIGH",
        "district": "CENTRALIA R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290840000244",
    },
    {
        "school": "HALLSVILLE INTERMEDIATE",
        "district": "HALLSVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291356000577",
    },
    {
        "school": "HALLSVILLE HIGH",
        "district": "HALLSVILLE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291356000578",
    },
    {
        "school": "HALLSVILLE MIDDLE",
        "district": "HALLSVILLE R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291356001597",
    },
    {
        "school": "HARRISBURG ELEM.",
        "district": "HARRISBURG R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291371000598",
    },
    {
        "school": "HARRISBURG HIGH",
        "district": "HARRISBURG R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291371000599",
    },
    {
        "school": "SOUTHERN BOONE MIDDLE",
        "district": "SOUTHERN BOONE CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292856001596",
    },
    {
        "school": "SOUTHERN BOONE ELEM.",
        "district": "SOUTHERN BOONE CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292856001765",
    },
    {
        "school": "SOUTHERN BOONE HIGH",
        "district": "SOUTHERN BOONE CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292856001766",
    },
    {
        "school": "SOUTHERN BOONE PRIMARY",
        "district": "SOUTHERN BOONE CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292856002802",
    },
    {
        "school": "STURGEON MIDDLE",
        "district": "STURGEON R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292970001392",
    },
    {
        "school": "STURGEON ELEM.",
        "district": "STURGEON R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292970002052",
    },
    {
        "school": "STURGEON HIGH",
        "district": "STURGEON R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292970002053",
    },
    {
        "school": "ROOSEVELT ELEM.",
        "district": "FARMINGTON R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291191002847",
    },
    {
        "school": "BISMARCK R-V ELEM.",
        "district": "BISMARCK R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290513000067",
    },
    {
        "school": "BISMARCK R-V HIGH",
        "district": "BISMARCK R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290513000068",
    },
    {
        "school": "INTERMEDIATE SCH.",
        "district": "NORTH ST. FRANCOIS CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290543000095",
    },
    {
        "school": "NORTH COUNTY PARKSIDE ELEM.",
        "district": "NORTH ST. FRANCOIS CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290543000096",
    },
    {
        "school": "UNITEC CAREER CTR.",
        "district": "NORTH ST. FRANCOIS CO. R-I",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290543000098",
    },
    {
        "school": "NORTH COUNTY PRIMARY",
        "district": "NORTH ST. FRANCOIS CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290543000099",
    },
    {
        "school": "NORTH CO. SR. HIGH",
        "district": "NORTH ST. FRANCOIS CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290543000100",
    },
    {
        "school": "NORTH CO. MIDDLE",
        "district": "NORTH ST. FRANCOIS CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290543000645",
    },
    {
        "school": "TRUMAN LEARNING CENTER",
        "district": "FARMINGTON R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291191000437",
    },
    {
        "school": "JEFFERSON ELEM.",
        "district": "FARMINGTON R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291191000438",
    },
    {
        "school": "FARMINGTON MIDDLE",
        "district": "FARMINGTON R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291191000439",
    },
    {
        "school": "FARMINGTON SR. HIGH",
        "district": "FARMINGTON R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291191000440",
    },
    {
        "school": "WASHINGTON-FRANKLIN ELEM.",
        "district": "FARMINGTON R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291191000442",
    },
    {
        "school": "LINCOLN INTERMEDIATE",
        "district": "FARMINGTON R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291191001065",
    },
    {
        "school": "JUVENILE DETENTION CTR.",
        "district": "FARMINGTON R-VII",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291191002589",
    },
    {
        "school": "WEST COUNTY ELEM.",
        "district": "WEST ST. FRANCOIS CO. R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291824000965",
    },
    {
        "school": "WEST COUNTY HIGH",
        "district": "WEST ST. FRANCOIS CO. R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291824000966",
    },
    {
        "school": "WEST COUNTY MIDDLE",
        "district": "WEST ST. FRANCOIS CO. R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291824001091",
    },
    {
        "school": "CENTRAL ELEM.",
        "district": "CENTRAL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292917001868",
    },
    {
        "school": "CENTRAL HIGH",
        "district": "CENTRAL R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292917001869",
    },
    {
        "school": "WEST ELEM.",
        "district": "CENTRAL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292917001871",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "CENTRAL R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292917002449",
    },
    {
        "school": "ANDERSON ELEM.",
        "district": "MCDONALD CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292061001100",
    },
    {
        "school": "NOEL ELEM.",
        "district": "MCDONALD CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292061001101",
    },
    {
        "school": "PINEVILLE ELEM.",
        "district": "MCDONALD CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292061001102",
    },
    {
        "school": "ROCKY COMFORT ELEM.",
        "district": "MCDONALD CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292061001103",
    },
    {
        "school": "MCDONALD COUNTY HIGH",
        "district": "MCDONALD CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292061001104",
    },
    {
        "school": "SOUTHWEST CITY ELEM.",
        "district": "MCDONALD CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292061001105",
    },
    {
        "school": "WHITE ROCK ELEM.",
        "district": "MCDONALD CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292061001106",
    },
    {
        "school": "CROCKER ELEM.",
        "district": "CROCKER R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291035000337",
    },
    {
        "school": "CROCKER HIGH",
        "district": "CROCKER R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291035000338",
    },
    {
        "school": "DIXON ELEM.",
        "district": "DIXON R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291083000367",
    },
    {
        "school": "DIXON MIDDLE",
        "district": "DIXON R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291083000368",
    },
    {
        "school": "DIXON HIGH",
        "district": "DIXON R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291083000369",
    },
    {
        "school": "LAQUEY R-V ELEM.",
        "district": "LAQUEY R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291788000956",
    },
    {
        "school": "LAQUEY R-V HIGH",
        "district": "LAQUEY R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291788000957",
    },
    {
        "school": "LAQUEY R-V MIDDLE",
        "district": "LAQUEY R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291788001027",
    },
    {
        "school": "RICHLAND ELEM.",
        "district": "RICHLAND R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292643001550",
    },
    {
        "school": "RICHLAND HIGH",
        "district": "RICHLAND R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292643001551",
    },
    {
        "school": "SWEDEBORG ELEM.",
        "district": "SWEDEBORG R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292985002061",
    },
    {
        "school": "WAYNESVILLE EAST ELEM.",
        "district": "WAYNESVILLE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293144002168",
    },
    {
        "school": "PARTRIDGE ELEM.",
        "district": "WAYNESVILLE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293144002171",
    },
    {
        "school": "WAYNESVILLE SR. HIGH",
        "district": "WAYNESVILLE R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293144002175",
    },
    {
        "school": "THAYER ELEM.",
        "district": "WAYNESVILLE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293144002176",
    },
    {
        "school": "WAYNESVILLE CAREER CENTER",
        "district": "WAYNESVILLE R-VI",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "293144002177",
    },
    {
        "school": "WAYNESVILLE MIDDLE",
        "district": "WAYNESVILLE R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293144002484",
    },
    {
        "school": "A. D. STOWELL ELEM.",
        "district": "HANNIBAL 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291365000587",
    },
    {
        "school": "EUGENE FIELD ELEM.",
        "district": "HANNIBAL 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291365000589",
    },
    {
        "school": "HANNIBAL CAREER  TECH. CTR.",
        "district": "HANNIBAL 60",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291365000590",
    },
    {
        "school": "MARK TWAIN ELEM.",
        "district": "HANNIBAL 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291365000592",
    },
    {
        "school": "OAKWOOD ELEM.",
        "district": "HANNIBAL 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291365000593",
    },
    {
        "school": "HANNIBAL SR. HIGH",
        "district": "HANNIBAL 60",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291365000595",
    },
    {
        "school": "HANNIBAL MIDDLE",
        "district": "HANNIBAL 60",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291365002554",
    },
    {
        "school": "VETERANS ELEM.",
        "district": "HANNIBAL 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291365002781",
    },
    {
        "school": "MARION CO. ELEM.",
        "district": "MARION CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292028001074",
    },
    {
        "school": "MARION CO. HIGH",
        "district": "MARION CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292028001075",
    },
    {
        "school": "PALMYRA ELEM.",
        "district": "PALMYRA R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292349001360",
    },
    {
        "school": "PALMYRA MIDDLE",
        "district": "PALMYRA R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292349001361",
    },
    {
        "school": "PALMYRA HIGH",
        "district": "PALMYRA R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292349001362",
    },
    {
        "school": "MARK TWAIN JR. HIGH",
        "district": "RALLS CO. R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292571001034",
    },
    {
        "school": "MARK TWAIN SR. HIGH",
        "district": "RALLS CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292571001510",
    },
    {
        "school": "RALLS COUNTY ELEMENTARY",
        "district": "RALLS CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292571001512",
    },
    {
        "school": "OAKVIEW SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203062",
    },
    {
        "school": "DELMAR A COBBLE SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203047",
    },
    {
        "school": "HELEN M DAVIS SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203061",
    },
    {
        "school": "SHADY GROVE SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203044",
    },
    {
        "school": "WHEELER HIGH",
        "district": "MO SCHOOL FOR THE DEAF",
        "level": "High",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002003021",
    },
    {
        "school": "WHEELER MIDDLE",
        "district": "MO SCHOOL FOR THE DEAF",
        "level": "Middle",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002003022",
    },
    {
        "school": "STARK ELEM.",
        "district": "MO SCHOOL FOR THE DEAF",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002003023",
    },
    {
        "school": "PARKVIEW SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203050",
    },
    {
        "school": "BRIARWOOD SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203066",
    },
    {
        "school": "MAPLE VALLEY SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203048",
    },
    {
        "school": "H KENNETH KIRCHNER SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203043",
    },
    {
        "school": "OZARK HILLS SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203072",
    },
    {
        "school": "BOOTHEEL SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203049",
    },
    {
        "school": "AUTUMN HILL SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203064",
    },
    {
        "school": "GREENE VALLEY SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203041",
    },
    {
        "school": "OZARK HORIZON SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203054",
    },
    {
        "school": "LAKEVIEW WOODS SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203045",
    },
    {
        "school": "B W SHEPERD SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203051",
    },
    {
        "school": "DALE M THOMPSON/TRAILS WEST S",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203076",
    },
    {
        "school": "COLLEGE VIEW SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203067",
    },
    {
        "school": "MAPAVILLE SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203042",
    },
    {
        "school": "ROLLING MEADOW SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203075",
    },
    {
        "school": "VERELLE PENISTON SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203055",
    },
    {
        "school": "MISSISSIPPI VALLEY SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203063",
    },
    {
        "school": "DOGWOOD HILLS SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203069",
    },
    {
        "school": "E W THOMPSON SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203056",
    },
    {
        "school": "B W ROBINSON SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203057",
    },
    {
        "school": "LILLIAN SCHAPER SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203052",
    },
    {
        "school": "CURRENT RIVER SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203071",
    },
    {
        "school": "BOONSLICK SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203046",
    },
    {
        "school": "SPECIAL ACRES SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203053",
    },
    {
        "school": "DISCOVERY HALL",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000903077",
    },
    {
        "school": "PRAIRIE VIEW SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203070",
    },
    {
        "school": "NEW DAWN SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203068",
    },
    {
        "school": "CROWLEY RIDGE SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203059",
    },
    {
        "school": "CEDAR RIDGE SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203073",
    },
    {
        "school": "CITADEL SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203058",
    },
    {
        "school": "SKYVIEW SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203060",
    },
    {
        "school": "GATEWAY/HUBERT WHEELER SCHOOL",
        "district": "MO SCHLS FOR THE SEV DISABLED",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002203074",
    },
    {
        "school": "BARTLEY ELEM.",
        "district": "FULTON 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291255000517",
    },
    {
        "school": "BUSH ELEM.",
        "district": "FULTON 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291255000518",
    },
    {
        "school": "MCINTIRE ELEM.",
        "district": "FULTON 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291255000522",
    },
    {
        "school": "FULTON SR. HIGH",
        "district": "FULTON 58",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291255000524",
    },
    {
        "school": "FULTON MIDDLE",
        "district": "FULTON 58",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291255002525",
    },
    {
        "school": "NORTH ELEM.",
        "district": "JEFFERSON CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619000753",
    },
    {
        "school": "CALLAWAY HILLS ELEM.",
        "district": "JEFFERSON CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619002288",
    },
    {
        "school": "NEW BLOOMFIELD ELEM.",
        "district": "NEW BLOOMFIELD R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292187501218",
    },
    {
        "school": "NEW BLOOMFIELD HIGH",
        "district": "NEW BLOOMFIELD R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292187501219",
    },
    {
        "school": "AUXVASSE ELEM.",
        "district": "NORTH CALLAWAY CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292274001252",
    },
    {
        "school": "HATTON-MCCREDIE ELEM.",
        "district": "NORTH CALLAWAY CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292274001253",
    },
    {
        "school": "NORTH CALLAWAY HIGH",
        "district": "NORTH CALLAWAY CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292274001254",
    },
    {
        "school": "WILLIAMSBURG ELEM.",
        "district": "NORTH CALLAWAY CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292274001255",
    },
    {
        "school": "SOUTH CALLAWAY ELEM.",
        "district": "SOUTH CALLAWAY CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292843001756",
    },
    {
        "school": "SOUTH CALLAWAY HIGH",
        "district": "SOUTH CALLAWAY CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292843001757",
    },
    {
        "school": "SOUTH CALLAWAY MIDDLE",
        "district": "SOUTH CALLAWAY CO. R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292843002401",
    },
    {
        "school": "BLAIR OAKS ELEM.",
        "district": "BLAIR OAKS R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290993000294",
    },
    {
        "school": "BLAIR OAKS HIGH",
        "district": "BLAIR OAKS R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290993000295",
    },
    {
        "school": "EUGENE ELEM.",
        "district": "COLE CO. R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291155000410",
    },
    {
        "school": "EUGENE HIGH",
        "district": "COLE CO. R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291155000411",
    },
    {
        "school": "LEWIS AND CLARK MIDDLE",
        "district": "JEFFERSON CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619000476",
    },
    {
        "school": "THOMAS JEFFERSON MIDDLE",
        "district": "JEFFERSON CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619000495",
    },
    {
        "school": "BELAIR ELEM.",
        "district": "JEFFERSON CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619000746",
    },
    {
        "school": "CEDAR HILL ELEM.",
        "district": "JEFFERSON CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619000747",
    },
    {
        "school": "EAST ELEM.",
        "district": "JEFFERSON CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619000748",
    },
    {
        "school": "JEFFERSON CITY HIGH",
        "district": "JEFFERSON CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619000749",
    },
    {
        "school": "MOREAU HEIGHTS ELEM.",
        "district": "JEFFERSON CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619000751",
    },
    {
        "school": "NICHOLS CAREER CTR.",
        "district": "JEFFERSON CITY",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291619000752",
    },
    {
        "school": "SOUTH ELEM.",
        "district": "JEFFERSON CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619000755",
    },
    {
        "school": "THORPE J. GORDON ELEM.",
        "district": "JEFFERSON CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619000757",
    },
    {
        "school": "WEST ELEM.",
        "district": "JEFFERSON CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619000758",
    },
    {
        "school": "CLARENCE LAWSON ELEM.",
        "district": "JEFFERSON CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619002494",
    },
    {
        "school": "PRENGER FAMILY CTR.",
        "district": "JEFFERSON CITY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291619002599",
    },
    {
        "school": "COLE CO. R-I MIDDLE",
        "district": "COLE CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292697000847",
    },
    {
        "school": "COLE CO. R-I ELEM.",
        "district": "COLE CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292697001638",
    },
    {
        "school": "RUSSELLVILLE HIGH",
        "district": "COLE CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292697001639",
    },
    {
        "school": "CALIFORNIA ELEM.",
        "district": "MONITEAU CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290651000167",
    },
    {
        "school": "CALIFORNIA HIGH",
        "district": "MONITEAU CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290651000168",
    },
    {
        "school": "CALIFORNIA MIDDLE",
        "district": "MONITEAU CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290651001522",
    },
    {
        "school": "CLARKSBURG ELEM.",
        "district": "CLARKSBURG C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290909000267",
    },
    {
        "school": "JAMESTOWN C-I ELEM.",
        "district": "JAMESTOWN C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291566000742",
    },
    {
        "school": "JAMESTOWN C-I HIGH",
        "district": "JAMESTOWN C-1",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291566000743",
    },
    {
        "school": "HIGH POINT ELEM.",
        "district": "HIGH POINT R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292115001163",
    },
    {
        "school": "LATHAM ELEM.",
        "district": "MONITEAU CO. R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292118001164",
    },
    {
        "school": "TIPTON HIGH",
        "district": "TIPTON R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293033002073",
    },
    {
        "school": "TIPTON ELEM.",
        "district": "TIPTON R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293033002075",
    },
    {
        "school": "OSAGE CO. ELEM.",
        "district": "OSAGE CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290849000249",
    },
    {
        "school": "CHAMOIS HIGH",
        "district": "OSAGE CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290849000250",
    },
    {
        "school": "OSAGE CO. ELEM.",
        "district": "OSAGE CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291908001029",
    },
    {
        "school": "LINN HIGH",
        "district": "OSAGE CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291908001030",
    },
    {
        "school": "FATIMA HIGH",
        "district": "OSAGE CO. R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293183002226",
    },
    {
        "school": "FATIMA ELEM.",
        "district": "OSAGE CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293183002229",
    },
    {
        "school": "N.E. COMMUNITY TREATMENT CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901368",
    },
    {
        "school": "RICH HILL YOUTH DEV. CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902714",
    },
    {
        "school": "CORNERSTONE",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902179",
    },
    {
        "school": "RIVERBEND TREATMENT CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902712",
    },
    {
        "school": "W. E. SEARS YOUTH CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901178",
    },
    {
        "school": "SIERRA-OSAGE TREATMENT CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901185",
    },
    {
        "school": "FULTON TREATMENT CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902172",
    },
    {
        "school": "ROSA PARKS CENTER",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902793",
    },
    {
        "school": "GIRARDOT CENTER FOR YOUTH",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901192",
    },
    {
        "school": "ECHO DAY TREATMENT CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901193",
    },
    {
        "school": "NORTHWEST REG. YOUTH CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901270",
    },
    {
        "school": "WATKINS MILL PARK CAMP",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901289",
    },
    {
        "school": "S.T.A.R. DAY TREATMENT CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901593",
    },
    {
        "school": "COMMUNITY LEARNING CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901352",
    },
    {
        "school": "WILSON CREEK GROUP HOME",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901358",
    },
    {
        "school": "EXCEL SCHOOL",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901364",
    },
    {
        "school": "DATEMA HOUSE",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901936",
    },
    {
        "school": "LANGSFORD HOUSE",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901285",
    },
    {
        "school": "ALTERNATIVE RESOURCE CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290000901287",
    },
    {
        "school": "GATEWAY SCHOOL",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902211",
    },
    {
        "school": "NEW DAY - DAY TREATMENT",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901265",
    },
    {
        "school": "HILLSBORO TREATMENT CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902713",
    },
    {
        "school": "WAVERLY REGIONAL YOUTH CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901283",
    },
    {
        "school": "MT. VERNON TREATMENT CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902716",
    },
    {
        "school": "CAMP AVERY PARK CAMP",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901273",
    },
    {
        "school": "MONTGOMERY CITY TREATMENT CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290000901145",
    },
    {
        "school": "NEW MADRID BEND YOUTH CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902710",
    },
    {
        "school": "QUEST DAY TREATMENT",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902196",
    },
    {
        "school": "BISSELL HALL",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901199",
    },
    {
        "school": "TWIN RIVERS",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901215",
    },
    {
        "school": "FORT BELLEFONTAINE CAMPUS",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901226",
    },
    {
        "school": "SPANISH LAKE CAMPUS",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901259",
    },
    {
        "school": "LEWIS AND CLARK HALL",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901261",
    },
    {
        "school": "BABLER LODGE",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901271",
    },
    {
        "school": "SIKESTON HOPE CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902711",
    },
    {
        "school": "DELMINA WOODS YOUTH FACILITY",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901276",
    },
    {
        "school": "GENTRY RESIDENTIAL TREAT. FAC.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000902715",
    },
    {
        "school": "HOGAN ST REGIONAL YOUTH CTR.",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901195",
    },
    {
        "school": "REACH ST. LOUIS DAY TREATMENT",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000901269",
    },
    {
        "school": "AVILLA ELEM.",
        "district": "AVILLA R-XIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290411000038",
    },
    {
        "school": "Carl Junction Intermediate",
        "district": "CARL JUNCTION R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290735000196",
    },
    {
        "school": "Carl Junction Primary 2-3",
        "district": "CARL JUNCTION R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290735000197",
    },
    {
        "school": "Carl Junction High School",
        "district": "CARL JUNCTION R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290735000198",
    },
    {
        "school": "Carl Junction Jr. High",
        "district": "CARL JUNCTION R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290735000199",
    },
    {
        "school": "Carl Junction Satellite School",
        "district": "CARL JUNCTION R-I",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290735002582",
    },
    {
        "school": "Carl Junction Primary K-1",
        "district": "CARL JUNCTION R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290735002811",
    },
    {
        "school": "COLUMBIAN ELEM.",
        "district": "CARTHAGE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290746000204",
    },
    {
        "school": "FAIRVIEW ELEM.",
        "district": "CARTHAGE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290746000206",
    },
    {
        "school": "CARTHAGE JR. HIGH",
        "district": "CARTHAGE R-IX",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290746000208",
    },
    {
        "school": "MARK TWAIN ELEM.",
        "district": "CARTHAGE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290746000209",
    },
    {
        "school": "PLEASANT VALLEY ELEM.",
        "district": "CARTHAGE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290746000210",
    },
    {
        "school": "CARTHAGE HIGH SCHOOL",
        "district": "CARTHAGE R-IX",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290746000211",
    },
    {
        "school": "STEADLEY ELEM.",
        "district": "CARTHAGE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290746001980",
    },
    {
        "school": "CARTHAGE TECHNICAL CTR.",
        "district": "CARTHAGE R-IX",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290746002275",
    },
    {
        "school": "JASPER CO. ELEM.",
        "district": "JASPER CO. R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291614000744",
    },
    {
        "school": "JASPER HIGH",
        "district": "JASPER CO. R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291614000745",
    },
    {
        "school": "COLUMBIA ELEM.",
        "district": "JOPLIN SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635000772",
    },
    {
        "school": "SOARING HEIGHTS ELEM.",
        "district": "JOPLIN SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635000773",
    },
    {
        "school": "EASTMORLAND ELEM.",
        "district": "JOPLIN SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635000775",
    },
    {
        "school": "FRANKLIN TECHNOLOGY CTR.",
        "district": "JOPLIN SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291635000777",
    },
    {
        "school": "JEFFERSON ELEM.",
        "district": "JOPLIN SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635000779",
    },
    {
        "school": "KELSEY NORMAN ELEM.",
        "district": "JOPLIN SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635000780",
    },
    {
        "school": "MCKINLEY ELEM.",
        "district": "JOPLIN SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635000783",
    },
    {
        "school": "JOPLIN HIGH",
        "district": "JOPLIN SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635000787",
    },
    {
        "school": "ROYAL HEIGHTS ELEM.",
        "district": "JOPLIN SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635000788",
    },
    {
        "school": "WEST CENTRAL ELEM.",
        "district": "JOPLIN SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635000793",
    },
    {
        "school": "SOUTH MIDDLE",
        "district": "JOPLIN SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635002429",
    },
    {
        "school": "NORTH MIDDLE",
        "district": "JOPLIN SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635002430",
    },
    {
        "school": "EAST MIDDLE",
        "district": "JOPLIN SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635002431",
    },
    {
        "school": "CECIL FLOYD ELEM.",
        "district": "JOPLIN SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635002432",
    },
    {
        "school": "JOPLIN EARLY CHILDHOOD CTR.",
        "district": "JOPLIN SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635002778",
    },
    {
        "school": "SARCOXIE HIGH",
        "district": "SARCOXIE R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292754001686",
    },
    {
        "school": "WILDWOOD ELEM.",
        "district": "SARCOXIE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292754001687",
    },
    {
        "school": "WEBB CITY MIDDLE",
        "district": "WEBB CITY R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293150000559",
    },
    {
        "school": "HARRY S. TRUMAN ELEM.",
        "district": "WEBB CITY R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293150002182",
    },
    {
        "school": "CARTERVILLE ELEM.",
        "district": "WEBB CITY R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293150002183",
    },
    {
        "school": "EUGENE FIELD ELEM.",
        "district": "WEBB CITY R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293150002184",
    },
    {
        "school": "MADGE T. JAMES KIND. CTR.",
        "district": "WEBB CITY R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293150002185",
    },
    {
        "school": "WEBB CITY HIGH",
        "district": "WEBB CITY R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293150002186",
    },
    {
        "school": "MARK TWAIN ELEM.",
        "district": "WEBB CITY R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293150002188",
    },
    {
        "school": "WEBSTER PRIMARY CTR.",
        "district": "WEBB CITY R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293150002189",
    },
    {
        "school": "HERITAGE PRESCHOOL",
        "district": "WEBB CITY R-VII",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293150002377",
    },
    {
        "school": "WEBB CITY JR. HIGH",
        "district": "WEBB CITY R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293150002756",
    },
    {
        "school": "GOODMAN ELEM.",
        "district": "NEOSHO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292181001206",
    },
    {
        "school": "CROWDER AVTS",
        "district": "CROWDER COLLEGE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290000700817",
    },
    {
        "school": "DIAMOND ELEM.",
        "district": "DIAMOND R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291080000365",
    },
    {
        "school": "DIAMOND HIGH",
        "district": "DIAMOND R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291080000366",
    },
    {
        "school": "DIAMOND MIDDLE",
        "district": "DIAMOND R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291080000572",
    },
    {
        "school": "STAPLETON ELEM.",
        "district": "JOPLIN SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635000791",
    },
    {
        "school": "BENTON ELEM.",
        "district": "NEOSHO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292181001203",
    },
    {
        "school": "CENTRAL ELEM.",
        "district": "NEOSHO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292181001204",
    },
    {
        "school": "FIELD EARLY CHILD./KDGN. CTR.",
        "district": "NEOSHO SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292181001205",
    },
    {
        "school": "MIDDLE SCH.",
        "district": "NEOSHO SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292181001207",
    },
    {
        "school": "NEOSHO JR. HIGH",
        "district": "NEOSHO SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292181001208",
    },
    {
        "school": "NEOSHO HIGH",
        "district": "NEOSHO SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292181001209",
    },
    {
        "school": "SOUTH ELEM.",
        "district": "NEOSHO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292181001210",
    },
    {
        "school": "SENECA ELEM.",
        "district": "SENECA R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292790001717",
    },
    {
        "school": "SENECA HIGH",
        "district": "SENECA R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292790001719",
    },
    {
        "school": "SENECA JUNIOR HIGH",
        "district": "SENECA R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292790002446",
    },
    {
        "school": "GRANBY",
        "district": "EAST NEWTON CO. R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293042002083",
    },
    {
        "school": "EAST NEWTON HIGH",
        "district": "EAST NEWTON CO. R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293042002084",
    },
    {
        "school": "TRIWAY",
        "district": "EAST NEWTON CO. R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293042002085",
    },
    {
        "school": "WESTVIEW ELEM.",
        "district": "WESTVIEW C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293189002233",
    },
    {
        "school": "BELTON MIDDLE SCHOOL",
        "district": "BELTON 124",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290462003025",
    },
    {
        "school": "EAGLE GLEN ELEMENTARY",
        "district": "RAYMORE-PECULIAR R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292373003024",
    },
    {
        "school": "DOGWOOD ELEM.",
        "district": "KEARNEY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291645002862",
    },
    {
        "school": "SOUTH VALLEY MIDDLE",
        "district": "LIBERTY 53",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854002800",
    },
    {
        "school": "LIBERTY OAKS ELEM.",
        "district": "LIBERTY 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854002863",
    },
    {
        "school": "PAUL KINDER MIDDLE SCHOOL",
        "district": "BLUE SPRINGS R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531002835",
    },
    {
        "school": "VOY SPEARS JR. ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531002836",
    },
    {
        "school": "PRAIRIE BRANCH ELEM.",
        "district": "GRAIN VALLEY R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291308002866",
    },
    {
        "school": "LEE'S SUMMIT WEST HIGH",
        "district": "LEE'S SUMMIT R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830002795",
    },
    {
        "school": "LONGVIEW FARM ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830002867",
    },
    {
        "school": "HAWTHORN ELEM.",
        "district": "PARK HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355002841",
    },
    {
        "school": "ADRIAN ELEM.",
        "district": "ADRIAN R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290285000001",
    },
    {
        "school": "ADRIAN SR. HIGH",
        "district": "ADRIAN R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290285000002",
    },
    {
        "school": "BALLARD ELEM.",
        "district": "BALLARD R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290417000041",
    },
    {
        "school": "BALLARD HIGH",
        "district": "BALLARD R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290417000042",
    },
    {
        "school": "BUTLER ELEM.",
        "district": "BUTLER R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290636000157",
    },
    {
        "school": "BUTLER HIGH",
        "district": "BUTLER R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290636000158",
    },
    {
        "school": "HUDSON ELEM.",
        "district": "HUDSON R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291524000693",
    },
    {
        "school": "HUME ELEM.",
        "district": "HUME R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291533000698",
    },
    {
        "school": "HUME HIGH",
        "district": "HUME R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291533000699",
    },
    {
        "school": "MIAMI ELEM.",
        "district": "MIAMI R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292082001138",
    },
    {
        "school": "MIAMI HIGH",
        "district": "MIAMI R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292082001139",
    },
    {
        "school": "RICH HILL HIGH",
        "district": "RICH HILL R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292631001544",
    },
    {
        "school": "RICH HILL ELEM.",
        "district": "RICH HILL R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292631001545",
    },
    {
        "school": "BRAYMER ELEM.",
        "district": "BRAYMER C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290582000126",
    },
    {
        "school": "BRAYMER HIGH",
        "district": "BRAYMER C-4",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290582000127",
    },
    {
        "school": "BRECKENRIDGE ELEM.",
        "district": "BRECKENRIDGE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290585000128",
    },
    {
        "school": "BRECKENRIDGE HIGH",
        "district": "BRECKENRIDGE R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290585000129",
    },
    {
        "school": "COWGILL ELEM.",
        "district": "COWGILL R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291023000329",
    },
    {
        "school": "HAMILTON ELEM.",
        "district": "HAMILTON R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291359000579",
    },
    {
        "school": "PENNEY HIGH",
        "district": "HAMILTON R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291359000580",
    },
    {
        "school": "HAMILTON MIDDLE",
        "district": "HAMILTON R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291359002663",
    },
    {
        "school": "KINGSTON ELEM.",
        "district": "KINGSTON 42",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291662000908",
    },
    {
        "school": "MIRABILE ELEM.",
        "district": "MIRABILE C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292103001150",
    },
    {
        "school": "NEW YORK ELEM.",
        "district": "NEW YORK R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292211001227",
    },
    {
        "school": "POLO MIDDLE",
        "district": "POLO R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292541000227",
    },
    {
        "school": "POLO ELEM.",
        "district": "POLO R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292541001464",
    },
    {
        "school": "POLO HIGH",
        "district": "POLO R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292541001465",
    },
    {
        "school": "CASS CO. ELEM.",
        "district": "ARCHIE R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290320000024",
    },
    {
        "school": "ARCHIE HIGH",
        "district": "ARCHIE R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290320000025",
    },
    {
        "school": "CAMBRIDGE ELEM.",
        "district": "BELTON 124",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290462000051",
    },
    {
        "school": "GLADDEN ELEM.",
        "district": "BELTON 124",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290462000052",
    },
    {
        "school": "HILLCREST STEAM ACADEMY",
        "district": "BELTON 124",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290462000053",
    },
    {
        "school": "BELTON HIGH",
        "district": "BELTON 124",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290462000055",
    },
    {
        "school": "MILL CREEK UPPER ELEM.",
        "district": "BELTON 124",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290462002724",
    },
    {
        "school": "GRACE EARLY CHILD.  ED. CTR.",
        "district": "BELTON 124",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290462002725",
    },
    {
        "school": "SHERWOOD ELEM.",
        "district": "SHERWOOD CASS R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291032000334",
    },
    {
        "school": "SHERWOOD HIGH",
        "district": "SHERWOOD CASS R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291032000335",
    },
    {
        "school": "SHERWOOD MIDDLE",
        "district": "SHERWOOD CASS R-VIII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291032001610",
    },
    {
        "school": "DREXEL ELEM.",
        "district": "DREXEL R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291107000378",
    },
    {
        "school": "DREXEL HIGH",
        "district": "DREXEL R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291107000379",
    },
    {
        "school": "EAST LYNNE ELEM.",
        "district": "EAST LYNNE 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291116000384",
    },
    {
        "school": "EARLY CHILDHOOD CTR.",
        "district": "HARRISONVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291376000091",
    },
    {
        "school": "CASS CAREER CTR.",
        "district": "HARRISONVILLE R-IX",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291376000600",
    },
    {
        "school": "HARRISONVILLE ELEM.",
        "district": "HARRISONVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291376000602",
    },
    {
        "school": "MCEOWEN ELEM.",
        "district": "HARRISONVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291376000604",
    },
    {
        "school": "HARRISONVILLE HIGH",
        "district": "HARRISONVILLE R-IX",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291376000605",
    },
    {
        "school": "EVERETT WADE JUVENILE CTR.",
        "district": "HARRISONVILLE R-IX",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291376002594",
    },
    {
        "school": "HARRISONVILLE MIDDLE",
        "district": "HARRISONVILLE R-IX",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291376002659",
    },
    {
        "school": "RAYMORE-PECULIAR EAST MIDDLE",
        "district": "RAYMORE-PECULIAR R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292373000088",
    },
    {
        "school": "RAYMORE-PECULIAR SR. HIGH",
        "district": "RAYMORE-PECULIAR R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292373001424",
    },
    {
        "school": "PECULIAR ELEM.",
        "district": "RAYMORE-PECULIAR R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292373001426",
    },
    {
        "school": "RAYMORE ELEM.",
        "district": "RAYMORE-PECULIAR R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292373001427",
    },
    {
        "school": "TIMBER CREEK ELEM.",
        "district": "RAYMORE-PECULIAR R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292373001959",
    },
    {
        "school": "STONEGATE ELEM.",
        "district": "RAYMORE-PECULIAR R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292373002723",
    },
    {
        "school": "PLEASANT HILL MIDDLE",
        "district": "PLEASANT HILL R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292533001459",
    },
    {
        "school": "PLEASANT HILL PRIMARY",
        "district": "PLEASANT HILL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292533001460",
    },
    {
        "school": "PLEASANT HILL HIGH",
        "district": "PLEASANT HILL R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292533001461",
    },
    {
        "school": "PLEASANT HILL ELEM.",
        "district": "PLEASANT HILL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292533002803",
    },
    {
        "school": "STRASBURG ELEM.",
        "district": "STRASBURG C-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292967002051",
    },
    {
        "school": "MIDWAY ELEM.",
        "district": "MIDWAY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293180002223",
    },
    {
        "school": "MIDWAY HIGH",
        "district": "MIDWAY R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293180002224",
    },
    {
        "school": "EXCELSIOR SPRINGS TECH. HIGH",
        "district": "EXCELSIOR SPRINGS 40",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291165000071",
    },
    {
        "school": "EXCELSIOR SPRINGS CAREER CTR.",
        "district": "EXCELSIOR SPRINGS 40",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291165000414",
    },
    {
        "school": "LEWIS ELEMENTARY",
        "district": "EXCELSIOR SPRINGS 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291165000417",
    },
    {
        "school": "EXCELSIOR SPRINGS MIDDLE",
        "district": "EXCELSIOR SPRINGS 40",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291165000418",
    },
    {
        "school": "EXCELSIOR SPRINGS HIGH",
        "district": "EXCELSIOR SPRINGS 40",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291165000420",
    },
    {
        "school": "WESTVIEW ELEMENTARY",
        "district": "EXCELSIOR SPRINGS 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291165000421",
    },
    {
        "school": "KEARNEY ELEM.",
        "district": "KEARNEY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291645000891",
    },
    {
        "school": "KEARNEY HIGH",
        "district": "KEARNEY R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291645000894",
    },
    {
        "school": "SOUTHVIEW ELEM.",
        "district": "KEARNEY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291645001434",
    },
    {
        "school": "KEARNEY JR. HIGH",
        "district": "KEARNEY R-I",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291645002531",
    },
    {
        "school": "HAWTHORNE ELEM.",
        "district": "KEARNEY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291645002532",
    },
    {
        "school": "ALEXANDER DONIPHAN ELEM.",
        "district": "LIBERTY 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854001004",
    },
    {
        "school": "FRANKLIN ELEM.",
        "district": "LIBERTY 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854001005",
    },
    {
        "school": "LEWIS AND CLARK ELEM.",
        "district": "LIBERTY 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854001007",
    },
    {
        "school": "MANOR HILL ELEM.",
        "district": "LIBERTY 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854001009",
    },
    {
        "school": "RIDGEVIEW ELEM.",
        "district": "LIBERTY 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854001010",
    },
    {
        "school": "LIBERTY HIGH",
        "district": "LIBERTY 53",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854001011",
    },
    {
        "school": "LIBERTY ACADEMY",
        "district": "LIBERTY 53",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291854001665",
    },
    {
        "school": "EARLY CHILD. EDUCATION CTR.",
        "district": "LIBERTY 53",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854002615",
    },
    {
        "school": "LIBERTY MIDDLE SCHOOL",
        "district": "LIBERTY 53",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854002616",
    },
    {
        "school": "JUVENILE JUSTICE CTR.",
        "district": "LIBERTY 53",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291854002658",
    },
    {
        "school": "LILLIAN SCHUMACHER ELEM.",
        "district": "LIBERTY 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854002729",
    },
    {
        "school": "SHOAL CREEK ELEM.",
        "district": "LIBERTY 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854002804",
    },
    {
        "school": "MISSOURI CITY ELEM.",
        "district": "MISSOURI CITY 56",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292106001151",
    },
    {
        "school": "ANTIOCH MIDDLE",
        "district": "NORTH KANSAS CITY 74",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001258",
    },
    {
        "school": "BRIARCLIFF ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001260",
    },
    {
        "school": "CHAPEL HILL ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001262",
    },
    {
        "school": "CHOUTEAU ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001263",
    },
    {
        "school": "CLARDY ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001264",
    },
    {
        "school": "CRESTVIEW ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001266",
    },
    {
        "school": "DAVIDSON ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001267",
    },
    {
        "school": "EASTGATE MIDDLE",
        "district": "NORTH KANSAS CITY 74",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001268",
    },
    {
        "school": "GASHLAND ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001272",
    },
    {
        "school": "GRACEMOR ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001274",
    },
    {
        "school": "LAKEWOOD ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001275",
    },
    {
        "school": "LINDEN WEST ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001277",
    },
    {
        "school": "MAPLE PARK MIDDLE",
        "district": "NORTH KANSAS CITY 74",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001278",
    },
    {
        "school": "MAPLEWOOD ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001279",
    },
    {
        "school": "MEADOWBROOK ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001280",
    },
    {
        "school": "NASHUA ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001281",
    },
    {
        "school": "NEW MARK MIDDLE",
        "district": "NORTH KANSAS CITY 74",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001282",
    },
    {
        "school": "NORTH KANSAS CITY HIGH",
        "district": "NORTH KANSAS CITY 74",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001284",
    },
    {
        "school": "OAK PARK HIGH",
        "district": "NORTH KANSAS CITY 74",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001286",
    },
    {
        "school": "OAKWOOD MANOR ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001288",
    },
    {
        "school": "RAVENWOOD ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001290",
    },
    {
        "school": "TOPPING ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001291",
    },
    {
        "school": "WEST ENGLEWOOD ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001292",
    },
    {
        "school": "WINNETONKA HIGH",
        "district": "NORTH KANSAS CITY 74",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001293",
    },
    {
        "school": "WINNWOOD ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280001294",
    },
    {
        "school": "CTR. FOR EDUC. DEVELOPMENT",
        "district": "NORTH KANSAS CITY 74",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292280002535",
    },
    {
        "school": "FOX HILL ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280002621",
    },
    {
        "school": "PLEASANT VALLEY EARLY CHILDHOO",
        "district": "NORTH KANSAS CITY 74",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280002662",
    },
    {
        "school": "NORTHGATE MIDDLE",
        "district": "NORTH KANSAS CITY 74",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280002730",
    },
    {
        "school": "NORTHVIEW ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280002731",
    },
    {
        "school": "SMITHVILLE MIDDLE",
        "district": "SMITHVILLE R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292841000070",
    },
    {
        "school": "Smithville Maple Elementary",
        "district": "SMITHVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292841001753",
    },
    {
        "school": "SMITHVILLE HIGH",
        "district": "SMITHVILLE R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292841001754",
    },
    {
        "school": "SMITHVILLE HORIZON ELEM.",
        "district": "SMITHVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292841002274",
    },
    {
        "school": "CAMERON HIGH",
        "district": "CAMERON R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290702000176",
    },
    {
        "school": "CAMERON VETERANS MIDDLE",
        "district": "CAMERON R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290702000177",
    },
    {
        "school": "PARKVIEW ELEM.",
        "district": "CAMERON R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290702000178",
    },
    {
        "school": "LATHROP ELEM.",
        "district": "LATHROP R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291797000959",
    },
    {
        "school": "LATHROP HIGH",
        "district": "LATHROP R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291797000960",
    },
    {
        "school": "LATHROP MIDDLE",
        "district": "LATHROP R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291797001684",
    },
    {
        "school": "CLINTON CO. R-III MIDDLE",
        "district": "CLINTON CO. R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292529000846",
    },
    {
        "school": "ELLIS ELEM.",
        "district": "CLINTON CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292529001457",
    },
    {
        "school": "PLATTSBURG HIGH",
        "district": "CLINTON CO. R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292529001458",
    },
    {
        "school": "CORDILL-MASON ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531000078",
    },
    {
        "school": "FRANKLIN SMITH ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531000080",
    },
    {
        "school": "JAMES LEWIS ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531000082",
    },
    {
        "school": "JAMES WALKER ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531000083",
    },
    {
        "school": "JOHN NOWLIN ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531000084",
    },
    {
        "school": "BLUE SPRINGS HIGH",
        "district": "BLUE SPRINGS R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531000085",
    },
    {
        "school": "THOMAS J. ULTICAN ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531000086",
    },
    {
        "school": "WILLIAM YATES ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531000087",
    },
    {
        "school": "BLUE SPRINGS SOUTH HIGH",
        "district": "BLUE SPRINGS R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531000170",
    },
    {
        "school": "VALLEY VIEW HIGH",
        "district": "BLUE SPRINGS R-IV",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290531000200",
    },
    {
        "school": "LIGGETT TRAIL EDUCATION CENTER",
        "district": "BLUE SPRINGS R-IV",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531000270",
    },
    {
        "school": "BRITTANY HILL MIDDLE",
        "district": "BLUE SPRINGS R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531000943",
    },
    {
        "school": "MORELAND RIDGE MIDDLE",
        "district": "BLUE SPRINGS R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531001706",
    },
    {
        "school": "DANIEL YOUNG ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531002367",
    },
    {
        "school": "WILLIAM BRYANT ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531002488",
    },
    {
        "school": "LUCY FRANKLIN ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531002549",
    },
    {
        "school": "CHAPEL LAKES ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531002682",
    },
    {
        "school": "BLUE SPRINGS HIGH SCHOOL CAMPU",
        "district": "BLUE SPRINGS R-IV",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531002735",
    },
    {
        "school": "DELTA WOODS MIDDLE",
        "district": "BLUE SPRINGS R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531002736",
    },
    {
        "school": "SUNNY POINTE ELEM.",
        "district": "BLUE SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290531002737",
    },
    {
        "school": "BOONE ELEM.",
        "district": "CENTER 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290825000223",
    },
    {
        "school": "CENTER ELEM.",
        "district": "CENTER 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290825000224",
    },
    {
        "school": "CENTER SR. HIGH",
        "district": "CENTER 58",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290825000225",
    },
    {
        "school": "INDIAN CREEK ELEM.",
        "district": "CENTER 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290825000226",
    },
    {
        "school": "RED BRIDGE ELEM.",
        "district": "CENTER 58",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290825000228",
    },
    {
        "school": "CENTER MIDDLE",
        "district": "CENTER 58",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290825000230",
    },
    {
        "school": "EARLY CHILDHOOD EDUC. CTR.",
        "district": "CENTER 58",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290825002755",
    },
    {
        "school": "CENTER ALTERNATIVE",
        "district": "CENTER 58",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290825002810",
    },
    {
        "school": "CAR.  TECH. CTR. AT FT. OSAGE",
        "district": "FORT OSAGE R-I",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291229000488",
    },
    {
        "school": "BLUE HILLS ELEM.",
        "district": "FORT OSAGE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291229000489",
    },
    {
        "school": "BUCKNER ELEM.",
        "district": "FORT OSAGE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291229000490",
    },
    {
        "school": "CLER-MONT ELEM.",
        "district": "FORT OSAGE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291229000491",
    },
    {
        "school": "ELM GROVE ELEM.",
        "district": "FORT OSAGE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291229000493",
    },
    {
        "school": "OSAGE TRAIL MIDDLE",
        "district": "FORT OSAGE R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291229000494",
    },
    {
        "school": "FORT OSAGE HIGH",
        "district": "FORT OSAGE R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291229000496",
    },
    {
        "school": "FIRE PRAIRIE MIDDLE",
        "district": "FORT OSAGE R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291229002284",
    },
    {
        "school": "EARLY CHILDHOOD CTR.",
        "district": "FORT OSAGE R-I",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291229002310",
    },
    {
        "school": "GRAIN VALLEY HIGH",
        "district": "GRAIN VALLEY R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291308000546",
    },
    {
        "school": "MATTHEWS ELEM.",
        "district": "GRAIN VALLEY R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291308000547",
    },
    {
        "school": "SNI-A-BAR ELEM.",
        "district": "GRAIN VALLEY R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291308001965",
    },
    {
        "school": "GRAIN VALLEY SOUTH MIDDLE SCHL",
        "district": "GRAIN VALLEY R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291308002463",
    },
    {
        "school": "BELVIDERE ELEM.",
        "district": "GRANDVIEW C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291314000548",
    },
    {
        "school": "BUTCHER-GREENE ELEM.",
        "district": "GRANDVIEW C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291314000549",
    },
    {
        "school": "CONN-WEST ELEM.",
        "district": "GRANDVIEW C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291314000550",
    },
    {
        "school": "GRANDVIEW MIDDLE",
        "district": "GRANDVIEW C-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291314000551",
    },
    {
        "school": "HIGH GROVE Early Childhood",
        "district": "GRANDVIEW C-4",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291314000552",
    },
    {
        "school": "MARTIN CITY ELEM.",
        "district": "GRANDVIEW C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291314000554",
    },
    {
        "school": "MEADOWMERE ELEM.",
        "district": "GRANDVIEW C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291314000555",
    },
    {
        "school": "GRANDVIEW SR. HIGH",
        "district": "GRANDVIEW C-4",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291314000556",
    },
    {
        "school": "GRANDVIEW ALTERNATIVE SCH.",
        "district": "GRANDVIEW C-4",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291314000948",
    },
    {
        "school": "COMPASS ELEMENTARY",
        "district": "HICKMAN MILLS C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434000651",
    },
    {
        "school": "DOBBS ELEM.",
        "district": "HICKMAN MILLS C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434000652",
    },
    {
        "school": "INGELS ELEM.",
        "district": "HICKMAN MILLS C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434000655",
    },
    {
        "school": "MILLENNIUM AT SANTE FE",
        "district": "HICKMAN MILLS C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434000659",
    },
    {
        "school": "TRUMAN ELEM.",
        "district": "HICKMAN MILLS C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434000663",
    },
    {
        "school": "WARFORD ELEM.",
        "district": "HICKMAN MILLS C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434000664",
    },
    {
        "school": "CRITTENTON TREATMENT CENTER",
        "district": "HICKMAN MILLS C-1",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434002287",
    },
    {
        "school": "THOMAS HART BENTON ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000707",
    },
    {
        "school": "BLACKBURN ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000708",
    },
    {
        "school": "BRIDGER MIDDLE",
        "district": "INDEPENDENCE 30",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000709",
    },
    {
        "school": "BRYANT ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000710",
    },
    {
        "school": "GLENDALE ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000711",
    },
    {
        "school": "JOHN W. LUFF ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000713",
    },
    {
        "school": "MILL CREEK ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000714",
    },
    {
        "school": "OTT ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000716",
    },
    {
        "school": "PROCTER ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000718",
    },
    {
        "school": "RANDALL ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000719",
    },
    {
        "school": "SPRING BRANCH ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000720",
    },
    {
        "school": "SYCAMORE HILLS ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000721",
    },
    {
        "school": "TRUMAN HIGH",
        "district": "INDEPENDENCE 30",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000722",
    },
    {
        "school": "WILLIAM CHRISMAN HIGH",
        "district": "INDEPENDENCE 30",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000724",
    },
    {
        "school": "WILLIAM SOUTHERN ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000725",
    },
    {
        "school": "DAY TREATMENT",
        "district": "INDEPENDENCE 30",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548000952",
    },
    {
        "school": "HANTHORN EARLY EDUCATION",
        "district": "INDEPENDENCE 30",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548001485",
    },
    {
        "school": "INDEPENDENCE ACADEMY",
        "district": "INDEPENDENCE 30",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291548001707",
    },
    {
        "school": "BINGHAM MIDDLE",
        "district": "INDEPENDENCE 30",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548002339",
    },
    {
        "school": "SANTA FE TRAIL ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548002374",
    },
    {
        "school": "PIONEER RIDGE MIDDLE",
        "district": "INDEPENDENCE 30",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548002807",
    },
    {
        "school": "BORDER STAR MONTESSORI",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000557",
    },
    {
        "school": "FAXON ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000808",
    },
    {
        "school": "CARVER DUAL LANGUAGE SCHOOL",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000818",
    },
    {
        "school": "GARFIELD ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000824",
    },
    {
        "school": "GEORGE MELCHER ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000826",
    },
    {
        "school": "JAMES ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000837",
    },
    {
        "school": "JOHN T. HARTMAN ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000838",
    },
    {
        "school": "CENTRAL HIGH SCHOOL",
        "district": "KANSAS CITY 33",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000840",
    },
    {
        "school": "LINCOLN COLLEGE PREP.",
        "district": "KANSAS CITY 33",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000844",
    },
    {
        "school": "LONGFELLOW ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000848",
    },
    {
        "school": "NORTHEAST HIGH",
        "district": "KANSAS CITY 33",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000860",
    },
    {
        "school": "PASEO ACAD. OF PERFORMING ARTS",
        "district": "KANSAS CITY 33",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000862",
    },
    {
        "school": "PHILLIS WHEATLEY ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000863",
    },
    {
        "school": "PITCHER ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000864",
    },
    {
        "school": "CONTRACT",
        "district": "KANSAS CITY 33",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000865",
    },
    {
        "school": "TROOST ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000879",
    },
    {
        "school": "EAST HIGH SCHOOL",
        "district": "KANSAS CITY 33",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000880",
    },
    {
        "school": "WENDELL PHILLIPS ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000882",
    },
    {
        "school": "WHITTIER ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640000887",
    },
    {
        "school": "AC PREP ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640001718",
    },
    {
        "school": "ROGERS ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640002375",
    },
    {
        "school": "FOREIGN LANGUAGE ACADEMY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640002376",
    },
    {
        "school": "GLADSTONE ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640002529",
    },
    {
        "school": "PRIMITIVO GARCIA ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640002530",
    },
    {
        "school": "B. BANNEKER ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640002602",
    },
    {
        "school": "TRAILWOODS ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640002603",
    },
    {
        "school": "HOLLIDAY MONTESSORI",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640002606",
    },
    {
        "school": "MANUAL CAREER  TECH. CTR.",
        "district": "KANSAS CITY 33",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291640002608",
    },
    {
        "school": "BERNARD C. CAMPBELL MIDDLE",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000222",
    },
    {
        "school": "RICHARDSON ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000523",
    },
    {
        "school": "TRAILRIDGE ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000544",
    },
    {
        "school": "GREENWOOD ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000976",
    },
    {
        "school": "HAZEL GROVE ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000977",
    },
    {
        "school": "LEE'S SUMMIT ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000978",
    },
    {
        "school": "MASON ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000979",
    },
    {
        "school": "MEADOW LANE ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000980",
    },
    {
        "school": "PLEASANT LEA ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000981",
    },
    {
        "school": "PLEASANT LEA MIDDLE",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000982",
    },
    {
        "school": "LEE'S SUMMIT SR. HIGH",
        "district": "LEE'S SUMMIT R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000983",
    },
    {
        "school": "WESTVIEW ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830000984",
    },
    {
        "school": "LEE'S SUMMIT NORTH HIGH",
        "district": "LEE'S SUMMIT R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830001481",
    },
    {
        "school": "CEDAR CREEK ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830001971",
    },
    {
        "school": "PRAIRIE VIEW ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830002291",
    },
    {
        "school": "HIGHLAND PARK ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830002311",
    },
    {
        "school": "GREAT BEGINNINGS EARLY ED CTR.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830002612",
    },
    {
        "school": "HILLTOP SCHOOL",
        "district": "LEE'S SUMMIT R-VII",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291830002614",
    },
    {
        "school": "UNDERWOOD ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830002669",
    },
    {
        "school": "HAWTHORN HILL ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830002775",
    },
    {
        "school": "WOODLAND ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830002776",
    },
    {
        "school": "SUMMIT LAKES MIDDLE",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830002806",
    },
    {
        "school": "LONE JACK ELEM.",
        "district": "LONE JACK C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291923001039",
    },
    {
        "school": "LONE JACK HIGH",
        "district": "LONE JACK C-6",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291923001040",
    },
    {
        "school": "OAK GROVE PRIMARY",
        "district": "OAK GROVE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292301000141",
    },
    {
        "school": "OAK GROVE ELEM.",
        "district": "OAK GROVE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292301001316",
    },
    {
        "school": "OAK GROVE HIGH",
        "district": "OAK GROVE R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292301001317",
    },
    {
        "school": "OAK GROVE MIDDLE",
        "district": "OAK GROVE R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292301001318",
    },
    {
        "school": "BLUE RIDGE ELEM.",
        "district": "RAYTOWN C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607000545",
    },
    {
        "school": "NEW TRAILS EARLY LEARNING CTR.",
        "district": "RAYTOWN C-2",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607000945",
    },
    {
        "school": "HERNDON CAREER CTR.",
        "district": "RAYTOWN C-2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292607001515",
    },
    {
        "school": "EASTWOOD HILLS ELEM.",
        "district": "RAYTOWN C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001518",
    },
    {
        "school": "FLEETRIDGE ELEM.",
        "district": "RAYTOWN C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001519",
    },
    {
        "school": "LAUREL HILLS ELEM.",
        "district": "RAYTOWN C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001520",
    },
    {
        "school": "NORFLEET ELEM.",
        "district": "RAYTOWN C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001521",
    },
    {
        "school": "RAYTOWN MIDDLE",
        "district": "RAYTOWN C-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001523",
    },
    {
        "school": "SOUTH MIDDLE",
        "district": "RAYTOWN C-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001524",
    },
    {
        "school": "RAYTOWN SR. HIGH",
        "district": "RAYTOWN C-2",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001525",
    },
    {
        "school": "RAYTOWN SOUTH SR. HIGH",
        "district": "RAYTOWN C-2",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001526",
    },
    {
        "school": "ROBINSON ELEM.",
        "district": "RAYTOWN C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001528",
    },
    {
        "school": "SOUTHWOOD ELEM.",
        "district": "RAYTOWN C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001530",
    },
    {
        "school": "SPRING VALLEY ELEM.",
        "district": "RAYTOWN C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001531",
    },
    {
        "school": "WESTRIDGE ELEM.",
        "district": "RAYTOWN C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607001532",
    },
    {
        "school": "RAYTOWN EDUCATION CTR.",
        "district": "RAYTOWN C-2",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292607001973",
    },
    {
        "school": "SANTA FE ELEM.",
        "district": "SANTA FE R-X",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290300000012",
    },
    {
        "school": "SANTA FE HIGH",
        "district": "SANTA FE R-X",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290300000013",
    },
    {
        "school": "CONCORDIA ELEM.",
        "district": "CONCORDIA R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291008000321",
    },
    {
        "school": "CONCORDIA HIGH",
        "district": "CONCORDIA R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291008000322",
    },
    {
        "school": "GRANDVIEW ELEM.",
        "district": "LAFAYETTE CO. C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291440000669",
    },
    {
        "school": "LAFAYETTE CO. HIGH",
        "district": "LAFAYETTE CO. C-1",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291440000672",
    },
    {
        "school": "LAFAYETTE CO. MIDDLE",
        "district": "LAFAYETTE CO. C-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291440002596",
    },
    {
        "school": "LESLIE BELL ELEM.",
        "district": "LEXINGTON R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291848000998",
    },
    {
        "school": "LEX LA-RAY TECHNICAL CTR.",
        "district": "LEXINGTON R-V",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291848000999",
    },
    {
        "school": "LEXINGTON MIDDLE",
        "district": "LEXINGTON R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291848001000",
    },
    {
        "school": "LEXINGTON HIGH",
        "district": "LEXINGTON R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291848001001",
    },
    {
        "school": "MCQUERRY ELEMENTARY",
        "district": "ODESSA R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292310001323",
    },
    {
        "school": "ODESSA HIGH",
        "district": "ODESSA R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292310001325",
    },
    {
        "school": "ODESSA MIDDLE",
        "district": "ODESSA R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292310001730",
    },
    {
        "school": "ODESSA UPPER ELEMENTARY",
        "district": "ODESSA R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292310001743",
    },
    {
        "school": "WELLINGTON-NAPOLEON ELEM.",
        "district": "WELLINGTON-NAPOLEON R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293156002198",
    },
    {
        "school": "WELLINGTON-NAPOLEON HIGH",
        "district": "WELLINGTON-NAPOLEON R-IX",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293156002199",
    },
    {
        "school": "NORTH PLATTE ELEM.",
        "district": "NORTH PLATTE CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292283001295",
    },
    {
        "school": "NORTH PLATTE HIGH",
        "district": "NORTH PLATTE CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292283001297",
    },
    {
        "school": "NORTH PLATTE JR. HIGH",
        "district": "NORTH PLATTE CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292283002016",
    },
    {
        "school": "NORTH PLATTE INTERMEDIATE",
        "district": "NORTH PLATTE CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292283002021",
    },
    {
        "school": "PLATTE VALLEY COOP.",
        "district": "NORTH PLATTE CO. R-I",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "292283002817",
    },
    {
        "school": "ENGLISH LANDING ELEM.",
        "district": "PARK HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355000615",
    },
    {
        "school": "ALFRED L. RENNER ELEM.",
        "district": "PARK HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355001366",
    },
    {
        "school": "GRADEN ELEM.",
        "district": "PARK HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355001367",
    },
    {
        "school": "PLAZA MIDDLE",
        "district": "PARK HILL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355001369",
    },
    {
        "school": "LINE CREEK ELEM.",
        "district": "PARK HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355001370",
    },
    {
        "school": "PARK HILL HIGH",
        "district": "PARK HILL",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355001371",
    },
    {
        "school": "SOUTHEAST ELEM.",
        "district": "PARK HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355001372",
    },
    {
        "school": "THOMAS B. CHINN ELEM.",
        "district": "PARK HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355001373",
    },
    {
        "school": "UNION CHAPEL ELEM.",
        "district": "PARK HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355001374",
    },
    {
        "school": "PRAIRIE POINT ELEM.",
        "district": "PARK HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355002025",
    },
    {
        "school": "PARK HILL SOUTH HIGH",
        "district": "PARK HILL",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355002413",
    },
    {
        "school": "CONGRESS MIDDLE",
        "district": "PARK HILL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355002418",
    },
    {
        "school": "RUSSELL JONES ED CENTER",
        "district": "PARK HILL",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355002537",
    },
    {
        "school": "LAKEVIEW MIDDLE",
        "district": "PARK HILL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355002623",
    },
    {
        "school": "BARRY SCH.",
        "district": "PLATTE CO. R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292523001451",
    },
    {
        "school": "PLATTE CITY MIDDLE",
        "district": "PLATTE CO. R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292523001455",
    },
    {
        "school": "PLATTE COUNTY HIGH",
        "district": "PLATTE CO. R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292523001456",
    },
    {
        "school": "DONALD D. SIEGRIST ELEM.",
        "district": "PLATTE CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292523002024",
    },
    {
        "school": "NORTHLAND CAREER CTR.",
        "district": "PLATTE CO. R-III",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292523002298",
    },
    {
        "school": "CENTRAL ELEM.",
        "district": "WEST PLATTE CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293171002218",
    },
    {
        "school": "WEST PLATTE HIGH",
        "district": "WEST PLATTE CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293171002220",
    },
    {
        "school": "ELKHORN ELEMENTARY",
        "district": "EXCELSIOR SPRINGS 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291165000416",
    },
    {
        "school": "HARDIN-CENTRAL ELEM.",
        "district": "HARDIN-CENTRAL C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291368000596",
    },
    {
        "school": "HARDIN-CENTRAL HIGH",
        "district": "HARDIN-CENTRAL C-2",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291368000597",
    },
    {
        "school": "LAWSON MIDDLE",
        "district": "LAWSON R-XIV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291822000961",
    },
    {
        "school": "LAWSON HIGH",
        "district": "LAWSON R-XIV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291822000962",
    },
    {
        "school": "SOUTHWEST ELEM.",
        "district": "LAWSON R-XIV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291822000964",
    },
    {
        "school": "ORRICK ELEM.",
        "district": "ORRICK R-XI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292322001335",
    },
    {
        "school": "ORRICK HIGH",
        "district": "ORRICK R-XI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292322001336",
    },
    {
        "school": "DEAR ELEM.",
        "district": "RICHMOND R-XVI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292648001552",
    },
    {
        "school": "RICHMOND HIGH",
        "district": "RICHMOND R-XVI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292648001554",
    },
    {
        "school": "SUNRISE ELEM.",
        "district": "RICHMOND R-XVI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292648001878",
    },
    {
        "school": "RICHMOND MIDDLE",
        "district": "RICHMOND R-XVI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292648002444",
    },
    {
        "school": "EAST BUCHANAN MIDDLE",
        "district": "EAST BUCHANAN CO. C-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291125002282",
    },
    {
        "school": "EAST BUCHANAN ELEM.",
        "district": "EAST BUCHANAN CO. C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291125000390",
    },
    {
        "school": "EAST BUCHANAN HIGH",
        "district": "EAST BUCHANAN CO. C-1",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291125000391",
    },
    {
        "school": "CAMPBELL ELEM.",
        "district": "CAMPBELL R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290705000179",
    },
    {
        "school": "CAMPBELL HIGH",
        "district": "CAMPBELL R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290705000180",
    },
    {
        "school": "CLARKTON ELEM.",
        "district": "CLARKTON C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290912000268",
    },
    {
        "school": "CLARKTON HIGH",
        "district": "CLARKTON C-4",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290912000269",
    },
    {
        "school": "HOLCOMB ELEM.",
        "district": "HOLCOMB R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291446000677",
    },
    {
        "school": "HOLCOMB HIGH",
        "district": "HOLCOMB R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291446000678",
    },
    {
        "school": "H. BYRON MASTERSON ELEM.",
        "district": "KENNETT 39",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291650000896",
    },
    {
        "school": "KENNETT HIGH",
        "district": "KENNETT 39",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291650000897",
    },
    {
        "school": "KENNETT CAREER  TECH. CTR.",
        "district": "KENNETT 39",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291650000898",
    },
    {
        "school": "DIAGNOSTIC CTR.",
        "district": "KENNETT 39",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "291650000899",
    },
    {
        "school": "SOUTH ELEM.",
        "district": "KENNETT 39",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291650000902",
    },
    {
        "school": "KENNETT MIDDLE",
        "district": "KENNETT 39",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291650002654",
    },
    {
        "school": "EARLY CHILDHOOD CTR.",
        "district": "KENNETT 39",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291650002656",
    },
    {
        "school": "MALDEN LOWER ELEM.",
        "district": "MALDEN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291989001056",
    },
    {
        "school": "MALDEN HIGH",
        "district": "MALDEN R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291989001058",
    },
    {
        "school": "SENATH-HORNERSVILLE MIDDLE SCH",
        "district": "SENATH-HORNERSVILLE C-8",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292787001714",
    },
    {
        "school": "SENATH-HORNERSVILLE ELEM SCH",
        "district": "SENATH-HORNERSVILLE C-8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292787001715",
    },
    {
        "school": "SENATH-HORNERSVILLE HIGH SCHOO",
        "district": "SENATH-HORNERSVILLE C-8",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292787001716",
    },
    {
        "school": "SOUTHLAND ELEM.",
        "district": "SOUTHLAND C-9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292862001769",
    },
    {
        "school": "SOUTHLAND HIGH",
        "district": "SOUTHLAND C-9",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292862001770",
    },
    {
        "school": "BLACK HAWK ELEM.",
        "district": "CLARK CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291638000794",
    },
    {
        "school": "RUNNING FOX ELEM.",
        "district": "CLARK CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291638000796",
    },
    {
        "school": "CLARK CO. HIGH",
        "district": "CLARK CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291638000797",
    },
    {
        "school": "CLARK CO. MIDDLE",
        "district": "CLARK CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291638001656",
    },
    {
        "school": "ADAIR CO. ELEM.",
        "district": "ADAIR CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290579000124",
    },
    {
        "school": "ADAIR CO. HIGH",
        "district": "ADAIR CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290579000125",
    },
    {
        "school": "KIRKSVILLE AREA TECH. CTR.",
        "district": "KIRKSVILLE R-III",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291674000915",
    },
    {
        "school": "KIRKSVILLE SR. HIGH",
        "district": "KIRKSVILLE R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291674000916",
    },
    {
        "school": "RAY MILLER ELEM.",
        "district": "KIRKSVILLE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291674000917",
    },
    {
        "school": "KIRKSVILLE PRIMARY",
        "district": "KIRKSVILLE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291674002219",
    },
    {
        "school": "WILLIAM MATTHEW MIDDLE SCHOOL",
        "district": "KIRKSVILLE R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291674002611",
    },
    {
        "school": "ADAIR CO. ELEM.",
        "district": "ADAIR CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292298001314",
    },
    {
        "school": "ADAIR CO. HIGH",
        "district": "ADAIR CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292298001315",
    },
    {
        "school": "SCHUYLER CO. ELEM.",
        "district": "SCHUYLER CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292766001698",
    },
    {
        "school": "SCHUYLER CO. HIGH",
        "district": "SCHUYLER CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292766001702",
    },
    {
        "school": "EZARD ELEM.",
        "district": "LACLEDE CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291011000323",
    },
    {
        "school": "CONWAY HIGH SCHOOLS",
        "district": "LACLEDE CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291011000324",
    },
    {
        "school": "GASCONADE ELEM.",
        "district": "GASCONADE C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291272000533",
    },
    {
        "school": "JOEL E. BARBER ELEM.",
        "district": "LACLEDE CO. C-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291700000940",
    },
    {
        "school": "LEBANON TECH.  CAREER CTR.",
        "district": "LEBANON R-III",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "291827000970",
    },
    {
        "school": "LEBANON MIDDLE SCHOOL",
        "district": "LEBANON R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291827000971",
    },
    {
        "school": "LEBANON SR. HIGH",
        "district": "LEBANON R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291827000972",
    },
    {
        "school": "MAPLECREST ELEM.",
        "district": "LEBANON R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291827000973",
    },
    {
        "school": "BOSWELL ELEM.",
        "district": "LEBANON R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291827000974",
    },
    {
        "school": "JOE D. ESTHER ELEM.",
        "district": "LEBANON R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291827000975",
    },
    {
        "school": "HILLCREST EDUCATION CENTER",
        "district": "LEBANON R-III",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291827002813",
    },
    {
        "school": "GILLIAM ELEM.",
        "district": "GILLIAM C-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291284000536",
    },
    {
        "school": "Malta Bend Elementary School",
        "district": "MALTA BEND R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291992001059",
    },
    {
        "school": "Malta Bend High School",
        "district": "MALTA BEND R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291992001060",
    },
    {
        "school": "SALINE CO. CAREER CTR.",
        "district": "MARSHALL",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292041001081",
    },
    {
        "school": "BENTON ELEM.",
        "district": "MARSHALL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292041001082",
    },
    {
        "school": "BUEKER MIDDLE",
        "district": "MARSHALL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292041001083",
    },
    {
        "school": "EASTWOOD ELEM.",
        "district": "MARSHALL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292041001084",
    },
    {
        "school": "NORTHWEST ELEM.",
        "district": "MARSHALL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292041001085",
    },
    {
        "school": "MARSHALL SR. HIGH",
        "district": "MARSHALL",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292041001086",
    },
    {
        "school": "SOUTHEAST ELEM.",
        "district": "MARSHALL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292041001087",
    },
    {
        "school": "MIAMI ELEM.",
        "district": "MIAMI R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292084001140",
    },
    {
        "school": "HARDEMAN ELEM.",
        "district": "HARDEMAN R-X",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292733001680",
    },
    {
        "school": "OREARVILLE ELEM.",
        "district": "OREARVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292745001682",
    },
    {
        "school": "ALEXANDER ELEM.",
        "district": "SLATER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292836001749",
    },
    {
        "school": "SLATER HIGH",
        "district": "SLATER",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292836001750",
    },
    {
        "school": "SWEET SPRINGS ELEM.",
        "district": "SWEET SPRINGS R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292988002062",
    },
    {
        "school": "SWEET SPRINGS HIGH",
        "district": "SWEET SPRINGS R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292988002064",
    },
    {
        "school": "NODAWAY-HOLT ELEM.",
        "district": "NODAWAY-HOLT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292256002816",
    },
    {
        "school": "JEFFERSON ELEM.",
        "district": "JEFFERSON C-123",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291620000759",
    },
    {
        "school": "JEFFERSON HIGH",
        "district": "JEFFERSON C-123",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291620000762",
    },
    {
        "school": "EUGENE FIELD ELEM.",
        "district": "MARYVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292049001093",
    },
    {
        "school": "NORTHWEST TECHNICAL SCH.",
        "district": "MARYVILLE R-II",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292049001094",
    },
    {
        "school": "MARYVILLE HIGH",
        "district": "MARYVILLE R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292049001095",
    },
    {
        "school": "MARYVILLE MIDDLE",
        "district": "MARYVILLE R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292049001096",
    },
    {
        "school": "Northeast Nodaway Elementary",
        "district": "NORTHEAST NODAWAY CO. R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292166001190",
    },
    {
        "school": "NORTHEAST NODAWAY HIGH",
        "district": "NORTHEAST NODAWAY CO. R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292166001191",
    },
    {
        "school": "NORTH NODAWAY JR.-SR. HIGH",
        "district": "NORTH NODAWAY CO. R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292169001194",
    },
    {
        "school": "NORTH NODAWAY ELEM.",
        "district": "NORTH NODAWAY CO. R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292169001196",
    },
    {
        "school": "Nodaway-Holt MS/HS",
        "district": "NODAWAY-HOLT R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292256001234",
    },
    {
        "school": "SOUTH NODAWAY ELEM.",
        "district": "SOUTH NODAWAY CO. R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292850001760",
    },
    {
        "school": "SOUTH NODAWAY HIGH",
        "district": "SOUTH NODAWAY CO. R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292850001761",
    },
    {
        "school": "WEST NODAWAY R-I ELEM.",
        "district": "WEST NODAWAY CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293090002135",
    },
    {
        "school": "WEST NODAWAY HIGH",
        "district": "WEST NODAWAY CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293090002136",
    },
    {
        "school": "COMMUNITY ELEM.",
        "district": "COMMUNITY R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291002000318",
    },
    {
        "school": "COMMUNITY HIGH",
        "district": "COMMUNITY R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291002000319",
    },
    {
        "school": "EUGENE FIELD ELEM.",
        "district": "MEXICO 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292081001132",
    },
    {
        "school": "HAWTHORNE ELEM.",
        "district": "MEXICO 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292081001133",
    },
    {
        "school": "MCMILLAN EARLY LEARNING CENTER",
        "district": "MEXICO 59",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292081001134",
    },
    {
        "school": "DAVIS H. HART CAREER CTR.",
        "district": "MEXICO 59",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292081001135",
    },
    {
        "school": "MEXICO MIDDLE",
        "district": "MEXICO 59",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292081001136",
    },
    {
        "school": "MEXICO HIGH",
        "district": "MEXICO 59",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292081001137",
    },
    {
        "school": "VAN-FAR JR./SR. HIGH",
        "district": "VAN-FAR R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293078002124",
    },
    {
        "school": "VAN-FAR ELEM.",
        "district": "VAN-FAR R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293078002125",
    },
    {
        "school": "HIGBEE ELEM.",
        "district": "HIGBEE R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291437000666",
    },
    {
        "school": "HIGBEE HIGH",
        "district": "HIGBEE R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291437000667",
    },
    {
        "school": "MOBERLY SR. HIGH",
        "district": "MOBERLY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292110001154",
    },
    {
        "school": "MOBERLY AREA TECHNICAL CTR.",
        "district": "MOBERLY",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292110001156",
    },
    {
        "school": "NORTH PARK ELEM.",
        "district": "MOBERLY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292110001157",
    },
    {
        "school": "SOUTH PARK ELEM.",
        "district": "MOBERLY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292110001158",
    },
    {
        "school": "NORTH CENTRAL REGIONAL",
        "district": "MOBERLY",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292110001853",
    },
    {
        "school": "MOBERLY MIDDLE",
        "district": "MOBERLY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292110002561",
    },
    {
        "school": "GRATZ BROWN ELEM.",
        "district": "MOBERLY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292110002820",
    },
    {
        "school": "NORTHEAST HIGH",
        "district": "NORTHEAST RANDOLPH CO. R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292286001299",
    },
    {
        "school": "NORTHEAST ELEM.",
        "district": "NORTHEAST RANDOLPH CO. R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292286002536",
    },
    {
        "school": "RENICK ELEM.",
        "district": "RENICK R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292619001537",
    },
    {
        "school": "WESTRAN ELEM.",
        "district": "WESTRAN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293186002230",
    },
    {
        "school": "WESTRAN HIGH",
        "district": "WESTRAN R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293186002232",
    },
    {
        "school": "WESTRAN MIDDLE",
        "district": "WESTRAN R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293186002514",
    },
    {
        "school": "NEELYVILLE HIGH",
        "district": "NEELYVILLE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292175001200",
    },
    {
        "school": "HILLVIEW ELEM.",
        "district": "NEELYVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292175001201",
    },
    {
        "school": "NEELYVILLE ELEM.",
        "district": "NEELYVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292175001202",
    },
    {
        "school": "POPLAR BLUFF TECH. CAREER CTR.",
        "district": "POPLAR BLUFF R-I",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292545001466",
    },
    {
        "school": "EUGENE FIELD ELEM.",
        "district": "POPLAR BLUFF R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292545001467",
    },
    {
        "school": "POPLAR BLUFF JR. HIGH",
        "district": "POPLAR BLUFF R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292545001469",
    },
    {
        "school": "LAKE ROAD ELEM.",
        "district": "POPLAR BLUFF R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292545001471",
    },
    {
        "school": "POPLAR BLUFF KINDERGARTEN CTR.",
        "district": "POPLAR BLUFF R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292545001472",
    },
    {
        "school": "O'NEAL ELEM.",
        "district": "POPLAR BLUFF R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292545001473",
    },
    {
        "school": "OAK GROVE ELEM.",
        "district": "POPLAR BLUFF R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292545001474",
    },
    {
        "school": "POPLAR BLUFF HIGH",
        "district": "POPLAR BLUFF R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292545001475",
    },
    {
        "school": "POPLAR BLUFF MIDDLE SCHOOL",
        "district": "POPLAR BLUFF R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292545001947",
    },
    {
        "school": "POPLAR BLUFF EARLY CHILDHOOD C",
        "district": "POPLAR BLUFF R-I",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292545002769",
    },
    {
        "school": "FISK ELEMENTARY",
        "district": "TWIN RIVERS R-X",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293052002093",
    },
    {
        "school": "QULIN ELEMENTARY",
        "district": "TWIN RIVERS R-X",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293052002094",
    },
    {
        "school": "TWIN RIVERS HIGH",
        "district": "TWIN RIVERS R-X",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293052002095",
    },
    {
        "school": "CANTON ELEM.",
        "district": "CANTON R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290708000181",
    },
    {
        "school": "CANTON HIGH",
        "district": "CANTON R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290708000182",
    },
    {
        "school": "HIGHLAND JR.-SR. HIGH",
        "district": "LEWIS CO. C-1",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291846000993",
    },
    {
        "school": "HIGHLAND ELEM.",
        "district": "LEWIS CO. C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291846001989",
    },
    {
        "school": "ST. JAMES MIDDLE",
        "district": "ST. JAMES R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292925002840",
    },
    {
        "school": "NEWBURG ELEM.",
        "district": "NEWBURG R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292214001228",
    },
    {
        "school": "NEWBURG HIGH",
        "district": "NEWBURG R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292214001229",
    },
    {
        "school": "PHELPS CO. ELEM.",
        "district": "PHELPS CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292508001439",
    },
    {
        "school": "ROLLA TECHNICAL INST.",
        "district": "ROLLA 31",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292689001630",
    },
    {
        "school": "COL. JOHN B. WYMAN ELEM.",
        "district": "ROLLA 31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292689001631",
    },
    {
        "school": "HARRY S. TRUMAN ELEM.",
        "district": "ROLLA 31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292689001632",
    },
    {
        "school": "ROLLA JR. HIGH",
        "district": "ROLLA 31",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292689001633",
    },
    {
        "school": "MARK TWAIN ELEM.",
        "district": "ROLLA 31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292689001634",
    },
    {
        "school": "ROLLA MIDDLE",
        "district": "ROLLA 31",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292689001635",
    },
    {
        "school": "ROLLA SR. HIGH",
        "district": "ROLLA 31",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292689001636",
    },
    {
        "school": "ROLLA TECHNICAL CTR.",
        "district": "ROLLA 31",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292689002759",
    },
    {
        "school": "ST. JAMES HIGH",
        "district": "ST. JAMES R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292925001872",
    },
    {
        "school": "LUCY WORTHAM JAMES ELEM.",
        "district": "ST. JAMES R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292925001873",
    },
    {
        "school": "MAYSVILLE ELEM.",
        "district": "MAYSVILLE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292055001098",
    },
    {
        "school": "MAYSVILLE JR.-SR. HIGH",
        "district": "MAYSVILLE R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292055001099",
    },
    {
        "school": "OSBORN ELEM.",
        "district": "OSBORN R-O",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292325001337",
    },
    {
        "school": "OSBORN HIGH",
        "district": "OSBORN R-O",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292325001338",
    },
    {
        "school": "STEWARTSVILLE ELEM.",
        "district": "STEWARTSVILLE C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292949002041",
    },
    {
        "school": "STEWARTSVILLE HIGH",
        "district": "STEWARTSVILLE C-2",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292949002042",
    },
    {
        "school": "UNION STAR ELEM.",
        "district": "UNION STAR R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293060002102",
    },
    {
        "school": "UNION STAR HIGH",
        "district": "UNION STAR R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293060002103",
    },
    {
        "school": "AVENUE CITY ELEM.",
        "district": "AVENUE CITY R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290408000037",
    },
    {
        "school": "NORTH ANDREW MIDDLE",
        "district": "NORTH ANDREW CO. R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292271000006",
    },
    {
        "school": "NORTH ANDREW ELEM.",
        "district": "NORTH ANDREW CO. R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292271001250",
    },
    {
        "school": "NORTH ANDREW HIGH",
        "district": "NORTH ANDREW CO. R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292271001251",
    },
    {
        "school": "AMAZONIA ELEM.",
        "district": "SAVANNAH R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292757001688",
    },
    {
        "school": "HELENA ELEM.",
        "district": "SAVANNAH R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292757001689",
    },
    {
        "school": "JOHN GLENN ELEM.",
        "district": "SAVANNAH R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292757001690",
    },
    {
        "school": "SAVANNAH MIDDLE",
        "district": "SAVANNAH R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292757001691",
    },
    {
        "school": "MINNIE CLINE ELEM.",
        "district": "SAVANNAH R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292757001692",
    },
    {
        "school": "SAVANNAH HIGH",
        "district": "SAVANNAH R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292757001693",
    },
    {
        "school": "DEKALB JR.-SR. HIGH",
        "district": "BUCHANAN CO. R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291059000355",
    },
    {
        "school": "RUSHVILLE ELEM.",
        "district": "BUCHANAN CO. R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291059000356",
    },
    {
        "school": "MID-BUCHANAN ELEM.",
        "district": "MID-BUCHANAN CO. R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291194000443",
    },
    {
        "school": "MID-BUCHANAN SR. HIGH",
        "district": "MID-BUCHANAN CO. R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291194000445",
    },
    {
        "school": "BENTON HIGH",
        "district": "ST. JOSEPH",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001644",
    },
    {
        "school": "BODE MIDDLE",
        "district": "ST. JOSEPH",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001646",
    },
    {
        "school": "BUCHANAN CO. ACADEMY",
        "district": "ST. JOSEPH",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001647",
    },
    {
        "school": "CENTRAL HIGH",
        "district": "ST. JOSEPH",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001648",
    },
    {
        "school": "EDISON ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001649",
    },
    {
        "school": "ELLISON ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001650",
    },
    {
        "school": "FIELD ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001652",
    },
    {
        "school": "COLEMAN ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001654",
    },
    {
        "school": "HILLYARD TECHNICAL CTR.",
        "district": "ST. JOSEPH",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292706001655",
    },
    {
        "school": "HOSEA ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001657",
    },
    {
        "school": "HYDE ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001659",
    },
    {
        "school": "LAFAYETTE HIGH",
        "district": "ST. JOSEPH",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001660",
    },
    {
        "school": "LINDBERGH ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001662",
    },
    {
        "school": "MARK TWAIN ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001663",
    },
    {
        "school": "PARKWAY ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001667",
    },
    {
        "school": "PERSHING ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001668",
    },
    {
        "school": "PICKETT ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001669",
    },
    {
        "school": "ROBIDOUX MIDDLE",
        "district": "ST. JOSEPH",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001670",
    },
    {
        "school": "SKAITH ELEM.",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001672",
    },
    {
        "school": "SPRING GARDEN MIDDLE",
        "district": "ST. JOSEPH",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001673",
    },
    {
        "school": "TRUMAN MIDDLE",
        "district": "ST. JOSEPH",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706001674",
    },
    {
        "school": "ALT. RESOURCE CTR.",
        "district": "ST. JOSEPH",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706002445",
    },
    {
        "school": "RIVERBEND SCH.",
        "district": "MERAMEC VALLEY R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292346002864",
    },
    {
        "school": "EARLY LEARNING CENTER",
        "district": "WASHINGTON",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293111002833",
    },
    {
        "school": "RAYMOND  NANCY HODGE ELEM.",
        "district": "FOX C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230003027",
    },
    {
        "school": "DON EARL EARLY CHILDHOOD CTR.",
        "district": "FOX C-6",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230003028",
    },
    {
        "school": "WINDSOR ELEM.",
        "district": "WINDSOR C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293210002868",
    },
    {
        "school": "BOONE ELEM.",
        "district": "TROY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293045002855",
    },
    {
        "school": "LINCOLN ELEM.",
        "district": "TROY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293045002856",
    },
    {
        "school": "EMGE ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002842",
    },
    {
        "school": "OSTMANN ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002843",
    },
    {
        "school": "HERITAGE LANDING",
        "district": "FRANCIS HOWELL R-III",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895003030",
    },
    {
        "school": "TIMBERLAND HIGH",
        "district": "WENTZVILLE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165002844",
    },
    {
        "school": "CROSSROADS ELEM.",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165002845",
    },
    {
        "school": "FRONTIER MIDDLE",
        "district": "WENTZVILLE R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165002869",
    },
    {
        "school": "PRAIRIE VIEW ELEM.",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165002870",
    },
    {
        "school": "WEST MIDDLE",
        "district": "HAZELWOOD",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383002857",
    },
    {
        "school": "ARROWPOINT ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383002858",
    },
    {
        "school": "KIRKWOOD EARLY CHILD. CTR.",
        "district": "KIRKWOOD R-VII",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291677003031",
    },
    {
        "school": "MRH ELEMENTARY",
        "district": "MAPLEWOOD-RICHMOND HEIGHTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292001002860",
    },
    {
        "school": "BERNARD MIDDLE",
        "district": "MEHLVILLE R-IX",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067003032",
    },
    {
        "school": "LUCAS CROSSING ELEM. COMPLEX",
        "district": "NORMANDY SCHOOLS COLLABORATIVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292265002850",
    },
    {
        "school": "ROBERT DRUMMOND ELEM.",
        "district": "PATTONVILLE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292370002848",
    },
    {
        "school": "ROCKWOOD CTR. EARLY CHILD. ED.",
        "district": "ROCKWOOD R-VI",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685002849",
    },
    {
        "school": "FAIRWAY ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685002859",
    },
    {
        "school": "MO School for the Blind - HS",
        "district": "MO SCHOOL FOR THE BLIND",
        "level": "High",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002103038",
    },
    {
        "school": "MO School for the Blind - ELEM",
        "district": "MO SCHOOL FOR THE BLIND",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "290002103039",
    },
    {
        "school": "EARL NANCE SR. ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002853",
    },
    {
        "school": "POTOSI ELEM.",
        "district": "POTOSI R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292550001493",
    },
    {
        "school": "JOHN A. EVANS MIDDLE",
        "district": "POTOSI R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292550001495",
    },
    {
        "school": "POTOSI HIGH",
        "district": "POTOSI R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292550001497",
    },
    {
        "school": "TROJAN INTERMEDIATE",
        "district": "POTOSI R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292550002766",
    },
    {
        "school": "CALEDONIA ELEM.",
        "district": "VALLEY R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293072002118",
    },
    {
        "school": "VALLEY HIGH",
        "district": "VALLEY R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293072002119",
    },
    {
        "school": "KINGSTON HIGH",
        "district": "KINGSTON K-14",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293114001901",
    },
    {
        "school": "KINGSTON ELEM.",
        "district": "KINGSTON K-14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293114002165",
    },
    {
        "school": "KINGSTON MIDDLE",
        "district": "KINGSTON K-14",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293114002708",
    },
    {
        "school": "RICHWOODS ELEM.",
        "district": "RICHWOODS R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293123002167",
    },
    {
        "school": "BOURBON ELEMENTARY SCHOOL",
        "district": "CRAWFORD CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290564000108",
    },
    {
        "school": "BOURBON HIGH SCHOOL",
        "district": "CRAWFORD CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290564000109",
    },
    {
        "school": "BOURBON MIDDLE SCHOOL",
        "district": "CRAWFORD CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290564001699",
    },
    {
        "school": "CUBA MIDDLE",
        "district": "CRAWFORD CO. R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291041000018",
    },
    {
        "school": "CUBA HIGH",
        "district": "CRAWFORD CO. R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291041000341",
    },
    {
        "school": "CUBA ELEM.",
        "district": "CRAWFORD CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291041000342",
    },
    {
        "school": "STEELVILLE ELEM.",
        "district": "STEELVILLE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292943002036",
    },
    {
        "school": "STEELVILLE HIGH",
        "district": "STEELVILLE R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292943002037",
    },
    {
        "school": "STEELVILLE MIDDLE",
        "district": "STEELVILLE R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292943002482",
    },
    {
        "school": "SPRING BLUFF ELEM.",
        "district": "SPRING BLUFF R-XV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291245000509",
    },
    {
        "school": "STRAIN-JAPAN ELEM.",
        "district": "STRAIN-JAPAN R-XVI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291248000510",
    },
    {
        "school": "FRANKLIN CO. ELEM.",
        "district": "FRANKLIN CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291251000511",
    },
    {
        "school": "LONEDELL ELEM.",
        "district": "LONEDELL R-14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291920001038",
    },
    {
        "school": "NEW HAVEN ELEM.",
        "district": "NEW HAVEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292196001224",
    },
    {
        "school": "NEW HAVEN HIGH",
        "district": "NEW HAVEN",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292196001225",
    },
    {
        "school": "NEW HAVEN MIDDLE",
        "district": "NEW HAVEN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292196002732",
    },
    {
        "school": "COLEMAN ELEM.",
        "district": "MERAMEC VALLEY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292346001353",
    },
    {
        "school": "NIKE ELEM.",
        "district": "MERAMEC VALLEY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292346001354",
    },
    {
        "school": "PACIFIC INTERMEDIATE",
        "district": "MERAMEC VALLEY R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292346001355",
    },
    {
        "school": "PACIFIC HIGH",
        "district": "MERAMEC VALLEY R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292346001356",
    },
    {
        "school": "ROBERTSVILLE ELEM.",
        "district": "MERAMEC VALLEY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292346001357",
    },
    {
        "school": "ZITZMAN ELEM.",
        "district": "MERAMEC VALLEY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292346001359",
    },
    {
        "school": "DORIS HOFFMAN EARLY LEARNING C",
        "district": "MERAMEC VALLEY R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292346002278",
    },
    {
        "school": "TRUMAN ELEM.",
        "district": "MERAMEC VALLEY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292346002472",
    },
    {
        "school": "EDGAR MURRAY ELEM.",
        "district": "ST. CLAIR R-XIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292910001862",
    },
    {
        "school": "ST. CLAIR JR. HIGH",
        "district": "ST. CLAIR R-XIII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292910001863",
    },
    {
        "school": "ST. CLAIR HIGH",
        "district": "ST. CLAIR R-XIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292910001864",
    },
    {
        "school": "ST. CLAIR ELEM.",
        "district": "ST. CLAIR R-XIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292910001865",
    },
    {
        "school": "FRANKLIN CO. SPECL. ED. COOP.",
        "district": "ST. CLAIR R-XIII",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "292910002568",
    },
    {
        "school": "SULLIVAN ELEM.",
        "district": "SULLIVAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292976002055",
    },
    {
        "school": "SULLIVAN MIDDLE",
        "district": "SULLIVAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292976002056",
    },
    {
        "school": "SULLIVAN SR. HIGH",
        "district": "SULLIVAN",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292976002057",
    },
    {
        "school": "SULLIVAN PRIMARY",
        "district": "SULLIVAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292976002805",
    },
    {
        "school": "CLARK-VITT ELEM.",
        "district": "UNION R-XI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293057002096",
    },
    {
        "school": "BEAUFORT ELEM.",
        "district": "UNION R-XI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293057002097",
    },
    {
        "school": "CENTRAL ELEM.",
        "district": "UNION R-XI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293057002098",
    },
    {
        "school": "UNION HIGH",
        "district": "UNION R-XI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293057002101",
    },
    {
        "school": "UNION MIDDLE",
        "district": "UNION R-XI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293057002575",
    },
    {
        "school": "FOUR RIVERS CAREER CTR.",
        "district": "WASHINGTON",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "293111002155",
    },
    {
        "school": "CAMPBELLTON ELEM.",
        "district": "WASHINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293111002157",
    },
    {
        "school": "CLEARVIEW ELEM.",
        "district": "WASHINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293111002158",
    },
    {
        "school": "WASHINGTON MIDDLE",
        "district": "WASHINGTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293111002160",
    },
    {
        "school": "LABADIE ELEM.",
        "district": "WASHINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293111002161",
    },
    {
        "school": "WASHINGTON HIGH",
        "district": "WASHINGTON",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293111002163",
    },
    {
        "school": "SOUTH POINT ELEM.",
        "district": "WASHINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293111002164",
    },
    {
        "school": "WASHINGTON WEST ELEM.",
        "district": "WASHINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293111002295",
    },
    {
        "school": "JEFFERSON COLLEGE",
        "district": "JEFFERSON COLLEGE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290000600814",
    },
    {
        "school": "CRYSTAL CITY ELEM.",
        "district": "CRYSTAL CITY 47",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291038000339",
    },
    {
        "school": "CRYSTAL CITY HIGH",
        "district": "CRYSTAL CITY 47",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291038000340",
    },
    {
        "school": "ATHENA ELEM.",
        "district": "DESOTO 73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291050000347",
    },
    {
        "school": "DESOTO JR. HIGH",
        "district": "DESOTO 73",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291050000349",
    },
    {
        "school": "DESOTO SR. HIGH",
        "district": "DESOTO 73",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291050000350",
    },
    {
        "school": "VINELAND ELEM.",
        "district": "DESOTO 73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291050000351",
    },
    {
        "school": "FESTUS ELEM.",
        "district": "FESTUS R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291203000479",
    },
    {
        "school": "FESTUS SR. HIGH",
        "district": "FESTUS R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291203000481",
    },
    {
        "school": "FESTUS MIDDLE",
        "district": "FESTUS R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291203002522",
    },
    {
        "school": "FESTUS INTERMEDIATE",
        "district": "FESTUS R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291203002779",
    },
    {
        "school": "ANTONIA ELEM.",
        "district": "FOX C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230000497",
    },
    {
        "school": "CLYDE HAMRICK ELEM.",
        "district": "FOX C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230000498",
    },
    {
        "school": "FOX ELEM.",
        "district": "FOX C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230000499",
    },
    {
        "school": "FOX MIDDLE",
        "district": "FOX C-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230000500",
    },
    {
        "school": "MERAMEC HEIGHTS ELEM.",
        "district": "FOX C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230000501",
    },
    {
        "school": "RIDGEWOOD MIDDLE",
        "district": "FOX C-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230000502",
    },
    {
        "school": "ROCKPORT HEIGHTS ELEM.",
        "district": "FOX C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230000503",
    },
    {
        "school": "SECKMAN ELEM.",
        "district": "FOX C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230000504",
    },
    {
        "school": "SECKMAN MIDDLE",
        "district": "FOX C-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230000505",
    },
    {
        "school": "FOX SR. HIGH",
        "district": "FOX C-6",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230000506",
    },
    {
        "school": "SHERWOOD ELEM.",
        "district": "FOX C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230000507",
    },
    {
        "school": "RICHARD SIMPSON ELEM.",
        "district": "FOX C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230001019",
    },
    {
        "school": "SECKMAN SR. HIGH",
        "district": "FOX C-6",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230001981",
    },
    {
        "school": "GEORGE GUFFEY ELEM.",
        "district": "FOX C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230002402",
    },
    {
        "school": "LONE DELL ELEM.",
        "district": "FOX C-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230002593",
    },
    {
        "school": "GRANDVIEW ELEM.",
        "district": "GRANDVIEW R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291317000558",
    },
    {
        "school": "GRANDVIEW MIDDLE",
        "district": "GRANDVIEW R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291317001490",
    },
    {
        "school": "GRANDVIEW HIGH",
        "district": "GRANDVIEW R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291317002285",
    },
    {
        "school": "HERCULANEUM HIGH",
        "district": "DUNKLIN R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291425000639",
    },
    {
        "school": "PEVELY ELEM.",
        "district": "DUNKLIN R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291425000641",
    },
    {
        "school": "SENN-THOMAS MIDDLE",
        "district": "DUNKLIN R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291425002399",
    },
    {
        "school": "HILLSBORO ELEM.",
        "district": "HILLSBORO R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291443000673",
    },
    {
        "school": "HILLSBORO MIDDLE ELEM.",
        "district": "HILLSBORO R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291443000674",
    },
    {
        "school": "HILLSBORO HIGH",
        "district": "HILLSBORO R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291443000675",
    },
    {
        "school": "JUVENILE DETENTION CTR.",
        "district": "HILLSBORO R-III",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291443001017",
    },
    {
        "school": "HILLSBORO JR. HIGH",
        "district": "HILLSBORO R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291443002597",
    },
    {
        "school": "HILLSBORO PRIMARY",
        "district": "HILLSBORO R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291443002598",
    },
    {
        "school": "PLATTIN PRIMARY",
        "district": "JEFFERSON CO. R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291623000763",
    },
    {
        "school": "DANBY-RUSH TOWER MIDDLE",
        "district": "JEFFERSON CO. R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291623001722",
    },
    {
        "school": "TELEGRAPH INTERMEDIATE",
        "district": "JEFFERSON CO. R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291623001725",
    },
    {
        "school": "BRENNAN WOODS ELEM.",
        "district": "NORTHWEST R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292289001301",
    },
    {
        "school": "HIGH RIDGE ELEM.",
        "district": "NORTHWEST R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292289001303",
    },
    {
        "school": "HOUSE SPRINGS ELEM.",
        "district": "NORTHWEST R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292289001304",
    },
    {
        "school": "MAPLE GROVE ELEM.",
        "district": "NORTHWEST R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292289001306",
    },
    {
        "school": "MURPHY ELEM.",
        "district": "NORTHWEST R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292289001307",
    },
    {
        "school": "NORTHWEST HIGH",
        "district": "NORTHWEST R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292289001309",
    },
    {
        "school": "NORTHWEST VALLEY SCH.",
        "district": "NORTHWEST R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292289002378",
    },
    {
        "school": "CEDAR SPRINGS ELEM.",
        "district": "NORTHWEST R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292289002564",
    },
    {
        "school": "SUNRISE ELEM.",
        "district": "SUNRISE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292982002060",
    },
    {
        "school": "WINDSOR INTERMEDIATE",
        "district": "WINDSOR C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293210002250",
    },
    {
        "school": "JAMES E. FREER ELEM.",
        "district": "WINDSOR C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293210002251",
    },
    {
        "school": "WINDSOR HIGH",
        "district": "WINDSOR C-1",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293210002253",
    },
    {
        "school": "WINDSOR MIDDLE",
        "district": "WINDSOR C-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293210002653",
    },
    {
        "school": "CLARENCE CANNON ELEM.",
        "district": "ELSBERRY R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291140000406",
    },
    {
        "school": "ELSBERRY HIGH",
        "district": "ELSBERRY R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291140000407",
    },
    {
        "school": "IDA CANNON MIDDLE",
        "district": "ELSBERRY R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291140001990",
    },
    {
        "school": "SILEX ELEM.",
        "district": "SILEX R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292829001747",
    },
    {
        "school": "SILEX HIGH",
        "district": "SILEX R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292829001748",
    },
    {
        "school": "HAWK POINT ELEM.",
        "district": "TROY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293045002087",
    },
    {
        "school": "TROY MIDDLE",
        "district": "TROY R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293045002088",
    },
    {
        "school": "WM. R. CAPPEL ELEM.",
        "district": "TROY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293045002089",
    },
    {
        "school": "TROY BUCHANAN HIGH",
        "district": "TROY R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293045002090",
    },
    {
        "school": "MAIN STREET ELEM.",
        "district": "TROY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293045002574",
    },
    {
        "school": "WINFIELD ELEM.",
        "district": "WINFIELD R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293219002256",
    },
    {
        "school": "WINFIELD HIGH",
        "district": "WINFIELD R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293219002257",
    },
    {
        "school": "WINFIELD INTERMEDIATE",
        "district": "WINFIELD R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293219002545",
    },
    {
        "school": "WINFIELD MIDDLE",
        "district": "WINFIELD R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293219002814",
    },
    {
        "school": "WRIGHT CITY MIDDLE",
        "district": "WRIGHT CITY R-II OF WARREN CO.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293231002576",
    },
    {
        "school": "FOREST PARK ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837000234",
    },
    {
        "school": "JOSEPH L. MUDD ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837000235",
    },
    {
        "school": "LEWIS  CLARK ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837000236",
    },
    {
        "school": "MOUNT HOPE ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837000237",
    },
    {
        "school": "PROGRESS SOUTH ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837000238",
    },
    {
        "school": "FT. ZUMWALT NORTH HIGH",
        "district": "FT. ZUMWALT R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837000239",
    },
    {
        "school": "ST. PETERS ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837000241",
    },
    {
        "school": "TWIN CHIMNEYS ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837000619",
    },
    {
        "school": "DR. BERNARD J. DUBRAY MIDDLE",
        "district": "FT. ZUMWALT R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837001539",
    },
    {
        "school": "ROCK CREEK ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837001883",
    },
    {
        "school": "MID RIVERS ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002038",
    },
    {
        "school": "HAWTHORN ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002369",
    },
    {
        "school": "FT. ZUMWALT SOUTH MIDDLE",
        "district": "FT. ZUMWALT R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002427",
    },
    {
        "school": "FT. ZUMWALT SOUTH HIGH",
        "district": "FT. ZUMWALT R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002490",
    },
    {
        "school": "FT. ZUMWALT NORTH MIDDLE",
        "district": "FT. ZUMWALT R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002491",
    },
    {
        "school": "DARDENNE ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002492",
    },
    {
        "school": "FT. ZUMWALT WEST HIGH",
        "district": "FT. ZUMWALT R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002624",
    },
    {
        "school": "PHEASANT POINT ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002697",
    },
    {
        "school": "FT. ZUWMALT WEST MIDDLE",
        "district": "FT. ZUMWALT R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002782",
    },
    {
        "school": "WESTHOFF ELEM.",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002783",
    },
    {
        "school": "FT. ZUMWALT HOPE HIGH",
        "district": "FT. ZUMWALT R-II",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290837002821",
    },
    {
        "school": "Orchard Farm Elementary",
        "district": "ORCHARD FARM R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292316001329",
    },
    {
        "school": "Orchard Farm Middle School",
        "district": "ORCHARD FARM R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292316001330",
    },
    {
        "school": "Orchard Farm High School",
        "district": "ORCHARD FARM R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292316001331",
    },
    {
        "school": "GEORGE M. NULL ELEM.",
        "district": "ST. CHARLES R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292892001840",
    },
    {
        "school": "JEFFERSON INTERMEDIATE SCHOOL",
        "district": "ST. CHARLES R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292892001841",
    },
    {
        "school": "LEWIS  CLARK CAREER CTR.",
        "district": "ST. CHARLES R-VI",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292892001842",
    },
    {
        "school": "LINCOLN ELEM.",
        "district": "ST. CHARLES R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292892001843",
    },
    {
        "school": "COVERDELL ELEM.",
        "district": "ST. CHARLES R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292892001844",
    },
    {
        "school": "MONROE ELEM.",
        "district": "ST. CHARLES R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292892001846",
    },
    {
        "school": "ST. CHARLES HIGH",
        "district": "ST. CHARLES R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292892001848",
    },
    {
        "school": "HARDIN MIDDLE",
        "district": "ST. CHARLES R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292892001850",
    },
    {
        "school": "ST. CHARLES WEST HIGH",
        "district": "ST. CHARLES R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292892001851",
    },
    {
        "school": "HARRIS ELEM.",
        "district": "ST. CHARLES R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292892001852",
    },
    {
        "school": "FRANCIS HOWELL MIDDLE",
        "district": "FRANCIS HOWELL R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895000220",
    },
    {
        "school": "EARLY CHILD. FAMILY EDUC. CTR.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895000643",
    },
    {
        "school": "BECKY-DAVID ELEM.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895001854",
    },
    {
        "school": "HOLLENBECK MIDDLE",
        "district": "FRANCIS HOWELL R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895001855",
    },
    {
        "school": "CASTLIO ELEM.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895001856",
    },
    {
        "school": "CENTRAL ELEM.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895001857",
    },
    {
        "school": "DANIEL BOONE ELEM.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895001858",
    },
    {
        "school": "FAIRMOUNT ELEM.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895001859",
    },
    {
        "school": "FRANCIS HOWELL HIGH",
        "district": "FRANCIS HOWELL R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895001860",
    },
    {
        "school": "SAEGER MIDDLE",
        "district": "FRANCIS HOWELL R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895001884",
    },
    {
        "school": "FRANCIS HOWELL UNION HIGH",
        "district": "FRANCIS HOWELL R-III",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292895002063",
    },
    {
        "school": "FRANCIS HOWELL CENTRAL HIGH",
        "district": "FRANCIS HOWELL R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895002072",
    },
    {
        "school": "EARLY CHILD. FAMILY EDUC. CTR.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895002077",
    },
    {
        "school": "EARLY CHILD. FAMILY EDUC. CTR.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895002108",
    },
    {
        "school": "BARNWELL MIDDLE",
        "district": "FRANCIS HOWELL R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895002307",
    },
    {
        "school": "HENDERSON ELEM.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895002447",
    },
    {
        "school": "FRANCIS HOWELL NORTH HIGH",
        "district": "FRANCIS HOWELL R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895002481",
    },
    {
        "school": "JOHN WELDON ELEM.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895002666",
    },
    {
        "school": "HARVEST RIDGE ELEM.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895002681",
    },
    {
        "school": "BRYAN MIDDLE",
        "district": "FRANCIS HOWELL R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895002698",
    },
    {
        "school": "INDEPENDENCE ELEM.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895002761",
    },
    {
        "school": "WARREN ELEM.",
        "district": "FRANCIS HOWELL R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292895002822",
    },
    {
        "school": "AUGUSTA ELEM.",
        "district": "WASHINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293111002156",
    },
    {
        "school": "WENTZVILLE SOUTH MIDDLE",
        "district": "WENTZVILLE R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165001036",
    },
    {
        "school": "GREEN TREE ELEM.",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165002110",
    },
    {
        "school": "HERITAGE PRIMARY",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165002207",
    },
    {
        "school": "EMIL E. HOLT SR. HIGH",
        "district": "WENTZVILLE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165002208",
    },
    {
        "school": "WENTZVILLE MIDDLE",
        "district": "WENTZVILLE R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165002209",
    },
    {
        "school": "HERITAGE INTERMEDIATE",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165002456",
    },
    {
        "school": "BOONE TRAIL ELEM.",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165002652",
    },
    {
        "school": "GOTSCH INTERMEDIATE SCH.",
        "district": "AFFTON 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290291000005",
    },
    {
        "school": "MESNIER PRIMARY SCH.",
        "district": "AFFTON 101",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290291000007",
    },
    {
        "school": "AFFTON HIGH",
        "district": "AFFTON 101",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290291000009",
    },
    {
        "school": "ROGERS MIDDLE",
        "district": "AFFTON 101",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290291002461",
    },
    {
        "school": "BAYLESS ELEMENTARY",
        "district": "BAYLESS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290450000043",
    },
    {
        "school": "BAYLESS SENIOR HIGH",
        "district": "BAYLESS",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290450000044",
    },
    {
        "school": "BAYLESS JUNIOR HIGH",
        "district": "BAYLESS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290450000715",
    },
    {
        "school": "BRENTWOOD HIGH",
        "district": "BRENTWOOD",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290588000131",
    },
    {
        "school": "MARK TWAIN ELEM.",
        "district": "BRENTWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290588000132",
    },
    {
        "school": "MCGRATH ELEM.",
        "district": "BRENTWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290588000133",
    },
    {
        "school": "BRENTWOOD MIDDLE",
        "district": "BRENTWOOD",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290588001113",
    },
    {
        "school": "GLENRIDGE ELEM.",
        "district": "CLAYTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290972000271",
    },
    {
        "school": "MERAMEC ELEM.",
        "district": "CLAYTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290972000273",
    },
    {
        "school": "RALPH M. CAPTAIN ELEM.",
        "district": "CLAYTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290972000274",
    },
    {
        "school": "CLAYTON HIGH",
        "district": "CLAYTON",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290972000275",
    },
    {
        "school": "FAMILY CTR.",
        "district": "CLAYTON",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290972002583",
    },
    {
        "school": "WYDOWN MIDDLE",
        "district": "CLAYTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290972002584",
    },
    {
        "school": "CROSS KEYS MIDDLE",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000301",
    },
    {
        "school": "BERMUDA ELEMENTARY",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000452",
    },
    {
        "school": "CENTRAL ELEMENTARY",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000454",
    },
    {
        "school": "COMBS ELEMENTARY",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000455",
    },
    {
        "school": "COMMONS LANE ELEMENTARY",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000456",
    },
    {
        "school": "DUCHESNE ELEMENTARY",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000460",
    },
    {
        "school": "FERGUSON MIDDLE",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000462",
    },
    {
        "school": "GRIFFITH ELEMENTARY",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000466",
    },
    {
        "school": "HALLS FERRY ELEMENTARY",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000467",
    },
    {
        "school": "HOLMAN ELEMENTARY",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000468",
    },
    {
        "school": "LEE HAMILTON ELEMENTARY",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000469",
    },
    {
        "school": "MCCLUER NORTH HIGH",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000471",
    },
    {
        "school": "MCCLUER HIGH",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000472",
    },
    {
        "school": "PARKER ROAD ELEMENTARY",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000473",
    },
    {
        "school": "ROBINWOOD ELEMENTARY",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000475",
    },
    {
        "school": "WALNUT GROVE ELEM.",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000477",
    },
    {
        "school": "WEDGWOOD SCHOOL",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201000478",
    },
    {
        "school": "EARLY EDUCATION CENTER",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201002591",
    },
    {
        "school": "STEAM ACADEMY AT MSB HIGH SCHO",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201002691",
    },
    {
        "school": "JOHNSON WABASH SCHOOL",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201002784",
    },
    {
        "school": "HANCOCK SR. HIGH",
        "district": "HANCOCK PLACE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291362000583",
    },
    {
        "school": "HANCOCK PLACE ELEM.",
        "district": "HANCOCK PLACE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291362000584",
    },
    {
        "school": "HANCOCK PLACE MIDDLE",
        "district": "HANCOCK PLACE",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291362001894",
    },
    {
        "school": "BARRINGTON ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000447",
    },
    {
        "school": "ARMSTRONG ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000613",
    },
    {
        "school": "KEEVEN ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000614",
    },
    {
        "school": "BROWN ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000616",
    },
    {
        "school": "LAWSON ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000617",
    },
    {
        "school": "COLD WATER ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000618",
    },
    {
        "school": "GARRETT ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000620",
    },
    {
        "school": "GRANNEMANN ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000621",
    },
    {
        "school": "HAZELWOOD CENTRAL HIGH",
        "district": "HAZELWOOD",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000622",
    },
    {
        "school": "NORTHWEST MIDDLE",
        "district": "HAZELWOOD",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000624",
    },
    {
        "school": "HAZELWOOD WEST HIGH",
        "district": "HAZELWOOD",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000625",
    },
    {
        "school": "JAMESTOWN ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000626",
    },
    {
        "school": "JANA ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000627",
    },
    {
        "school": "JURY ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000628",
    },
    {
        "school": "EAST MIDDLE",
        "district": "HAZELWOOD",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000629",
    },
    {
        "school": "LARIMORE ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000630",
    },
    {
        "school": "LUSHER ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000631",
    },
    {
        "school": "MCCURDY ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000632",
    },
    {
        "school": "MCNAIR ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000633",
    },
    {
        "school": "RUSSELL ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000634",
    },
    {
        "school": "TOWNSEND ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000635",
    },
    {
        "school": "TWILLMAN ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000636",
    },
    {
        "school": "WALKER ELEM.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383000637",
    },
    {
        "school": "ELEM. SPECIAL PROGRAMS DEPT.",
        "district": "HAZELWOOD",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "291383000650",
    },
    {
        "school": "HAZELWOOD EAST HIGH",
        "district": "HAZELWOOD",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383002696",
    },
    {
        "school": "FAIRVIEW PRIMARY",
        "district": "JENNINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291629000766",
    },
    {
        "school": "JENNINGS JR. HIGH",
        "district": "JENNINGS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291629000767",
    },
    {
        "school": "NORTHVIEW ELEM.",
        "district": "JENNINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291629000768",
    },
    {
        "school": "JENNINGS HIGH",
        "district": "JENNINGS",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291629000769",
    },
    {
        "school": "WOODLAND ELEM.",
        "district": "JENNINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291629000770",
    },
    {
        "school": "KENNETH C. HANRAHAN ELEM.",
        "district": "JENNINGS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291629002786",
    },
    {
        "school": "F. P. TILLMAN ELEM.",
        "district": "KIRKWOOD R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291677000920",
    },
    {
        "school": "GEORGE R. ROBINSON ELEM.",
        "district": "KIRKWOOD R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291677000921",
    },
    {
        "school": "NIPHER MIDDLE",
        "district": "KIRKWOOD R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291677000923",
    },
    {
        "school": "NORTH GLENDALE ELEM.",
        "district": "KIRKWOOD R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291677000924",
    },
    {
        "school": "NORTH KIRKWOOD MIDDLE",
        "district": "KIRKWOOD R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291677000925",
    },
    {
        "school": "KIRKWOOD SR. HIGH",
        "district": "KIRKWOOD R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291677000926",
    },
    {
        "school": "W. W. KEYSOR ELEM.",
        "district": "KIRKWOOD R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291677000927",
    },
    {
        "school": "WESTCHESTER ELEM.",
        "district": "KIRKWOOD R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291677000928",
    },
    {
        "school": "CONWAY ELEM.",
        "district": "LADUE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291782000942",
    },
    {
        "school": "LADUE MIDDLE",
        "district": "LADUE",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291782000944",
    },
    {
        "school": "LADUE HORTON WATKINS HIGH",
        "district": "LADUE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291782000946",
    },
    {
        "school": "OLD BONHOMME ELEM.",
        "district": "LADUE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291782000947",
    },
    {
        "school": "REED ELEM.",
        "district": "LADUE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291782000949",
    },
    {
        "school": "SPOEDE ELEM.",
        "district": "LADUE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291782000950",
    },
    {
        "school": "CRESTWOOD ELEM.",
        "district": "LINDBERGH SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291869001018",
    },
    {
        "school": "KENNERLY ELEM.",
        "district": "LINDBERGH SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291869001021",
    },
    {
        "school": "LONG ELEM.",
        "district": "LINDBERGH SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291869001022",
    },
    {
        "school": "ROBERT H. SPERRENG MIDDLE",
        "district": "LINDBERGH SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291869001024",
    },
    {
        "school": "SAPPINGTON ELEM.",
        "district": "LINDBERGH SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291869001025",
    },
    {
        "school": "LINDBERGH SR. HIGH",
        "district": "LINDBERGH SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291869001026",
    },
    {
        "school": "CONCORD ELEM. SCHOOL",
        "district": "LINDBERGH SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291869002468",
    },
    {
        "school": "MAPLEWOOD-RICHMOND HGTS. HIGH",
        "district": "MAPLEWOOD-RICHMOND HEIGHTS",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292001001067",
    },
    {
        "school": "MRH EARLY CHILDHOOD CENTER",
        "district": "MAPLEWOOD-RICHMOND HEIGHTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292001001068",
    },
    {
        "school": "MRH MIDDLE",
        "district": "MAPLEWOOD-RICHMOND HEIGHTS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292001001895",
    },
    {
        "school": "HAGEMANN ELEM.",
        "district": "MEHLVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001097",
    },
    {
        "school": "BEASLEY ELEM.",
        "district": "MEHLVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001109",
    },
    {
        "school": "BIERBAUM ELEM.",
        "district": "MEHLVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001111",
    },
    {
        "school": "BLADES ELEM.",
        "district": "MEHLVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001112",
    },
    {
        "school": "MARGARET BUERKLE MIDDLE",
        "district": "MEHLVILLE R-IX",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001114",
    },
    {
        "school": "MEHLVILLE HIGH SCHOOL",
        "district": "MEHLVILLE R-IX",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001115",
    },
    {
        "school": "OAKVILLE ELEM.",
        "district": "MEHLVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001116",
    },
    {
        "school": "OAKVILLE MIDDLE",
        "district": "MEHLVILLE R-IX",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001117",
    },
    {
        "school": "OAKVILLE SR. HIGH",
        "district": "MEHLVILLE R-IX",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001118",
    },
    {
        "school": "POINT ELEM.",
        "district": "MEHLVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001119",
    },
    {
        "school": "TRAUTWEIN ELEM.",
        "district": "MEHLVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001121",
    },
    {
        "school": "WASHINGTON MIDDLE",
        "district": "MEHLVILLE R-IX",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001123",
    },
    {
        "school": "WOHLWEND ELEM.",
        "district": "MEHLVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067001124",
    },
    {
        "school": "FORDER ELEM.",
        "district": "MEHLVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067002420",
    },
    {
        "school": "ROGERS ELEM.",
        "district": "MEHLVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067002683",
    },
    {
        "school": "JEFFERSON ELEM.",
        "district": "NORMANDY SCHOOLS COLLABORATIVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292265001243",
    },
    {
        "school": "NORMANDY HIGH",
        "district": "NORMANDY SCHOOLS COLLABORATIVE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292265001248",
    },
    {
        "school": "WASHINGTON ELEM.",
        "district": "NORMANDY SCHOOLS COLLABORATIVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292265001249",
    },
    {
        "school": "BARRETTS ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001375",
    },
    {
        "school": "BELLERIVE ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001376",
    },
    {
        "school": "CARMAN TRAILS ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001377",
    },
    {
        "school": "CENTRAL HIGH",
        "district": "PARKWAY C-2",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001379",
    },
    {
        "school": "CLAYMONT ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001380",
    },
    {
        "school": "CRAIG ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001382",
    },
    {
        "school": "GREEN TRAILS ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001385",
    },
    {
        "school": "HANNA WOODS ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001386",
    },
    {
        "school": "HENRY ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001387",
    },
    {
        "school": "HIGHCROFT RIDGE ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001388",
    },
    {
        "school": "MASON RIDGE ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001390",
    },
    {
        "school": "MCKELVEY ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001391",
    },
    {
        "school": "NORTH HIGH",
        "district": "PARKWAY C-2",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001393",
    },
    {
        "school": "SOUTH HIGH",
        "district": "PARKWAY C-2",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001394",
    },
    {
        "school": "PIERREMONT ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001395",
    },
    {
        "school": "RIVER BEND ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001396",
    },
    {
        "school": "ROSS ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001398",
    },
    {
        "school": "SHENANDOAH VALLEY ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001399",
    },
    {
        "school": "SORRENTO SPRINGS ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001400",
    },
    {
        "school": "WEST HIGH",
        "district": "PARKWAY C-2",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001404",
    },
    {
        "school": "WREN HOLLOW ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001405",
    },
    {
        "school": "SOUTHWEST MIDDLE",
        "district": "PARKWAY C-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001540",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "PARKWAY C-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001547",
    },
    {
        "school": "NORTHEAST MIDDLE",
        "district": "PARKWAY C-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001549",
    },
    {
        "school": "SOUTH MIDDLE",
        "district": "PARKWAY C-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001553",
    },
    {
        "school": "WEST MIDDLE",
        "district": "PARKWAY C-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358001555",
    },
    {
        "school": "OAK BROOK ELEM.",
        "district": "PARKWAY C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358002626",
    },
    {
        "school": "PATTONVILLE Early CHol",
        "district": "PATTONVILLE R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292370000656",
    },
    {
        "school": "BRIDGEWAY ELEM.",
        "district": "PATTONVILLE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292370001412",
    },
    {
        "school": "HOLMAN MIDDLE",
        "district": "PATTONVILLE R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292370001415",
    },
    {
        "school": "PARKWOOD ELEM.",
        "district": "PATTONVILLE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292370001416",
    },
    {
        "school": "PATTONVILLE HEIGHTS MIDDLE",
        "district": "PATTONVILLE R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292370001417",
    },
    {
        "school": "TRADITIONAL SCH.",
        "district": "PATTONVILLE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292370001419",
    },
    {
        "school": "ROSE ACRES ELEM.",
        "district": "PATTONVILLE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292370001420",
    },
    {
        "school": "PATTONVILLE SR. HIGH",
        "district": "PATTONVILLE R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292370001421",
    },
    {
        "school": "WILLOW BROOK ELEM.",
        "district": "PATTONVILLE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292370001423",
    },
    {
        "school": "HOECH MIDDLE",
        "district": "RITENOUR",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292664001567",
    },
    {
        "school": "IVELAND ELEM.",
        "district": "RITENOUR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292664001568",
    },
    {
        "school": "KRATZ ELEM.",
        "district": "RITENOUR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292664001569",
    },
    {
        "school": "MARION ELEM.",
        "district": "RITENOUR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292664001570",
    },
    {
        "school": "MARVIN ELEM.",
        "district": "RITENOUR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292664001571",
    },
    {
        "school": "RITENOUR MIDDLE",
        "district": "RITENOUR",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292664001572",
    },
    {
        "school": "RITENOUR SR. HIGH",
        "district": "RITENOUR",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292664001573",
    },
    {
        "school": "WYLAND ELEM.",
        "district": "RITENOUR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292664001575",
    },
    {
        "school": "BUDER ELEM.",
        "district": "RITENOUR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292664002473",
    },
    {
        "school": "GIBSON ELEM.",
        "district": "RIVERVIEW GARDENS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667000726",
    },
    {
        "school": "DANFORTH ELEM.",
        "district": "RIVERVIEW GARDENS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667001577",
    },
    {
        "school": "GLASGOW ELEM.",
        "district": "RIVERVIEW GARDENS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667001579",
    },
    {
        "school": "KOCH ELEM.",
        "district": "RIVERVIEW GARDENS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667001581",
    },
    {
        "school": "LEMASTERS ELEM.",
        "district": "RIVERVIEW GARDENS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667001582",
    },
    {
        "school": "LEWIS AND CLARK ELEM.",
        "district": "RIVERVIEW GARDENS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667001583",
    },
    {
        "school": "MEADOWS ELEM.",
        "district": "RIVERVIEW GARDENS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667001584",
    },
    {
        "school": "RIVERVIEW GARDENS SR. HIGH",
        "district": "RIVERVIEW GARDENS",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667001586",
    },
    {
        "school": "R. G. CENTRAL MIDDLE",
        "district": "RIVERVIEW GARDENS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667002539",
    },
    {
        "school": "HIGHLAND ELEM.",
        "district": "RIVERVIEW GARDENS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667002627",
    },
    {
        "school": "WESTVIEW MIDDLE",
        "district": "RIVERVIEW GARDENS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667002687",
    },
    {
        "school": "MOLINE ELEM.",
        "district": "RIVERVIEW GARDENS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667002701",
    },
    {
        "school": "EARLY CHILD. EDUCATION",
        "district": "RIVERVIEW GARDENS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292667002765",
    },
    {
        "school": "ACKERMAN SCH.",
        "district": "SPECL. SCH. DST. ST. LOUIS CO.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292676001588",
    },
    {
        "school": "LITZSINGER",
        "district": "SPECL. SCH. DST. ST. LOUIS CO.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292676001599",
    },
    {
        "school": "NORTH TECHNICAL",
        "district": "SPECL. SCH. DST. ST. LOUIS CO.",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292676001604",
    },
    {
        "school": "SOUTH TECHNICAL",
        "district": "SPECL. SCH. DST. ST. LOUIS CO.",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292676001607",
    },
    {
        "school": "SOUTHVIEW",
        "district": "SPECL. SCH. DST. ST. LOUIS CO.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292676001608",
    },
    {
        "school": "EXTERNAL SITES",
        "district": "SPECL. SCH. DST. ST. LOUIS CO.",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292676002628",
    },
    {
        "school": "JUVENILE DETENTION CTR.",
        "district": "SPECL. SCH. DST. ST. LOUIS CO.",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292676002630",
    },
    {
        "school": "NORTHVIEW",
        "district": "SPECL. SCH. DST. ST. LOUIS CO.",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292676002632",
    },
    {
        "school": "MARQUETTE SR. HIGH",
        "district": "ROCKWOOD R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685000657",
    },
    {
        "school": "ROCKWOOD SUMMIT SR. HIGH",
        "district": "ROCKWOOD R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685000665",
    },
    {
        "school": "CRESTVIEW MIDDLE",
        "district": "ROCKWOOD R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685000670",
    },
    {
        "school": "LASALLE SPRINGS MIDDLE",
        "district": "ROCKWOOD R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685000671",
    },
    {
        "school": "ROCKWOOD SOUTH MIDDLE",
        "district": "ROCKWOOD R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685000706",
    },
    {
        "school": "SELVIDGE MIDDLE",
        "district": "ROCKWOOD R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685000712",
    },
    {
        "school": "BALLWIN ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001614",
    },
    {
        "school": "BOWLES ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001615",
    },
    {
        "school": "CHESTERFIELD ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001616",
    },
    {
        "school": "ELLISVILLE ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001618",
    },
    {
        "school": "EUREKA ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001619",
    },
    {
        "school": "EUREKA SR. HIGH",
        "district": "ROCKWOOD R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001621",
    },
    {
        "school": "GEGGIE ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001622",
    },
    {
        "school": "KELLISON ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001623",
    },
    {
        "school": "LAFAYETTE SR. HIGH",
        "district": "ROCKWOOD R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001624",
    },
    {
        "school": "POND ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001626",
    },
    {
        "school": "STANTON ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001627",
    },
    {
        "school": "WESTRIDGE ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001628",
    },
    {
        "school": "WOERTHER ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685001629",
    },
    {
        "school": "GREEN PINES ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685002478",
    },
    {
        "school": "RIDGE MEADOWS ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685002507",
    },
    {
        "school": "BABLER ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685002566",
    },
    {
        "school": "KEHRS MILL ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685002567",
    },
    {
        "school": "UTHOFF VALLEY ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685002637",
    },
    {
        "school": "ROCKWOOD VALLEY MIDDLE",
        "district": "ROCKWOOD R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685002688",
    },
    {
        "school": "CENTER FOR CREATIVE LEARNING",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292685002689",
    },
    {
        "school": "WILD HORSE ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685002700",
    },
    {
        "school": "BLEVINS ELEM.",
        "district": "ROCKWOOD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685002762",
    },
    {
        "school": "WILDWOOD MIDDLE",
        "district": "ROCKWOOD R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292685002785",
    },
    {
        "school": "JULIA GOLDSTEIN EARLY CHILD.",
        "district": "UNIVERSITY CITY",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293066001898",
    },
    {
        "school": "BARBARA JORDAN ELEM.",
        "district": "UNIVERSITY CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293066002105",
    },
    {
        "school": "FLYNN PARK ELEM.",
        "district": "UNIVERSITY CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293066002107",
    },
    {
        "school": "JACKSON PARK ELEM.",
        "district": "UNIVERSITY CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293066002109",
    },
    {
        "school": "PERSHING ELEM.",
        "district": "UNIVERSITY CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293066002112",
    },
    {
        "school": "UNIVERSITY CITY SR. HIGH",
        "district": "UNIVERSITY CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293066002113",
    },
    {
        "school": "BRITTANY WOODS",
        "district": "UNIVERSITY CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293066002511",
    },
    {
        "school": "VALLEY PARK MIDDLE",
        "district": "VALLEY PARK",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293069001557",
    },
    {
        "school": "VALLEY PARK ELEM.",
        "district": "VALLEY PARK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293069002115",
    },
    {
        "school": "VALLEY PARK SR. HIGH",
        "district": "VALLEY PARK",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293069002116",
    },
    {
        "school": "AVERY ELEM.",
        "district": "WEBSTER GROVES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293153002190",
    },
    {
        "school": "BRISTOL ELEM.",
        "district": "WEBSTER GROVES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293153002191",
    },
    {
        "school": "CLARK ELEM.",
        "district": "WEBSTER GROVES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293153002192",
    },
    {
        "school": "EDGAR ROAD ELEM.",
        "district": "WEBSTER GROVES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293153002193",
    },
    {
        "school": "HIXSON MIDDLE",
        "district": "WEBSTER GROVES",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293153002194",
    },
    {
        "school": "STEGER SIXTH GRADE CTR.",
        "district": "WEBSTER GROVES",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293153002195",
    },
    {
        "school": "WEBSTER GROVES HIGH",
        "district": "WEBSTER GROVES",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293153002197",
    },
    {
        "school": "HUDSON ELEM.",
        "district": "WEBSTER GROVES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293153002417",
    },
    {
        "school": "DR. HENRY GIVENS JR. ELEM.",
        "district": "WEBSTER GROVES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293153002486",
    },
    {
        "school": "WALTER AMBROSE FAMILY CENTER",
        "district": "WEBSTER GROVES",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293153002651",
    },
    {
        "school": "DANIEL BOONE ELEM.",
        "district": "WARREN CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293105002149",
    },
    {
        "school": "WARRENTON HIGH",
        "district": "WARREN CO. R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293105002151",
    },
    {
        "school": "REBECCA BOONE ELEM.",
        "district": "WARREN CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293105002416",
    },
    {
        "school": "BLACK HAWK MIDDLE",
        "district": "WARREN CO. R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293105002649",
    },
    {
        "school": "MARTHASVILLE ELEM.",
        "district": "WASHINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293111002162",
    },
    {
        "school": "WRIGHT CITY WEST ELEM.",
        "district": "WRIGHT CITY R-II OF WARREN CO.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293231002265",
    },
    {
        "school": "WRIGHT CITY HIGH",
        "district": "WRIGHT CITY R-II OF WARREN CO.",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293231002266",
    },
    {
        "school": "GATEWAY HIGH",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928000434",
    },
    {
        "school": "HICKEY ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928000444",
    },
    {
        "school": "SOLDAN INTERNATIONAL STUDIES",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928000790",
    },
    {
        "school": "CARR LANE VPA MIDDLE",
        "district": "ST. LOUIS CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928000792",
    },
    {
        "school": "MULLANPHY BOTANICAL GARDENS",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928000798",
    },
    {
        "school": "GATEWAY MIDDLE",
        "district": "ST. LOUIS CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001585",
    },
    {
        "school": "GATEWAY ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001587",
    },
    {
        "school": "STIX EARLY CHILDHOOD CTR.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001590",
    },
    {
        "school": "VICC",
        "district": "ST. LOUIS CITY",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292928001591",
    },
    {
        "school": "VO. TECH. TUITION",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292928001592",
    },
    {
        "school": "ASHLAND ELEM. AND BR.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001877",
    },
    {
        "school": "BEAUMONT CTE HIGH SCHOOL",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001882",
    },
    {
        "school": "BRYAN HILL ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001888",
    },
    {
        "school": "BUDER ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001889",
    },
    {
        "school": "CLAY ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001903",
    },
    {
        "school": "COLE ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001906",
    },
    {
        "school": "DUNBAR AND BR.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001916",
    },
    {
        "school": "ELIAS MICHAEL ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001917",
    },
    {
        "school": "FANNING MIDDLE COMMUNITY ED.",
        "district": "ST. LOUIS CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001922",
    },
    {
        "school": "FARRAGUT ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001923",
    },
    {
        "school": "COMMUNITY ACCESS JOB TRAINING",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001926",
    },
    {
        "school": "COMPTON-DREW ILC MIDDLE",
        "district": "ST. LOUIS CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001927",
    },
    {
        "school": "FROEBEL ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001928",
    },
    {
        "school": "MASON ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001930",
    },
    {
        "school": "HAMILTON ELEM. COMMUNITY ED.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001937",
    },
    {
        "school": "HENRY ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001942",
    },
    {
        "school": "HERZOG ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001943",
    },
    {
        "school": "JEFFERSON ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001950",
    },
    {
        "school": "LACLEDE ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001955",
    },
    {
        "school": "LEXINGTON ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001958",
    },
    {
        "school": "LONG MIDDLE COMMUNITY ED. CTR.",
        "district": "ST. LOUIS CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001960",
    },
    {
        "school": "MALLINCKRODT A.B.I. ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001967",
    },
    {
        "school": "MANN ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001968",
    },
    {
        "school": "MERAMEC ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001975",
    },
    {
        "school": "METRO HIGH",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001976",
    },
    {
        "school": "OAK HILL ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001986",
    },
    {
        "school": "ROOSEVELT HIGH",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001994",
    },
    {
        "school": "SHENANDOAH ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928001997",
    },
    {
        "school": "SIGEL ELEM. COMM. ED. CTR.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002000",
    },
    {
        "school": "ST. LOUIS CHILDREN'S HOSPITAL",
        "district": "ST. LOUIS CITY",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292928002005",
    },
    {
        "school": "SUMNER HIGH",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002009",
    },
    {
        "school": "VASHON HIGH",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002011",
    },
    {
        "school": "CENTRAL VISUAL/PERF. ARTS HIGH",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002013",
    },
    {
        "school": "WALBRIDGE ELEM. COMMUNITY ED.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002015",
    },
    {
        "school": "WOODWARD ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002026",
    },
    {
        "school": "HODGEN ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002170",
    },
    {
        "school": "CLEVELAND NJROTC ACADEMY",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002313",
    },
    {
        "school": "LYON AT BLOW ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002403",
    },
    {
        "school": "SHAW VISUAL/PERF. ARTS CTR.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002404",
    },
    {
        "school": "PEABODY ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002454",
    },
    {
        "school": "BUSCH MS CHARACTER  ATHLETICS",
        "district": "ST. LOUIS CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002569",
    },
    {
        "school": "AMES VISUAL/PERF. ARTS",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002570",
    },
    {
        "school": "FORD-FORD BR. ELEM. COMM. ED.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002571",
    },
    {
        "school": "WASHINGTON MONTESSORI",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002572",
    },
    {
        "school": "DEWEY SCH.-INTERNAT'L. STUDIES",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002641",
    },
    {
        "school": "KENNARD/CLASSICAL JR. ACAD.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002645",
    },
    {
        "school": "WILKINSON EARLY CHILDHOOD CTR.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002646",
    },
    {
        "school": "COLUMBIA ELEM. COMM. ED. CTR.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002693",
    },
    {
        "school": "MILLER CAREER ACADEMY",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292928002767",
    },
    {
        "school": "ADAMS ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002789",
    },
    {
        "school": "MONROE ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002790",
    },
    {
        "school": "WOERNER ELEM.",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002829",
    },
    {
        "school": "STATE FAIR",
        "district": "STATE FAIR COMMUNITY COLLEGE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290000500812",
    },
    {
        "school": "GREEN RIDGE ELEM.",
        "district": "GREEN RIDGE R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291329000563",
    },
    {
        "school": "GREEN RIDGE HIGH",
        "district": "GREEN RIDGE R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291329000564",
    },
    {
        "school": "NORTHWEST ELEM.",
        "district": "PETTIS CO. R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291527000694",
    },
    {
        "school": "NORTHWEST HIGH",
        "district": "PETTIS CO. R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291527000695",
    },
    {
        "school": "LA MONTE ELEM.",
        "district": "LA MONTE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291692000936",
    },
    {
        "school": "LA MONTE HIGH",
        "district": "LA MONTE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291692000937",
    },
    {
        "school": "PETTIS CO. ELEM.",
        "district": "PETTIS CO. R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292469001713",
    },
    {
        "school": "HEBER HUNT ELEM.",
        "district": "SEDALIA 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292783001703",
    },
    {
        "school": "HORACE MANN ELEM.",
        "district": "SEDALIA 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292783001704",
    },
    {
        "school": "SMITH-COTTON HIGH SCHOOL",
        "district": "SEDALIA 200",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292783001709",
    },
    {
        "school": "WASHINGTON ELEM.",
        "district": "SEDALIA 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292783001711",
    },
    {
        "school": "SEDALIA MIDDLE SCHOOL",
        "district": "SEDALIA 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292783002304",
    },
    {
        "school": "PARKVIEW ELEM.",
        "district": "SEDALIA 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292783002639",
    },
    {
        "school": "SKYLINE ELEM.",
        "district": "SEDALIA 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292783002640",
    },
    {
        "school": "EARLY CHILDHOOD CTR.",
        "district": "SEDALIA 200",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292783002678",
    },
    {
        "school": "SMITHTON ELEM.",
        "district": "SMITHTON R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292838001751",
    },
    {
        "school": "SMITHTON HIGH",
        "district": "SMITHTON R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292838001752",
    },
    {
        "school": "SCOTT CO. ELEM.",
        "district": "SCOTT CO. R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290489000058",
    },
    {
        "school": "THOMAS W. KELLY HIGH",
        "district": "SCOTT CO. R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290489000059",
    },
    {
        "school": "SCOTT CO. MIDDLE",
        "district": "SCOTT CO. R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290489002703",
    },
    {
        "school": "CHAFFEE ELEM.",
        "district": "CHAFFEE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290846000247",
    },
    {
        "school": "CHAFFEE JR.-SR. HIGH",
        "district": "CHAFFEE R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290846000248",
    },
    {
        "school": "SCOTT CITY ELEM.",
        "district": "SCOTT CITY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291545000704",
    },
    {
        "school": "SCOTT CITY HIGH",
        "district": "SCOTT CITY R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291545000705",
    },
    {
        "school": "SCOTT CITY MIDDLE",
        "district": "SCOTT CITY R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291545002702",
    },
    {
        "school": "KELSO ELEM.",
        "district": "KELSO C-7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291647000895",
    },
    {
        "school": "SCOTT CO. CENTRAL ELEM.",
        "district": "SCOTT CO. CENTRAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292142001176",
    },
    {
        "school": "SCOTT CO. CENTRAL HIGH",
        "district": "SCOTT CO. CENTRAL",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292142001177",
    },
    {
        "school": "ORAN ELEMENTARY SCHOOL",
        "district": "ORAN R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292313001326",
    },
    {
        "school": "ORAN HIGH SCHOOL",
        "district": "ORAN R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292313001327",
    },
    {
        "school": "WING ELEM.",
        "district": "SIKESTON R-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292826001566",
    },
    {
        "school": "SIKESTON CAREER  TECH. CTR.",
        "district": "SIKESTON R-6",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "292826001736",
    },
    {
        "school": "7TH AND 8TH GRADE CTR.",
        "district": "SIKESTON R-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292826001737",
    },
    {
        "school": "SIKESTON KINDERGARTEN CTR.",
        "district": "SIKESTON R-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292826001738",
    },
    {
        "school": "LEE HUNTER ELEM.",
        "district": "SIKESTON R-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292826001739",
    },
    {
        "school": "5TH AND 6TH GRADE CTR.",
        "district": "SIKESTON R-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292826001741",
    },
    {
        "school": "SOUTHEAST ELEM.",
        "district": "SIKESTON R-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292826001742",
    },
    {
        "school": "SIKESTON SR. HIGH",
        "district": "SIKESTON R-6",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292826001744",
    },
    {
        "school": "SUMMIT INTERMEDIATE SCHOOL",
        "district": "Nixa Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292253002799",
    },
    {
        "school": "WILSON'S CREEK 5-6 INTER. CTR.",
        "district": "SPRINGFIELD R-XII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886002865",
    },
    {
        "school": "DALLAS COUNTY TECHNICAL CENTER",
        "district": "DALLAS CO. R-I",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290612000148",
    },
    {
        "school": "BUFFALO HIGH",
        "district": "DALLAS CO. R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290612000149",
    },
    {
        "school": "MALLORY ELEM.",
        "district": "DALLAS CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290612000150",
    },
    {
        "school": "BUFFALO MIDDLE",
        "district": "DALLAS CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290612000858",
    },
    {
        "school": "BOLIVAR PRIMARY",
        "district": "BOLIVAR R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290537000090",
    },
    {
        "school": "BOLIVAR HIGH",
        "district": "BOLIVAR R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290537000092",
    },
    {
        "school": "BOLIVAR INTERMEDIATE SCH.",
        "district": "BOLIVAR R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290537001535",
    },
    {
        "school": "BOLIVAR MIDDLE",
        "district": "BOLIVAR R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290537002423",
    },
    {
        "school": "FAIR PLAY ELEM.",
        "district": "FAIR PLAY R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291173000430",
    },
    {
        "school": "FAIR PLAY HIGH",
        "district": "FAIR PLAY R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291173000431",
    },
    {
        "school": "HALFWAY ELEM.",
        "district": "HALFWAY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291353000575",
    },
    {
        "school": "HALFWAY SECONDARY",
        "district": "HALFWAY R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291353000576",
    },
    {
        "school": "HUMANSVILLE ELEM.",
        "district": "HUMANSVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291530000696",
    },
    {
        "school": "HUMANSVILLE HIGH",
        "district": "HUMANSVILLE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291530000697",
    },
    {
        "school": "MARION C. EARLY ELEM.",
        "district": "MARION C. EARLY R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292016001072",
    },
    {
        "school": "MARION C. EARLY HIGH",
        "district": "MARION C. EARLY R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292016001073",
    },
    {
        "school": "PLEASANT HOPE ELEM.",
        "district": "PLEASANT HOPE R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292535001462",
    },
    {
        "school": "PLEASANT HOPE HIGH",
        "district": "PLEASANT HOPE R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292535001463",
    },
    {
        "school": "PLEASANT HOPE MIDDLE",
        "district": "PLEASANT HOPE R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292535002436",
    },
    {
        "school": "PLEASANT HOPE RANCH SCH.",
        "district": "PLEASANT HOPE R-VI",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292535002819",
    },
    {
        "school": "BILLINGS ELEM.",
        "district": "BILLINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290507000065",
    },
    {
        "school": "BILLINGS SR. HIGH",
        "district": "BILLINGS R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290507000066",
    },
    {
        "school": "CHADWICK ELEMENTARY",
        "district": "CHADWICK R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290843000245",
    },
    {
        "school": "CHADWICK HIGH",
        "district": "CHADWICK R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290843000246",
    },
    {
        "school": "CLEVER ELEM.",
        "district": "CLEVER R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290978000281",
    },
    {
        "school": "CLEVER HIGH",
        "district": "CLEVER R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290978000282",
    },
    {
        "school": "NIXA HIGH",
        "district": "Nixa Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292253000424",
    },
    {
        "school": "NIXA JUNIOR HIGH",
        "district": "Nixa Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292253000425",
    },
    {
        "school": "NICHOLAS A. INMAN INTERMEDIATE",
        "district": "Nixa Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292253000463",
    },
    {
        "school": "MATHEWS ELEM.",
        "district": "Nixa Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292253001651",
    },
    {
        "school": "ESPY ELEM.",
        "district": "Nixa Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292253002504",
    },
    {
        "school": "CENTURY ELEM.",
        "district": "Nixa Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292253002771",
    },
    {
        "school": "OZARK MIDDLE SCHOOL",
        "district": "OZARK R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292343000470",
    },
    {
        "school": "OZARK HIGH",
        "district": "OZARK R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292343001351",
    },
    {
        "school": "EAST ELEM.",
        "district": "OZARK R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292343001433",
    },
    {
        "school": "OZARK JR. HIGH",
        "district": "OZARK R-VI",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292343002438",
    },
    {
        "school": "SOUTH ELEM.",
        "district": "OZARK R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292343002439",
    },
    {
        "school": "NORTH ELEM.",
        "district": "OZARK R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292343002727",
    },
    {
        "school": "SPARTA MIDDLE",
        "district": "SPARTA R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292874001430",
    },
    {
        "school": "SPARTA ELEM.",
        "district": "SPARTA R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292874001775",
    },
    {
        "school": "SPARTA HIGH",
        "district": "SPARTA R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292874001776",
    },
    {
        "school": "SPOKANE MIDDLE",
        "district": "SPOKANE R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292880000008",
    },
    {
        "school": "HIGHLANDVILLE ELEM.",
        "district": "SPOKANE R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292880001778",
    },
    {
        "school": "SPOKANE HIGH",
        "district": "SPOKANE R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292880001779",
    },
    {
        "school": "GRAFF CAREER CENTER",
        "district": "OZARKS TECHNICAL COMM COLLEGE",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "290000800821",
    },
    {
        "school": "BOIS D'ARC ELEM.",
        "district": "ASH GROVE R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290327000026",
    },
    {
        "school": "ASH GROVE ELEM.",
        "district": "ASH GROVE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290327000027",
    },
    {
        "school": "ASH GROVE HIGH",
        "district": "ASH GROVE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290327000028",
    },
    {
        "school": "FAIR GROVE ELEM.",
        "district": "FAIR GROVE R-X",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291170000428",
    },
    {
        "school": "FAIR GROVE HIGH",
        "district": "FAIR GROVE R-X",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291170000429",
    },
    {
        "school": "FAIR GROVE MIDDLE",
        "district": "FAIR GROVE R-X",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291170002283",
    },
    {
        "school": "LOGAN-ROGERSVILLE HIGH",
        "district": "LOGAN-ROGERSVILLE R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291917001037",
    },
    {
        "school": "LOGAN-ROGERSVILLE PRIMARY",
        "district": "LOGAN-ROGERSVILLE R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291917002434",
    },
    {
        "school": "REPUBLIC HIGH",
        "district": "REPUBLIC R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292622001541",
    },
    {
        "school": "REPUBLIC MIDDLE",
        "district": "REPUBLIC R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292622002302",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "REPUBLIC R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292622002733",
    },
    {
        "school": "CARVER MIDDLE",
        "district": "SPRINGFIELD R-XII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886000901",
    },
    {
        "school": "JUVENILE JUSTICE CTR.",
        "district": "SPRINGFIELD R-XII",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292886001480",
    },
    {
        "school": "BINGHAM ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001781",
    },
    {
        "school": "BISSETT ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001782",
    },
    {
        "school": "BOWERMAN ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001783",
    },
    {
        "school": "BOYD ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001784",
    },
    {
        "school": "CAMPBELL ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001785",
    },
    {
        "school": "CENTRAL HIGH",
        "district": "SPRINGFIELD R-XII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001786",
    },
    {
        "school": "CHEROKEE MIDDLE",
        "district": "SPRINGFIELD R-XII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001788",
    },
    {
        "school": "COWDEN ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001789",
    },
    {
        "school": "DELAWARE ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001790",
    },
    {
        "school": "FIELD ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001794",
    },
    {
        "school": "FREMONT ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001795",
    },
    {
        "school": "GLENDALE HIGH",
        "district": "SPRINGFIELD R-XII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001796",
    },
    {
        "school": "HICKORY HILLS ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001797",
    },
    {
        "school": "HICKORY HILLS MIDDLE",
        "district": "SPRINGFIELD R-XII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001798",
    },
    {
        "school": "HILLCREST HIGH",
        "district": "SPRINGFIELD R-XII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001800",
    },
    {
        "school": "HOLLAND ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001801",
    },
    {
        "school": "HORACE MANN ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001802",
    },
    {
        "school": "JARRETT MIDDLE",
        "district": "SPRINGFIELD R-XII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001803",
    },
    {
        "school": "KICKAPOO HIGH",
        "district": "SPRINGFIELD R-XII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001804",
    },
    {
        "school": "MARK TWAIN ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001805",
    },
    {
        "school": "MCGREGOR ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001806",
    },
    {
        "school": "PARKVIEW HIGH",
        "district": "SPRINGFIELD R-XII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001808",
    },
    {
        "school": "PERSHING ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001810",
    },
    {
        "school": "PERSHING MIDDLE",
        "district": "SPRINGFIELD R-XII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001811",
    },
    {
        "school": "PIPKIN MIDDLE",
        "district": "SPRINGFIELD R-XII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001813",
    },
    {
        "school": "PITTMAN ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001814",
    },
    {
        "school": "PLEASANT VIEW ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001815",
    },
    {
        "school": "PORTLAND ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001817",
    },
    {
        "school": "REED MIDDLE",
        "district": "SPRINGFIELD R-XII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001818",
    },
    {
        "school": "ROBBERSON ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001820",
    },
    {
        "school": "ROUNTREE ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001821",
    },
    {
        "school": "SEQUIOTA ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001822",
    },
    {
        "school": "SHERWOOD ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001824",
    },
    {
        "school": "WESTPORT MIDDLE SCHOOL",
        "district": "SPRINGFIELD R-XII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001827",
    },
    {
        "school": "SUNSHINE ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001828",
    },
    {
        "school": "WALT DISNEY ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001830",
    },
    {
        "school": "WATKINS ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001831",
    },
    {
        "school": "WEAVER ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001832",
    },
    {
        "school": "WELLER ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001833",
    },
    {
        "school": "WESTPORT ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001834",
    },
    {
        "school": "WILDER ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001835",
    },
    {
        "school": "WILLIAMS ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001837",
    },
    {
        "school": "YORK ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886001838",
    },
    {
        "school": "JEFFRIES ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886002305",
    },
    {
        "school": "MCBRIDE ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886002306",
    },
    {
        "school": "GRAY ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886002480",
    },
    {
        "school": "STUDY ALTERNATIVE HIGH",
        "district": "SPRINGFIELD R-XII",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292886002541",
    },
    {
        "school": "TRUMAN ELEM.",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886002675",
    },
    {
        "school": "PLEASANT VIEW MIDDLE",
        "district": "SPRINGFIELD R-XII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886002680",
    },
    {
        "school": "PHELPS GIFTED CTR.",
        "district": "SPRINGFIELD R-XII",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886002734",
    },
    {
        "school": "STRAFFORD MIDDLE",
        "district": "STRAFFORD R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292964001479",
    },
    {
        "school": "STRAFFORD ELEM.",
        "district": "STRAFFORD R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292964002049",
    },
    {
        "school": "STRAFFORD HIGH",
        "district": "STRAFFORD R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292964002050",
    },
    {
        "school": "WALNUT GROVE ELEM.",
        "district": "WALNUT GROVE R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293099002140",
    },
    {
        "school": "WALNUT GROVE HIGH",
        "district": "WALNUT GROVE R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293099002141",
    },
    {
        "school": "WILLARD CENTRAL ELEM.",
        "district": "WILLARD R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293201001700",
    },
    {
        "school": "WILLARD SOUTH ELEM.",
        "district": "WILLARD R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293201002241",
    },
    {
        "school": "WILLARD MIDDLE",
        "district": "WILLARD R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293201002242",
    },
    {
        "school": "WILLARD HIGH",
        "district": "WILLARD R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293201002243",
    },
    {
        "school": "WILLARD NORTH ELEM.",
        "district": "WILLARD R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293201002244",
    },
    {
        "school": "WILLARD EAST ELEM.",
        "district": "WILLARD R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293201002773",
    },
    {
        "school": "FORDLAND ELEM.",
        "district": "FORDLAND R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291218000484",
    },
    {
        "school": "FORDLAND HIGH",
        "district": "FORDLAND R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291218000485",
    },
    {
        "school": "FORDLAND MIDDLE",
        "district": "FORDLAND R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291218001578",
    },
    {
        "school": "LOGAN-ROGERSVILLE MIDDLE",
        "district": "LOGAN-ROGERSVILLE R-VIII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291917002433",
    },
    {
        "school": "LOGAN-ROGERSVILLE UPPER ELEM.",
        "district": "LOGAN-ROGERSVILLE R-VIII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291917002677",
    },
    {
        "school": "MARSHFIELD JR. HIGH",
        "district": "MARSHFIELD R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292043001088",
    },
    {
        "school": "EDWIN P. HUBBLE ELEM.",
        "district": "MARSHFIELD R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292043001089",
    },
    {
        "school": "MARSHFIELD HIGH",
        "district": "MARSHFIELD R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292043001090",
    },
    {
        "school": "DANIEL WEBSTER ELEM.",
        "district": "MARSHFIELD R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292043002470",
    },
    {
        "school": "SHOOK ELEM.",
        "district": "MARSHFIELD R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292043002709",
    },
    {
        "school": "NIANGUA ELEM.",
        "district": "NIANGUA R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292250001232",
    },
    {
        "school": "NIANGUA HIGH",
        "district": "NIANGUA R-V",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292250001233",
    },
    {
        "school": "SEYMOUR MIDDLE",
        "district": "SEYMOUR R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292793001580",
    },
    {
        "school": "SEYMOUR ELEM.",
        "district": "SEYMOUR R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292793001720",
    },
    {
        "school": "SEYMOUR HIGH",
        "district": "SEYMOUR R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292793001721",
    },
    {
        "school": "CREST RIDGE ELEM.",
        "district": "JOHNSON CO. R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290832000231",
    },
    {
        "school": "CREST RIDGE HIGH",
        "district": "JOHNSON CO. R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290832002276",
    },
    {
        "school": "CHILHOWEE ELEM.",
        "district": "CHILHOWEE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290873000256",
    },
    {
        "school": "CHILHOWEE HIGH",
        "district": "CHILHOWEE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290873000257",
    },
    {
        "school": "HOLDEN MIDDLE",
        "district": "HOLDEN R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291449000679",
    },
    {
        "school": "HOLDEN HIGH",
        "district": "HOLDEN R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291449000680",
    },
    {
        "school": "HOLDEN ELEM.",
        "district": "HOLDEN R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291449000681",
    },
    {
        "school": "KINGSVILLE ELEM.",
        "district": "KINGSVILLE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291666000909",
    },
    {
        "school": "KINGSVILLE HIGH",
        "district": "KINGSVILLE R-I",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291666000910",
    },
    {
        "school": "KNOB NOSTER ELEM.",
        "district": "KNOB NOSTER R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291683000931",
    },
    {
        "school": "KNOB NOSTER HIGH",
        "district": "KNOB NOSTER R-VIII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291683000932",
    },
    {
        "school": "WHITEMAN A.F.B. ELEM.",
        "district": "KNOB NOSTER R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291683000933",
    },
    {
        "school": "KNOB NOSTER MIDDLE",
        "district": "KNOB NOSTER R-VIII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291683002290",
    },
    {
        "school": "LEETON ELEM.",
        "district": "LEETON R-X",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291836000986",
    },
    {
        "school": "LEETON HIGH",
        "district": "LEETON R-X",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291836000987",
    },
    {
        "school": "LEETON MIDDLE",
        "district": "LEETON R-X",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291836002812",
    },
    {
        "school": "GATEWAY EDUCATIONAL CTR.",
        "district": "WARRENSBURG R-VI",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "293102001511",
    },
    {
        "school": "STERLING ELEM.",
        "district": "WARRENSBURG R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293102001729",
    },
    {
        "school": "WARRENSBURG MIDDLE",
        "district": "WARRENSBURG R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293102002142",
    },
    {
        "school": "RIDGE VIEW ELEM.",
        "district": "WARRENSBURG R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293102002144",
    },
    {
        "school": "WARRENSBURG HIGH",
        "district": "WARRENSBURG R-VI",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293102002145",
    },
    {
        "school": "WARRENSBURG AREA CAREER CTR.",
        "district": "WARRENSBURG R-VI",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "293102002147",
    },
    {
        "school": "MARTIN WARREN ELEM.",
        "district": "WARRENSBURG R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293102002513",
    },
    {
        "school": "LIBERTY MIDDLE",
        "district": "MOUNTAIN VIEW-BIRCH TREE R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292154003026",
    },
    {
        "school": "FAIRVIEW ELEM.",
        "district": "FAIRVIEW R-XI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291185000435",
    },
    {
        "school": "JUNCTION HILL ELEM.",
        "district": "JUNCTION HILL C-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291506000689",
    },
    {
        "school": "GLENWOOD ELEM.",
        "district": "GLENWOOD R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291518000691",
    },
    {
        "school": "HOWELL VALLEY ELEM.",
        "district": "HOWELL VALLEY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291521000692",
    },
    {
        "school": "LIBERTY SR. HIGH",
        "district": "MOUNTAIN VIEW-BIRCH TREE R-III",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292154001186",
    },
    {
        "school": "MOUNTAIN VIEW ELEM.",
        "district": "MOUNTAIN VIEW-BIRCH TREE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292154001187",
    },
    {
        "school": "RICHARDS ELEM.",
        "district": "RICHARDS R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292637001546",
    },
    {
        "school": "WEST PLAINS MIDDLE",
        "district": "WEST PLAINS R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293168002213",
    },
    {
        "school": "WEST PLAINS SR. HIGH",
        "district": "WEST PLAINS R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293168002215",
    },
    {
        "school": "SOUTH CENTRAL CAREER CTR.",
        "district": "WEST PLAINS R-VII",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MO",
        "nces_id": "293168002216",
    },
    {
        "school": "SOUTH FORK ELEM.",
        "district": "WEST PLAINS R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293168002217",
    },
    {
        "school": "WEST PLAINS ELEM.",
        "district": "WEST PLAINS R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293168002543",
    },
    {
        "school": "WILLOW SPRINGS HIGH",
        "district": "WILLOW SPRINGS R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293207002245",
    },
    {
        "school": "WILLOW SPRINGS MIDDLE",
        "district": "WILLOW SPRINGS R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293207002246",
    },
    {
        "school": "WILLOW SPRINGS ELEM.",
        "district": "WILLOW SPRINGS R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293207002249",
    },
    {
        "school": "BIRCH TREE ELEM.",
        "district": "MOUNTAIN VIEW-BIRCH TREE R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292154001184",
    },
    {
        "school": "OVERPARK ELEMENTARY",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001281",
    },
    {
        "school": "LAKE CORMORANT MIDDLE",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001282",
    },
    {
        "school": "HERNANDO HILLS ELEMENTARY",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001287",
    },
    {
        "school": "LEWISBURG HIGH SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001288",
    },
    {
        "school": "CENTER HILL HIGH SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001289",
    },
    {
        "school": "JEFFERSON CO JR HI",
        "district": "JEFFERSON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280222001292",
    },
    {
        "school": "LAFAYETTE UPPER ELEMENTARY SCHOOL",
        "district": "LAFAYETTE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280237001280",
    },
    {
        "school": "REUBEN B. MYERS CANTON SCHOOL OF AR",
        "district": "CANTON PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280090001285",
    },
    {
        "school": "GERMANTOWN MIDDLE SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001283",
    },
    {
        "school": "MADISON CROSSING ELEMENTARY",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001290",
    },
    {
        "school": "BYHALIA MIDDLE SCHOOL (6-8)",
        "district": "MARSHALL CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280285001291",
    },
    {
        "school": "MONROE CO ADVANCED LEARNING CENTER",
        "district": "MONROE CO SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280294001293",
    },
    {
        "school": "STRAYHORN HIGH SCHOOL",
        "district": "TATE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280423001295",
    },
    {
        "school": "HOLLY SPRINGS JUNIOR HIGH SCHOOL",
        "district": "HOLLY SPRINGS SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280195001248",
    },
    {
        "school": "EAST CENTRAL ALTERNATIVE SCHOOL",
        "district": "NEWTON COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280315001258",
    },
    {
        "school": "NEW ALBANY ELEMENTARY SCHOOL",
        "district": "NEW ALBANY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280312001259",
    },
    {
        "school": "WILLIAM WINANS MIDDLE SCHOOL",
        "district": "WILKINSON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280471001580",
    },
    {
        "school": "ETHEL ATTENDANCE CENTER",
        "district": "ATTALA CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280051000036",
    },
    {
        "school": "GREENLEE ATTENDANCE CENTER",
        "district": "ATTALA CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280051000037",
    },
    {
        "school": "LONG CREEK ATTENDANCE CENTER",
        "district": "ATTALA CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280051000038",
    },
    {
        "school": "MCADAMS ATTENDANCE CENTER",
        "district": "ATTALA CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280051000039",
    },
    {
        "school": "KOSCIUSKO ATTALA CAREER TECHNICAL C",
        "district": "ATTALA CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280051001020",
    },
    {
        "school": "KOSCIUSKO ALTERNATIVE SCHOOL",
        "district": "KOSCIUSKO SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280234000456",
    },
    {
        "school": "KOSCIUSKO JUNIOR HIGH SCHOOL",
        "district": "KOSCIUSKO SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280234000457",
    },
    {
        "school": "KOSCIUSKO LOWER ELEM",
        "district": "KOSCIUSKO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280234000458",
    },
    {
        "school": "KOSCIUSKO MIDDLE",
        "district": "KOSCIUSKO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280234000459",
    },
    {
        "school": "KOSCIUSKO SENIOR HIGH SCHOOL",
        "district": "KOSCIUSKO SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280234000460",
    },
    {
        "school": "KOSCIUSKO UPPER ELEM",
        "district": "KOSCIUSKO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280234000461",
    },
    {
        "school": "ASHLAND ELEMENTARY SCHOOL",
        "district": "BENTON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280060000048",
    },
    {
        "school": "ASHLAND MIDDLE-HIGH SCHOOL",
        "district": "BENTON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280060000049",
    },
    {
        "school": "HICKORY FLAT ATTENDANCE CENTER",
        "district": "BENTON CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280060000050",
    },
    {
        "school": "BENTON CO REGIONAL VOCATIONAL CEN",
        "district": "BENTON CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280060000929",
    },
    {
        "school": "BRUCE HIGH SCHOOL",
        "district": "CALHOUN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280087000097",
    },
    {
        "school": "CALHOUN CITY HIGH SCHOOL",
        "district": "CALHOUN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280087000098",
    },
    {
        "school": "VARDAMAN HIGH SCHOOL",
        "district": "CALHOUN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280087000099",
    },
    {
        "school": "BRUCE ELEMENTARY SCHOOL",
        "district": "CALHOUN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280087001102",
    },
    {
        "school": "CALHOUN CITY ELEMENTARY SCHOOL",
        "district": "CALHOUN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280087001104",
    },
    {
        "school": "VARDAMAN ELEMENTARY SCHOOL",
        "district": "CALHOUN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280087001106",
    },
    {
        "school": "HOULKA ATTENDANCE CENTER",
        "district": "CHICKASAW CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280096000108",
    },
    {
        "school": "HOUSTON MIDDLE SCHOOL",
        "district": "HOUSTON  SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280201000040",
    },
    {
        "school": "HOUSTON LOWER ELEMENTARY",
        "district": "HOUSTON  SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280201000344",
    },
    {
        "school": "HOUSTON HIGH SCHOOL",
        "district": "HOUSTON  SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280201000345",
    },
    {
        "school": "HOUSTON UPPER ELEMENTARY",
        "district": "HOUSTON  SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280201000346",
    },
    {
        "school": "HOUSTON CAREER & TECHNOLOGY ED.",
        "district": "HOUSTON  SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280201000347",
    },
    {
        "school": "OKOLONA ELEMENTARY SCHOOL",
        "district": "OKOLONA SEPARATE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280339000653",
    },
    {
        "school": "OKOLONA HIGH SCHOOL",
        "district": "OKOLONA SEPARATE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280339000654",
    },
    {
        "school": "OKOLONA VOC COMPLEX",
        "district": "OKOLONA SEPARATE SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280339000655",
    },
    {
        "school": "ACKERMAN ELEM",
        "district": "CHOCTAW CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280099000110",
    },
    {
        "school": "CHOCTAW COUNTY HIGH SCHOOL",
        "district": "CHOCTAW CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280099000111",
    },
    {
        "school": "CHOCTAW CO VOCATIONAL COMPLEX",
        "district": "CHOCTAW CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280099000112",
    },
    {
        "school": "FRENCH CAMP ELEM SCHOOL",
        "district": "CHOCTAW CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280099000113",
    },
    {
        "school": "WEIR ELEMENTARY SCHOOL",
        "district": "CHOCTAW CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280099000114",
    },
    {
        "school": "CLAIBORNE COUNTY VOC COMPLEX",
        "district": "CLAIBORNE CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280102000082",
    },
    {
        "school": "PORT GIBSON MIDDLE SCHOOL",
        "district": "CLAIBORNE CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280102000115",
    },
    {
        "school": "PORT GIBSON HIGH SCHOOL",
        "district": "CLAIBORNE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280102000116",
    },
    {
        "school": "A. W. WATSON UPPER ELEMENTARY",
        "district": "CLAIBORNE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280102001213",
    },
    {
        "school": "COLLINS ELEMENTARY",
        "district": "COVINGTON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280129000176",
    },
    {
        "school": "COLLINS HIGH SCHOOL",
        "district": "COVINGTON COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280129000177",
    },
    {
        "school": "CARVER MIDDLE SCHOOL",
        "district": "COVINGTON COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280129000178",
    },
    {
        "school": "COVINGTON CO VOCATIONAL TECHNICAL",
        "district": "COVINGTON COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280129000179",
    },
    {
        "school": "HOPEWELL ELEMENTARY SCHOOL",
        "district": "COVINGTON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280129000180",
    },
    {
        "school": "MOUNT OLIVE ATTENDANCE CENTER",
        "district": "COVINGTON COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280129000181",
    },
    {
        "school": "SEMINARY HIGH SCHOOL",
        "district": "COVINGTON COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280129000182",
    },
    {
        "school": "COVINGTON COUNTY ALTERNATIVE SCHOOL",
        "district": "COVINGTON COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280129000957",
    },
    {
        "school": "FRANKLIN LOWER ELEMENTARY",
        "district": "FRANKLIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280153000223",
    },
    {
        "school": "FRANKLIN HIGH SCHOOL",
        "district": "FRANKLIN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280153000224",
    },
    {
        "school": "FRANKLIN CAREER & TECHNICAL CENTER",
        "district": "FRANKLIN CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280153000225",
    },
    {
        "school": "FRANKLIN UPPER ELEMENTARY",
        "district": "FRANKLIN CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280153001110",
    },
    {
        "school": "FRANKLIN COUNTY MIDDLE SCHOOL",
        "district": "FRANKLIN CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280153001111",
    },
    {
        "school": "GREENE COUNTY HIGH SCHOOL",
        "district": "GREENE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280159000232",
    },
    {
        "school": "MC LAIN ELEMENTARY SCHOOL",
        "district": "GREENE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280159000233",
    },
    {
        "school": "SAND HILL ELEMENTARY SCHOOL",
        "district": "GREENE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280159000234",
    },
    {
        "school": "LEAKESVILLE ELEMENTARY SCHOOL",
        "district": "GREENE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280159001031",
    },
    {
        "school": "GREENE COUNTY VOCATIONAL TECHNICAL",
        "district": "GREENE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280159001032",
    },
    {
        "school": "LEAKESVILLE JR HIGH SCHOOL",
        "district": "GREENE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280159001134",
    },
    {
        "school": "HUMPHREYS CO VOC CENTER",
        "district": "HUMPHREYS CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280204000348",
    },
    {
        "school": "IDA GREENE LOWER ELEMENTARY",
        "district": "HUMPHREYS CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280204000349",
    },
    {
        "school": "O M MC NAIR UPPER ELEMENTARY",
        "district": "HUMPHREYS CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280204001039",
    },
    {
        "school": "HUMPHREYS COUNTY HIGH SCHOOL",
        "district": "HUMPHREYS CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280204001041",
    },
    {
        "school": "JEFFERSON COUNTY UPPER ELEMENTARY",
        "district": "JEFFERSON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280222000209",
    },
    {
        "school": "FAYETTE VOC CENTER",
        "district": "JEFFERSON CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280222000425",
    },
    {
        "school": "JEFFERSON CO ELEM SCHOOL",
        "district": "JEFFERSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280222000426",
    },
    {
        "school": "JEFFERSON CO HIGH",
        "district": "JEFFERSON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280222000427",
    },
    {
        "school": "JEFFERSON COUNTY ALTERNATIVE SCHOOL",
        "district": "JEFFERSON CO SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280222000950",
    },
    {
        "school": "JDC HIGH SCHOOL",
        "district": "JEFFERSON DAVIS CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280225000429",
    },
    {
        "school": "CARVER ELEMENTARY SCHOOL",
        "district": "JEFFERSON DAVIS CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280225000430",
    },
    {
        "school": "JEFF DAVIS CO VOC TECH CENTER",
        "district": "JEFFERSON DAVIS CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280225000431",
    },
    {
        "school": "J E JOHNSON ELEMENTARY",
        "district": "JEFFERSON DAVIS CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280225000432",
    },
    {
        "school": "ROD PAIGE MIDDLE SCHOOL",
        "district": "LAWRENCE CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280249000480",
    },
    {
        "school": "MONTICELLO ELEMENTARY SCHOOL",
        "district": "LAWRENCE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280249000481",
    },
    {
        "school": "LAWRENCE COUNTY HIGH SCHOOL",
        "district": "LAWRENCE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280249000482",
    },
    {
        "school": "NEW HEBRON ATTENDANCE CENTER",
        "district": "LAWRENCE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280249000483",
    },
    {
        "school": "TOPEKA TILTON ATTENDANCE CENTER",
        "district": "LAWRENCE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280249000485",
    },
    {
        "school": "LAWRENCE CO TECH & CAREER CENTER",
        "district": "LAWRENCE CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280249001117",
    },
    {
        "school": "LEAKE CO CAREER & TECHNICAL CENTER",
        "district": "LEAKE CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280252000238",
    },
    {
        "school": "LEAKE CENTRAL HIGH SCHOOL",
        "district": "LEAKE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280252000487",
    },
    {
        "school": "LEAKE COUNTY HIGH SCHOOL",
        "district": "LEAKE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280252000490",
    },
    {
        "school": "LEAKE CENTRAL ELEMENTARY SCHOOL",
        "district": "LEAKE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280252001118",
    },
    {
        "school": "LEAKE CENTRAL JUNIOR HIGH",
        "district": "LEAKE CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280252001119",
    },
    {
        "school": "LEAKE COUNTY ELEMENTARY SCHOOL",
        "district": "LEAKE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280252001120",
    },
    {
        "school": "COLUMBIA ELEMENTARY SCHOOL",
        "district": "COLUMBIA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280117000148",
    },
    {
        "school": "COLUMBIA HIGH SCHOOL",
        "district": "COLUMBIA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280117000149",
    },
    {
        "school": "COLUMBIA PRIMARY SCHOOL",
        "district": "COLUMBIA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280117000150",
    },
    {
        "school": "JEFFERSON MIDDLE SCHOOL",
        "district": "COLUMBIA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280117000151",
    },
    {
        "school": "EAST MARION HIGH SCHOOL",
        "district": "MARION CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280282000545",
    },
    {
        "school": "MARION CO VOC COMPLEX",
        "district": "MARION CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280282000546",
    },
    {
        "school": "WEST MARION PRIMARY SCHOOL",
        "district": "MARION CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280282001060",
    },
    {
        "school": "EAST MARION ELEMENTARY  SCHOOL",
        "district": "MARION CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280282001243",
    },
    {
        "school": "WEST MARION ELEMENTARY",
        "district": "MARION CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280282001246",
    },
    {
        "school": "WEST MARION HIGH SCHOOL",
        "district": "MARION CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280282001247",
    },
    {
        "school": "ABERDEEN HIGH SCHOOL",
        "district": "ABERDEEN SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280036000009",
    },
    {
        "school": "EAST AMORY SCHOOL",
        "district": "AMORY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280045000028",
    },
    {
        "school": "AMORY HIGH SCHOOL",
        "district": "AMORY SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280045000029",
    },
    {
        "school": "AMORY MIDDLE SCHOOL",
        "district": "AMORY SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280045000030",
    },
    {
        "school": "AMORY CAREER TECHNICAL CENTER",
        "district": "AMORY SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280045000031",
    },
    {
        "school": "WEST AMORY SCHOOL",
        "district": "AMORY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280045000032",
    },
    {
        "school": "HAMILTON HIGH SCHOOL",
        "district": "MONROE CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280294000580",
    },
    {
        "school": "HATLEY HIGH SCHOOL",
        "district": "MONROE CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280294000581",
    },
    {
        "school": "SMITHVILLE HIGH SCHOOL",
        "district": "MONROE CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280294000582",
    },
    {
        "school": "MONROE CO VOC TECH",
        "district": "MONROE CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280294001063",
    },
    {
        "school": "NESHOBA CENTRAL ELEMENTARY SCHOOL",
        "district": "NESHOBA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280306000611",
    },
    {
        "school": "NESHOBA CENTRAL HIGH SCHOOL",
        "district": "NESHOBA COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280306000612",
    },
    {
        "school": "NESHOBA CENTRAL MIDDLE SCHOOL",
        "district": "NESHOBA COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280306000990",
    },
    {
        "school": "PHILADELPHIA ELEMENTARY SCHOOL",
        "district": "PHILADELPHIA PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280360000691",
    },
    {
        "school": "PHILADELPHIA HIGH SCHOOL",
        "district": "PHILADELPHIA PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280360000692",
    },
    {
        "school": "NEWTON COUNTY VOC COMPLEX",
        "district": "NEWTON COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280315000940",
    },
    {
        "school": "NEWTON COUNTY HIGH SCHOOL",
        "district": "NEWTON COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280315001135",
    },
    {
        "school": "NEWTON COUNTY ELEMENTARY SCHOOL",
        "district": "NEWTON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280315001222",
    },
    {
        "school": "NEWTON HIGH SCHOOL",
        "district": "NEWTON MUNICIPAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280318000626",
    },
    {
        "school": "NEWTON ELEMENTARY SCHOOL",
        "district": "NEWTON MUNICIPAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280318001137",
    },
    {
        "school": "NEWTON MUNICIPAL CAREER CENTER",
        "district": "NEWTON MUNICIPAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280318001138",
    },
    {
        "school": "N H PILATE MIDDLE SCHOOL",
        "district": "NEWTON MUNICIPAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280318001179",
    },
    {
        "school": "UNION HIGH SCHOOL",
        "district": "UNION PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280438000825",
    },
    {
        "school": "EARL NASH ELEMENTARY SCHOOL",
        "district": "NOXUBEE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280330000641",
    },
    {
        "school": "NOXUBEE COUNTY HIGH SCHOOL",
        "district": "NOXUBEE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280330000642",
    },
    {
        "school": "B F LIDDELL MIDDLE SCHOOL",
        "district": "NOXUBEE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280330000643",
    },
    {
        "school": "NOXUBEE CO VOC TECH",
        "district": "NOXUBEE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280330000644",
    },
    {
        "school": "COMO PRIMARY",
        "district": "NORTH PANOLA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280321000627",
    },
    {
        "school": "GREEN HILL INTERMEDIATE",
        "district": "NORTH PANOLA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280321000629",
    },
    {
        "school": "NORTH PANOLA HIGH SCHOOL",
        "district": "NORTH PANOLA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280321000630",
    },
    {
        "school": "NORTH PANOLA VOC COMP",
        "district": "NORTH PANOLA SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280321000631",
    },
    {
        "school": "NORTH PANOLA ACHIEVEMENT ACADEMY",
        "district": "NORTH PANOLA SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280321000909",
    },
    {
        "school": "BATESVILLE ELEMENTARY SCHOOL",
        "district": "SOUTH PANOLA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280405000763",
    },
    {
        "school": "BATESVILLE JUNIOR HIGH SCHOOL",
        "district": "SOUTH PANOLA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280405000764",
    },
    {
        "school": "POPE ELEMENTARY SCHOOL",
        "district": "SOUTH PANOLA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280405000765",
    },
    {
        "school": "SOUTH PANOLA HIGH SCHOOL",
        "district": "SOUTH PANOLA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280405000766",
    },
    {
        "school": "BATESVILLE INTERMEDIATE SCHOOL",
        "district": "SOUTH PANOLA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280405001089",
    },
    {
        "school": "BATESVILLE MIDDLE SCHOOL",
        "district": "SOUTH PANOLA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280405001250",
    },
    {
        "school": "NORTHEAST MS REGIONAL ALTERNATIVE",
        "district": "BOONEVILLE SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280082000911",
    },
    {
        "school": "BOONEVILLE HIGH SCHOOL",
        "district": "BOONEVILLE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280082001024",
    },
    {
        "school": "ANDERSON ELEMENTARY SCHOOL",
        "district": "BOONEVILLE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280082001025",
    },
    {
        "school": "HILLS CHAPEL SCHOOL",
        "district": "PRENTISS CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280375000716",
    },
    {
        "school": "JUMPERTOWN HIGH SCHOOL",
        "district": "PRENTISS CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280375000717",
    },
    {
        "school": "MARIETTA ELEMENTARY SCHOOL",
        "district": "PRENTISS CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280375000718",
    },
    {
        "school": "NEW SITE HIGH SCHOOL",
        "district": "PRENTISS CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280375000719",
    },
    {
        "school": "PRENTISS CO VOC COMPLEX",
        "district": "PRENTISS CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280375000720",
    },
    {
        "school": "THRASHER HIGH SCHOOL",
        "district": "PRENTISS CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280375000721",
    },
    {
        "school": "WHEELER HIGH SCHOOL",
        "district": "PRENTISS CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280375000722",
    },
    {
        "school": "M. S. PALMER HIGH SCHOOL",
        "district": "QUITMAN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280381000730",
    },
    {
        "school": "QUITMAN CO VOCATIONAL COMPLEX",
        "district": "QUITMAN CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280381000731",
    },
    {
        "school": "QUITMAN COUNTY ELEMENTARY SCHOOL",
        "district": "QUITMAN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280381000732",
    },
    {
        "school": "QUITMAN COUNTY MIDDLE SCHOOL",
        "district": "QUITMAN CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280381000734",
    },
    {
        "school": "FOREST ELEMENTARY SCHOOL",
        "district": "FOREST MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280147000212",
    },
    {
        "school": "FOREST HIGH SCHOOL",
        "district": "FOREST MUNICIPAL SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280147000213",
    },
    {
        "school": "HAWKINS MIDDLE SCHOOL",
        "district": "FOREST MUNICIPAL SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280147000214",
    },
    {
        "school": "FOREST SCOTT CO VOC TECH CENTER",
        "district": "SCOTT CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280390000745",
    },
    {
        "school": "MORTON ELEMENTARY SCHOOL",
        "district": "SCOTT CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280390000747",
    },
    {
        "school": "SCOTT CENTRAL ATTENDANCE CENTER",
        "district": "SCOTT CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280390000748",
    },
    {
        "school": "SEBASTOPOL ATTENDANCE CENTER",
        "district": "SCOTT CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280390000749",
    },
    {
        "school": "LAKE MIDDLE SCHOOL",
        "district": "SCOTT CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280390001144",
    },
    {
        "school": "BETTYE MAE JACK MIDDLE SCHOOL",
        "district": "SCOTT CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280390001145",
    },
    {
        "school": "MORTON HIGH SCHOOL",
        "district": "SCOTT CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280390001184",
    },
    {
        "school": "SOUTH DELTA MIDDLE SCHOOL",
        "district": "SOUTH DELTA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280396000383",
    },
    {
        "school": "SOUTH DELTA ELEMENTARY SCHOOL",
        "district": "SOUTH DELTA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280396000752",
    },
    {
        "school": "SOUTH DELTA HIGH SCHOOL",
        "district": "SOUTH DELTA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280396000753",
    },
    {
        "school": "SOUTH DELTA VOCATIONAL COMPLEX",
        "district": "SOUTH DELTA SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280396000754",
    },
    {
        "school": "MIZE ATTENDANCE CENTER",
        "district": "SMITH CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280402000758",
    },
    {
        "school": "RALEIGH HIGH SCHOOL",
        "district": "SMITH CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280402000759",
    },
    {
        "school": "SMITH COUNTY CAREER CENTER",
        "district": "SMITH CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280402000761",
    },
    {
        "school": "TAYLORSVILLE ATTENDANCE CENTER",
        "district": "SMITH CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280402000762",
    },
    {
        "school": "COMMUNITY LEARNING CENTER",
        "district": "SMITH CO SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280402000925",
    },
    {
        "school": "RALEIGH ELEMENTARY SCHOOL",
        "district": "SMITH CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280402001146",
    },
    {
        "school": "CHARLESTON ELEMENTARY SCHOOL",
        "district": "EAST TALLAHATCHIE CONSOL SCH DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280141000206",
    },
    {
        "school": "CHARLESTON HIGH SCHOOL",
        "district": "EAST TALLAHATCHIE CONSOL SCH DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280141000207",
    },
    {
        "school": "CHARLESTON MIDDLE SCHOOL",
        "district": "EAST TALLAHATCHIE CONSOL SCH DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280141000208",
    },
    {
        "school": "E TALLAHATCHIE VOC CENTER",
        "district": "EAST TALLAHATCHIE CONSOL SCH DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280141000973",
    },
    {
        "school": "NORTH DELTA ALTERNATIVE SCHOOL",
        "district": "WEST TALLAHATCHIE SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280465000729",
    },
    {
        "school": "R H BEARDEN ELEMENTARY SCHOOL",
        "district": "WEST TALLAHATCHIE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280465000872",
    },
    {
        "school": "WEST TALLAHATCHIE HIGH SCHOOL",
        "district": "WEST TALLAHATCHIE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280465000873",
    },
    {
        "school": "CHALYBEATE ELEMENTARY SCHOOL",
        "district": "NORTH TIPPAH SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280327000637",
    },
    {
        "school": "FALKNER HIGH SCHOOL",
        "district": "NORTH TIPPAH SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280327000638",
    },
    {
        "school": "WALNUT ATTENDANCE CENTER",
        "district": "NORTH TIPPAH SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280327000640",
    },
    {
        "school": "FALKNER ELEMENTARY SCHOOL",
        "district": "NORTH TIPPAH SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280327001139",
    },
    {
        "school": "BLUE MOUNTAIN HIGH SCHOOL",
        "district": "SOUTH TIPPAH SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280411000775",
    },
    {
        "school": "PINE GROVE HIGH SCHOOL",
        "district": "SOUTH TIPPAH SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280411000776",
    },
    {
        "school": "RIPLEY ELEMENTARY SCHOOL",
        "district": "SOUTH TIPPAH SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280411000777",
    },
    {
        "school": "RIPLEY HIGH SCHOOL",
        "district": "SOUTH TIPPAH SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280411000778",
    },
    {
        "school": "RIPLEY MIDDLE SCHOOL",
        "district": "SOUTH TIPPAH SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280411000779",
    },
    {
        "school": "NORTH SOUTH TIPPAH VOC TECH CENTER",
        "district": "SOUTH TIPPAH SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280411001090",
    },
    {
        "school": "BELMONT SCHOOL",
        "district": "TISHOMINGO CO SP MUN SCH DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280426000803",
    },
    {
        "school": "BURNSVILLE ELEMENTARY",
        "district": "TISHOMINGO CO SP MUN SCH DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280426000804",
    },
    {
        "school": "TISHOMINGO ELEMENTARY",
        "district": "TISHOMINGO CO SP MUN SCH DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280426000805",
    },
    {
        "school": "TISH. CO. CAREER AND TECHNICAL CENT",
        "district": "TISHOMINGO CO SP MUN SCH DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280426000806",
    },
    {
        "school": "TISHOMINGO CO ALTERNATIVE SCHOOL",
        "district": "TISHOMINGO CO SP MUN SCH DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280426000927",
    },
    {
        "school": "IUKA ELEMENTARY SCHOOL",
        "district": "TISHOMINGO CO SP MUN SCH DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280426001225",
    },
    {
        "school": "IUKA MIDDLE SCHOOL",
        "district": "TISHOMINGO CO SP MUN SCH DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280426001226",
    },
    {
        "school": "TISHOMINGO COUNTY HIGH SCHOOL",
        "district": "TISHOMINGO CO SP MUN SCH DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280426001227",
    },
    {
        "school": "NEW ALBANY HIGH SCHOOL",
        "district": "NEW ALBANY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280312000615",
    },
    {
        "school": "NEW ALBANY MIDDLE SCHOOL",
        "district": "NEW ALBANY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280312000618",
    },
    {
        "school": "SCHOOL OF CAREER AND TECHNICAL ED",
        "district": "NEW ALBANY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280312000620",
    },
    {
        "school": "NEW ALBANY/S.TIPPAH/UNION CO. ALT",
        "district": "NEW ALBANY PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280312000944",
    },
    {
        "school": "EAST UNION ATTENDANCE CENTER",
        "district": "UNION CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280435000821",
    },
    {
        "school": "INGOMAR ATTENDANCE CENTER",
        "district": "UNION CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280435000822",
    },
    {
        "school": "MYRTLE ATTENDANCE CENTER",
        "district": "UNION CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280435000823",
    },
    {
        "school": "WEST UNION ATTENDANCE CENTER",
        "district": "UNION CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280435000824",
    },
    {
        "school": "DEXTER ELEMENTARY SCHOOL",
        "district": "WALTHALL CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280444000833",
    },
    {
        "school": "SALEM ATTENDANCE CENTER",
        "district": "WALTHALL CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280444000834",
    },
    {
        "school": "TYLERTOWN ELEMENTARY SCHOOL",
        "district": "WALTHALL CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280444000835",
    },
    {
        "school": "TYLERTOWN HIGH SCHOOL",
        "district": "WALTHALL CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280444000836",
    },
    {
        "school": "WALTHALL CO CAREER AND TECH CENTER",
        "district": "WALTHALL CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280444001015",
    },
    {
        "school": "TYLERTOWN PRIMARY SCHOOL",
        "district": "WALTHALL CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280444001148",
    },
    {
        "school": "BEAT FOUR ELEMENTARY SCHOOL",
        "district": "WAYNE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280453000846",
    },
    {
        "school": "CLARA ELEMENTARY SCHOOL",
        "district": "WAYNE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280453000848",
    },
    {
        "school": "WAYNE CENTRAL ELEMENTARY SCHOOL",
        "district": "WAYNE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280453000849",
    },
    {
        "school": "WAYNE COUNTY HIGH SCHOOL",
        "district": "WAYNE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280453000850",
    },
    {
        "school": "WAYNESBORO RIVERVIEW ELE SCHOOL",
        "district": "WAYNE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280453000851",
    },
    {
        "school": "BUCKATUNNA ELEMENTARY SCHOOL",
        "district": "WAYNE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280453000898",
    },
    {
        "school": "WAYNE COUNTY ALTERNATIVE SCHOOL",
        "district": "WAYNE CO SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280453000997",
    },
    {
        "school": "WAYNE CO CAREER & TECHNICAL",
        "district": "WAYNE CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280453001096",
    },
    {
        "school": "EAST WEBSTER HIGH SCHOOL",
        "district": "WEBSTER CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280456000852",
    },
    {
        "school": "EUPORA ELEMENTARY SCHOOL",
        "district": "WEBSTER CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280456000853",
    },
    {
        "school": "EAST WEBSTER ELEMENTARY SCHOOL",
        "district": "WEBSTER CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280456000855",
    },
    {
        "school": "WEBSTER CO CAREER & TECHNOL CTR",
        "district": "WEBSTER CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280456000856",
    },
    {
        "school": "EUPORA HIGH SCHOOL",
        "district": "WEBSTER CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280456001097",
    },
    {
        "school": "FINCH ELEMENTARY",
        "district": "WILKINSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280471000877",
    },
    {
        "school": "MARTIN L KING CAREER TECHNOLOGY",
        "district": "WILKINSON CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280471000878",
    },
    {
        "school": "WILKINSON COUNTY HIGH",
        "district": "WILKINSON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280471000879",
    },
    {
        "school": "WILKINSON COUNTY ELEMENTARY",
        "district": "WILKINSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280471001149",
    },
    {
        "school": "LOUISVILLE ELEMENTARY SCHOOL",
        "district": "LOUISVILLE MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280270000522",
    },
    {
        "school": "LOUISVILLE HIGH SCHOOL",
        "district": "LOUISVILLE MUNICIPAL SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280270000523",
    },
    {
        "school": "EILAND MIDDLE SCHOOL",
        "district": "LOUISVILLE MUNICIPAL SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280270000524",
    },
    {
        "school": "WINSTON LOUISVILLE VOC CENTER",
        "district": "LOUISVILLE MUNICIPAL SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280270000525",
    },
    {
        "school": "NANIH WAIYA ATTENDANCE CENTER",
        "district": "LOUISVILLE MUNICIPAL SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280270000526",
    },
    {
        "school": "NOXAPATER ATTENDANCE CENTER",
        "district": "LOUISVILLE MUNICIPAL SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280270000527",
    },
    {
        "school": "FAIR ELEMENTARY SCHOOL",
        "district": "LOUISVILLE MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280270001156",
    },
    {
        "school": "COFFEEVILLE HIGH SCHOOL",
        "district": "COFFEEVILLE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280114000146",
    },
    {
        "school": "COFFEEVILLE ELEMENTARY SCHOOL",
        "district": "COFFEEVILLE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280114001108",
    },
    {
        "school": "WATER VALLEY HIGH SCHOOL",
        "district": "WATER VALLEY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280450000845",
    },
    {
        "school": "DAVIDSON ELEMENTARY SCHOOL",
        "district": "WATER VALLEY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280450001095",
    },
    {
        "school": "MS SCHOOL FOR THE ARTS",
        "district": "MS SCHOOL FOR THE ARTS",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280003101574",
    },
    {
        "school": "ALEXANDER JUNIOR HIGH SCHOOL",
        "district": "BROOKHAVEN SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280084000090",
    },
    {
        "school": "BROOKHAVEN ELEMENTARY SCHOOL",
        "district": "BROOKHAVEN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280084000091",
    },
    {
        "school": "BROOKHAVEN HIGH SCHOOL",
        "district": "BROOKHAVEN SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280084000092",
    },
    {
        "school": "BROOKHAVEN TECHNICAL CENTER",
        "district": "BROOKHAVEN SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280084000093",
    },
    {
        "school": "LIPSEY SCHOOL",
        "district": "BROOKHAVEN SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280084000094",
    },
    {
        "school": "MAMIE MARTIN ELEMENTARY SCHOOL",
        "district": "BROOKHAVEN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280084000095",
    },
    {
        "school": "MULLINS SCHOOL",
        "district": "BROOKHAVEN SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280084000952",
    },
    {
        "school": "BOGUE CHITTO SCHOOL",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280264000512",
    },
    {
        "school": "ENTERPRISE SCHOOL",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280264000513",
    },
    {
        "school": "LOYD STAR SCHOOL",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280264000515",
    },
    {
        "school": "WEST LINCOLN SCHOOL",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280264000516",
    },
    {
        "school": "CLARKSDALE HIGH SCHOOL",
        "district": "CLARKSDALE MUNICIPAL SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280105000118",
    },
    {
        "school": "W.A. HIGGINS MIDDLE SCHOOL ACADEMY",
        "district": "CLARKSDALE MUNICIPAL SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280105000119",
    },
    {
        "school": "HEIDELBERG SCHOOL MATH & SCIENCE",
        "district": "CLARKSDALE MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280105000121",
    },
    {
        "school": "KIRKPATRICK  HEALTH /WELLNESS",
        "district": "CLARKSDALE MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280105000122",
    },
    {
        "school": "OAKHURST INTERMEDIATE ACADEMY",
        "district": "CLARKSDALE MUNICIPAL SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280105000123",
    },
    {
        "school": "GEO H OLIVER VISUAL/PERF. ARTS",
        "district": "CLARKSDALE MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280105000124",
    },
    {
        "school": "JEROME W. STAMPLEY 9TH GRADE ACADEM",
        "district": "CLARKSDALE MUNICIPAL SCHOOL DIST",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280105000126",
    },
    {
        "school": "CARL KEEN VOC",
        "district": "CLARKSDALE MUNICIPAL SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280105000127",
    },
    {
        "school": "BOOKER T WASHINGTON INTERN. STUDIES",
        "district": "CLARKSDALE MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280105000128",
    },
    {
        "school": "COAHOMA EARLY COLLEGE HIGH SCHOOL",
        "district": "COAHOMA EARLY COLLEGE",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280110000137",
    },
    {
        "school": "COAHOMA COUNTY JR/SR HIGH SCHOOL",
        "district": "COAHOMA COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280111000139",
    },
    {
        "school": "FRIARS POINT ELEMENTARY SCHOOL",
        "district": "COAHOMA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280111000141",
    },
    {
        "school": "LYON ELEMENTARY SCHOOL",
        "district": "COAHOMA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280111000143",
    },
    {
        "school": "SHERARD ELEMENTARY SCHOOL",
        "district": "COAHOMA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280111000145",
    },
    {
        "school": "JONESTOWN ELEMENTARY SCHOOL",
        "district": "COAHOMA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280111000895",
    },
    {
        "school": "BELL ELEMENTARY SCHOOL",
        "district": "CLEVELAND SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280075000075",
    },
    {
        "school": "CLEVELAND VOC TECH COMPLEX",
        "district": "CLEVELAND SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280075000077",
    },
    {
        "school": "NAILOR ELEMENTARY SCHOOL",
        "district": "CLEVELAND SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280075000083",
    },
    {
        "school": "PARKS ELEMENTARY SCHOOL",
        "district": "CLEVELAND SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280075000084",
    },
    {
        "school": "PEARMAN ELEMENTARY SCHOOL",
        "district": "CLEVELAND SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280075000085",
    },
    {
        "school": "HAYES COOPER CENTER FOR MATH SC TEC",
        "district": "CLEVELAND SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280075001212",
    },
    {
        "school": "MS SCHOOL FOR MATH AND SCIENCE",
        "district": "MS SCHOOL FOR MATH AND SCIENCE",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280119401201",
    },
    {
        "school": "STOKES BEARD ELEMENTARY SCHOOL",
        "district": "COLUMBUS MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280120000152",
    },
    {
        "school": "COLUMBUS HIGH SCHOOL",
        "district": "COLUMBUS MUNICIPAL SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280120000154",
    },
    {
        "school": "COOK ELEMENTARY SCHOOL",
        "district": "COLUMBUS MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280120000156",
    },
    {
        "school": "FAIRVIEW ELEMENTARY SCHOOL",
        "district": "COLUMBUS MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280120000158",
    },
    {
        "school": "FRANKLIN ACADEMY",
        "district": "COLUMBUS MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280120000159",
    },
    {
        "school": "SALE ELEMENTARY SCHOOL",
        "district": "COLUMBUS MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280120000164",
    },
    {
        "school": "MCKELLAR VOCATIONAL CENTER",
        "district": "COLUMBUS MUNICIPAL SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280120000166",
    },
    {
        "school": "CMSD ALTERNATIVE SCHOOL",
        "district": "COLUMBUS MUNICIPAL SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280120000616",
    },
    {
        "school": "CALEDONIA ELEMENTARY SCHOOL",
        "district": "LOWNDES CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280273000528",
    },
    {
        "school": "WEST LOWNDES HIGH SCHOOL",
        "district": "LOWNDES CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280273000531",
    },
    {
        "school": "NEW HOPE ELEMENTARY SCHOOL",
        "district": "LOWNDES CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280273000532",
    },
    {
        "school": "CALEDONIA HIGH SCHOOL",
        "district": "LOWNDES CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280273001125",
    },
    {
        "school": "CALEDONIA MIDDLE SCHOOL",
        "district": "LOWNDES CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280273001126",
    },
    {
        "school": "NEW HOPE HIGH SCHOOL",
        "district": "LOWNDES CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280273001127",
    },
    {
        "school": "NEW HOPE MIDDLE SCHOOL",
        "district": "LOWNDES CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280273001128",
    },
    {
        "school": "WEST LOWNDES ELEMENTARY",
        "district": "LOWNDES CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280273001177",
    },
    {
        "school": "KOSSUTH MIDDLE SCHOOL",
        "district": "ALCORN SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280039001566",
    },
    {
        "school": "ALCORN CO VOC COMPLEX",
        "district": "ALCORN SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280039000016",
    },
    {
        "school": "BIGGERSVILLE ELEMENTARY",
        "district": "ALCORN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280039000017",
    },
    {
        "school": "ALCORN CENTRAL HIGH SCHOOL",
        "district": "ALCORN SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280039000018",
    },
    {
        "school": "KOSSUTH HIGH SCHOOL",
        "district": "ALCORN SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280039000020",
    },
    {
        "school": "Alcorn ALTERNATIVE SCHOOL",
        "district": "ALCORN SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280039000837",
    },
    {
        "school": "ALCORN CENTRAL ELEMENTARY SCHOOL",
        "district": "ALCORN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280039001150",
    },
    {
        "school": "KOSSUTH ELEMENTARY SCHOOL",
        "district": "ALCORN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280039001151",
    },
    {
        "school": "BIGGERSVILLE HIGH SCHOOL",
        "district": "ALCORN SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280039001152",
    },
    {
        "school": "ALCORN CENTRAL MIDDLE SCHOOL",
        "district": "ALCORN SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280039001188",
    },
    {
        "school": "CORINTH MIDDLE SCHOOL",
        "district": "CORINTH SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280126000006",
    },
    {
        "school": "CORINTH HIGH SCHOOL",
        "district": "CORINTH SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280126000171",
    },
    {
        "school": "HOLLANDALE ALTERNATIVE PROGRAM",
        "district": "HOLLANDALE SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280189001273",
    },
    {
        "school": "AKIN ELEMENTARY SCHOOL",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280162000236",
    },
    {
        "school": "ARMSTRONG ELEMENTARY SCHOOL",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280162000237",
    },
    {
        "school": "BOYD ELEMENTARY SCHOOL",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280162000239",
    },
    {
        "school": "COLEMAN MIDDLE SCHOOL",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280162000240",
    },
    {
        "school": "GREENVILLE TECHNICAL CENTER",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280162000243",
    },
    {
        "school": "GREENVILLE HIGH SCHOOL",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280162000244",
    },
    {
        "school": "MC BRIDE PRE-K ACADEMY",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280162000247",
    },
    {
        "school": "STERN ELEMENTARY SCHOOL",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280162000249",
    },
    {
        "school": "TRIGG ELEMENTARY SCHOOL",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280162000250",
    },
    {
        "school": "WEBB PREPARATORY SCHOOL",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280162000251",
    },
    {
        "school": "WEDDINGTON ELEMENTARY SCHOOL",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280162000252",
    },
    {
        "school": "SANDERS ELEMENTARY SCHOOL",
        "district": "HOLLANDALE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280189000333",
    },
    {
        "school": "SIMMONS HIGH SCHOOL",
        "district": "HOLLANDALE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280189001037",
    },
    {
        "school": "EDNA M SCOTT ELEMENTARY SCHOOL",
        "district": "LELAND SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280261000509",
    },
    {
        "school": "LELAND CAREER & TECHNICAL CENTER",
        "district": "LELAND SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280261000510",
    },
    {
        "school": "LELAND HIGH SCHOOL",
        "district": "LELAND SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280261001059",
    },
    {
        "school": "O'BANNON ELEMENTARY SCHOOL",
        "district": "WESTERN LINE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280468000875",
    },
    {
        "school": "RIVERSIDE ELEMENTARY SCHOOL",
        "district": "WESTERN LINE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280468000876",
    },
    {
        "school": "O'BANNON HIGH SCHOOL",
        "district": "WESTERN LINE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280468000975",
    },
    {
        "school": "RIVERSIDE HIGH SCHOOL",
        "district": "WESTERN LINE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280468000976",
    },
    {
        "school": "J Z GEORGE HIGH SCHOOL",
        "district": "CARROLL COUNTY SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280093000104",
    },
    {
        "school": "MARSHALL ELEMENTARY SCHOOL",
        "district": "CARROLL COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280093000105",
    },
    {
        "school": "GRENADA HIGH",
        "district": "GRENADA SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280168000262",
    },
    {
        "school": "GRENADA VOC COMPLEX",
        "district": "GRENADA SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280168000263",
    },
    {
        "school": "GRENADA MIDDLE SCHOOL",
        "district": "GRENADA SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280168000264",
    },
    {
        "school": "GRENADA ENRICHMENT & TRANSITION CEN",
        "district": "GRENADA SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280168000266",
    },
    {
        "school": "GRENADA ELEMENTARY SCHOOL",
        "district": "GRENADA SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280168000900",
    },
    {
        "school": "BILOXI JUNIOR HIGH",
        "district": "BILOXI PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280063001107",
    },
    {
        "school": "NICHOLS ELEMENTARY SCHOOL",
        "district": "BILOXI PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280063001263",
    },
    {
        "school": "PERKINSTON ELEMENTARY SCHOOL",
        "district": "STONE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280417000788",
    },
    {
        "school": "STONE ELEMENTARY SCHOOL",
        "district": "STONE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280417000789",
    },
    {
        "school": "STONE HIGH SCHOOL",
        "district": "STONE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280417000790",
    },
    {
        "school": "STONE MIDDLE SCHOOL",
        "district": "STONE CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280417000791",
    },
    {
        "school": "BAY HIGH SCHOOL",
        "district": "BAY ST LOUIS WAVELAND SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280057000045",
    },
    {
        "school": "NORTH BAY ELEMENTARY SCHOOL",
        "district": "BAY ST LOUIS WAVELAND SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280057000046",
    },
    {
        "school": "Bay Waveland Middle School",
        "district": "BAY ST LOUIS WAVELAND SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280057001233",
    },
    {
        "school": "SOUTH HANCOCK ELEMENTARY SCHOOL",
        "district": "HANCOCK CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280174000280",
    },
    {
        "school": "HANCOCK NORTH CENTRAL ELEMENTARY",
        "district": "HANCOCK CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280174000281",
    },
    {
        "school": "EAST HANCOCK ELEMENTARY SCHOOL",
        "district": "HANCOCK CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280174000982",
    },
    {
        "school": "HANCOCK HIGH SCHOOL",
        "district": "HANCOCK CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280174001153",
    },
    {
        "school": "HANCOCK COUNTY CAREER TECHNICAL CEN",
        "district": "HANCOCK CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280174001215",
    },
    {
        "school": "HANCOCK MIDDLE SCHOOL",
        "district": "HANCOCK CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280174001232",
    },
    {
        "school": "BILOXI HIGH SCHOOL",
        "district": "BILOXI PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280063000053",
    },
    {
        "school": "JEFF DAVIS ELEMENTARY SCHOOL",
        "district": "BILOXI PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280063000055",
    },
    {
        "school": "GORENFLO ELEMENTARY SCHOOL",
        "district": "BILOXI PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280063000058",
    },
    {
        "school": "POPPS FERRY ELEMENTARY SCHOOL",
        "district": "BILOXI PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280063000063",
    },
    {
        "school": "R D BROWN VOC CENTER",
        "district": "BILOXI PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280063000901",
    },
    {
        "school": "NORTH BAY ELEMENTARY SCHOOL",
        "district": "BILOXI PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280063001234",
    },
    {
        "school": "LOPEZ SCHOOL",
        "district": "BILOXI PUBLIC SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280063001235",
    },
    {
        "school": "ANNISTON AVENUE ELEMENTARY SCHOOL",
        "district": "GULFPORT SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280171000268",
    },
    {
        "school": "BAYOU VIEW ELEMENTARY SCHOOL",
        "district": "GULFPORT SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280171000269",
    },
    {
        "school": "BAYOU VIEW MIDDLE SCHOOL",
        "district": "GULFPORT SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280171000270",
    },
    {
        "school": "CENTRAL ELEM",
        "district": "GULFPORT SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280171000271",
    },
    {
        "school": "GULFPORT CENTRAL MIDDLE SCHOOL",
        "district": "GULFPORT SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280171000272",
    },
    {
        "school": "GULFPORT HIGH SCHOOL",
        "district": "GULFPORT SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280171000276",
    },
    {
        "school": "PASS ROAD ELEMENTARY SCHOOL",
        "district": "GULFPORT SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280171000277",
    },
    {
        "school": "WEST ELEMENTARY SCHOOL",
        "district": "GULFPORT SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280171000279",
    },
    {
        "school": "THE LEARNING CENTER",
        "district": "GULFPORT SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280171000508",
    },
    {
        "school": "GULFPORT VOCATIONAL ANNEX",
        "district": "GULFPORT SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280171001113",
    },
    {
        "school": "BEL AIRE ELEMENTARY SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000283",
    },
    {
        "school": "DIBERVILLE ELEM",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000284",
    },
    {
        "school": "DIBERVILLE SENIOR HIGH SCH",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000285",
    },
    {
        "school": "DIBERVILLE MIDDLE SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000286",
    },
    {
        "school": "HARRISON CENTRAL ELEMENTARY",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000287",
    },
    {
        "school": "HARRISON CENTRAL HIGH SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000288",
    },
    {
        "school": "HARRISON CO CHILD DEVELOPMENT CEN",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000289",
    },
    {
        "school": "HARRISON CO VOC COMPLEX",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280177000290",
    },
    {
        "school": "LIZANA ELEMENTARY SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000291",
    },
    {
        "school": "LYMAN ELEMENTARY SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000292",
    },
    {
        "school": "ORANGE GROVE ELEMENTARY",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000295",
    },
    {
        "school": "PINEVILLE ELEMENTARY SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000296",
    },
    {
        "school": "SAUCIER ELEMENTARY SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000297",
    },
    {
        "school": "WOOLMARKET ELEMENTARY SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000298",
    },
    {
        "school": "THREE RIVERS ELEMENTARY",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000913",
    },
    {
        "school": "NORTH WOOLMARKET ELEMENTARY AND MID",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000958",
    },
    {
        "school": "WEST WORTHAM ELEMENTARY AND MIDDLE",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177000959",
    },
    {
        "school": "HARRISON COUNTY ALTERNATIVE SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280177000960",
    },
    {
        "school": "HARPER MC CAUGHAN ELEM SCHOOL",
        "district": "LONG BEACH SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280267000517",
    },
    {
        "school": "THOMAS L REEVES ELEMENTARY SCHOOL",
        "district": "LONG BEACH SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280267000518",
    },
    {
        "school": "LONG BEACH MIDDLE SCHOOL",
        "district": "LONG BEACH SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280267000519",
    },
    {
        "school": "LONG BEACH SENIOR HIGH SCHOOL",
        "district": "LONG BEACH SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280267000520",
    },
    {
        "school": "WJ QUARLES ELEMENTARY SCHOOL",
        "district": "LONG BEACH SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280267000521",
    },
    {
        "school": "DELISLE ELEMENTARY SCHOOL",
        "district": "PASS CHRISTIAN PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280351000682",
    },
    {
        "school": "PASS CHRISTIAN ELEM",
        "district": "PASS CHRISTIAN PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280351000683",
    },
    {
        "school": "PASS CHRISTIAN HIGH SCHOOL",
        "district": "PASS CHRISTIAN PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280351000684",
    },
    {
        "school": "PASS CHRISTIAN MIDDLE",
        "district": "PASS CHRISTIAN PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280351000685",
    },
    {
        "school": "MARY BETHUNE ALTERNATIVE",
        "district": "HATTIESBURG PUBLIC SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280180001019",
    },
    {
        "school": "HAWKINS ELEMENTARY SCHOOL",
        "district": "HATTIESBURG PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280180001570",
    },
    {
        "school": "ROWAN ELEMENTARY SCHOOL",
        "district": "HATTIESBURG PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280180001571",
    },
    {
        "school": "OAK GROVE MIDDLE SCHOOL",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001253",
    },
    {
        "school": "PURVIS MIDDLE SCHOOL",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001254",
    },
    {
        "school": "SOUTH PERRY ELEMENTARY SCHOOL",
        "district": "PERRY CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280357000687",
    },
    {
        "school": "PERRY CENTRAL MIDDLE SCHOOL",
        "district": "PERRY CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280357000689",
    },
    {
        "school": "RUNNELSTOWN ELEMENTARY SCHOOL",
        "district": "PERRY CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280357000690",
    },
    {
        "school": "PERRY COUNTY ALTERNATIVE CENTER",
        "district": "PERRY CO SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280357000941",
    },
    {
        "school": "PERRY CENTRAL HIGH SCHOOL",
        "district": "PERRY CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280357001071",
    },
    {
        "school": "PERRY CO VOC COMPLEX",
        "district": "PERRY CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280357001209",
    },
    {
        "school": "RICHTON HIGH SCHOOL",
        "district": "RICHTON SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280387000744",
    },
    {
        "school": "RICHTON ELEMENTARY SCHOOL",
        "district": "RICHTON SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280387001164",
    },
    {
        "school": "DIXIE ATTENDANCE CENTER",
        "district": "FORREST COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280149000216",
    },
    {
        "school": "NORTH FORREST ATTENDANCE CENTER",
        "district": "FORREST COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280149000217",
    },
    {
        "school": "NORTH FORREST HIGH SCHOOL",
        "district": "FORREST COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280149000218",
    },
    {
        "school": "RAWLS SPRINGS ATTENDANCE CENTER",
        "district": "FORREST COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280149000219",
    },
    {
        "school": "SOUTH FORREST ATTENDANCE CENTER",
        "district": "FORREST COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280149000220",
    },
    {
        "school": "EARL TRAVILLION ATTENDANCE CENTER",
        "district": "FORREST COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280149000221",
    },
    {
        "school": "FORREST COUNTY AGRICULTURAL HI SCH",
        "district": "FORREST COUNTY AG HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280151000222",
    },
    {
        "school": "GRACE CHRISTIAN ELEMENTARY SCHOOL",
        "district": "HATTIESBURG PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280180000302",
    },
    {
        "school": "HATTIESBURG HIGH SCHOOL",
        "district": "HATTIESBURG PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280180000310",
    },
    {
        "school": "THAMES ELEMENTARY SCHOOL",
        "district": "HATTIESBURG PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280180000311",
    },
    {
        "school": "WOODLEY ELEMENTARY SCHOOL",
        "district": "HATTIESBURG PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280180000314",
    },
    {
        "school": "N R BURGER MIDDLE SCHOOL",
        "district": "HATTIESBURG PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280180000980",
    },
    {
        "school": "PETAL MIDDLE SCHOOL",
        "district": "PETAL SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280353000005",
    },
    {
        "school": "PETAL UPPER ELEMENTARY SCHOOL",
        "district": "PETAL SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280353000007",
    },
    {
        "school": "PETAL PRIMARY SCHOOL",
        "district": "PETAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280353001067",
    },
    {
        "school": "PETAL HIGH SCHOOL",
        "district": "PETAL SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280353001068",
    },
    {
        "school": "BAXTERVILLE SCHOOL",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240000464",
    },
    {
        "school": "PURVIS LOWER ELEMENTARY",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240000968",
    },
    {
        "school": "SUMRALL ELEMENTARY SCHOOL",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240000969",
    },
    {
        "school": "JEFFERSON/TODD ALTERNATIVE PROGRAM",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280240000987",
    },
    {
        "school": "OAK GROVE HIGH SCHOOL",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001171",
    },
    {
        "school": "PURVIS HIGH SCHOOL",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001172",
    },
    {
        "school": "SUMRALL  HIGH SCHOOL",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001173",
    },
    {
        "school": "LAMAR CO VOC TECH CENTER",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280240001200",
    },
    {
        "school": "OAK GROVE PRIMARY",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001239",
    },
    {
        "school": "OAK GROVE UPPER  ELEMENTARY",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001240",
    },
    {
        "school": "MCWILLIE ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219001242",
    },
    {
        "school": "RIDGELAND HIGH SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001257",
    },
    {
        "school": "ROSA SCOTT SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001267",
    },
    {
        "school": "NORTHSHORE ELEMENTARY",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001270",
    },
    {
        "school": "OAKDALE ELEMENTARY",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001271",
    },
    {
        "school": "STEEN'S CREEK ELEMENTARY",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001277",
    },
    {
        "school": "CRYSTAL SPRINGS MIDDLE SCHOOL",
        "district": "COPIAH CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280122000167",
    },
    {
        "school": "CRYSTAL SPRINGS HIGH SCHOOL",
        "district": "COPIAH CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280122000168",
    },
    {
        "school": "WESSON ATTENDANCE CENTER",
        "district": "COPIAH CO SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280122000169",
    },
    {
        "school": "CRYSTAL SPRINGS ELEMENTARY",
        "district": "COPIAH CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280122001189",
    },
    {
        "school": "HAZLEHURST HIGH SCHOOL",
        "district": "HAZLEHURST CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280183000315",
    },
    {
        "school": "HAZLEHURST MIDDLE SCHOOL",
        "district": "HAZLEHURST CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280183000316",
    },
    {
        "school": "MAGEE HIGH SCHOOL",
        "district": "SIMPSON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280399000755",
    },
    {
        "school": "MENDENHALL ELEMENTARY SCHOOL",
        "district": "SIMPSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280399000756",
    },
    {
        "school": "SIMPSON CENTRAL SCHOOL",
        "district": "SIMPSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280399000757",
    },
    {
        "school": "SIMPSON COUNTY ACHIEVEMENT CENTER",
        "district": "SIMPSON CO SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280399000942",
    },
    {
        "school": "MAGEE ELEMENTARY SCHOOL",
        "district": "SIMPSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280399001084",
    },
    {
        "school": "MAGEE MIDDLE SCHOOL",
        "district": "SIMPSON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280399001085",
    },
    {
        "school": "MENDENHALL HIGH SCHOOL",
        "district": "SIMPSON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280399001086",
    },
    {
        "school": "MENDENHALL JUNIOR HIGH SCHOOL",
        "district": "SIMPSON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280399001087",
    },
    {
        "school": "SIMPSON CO TECHNICAL CENTER",
        "district": "SIMPSON CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280399001088",
    },
    {
        "school": "CARVER MIDDLE SCHOOL",
        "district": "HINDS CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280186000322",
    },
    {
        "school": "CLINTON HIGH SCHOOL",
        "district": "CLINTON PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280109000131",
    },
    {
        "school": "CLINTON JR HI SCHOOL",
        "district": "CLINTON PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280109000132",
    },
    {
        "school": "CLINTON PARK ELEM SCHOOL",
        "district": "CLINTON PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280109000133",
    },
    {
        "school": "CLINTON VOC COMPLEX",
        "district": "CLINTON PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280109000134",
    },
    {
        "school": "EASTSIDE ELEM",
        "district": "CLINTON PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280109000135",
    },
    {
        "school": "NORTHSIDE ELEM",
        "district": "CLINTON PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280109000136",
    },
    {
        "school": "CLINTON ALTERNATIVE SCHOOL",
        "district": "CLINTON PUBLIC SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280109000948",
    },
    {
        "school": "LOVETT ELEM SCHOOL",
        "district": "CLINTON PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280109001028",
    },
    {
        "school": "SUMNER HILL JR HI SCHOOL",
        "district": "CLINTON PUBLIC SCHOOL DIST",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280109001029",
    },
    {
        "school": "MS SCHOOL FOR THE BLIND",
        "district": "MS SCHS FOR THE BLIND AND DEAF",
        "level": "Other",
        "type": "Special education school",
        "state": "MS",
        "nces_id": "280118901194",
    },
    {
        "school": "WILLIAMS SCHOOL",
        "district": "MDHS DIVISION OF YOUTH SERVICES",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280119101197",
    },
    {
        "school": "BYRAM MIDDLE SCHOOL",
        "district": "HINDS CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280186000321",
    },
    {
        "school": "HINDS CO CAREER/TECHNICAL CENTER",
        "district": "HINDS CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280186000324",
    },
    {
        "school": "UTICA ELEM. / MIDDLE SCHOOL",
        "district": "HINDS CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280186000326",
    },
    {
        "school": "RAYMOND HIGH SCHOOL",
        "district": "HINDS CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280186000328",
    },
    {
        "school": "TERRY HIGH SCHOOL",
        "district": "HINDS CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280186000902",
    },
    {
        "school": "MAIN STREET ALTERNATIVE SCHOOL",
        "district": "HINDS CO SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280186000914",
    },
    {
        "school": "RAYMOND ELEMENTARY SCHOOL",
        "district": "HINDS CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280186000961",
    },
    {
        "school": "GARY ROAD INTERMEDIATE SCHOOL",
        "district": "HINDS CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280186000983",
    },
    {
        "school": "BOLTON-EDWARDS ELEM./MIDDLE SCHOOL",
        "district": "HINDS CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280186000984",
    },
    {
        "school": "GARY ROAD ELEMENTARY",
        "district": "HINDS CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280186001036",
    },
    {
        "school": "BAKER ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000370",
    },
    {
        "school": "BARR ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000371",
    },
    {
        "school": "BLACKBURN MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000372",
    },
    {
        "school": "BOYD ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000373",
    },
    {
        "school": "BRINKLEY MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000375",
    },
    {
        "school": "CALLAWAY HIGH SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000377",
    },
    {
        "school": "CAREER DEVELOPMENT CENTER",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280219000378",
    },
    {
        "school": "CASEY ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000379",
    },
    {
        "school": "CHASTAIN MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000380",
    },
    {
        "school": "CLAUSELL ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000381",
    },
    {
        "school": "DAWSON ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000382",
    },
    {
        "school": "FOREST HILL HIGH SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000384",
    },
    {
        "school": "GALLOWAY ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000386",
    },
    {
        "school": "GREEN ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000388",
    },
    {
        "school": "HARDY MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000389",
    },
    {
        "school": "JIM HILL HIGH SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000390",
    },
    {
        "school": "ISABLE ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000391",
    },
    {
        "school": "JOHN HOPKINS ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000392",
    },
    {
        "school": "JOHNSON ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000393",
    },
    {
        "school": "KEY ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000394",
    },
    {
        "school": "LAKE ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000395",
    },
    {
        "school": "LANIER HIGH SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000396",
    },
    {
        "school": "LEE ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000397",
    },
    {
        "school": "LESTER ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000398",
    },
    {
        "school": "MARSHALL ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000399",
    },
    {
        "school": "MC LEOD ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000400",
    },
    {
        "school": "MORRISON ACADEMIC ADVANCEMENT CTR",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280219000402",
    },
    {
        "school": "MURRAH HIGH SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000403",
    },
    {
        "school": "OAK FOREST ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000404",
    },
    {
        "school": "PEEPLES MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000405",
    },
    {
        "school": "POWELL MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000407",
    },
    {
        "school": "POWER APAC SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000408",
    },
    {
        "school": "PROVINE HIGH SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000409",
    },
    {
        "school": "RAINES ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000410",
    },
    {
        "school": "ROWAN MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280219000411",
    },
    {
        "school": "SIWELL MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000412",
    },
    {
        "school": "SMITH ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000413",
    },
    {
        "school": "SPANN ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000414",
    },
    {
        "school": "SYKES ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000415",
    },
    {
        "school": "TIMBERLAWN ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000416",
    },
    {
        "school": "VAN WINKLE ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000417",
    },
    {
        "school": "WALTON ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000418",
    },
    {
        "school": "WATKINS ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000419",
    },
    {
        "school": "PECAN PARK ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000420",
    },
    {
        "school": "WHITTEN MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000421",
    },
    {
        "school": "WILKINS ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000422",
    },
    {
        "school": "WINGFIELD HIGH SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219000423",
    },
    {
        "school": "CAREER ACADEMIC PLACEMENT PROGRAM",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280219000542",
    },
    {
        "school": "CAPITAL CITY ALTERNATIVE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280219000946",
    },
    {
        "school": "YOUTH COURT SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280219000947",
    },
    {
        "school": "BARACK H OBAMA ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219001052",
    },
    {
        "school": "NORTH JACKSON ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219001054",
    },
    {
        "school": "NORTHWEST MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219001155",
    },
    {
        "school": "CANTON ELEMENTARY SCHOOL",
        "district": "CANTON PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280090000100",
    },
    {
        "school": "CANTON PUBLIC HIGH SCHOOL",
        "district": "CANTON PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280090000101",
    },
    {
        "school": "MC NEAL ELEMENTARY SCHOOL",
        "district": "CANTON PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280090000102",
    },
    {
        "school": "NICHOLS MIDDLE SCHOOL",
        "district": "CANTON PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280090000103",
    },
    {
        "school": "CANTON EDUCATIONAL SERVICES CENTER",
        "district": "CANTON PUBLIC SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280090000953",
    },
    {
        "school": "CANTON CAREER CENTER",
        "district": "CANTON PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280090001026",
    },
    {
        "school": "MADISON STATION ELEMENTARY SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279000304",
    },
    {
        "school": "LUTHER BRANSON SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279000537",
    },
    {
        "school": "VELMA JACKSON HIGH SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279000541",
    },
    {
        "school": "HIGHLAND ELEMENTARY",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279000937",
    },
    {
        "school": "OLDE TOWNE MIDDLE",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279000938",
    },
    {
        "school": "MADISON CO. ALTERNATIVE SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280279000939",
    },
    {
        "school": "CAMDEN ELEMENTARY",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279000988",
    },
    {
        "school": "SHIRLEY D. SIMMONS MIDDLE SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279000989",
    },
    {
        "school": "EAST FLORA ELEMENTARY",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001006",
    },
    {
        "school": "MADISON AVENUE UPPER ELEMENTARY",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001007",
    },
    {
        "school": "ANN SMITH ELEMENTARY",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001081",
    },
    {
        "school": "MADISON MIDDLE SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001082",
    },
    {
        "school": "MADISON CO VOC COMPLEX",
        "district": "MADISON CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280279001129",
    },
    {
        "school": "MADISON AVENUE LOWER ELEMENTARY",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001219",
    },
    {
        "school": "MADISON CENTRAL HIGH SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001220",
    },
    {
        "school": "C B NOBLIN SCHOOL",
        "district": "HUDSPETH CENTER ADMINISTRATION",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280119601210",
    },
    {
        "school": "NORTHSIDE ELEMENTARY SCHOOL",
        "district": "PEARL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280352000001",
    },
    {
        "school": "PEARL LOWER ELEMENTARY SCHOOL",
        "district": "PEARL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280352000002",
    },
    {
        "school": "PEARL HIGH SCHOOL",
        "district": "PEARL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280352000003",
    },
    {
        "school": "PEARL UPPER SCHOOL",
        "district": "PEARL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280352001181",
    },
    {
        "school": "FLOWOOD ELEMENTARY SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000711",
    },
    {
        "school": "RANKIN COUNTY LEARNING CENTER",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280383000712",
    },
    {
        "school": "BRANDON ELEMENTARY SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000736",
    },
    {
        "school": "BRANDON MIDDLE SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000737",
    },
    {
        "school": "FLORENCE MIDDLE SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000738",
    },
    {
        "school": "MCLAURIN ATTENDANCE CENTER",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000739",
    },
    {
        "school": "PELAHATCHIE ATTENDANCE CENTER",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000740",
    },
    {
        "school": "PISGAH ELEMENTARY SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000741",
    },
    {
        "school": "PUCKETT ATTENDANCE CENTER",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000742",
    },
    {
        "school": "RICHLAND HIGH SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000743",
    },
    {
        "school": "MCLAURIN ELEMENTARY SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000924",
    },
    {
        "school": "ROUSE ELEMENTARY",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000954",
    },
    {
        "school": "NORTHWEST RANKIN MIDDLE SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383000955",
    },
    {
        "school": "BRANDON HIGH SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001074",
    },
    {
        "school": "FLORENCE HIGH SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001075",
    },
    {
        "school": "NORTHWEST RANKIN HIGH SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001076",
    },
    {
        "school": "NORTHWEST ELEMENTARY SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001077",
    },
    {
        "school": "PELAHATCHIE ELEMENTARY SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001078",
    },
    {
        "school": "PISGAH HIGH SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001079",
    },
    {
        "school": "RICHLAND ELEMENTARY SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001143",
    },
    {
        "school": "FLORENCE ELEMENTARY SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001163",
    },
    {
        "school": "RICHLAND UPPER ELEMENTARY",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001223",
    },
    {
        "school": "HEIDELBERG HIGH SCHOOL",
        "district": "EAST JASPER CONSOLIDATED SCH DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280138000204",
    },
    {
        "school": "WILLIAM J BERRY ELEMENTARY SCHOOL",
        "district": "EAST JASPER CONSOLIDATED SCH DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280138000205",
    },
    {
        "school": "BAY SPRINGS HIGH SCHOOL",
        "district": "WEST JASPER CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280459000857",
    },
    {
        "school": "BAY SPRINGS ELEM SCH",
        "district": "WEST JASPER CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280459000858",
    },
    {
        "school": "STRINGER ATTENDANCE CENTER",
        "district": "WEST JASPER CONSOLIDATED SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280459000859",
    },
    {
        "school": "BAY SPRINGS MIDDLE SCH",
        "district": "WEST JASPER CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280459000899",
    },
    {
        "school": "ELLISVILLE STATE SCHOOL",
        "district": "ELLISVILLE STATE SCHOOL ADM",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280119201198",
    },
    {
        "school": "JONES CO CAREER & TECH ED CENTER",
        "district": "JONES CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280228000436",
    },
    {
        "school": "GLADE ELEMENTARY SCHOOL",
        "district": "JONES CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280228000439",
    },
    {
        "school": "MOSELLE ELEMENTARY SCHOOL",
        "district": "JONES CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280228000441",
    },
    {
        "school": "NORTHEAST JONES HIGH SCHOOL",
        "district": "JONES CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280228000443",
    },
    {
        "school": "SOUTH JONES HIGH SCHOOL",
        "district": "JONES CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280228000450",
    },
    {
        "school": "WEST JONES HIGH SCHOOL",
        "district": "JONES CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280228000451",
    },
    {
        "school": "JONES COUNTY LEARNING CENTER",
        "district": "JONES CO SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280228000904",
    },
    {
        "school": "EAST JONES ELEMENTARY SCHOOL",
        "district": "JONES CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280228000985",
    },
    {
        "school": "SOUTH JONES ELEMENTARY SCHOOL",
        "district": "JONES CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280228000986",
    },
    {
        "school": "WEST JONES ELEMENTARY SCHOOL",
        "district": "JONES CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280228001237",
    },
    {
        "school": "LAUREL MAGNET SCHOOL OF THE ARTS",
        "district": "LAUREL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280246000472",
    },
    {
        "school": "MASON ELEMENTARY SCHOOL",
        "district": "LAUREL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280246000476",
    },
    {
        "school": "OAK PARK ELEMENTARY SCHOOL",
        "district": "LAUREL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280246000477",
    },
    {
        "school": "LAUREL HIGH SCHOOL",
        "district": "LAUREL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280246000479",
    },
    {
        "school": "LAUREL EDUCATION CENTER",
        "district": "LAUREL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280246000916",
    },
    {
        "school": "LAUREL HIGH SCHOOL VOC COMPLEX",
        "district": "LAUREL SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280246001058",
    },
    {
        "school": "AMITE COUNTY HIGH SCHOOL",
        "district": "AMITE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280042000027",
    },
    {
        "school": "AMITE COUNTY VOC COMPLEX",
        "district": "AMITE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280042001100",
    },
    {
        "school": "MCCOMB MIDDLE SCHOOL",
        "district": "MCCOMB SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280288000554",
    },
    {
        "school": "OTKEN ELEMENTARY SCHOOL",
        "district": "MCCOMB SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280288000555",
    },
    {
        "school": "MCCOMB HIGH SCHOOL",
        "district": "MCCOMB SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280288000556",
    },
    {
        "school": "BUSINESS & TECHNOLOGY COMPLEX",
        "district": "MCCOMB SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280288000557",
    },
    {
        "school": "DENMAN JUNIOR HIGH SCHOOL",
        "district": "MCCOMB SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280288000972",
    },
    {
        "school": "KENNEDY ELEMENTARY SCHOOL",
        "district": "MCCOMB SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280288001061",
    },
    {
        "school": "NORTH PIKE ELEMENTARY SCHOOL",
        "district": "NORTH PIKE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280324000634",
    },
    {
        "school": "NORTH PIKE MIDDLE SCHOOL",
        "district": "NORTH PIKE SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280324000635",
    },
    {
        "school": "NORTH PIKE SENIOR HIGH SCHOOL",
        "district": "NORTH PIKE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280324000636",
    },
    {
        "school": "SOUTH PIKE CAREER & TECHNICAL CENTE",
        "district": "SOUTH PIKE SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280408000369",
    },
    {
        "school": "EVA GORDON ELEMENTARY SCHOOL",
        "district": "SOUTH PIKE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280408000768",
    },
    {
        "school": "EVA GORDON UPPER ELEMENTARY SCHOOL",
        "district": "SOUTH PIKE SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280408000769",
    },
    {
        "school": "OSYKA ELEMENTARY SCHOOL",
        "district": "SOUTH PIKE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280408000770",
    },
    {
        "school": "SOUTH PIKE JR HIGH",
        "district": "SOUTH PIKE SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280408000772",
    },
    {
        "school": "SOUTH PIKE SENIOR HIGH SCHOOL",
        "district": "SOUTH PIKE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280408000773",
    },
    {
        "school": "SOUTH PIKE ALTERNATIVE SCHOOL",
        "district": "SOUTH PIKE SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280408000910",
    },
    {
        "school": "CENTER HILL ELEMENTARY SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001018",
    },
    {
        "school": "PLEASANT HILL ELEMENTARY",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001262",
    },
    {
        "school": "LEWISBURG ELEMENTARY SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001275",
    },
    {
        "school": "DESOTO CENTRAL HIGH SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001569",
    },
    {
        "school": "H. W. BYERS ELEMENTARY (K-6)",
        "district": "MARSHALL CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280285001268",
    },
    {
        "school": "TCS ALTERNATIVE SCHOOL",
        "district": "TUNICA COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280429001579",
    },
    {
        "school": "HOLLY SPRINGS HIGH SCHOOL",
        "district": "HOLLY SPRINGS SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280195000335",
    },
    {
        "school": "HOLLY SPRINGS INTERMEDIATE SCHOOL",
        "district": "HOLLY SPRINGS SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280195000336",
    },
    {
        "school": "HOLLY SPRINGS PRIMARY SCHOOL",
        "district": "HOLLY SPRINGS SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280195000337",
    },
    {
        "school": "HOLLY SPRINGS CAREER & TECH CENTER",
        "district": "HOLLY SPRINGS SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280195000338",
    },
    {
        "school": "BYHALIA HIGH SCHOOL (9-12)",
        "district": "MARSHALL CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280285000548",
    },
    {
        "school": "GALENA ELEMENTARY SCHOOL (K-6)",
        "district": "MARSHALL CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280285000549",
    },
    {
        "school": "BYHALIA ELEMENTARY SCHOOL (K-5)",
        "district": "MARSHALL CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280285000550",
    },
    {
        "school": "POTTS CAMP HIGH SCHOOL (7-12)",
        "district": "MARSHALL CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280285000551",
    },
    {
        "school": "MARY REID SCHOOL (K-6)",
        "district": "MARSHALL CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280285000552",
    },
    {
        "school": "H. W. BYERS HIGH SCHOOL (7-12)",
        "district": "MARSHALL CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280285000553",
    },
    {
        "school": "SENATOBIA ELEMENTARY SCHOOL",
        "district": "SENATOBIA MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280393000750",
    },
    {
        "school": "SENATOBIA HIGH SCHOOL",
        "district": "SENATOBIA MUNICIPAL SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280393000751",
    },
    {
        "school": "SENATOBIA MIDDLE SCHOOL",
        "district": "SENATOBIA MUNICIPAL SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280393001083",
    },
    {
        "school": "SEN./TATE CO. OPTIONAL LEARNING CEN",
        "district": "SENATOBIA MUNICIPAL SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280393001252",
    },
    {
        "school": "EAST TATE ELEMENTARY SCHOOL",
        "district": "TATE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280423000799",
    },
    {
        "school": "INDEPENDENCE HIGH SCHOOL",
        "district": "TATE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280423000800",
    },
    {
        "school": "STRAYHORN ELEMENTARY SCHOOL",
        "district": "TATE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280423000801",
    },
    {
        "school": "SENATOBIA TATE CO REGIONAL VOC CTR",
        "district": "TATE CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280423001091",
    },
    {
        "school": "ROSA FORT HIGH SCHOOL",
        "district": "TUNICA COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280429000808",
    },
    {
        "school": "TUNICA MIDDLE SCHOOL",
        "district": "TUNICA COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280429000809",
    },
    {
        "school": "DUNDEE ELEMENTARY SCHOOL",
        "district": "TUNICA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280429000974",
    },
    {
        "school": "ROBINSONVILLE ELEMENTARY SCHOOL",
        "district": "TUNICA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280429001014",
    },
    {
        "school": "DAVID WILLIAMS JR CAREER &TECH CNT",
        "district": "TUNICA COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280429001147",
    },
    {
        "school": "TUNICA ELEMENTARY SCHOOL",
        "district": "TUNICA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280429001185",
    },
    {
        "school": "HERNANDO MIDDLE SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000140",
    },
    {
        "school": "DESOTO CO VOC COMPLEX",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280132000183",
    },
    {
        "school": "GREENBROOK ELEMENTARY SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000185",
    },
    {
        "school": "HERNANDO ELEM",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000186",
    },
    {
        "school": "HERNANDO HIGH SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000187",
    },
    {
        "school": "OAK GROVE CENTRAL ELEMENTARY",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000188",
    },
    {
        "school": "HORN LAKE ELEM",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000189",
    },
    {
        "school": "HORN LAKE HIGH",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000190",
    },
    {
        "school": "HORN LAKE MIDDLE SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000191",
    },
    {
        "school": "OLIVE BRANCH ELEM",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000192",
    },
    {
        "school": "OLIVE BRANCH HIGH SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000193",
    },
    {
        "school": "OLIVE BRANCH MIDDLE",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000194",
    },
    {
        "school": "SOUTHAVEN ELEMENTARY",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000195",
    },
    {
        "school": "SOUTHAVEN HIGH SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000196",
    },
    {
        "school": "HOPE SULLIVAN ELEMENTARY SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000197",
    },
    {
        "school": "WALLS ELEMENTARY SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000198",
    },
    {
        "school": "DESOTO COUNTY ALTERNATIVE CENTER",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280132000493",
    },
    {
        "school": "OLIVE BRANCH INTERMEDIATE SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000932",
    },
    {
        "school": "SOUTHAVEN MIDDLE SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000933",
    },
    {
        "school": "HORN LAKE INTERMEDIATE SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000945",
    },
    {
        "school": "DESOTO CENTRAL MIDDLE SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000979",
    },
    {
        "school": "DESOTO CENTRAL ELEMENTARY SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132000998",
    },
    {
        "school": "CHICKASAW ELEMENTARY SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001190",
    },
    {
        "school": "SHADOW OAKS ELEMENTARY SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001191",
    },
    {
        "school": "QUITMAN ALTERNATIVE SCHOOL",
        "district": "QUITMAN SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280378001567",
    },
    {
        "school": "SOUTHEAST LAUDERDALE ELEMENTARY",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243001573",
    },
    {
        "school": "ENTERPRISE ELEMENTARY",
        "district": "ENTERPRISE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280144000210",
    },
    {
        "school": "ENTERPRISE HIGH SCHOOL",
        "district": "ENTERPRISE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280144000211",
    },
    {
        "school": "ENTERPRISE MIDDLE SCHOOL",
        "district": "ENTERPRISE SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280144000977",
    },
    {
        "school": "QUITMAN JR HIGH SCHOOL",
        "district": "QUITMAN SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280378000723",
    },
    {
        "school": "QUITMAN UPPER ELEMENTARY SCHOOL",
        "district": "QUITMAN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280378000724",
    },
    {
        "school": "QUITMAN HIGH SCHOOL",
        "district": "QUITMAN SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280378000725",
    },
    {
        "school": "QUITMAN LOWER ELEMENTARY SCHOOL",
        "district": "QUITMAN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280378001142",
    },
    {
        "school": "CLARKE CO CAREER & TECHNOLOGY CTR",
        "district": "QUITMAN SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280378001182",
    },
    {
        "school": "EAST KEMPER ATTENDANCE CENTER",
        "district": "KEMPER CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280231000452",
    },
    {
        "school": "STENNIS VOC TECH COMPLEX",
        "district": "KEMPER CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280231000454",
    },
    {
        "school": "WEST KEMPER ELEMENTARY SCHOOL",
        "district": "KEMPER CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280231000455",
    },
    {
        "school": "KEMPER COUNTY HIGH SCHOOL",
        "district": "KEMPER CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280231001116",
    },
    {
        "school": "CLARKDALE MIDDLE SCHOOL",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243000468",
    },
    {
        "school": "NORTHEAST LAUDERDALE HIGH SCHOOL",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243000469",
    },
    {
        "school": "SOUTHEAST LAUDERDALE HIGH SCHOOL",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243000470",
    },
    {
        "school": "WEST LAUDERDALE MIDDLE SCHOOL",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243000471",
    },
    {
        "school": "NORTHEAST LAUDERDALE MIDDLE SCHOOL",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243000568",
    },
    {
        "school": "NORTHEAST LAUDERDALE ELEMENTARY",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243001056",
    },
    {
        "school": "SOUTHEAST LAUDERDALE MIDDLE SCHOOL",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243001174",
    },
    {
        "school": "WEST LAUDERDALE ELEMENTARY SCHOOL",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243001241",
    },
    {
        "school": "GEORGE WASHINGTON CARVER MIDDLE",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280291000559",
    },
    {
        "school": "CRESTWOOD ELEMENTARY SCHOOL",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280291000560",
    },
    {
        "school": "MAGNOLIA MIDDLE SCHOOL",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280291000564",
    },
    {
        "school": "MERIDIAN HIGH SCHOOL",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280291000567",
    },
    {
        "school": "NORTHWEST JUNIOR HIGH SCHOOL",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280291000569",
    },
    {
        "school": "OAKLAND HEIGHTS ELEMENTARY SCHOOL",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280291000570",
    },
    {
        "school": "PARKVIEW ELEMENTARY SCHOOL",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280291000571",
    },
    {
        "school": "POPLAR SPRINGS ELEMENTARY SCHOOL",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280291000572",
    },
    {
        "school": "WEST HILLS ELEMENTARY SCHOOL",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280291000575",
    },
    {
        "school": "T J HARRIS  ELEMENTARY",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280291000917",
    },
    {
        "school": "MARION PARK COMPLEX",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280291000918",
    },
    {
        "school": "ROSS COLLINS VOC CENTER",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280291001132",
    },
    {
        "school": "CENTRAL SCHOOL",
        "district": "NATCHEZ-ADAMS SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280303000453",
    },
    {
        "school": "MC LAURIN ELEMENTARY SCHOOL",
        "district": "NATCHEZ-ADAMS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280303000600",
    },
    {
        "school": "MORGANTOWN MIDDLE",
        "district": "NATCHEZ-ADAMS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280303000602",
    },
    {
        "school": "ROBERT LEWIS MAGNET SCHOOL",
        "district": "NATCHEZ-ADAMS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280303000604",
    },
    {
        "school": "CAREER AND TECHNOLOGY CENTER",
        "district": "NATCHEZ-ADAMS SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280303000605",
    },
    {
        "school": "JOSEPH L FRAZIER ELEMENTARY",
        "district": "NATCHEZ-ADAMS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280303000606",
    },
    {
        "school": "NATCHEZ HIGH SCHOOL",
        "district": "NATCHEZ-ADAMS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280303000608",
    },
    {
        "school": "SUSIE B WEST ELEMENTARY SCHOOL",
        "district": "NATCHEZ-ADAMS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280303000610",
    },
    {
        "school": "STOVALL SPED COMPLEX",
        "district": "STOVALL SPED COMPLEX ADMINISTRATION",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280119301199",
    },
    {
        "school": "LAFAYETTE ELEMENTARY SCHOOL",
        "district": "LAFAYETTE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280237000462",
    },
    {
        "school": "LAFAYETTE HIGH SCHOOL",
        "district": "LAFAYETTE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280237000463",
    },
    {
        "school": "OXF/LAF SCHOOL OF APPLIED TECH",
        "district": "LAFAYETTE CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280237000936",
    },
    {
        "school": "LAFAYETTE MIDDLE SCHOOL",
        "district": "LAFAYETTE CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280237000967",
    },
    {
        "school": "OXFORD LEARNING CENTER",
        "district": "OXFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280345000566",
    },
    {
        "school": "BRAMLETT ELEMENTARY SCHOOL",
        "district": "OXFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280345000661",
    },
    {
        "school": "OXFORD ELEMENTARY SCHOOL",
        "district": "OXFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280345000662",
    },
    {
        "school": "OXFORD HIGH SCHOOL",
        "district": "OXFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280345000663",
    },
    {
        "school": "OXFORD MIDDLE SCHOOL",
        "district": "OXFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280345000664",
    },
    {
        "school": "AGRICOLA ELEMENTARY SCHOOL",
        "district": "GEORGE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280156000226",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "GEORGE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280156000227",
    },
    {
        "school": "GEORGE COUNTY HIGH SCHOOL",
        "district": "GEORGE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280156000228",
    },
    {
        "school": "LC HATCHER ELEMENTARY SCHOOL",
        "district": "GEORGE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280156000229",
    },
    {
        "school": "ROCKY CREEK ELEMENTARY SCHOOL",
        "district": "GEORGE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280156000231",
    },
    {
        "school": "GEORGE COUNTY MIDDLE SCHOOL",
        "district": "GEORGE CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280156000840",
    },
    {
        "school": "LT TAYLOR INTERMEDIATE SCHOOL",
        "district": "GEORGE CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280156000870",
    },
    {
        "school": "BENNDALE ELEMENTARY SCHOOL",
        "district": "GEORGE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280156000981",
    },
    {
        "school": "EAST CENTRAL MIDDLE SCHOOL",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216000364",
    },
    {
        "school": "ST MARTIN N ELEMENTARY SCHOOL",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216000366",
    },
    {
        "school": "VANCLEAVE UPPER ELEMENTARY",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216000368",
    },
    {
        "school": "EAST CENTRAL LOWER ELEMENTARY",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216000962",
    },
    {
        "school": "ST. MARTIN MIDDLE SCHOOL",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216000963",
    },
    {
        "school": "VANCLEAVE LOWER ELEMENTARY",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216000964",
    },
    {
        "school": "EAST CENTRAL UPPER ELEMENTARY",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216001044",
    },
    {
        "school": "EAST CENTRAL HIGH SCHOOL",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216001045",
    },
    {
        "school": "ST MARTIN HIGH SCHOOL",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216001046",
    },
    {
        "school": "ST MARTIN UPPER ELEMENTARY",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216001047",
    },
    {
        "school": "ST MARTIN EAST ELEMENTARY SCHOOL",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216001048",
    },
    {
        "school": "VANCLEAVE MIDDLE SCHOOL",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216001049",
    },
    {
        "school": "VANCLEAVE HIGH SCHOOL",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280216001050",
    },
    {
        "school": "JACKSON COUNTY VOCATIONAL CENTER",
        "district": "JACKSON CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280216001051",
    },
    {
        "school": "MOSS POINT ALTERNATIVE SCHOOL",
        "district": "MOSS POINT SEPARATE SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280300000558",
    },
    {
        "school": "MOSS POINT HIGH SCHOOL",
        "district": "MOSS POINT SEPARATE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280300000587",
    },
    {
        "school": "MOSS POINT ESCATAWPA UPPER ELEM",
        "district": "MOSS POINT SEPARATE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280300000589",
    },
    {
        "school": "MOSS POINT KREOLE PRIMARY SCHOOL",
        "district": "MOSS POINT SEPARATE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280300000591",
    },
    {
        "school": "MAGNOLIA MIDDLE SCHOOL",
        "district": "MOSS POINT SEPARATE SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280300000592",
    },
    {
        "school": "MOSS POINT CAREER & TECHNICAL EDUCA",
        "district": "MOSS POINT SEPARATE SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280300001133",
    },
    {
        "school": "OAK PARK ELEMENTARY SCHOOL",
        "district": "OCEAN SPRINGS SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280336000647",
    },
    {
        "school": "MAGNOLIA PARK ELEMENTARY",
        "district": "OCEAN SPRINGS SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280336000648",
    },
    {
        "school": "OCEAN SPRINGS HIGH SCHOOL",
        "district": "OCEAN SPRINGS SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280336000650",
    },
    {
        "school": "PECAN PARK ELEMENTARY SCHOOL",
        "district": "OCEAN SPRINGS SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280336000652",
    },
    {
        "school": "OCEAN SPRINGS MIDDLE SCHOOL",
        "district": "OCEAN SPRINGS SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280336000934",
    },
    {
        "school": "KEYS VOC CENTER",
        "district": "OCEAN SPRINGS SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280336001066",
    },
    {
        "school": "PASCAGOULA OPPORTUNITY CENTER",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280348000561",
    },
    {
        "school": "ARLINGTON HEIGHTS ELEM SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000666",
    },
    {
        "school": "BEACH ELEMENTARY SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000667",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000668",
    },
    {
        "school": "CHEROKEE ELEMENTARY SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000669",
    },
    {
        "school": "COLLEGE PARK ELEM",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000670",
    },
    {
        "school": "WILLIAM M COLMER MIDDLE SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000671",
    },
    {
        "school": "EASTLAWN ELEMENTARY SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000672",
    },
    {
        "school": "GAUTIER ELEMENTARY SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000674",
    },
    {
        "school": "GAUTIER MIDDLE SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000675",
    },
    {
        "school": "JACKSON ELEMENTARY SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000676",
    },
    {
        "school": "LAKE ELEMENTARY SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000677",
    },
    {
        "school": "PASCAGOULA HIGH SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000678",
    },
    {
        "school": "TRENT LOTT ACADEMY",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000679",
    },
    {
        "school": "SINGING RIVER ACADEMY",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000680",
    },
    {
        "school": "GAUTIER HIGH SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348000935",
    },
    {
        "school": "COLLEGE & CAREER TECHNICAL INST.",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280348001141",
    },
    {
        "school": "EXCEPTIONAL SCHOOL",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348001161",
    },
    {
        "school": "MARTIN BLUFF",
        "district": "PASCAGOULA-GAUTIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280348001236",
    },
    {
        "school": "EARLY HEAD START ROSA STREET",
        "district": "PICAYUNE SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280363001576",
    },
    {
        "school": "PEARL RIVER CENTRAL ELEMENTAR",
        "district": "PEARL RIVER CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280354000686",
    },
    {
        "school": "PEARL RIVER CENTRAL JUNIOR HIGH",
        "district": "PEARL RIVER CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280354001069",
    },
    {
        "school": "PEARL RIVER CENTRAL HIGH SCHOOL",
        "district": "PEARL RIVER CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280354001070",
    },
    {
        "school": "SOUTH SIDE LOWER ELEMENTARY SCHOOL",
        "district": "PICAYUNE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280363000632",
    },
    {
        "school": "CENTER FOR ALTERNATIVE EDUCATION",
        "district": "PICAYUNE SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280363000688",
    },
    {
        "school": "NICHOLSON ELEMENTARY SCHOOL",
        "district": "PICAYUNE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280363000694",
    },
    {
        "school": "PICAYUNE MEMORIAL HIGH SCHOOL",
        "district": "PICAYUNE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280363000695",
    },
    {
        "school": "PMHS CAREER & TECHNOLOGY CENTER",
        "district": "PICAYUNE SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280363000696",
    },
    {
        "school": "PICAYUNE JUNIOR HIGH SCHOOL",
        "district": "PICAYUNE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280363000697",
    },
    {
        "school": "ROSELAND PARK ELEMENTARY SCHOOL",
        "district": "PICAYUNE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280363000698",
    },
    {
        "school": "SOUTH SIDE ELEMENTARY SCHOOL",
        "district": "PICAYUNE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280363000699",
    },
    {
        "school": "WEST SIDE ELEMENTARY SCHOOL",
        "district": "PICAYUNE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280363000700",
    },
    {
        "school": "POPLARVILLE JR SR HIGH SCHOOL",
        "district": "POPLARVILLE SEPARATE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280372000708",
    },
    {
        "school": "POPLARVILLE LOWER ELEMENTARY SCHOOL",
        "district": "POPLARVILLE SEPARATE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280372000709",
    },
    {
        "school": "POPLARVILLE UPPER ELEMENTARY SCH",
        "district": "POPLARVILLE SEPARATE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280372000710",
    },
    {
        "school": "MIDDLE SCHOOL OF POPLARVILLE",
        "district": "POPLARVILLE SEPARATE SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280372000992",
    },
    {
        "school": "POPLARVILLE CAREER DEVELOPMENT CTR",
        "district": "POPLARVILLE SEPARATE SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280372001073",
    },
    {
        "school": "LEE CO. SCHOOLS IMPROVEMENT CENTER",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280255001264",
    },
    {
        "school": "SALTILLO PRIMARY SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255001265",
    },
    {
        "school": "SHANNON PRIMARY SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255001266",
    },
    {
        "school": "MOOREVILLE MIDDLE SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255001276",
    },
    {
        "school": "EARLY CHILDHOOD EDUCATION CENTER",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432001255",
    },
    {
        "school": "PARKWAY ELEMENTARY SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432001256",
    },
    {
        "school": "NETTLETON JUNIOR HIGH SCHOOL",
        "district": "NETTLETON SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280309001159",
    },
    {
        "school": "DORSEY ATTENDANCE CENTER",
        "district": "ITAWAMBA COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280210000356",
    },
    {
        "school": "FAIRVIEW ATTENDANCE CENTER",
        "district": "ITAWAMBA COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280210000357",
    },
    {
        "school": "ITAWAMBA ATTENDANCE CENTER",
        "district": "ITAWAMBA COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280210000358",
    },
    {
        "school": "ITAWAMBA CAREER & TECHNICAL CENTER",
        "district": "ITAWAMBA COUNTY SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280210000360",
    },
    {
        "school": "MANTACHIE ATTENDANCE CENTER",
        "district": "ITAWAMBA COUNTY SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280210000361",
    },
    {
        "school": "TREMONT ATTENDANCE CENTER",
        "district": "ITAWAMBA COUNTY SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280210000362",
    },
    {
        "school": "ITAWAMBA AGRICULTURAL HIGH SCHOOL",
        "district": "ITAWAMBA COUNTY SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280210000949",
    },
    {
        "school": "ITAWAMBA IMPROVEMENT CENTER",
        "district": "ITAWAMBA COUNTY SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280210000999",
    },
    {
        "school": "BALDWYN ELEMENTARY SCHOOL",
        "district": "BALDWYN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280054000041",
    },
    {
        "school": "GUNTOWN MIDDLE SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255000492",
    },
    {
        "school": "MOOREVILLE HIGH SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255000494",
    },
    {
        "school": "PLANTERSVILLE MIDDLE SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255000495",
    },
    {
        "school": "SALTILLO HIGH SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255000496",
    },
    {
        "school": "SHANNON HIGH SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255000497",
    },
    {
        "school": "VERONA ELEMENTARY SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255000498",
    },
    {
        "school": "SALTILLO ELEMENTARY SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255000920",
    },
    {
        "school": "MOOREVILLE ELEMENTARY SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255001000",
    },
    {
        "school": "SHANNON ELEMENTARY SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255001122",
    },
    {
        "school": "NETTLETON HIGH SCHOOL",
        "district": "NETTLETON SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280309000613",
    },
    {
        "school": "NETTLETON PRIMARY SCHOOL",
        "district": "NETTLETON SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280309000614",
    },
    {
        "school": "NETTLETON UPPER ELEMENTARY SCHOOL",
        "district": "NETTLETON SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280309001160",
    },
    {
        "school": "TUPELO MIDDLE SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432000293",
    },
    {
        "school": "JOYNER ELEMENTARY SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432000813",
    },
    {
        "school": "LAWHON ELEMENTARY SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432000814",
    },
    {
        "school": "PIERCE STREET ELEMENTARY SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432000816",
    },
    {
        "school": "RANKIN ELEMENTARY SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432000817",
    },
    {
        "school": "THOMAS STREET ELEMENTARY SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432000818",
    },
    {
        "school": "TUPELO HIGH SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432000819",
    },
    {
        "school": "TUPELO LEE CO VOC TECH SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280432000820",
    },
    {
        "school": "CARVER ELEMENTARY SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432001001",
    },
    {
        "school": "LAWNDALE ELEMENTARY SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432001002",
    },
    {
        "school": "MILAM ELEMENTARY SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280432001003",
    },
    {
        "school": "TUPELO ALTERNATIVE SCHOOL",
        "district": "TUPELO PUBLIC SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280432001004",
    },
    {
        "school": "North Pontotoc High School",
        "district": "PONTOTOC CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280366000701",
    },
    {
        "school": "Pontotoc Ridge Career & Tech. Cnt.",
        "district": "PONTOTOC CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280366000702",
    },
    {
        "school": "South Pontotoc High School",
        "district": "PONTOTOC CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280366000703",
    },
    {
        "school": "North Pontotoc Elementary School",
        "district": "PONTOTOC CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280366001008",
    },
    {
        "school": "North Pontotoc Middle School",
        "district": "PONTOTOC CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280366001009",
    },
    {
        "school": "South Pontotoc Elementary School",
        "district": "PONTOTOC CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280366001010",
    },
    {
        "school": "South Pontotoc Middle School",
        "district": "PONTOTOC CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280366001011",
    },
    {
        "school": "D T COX ELEMENTARY SCHOOL",
        "district": "PONTOTOC CITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280369000704",
    },
    {
        "school": "PONTOTOC ELEMENTARY SCHOOL",
        "district": "PONTOTOC CITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280369000705",
    },
    {
        "school": "PONTOTOC HIGH SCHOOL",
        "district": "PONTOTOC CITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280369000706",
    },
    {
        "school": "PONTOTOC JUNIOR HIGH SCHOOL",
        "district": "PONTOTOC CITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280369001162",
    },
    {
        "school": "BALDWYN HIGH SCHOOL",
        "district": "BALDWYN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280054000042",
    },
    {
        "school": "CENTER FOR ALTERNATIVE PROGRAMS",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280447000401",
    },
    {
        "school": "BOWMAR AVENUE SCHOOL",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447000826",
    },
    {
        "school": "VICKSBURG HIGH SCHOOL",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447000830",
    },
    {
        "school": "VICKSBURG JUNIOR HIGH SCHOOL",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447000831",
    },
    {
        "school": "REDWOOD ELEMENTARY SCHOOL",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447000841",
    },
    {
        "school": "WARREN CENTRAL HIGH SCHOOL",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447000842",
    },
    {
        "school": "WARREN CENTRAL JUNIOR HIGH SCHOOL",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447000843",
    },
    {
        "school": "WARRENTON ELEMENTARY SCHOOL",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447000844",
    },
    {
        "school": "DANA ROAD ELEMENTARY",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447000993",
    },
    {
        "school": "VICKSBURG INTERMEDIATE",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447000994",
    },
    {
        "school": "SHERMAN AVE ELEMENTARY",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447000995",
    },
    {
        "school": "WARREN CENTRAL INTERMEDIATE",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447000996",
    },
    {
        "school": "HINDS COMMUNITY VICKSBURG CENTER",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280447001016",
    },
    {
        "school": "SOUTH PARK ELEMENTARY SCHOOL",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447001094",
    },
    {
        "school": "BEECHWOOD ELEMENTARY SCHOOL",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447001186",
    },
    {
        "school": "MCCOY ELEMENTARY SCHOOL",
        "district": "YAZOO CITY MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280477001260",
    },
    {
        "school": "ALTERNATIVE LEARNING CENTER",
        "district": "YAZOO CITY MUNICIPAL SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280477001261",
    },
    {
        "school": "YAZOO COUNTY MIDDLE SCHOOL",
        "district": "YAZOO CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280480001581",
    },
    {
        "school": "WEBSTER STREET ELEMENTARY SCHOOL",
        "district": "YAZOO CITY MUNICIPAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280477000886",
    },
    {
        "school": "BETTIE E WOOLFOLK MIDDLE SCHOOL",
        "district": "YAZOO CITY MUNICIPAL SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280477000887",
    },
    {
        "school": "YAZOO CITY HIGH SCHOOL",
        "district": "YAZOO CITY MUNICIPAL SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280477000888",
    },
    {
        "school": "YAZOO CITY VOC COMPLEX",
        "district": "YAZOO CITY MUNICIPAL SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280477001098",
    },
    {
        "school": "YAZOO COUNTY HIGH SCHOOL",
        "district": "YAZOO CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280480000890",
    },
    {
        "school": "BENTONIA GIBBS SCHOOL",
        "district": "YAZOO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280480000891",
    },
    {
        "school": "LINWOOD ELEMENTARY SCHOOL",
        "district": "YAZOO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280480000893",
    },
    {
        "school": "Wyola 7-8",
        "district": "Wyola Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302880000355",
    },
    {
        "school": "Chester-Joplin-Inverness Schl",
        "district": "Chester-Joplin-Inverness El",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009800178",
    },
    {
        "school": "Sage Creek Elementary",
        "district": "Chester-Joplin-Inverness El",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009800329",
    },
    {
        "school": "Chester-Joplin-Inverness 7-8",
        "district": "Chester-Joplin-Inverness El",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009800998",
    },
    {
        "school": "Chester-Joplin-Inverness HS",
        "district": "Chester-Joplin-Inverness HS",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300010100179",
    },
    {
        "school": "Heart Butte Elementary",
        "district": "Heart Butte K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009900414",
    },
    {
        "school": "Heart Butte 6-8",
        "district": "Heart Butte K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009901031",
    },
    {
        "school": "Dutton/Brady Elementary",
        "district": "Dutton/Brady K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300010200265",
    },
    {
        "school": "Dutton/Brady High School",
        "district": "Dutton/Brady K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300010200266",
    },
    {
        "school": "Dutton/Brady Middle School",
        "district": "Dutton/Brady K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300010201034",
    },
    {
        "school": "Beaverhead Co High School",
        "district": "Beaverhead County H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300309000041",
    },
    {
        "school": "Dillon Middle School",
        "district": "Dillon Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300891000256",
    },
    {
        "school": "Parkview School",
        "district": "Dillon Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300891000257",
    },
    {
        "school": "Wise River School",
        "district": "Wise River Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301082000794",
    },
    {
        "school": "Grant School",
        "district": "Grant Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301290000350",
    },
    {
        "school": "Jackson School",
        "district": "Jackson Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301506000459",
    },
    {
        "school": "Lima School",
        "district": "Lima K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301671000519",
    },
    {
        "school": "Lima High School",
        "district": "Lima K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301671000520",
    },
    {
        "school": "Lima 7-8",
        "district": "Lima K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301671000929",
    },
    {
        "school": "Polaris School",
        "district": "Polaris Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302103000629",
    },
    {
        "school": "Reichle School",
        "district": "Reichle Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302229000658",
    },
    {
        "school": "Wisdom School",
        "district": "Wisdom Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302850000793",
    },
    {
        "school": "Spring Creek School",
        "district": "Spring Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300366000053",
    },
    {
        "school": "Crow Agency School",
        "district": "Hardin Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301331000392",
    },
    {
        "school": "Fort Smith School",
        "district": "Hardin Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301331000393",
    },
    {
        "school": "Hardin Middle School",
        "district": "Hardin Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301331000394",
    },
    {
        "school": "Hardin Intermediate",
        "district": "Hardin Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301331000395",
    },
    {
        "school": "Hardin Primary",
        "district": "Hardin Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301331000396",
    },
    {
        "school": "Hardin High School",
        "district": "Hardin H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301334000397",
    },
    {
        "school": "Plenty Coups High School",
        "district": "Plenty Coups H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301336000398",
    },
    {
        "school": "Lodge Grass School",
        "district": "Lodge Grass Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301701000533",
    },
    {
        "school": "Lodge Grass 7-8",
        "district": "Lodge Grass Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301701000931",
    },
    {
        "school": "Lodge Grass High School",
        "district": "Lodge Grass H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301704000534",
    },
    {
        "school": "Arrow Creek Elem School",
        "district": "Pryor Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302172000647",
    },
    {
        "school": "Pryor 7-8",
        "district": "Pryor Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302172000930",
    },
    {
        "school": "Wyola School",
        "district": "Wyola Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302880000804",
    },
    {
        "school": "Bear Paw School",
        "district": "Bear Paw Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300300000039",
    },
    {
        "school": "Cleveland School",
        "district": "Cleveland Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300405000094",
    },
    {
        "school": "Meadowlark School",
        "district": "Chinook Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300626000181",
    },
    {
        "school": "Hartland Elementary School",
        "district": "Chinook Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300626000339",
    },
    {
        "school": "Chinook 7-8",
        "district": "Chinook Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300626000932",
    },
    {
        "school": "Chinook High School",
        "district": "Chinook H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300627000182",
    },
    {
        "school": "Harlem Elementary School",
        "district": "Harlem Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301339500399",
    },
    {
        "school": "Harlem 7-8",
        "district": "Harlem Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301339500909",
    },
    {
        "school": "Harlem High School",
        "district": "Harlem H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301340000400",
    },
    {
        "school": "Lodge Pole School",
        "district": "Hays-Lodge Pole K-12 Schls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301366000097",
    },
    {
        "school": "Hays-Lodge Pole High Sch",
        "district": "Hays-Lodge Pole K-12 Schls",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301366000413",
    },
    {
        "school": "Hays-Lodge Pole 7-8",
        "district": "Hays-Lodge Pole K-12 Schls",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301366000934",
    },
    {
        "school": "North Harlem Elementary",
        "district": "North Harlem Colony Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301931000597",
    },
    {
        "school": "Turner School",
        "district": "Turner Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302664000750",
    },
    {
        "school": "Turner 7-8",
        "district": "Turner Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302664000933",
    },
    {
        "school": "Turner High School",
        "district": "Turner H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302667000751",
    },
    {
        "school": "Zurich School",
        "district": "Zurich Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302891000807",
    },
    {
        "school": "Broadwater High School",
        "district": "Townsend K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300498000123",
    },
    {
        "school": "Cecelia Hazelton School",
        "district": "Townsend K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300498000743",
    },
    {
        "school": "Townsend 7-8",
        "district": "Townsend K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300498000935",
    },
    {
        "school": "Alzada School",
        "district": "Alzada Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300195000006",
    },
    {
        "school": "Carter County High School",
        "district": "Carter County H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300561000162",
    },
    {
        "school": "Ekalaka Elementary School",
        "district": "Ekalaka Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300967000271",
    },
    {
        "school": "Ekalaka 7-8",
        "district": "Ekalaka Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300967000940",
    },
    {
        "school": "Hammond School",
        "district": "Hawks Home Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301328000338",
    },
    {
        "school": "Benton Lake School",
        "district": "Benton Lake Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300348000084",
    },
    {
        "school": "Big Sandy High School",
        "district": "Big Sandy K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300375000054",
    },
    {
        "school": "Carter School",
        "district": "Carter Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300576000167",
    },
    {
        "school": "Fort Benton 7-8",
        "district": "Fort Benton Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301124000305",
    },
    {
        "school": "Fort Benton School",
        "district": "Fort Benton Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301124000306",
    },
    {
        "school": "Fort Benton High School",
        "district": "Fort Benton H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301126000307",
    },
    {
        "school": "Geraldine High School",
        "district": "Geraldine K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301221000333",
    },
    {
        "school": "Highwood High School",
        "district": "Highwood K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301407000437",
    },
    {
        "school": "Knees School",
        "district": "Knees Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301569000483",
    },
    {
        "school": "Custer Co District High",
        "district": "Custer County H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300793000226",
    },
    {
        "school": "Spring Creek School",
        "district": "Spring Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300795000227",
    },
    {
        "school": "Kinsey School",
        "district": "Kinsey Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300798000228",
    },
    {
        "school": "S Y School",
        "district": "S Y Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300801000229",
    },
    {
        "school": "S H School",
        "district": "S H Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300804000230",
    },
    {
        "school": "Kircher School",
        "district": "Kircher Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301564000482",
    },
    {
        "school": "Highland Park School",
        "district": "Miles City Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301841000557",
    },
    {
        "school": "Jefferson School",
        "district": "Miles City Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301841000558",
    },
    {
        "school": "Lincoln School",
        "district": "Miles City Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301841000559",
    },
    {
        "school": "Washington 7-8",
        "district": "Miles City Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301841000561",
    },
    {
        "school": "Garfield School",
        "district": "Miles City Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301841000823",
    },
    {
        "school": "Riverview School",
        "district": "Trail Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302640000744",
    },
    {
        "school": "Scobey School",
        "district": "Scobey K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302367000687",
    },
    {
        "school": "Scobey High School",
        "district": "Scobey K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302367000688",
    },
    {
        "school": "Scobey 7-8",
        "district": "Scobey K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302367000949",
    },
    {
        "school": "Bloomfield School",
        "district": "Bloomfield Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300420000098",
    },
    {
        "school": "Dawson High School",
        "district": "Dawson H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300834000240",
    },
    {
        "school": "Lindsay School",
        "district": "Lindsay Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300840000243",
    },
    {
        "school": "Deer Creek School",
        "district": "Deer Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300847000244",
    },
    {
        "school": "Jefferson School",
        "district": "Glendive Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301251000344",
    },
    {
        "school": "Lincoln School",
        "district": "Glendive Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301251000345",
    },
    {
        "school": "Washington Middle School",
        "district": "Glendive Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301251000952",
    },
    {
        "school": "Richey School",
        "district": "Richey Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302237000659",
    },
    {
        "school": "Richey 7-8",
        "district": "Richey Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302237000953",
    },
    {
        "school": "Richey High School",
        "district": "Richey H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302241000660",
    },
    {
        "school": "Fred Moodry Intermediate",
        "district": "Anaconda Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300201000010",
    },
    {
        "school": "Lincoln Primary",
        "district": "Anaconda Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300201000011",
    },
    {
        "school": "Anaconda Jr High School",
        "district": "Anaconda Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300201000014",
    },
    {
        "school": "Anaconda Sr High School",
        "district": "Anaconda H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300203000015",
    },
    {
        "school": "Baker 7-8",
        "district": "Baker K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300273000031",
    },
    {
        "school": "Lincoln School",
        "district": "Baker K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300273000032",
    },
    {
        "school": "Longfellow School",
        "district": "Baker K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300273000033",
    },
    {
        "school": "Baker High School",
        "district": "Baker K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300273000035",
    },
    {
        "school": "Plevna School",
        "district": "Plevna K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302100000627",
    },
    {
        "school": "Plevna High School",
        "district": "Plevna K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302100000628",
    },
    {
        "school": "Plevna 7-8",
        "district": "Plevna K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302100000954",
    },
    {
        "school": "Ayers School",
        "district": "Ayers Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300257000028",
    },
    {
        "school": "Deerfield School",
        "district": "Deerfield Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300873000250",
    },
    {
        "school": "Denton High School",
        "district": "Denton H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300885000252",
    },
    {
        "school": "Denton School",
        "district": "Denton Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300886000253",
    },
    {
        "school": "Denton 7-8",
        "district": "Denton Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300886000958",
    },
    {
        "school": "Fergus High School",
        "district": "Fergus H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301053000287",
    },
    {
        "school": "Grass Range School",
        "district": "Grass Range Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301296000351",
    },
    {
        "school": "Grass Range 7-8",
        "district": "Grass Range Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301296000955",
    },
    {
        "school": "Grass Range High School",
        "district": "Grass Range H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301299000352",
    },
    {
        "school": "King Colony School",
        "district": "King Colony Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301561000481",
    },
    {
        "school": "Garfield School",
        "district": "Lewistown Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301649000507",
    },
    {
        "school": "Highland Park School",
        "district": "Lewistown Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301649000508",
    },
    {
        "school": "Lewis & Clark School",
        "district": "Lewistown Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301649000509",
    },
    {
        "school": "Lewistown 7-8",
        "district": "Lewistown Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301649000510",
    },
    {
        "school": "Moore School",
        "district": "Moore Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301887000588",
    },
    {
        "school": "Moore 6-8",
        "district": "Moore Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301887000956",
    },
    {
        "school": "Moore High School",
        "district": "Moore H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301890000589",
    },
    {
        "school": "Roy School",
        "district": "Roy K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302316000676",
    },
    {
        "school": "Roy High School",
        "district": "Roy K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302316000677",
    },
    {
        "school": "Roy 6-8",
        "district": "Roy K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302316000957",
    },
    {
        "school": "Spring Creek Colony Schl",
        "district": "Spring Creek Colony Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302469000710",
    },
    {
        "school": "Winifred School",
        "district": "Winifred K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302838000789",
    },
    {
        "school": "Winifred High School",
        "district": "Winifred K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302838000790",
    },
    {
        "school": "Winifred 6-8",
        "district": "Winifred K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302838000959",
    },
    {
        "school": "Cohagen School",
        "district": "Cohagen Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300703000192",
    },
    {
        "school": "Garfield Co Dist HS",
        "district": "Garfield County H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301188000323",
    },
    {
        "school": "Ross School",
        "district": "Ross Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301199000328",
    },
    {
        "school": "Sand Springs School",
        "district": "Sand Springs Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301206000330",
    },
    {
        "school": "Jordan Elementary School",
        "district": "Jordan Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301534000467",
    },
    {
        "school": "Jordan 7-8",
        "district": "Jordan Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301534000979",
    },
    {
        "school": "Kester School",
        "district": "Kester Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301551000478",
    },
    {
        "school": "Pine Grove School",
        "district": "Pine Grove Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302069000620",
    },
    {
        "school": "Glacier Elementary School",
        "district": "Cut Bank Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000300018",
    },
    {
        "school": "Anna Jeffries Elementary",
        "district": "Cut Bank Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000300233",
    },
    {
        "school": "Cut Bank Middle School",
        "district": "Cut Bank Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000300234",
    },
    {
        "school": "Hidden Lake Elementary",
        "district": "Cut Bank Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000300242",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Mountain View Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000400899",
    },
    {
        "school": "Babb School",
        "district": "Browning Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300514000129",
    },
    {
        "school": "KW-VC Elementary",
        "district": "Browning Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300514000131",
    },
    {
        "school": "Napi School",
        "district": "Browning Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300514000132",
    },
    {
        "school": "Big Sky School",
        "district": "Browning Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300514000812",
    },
    {
        "school": "Glendale School",
        "district": "Browning Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300514000813",
    },
    {
        "school": "Browning Middle School",
        "district": "Browning Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300514000872",
    },
    {
        "school": "Browning High School",
        "district": "Browning H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300519000136",
    },
    {
        "school": "Cut Bank High School",
        "district": "Cut Bank H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300819000236",
    },
    {
        "school": "East Glacier Park School",
        "district": "East Glacier Park Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300951000267",
    },
    {
        "school": "Lavina School",
        "district": "Lavina K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301629000502",
    },
    {
        "school": "Lavina High School",
        "district": "Lavina K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301629000503",
    },
    {
        "school": "Lavina 7-8",
        "district": "Lavina K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301629000982",
    },
    {
        "school": "Ryegate School",
        "district": "Ryegate K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302334000680",
    },
    {
        "school": "Ryegate High School",
        "district": "Ryegate K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302334000681",
    },
    {
        "school": "Ryegate 7-8",
        "district": "Ryegate K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302334000981",
    },
    {
        "school": "Drummond School",
        "district": "Drummond Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300918000262",
    },
    {
        "school": "Drummond 7-8",
        "district": "Drummond Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300918000984",
    },
    {
        "school": "Drummond High School",
        "district": "Drummond H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300921000263",
    },
    {
        "school": "Granite High School",
        "district": "Philipsburg K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301284000349",
    },
    {
        "school": "Philipsburg School",
        "district": "Philipsburg K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301284000616",
    },
    {
        "school": "Philipsburg 7-8",
        "district": "Philipsburg K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301284000983",
    },
    {
        "school": "Hall School",
        "district": "Hall Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301320000383",
    },
    {
        "school": "Geyser School",
        "district": "Geyser Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301227000334",
    },
    {
        "school": "Geyser 7-8",
        "district": "Geyser Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301227000993",
    },
    {
        "school": "Geyser High School",
        "district": "Geyser H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301230000335",
    },
    {
        "school": "Hobson School",
        "district": "Hobson K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301443000445",
    },
    {
        "school": "Hobson High School",
        "district": "Hobson K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301443000446",
    },
    {
        "school": "Hobson 6-8",
        "district": "Hobson K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301443000992",
    },
    {
        "school": "Stanford School",
        "district": "Stanford K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302499000021",
    },
    {
        "school": "Stanford 7-8",
        "district": "Stanford K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302499000716",
    },
    {
        "school": "Stanford High School",
        "district": "Stanford K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302499000717",
    },
    {
        "school": "Arlee Elementary",
        "district": "Arlee Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300222000019",
    },
    {
        "school": "Arlee 7-8",
        "district": "Arlee Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300222000900",
    },
    {
        "school": "Arlee High School",
        "district": "Arlee H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300225000020",
    },
    {
        "school": "St Ignatius Elementary School",
        "district": "St Ignatius K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300611000174",
    },
    {
        "school": "St Ignatius High School",
        "district": "St Ignatius K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300611000175",
    },
    {
        "school": "St Ignatius Middle School",
        "district": "St Ignatius K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300611000994",
    },
    {
        "school": "Charlo Elementary",
        "district": "Charlo Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300611200176",
    },
    {
        "school": "Charlo 7-8",
        "district": "Charlo Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300611200814",
    },
    {
        "school": "Charlo High School",
        "district": "Charlo H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300611500177",
    },
    {
        "school": "Dayton School",
        "district": "Upper West Shore Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301590000487",
    },
    {
        "school": "Salmon Prairie School",
        "district": "Swan Lake-Salmon Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301593000489",
    },
    {
        "school": "Cherry Valley School",
        "district": "Polson Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302106000630",
    },
    {
        "school": "Linderman School",
        "district": "Polson Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302106000631",
    },
    {
        "school": "Polson Middle School",
        "district": "Polson Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302106000632",
    },
    {
        "school": "Polson High School",
        "district": "Polson H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302109000633",
    },
    {
        "school": "Pablo Elementary",
        "district": "Ronan Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302279000667",
    },
    {
        "school": "Ronan Middle School",
        "district": "Ronan Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302279000668",
    },
    {
        "school": "K William Harvey Elem",
        "district": "Ronan Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302279000669",
    },
    {
        "school": "Ronan High School",
        "district": "Ronan H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302280000670",
    },
    {
        "school": "Valley View School",
        "district": "Valley View Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302715000760",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Liberty Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009300920",
    },
    {
        "school": "McCormick School",
        "district": "McCormick Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300603000173",
    },
    {
        "school": "Eureka Elementary School",
        "district": "Eureka Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301008000279",
    },
    {
        "school": "Eureka Middle School 5-8",
        "district": "Eureka Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301008001000",
    },
    {
        "school": "Fortine School",
        "district": "Fortine Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301134000309",
    },
    {
        "school": "Libby Elementary School",
        "district": "Libby K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301653000512",
    },
    {
        "school": "Libby Middle School",
        "district": "Libby K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301653000517",
    },
    {
        "school": "Libby High School",
        "district": "Libby K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301653000518",
    },
    {
        "school": "Lincoln Co High School",
        "district": "Lincoln County H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301677000521",
    },
    {
        "school": "Trego School",
        "district": "Trego Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302646000745",
    },
    {
        "school": "W F Morrison School",
        "district": "Troy Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302655000748",
    },
    {
        "school": "Troy 7-8",
        "district": "Troy Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302655000999",
    },
    {
        "school": "Troy High School",
        "district": "Troy H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302658000749",
    },
    {
        "school": "Yaak School",
        "district": "Yaak Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302883000805",
    },
    {
        "school": "Bo Peep School",
        "district": "Circle Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300679000185",
    },
    {
        "school": "Redwater School",
        "district": "Circle Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300679000186",
    },
    {
        "school": "Redwater 7-8",
        "district": "Circle Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300679001005",
    },
    {
        "school": "Circle High School",
        "district": "Circle H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300681000187",
    },
    {
        "school": "Vida School",
        "district": "Vida Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302734000764",
    },
    {
        "school": "Ennis High School",
        "district": "Ennis K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300993000277",
    },
    {
        "school": "Ennis School",
        "district": "Ennis K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300993000278",
    },
    {
        "school": "Ennis 7-8",
        "district": "Ennis K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300993001004",
    },
    {
        "school": "Harrison School",
        "district": "Harrison K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301353000403",
    },
    {
        "school": "Harrison High School",
        "district": "Harrison K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301353000404",
    },
    {
        "school": "Harrison 7-8",
        "district": "Harrison K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301353001003",
    },
    {
        "school": "Alder School",
        "district": "Alder Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301746000541",
    },
    {
        "school": "Sheridan Elementary Schl",
        "district": "Sheridan Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302415000697",
    },
    {
        "school": "Sheridan 7-8",
        "district": "Sheridan Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302415001001",
    },
    {
        "school": "Sheridan High School",
        "district": "Sheridan H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302418000698",
    },
    {
        "school": "Twin Bridges School",
        "district": "Twin Bridges K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302673000752",
    },
    {
        "school": "Twin Bridges High School",
        "district": "Twin Bridges K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302673000753",
    },
    {
        "school": "Twin Bridges 7-8",
        "district": "Twin Bridges K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302673001002",
    },
    {
        "school": "White Sulphur Springs HS",
        "district": "White Sulphur Spgs K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302877000803",
    },
    {
        "school": "Alberton School",
        "district": "Alberton K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300186000003",
    },
    {
        "school": "Alberton High School",
        "district": "Alberton K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300186000004",
    },
    {
        "school": "Alberton 7-8",
        "district": "Alberton K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300186001007",
    },
    {
        "school": "St Regis School",
        "district": "St Regis K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302493000714",
    },
    {
        "school": "St Regis High School",
        "district": "St Regis K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302493000715",
    },
    {
        "school": "St Regis 7-8",
        "district": "St Regis K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302493001009",
    },
    {
        "school": "Superior Elementary",
        "district": "Superior K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302547000728",
    },
    {
        "school": "Superior High School",
        "district": "Superior K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302547000729",
    },
    {
        "school": "Superior 7-8",
        "district": "Superior K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302547001008",
    },
    {
        "school": "Melstone School",
        "district": "Melstone Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301824000554",
    },
    {
        "school": "Melstone 6-8",
        "district": "Melstone Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301824001020",
    },
    {
        "school": "Melstone High School",
        "district": "Melstone H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301827000555",
    },
    {
        "school": "Roundup Elementary",
        "district": "Roundup Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302304000673",
    },
    {
        "school": "Roundup 7-8",
        "district": "Roundup Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302304000914",
    },
    {
        "school": "Roundup H S",
        "district": "Roundup High School",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302307000675",
    },
    {
        "school": "Shields Valley Elementary",
        "district": "Shields Valley Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300093201024",
    },
    {
        "school": "Shields Valley 7-8",
        "district": "Shields Valley Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300093201025",
    },
    {
        "school": "Shields Valley High Schl",
        "district": "Shields Valley H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300093301026",
    },
    {
        "school": "Arrowhead School",
        "district": "Arrowhead Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300230000022",
    },
    {
        "school": "Arrowhead 7-8",
        "district": "Arrowhead Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300230000199",
    },
    {
        "school": "Cooke City School",
        "district": "Cooke City Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300735001023",
    },
    {
        "school": "Gardiner School",
        "district": "Gardiner Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301182000321",
    },
    {
        "school": "Gardiner 7-8",
        "district": "Gardiner Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301182001022",
    },
    {
        "school": "Gardiner High School",
        "district": "Gardiner H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301185000322",
    },
    {
        "school": "B A Winans School",
        "district": "Livingston Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301688000523",
    },
    {
        "school": "East Side School",
        "district": "Livingston Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301688000524",
    },
    {
        "school": "Sleeping Giant Middle Sch",
        "district": "Livingston Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301688001021",
    },
    {
        "school": "Park High School",
        "district": "Park H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302010000611",
    },
    {
        "school": "Pine Creek 6-8",
        "district": "Pine Creek Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302067000166",
    },
    {
        "school": "Pine Creek School",
        "district": "Pine Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302067000619",
    },
    {
        "school": "Winnett School",
        "district": "Winnett K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302847000791",
    },
    {
        "school": "Winnett High School",
        "district": "Winnett K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302847000792",
    },
    {
        "school": "Winnett 7-8",
        "district": "Winnett K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302847001027",
    },
    {
        "school": "Dodson High School",
        "district": "Dodson K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300912000261",
    },
    {
        "school": "Malta 6-7-8",
        "district": "Malta K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301758000544",
    },
    {
        "school": "Malta K-5",
        "district": "Malta K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301758000545",
    },
    {
        "school": "Malta High School",
        "district": "Malta K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301758000546",
    },
    {
        "school": "Loring Colony School",
        "district": "Malta K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301758000895",
    },
    {
        "school": "Saco School",
        "district": "Saco Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302337000682",
    },
    {
        "school": "Saco 7-8",
        "district": "Saco Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302337001030",
    },
    {
        "school": "Saco High School",
        "district": "Saco H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302340000683",
    },
    {
        "school": "Whitewater School",
        "district": "Whitewater K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302793000779",
    },
    {
        "school": "Whitewater High School",
        "district": "Whitewater K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302793000780",
    },
    {
        "school": "Whitewater 6-8",
        "district": "Whitewater K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302793001029",
    },
    {
        "school": "Heart Butte High School",
        "district": "Heart Butte K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009900924",
    },
    {
        "school": "Conrad High School",
        "district": "Conrad H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300732000210",
    },
    {
        "school": "Meadowlark School",
        "district": "Conrad Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300733000207",
    },
    {
        "school": "Utterback 7-8",
        "district": "Conrad Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300733000209",
    },
    {
        "school": "Utterback 4-6",
        "district": "Conrad Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300733001032",
    },
    {
        "school": "Dupuyer School",
        "district": "Dupuyer Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300933000264",
    },
    {
        "school": "Miami School",
        "district": "Miami Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302115000634",
    },
    {
        "school": "Valier School",
        "district": "Valier Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302706000758",
    },
    {
        "school": "Valier 7-8",
        "district": "Valier Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302706001033",
    },
    {
        "school": "Kingsbury Colony Attn Ctr",
        "district": "Valier Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302706001088",
    },
    {
        "school": "Valier High School",
        "district": "Valier H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302709000759",
    },
    {
        "school": "Broadus School",
        "district": "Broadus Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000600120",
    },
    {
        "school": "Broadus 7-8",
        "district": "Broadus Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000601035",
    },
    {
        "school": "South Stacey School",
        "district": "South Stacey Elem",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000700707",
    },
    {
        "school": "Biddle School",
        "district": "Biddle Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300360000051",
    },
    {
        "school": "Powder River Co Dist High",
        "district": "Powder River Co Dist H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300486000119",
    },
    {
        "school": "Avon School",
        "district": "Avon Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300255000027",
    },
    {
        "school": "E F Duvall 7-8",
        "district": "Deer Lodge Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300867000246",
    },
    {
        "school": "O D Speer School",
        "district": "Deer Lodge Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300867000248",
    },
    {
        "school": "Elliston School",
        "district": "Elliston Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300978000274",
    },
    {
        "school": "Gold Creek School",
        "district": "Gold Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301257000347",
    },
    {
        "school": "Helmville School",
        "district": "Helmville Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301389000433",
    },
    {
        "school": "Ovando School",
        "district": "Ovando Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301995000607",
    },
    {
        "school": "Powell County High School",
        "district": "Powell County H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302145000641",
    },
    {
        "school": "Garrison School",
        "district": "Garrison Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302148000642",
    },
    {
        "school": "Terry School",
        "district": "Terry K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302595000735",
    },
    {
        "school": "Terry High School",
        "district": "Terry K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302595000736",
    },
    {
        "school": "Terry Middle School",
        "district": "Terry K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302595001036",
    },
    {
        "school": "Quentin Brown Primary K-4",
        "district": "Corvallis K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300741000212",
    },
    {
        "school": "Corvallis 7-8",
        "district": "Corvallis K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300741000213",
    },
    {
        "school": "Edna Thomas School",
        "district": "Corvallis K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300741000214",
    },
    {
        "school": "Corvallis High School",
        "district": "Corvallis K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300741000215",
    },
    {
        "school": "Darby School",
        "district": "Darby K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300828000237",
    },
    {
        "school": "Darby High School",
        "district": "Darby K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300828000238",
    },
    {
        "school": "Darby 7-8",
        "district": "Darby K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300828001038",
    },
    {
        "school": "Florence-Carlton El Schl",
        "district": "Florence-Carlton K-12 Schls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301110000300",
    },
    {
        "school": "Florence-Carlton HS",
        "district": "Florence-Carlton K-12 Schls",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301110000301",
    },
    {
        "school": "Florence-Carlton 7-8",
        "district": "Florence-Carlton K-12 Schls",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301110001039",
    },
    {
        "school": "Daly School",
        "district": "Hamilton K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301326000384",
    },
    {
        "school": "Washington School",
        "district": "Hamilton K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301326000387",
    },
    {
        "school": "Hamilton Middle School",
        "district": "Hamilton K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301326000388",
    },
    {
        "school": "Hamilton High School",
        "district": "Hamilton K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301326000389",
    },
    {
        "school": "Lone Rock Middle School",
        "district": "Lone Rock Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301719000251",
    },
    {
        "school": "Lone Rock School",
        "district": "Lone Rock Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301719000538",
    },
    {
        "school": "Stevensville 7-8",
        "district": "Stevensville Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302502000718",
    },
    {
        "school": "Stevensville K-6",
        "district": "Stevensville Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302502000719",
    },
    {
        "school": "Stevensville High School",
        "district": "Stevensville H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302505000720",
    },
    {
        "school": "Victor School",
        "district": "Victor K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302727000762",
    },
    {
        "school": "Victor High School",
        "district": "Victor K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302727000763",
    },
    {
        "school": "Victor Middle School",
        "district": "Victor K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302727001037",
    },
    {
        "school": "Brorson School",
        "district": "Brorson Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300513000128",
    },
    {
        "school": "Fairview School",
        "district": "Fairview Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301021000282",
    },
    {
        "school": "Fairview 7-8",
        "district": "Fairview Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301021001041",
    },
    {
        "school": "Fairview High School",
        "district": "Fairview H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301029000284",
    },
    {
        "school": "Lambert School",
        "district": "Lambert Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301599000492",
    },
    {
        "school": "Lambert 7-8",
        "district": "Lambert Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301599001042",
    },
    {
        "school": "Lambert High School",
        "district": "Lambert H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301602000493",
    },
    {
        "school": "Rau School",
        "district": "Rau Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302196000651",
    },
    {
        "school": "Savage School",
        "district": "Savage Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302352000685",
    },
    {
        "school": "Savage 7-8",
        "district": "Savage Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302352001040",
    },
    {
        "school": "Savage High School",
        "district": "Savage H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302355000686",
    },
    {
        "school": "Central Elementary",
        "district": "Sidney Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302420000699",
    },
    {
        "school": "Sidney Middle School",
        "district": "Sidney Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302420000897",
    },
    {
        "school": "Sidney High School",
        "district": "Sidney H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302423000702",
    },
    {
        "school": "Bainville School",
        "district": "Bainville K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300264000029",
    },
    {
        "school": "Bainville High School",
        "district": "Bainville K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300264000030",
    },
    {
        "school": "Bainville 7-8",
        "district": "Bainville K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300264001047",
    },
    {
        "school": "Barbara Gilligan School",
        "district": "Brockton Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300501000124",
    },
    {
        "school": "Barbara Gilligan 7-8",
        "district": "Brockton Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300501001046",
    },
    {
        "school": "Brockton High School",
        "district": "Brockton H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300504000125",
    },
    {
        "school": "Culbertson School",
        "district": "Culbertson Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300783000224",
    },
    {
        "school": "Culbertson 7-8",
        "district": "Culbertson Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300783001045",
    },
    {
        "school": "Culbertson High School",
        "district": "Culbertson H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300786000225",
    },
    {
        "school": "Froid Elementary School",
        "district": "Froid Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301155000314",
    },
    {
        "school": "Froid 7-8",
        "district": "Froid Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301155001048",
    },
    {
        "school": "Froid High School",
        "district": "Froid H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301158000315",
    },
    {
        "school": "Frontier School",
        "district": "Frontier Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301167000318",
    },
    {
        "school": "Frontier 7-8",
        "district": "Frontier Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301167001043",
    },
    {
        "school": "Poplar 7-8",
        "district": "Poplar Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302124000636",
    },
    {
        "school": "Poplar School",
        "district": "Poplar Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302124000637",
    },
    {
        "school": "Poplar 5-6 School",
        "district": "Poplar Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302124001044",
    },
    {
        "school": "Poplar High School",
        "district": "Poplar H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302127000638",
    },
    {
        "school": "Northside School",
        "district": "Wolf Point Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302859000796",
    },
    {
        "school": "Southside School",
        "district": "Wolf Point Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302859000797",
    },
    {
        "school": "Wolf Point 7-8",
        "district": "Wolf Point Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302859000798",
    },
    {
        "school": "Wolf Point High School",
        "district": "Wolf Point H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302862000799",
    },
    {
        "school": "Ashland School",
        "district": "Ashland Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000800023",
    },
    {
        "school": "Ashland 7-8",
        "district": "Ashland Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000801051",
    },
    {
        "school": "Lame Deer High School",
        "district": "Lame Deer H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009500137",
    },
    {
        "school": "Birney School",
        "district": "Birney Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300399000093",
    },
    {
        "school": "Pine Butte Elementary Sch",
        "district": "Colstrip Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300705000873",
    },
    {
        "school": "Frank Brattin Middle Schl",
        "district": "Colstrip Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300705000874",
    },
    {
        "school": "Colstrip High School",
        "district": "Colstrip H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300708000194",
    },
    {
        "school": "Forsyth 7-8",
        "district": "Forsyth Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301116000302",
    },
    {
        "school": "Forsyth Elementary School",
        "district": "Forsyth Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301116000303",
    },
    {
        "school": "Forsyth High School",
        "district": "Forsyth H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301119000304",
    },
    {
        "school": "Lame Deer School",
        "district": "Lame Deer Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301605000494",
    },
    {
        "school": "Lame Deer 7-8",
        "district": "Lame Deer Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301605001049",
    },
    {
        "school": "Rosebud High School",
        "district": "Rosebud K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302292000672",
    },
    {
        "school": "Noxon School",
        "district": "Noxon Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009000599",
    },
    {
        "school": "Noxon 7-8",
        "district": "Noxon Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009001053",
    },
    {
        "school": "Dixon 7-8",
        "district": "Dixon Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300903000222",
    },
    {
        "school": "Dixon Elementary",
        "district": "Dixon Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300903000259",
    },
    {
        "school": "Hot Springs High School",
        "district": "Hot Springs K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301464000449",
    },
    {
        "school": "Noxon High School",
        "district": "Noxon H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301950000600",
    },
    {
        "school": "Plains High School",
        "district": "Plains K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302085000623",
    },
    {
        "school": "Thompson Falls Elem Schl",
        "district": "Thompson Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302607000737",
    },
    {
        "school": "Thompson Falls 7-8",
        "district": "Thompson Falls Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302607001052",
    },
    {
        "school": "Thompson Falls High Schl",
        "district": "Thompson Falls H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302610000738",
    },
    {
        "school": "Trout Creek 7-8",
        "district": "Trout Creek Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302652000211",
    },
    {
        "school": "Trout Creek School",
        "district": "Trout Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302652000747",
    },
    {
        "school": "Medicine Lake School",
        "district": "Medicine Lake K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301817000551",
    },
    {
        "school": "Medicine Lake High School",
        "district": "Medicine Lake K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301817000552",
    },
    {
        "school": "Medicine Lake 7-8",
        "district": "Medicine Lake K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301817001055",
    },
    {
        "school": "Plentywood School",
        "district": "Plentywood K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302096000625",
    },
    {
        "school": "Plentywood High School",
        "district": "Plentywood K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302096000626",
    },
    {
        "school": "Plentywood 7-8",
        "district": "Plentywood K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302096001056",
    },
    {
        "school": "Westby School",
        "district": "Westby K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302773000770",
    },
    {
        "school": "Westby High School",
        "district": "Westby K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302773000771",
    },
    {
        "school": "Westby 7-8",
        "district": "Westby K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302773001089",
    },
    {
        "school": "Absarokee School",
        "district": "Absarokee Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300171000001",
    },
    {
        "school": "Absarokee 6-8",
        "district": "Absarokee Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300171001063",
    },
    {
        "school": "Absarokee High School",
        "district": "Absarokee H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300174000002",
    },
    {
        "school": "Columbus Elem School",
        "district": "Columbus Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300719000204",
    },
    {
        "school": "Columbus Middle School",
        "district": "Columbus Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300719001060",
    },
    {
        "school": "Columbus High School",
        "district": "Columbus H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300720000205",
    },
    {
        "school": "Fishtail School",
        "district": "Fishtail Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301080000289",
    },
    {
        "school": "Molt School",
        "district": "Molt Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301866000584",
    },
    {
        "school": "Nye School",
        "district": "Nye Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301953000601",
    },
    {
        "school": "Park City School",
        "district": "Park City Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302004000609",
    },
    {
        "school": "Park City 7-8",
        "district": "Park City Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302004001059",
    },
    {
        "school": "Park City High School",
        "district": "Park City H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302007000610",
    },
    {
        "school": "Rapelje School",
        "district": "Rapelje Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302187000649",
    },
    {
        "school": "Rapelje 7-8",
        "district": "Rapelje Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302187001062",
    },
    {
        "school": "Rapelje High School",
        "district": "Rapelje H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302190000650",
    },
    {
        "school": "Reed Point Elementary",
        "district": "Reed Point Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302223000656",
    },
    {
        "school": "Reed Point 7-8",
        "district": "Reed Point Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302223001061",
    },
    {
        "school": "Reed Point High School",
        "district": "Reed Point H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302226000657",
    },
    {
        "school": "Big Timber School",
        "district": "Big Timber Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300380000056",
    },
    {
        "school": "Big Timber 7-8",
        "district": "Big Timber Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300380001064",
    },
    {
        "school": "Greycliff School",
        "district": "Greycliff Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301314000382",
    },
    {
        "school": "McLeod School",
        "district": "McLeod Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301806000550",
    },
    {
        "school": "Melville School",
        "district": "Melville Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301829000556",
    },
    {
        "school": "Sweet Grass Co High Schl",
        "district": "Sweet Grass County H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302556000732",
    },
    {
        "school": "Bynum School",
        "district": "Bynum Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300533000157",
    },
    {
        "school": "Choteau School",
        "district": "Choteau Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300632000183",
    },
    {
        "school": "Choteau 7-8",
        "district": "Choteau Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300632001065",
    },
    {
        "school": "Choteau High School",
        "district": "Choteau H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300633000184",
    },
    {
        "school": "Fairfield Elementary School",
        "district": "Fairfield Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301014000280",
    },
    {
        "school": "Fairfield 7-8",
        "district": "Fairfield Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301014001066",
    },
    {
        "school": "Fairfield High School",
        "district": "Fairfield H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301017000281",
    },
    {
        "school": "Golden Ridge School",
        "district": "Golden Ridge Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301260000348",
    },
    {
        "school": "Greenfield 7-8",
        "district": "Greenfield Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301311000068",
    },
    {
        "school": "Greenfield School",
        "district": "Greenfield Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301311000381",
    },
    {
        "school": "Pendroy School",
        "district": "Pendroy Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302024000615",
    },
    {
        "school": "Power School",
        "district": "Power Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302151000643",
    },
    {
        "school": "Power 7-8",
        "district": "Power Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302151001068",
    },
    {
        "school": "Power High School",
        "district": "Power H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302154000644",
    },
    {
        "school": "Galata School",
        "district": "Galata Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301173000319",
    },
    {
        "school": "Cam Rose School",
        "district": "Shelby Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302390000288",
    },
    {
        "school": "Shelby Elementary School",
        "district": "Shelby Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302390000692",
    },
    {
        "school": "Shelby 7-8",
        "district": "Shelby Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302390000693",
    },
    {
        "school": "Shelby High School",
        "district": "Shelby H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302391000694",
    },
    {
        "school": "Sunburst Elementary",
        "district": "Sunburst K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302532000725",
    },
    {
        "school": "Sunburst High School",
        "district": "Sunburst K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302532000726",
    },
    {
        "school": "Sunburst  7 - 8",
        "district": "Sunburst K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302532001069",
    },
    {
        "school": "Hysham School",
        "district": "Hysham K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301476000453",
    },
    {
        "school": "Hysham High School",
        "district": "Hysham K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301476000454",
    },
    {
        "school": "Hysham 7-8",
        "district": "Hysham K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301476001070",
    },
    {
        "school": "Frazer Elementary",
        "district": "Frazer Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301142000310",
    },
    {
        "school": "Frazer 7-8",
        "district": "Frazer Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301142001072",
    },
    {
        "school": "Frazer High School",
        "district": "Frazer H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301146000311",
    },
    {
        "school": "Irle Elementary School",
        "district": "Glasgow K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301242000340",
    },
    {
        "school": "Glasgow High School",
        "district": "Glasgow K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301242000343",
    },
    {
        "school": "Glasgow Middle School",
        "district": "Glasgow K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301242000880",
    },
    {
        "school": "Hinsdale School",
        "district": "Hinsdale Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301434000443",
    },
    {
        "school": "Hinsdale 7-8",
        "district": "Hinsdale Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301434001073",
    },
    {
        "school": "Hinsdale High School",
        "district": "Hinsdale H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301437000444",
    },
    {
        "school": "Lustre School",
        "district": "Lustre Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301734000539",
    },
    {
        "school": "Nashua School",
        "district": "Nashua K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301917000593",
    },
    {
        "school": "Nashua High School",
        "district": "Nashua K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301917000594",
    },
    {
        "school": "Nashua 6-8",
        "district": "Nashua K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301917001075",
    },
    {
        "school": "Opheim School",
        "district": "Opheim K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301974000602",
    },
    {
        "school": "Opheim High School",
        "district": "Opheim K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301974000603",
    },
    {
        "school": "Opheim 7-8",
        "district": "Opheim K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301974001074",
    },
    {
        "school": "Harlowton High School",
        "district": "Harlowton K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301347000402",
    },
    {
        "school": "Judith Gap School",
        "district": "Judith Gap Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301536000468",
    },
    {
        "school": "Judith Gap 7-8",
        "district": "Judith Gap Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301536001077",
    },
    {
        "school": "Judith Gap High School",
        "district": "Judith Gap H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301539000469",
    },
    {
        "school": "Wibaux High School",
        "district": "Wibaux K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302802000783",
    },
    {
        "school": "Wibaux Elementary School",
        "district": "Wibaux K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302802000784",
    },
    {
        "school": "Wibaux 7-8",
        "district": "Wibaux K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302802001078",
    },
    {
        "school": "Belfry School",
        "district": "Belfry K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300327000042",
    },
    {
        "school": "Belfry High School",
        "district": "Belfry K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300327000043",
    },
    {
        "school": "Belfry 7-8",
        "district": "Belfry K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300327000939",
    },
    {
        "school": "Bridger Elementary School",
        "district": "Bridger K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300480000117",
    },
    {
        "school": "Bridger High School",
        "district": "Bridger K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300480000118",
    },
    {
        "school": "Bridger 7-8",
        "district": "Bridger K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300480000936",
    },
    {
        "school": "Fromberg High School",
        "district": "Fromberg K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301165000317",
    },
    {
        "school": "Joliet School",
        "district": "Joliet Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301520000463",
    },
    {
        "school": "Joliet Middle School",
        "district": "Joliet Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301520000910",
    },
    {
        "school": "Joliet High School",
        "district": "Joliet H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301526000464",
    },
    {
        "school": "Luther School",
        "district": "Luther Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301737000540",
    },
    {
        "school": "Mountain View School",
        "district": "Red Lodge Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302208000653",
    },
    {
        "school": "Roosevelt Junior High",
        "district": "Red Lodge Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302208000913",
    },
    {
        "school": "Red Lodge High School",
        "district": "Red Lodge H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302211000655",
    },
    {
        "school": "Roberts School",
        "district": "Roberts K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302271000664",
    },
    {
        "school": "Roberts High School",
        "district": "Roberts K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302271000665",
    },
    {
        "school": "Roberts 7-8",
        "district": "Roberts K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302271000937",
    },
    {
        "school": "Arrowhead School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000059",
    },
    {
        "school": "Bench School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000061",
    },
    {
        "school": "Bitterroot School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000062",
    },
    {
        "school": "Boulder School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000063",
    },
    {
        "school": "Broadwater School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000064",
    },
    {
        "school": "Burlington School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000065",
    },
    {
        "school": "Central Heights School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000067",
    },
    {
        "school": "Highland School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000071",
    },
    {
        "school": "McKinley School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000072",
    },
    {
        "school": "Meadowlark School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000073",
    },
    {
        "school": "Miles Avenue School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000074",
    },
    {
        "school": "Newman School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000075",
    },
    {
        "school": "Orchard School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000077",
    },
    {
        "school": "Poly Drive School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000078",
    },
    {
        "school": "Ponderosa School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000079",
    },
    {
        "school": "Rose Park School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000082",
    },
    {
        "school": "Sandstone School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000083",
    },
    {
        "school": "Washington School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000085",
    },
    {
        "school": "Alkali Creek School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000808",
    },
    {
        "school": "Castle Rock Middle School",
        "district": "Billings Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000869",
    },
    {
        "school": "Lewis & Clark Middle School",
        "district": "Billings Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000870",
    },
    {
        "school": "Big Sky Elementary",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000901",
    },
    {
        "school": "Eagle Cliffs Elementary",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000902",
    },
    {
        "school": "Riverside Middle School",
        "district": "Billings Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000903",
    },
    {
        "school": "Will James Middle School",
        "district": "Billings Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387000904",
    },
    {
        "school": "Billings Sr High School",
        "district": "Billings H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300390000090",
    },
    {
        "school": "Billings West High School",
        "district": "Billings H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300390000091",
    },
    {
        "school": "Skyview High School",
        "district": "Billings H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300390000871",
    },
    {
        "school": "Blue Creek School",
        "district": "Blue Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300423000099",
    },
    {
        "school": "Broadview School",
        "district": "Broadview Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300489000121",
    },
    {
        "school": "Broadview 7-8",
        "district": "Broadview Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300489001082",
    },
    {
        "school": "Broadview High School",
        "district": "Broadview H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300492000122",
    },
    {
        "school": "Canyon Creek School",
        "district": "Canyon Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300546000160",
    },
    {
        "school": "Canyon Creek 7-8",
        "district": "Canyon Creek Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300546001079",
    },
    {
        "school": "Custer School",
        "district": "Custer K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300813000231",
    },
    {
        "school": "Custer High School",
        "district": "Custer K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300813000232",
    },
    {
        "school": "Custer 7-8",
        "district": "Custer K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300813001081",
    },
    {
        "school": "Elder Grove School",
        "district": "Elder Grove Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300972000273",
    },
    {
        "school": "Elder Grove 7-8",
        "district": "Elder Grove Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300972001080",
    },
    {
        "school": "Elysian School",
        "district": "Elysian Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300984000276",
    },
    {
        "school": "Elysian Middle School",
        "district": "Elysian Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300984000293",
    },
    {
        "school": "Huntley Project Elem K-6",
        "district": "Huntley Project K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301470000450",
    },
    {
        "school": "Huntley Project High Schl",
        "district": "Huntley Project K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301470000452",
    },
    {
        "school": "Huntley Project 7-8",
        "district": "Huntley Project K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301470000887",
    },
    {
        "school": "Independent School",
        "district": "Independent Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301482000455",
    },
    {
        "school": "Fred W Graff School",
        "district": "Laurel Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301620000497",
    },
    {
        "school": "West School",
        "district": "Laurel Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301620000499",
    },
    {
        "school": "Laurel Middle School",
        "district": "Laurel Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301620000890",
    },
    {
        "school": "Laurel High School",
        "district": "Laurel H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301623000501",
    },
    {
        "school": "Morin School",
        "district": "Morin Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301896000590",
    },
    {
        "school": "Pioneer School",
        "district": "Pioneer Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302079000621",
    },
    {
        "school": "Shepherd Elementary",
        "district": "Shepherd Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302394000695",
    },
    {
        "school": "Shepherd Middle School",
        "district": "Shepherd Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302394001083",
    },
    {
        "school": "Shepherd High School",
        "district": "Shepherd H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302397000696",
    },
    {
        "school": "Yellowstone Academy Elem",
        "district": "Yellowstone Academy Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302886000806",
    },
    {
        "school": "Cottonwood School",
        "district": "Cottonwood Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300750000353",
    },
    {
        "school": "Malmborg School",
        "district": "Malmborg Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301752000354",
    },
    {
        "school": "Amsterdam School",
        "district": "Amsterdam Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300198000007",
    },
    {
        "school": "Anderson School",
        "district": "Anderson Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300207000016",
    },
    {
        "school": "Anderson 7-8",
        "district": "Anderson Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300207000976",
    },
    {
        "school": "Belgrade Middle School",
        "district": "Belgrade Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300329000044",
    },
    {
        "school": "Heck/Quaw Elementary",
        "district": "Belgrade Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300329000324",
    },
    {
        "school": "Ridge View Elementary",
        "district": "Belgrade Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300329000342",
    },
    {
        "school": "Belgrade High School",
        "district": "Belgrade H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300333000046",
    },
    {
        "school": "Emily Dickinson School",
        "district": "Bozeman Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300456000017",
    },
    {
        "school": "Morning Star School",
        "district": "Bozeman Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300456000106",
    },
    {
        "school": "Hawthorne School",
        "district": "Bozeman Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300456000107",
    },
    {
        "school": "Irving School",
        "district": "Bozeman Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300456000108",
    },
    {
        "school": "Longfellow School",
        "district": "Bozeman Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300456000109",
    },
    {
        "school": "Whittier School",
        "district": "Bozeman Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300456000110",
    },
    {
        "school": "Chief Joseph Middle School",
        "district": "Bozeman Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300456000112",
    },
    {
        "school": "Sacajawea Middle School",
        "district": "Bozeman Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300456000165",
    },
    {
        "school": "Bozeman High School",
        "district": "Bozeman H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300459000113",
    },
    {
        "school": "Gallatin Gateway School",
        "district": "Gallatin Gateway Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301179000320",
    },
    {
        "school": "Gallatin Gateway 7-8",
        "district": "Gallatin Gateway Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301179000975",
    },
    {
        "school": "LaMotte 6-8",
        "district": "LaMotte Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301611000241",
    },
    {
        "school": "LaMotte School",
        "district": "LaMotte Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301611000495",
    },
    {
        "school": "Manhattan Elem",
        "district": "Manhattan School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301761000547",
    },
    {
        "school": "Manhattan 5-8",
        "district": "Manhattan School",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301761000971",
    },
    {
        "school": "Manhattan H S",
        "district": "Manhattan High School",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301764000548",
    },
    {
        "school": "Monforton School",
        "district": "Monforton Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301875000585",
    },
    {
        "school": "Monforton Primary",
        "district": "Monforton Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301875000826",
    },
    {
        "school": "Monforton 6-8",
        "district": "Monforton Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301875000974",
    },
    {
        "school": "Pass Creek School",
        "district": "Pass Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302017000612",
    },
    {
        "school": "Springhill School",
        "district": "Springhill Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302481000713",
    },
    {
        "school": "Three Forks Elem School",
        "district": "Three Forks Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302616000740",
    },
    {
        "school": "Three Forks 7-8",
        "district": "Three Forks Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302616000973",
    },
    {
        "school": "Three Forks High School",
        "district": "Three Forks H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302619000741",
    },
    {
        "school": "West Yellowstone School",
        "district": "West Yellowstone K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302763000768",
    },
    {
        "school": "West Yellowstone HS",
        "district": "West Yellowstone K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302763000769",
    },
    {
        "school": "West Yellowstone 7-8",
        "district": "West Yellowstone K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302763000977",
    },
    {
        "school": "Willow Creek School",
        "district": "Willow Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302814000785",
    },
    {
        "school": "Willow Creek 7-8",
        "district": "Willow Creek Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302814000972",
    },
    {
        "school": "Willow Creek High School",
        "district": "Willow Creek H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302817000786",
    },
    {
        "school": "Emerson School",
        "district": "Butte Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300528000140",
    },
    {
        "school": "Hillcrest School",
        "district": "Butte Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300528000143",
    },
    {
        "school": "Kennedy School",
        "district": "Butte Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300528000144",
    },
    {
        "school": "Margaret Leary School",
        "district": "Butte Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300528000148",
    },
    {
        "school": "Whittier School",
        "district": "Butte Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300528000153",
    },
    {
        "school": "East Middle School",
        "district": "Butte Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300528000905",
    },
    {
        "school": "West Elementary School",
        "district": "Butte Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300528000906",
    },
    {
        "school": "Butte High School",
        "district": "Butte H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300531000156",
    },
    {
        "school": "Divide School",
        "district": "Divide Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300900000258",
    },
    {
        "school": "Melrose School",
        "district": "Melrose Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301821000553",
    },
    {
        "school": "Ramsay School",
        "district": "Ramsay Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302185000648",
    },
    {
        "school": "Ramsay 7-8",
        "district": "Ramsay Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302185001058",
    },
    {
        "school": "MT Sch For Deaf & Blnd HS",
        "district": "Mont Sch for Deaf Blind",
        "level": "High",
        "type": "Special education school",
        "state": "MT",
        "nces_id": "300010000114",
    },
    {
        "school": "MT Sch For Deaf & Blnd El",
        "district": "Mont Sch for Deaf Blind",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MT",
        "nces_id": "300010001084",
    },
    {
        "school": "Belt School",
        "district": "Belt Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300342000047",
    },
    {
        "school": "Pleasant Valley School",
        "district": "Belt Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300342000925",
    },
    {
        "school": "Belt 7-8",
        "district": "Belt Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300342000943",
    },
    {
        "school": "Belt High School",
        "district": "Belt H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300345000048",
    },
    {
        "school": "Vaughn School",
        "district": "Vaughn Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300585000168",
    },
    {
        "school": "Vaughn 7-8",
        "district": "Vaughn Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300585000944",
    },
    {
        "school": "Cascade School",
        "district": "Cascade Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300588000169",
    },
    {
        "school": "Cascade 7-8",
        "district": "Cascade Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300588000941",
    },
    {
        "school": "Cascade High School",
        "district": "Cascade H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300591000170",
    },
    {
        "school": "Chief Joseph School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000357",
    },
    {
        "school": "Lewis & Clark School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000361",
    },
    {
        "school": "Lincoln School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000362",
    },
    {
        "school": "Longfellow School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000363",
    },
    {
        "school": "Loy School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000365",
    },
    {
        "school": "Meadow Lark School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000367",
    },
    {
        "school": "Morningside School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000368",
    },
    {
        "school": "Mountain View School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000369",
    },
    {
        "school": "Riverview School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000370",
    },
    {
        "school": "Sacajawea School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000373",
    },
    {
        "school": "Sunnyside School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000376",
    },
    {
        "school": "Valley View School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000377",
    },
    {
        "school": "Whittier School",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000378",
    },
    {
        "school": "West Elementary",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000881",
    },
    {
        "school": "East Middle School",
        "district": "Great Falls Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000882",
    },
    {
        "school": "North Middle School",
        "district": "Great Falls Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304000883",
    },
    {
        "school": "C M Russell High School",
        "district": "Great Falls H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301305000379",
    },
    {
        "school": "Great Falls High School",
        "district": "Great Falls H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301305000380",
    },
    {
        "school": "Fort Shaw Elem School",
        "district": "Sun River Valley Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302430000703",
    },
    {
        "school": "Sun River Middle School",
        "district": "Sun River Valley Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302430000724",
    },
    {
        "school": "Cascade Colony School",
        "district": "Sun River Valley Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302430000928",
    },
    {
        "school": "Simms High School",
        "district": "Simms H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302433000704",
    },
    {
        "school": "Centerville School",
        "district": "Centerville Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302513000721",
    },
    {
        "school": "Big Stone School",
        "district": "Centerville Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302513000922",
    },
    {
        "school": "Centerville 6-8",
        "district": "Centerville Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302513000942",
    },
    {
        "school": "Centerville High School",
        "district": "Centerville H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302514000722",
    },
    {
        "school": "Ulm School",
        "district": "Ulm Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302688000756",
    },
    {
        "school": "Fairhaven Colony",
        "district": "Ulm Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302688000923",
    },
    {
        "school": "Ulm Junior High",
        "district": "Ulm Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302688000945",
    },
    {
        "school": "North Star 7-8",
        "district": "North Star Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009600441",
    },
    {
        "school": "North Star School",
        "district": "North Star Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009600485",
    },
    {
        "school": "North Star High School",
        "district": "North Star HS",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009700679",
    },
    {
        "school": "Box Elder School",
        "district": "Box Elder Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300444000103",
    },
    {
        "school": "Box Elder 7-8",
        "district": "Box Elder Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300444000985",
    },
    {
        "school": "Box Elder High School",
        "district": "Box Elder H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300450000104",
    },
    {
        "school": "Davey Elementary",
        "district": "Davey Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300831000239",
    },
    {
        "school": "Gildford Colony School",
        "district": "Gildford Colony Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301235000336",
    },
    {
        "school": "Havre Middle School",
        "district": "Havre Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301356000406",
    },
    {
        "school": "Highland Park School",
        "district": "Havre Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301356000408",
    },
    {
        "school": "Lincoln-McKinley School",
        "district": "Havre Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301356000409",
    },
    {
        "school": "Sunnyside School",
        "district": "Havre Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301356000410",
    },
    {
        "school": "Havre High School",
        "district": "Havre H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301359000411",
    },
    {
        "school": "Cottonwood School",
        "district": "Cottonwood Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301415000439",
    },
    {
        "school": "Rocky Boy School",
        "district": "Rocky Boy Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302275000666",
    },
    {
        "school": "Rocky Boy 7-8",
        "district": "Rocky Boy Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302275000986",
    },
    {
        "school": "Rocky Boy High School",
        "district": "Rocky Boy H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302891101086",
    },
    {
        "school": "Pine Hills Youth Corr Facil El",
        "district": "Dept of Corrections-Youth",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MT",
        "nces_id": "300009100138",
    },
    {
        "school": "Pine Hills Youth Corr Facil HS",
        "district": "Dept of Corrections-Youth",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MT",
        "nces_id": "300009100861",
    },
    {
        "school": "Basin School",
        "district": "Basin Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300282000036",
    },
    {
        "school": "Boulder Elementary School",
        "district": "Boulder Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300438000102",
    },
    {
        "school": "Boulder 7-8",
        "district": "Boulder Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300438000989",
    },
    {
        "school": "Cardwell School",
        "district": "Cardwell Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300555000161",
    },
    {
        "school": "Clancy School",
        "district": "Clancy Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300684000188",
    },
    {
        "school": "Clancy 7-8",
        "district": "Clancy Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300684000988",
    },
    {
        "school": "Jefferson High School",
        "district": "Jefferson H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301512000461",
    },
    {
        "school": "Montana City School",
        "district": "Montana City Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301878000586",
    },
    {
        "school": "Montana City Middle Schl",
        "district": "Montana City Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301878000990",
    },
    {
        "school": "Whitehall 6-8",
        "district": "Whitehall Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302781000776",
    },
    {
        "school": "Whitehall Elementary",
        "district": "Whitehall Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302781000777",
    },
    {
        "school": "Whitehall High School",
        "district": "Whitehall H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302784000778",
    },
    {
        "school": "Kessler Elementary School",
        "district": "Helena Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500337",
    },
    {
        "school": "Broadwater School",
        "district": "Helena Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500415",
    },
    {
        "school": "Bryant School",
        "district": "Helena Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500416",
    },
    {
        "school": "Central School",
        "district": "Helena Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500418",
    },
    {
        "school": "Four Georgians School",
        "district": "Helena Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500419",
    },
    {
        "school": "Hawthorne School",
        "district": "Helena Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500420",
    },
    {
        "school": "Jefferson School",
        "district": "Helena Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500421",
    },
    {
        "school": "Rossiter School",
        "district": "Helena Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500424",
    },
    {
        "school": "Smith School",
        "district": "Helena Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500425",
    },
    {
        "school": "Jim Darcy School",
        "district": "Helena Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500505",
    },
    {
        "school": "Warren School",
        "district": "Helena Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500506",
    },
    {
        "school": "Helena Middle School",
        "district": "Helena Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500885",
    },
    {
        "school": "C R Anderson Middle Schl",
        "district": "Helena Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000500886",
    },
    {
        "school": "Augusta Elementary School",
        "district": "Augusta Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300243000024",
    },
    {
        "school": "Augusta 7-8",
        "district": "Augusta Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300243000997",
    },
    {
        "school": "Augusta High School",
        "district": "Augusta H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300245000025",
    },
    {
        "school": "Auchard Creek School",
        "district": "Auchard Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300249000026",
    },
    {
        "school": "Capital High School",
        "district": "Helena H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301383000429",
    },
    {
        "school": "Helena High School",
        "district": "Helena H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301383000430",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Lincoln K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301681000522",
    },
    {
        "school": "Lincoln High School",
        "district": "Lincoln K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301681000892",
    },
    {
        "school": "Lincoln 7-8",
        "district": "Lincoln K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301681000996",
    },
    {
        "school": "Trinity School",
        "district": "Trinity Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302649000746",
    },
    {
        "school": "Wolf Creek School",
        "district": "Wolf Creek Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302855000795",
    },
    {
        "school": "Glacier High School",
        "district": "Flathead H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301542000358",
    },
    {
        "school": "Lakeside Elementary School",
        "district": "Somers Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000200705",
    },
    {
        "school": "Somers Middle School",
        "district": "Somers Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000200965",
    },
    {
        "school": "West Glacier School",
        "district": "West Glacier Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009400919",
    },
    {
        "school": "Smith Valley Primary Schl",
        "district": "Smith Valley Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300285000037",
    },
    {
        "school": "Smith Valley 7-8",
        "district": "Smith Valley Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300285000101",
    },
    {
        "school": "Bigfork Elementary",
        "district": "Bigfork Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300382000057",
    },
    {
        "school": "Bigfork 7-8",
        "district": "Bigfork Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300382000966",
    },
    {
        "school": "Bigfork High School",
        "district": "Bigfork H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300384000058",
    },
    {
        "school": "Cayuse Prairie School",
        "district": "Cayuse Prairie Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300599000172",
    },
    {
        "school": "Cayuse Prairie 7-8",
        "district": "Cayuse Prairie Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300599000963",
    },
    {
        "school": "Columbia Falls Jr HS",
        "district": "Columbia Falls Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300711000195",
    },
    {
        "school": "Glacier Gateway Elem",
        "district": "Columbia Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300711000196",
    },
    {
        "school": "Ruder Elementary",
        "district": "Columbia Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300711000198",
    },
    {
        "school": "Columbia Falls High Schl",
        "district": "Columbia Falls H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300714000203",
    },
    {
        "school": "Creston School",
        "district": "Creston Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300771000221",
    },
    {
        "school": "Deer Park School",
        "district": "Deer Park Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300870000249",
    },
    {
        "school": "Deer Park 7-8",
        "district": "Deer Park Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300870000960",
    },
    {
        "school": "Fair-Mont-Egan School",
        "district": "Fair-Mont-Egan Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301023000283",
    },
    {
        "school": "Fair-Mont-Egan Middle School",
        "district": "Fair-Mont-Egan Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301023000961",
    },
    {
        "school": "East Evergreen School",
        "district": "Evergreen Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301092000292",
    },
    {
        "school": "Evergreen Junior High",
        "district": "Evergreen Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301092000967",
    },
    {
        "school": "Bissell School",
        "district": "Olney-Bissell Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301095000296",
    },
    {
        "school": "Bissell 7-8",
        "district": "Olney-Bissell Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301095000969",
    },
    {
        "school": "Helena Flats School",
        "district": "Helena Flats Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301380000426",
    },
    {
        "school": "Helena Flats 7-8",
        "district": "Helena Flats Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301380000964",
    },
    {
        "school": "Flathead High School",
        "district": "Flathead H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301542000470",
    },
    {
        "school": "Kalispell Middle School",
        "district": "Kalispell Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301545000086",
    },
    {
        "school": "Cornelius Hedges School",
        "district": "Kalispell Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301545000471",
    },
    {
        "school": "Edgerton School",
        "district": "Kalispell Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301545000472",
    },
    {
        "school": "Elrod School",
        "district": "Kalispell Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301545000473",
    },
    {
        "school": "Lillian Peterson School",
        "district": "Kalispell Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301545000474",
    },
    {
        "school": "Russell School",
        "district": "Kalispell Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301545000475",
    },
    {
        "school": "Kila 7-8",
        "district": "Kila Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301557000130",
    },
    {
        "school": "Kila School",
        "district": "Kila Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301557000480",
    },
    {
        "school": "Marion School",
        "district": "Marion Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301770000549",
    },
    {
        "school": "Marion 7-8",
        "district": "Marion Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301770000968",
    },
    {
        "school": "Pleasant Valley School",
        "district": "Pleasant Valley Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302088000624",
    },
    {
        "school": "Swan River School",
        "district": "Swan River Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302550000730",
    },
    {
        "school": "Swan River 7-8",
        "district": "Swan River Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302550000962",
    },
    {
        "school": "West Valley School",
        "district": "West Valley Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302757000767",
    },
    {
        "school": "West Valley Middle School",
        "district": "West Valley Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302757000970",
    },
    {
        "school": "L A Muldown School",
        "district": "Whitefish Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302774000773",
    },
    {
        "school": "Whitefish Middle 5-8",
        "district": "Whitefish Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302774000830",
    },
    {
        "school": "Whitefish High School",
        "district": "Whitefish H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302779000775",
    },
    {
        "school": "Bonner School",
        "district": "Bonner Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300426000100",
    },
    {
        "school": "Bonner 7-8",
        "district": "Bonner Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300426001012",
    },
    {
        "school": "Clinton School",
        "district": "Clinton Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300687000189",
    },
    {
        "school": "Clinton 7-8",
        "district": "Clinton Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300687001016",
    },
    {
        "school": "DeSmet School",
        "district": "DeSmet Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300888000254",
    },
    {
        "school": "DeSmet 7-8",
        "district": "DeSmet Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300888001014",
    },
    {
        "school": "Frenchtown Elementary School",
        "district": "Frenchtown K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301152000312",
    },
    {
        "school": "Frenchtown High School",
        "district": "Frenchtown K-12 Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301152000313",
    },
    {
        "school": "Frenchtown 6-8",
        "district": "Frenchtown K-12 Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301152001019",
    },
    {
        "school": "Hellgate Elem Lower Grades",
        "district": "Hellgate Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301386000432",
    },
    {
        "school": "Hellgate Middle School",
        "district": "Hellgate Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301386001010",
    },
    {
        "school": "Lolo Elementary",
        "district": "Lolo Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301713000536",
    },
    {
        "school": "Lolo Middle School",
        "district": "Lolo Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301713000821",
    },
    {
        "school": "Hellgate High School",
        "district": "Missoula H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301854000562",
    },
    {
        "school": "Seeley-Swan High School",
        "district": "Missoula H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301854000563",
    },
    {
        "school": "Sentinel High School",
        "district": "Missoula H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301854000564",
    },
    {
        "school": "Big Sky High School",
        "district": "Missoula H S",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301854000824",
    },
    {
        "school": "Chief Charlo School",
        "district": "Missoula Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000164",
    },
    {
        "school": "Porter Middle School",
        "district": "Missoula Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000565",
    },
    {
        "school": "Jeannette Rankin El",
        "district": "Missoula Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000567",
    },
    {
        "school": "Franklin School",
        "district": "Missoula Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000569",
    },
    {
        "school": "Hawthorne School",
        "district": "Missoula Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000570",
    },
    {
        "school": "Lewis & Clark School",
        "district": "Missoula Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000572",
    },
    {
        "school": "Lowell School",
        "district": "Missoula Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000574",
    },
    {
        "school": "Meadow Hill Middle School",
        "district": "Missoula Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000575",
    },
    {
        "school": "Paxson School",
        "district": "Missoula Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000576",
    },
    {
        "school": "Rattlesnake Elementary School",
        "district": "Missoula Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000578",
    },
    {
        "school": "Russell School",
        "district": "Missoula Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000580",
    },
    {
        "school": "Washington Middle School",
        "district": "Missoula Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301857000581",
    },
    {
        "school": "Potomac School",
        "district": "Potomac Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302133000639",
    },
    {
        "school": "Potomac 7-8",
        "district": "Potomac Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302133001011",
    },
    {
        "school": "Seeley Lake Elementary",
        "district": "Seeley Lake Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302373000689",
    },
    {
        "school": "Seeley Lake 7-8",
        "district": "Seeley Lake Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302373001018",
    },
    {
        "school": "Sunset School",
        "district": "Sunset Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302538000727",
    },
    {
        "school": "Swan Valley School",
        "district": "Swan Valley Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302553000731",
    },
    {
        "school": "Swan Valley 7-8",
        "district": "Swan Valley Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302553001017",
    },
    {
        "school": "Target Range School",
        "district": "Target Range Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302589000734",
    },
    {
        "school": "Target Range 7-8",
        "district": "Target Range Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302589001015",
    },
    {
        "school": "Woodman School",
        "district": "Woodman Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302865000800",
    },
    {
        "school": "Woodman 7-8",
        "district": "Woodman Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302865001013",
    },
    {
        "school": "Columbus Charter School",
        "district": "Columbus Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370014002923",
    },
    {
        "school": "ABSS Early College at ACC",
        "district": "Alamance-Burlington Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003002972",
    },
    {
        "school": "Bertie Middle",
        "district": "Bertie County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036002818",
    },
    {
        "school": "Brunswick County Early College",
        "district": "Brunswick County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042002898",
    },
    {
        "school": "Middle College",
        "district": "Buncombe County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045002974",
    },
    {
        "school": "Burke Middle College",
        "district": "Burke County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048002908",
    },
    {
        "school": "Performance Learning Center",
        "district": "Cabarrus County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370053002975",
    },
    {
        "school": "Caldwell Early College",
        "district": "Caldwell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058002880",
    },
    {
        "school": "Maiden Middle School",
        "district": "Catawba County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069002884",
    },
    {
        "school": "Catawba Rosenwald Education Center",
        "district": "Catawba County Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370069002978",
    },
    {
        "school": "Tri-County Early College High",
        "district": "Cherokee County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078002892",
    },
    {
        "school": "CCCA - Fair Bluff /Southeastern Campuses",
        "district": "Columbus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096002902",
    },
    {
        "school": "Nakina Middle",
        "district": "Columbus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096002979",
    },
    {
        "school": "Craven Early College High",
        "district": "Craven County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002843",
    },
    {
        "school": "Creekside Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002980",
    },
    {
        "school": "Alger B. Wilkins High School",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370001102981",
    },
    {
        "school": "Central Davie Academy",
        "district": "Davie County Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370117002853",
    },
    {
        "school": "The Special Children's School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370150002985",
    },
    {
        "school": "Granville Central High",
        "district": "Granville County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180002829",
    },
    {
        "school": "Greene Early College High",
        "district": "Greene County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370183002860",
    },
    {
        "school": "Northern Guilford Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002855",
    },
    {
        "school": "Kearns Academy",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002989",
    },
    {
        "school": "Northern Guilford High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002991",
    },
    {
        "school": "EP Pearce Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002992",
    },
    {
        "school": "Reedy Fork Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002993",
    },
    {
        "school": "Haywood Early College",
        "district": "Haywood County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204002873",
    },
    {
        "school": "SandHoke Early College High",
        "district": "Hoke County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225002897",
    },
    {
        "school": "Dixon Road Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002856",
    },
    {
        "school": "West View Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002907",
    },
    {
        "school": "Archer Lodge Middle",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002998",
    },
    {
        "school": "Lee Early College",
        "district": "Lee County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256002868",
    },
    {
        "school": "Childers Elementary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268002851",
    },
    {
        "school": "Pumpkin Center Intermediate",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268002999",
    },
    {
        "school": "McDowell Early College",
        "district": "McDowell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294002809",
    },
    {
        "school": "Macon Early College High School",
        "district": "Macon County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370276002901",
    },
    {
        "school": "Performance Learning Center",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002842",
    },
    {
        "school": "Winget Park Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002857",
    },
    {
        "school": "Bailey Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002870",
    },
    {
        "school": "Highland Creek Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002877",
    },
    {
        "school": "J.V. Washam Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002891",
    },
    {
        "school": "Ardrey Kell High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002910",
    },
    {
        "school": "Cato Middle College High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003000",
    },
    {
        "school": "Lake Forest Academy",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370333002865",
    },
    {
        "school": "Isaac M Bear Early College High School",
        "district": "New Hanover County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002888",
    },
    {
        "school": "Central Elementary",
        "district": "Northampton County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370342002895",
    },
    {
        "school": "Gravelly Hill Middle",
        "district": "Orange County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348002900",
    },
    {
        "school": "Pender Early College High",
        "district": "Pender County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357002906",
    },
    {
        "school": "Roxboro Community School",
        "district": "Roxboro Community School",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370017502914",
    },
    {
        "school": "Hope Middle",
        "district": "Pitt County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202867",
    },
    {
        "school": "Polk County Early College",
        "district": "Polk County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370372003006",
    },
    {
        "school": "Randolph Early College High",
        "district": "Randolph County School System",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378002883",
    },
    {
        "school": "Scotland Early College High",
        "district": "Scotland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370420003007",
    },
    {
        "school": "Koontz Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405002850",
    },
    {
        "school": "Carson High",
        "district": "Rowan-Salisbury Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405002882",
    },
    {
        "school": "Stanly Early College High",
        "district": "Stanly County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432002890",
    },
    {
        "school": "Stanly Academy Learning Center",
        "district": "Stanly County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370432003008",
    },
    {
        "school": "Surry Early College",
        "district": "Surry County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441002903",
    },
    {
        "school": "Marvin Ridge High",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002845",
    },
    {
        "school": "Rock Rest Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002862",
    },
    {
        "school": "Union County Early College",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002893",
    },
    {
        "school": "Marvin Ridge Middle",
        "district": "Union County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002904",
    },
    {
        "school": "Panther Creek High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002810",
    },
    {
        "school": "Holly Springs High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002847",
    },
    {
        "school": "Barwell Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002854",
    },
    {
        "school": "River Bend Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002861",
    },
    {
        "school": "Carpenter Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002864",
    },
    {
        "school": "Wake Early College of Health and Science",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002866",
    },
    {
        "school": "Brier Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002887",
    },
    {
        "school": "Holly Grove Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002899",
    },
    {
        "school": "Warren New Tech High",
        "district": "Warren County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370474003009",
    },
    {
        "school": "Wayne Early / Middle College High",
        "district": "Wayne County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488002881",
    },
    {
        "school": "Wayne School of Engineering",
        "district": "Wayne County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488003010",
    },
    {
        "school": "Westwood Elementary",
        "district": "Ashe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370021002704",
    },
    {
        "school": "Bladenboro Middle",
        "district": "Bladen County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039002617",
    },
    {
        "school": "Elizabethtown Middle",
        "district": "Bladen County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039002618",
    },
    {
        "school": "Tar Heel Middle",
        "district": "Bladen County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039002619",
    },
    {
        "school": "West Bladen High",
        "district": "Bladen County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039002620",
    },
    {
        "school": "Hiwassee Dam High",
        "district": "Cherokee County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078002626",
    },
    {
        "school": "JF Webb HS Of Health And Life Sciences",
        "district": "Granville County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180002769",
    },
    {
        "school": "Polk County Middle School",
        "district": "Polk County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370372002790",
    },
    {
        "school": "Mountain Discovery",
        "district": "Mountain Discovery Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370012902614",
    },
    {
        "school": "Columbia Middle",
        "district": "Tyrrell County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370459002650",
    },
    {
        "school": "Alleghany High",
        "district": "Alleghany County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370012000037",
    },
    {
        "school": "Glade Creek Elementary",
        "district": "Alleghany County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370012000038",
    },
    {
        "school": "Piney Creek Elementary",
        "district": "Alleghany County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370012000039",
    },
    {
        "school": "Sparta Elementary",
        "district": "Alleghany County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370012000040",
    },
    {
        "school": "Blue Ridge Elementary",
        "district": "Ashe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370021000971",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Ashe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370021002284",
    },
    {
        "school": "Ashe County High",
        "district": "Ashe County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370021002425",
    },
    {
        "school": "Ashe County Middle",
        "district": "Ashe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370021002426",
    },
    {
        "school": "Grandfather Academy",
        "district": "Grandfather Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001602068",
    },
    {
        "school": "Marjorie Williams Academy",
        "district": "Williams Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370007702427",
    },
    {
        "school": "Avery County High",
        "district": "Avery County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370030000081",
    },
    {
        "school": "Banner Elk Elementary",
        "district": "Avery County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370030000082",
    },
    {
        "school": "Crossnore Elementary",
        "district": "Avery County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370030000084",
    },
    {
        "school": "Avery Middle",
        "district": "Avery County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370030000085",
    },
    {
        "school": "Newland Elementary",
        "district": "Avery County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370030000088",
    },
    {
        "school": "Riverside Elementary",
        "district": "Avery County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370030000089",
    },
    {
        "school": "Cranberry Middle",
        "district": "Avery County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370030001723",
    },
    {
        "school": "Freedom Trail Elementary",
        "district": "Avery County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370030001760",
    },
    {
        "school": "Bertie High",
        "district": "Bertie County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036000101",
    },
    {
        "school": "Aulander Elementary",
        "district": "Bertie County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036000104",
    },
    {
        "school": "West Bertie Elementary",
        "district": "Bertie County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036000106",
    },
    {
        "school": "Colerain Elementary",
        "district": "Bertie County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036000107",
    },
    {
        "school": "Windsor Elementary",
        "district": "Bertie County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036002285",
    },
    {
        "school": "Bladen Lakes Primary",
        "district": "Bladen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039000111",
    },
    {
        "school": "Clarkton School of Discovery",
        "district": "Bladen County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039000113",
    },
    {
        "school": "Dublin Primary",
        "district": "Bladen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039000114",
    },
    {
        "school": "East Arcadia Elementary",
        "district": "Bladen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039000115",
    },
    {
        "school": "East Bladen High",
        "district": "Bladen County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039000116",
    },
    {
        "school": "Elizabethtown Primary",
        "district": "Bladen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039000118",
    },
    {
        "school": "Plain View Primary",
        "district": "Bladen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039000119",
    },
    {
        "school": "Bladenboro Primary",
        "district": "Bladen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039002150",
    },
    {
        "school": "North Elementary",
        "district": "Caswell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370066000117",
    },
    {
        "school": "South Elementary",
        "district": "Caswell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370066000128",
    },
    {
        "school": "Bartlett Yancey High",
        "district": "Caswell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370066000264",
    },
    {
        "school": "N L Dillard Middle",
        "district": "Caswell County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370066000268",
    },
    {
        "school": "Oakwood Elementary",
        "district": "Caswell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370066000269",
    },
    {
        "school": "Stoney Creek Elementary",
        "district": "Caswell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370066000271",
    },
    {
        "school": "The Learning Center",
        "district": "The Learning Center",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370002102083",
    },
    {
        "school": "Andrews Elementary",
        "district": "Cherokee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078000317",
    },
    {
        "school": "Andrews High",
        "district": "Cherokee County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078000318",
    },
    {
        "school": "Hiwassee Dam Elementary/Middle",
        "district": "Cherokee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078000319",
    },
    {
        "school": "Martins Creek Elementary/Mid",
        "district": "Cherokee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078000321",
    },
    {
        "school": "Murphy Elementary",
        "district": "Cherokee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078000322",
    },
    {
        "school": "Murphy High",
        "district": "Cherokee County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078000323",
    },
    {
        "school": "Peachtree Elementary",
        "district": "Cherokee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078000324",
    },
    {
        "school": "Ranger Elementary/Middle",
        "district": "Cherokee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078000325",
    },
    {
        "school": "Murphy Middle",
        "district": "Cherokee County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078001056",
    },
    {
        "school": "Andrews Middle",
        "district": "Cherokee County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370078001820",
    },
    {
        "school": "The Oaks Academy",
        "district": "Cherokee County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370078002082",
    },
    {
        "school": "Chowan Middle",
        "district": "Edenton-Chowan Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370084000327",
    },
    {
        "school": "D F Walker Elementary",
        "district": "Edenton-Chowan Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370084000328",
    },
    {
        "school": "John A Holmes High",
        "district": "Edenton-Chowan Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370084000330",
    },
    {
        "school": "White Oak Elementary",
        "district": "Edenton-Chowan Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370084000331",
    },
    {
        "school": "Hayesville Elementary",
        "district": "Clay County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370087000332",
    },
    {
        "school": "Hayesville High",
        "district": "Clay County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370087000333",
    },
    {
        "school": "Hayesville Middle",
        "district": "Clay County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370087002226",
    },
    {
        "school": "East Columbus High",
        "district": "Columbus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000145",
    },
    {
        "school": "South Columbus High",
        "district": "Columbus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000237",
    },
    {
        "school": "Acme Delco Elementary",
        "district": "Columbus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000357",
    },
    {
        "school": "Acme Delco Middle",
        "district": "Columbus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000358",
    },
    {
        "school": "Cerro Gordo Elementary",
        "district": "Columbus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000360",
    },
    {
        "school": "Chadbourn Elementary",
        "district": "Columbus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000362",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Columbus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000363",
    },
    {
        "school": "Guideway Elementary",
        "district": "Columbus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000366",
    },
    {
        "school": "Hallsboro-Artesia Elementary",
        "district": "Columbus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000367",
    },
    {
        "school": "Hallsboro Middle",
        "district": "Columbus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000368",
    },
    {
        "school": "Old Dock Elementary",
        "district": "Columbus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000370",
    },
    {
        "school": "Tabor City Elementary",
        "district": "Columbus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000371",
    },
    {
        "school": "Tabor City Middle",
        "district": "Columbus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000372",
    },
    {
        "school": "West Columbus High",
        "district": "Columbus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000373",
    },
    {
        "school": "Williams Township",
        "district": "Columbus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370096000374",
    },
    {
        "school": "Central Middle",
        "district": "Whiteville City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370492001967",
    },
    {
        "school": "Edgewood Elementary",
        "district": "Whiteville City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370492001968",
    },
    {
        "school": "Whiteville Primary",
        "district": "Whiteville City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370492001969",
    },
    {
        "school": "Whiteville High",
        "district": "Whiteville City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370492001970",
    },
    {
        "school": "North Whiteville Academy",
        "district": "Whiteville City Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370492002510",
    },
    {
        "school": "B F Grady Elementary",
        "district": "Duplin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120000492",
    },
    {
        "school": "Beulaville Elementary",
        "district": "Duplin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120000493",
    },
    {
        "school": "East Duplin High",
        "district": "Duplin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120000497",
    },
    {
        "school": "James Kenan High",
        "district": "Duplin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120000498",
    },
    {
        "school": "Kenansville Elementary",
        "district": "Duplin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120000499",
    },
    {
        "school": "North Duplin Jr Sr High",
        "district": "Duplin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120000500",
    },
    {
        "school": "North Duplin Elementary",
        "district": "Duplin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120000501",
    },
    {
        "school": "Rose Hill-Magnolia Elementary",
        "district": "Duplin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120000503",
    },
    {
        "school": "Wallace Elementary",
        "district": "Duplin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120000504",
    },
    {
        "school": "Wallace-Rose Hill High",
        "district": "Duplin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120000505",
    },
    {
        "school": "Warsaw Elementary",
        "district": "Duplin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120000506",
    },
    {
        "school": "Chinquapin Elementary",
        "district": "Duplin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120001393",
    },
    {
        "school": "Buckland Elementary",
        "district": "Gates County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370168000718",
    },
    {
        "school": "Central Middle School",
        "district": "Gates County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370168000719",
    },
    {
        "school": "Gates County Senior High",
        "district": "Gates County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370168000720",
    },
    {
        "school": "Gatesville Elementary",
        "district": "Gates County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370168000721",
    },
    {
        "school": "T S Cooper Elementary",
        "district": "Gates County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370168000723",
    },
    {
        "school": "Robbinsville Middle",
        "district": "Graham County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370177000576",
    },
    {
        "school": "Robbinsville Elementary",
        "district": "Graham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370177000733",
    },
    {
        "school": "Robbinsville High",
        "district": "Graham County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370177000734",
    },
    {
        "school": "Midway High",
        "district": "Sampson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001676",
    },
    {
        "school": "Ahoskie Elementary",
        "district": "Hertford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370216000931",
    },
    {
        "school": "Riverview Elementary",
        "district": "Hertford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370216000938",
    },
    {
        "school": "Hertford County Middle",
        "district": "Hertford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370216002207",
    },
    {
        "school": "Hertford County High",
        "district": "Hertford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370216002208",
    },
    {
        "school": "Bearfield Primary",
        "district": "Hertford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370216002526",
    },
    {
        "school": "Ocracoke School",
        "district": "Hyde County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370228000979",
    },
    {
        "school": "Mattamuskeet Elementary",
        "district": "Hyde County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370228002460",
    },
    {
        "school": "Summit Charter",
        "district": "Summit Charter",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370002902321",
    },
    {
        "school": "Blue Ridge School",
        "district": "Jackson County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370234001001",
    },
    {
        "school": "Cullowhee Valley School",
        "district": "Jackson County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370234001002",
    },
    {
        "school": "Fairview Elementary",
        "district": "Jackson County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370234001004",
    },
    {
        "school": "Scotts Creek Elementary",
        "district": "Jackson County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370234001007",
    },
    {
        "school": "Smoky Mountain High School",
        "district": "Jackson County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370234001008",
    },
    {
        "school": "Smokey Mountain Elementary",
        "district": "Jackson County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370234002067",
    },
    {
        "school": "Jackson Co Sch of Alternatives",
        "district": "Jackson County Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370234002467",
    },
    {
        "school": "East McDowell Middle School",
        "district": "McDowell County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294001175",
    },
    {
        "school": "Eastfield Global Magnet School",
        "district": "McDowell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294001176",
    },
    {
        "school": "Glenwood Elementary School",
        "district": "McDowell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294001177",
    },
    {
        "school": "Marion Elementary School",
        "district": "McDowell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294001178",
    },
    {
        "school": "McDowell High School",
        "district": "McDowell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294001179",
    },
    {
        "school": "Nebo Elementary School",
        "district": "McDowell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294001180",
    },
    {
        "school": "North Cove Elementary School",
        "district": "McDowell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294001181",
    },
    {
        "school": "Old Fort Elementary School",
        "district": "McDowell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294001182",
    },
    {
        "school": "Pleasant Gardens Elementary School",
        "district": "McDowell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294001183",
    },
    {
        "school": "West Marion Elementary School",
        "district": "McDowell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294001184",
    },
    {
        "school": "West McDowell Middle School",
        "district": "McDowell County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294001185",
    },
    {
        "school": "Cartoogechaye Elementary",
        "district": "Macon County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370276001134",
    },
    {
        "school": "East Franklin Elementary",
        "district": "Macon County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370276001137",
    },
    {
        "school": "Franklin High",
        "district": "Macon County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370276001138",
    },
    {
        "school": "Highlands School",
        "district": "Macon County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370276001139",
    },
    {
        "school": "Iotla Valley Elementary",
        "district": "Macon County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370276001140",
    },
    {
        "school": "Macon Middle School",
        "district": "Macon County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370276001141",
    },
    {
        "school": "Nantahala School",
        "district": "Macon County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370276001142",
    },
    {
        "school": "South Macon Elementary",
        "district": "Macon County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370276002589",
    },
    {
        "school": "Jamesville Elementary",
        "district": "Martin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370288000812",
    },
    {
        "school": "E J Hayes Elementary",
        "district": "Martin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370288001159",
    },
    {
        "school": "South Creek Elementary",
        "district": "Martin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370288001160",
    },
    {
        "school": "South Creek Middle/High",
        "district": "Martin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370288001165",
    },
    {
        "school": "Rodgers Elementary",
        "district": "Martin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370288001167",
    },
    {
        "school": "Riverside High",
        "district": "Martin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370288001169",
    },
    {
        "school": "Riverside Middle",
        "district": "Martin County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370288001170",
    },
    {
        "school": "Williamston Primary",
        "district": "Martin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370288001171",
    },
    {
        "school": "Bowman Middle",
        "district": "Mitchell County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370300001292",
    },
    {
        "school": "Deyton Elementary",
        "district": "Mitchell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370300001294",
    },
    {
        "school": "Gouge Elementary",
        "district": "Mitchell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370300001295",
    },
    {
        "school": "Harris Middle",
        "district": "Mitchell County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370300001296",
    },
    {
        "school": "Mitchell High",
        "district": "Mitchell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370300001297",
    },
    {
        "school": "Greenlee Primary",
        "district": "Mitchell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370300002531",
    },
    {
        "school": "Candor Elementary",
        "district": "Montgomery County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306001306",
    },
    {
        "school": "East Montgomery High",
        "district": "Montgomery County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306001307",
    },
    {
        "school": "Mount Gilead Elementary",
        "district": "Montgomery County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306001310",
    },
    {
        "school": "Troy Elementary",
        "district": "Montgomery County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306001312",
    },
    {
        "school": "West Montgomery High",
        "district": "Montgomery County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306001313",
    },
    {
        "school": "Star Elementary",
        "district": "Montgomery County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306002099",
    },
    {
        "school": "East Middle",
        "district": "Montgomery County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306002267",
    },
    {
        "school": "West Middle",
        "district": "Montgomery County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306002268",
    },
    {
        "school": "Montgomery Learning Academy",
        "district": "Montgomery County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370306002328",
    },
    {
        "school": "Page Street Elementary",
        "district": "Montgomery County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306002532",
    },
    {
        "school": "Polk Central Elementary School",
        "district": "Polk County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370372000780",
    },
    {
        "school": "Polk County High School",
        "district": "Polk County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370372000785",
    },
    {
        "school": "Saluda Elementary School",
        "district": "Polk County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370372001511",
    },
    {
        "school": "Sunny View Elementary School",
        "district": "Polk County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370372001513",
    },
    {
        "school": "Tryon Elementary School",
        "district": "Polk County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370372002230",
    },
    {
        "school": "Butler Avenue Elementary",
        "district": "Clinton City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370093000352",
    },
    {
        "school": "Clinton High",
        "district": "Clinton City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370093000353",
    },
    {
        "school": "Langdon C Kerr Elementary",
        "district": "Clinton City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370093000355",
    },
    {
        "school": "Sampson Middle",
        "district": "Clinton City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370093000356",
    },
    {
        "school": "Union Middle",
        "district": "Sampson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414000790",
    },
    {
        "school": "Hobbton Middle",
        "district": "Sampson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414000939",
    },
    {
        "school": "Roseboro Elementary",
        "district": "Sampson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001665",
    },
    {
        "school": "Clement Elementary",
        "district": "Sampson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001667",
    },
    {
        "school": "Hargrove Elementary",
        "district": "Sampson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001671",
    },
    {
        "school": "Hobbton High",
        "district": "Sampson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001672",
    },
    {
        "school": "Hobbton Elementary",
        "district": "Sampson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001673",
    },
    {
        "school": "Lakewood High",
        "district": "Sampson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001674",
    },
    {
        "school": "Midway Elementary",
        "district": "Sampson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001675",
    },
    {
        "school": "Plain View Elementary",
        "district": "Sampson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001678",
    },
    {
        "school": "Roseboro-Salemburg Middle",
        "district": "Sampson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001679",
    },
    {
        "school": "Salemburg Elementary",
        "district": "Sampson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001680",
    },
    {
        "school": "Union Elementary",
        "district": "Sampson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001682",
    },
    {
        "school": "Union High",
        "district": "Sampson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414001683",
    },
    {
        "school": "Midway Middle",
        "district": "Sampson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414002481",
    },
    {
        "school": "Swain County High School",
        "district": "Swain County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370444001763",
    },
    {
        "school": "Cherokee Extension School",
        "district": "Swain County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370444002186",
    },
    {
        "school": "Swain County Middle School",
        "district": "Swain County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370444002314",
    },
    {
        "school": "Swain County East Elementary",
        "district": "Swain County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370444002315",
    },
    {
        "school": "Swain County West Elementary",
        "district": "Swain County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370444002316",
    },
    {
        "school": "Columbia High",
        "district": "Tyrrell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370459001788",
    },
    {
        "school": "Tyrrell Elementary",
        "district": "Tyrrell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370459001789",
    },
    {
        "school": "Haliwa-Saponi Tribal School",
        "district": "Haliwa-Saponi Tribal School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370011502562",
    },
    {
        "school": "Warren County Middle",
        "district": "Warren County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370474000329",
    },
    {
        "school": "Mariam Boyd Elementary",
        "district": "Warren County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370474001916",
    },
    {
        "school": "Northside K-8",
        "district": "Warren County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370474001919",
    },
    {
        "school": "Vaughan Elementary",
        "district": "Warren County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370474001921",
    },
    {
        "school": "Warren County High",
        "district": "Warren County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370474002189",
    },
    {
        "school": "Washington County High",
        "district": "Washington County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370480001930",
    },
    {
        "school": "Washington County Middle",
        "district": "Washington County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370480001933",
    },
    {
        "school": "Creswell Elementary",
        "district": "Washington County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370480002045",
    },
    {
        "school": "Pines Elementary",
        "district": "Washington County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370480002190",
    },
    {
        "school": "Burnsville Elementary",
        "district": "Yancey County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370507002025",
    },
    {
        "school": "Cane River Middle",
        "district": "Yancey County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370507002026",
    },
    {
        "school": "East Yancey Middle",
        "district": "Yancey County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370507002028",
    },
    {
        "school": "Micaville Elementary",
        "district": "Yancey County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370507002029",
    },
    {
        "school": "Mountain Heritage High",
        "district": "Yancey County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370507002030",
    },
    {
        "school": "South Toe Elementary",
        "district": "Yancey County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370507002032",
    },
    {
        "school": "Butner-Stem Elementary",
        "district": "Granville County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180000737",
    },
    {
        "school": "C. G. Credle Elementary",
        "district": "Granville County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180000738",
    },
    {
        "school": "Creedmoor Elementary",
        "district": "Granville County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180000739",
    },
    {
        "school": "G. C. Hawley Middle",
        "district": "Granville County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180000741",
    },
    {
        "school": "J. F. Webb High",
        "district": "Granville County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180000742",
    },
    {
        "school": "Stovall-Shaw Elementary",
        "district": "Granville County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180000745",
    },
    {
        "school": "West Oxford Elementary",
        "district": "Granville County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180000747",
    },
    {
        "school": "Wilton Elementary",
        "district": "Granville County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180000748",
    },
    {
        "school": "Northern Granville Middle",
        "district": "Granville County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180002264",
    },
    {
        "school": "Butner-Stem Middle",
        "district": "Granville County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180002385",
    },
    {
        "school": "Mount Energy Elementary",
        "district": "Granville County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180002581",
    },
    {
        "school": "Gray Stone Day",
        "district": "Gray Stone Day School",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370012802613",
    },
    {
        "school": "West Stanly Middle School",
        "district": "Stanly County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432002649",
    },
    {
        "school": "Albemarle High",
        "district": "Stanly County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432000022",
    },
    {
        "school": "Albemarle Middle",
        "district": "Stanly County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432000023",
    },
    {
        "school": "Central Elementary",
        "district": "Stanly County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432000024",
    },
    {
        "school": "East Albemarle Elementary",
        "district": "Stanly County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432000025",
    },
    {
        "school": "Aquadale Elementary",
        "district": "Stanly County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001707",
    },
    {
        "school": "Badin Elementary",
        "district": "Stanly County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001708",
    },
    {
        "school": "Endy Elementary",
        "district": "Stanly County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001709",
    },
    {
        "school": "Locust Elementary",
        "district": "Stanly County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001710",
    },
    {
        "school": "Millingport Elementary",
        "district": "Stanly County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001711",
    },
    {
        "school": "North Stanly Middle",
        "district": "Stanly County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001712",
    },
    {
        "school": "North Stanly High",
        "district": "Stanly County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001713",
    },
    {
        "school": "Norwood Elementary",
        "district": "Stanly County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001714",
    },
    {
        "school": "Richfield Elementary",
        "district": "Stanly County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001716",
    },
    {
        "school": "South Stanly High",
        "district": "Stanly County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001718",
    },
    {
        "school": "Stanfield Elementary",
        "district": "Stanly County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001719",
    },
    {
        "school": "West Stanly High",
        "district": "Stanly County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432001720",
    },
    {
        "school": "South Stanly Middle",
        "district": "Stanly County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432002547",
    },
    {
        "school": "School of Inquiry and Life Sciences",
        "district": "Asheville City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370027002749",
    },
    {
        "school": "North Windy Ridge Intermediate",
        "district": "Buncombe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045002622",
    },
    {
        "school": "Early College",
        "district": "Buncombe County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045002661",
    },
    {
        "school": "Clear Creek Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210002631",
    },
    {
        "school": "Sugarloaf Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210002996",
    },
    {
        "school": "Bethel Elementary",
        "district": "Haywood County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204000579",
    },
    {
        "school": "Bethel Middle",
        "district": "Haywood County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204000580",
    },
    {
        "school": "Canton Middle",
        "district": "Haywood County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204000897",
    },
    {
        "school": "Clyde Elementary",
        "district": "Haywood County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204000899",
    },
    {
        "school": "Riverbend Elementary",
        "district": "Haywood County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204000900",
    },
    {
        "school": "Hazelwood Elementary",
        "district": "Haywood County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204000902",
    },
    {
        "school": "Junaluska Elementary",
        "district": "Haywood County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204000903",
    },
    {
        "school": "North Canton Elementary",
        "district": "Haywood County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204000906",
    },
    {
        "school": "Pisgah High",
        "district": "Haywood County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204000908",
    },
    {
        "school": "Tuscola High",
        "district": "Haywood County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204000910",
    },
    {
        "school": "Waynesville Middle",
        "district": "Haywood County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204000911",
    },
    {
        "school": "Central Haywood High",
        "district": "Haywood County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370204001147",
    },
    {
        "school": "Jonathan Valley Elementary",
        "district": "Haywood County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204002159",
    },
    {
        "school": "Meadowbrook Elementary",
        "district": "Haywood County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370204002160",
    },
    {
        "school": "The Mountain Community Sch",
        "district": "The Mountain Community Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370008502458",
    },
    {
        "school": "Apple Valley Middle",
        "district": "Henderson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000797",
    },
    {
        "school": "North Henderson High",
        "district": "Henderson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000804",
    },
    {
        "school": "Upward Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000805",
    },
    {
        "school": "Dana Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000913",
    },
    {
        "school": "East Henderson High",
        "district": "Henderson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000915",
    },
    {
        "school": "Edneyville Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000917",
    },
    {
        "school": "Etowah Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000918",
    },
    {
        "school": "Flat Rock Middle",
        "district": "Henderson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000919",
    },
    {
        "school": "Fletcher Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000920",
    },
    {
        "school": "Hillandale Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000921",
    },
    {
        "school": "Mills River Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000922",
    },
    {
        "school": "Rugby Middle",
        "district": "Henderson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000923",
    },
    {
        "school": "West Henderson High",
        "district": "Henderson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000926",
    },
    {
        "school": "Bruce Drysdale Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000927",
    },
    {
        "school": "Hendersonville High",
        "district": "Henderson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000928",
    },
    {
        "school": "Hendersonville Middle",
        "district": "Henderson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000929",
    },
    {
        "school": "Hendersonville Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210000930",
    },
    {
        "school": "Henderson County Career Academy",
        "district": "Henderson County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370210001568",
    },
    {
        "school": "Atkinson Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210002094",
    },
    {
        "school": "Glenn C Marlow Elementary",
        "district": "Henderson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210002457",
    },
    {
        "school": "Francine Delany New School",
        "district": "Francine Delany New School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001702069",
    },
    {
        "school": "Evergreen Community Charter",
        "district": "Evergreen Community Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370007802430",
    },
    {
        "school": "ArtSpace Charter School",
        "district": "ArtSpace Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370011702569",
    },
    {
        "school": "Asheville High",
        "district": "Asheville City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370027000070",
    },
    {
        "school": "Hall Fletcher Elementary",
        "district": "Asheville City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370027000071",
    },
    {
        "school": "Claxton Elementary",
        "district": "Asheville City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370027000072",
    },
    {
        "school": "Ira B Jones Elementary",
        "district": "Asheville City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370027000076",
    },
    {
        "school": "Asheville Middle",
        "district": "Asheville City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370027000079",
    },
    {
        "school": "Vance Elementary",
        "district": "Asheville City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370027000080",
    },
    {
        "school": "Isaac Dickson Elementary",
        "district": "Asheville City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370027002202",
    },
    {
        "school": "Reynolds High",
        "district": "Buncombe County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000133",
    },
    {
        "school": "Reynolds Middle",
        "district": "Buncombe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000134",
    },
    {
        "school": "Black Mountain Primary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000138",
    },
    {
        "school": "Bell Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000139",
    },
    {
        "school": "Candler Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000140",
    },
    {
        "school": "Owen High",
        "district": "Buncombe County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000142",
    },
    {
        "school": "Erwin High",
        "district": "Buncombe County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000143",
    },
    {
        "school": "Erwin Middle",
        "district": "Buncombe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000144",
    },
    {
        "school": "Emma Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000146",
    },
    {
        "school": "Enka High",
        "district": "Buncombe County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000147",
    },
    {
        "school": "Fairview Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000148",
    },
    {
        "school": "Glen Arden Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000151",
    },
    {
        "school": "Haw Creek Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000152",
    },
    {
        "school": "Johnston Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000153",
    },
    {
        "school": "Leicester Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000154",
    },
    {
        "school": "North Buncombe High",
        "district": "Buncombe County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000156",
    },
    {
        "school": "Oakley Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000157",
    },
    {
        "school": "Pisgah Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000159",
    },
    {
        "school": "Enka Middle",
        "district": "Buncombe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000161",
    },
    {
        "school": "Williams Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000163",
    },
    {
        "school": "Roberson High",
        "district": "Buncombe County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000164",
    },
    {
        "school": "Valley Springs Middle",
        "district": "Buncombe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000165",
    },
    {
        "school": "Weaverville Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000167",
    },
    {
        "school": "Weaverville Primary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000168",
    },
    {
        "school": "West Buncombe Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000169",
    },
    {
        "school": "Woodfin Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000170",
    },
    {
        "school": "Sand Hill-Venable Elem",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045000626",
    },
    {
        "school": "Barnardsville Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045001003",
    },
    {
        "school": "Black Mountain Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045001361",
    },
    {
        "school": "Avery's Creek Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045001781",
    },
    {
        "school": "Estes Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045002063",
    },
    {
        "school": "North Buncombe Middle",
        "district": "Buncombe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045002192",
    },
    {
        "school": "Community High School",
        "district": "Buncombe County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370045002203",
    },
    {
        "school": "North Buncombe Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045002259",
    },
    {
        "school": "Owen Middle",
        "district": "Buncombe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045002286",
    },
    {
        "school": "Cane Creek Middle",
        "district": "Buncombe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045002507",
    },
    {
        "school": "Hominy Valley Elementary",
        "district": "Buncombe County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045002508",
    },
    {
        "school": "Madison Middle School",
        "district": "Madison County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370282000599",
    },
    {
        "school": "Hot Springs Elementary",
        "district": "Madison County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370282001151",
    },
    {
        "school": "Madison High School",
        "district": "Madison County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370282001153",
    },
    {
        "school": "Mars Hill Elementary",
        "district": "Madison County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370282001154",
    },
    {
        "school": "Brush Creek Elementary",
        "district": "Madison County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370282002590",
    },
    {
        "school": "Two Rivers Community School",
        "district": "Two Rivers Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370013802808",
    },
    {
        "school": "Bethel Elementary",
        "district": "Watauga County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370483001934",
    },
    {
        "school": "Blowing Rock Elementary",
        "district": "Watauga County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370483001935",
    },
    {
        "school": "Cove Creek Elementary",
        "district": "Watauga County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370483001936",
    },
    {
        "school": "Green Valley Elementary",
        "district": "Watauga County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370483001937",
    },
    {
        "school": "Hardin Park Elementary",
        "district": "Watauga County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370483001938",
    },
    {
        "school": "Mabel Elementary",
        "district": "Watauga County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370483001939",
    },
    {
        "school": "Parkway Elementary",
        "district": "Watauga County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370483001940",
    },
    {
        "school": "Valle Crucis Elementary",
        "district": "Watauga County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370483001941",
    },
    {
        "school": "Watauga High",
        "district": "Watauga County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370483001943",
    },
    {
        "school": "Brevard Academy",
        "district": "Brevard Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370006802412",
    },
    {
        "school": "Pisgah Forest Elementary",
        "district": "Transylvania County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370453000796",
    },
    {
        "school": "Brevard Elementary",
        "district": "Transylvania County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370453001777",
    },
    {
        "school": "Brevard High",
        "district": "Transylvania County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370453001778",
    },
    {
        "school": "Brevard Middle",
        "district": "Transylvania County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370453001779",
    },
    {
        "school": "Rosman Elementary",
        "district": "Transylvania County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370453001782",
    },
    {
        "school": "Rosman High",
        "district": "Transylvania County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370453001783",
    },
    {
        "school": "T C Henderson",
        "district": "Transylvania County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370453001785",
    },
    {
        "school": "Davidson River School",
        "district": "Transylvania County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370453002351",
    },
    {
        "school": "Rosman Middle",
        "district": "Transylvania County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370453002550",
    },
    {
        "school": "Highland Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003002838",
    },
    {
        "school": "The Hawbridge School",
        "district": "The Hawbridge School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370013202703",
    },
    {
        "school": "Alexander Wilson Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000001",
    },
    {
        "school": "Altamahaw-Ossipee Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000002",
    },
    {
        "school": "B. Everett Jordan Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000003",
    },
    {
        "school": "E M Yoder Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000005",
    },
    {
        "school": "Eastern Alamance High",
        "district": "Alamance-Burlington Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000006",
    },
    {
        "school": "Edwin M Holt Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000007",
    },
    {
        "school": "Elon Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000008",
    },
    {
        "school": "Graham High",
        "district": "Alamance-Burlington Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000009",
    },
    {
        "school": "Graham Middle",
        "district": "Alamance-Burlington Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000010",
    },
    {
        "school": "Haw River Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000011",
    },
    {
        "school": "North Graham Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000012",
    },
    {
        "school": "Pleasant Grove Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000013",
    },
    {
        "school": "South Graham Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000014",
    },
    {
        "school": "South Mebane Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000015",
    },
    {
        "school": "Southern Alamance High",
        "district": "Alamance-Burlington Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000016",
    },
    {
        "school": "Southern Alamance Middle",
        "district": "Alamance-Burlington Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000017",
    },
    {
        "school": "Sylvan Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000018",
    },
    {
        "school": "Western Alamance High",
        "district": "Alamance-Burlington Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000019",
    },
    {
        "school": "Western Alamance Middle",
        "district": "Alamance-Burlington Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000020",
    },
    {
        "school": "Woodlawn Middle",
        "district": "Alamance-Burlington Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000021",
    },
    {
        "school": "Broadview Middle",
        "district": "Alamance-Burlington Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000196",
    },
    {
        "school": "Eastlawn Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000197",
    },
    {
        "school": "Grove Park Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000199",
    },
    {
        "school": "Harvey R Newlin Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000200",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000201",
    },
    {
        "school": "Hugh M Cummings High",
        "district": "Alamance-Burlington Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000202",
    },
    {
        "school": "Marvin B Smith Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000203",
    },
    {
        "school": "R Homer Andrews Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000204",
    },
    {
        "school": "Turrentine Middle",
        "district": "Alamance-Burlington Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000206",
    },
    {
        "school": "Walter M Williams High",
        "district": "Alamance-Burlington Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003000207",
    },
    {
        "school": "Ray Street Academy",
        "district": "Alamance-Burlington Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370003002153",
    },
    {
        "school": "Audrey W. Garrett Elementary",
        "district": "Alamance-Burlington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003002501",
    },
    {
        "school": "Hawfields Middle",
        "district": "Alamance-Burlington Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003002566",
    },
    {
        "school": "River Mill Academy",
        "district": "River Mill Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370005002366",
    },
    {
        "school": "Clover Garden",
        "district": "Clover Garden",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370011602565",
    },
    {
        "school": "Charles E Boger Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002820",
    },
    {
        "school": "Hickory Ridge High",
        "district": "Cabarrus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002833",
    },
    {
        "school": "Mallard Creek High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002811",
    },
    {
        "school": "Anson Co. Early College High",
        "district": "Anson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370018002748",
    },
    {
        "school": "Carolina International School",
        "district": "Carolina International School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370013302706",
    },
    {
        "school": "C C Griffin Middle",
        "district": "Cabarrus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002623",
    },
    {
        "school": "Cox Mill Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002624",
    },
    {
        "school": "Harris Road Middle",
        "district": "Cabarrus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002625",
    },
    {
        "school": "Pitts School Road Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002750",
    },
    {
        "school": "Carl A Furr Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002839",
    },
    {
        "school": "W B Beam Intermediate School",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162002730",
    },
    {
        "school": "Edward D Sadler Jr  Elementary School",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162002731",
    },
    {
        "school": "Queen's Grant Community School",
        "district": "Queen's Grant Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370012702612",
    },
    {
        "school": "Community School of Davidson",
        "district": "Community School of Davidson",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370013502736",
    },
    {
        "school": "Socrates Academy",
        "district": "Socrates Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370013702786",
    },
    {
        "school": "KIPP Charlotte",
        "district": "KIPP: Charlotte",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370014202922",
    },
    {
        "school": "Charlotte Secondary",
        "district": "Charlotte Secondary School",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370014302924",
    },
    {
        "school": "Highland Mill Montessori",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002638",
    },
    {
        "school": "Jay M Robinson Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002639",
    },
    {
        "school": "Mountain Island Lake Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002640",
    },
    {
        "school": "Phillip O Berry Academy of Technology",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002641",
    },
    {
        "school": "Providence Spring Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002642",
    },
    {
        "school": "Walter G Byers School",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002660",
    },
    {
        "school": "Endhaven Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002675",
    },
    {
        "school": "Joseph W Grier Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002676",
    },
    {
        "school": "Mint Hill Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002677",
    },
    {
        "school": "Southwest Middle School",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002678",
    },
    {
        "school": "Oaklawn Language Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002737",
    },
    {
        "school": "Chantilly Montessori",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002782",
    },
    {
        "school": "Community House Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002783",
    },
    {
        "school": "Martin Luther King Jr Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002784",
    },
    {
        "school": "Torrence Creek Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002785",
    },
    {
        "school": "Elon Park Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002826",
    },
    {
        "school": "Antioch Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002740",
    },
    {
        "school": "Marvin Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002651",
    },
    {
        "school": "Porter Ridge Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002741",
    },
    {
        "school": "Kensington Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002798",
    },
    {
        "school": "Porter Ridge High School",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002799",
    },
    {
        "school": "Porter Ridge Middle School",
        "district": "Union County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002800",
    },
    {
        "school": "Sandy Ridge Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002801",
    },
    {
        "school": "Rea View Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002814",
    },
    {
        "school": "New Town Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002821",
    },
    {
        "school": "Rocky River Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002828",
    },
    {
        "school": "Ansonville Elementary",
        "district": "Anson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370018000042",
    },
    {
        "school": "Wadesboro Primary",
        "district": "Anson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370018000044",
    },
    {
        "school": "Morven Elementary",
        "district": "Anson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370018000046",
    },
    {
        "school": "Lilesville Elementary",
        "district": "Anson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370018000049",
    },
    {
        "school": "Wadesboro Elementary",
        "district": "Anson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370018000050",
    },
    {
        "school": "Peachland-Polkton Elem",
        "district": "Anson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370018000953",
    },
    {
        "school": "Anson High School",
        "district": "Anson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370018002054",
    },
    {
        "school": "Anson Middle",
        "district": "Anson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370018002056",
    },
    {
        "school": "Anson Academy",
        "district": "Anson County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370018002367",
    },
    {
        "school": "A T Allen Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000208",
    },
    {
        "school": "Bethel Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000209",
    },
    {
        "school": "Central Cabarrus High",
        "district": "Cabarrus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000210",
    },
    {
        "school": "Harrisburg Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000211",
    },
    {
        "school": "Mount Pleasant Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000214",
    },
    {
        "school": "Mount Pleasant High",
        "district": "Cabarrus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000215",
    },
    {
        "school": "Northwest Cabarrus High",
        "district": "Cabarrus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000216",
    },
    {
        "school": "Royal Oaks Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000217",
    },
    {
        "school": "W R Odell Primary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000218",
    },
    {
        "school": "Winecoff Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000219",
    },
    {
        "school": "Wolf Meadow Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000220",
    },
    {
        "school": "Beverly Hills Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000375",
    },
    {
        "school": "Coltrane-Webb Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000376",
    },
    {
        "school": "Concord Middle",
        "district": "Cabarrus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000377",
    },
    {
        "school": "Concord High",
        "district": "Cabarrus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000378",
    },
    {
        "school": "R Brown  McAllister Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053000379",
    },
    {
        "school": "Weddington Hills Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053001818",
    },
    {
        "school": "Northwest Cabarrus Middle",
        "district": "Cabarrus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002064",
    },
    {
        "school": "Cabarrus Co Opportunity School",
        "district": "Cabarrus County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370053002075",
    },
    {
        "school": "Rocky River Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002076",
    },
    {
        "school": "Mount Pleasant Middle",
        "district": "Cabarrus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002154",
    },
    {
        "school": "J N Fries Magnet School",
        "district": "Cabarrus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002260",
    },
    {
        "school": "W M Irvin Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002434",
    },
    {
        "school": "Jay M Robinson High",
        "district": "Cabarrus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053002570",
    },
    {
        "school": "A L Brown High",
        "district": "Kannapolis City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370243001039",
    },
    {
        "school": "Forest Park Elementary",
        "district": "Kannapolis City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370243001040",
    },
    {
        "school": "Fred L Wilson Elementary",
        "district": "Kannapolis City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370243001041",
    },
    {
        "school": "Shady Brook Elementary",
        "district": "Kannapolis City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370243001046",
    },
    {
        "school": "Kannapolis Middle",
        "district": "Kannapolis City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370243002161",
    },
    {
        "school": "Piedmont Community Charter School",
        "district": "Piedmont Community Charter",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370010402520",
    },
    {
        "school": "Ashbrook High",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000663",
    },
    {
        "school": "Belmont Central Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000665",
    },
    {
        "school": "Belmont Middle",
        "district": "Gaston County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000666",
    },
    {
        "school": "Bessemer City Central Elem",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000667",
    },
    {
        "school": "Bessemer City High",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000668",
    },
    {
        "school": "Bessemer City Primary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000669",
    },
    {
        "school": "Carr Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000670",
    },
    {
        "school": "Catawba Heights Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000671",
    },
    {
        "school": "Chapel Grove Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000672",
    },
    {
        "school": "Cherryville Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000673",
    },
    {
        "school": "Cherryville High",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000675",
    },
    {
        "school": "Costner Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000678",
    },
    {
        "school": "Cramerton Middle",
        "district": "Gaston County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000679",
    },
    {
        "school": "East Gaston High",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000681",
    },
    {
        "school": "Gardner Park Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000683",
    },
    {
        "school": "Webb Street School",
        "district": "Gaston County Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370162000684",
    },
    {
        "school": "Springfield Primary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000685",
    },
    {
        "school": "W P Grier Middle School",
        "district": "Gaston County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000687",
    },
    {
        "school": "Holbrook Middle",
        "district": "Gaston County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000690",
    },
    {
        "school": "Hunter Huss High",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000691",
    },
    {
        "school": "J B Page Primary School",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000692",
    },
    {
        "school": "Kiser Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000693",
    },
    {
        "school": "Bessemer City Middle",
        "district": "Gaston County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000694",
    },
    {
        "school": "Lingerfeldt Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000695",
    },
    {
        "school": "Lowell Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000696",
    },
    {
        "school": "McAdenville Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000697",
    },
    {
        "school": "Mount Holly Middle",
        "district": "Gaston County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000698",
    },
    {
        "school": "New Hope Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000700",
    },
    {
        "school": "North Belmont Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000701",
    },
    {
        "school": "North Gaston High",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000702",
    },
    {
        "school": "Pinewood Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000704",
    },
    {
        "school": "Pleasant Ridge Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000705",
    },
    {
        "school": "Ida Rankin Elementary School",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000706",
    },
    {
        "school": "Robinson Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000708",
    },
    {
        "school": "Sherwood Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000709",
    },
    {
        "school": "H H Beam Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000710",
    },
    {
        "school": "South Point High",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000711",
    },
    {
        "school": "Southwest Middle",
        "district": "Gaston County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000712",
    },
    {
        "school": "Stanley Middle",
        "district": "Gaston County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000713",
    },
    {
        "school": "Tryon Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000714",
    },
    {
        "school": "W C Friday Middle School",
        "district": "Gaston County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000716",
    },
    {
        "school": "Woodhill Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162000717",
    },
    {
        "school": "Brookside Elementary",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162001107",
    },
    {
        "school": "John Chavis Middle School",
        "district": "Gaston County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162002113",
    },
    {
        "school": "W A Bess Elementary School",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162002156",
    },
    {
        "school": "York Chester Middle",
        "district": "Gaston County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162002195",
    },
    {
        "school": "Warlick Academy",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370162002263",
    },
    {
        "school": "Forestview High",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162002384",
    },
    {
        "school": "Highland Sch of Technology",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162002521",
    },
    {
        "school": "Lake Norman Charter",
        "district": "Lake Norman Charter",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370006402399",
    },
    {
        "school": "Sugar Creek Charter",
        "district": "Sugar Creek Charter",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370008902472",
    },
    {
        "school": "Metrolina Reg Scholars Academy",
        "district": "Metrolina Regional Scholars Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370010702530",
    },
    {
        "school": "Lake Wylie Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297000614",
    },
    {
        "school": "South Charlotte Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297000632",
    },
    {
        "school": "University Meadows Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297000652",
    },
    {
        "school": "Irwin Academic Center",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297000682",
    },
    {
        "school": "Crown Point Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297000813",
    },
    {
        "school": "David Cox Road Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297000868",
    },
    {
        "school": "Turning Point Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370297000871",
    },
    {
        "school": "Smithfield Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297000889",
    },
    {
        "school": "Albemarle Road Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001186",
    },
    {
        "school": "Albemarle Road Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001187",
    },
    {
        "school": "Alexander Graham Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001188",
    },
    {
        "school": "J M Alexander Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001189",
    },
    {
        "school": "Allenbrook Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001190",
    },
    {
        "school": "Ashley Park PreK-8 School",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001192",
    },
    {
        "school": "Bain Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001193",
    },
    {
        "school": "Barringer Academic Center",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001194",
    },
    {
        "school": "Berryhill School",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001195",
    },
    {
        "school": "Beverly Woods Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001196",
    },
    {
        "school": "Briarwood Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001198",
    },
    {
        "school": "Carmel Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001200",
    },
    {
        "school": "Billingsville Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001201",
    },
    {
        "school": "Clear Creek Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001202",
    },
    {
        "school": "Cochrane Collegiate Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001203",
    },
    {
        "school": "Collinswood Language Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001204",
    },
    {
        "school": "Cornelius Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001205",
    },
    {
        "school": "Cotswold IB Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001206",
    },
    {
        "school": "Coulwood STEM Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001207",
    },
    {
        "school": "Davidson Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001208",
    },
    {
        "school": "Devonshire Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001210",
    },
    {
        "school": "First Ward Creative Arts Acad",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001211",
    },
    {
        "school": "Reid Park Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001212",
    },
    {
        "school": "Druid Hills Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001213",
    },
    {
        "school": "East Mecklenburg High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001214",
    },
    {
        "school": "Eastover Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001215",
    },
    {
        "school": "Eastway Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001216",
    },
    {
        "school": "Elizabeth Traditional Elem",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001217",
    },
    {
        "school": "Harding University High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001221",
    },
    {
        "school": "Hickory Grove Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001223",
    },
    {
        "school": "Hidden Valley Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001224",
    },
    {
        "school": "Highland Renaissance Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001225",
    },
    {
        "school": "Huntersville Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001226",
    },
    {
        "school": "Huntingtowne Farms Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001227",
    },
    {
        "school": "Idlewild Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001228",
    },
    {
        "school": "Independence High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001229",
    },
    {
        "school": "J H Gunn Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001231",
    },
    {
        "school": "Kennedy Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001232",
    },
    {
        "school": "Lansdowne Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001234",
    },
    {
        "school": "Long Creek Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001236",
    },
    {
        "school": "Matthews Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001238",
    },
    {
        "school": "McClintock Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001239",
    },
    {
        "school": "Metro School",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370297001241",
    },
    {
        "school": "Montclaire Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001243",
    },
    {
        "school": "Myers Park High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001244",
    },
    {
        "school": "Myers Park Traditional",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001245",
    },
    {
        "school": "Nations Ford Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001246",
    },
    {
        "school": "Newell Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001247",
    },
    {
        "school": "North Mecklenburg High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001248",
    },
    {
        "school": "Northeast Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001249",
    },
    {
        "school": "Northwest School of the Arts",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001250",
    },
    {
        "school": "Oakdale Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001251",
    },
    {
        "school": "Bruns Avenue Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001253",
    },
    {
        "school": "Olde Providence Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001254",
    },
    {
        "school": "Olympic High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001255",
    },
    {
        "school": "Park Road Montessori",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001256",
    },
    {
        "school": "Paw Creek Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001257",
    },
    {
        "school": "Piedmont IB Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001259",
    },
    {
        "school": "Pineville Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001260",
    },
    {
        "school": "Pinewood Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001261",
    },
    {
        "school": "Piney Grove Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001262",
    },
    {
        "school": "Quail Hollow Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001264",
    },
    {
        "school": "Rama Road Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001265",
    },
    {
        "school": "Randolph Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001266",
    },
    {
        "school": "Ranson Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001267",
    },
    {
        "school": "Dilworth Elementary School: Sedgefield C",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001268",
    },
    {
        "school": "Sedgefield Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001269",
    },
    {
        "school": "Selwyn Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001270",
    },
    {
        "school": "Shamrock Gardens Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001271",
    },
    {
        "school": "Sharon Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001272",
    },
    {
        "school": "Waddell Language Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001273",
    },
    {
        "school": "South Mecklenburg High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001274",
    },
    {
        "school": "Statesville Road Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001277",
    },
    {
        "school": "Steele Creek Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001278",
    },
    {
        "school": "Sterling Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001279",
    },
    {
        "school": "Thomasboro Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001280",
    },
    {
        "school": "Tuckaseegee Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001282",
    },
    {
        "school": "West Charlotte High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001285",
    },
    {
        "school": "West Mecklenburg High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001286",
    },
    {
        "school": "Westerly Hills Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001287",
    },
    {
        "school": "Windsor Park Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001290",
    },
    {
        "school": "Winterfield Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001291",
    },
    {
        "school": "Greenway Park Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001598",
    },
    {
        "school": "Winding Springs Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001601",
    },
    {
        "school": "Elizabeth Lane Elem",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001881",
    },
    {
        "school": "Governors Village STEM Academy (Lower)",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001886",
    },
    {
        "school": "Northridge Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001889",
    },
    {
        "school": "University Park Creative Arts",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297001893",
    },
    {
        "school": "McAlpine Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002166",
    },
    {
        "school": "Merry Oaks International Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002167",
    },
    {
        "school": "Charlotte-Mecklenburg  Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370297002169",
    },
    {
        "school": "Reedy Creek Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002170",
    },
    {
        "school": "Mallard Creek Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002198",
    },
    {
        "school": "McKee Road Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002219",
    },
    {
        "school": "Providence High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002220",
    },
    {
        "school": "Hawthorne Academy of Health Sciences",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002228",
    },
    {
        "school": "Lebanon Road Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002266",
    },
    {
        "school": "Hornets Nest Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002309",
    },
    {
        "school": "Butler High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002324",
    },
    {
        "school": "James Martin Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002325",
    },
    {
        "school": "Vance High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002326",
    },
    {
        "school": "Crestdale Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002394",
    },
    {
        "school": "Francis Bradley Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002395",
    },
    {
        "school": "Governors Village STEM Academy (Upper)",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002396",
    },
    {
        "school": "Blythe Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002397",
    },
    {
        "school": "Hawk Ridge Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002471",
    },
    {
        "school": "Hopewell High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297002593",
    },
    {
        "school": "Jackson Park Elementary",
        "district": "Kannapolis City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370243001045",
    },
    {
        "school": "Woodrow Wilson Elementary",
        "district": "Kannapolis City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370243001047",
    },
    {
        "school": "Union Academy",
        "district": "Union Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370011202551",
    },
    {
        "school": "South Providence",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370462001284",
    },
    {
        "school": "Benton Heights Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001299",
    },
    {
        "school": "East Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001300",
    },
    {
        "school": "Monroe High",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001301",
    },
    {
        "school": "Monroe Middle",
        "district": "Union County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001302",
    },
    {
        "school": "Walter Bickett Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001303",
    },
    {
        "school": "Wolfe School",
        "district": "Union County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370462001304",
    },
    {
        "school": "East Union Middle",
        "district": "Union County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001790",
    },
    {
        "school": "Fairview Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001791",
    },
    {
        "school": "Forest Hills High",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001792",
    },
    {
        "school": "Hemby Bridge Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001793",
    },
    {
        "school": "Indian Trail Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001794",
    },
    {
        "school": "Marshville Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001795",
    },
    {
        "school": "New Salem Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001796",
    },
    {
        "school": "Parkwood High",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001797",
    },
    {
        "school": "Parkwood Middle",
        "district": "Union County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001798",
    },
    {
        "school": "Piedmont High",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001799",
    },
    {
        "school": "Piedmont Middle",
        "district": "Union County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001800",
    },
    {
        "school": "Prospect Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001801",
    },
    {
        "school": "Shiloh Valley Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001802",
    },
    {
        "school": "Sun Valley High",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001803",
    },
    {
        "school": "Sun Valley Middle",
        "district": "Union County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001804",
    },
    {
        "school": "Union Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001805",
    },
    {
        "school": "Central Academy of Technology and Arts",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001806",
    },
    {
        "school": "Unionville Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001807",
    },
    {
        "school": "Waxhaw Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001808",
    },
    {
        "school": "Wesley Chapel Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001809",
    },
    {
        "school": "Western Union Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001810",
    },
    {
        "school": "Wingate Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462001811",
    },
    {
        "school": "Sardis Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002352",
    },
    {
        "school": "Weddington Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002353",
    },
    {
        "school": "Weddington Middle",
        "district": "Union County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002413",
    },
    {
        "school": "Weddington High",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462002552",
    },
    {
        "school": "Highland Elementary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201002630",
    },
    {
        "school": "Lillington-Shawtown Elementary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201002670",
    },
    {
        "school": "Overhills High",
        "district": "Harnett County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201002733",
    },
    {
        "school": "Overhills Elementary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201002995",
    },
    {
        "school": "Harnett Central Middle",
        "district": "Harnett County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000578",
    },
    {
        "school": "Anderson Creek Primary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000874",
    },
    {
        "school": "Angier Elementary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000875",
    },
    {
        "school": "Benhaven Elementary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000876",
    },
    {
        "school": "Boone Trail Elementary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000877",
    },
    {
        "school": "Buies Creek Elementary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000878",
    },
    {
        "school": "Coats Elementary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000879",
    },
    {
        "school": "Dunn Middle",
        "district": "Harnett County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000880",
    },
    {
        "school": "Erwin Elementary at Gentry",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000881",
    },
    {
        "school": "Harnett Primary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000883",
    },
    {
        "school": "Harnett Central High",
        "district": "Harnett County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000884",
    },
    {
        "school": "Johnsonville Elementary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000885",
    },
    {
        "school": "LaFayette Elementary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000886",
    },
    {
        "school": "North Harnett Primary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000890",
    },
    {
        "school": "South Harnett Elementary",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000892",
    },
    {
        "school": "Wayne Avenue Elem",
        "district": "Harnett County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000893",
    },
    {
        "school": "Western Harnett High",
        "district": "Harnett County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201000894",
    },
    {
        "school": "STAR Academy",
        "district": "Harnett County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370201002117",
    },
    {
        "school": "Triton High",
        "district": "Harnett County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201002158",
    },
    {
        "school": "Western Harnett Middle",
        "district": "Harnett County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201002296",
    },
    {
        "school": "Coats-Erwin Middle",
        "district": "Harnett County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201002456",
    },
    {
        "school": "Overhills Middle",
        "district": "Harnett County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201002525",
    },
    {
        "school": "Carrboro High",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072002823",
    },
    {
        "school": "Virginia Cross Elementary",
        "district": "Chatham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075002815",
    },
    {
        "school": "Central Park School For Child",
        "district": "Central Park School For Children",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370013002665",
    },
    {
        "school": "Voyager Academy",
        "district": "Voyager Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370013902921",
    },
    {
        "school": "J D Clement Early College HS",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126002726",
    },
    {
        "school": "Creekside Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126002727",
    },
    {
        "school": "Middle College HS @ DTCC",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126002761",
    },
    {
        "school": "Hillside New Tech High",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126002920",
    },
    {
        "school": "Rashkis Elementary",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072002679",
    },
    {
        "school": "Cedar Ridge High",
        "district": "Orange County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348002645",
    },
    {
        "school": "Partnership Academy",
        "district": "Orange County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370348002788",
    },
    {
        "school": "Bethel Hill Charter",
        "district": "Bethel Hill Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370010902538",
    },
    {
        "school": "Helena Elementary",
        "district": "Person County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370363001479",
    },
    {
        "school": "North Elementary",
        "district": "Person County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370363001480",
    },
    {
        "school": "North End Elementary",
        "district": "Person County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370363001481",
    },
    {
        "school": "Northern Middle",
        "district": "Person County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370363001482",
    },
    {
        "school": "Oak Lane Elementary",
        "district": "Person County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370363001483",
    },
    {
        "school": "Person High",
        "district": "Person County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370363001484",
    },
    {
        "school": "South Elementary",
        "district": "Person County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370363001485",
    },
    {
        "school": "Southern Middle",
        "district": "Person County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370363001486",
    },
    {
        "school": "Woodland Elementary",
        "district": "Person County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370363001487",
    },
    {
        "school": "Stories Creek Elementary",
        "district": "Person County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370363002539",
    },
    {
        "school": "Chatham Charter",
        "district": "Chatham Charter",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370002002081",
    },
    {
        "school": "Woods Charter",
        "district": "Woods Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370005302372",
    },
    {
        "school": "Bennett School",
        "district": "Chatham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000304",
    },
    {
        "school": "Bonlee School",
        "district": "Chatham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000305",
    },
    {
        "school": "Chatham Central High",
        "district": "Chatham County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000306",
    },
    {
        "school": "Chatham Middle",
        "district": "Chatham County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000307",
    },
    {
        "school": "Horton Middle",
        "district": "Chatham County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000309",
    },
    {
        "school": "J S Waters School",
        "district": "Chatham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000310",
    },
    {
        "school": "Jordan Matthews High",
        "district": "Chatham County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000311",
    },
    {
        "school": "Moncure School",
        "district": "Chatham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000312",
    },
    {
        "school": "Northwood High",
        "district": "Chatham County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000313",
    },
    {
        "school": "Pittsboro Elementary",
        "district": "Chatham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000314",
    },
    {
        "school": "Siler City Elementary",
        "district": "Chatham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000315",
    },
    {
        "school": "Silk Hope School",
        "district": "Chatham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075000316",
    },
    {
        "school": "SAGE Academy",
        "district": "Chatham County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370075002079",
    },
    {
        "school": "Perry W Harrison Elementary",
        "district": "Chatham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075002080",
    },
    {
        "school": "North Chatham Elementary",
        "district": "Chatham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075002288",
    },
    {
        "school": "Maureen Joy Charter School",
        "district": "Maureen Joy Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370002202089",
    },
    {
        "school": "Healthy Start Academy",
        "district": "Healthy Start Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370002302090",
    },
    {
        "school": "Carter Community Charter",
        "district": "Carter Community Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370005402375",
    },
    {
        "school": "Kestrel Heights School",
        "district": "Kestrel Heights School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370005502376",
    },
    {
        "school": "Research Triangle Charter",
        "district": "Research Triangle Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370008102444",
    },
    {
        "school": "Brogden Middle",
        "district": "Durham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000245",
    },
    {
        "school": "Burton Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000308",
    },
    {
        "school": "Club Boulevard Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000334",
    },
    {
        "school": "Hillside High",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000385",
    },
    {
        "school": "James E Shepard Middle",
        "district": "Durham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000441",
    },
    {
        "school": "Lakewood Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000472",
    },
    {
        "school": "Fayetteville Street Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000480",
    },
    {
        "school": "Bethesda Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000528",
    },
    {
        "school": "C E Jordan High",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000530",
    },
    {
        "school": "The School for Creative Studies",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000531",
    },
    {
        "school": "Eno Valley Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000532",
    },
    {
        "school": "George L Carrington Middle",
        "district": "Durham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000533",
    },
    {
        "school": "Glenn Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000534",
    },
    {
        "school": "Hillandale Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000535",
    },
    {
        "school": "Holt Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000536",
    },
    {
        "school": "Forest View Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000537",
    },
    {
        "school": "George Watts Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000538",
    },
    {
        "school": "Little River K-8 School",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000539",
    },
    {
        "school": "Lowe's Grove Middle",
        "district": "Durham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000540",
    },
    {
        "school": "Mangum Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000542",
    },
    {
        "school": "Merrick-Moore Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000543",
    },
    {
        "school": "Neal Middle",
        "district": "Durham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000544",
    },
    {
        "school": "Northern High",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000545",
    },
    {
        "school": "Oak Grove Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000546",
    },
    {
        "school": "Parkwood Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000547",
    },
    {
        "school": "Pearsontown Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000548",
    },
    {
        "school": "Sherwood Githens Middle",
        "district": "Durham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000549",
    },
    {
        "school": "Southern School of Energy and Sustainabi",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000550",
    },
    {
        "school": "Morehead Montessori",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000554",
    },
    {
        "school": "E K Powe Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000568",
    },
    {
        "school": "R N Harris Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000569",
    },
    {
        "school": "Rogers-Herr Middle",
        "district": "Durham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000570",
    },
    {
        "school": "C C Spaulding Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000571",
    },
    {
        "school": "W G Pearson Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000572",
    },
    {
        "school": "Y E Smith Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126000573",
    },
    {
        "school": "Durham School of the Arts",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126001547",
    },
    {
        "school": "Eastway Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126001850",
    },
    {
        "school": "DPS Hospital School",
        "district": "Durham Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126002206",
    },
    {
        "school": "Easley Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126002217",
    },
    {
        "school": "Southwest Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126002218",
    },
    {
        "school": "Riverside High",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126002292",
    },
    {
        "school": "Hope Valley Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126002442",
    },
    {
        "school": "Lakeview School",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370126002517",
    },
    {
        "school": "Eno River Academy",
        "district": "Eno River Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003502340",
    },
    {
        "school": "Carrboro Elementary",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072000294",
    },
    {
        "school": "Chapel Hill High",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072000295",
    },
    {
        "school": "Seawell Elementary",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072000296",
    },
    {
        "school": "Ephesus Elementary",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072000297",
    },
    {
        "school": "Estes Hills Elementary",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072000298",
    },
    {
        "school": "FPG Elementary",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072000299",
    },
    {
        "school": "Glenwood Elementary",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072000300",
    },
    {
        "school": "Culbreth Middle",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072000301",
    },
    {
        "school": "Phillips Middle",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072000302",
    },
    {
        "school": "UNC Hospital School",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072000303",
    },
    {
        "school": "McDougle Middle",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072001240",
    },
    {
        "school": "East Chapel Hill High",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072001942",
    },
    {
        "school": "McDougle Elementary",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072001962",
    },
    {
        "school": "Scroggs Elementary",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072002474",
    },
    {
        "school": "Smith Middle",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072002600",
    },
    {
        "school": "A L Stanback Middle",
        "district": "Orange County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348001441",
    },
    {
        "school": "Cameron Park Elementary",
        "district": "Orange County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348001442",
    },
    {
        "school": "Central Elementary",
        "district": "Orange County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348001443",
    },
    {
        "school": "Charles W Stanford Middle",
        "district": "Orange County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348001444",
    },
    {
        "school": "Efland Cheeks Elementary",
        "district": "Orange County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348001445",
    },
    {
        "school": "Grady Brown Elementary",
        "district": "Orange County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348001446",
    },
    {
        "school": "Orange High",
        "district": "Orange County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348001447",
    },
    {
        "school": "Hillsborough Elementary",
        "district": "Orange County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348001932",
    },
    {
        "school": "New Hope Elementary",
        "district": "Orange County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348002313",
    },
    {
        "school": "Pathways Elementary",
        "district": "Orange County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370348002536",
    },
    {
        "school": "Camden Intermediate",
        "district": "Camden County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370060002977",
    },
    {
        "school": "Camden County High",
        "district": "Camden County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370060000246",
    },
    {
        "school": "Camden Middle",
        "district": "Camden County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370060000247",
    },
    {
        "school": "Grandy Primary",
        "district": "Camden County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370060000248",
    },
    {
        "school": "Central Elementary",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354001452",
    },
    {
        "school": "Elizabeth City Middle",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354001453",
    },
    {
        "school": "J C Sawyer Elementary",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354001455",
    },
    {
        "school": "Northeastern High",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354001456",
    },
    {
        "school": "Pasquotank Elementary",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354001458",
    },
    {
        "school": "Sheep-Harney Elementary",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354001459",
    },
    {
        "school": "Weeksville Elementary",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354001460",
    },
    {
        "school": "Northside Elementary",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354002274",
    },
    {
        "school": "P W Moore Elementary",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354002275",
    },
    {
        "school": "H L Trigg Community",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370354002344",
    },
    {
        "school": "River Road Middle",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354002345",
    },
    {
        "school": "Pasquotank County High",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354002537",
    },
    {
        "school": "Perquimans Central",
        "district": "Perquimans County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370360001473",
    },
    {
        "school": "Hertford Grammar",
        "district": "Perquimans County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370360001474",
    },
    {
        "school": "Perquimans County High",
        "district": "Perquimans County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370360001475",
    },
    {
        "school": "Perquimans County Middle",
        "district": "Perquimans County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370360001476",
    },
    {
        "school": "Grays Creek High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102663",
    },
    {
        "school": "Cross Creek Early College",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102756",
    },
    {
        "school": "Cumberland Polytechnic",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102757",
    },
    {
        "school": "Don D Steed Elementary",
        "district": "Hoke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225002997",
    },
    {
        "school": "Rockfish Hoke Elementary",
        "district": "Hoke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225000581",
    },
    {
        "school": "Upchurch Elementary",
        "district": "Hoke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225000806",
    },
    {
        "school": "Hoke County High",
        "district": "Hoke County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225000968",
    },
    {
        "school": "J W McLauchlin Elementary",
        "district": "Hoke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225000969",
    },
    {
        "school": "West Hoke Middle",
        "district": "Hoke County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225000970",
    },
    {
        "school": "Scurlock Elementary",
        "district": "Hoke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225000972",
    },
    {
        "school": "Hawk Eye Elementary",
        "district": "Hoke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225000973",
    },
    {
        "school": "East Hoke Middle",
        "district": "Hoke County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225000974",
    },
    {
        "school": "West Hoke Elementary",
        "district": "Hoke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225000975",
    },
    {
        "school": "J W Turlington School",
        "district": "Hoke County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370225001172",
    },
    {
        "school": "Sandy Grove Elementary",
        "district": "Hoke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225002459",
    },
    {
        "school": "Ashley Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100394",
    },
    {
        "school": "Beaver Dam Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100395",
    },
    {
        "school": "Lillian Black Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100396",
    },
    {
        "school": "Brentwood Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100397",
    },
    {
        "school": "Douglas Byrd Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100399",
    },
    {
        "school": "Douglas Byrd High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100400",
    },
    {
        "school": "Cape Fear High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100402",
    },
    {
        "school": "Elizabeth M Cashwell Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100403",
    },
    {
        "school": "Eastover-Central Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100405",
    },
    {
        "school": "Anne Chesnutt Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100406",
    },
    {
        "school": "Cliffdale Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100407",
    },
    {
        "school": "College Lakes Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100408",
    },
    {
        "school": "J W Coon Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100409",
    },
    {
        "school": "Cumberland Mills Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100410",
    },
    {
        "school": "Cumberland Road Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100411",
    },
    {
        "school": "District No 7 Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100412",
    },
    {
        "school": "Alderman Road Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100414",
    },
    {
        "school": "Hope Mills Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100415",
    },
    {
        "school": "Ed V Baldwin Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100416",
    },
    {
        "school": "Lewis Chapel Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100417",
    },
    {
        "school": "Long Hill Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100418",
    },
    {
        "school": "Massey Hill Classical High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100420",
    },
    {
        "school": "Mary McArthur Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100421",
    },
    {
        "school": "Montclair Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100422",
    },
    {
        "school": "Morganton Road Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100423",
    },
    {
        "school": "Manchester Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100424",
    },
    {
        "school": "Pine Forest Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100425",
    },
    {
        "school": "Pine Forest High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100426",
    },
    {
        "school": "Ponderosa Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100427",
    },
    {
        "school": "Raleigh Road Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100428",
    },
    {
        "school": "Benjamin J Martin Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100429",
    },
    {
        "school": "Rockfish Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100430",
    },
    {
        "school": "J W Seabrook Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100431",
    },
    {
        "school": "Seventy-First High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100433",
    },
    {
        "school": "Sherwood Park Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100434",
    },
    {
        "school": "South View Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100435",
    },
    {
        "school": "South View High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100436",
    },
    {
        "school": "Spring Lake Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100437",
    },
    {
        "school": "Stedman Primary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100438",
    },
    {
        "school": "Sunnyside Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100440",
    },
    {
        "school": "Warrenwood Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100442",
    },
    {
        "school": "Westarea Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100443",
    },
    {
        "school": "Westover Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100444",
    },
    {
        "school": "Westover High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100445",
    },
    {
        "school": "William H Owen Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001100447",
    },
    {
        "school": "William T Brown Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001101097",
    },
    {
        "school": "Bill Hefner Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001101377",
    },
    {
        "school": "E Melvin Honeycutt Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001101391",
    },
    {
        "school": "Mac Williams Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001101832",
    },
    {
        "school": "Seventy-First Classical Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001101833",
    },
    {
        "school": "Stedman Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001101848",
    },
    {
        "school": "Armstrong Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102085",
    },
    {
        "school": "Howard Learning Academy",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370001102087",
    },
    {
        "school": "Alma O Easom Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102119",
    },
    {
        "school": "Loyd E Auman Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102120",
    },
    {
        "school": "C Wayne Collier Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102121",
    },
    {
        "school": "Luther Nick Jeralds Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102123",
    },
    {
        "school": "E E Smith High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102124",
    },
    {
        "school": "Ferguson-Easley Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102125",
    },
    {
        "school": "Glendale Acres Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102126",
    },
    {
        "school": "R Max Abbott Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102127",
    },
    {
        "school": "Howard L Hall Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102128",
    },
    {
        "school": "Lucile Souders Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102129",
    },
    {
        "school": "Margaret Willis Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102130",
    },
    {
        "school": "Walker-Spivey Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102131",
    },
    {
        "school": "Reid Ross Classical High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102132",
    },
    {
        "school": "Teresa C Berrien Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102133",
    },
    {
        "school": "Terry Sanford High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102134",
    },
    {
        "school": "Vanstory Hills Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102135",
    },
    {
        "school": "Ramsey Street High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370001102136",
    },
    {
        "school": "E E Miller Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102283",
    },
    {
        "school": "John R Griffin Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102439",
    },
    {
        "school": "Ireland Drive Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102440",
    },
    {
        "school": "Jack Britt High",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102512",
    },
    {
        "school": "Gallberry Farm Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102513",
    },
    {
        "school": "Lake Rim Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102514",
    },
    {
        "school": "Grays Creek Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102574",
    },
    {
        "school": "Stoney Point Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001102575",
    },
    {
        "school": "Alpha Academy",
        "district": "Alpha Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370010302511",
    },
    {
        "school": "Rutherford Early College High School",
        "district": "Rutherford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408002793",
    },
    {
        "school": "Thomas Jefferson Class Academy",
        "district": "Thomas Jefferson Classical Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009302480",
    },
    {
        "school": "Forrest W. Hunt Elementary School",
        "district": "Rutherford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408000909",
    },
    {
        "school": "R-S Middle School",
        "district": "Rutherford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408000925",
    },
    {
        "school": "Chase Middle School",
        "district": "Rutherford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001283",
    },
    {
        "school": "Chase High School",
        "district": "Rutherford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001636",
    },
    {
        "school": "Cliffside Elementary School",
        "district": "Rutherford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001637",
    },
    {
        "school": "Forest City-Dunbar Elementary School",
        "district": "Rutherford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001639",
    },
    {
        "school": "East Rutherford High School",
        "district": "Rutherford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001640",
    },
    {
        "school": "Ellenboro Elementary School",
        "district": "Rutherford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001641",
    },
    {
        "school": "Harris Elementary School",
        "district": "Rutherford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001645",
    },
    {
        "school": "Mt. Vernon-Ruth Elementary School",
        "district": "Rutherford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001646",
    },
    {
        "school": "East Rutherford Middle School",
        "district": "Rutherford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001648",
    },
    {
        "school": "Rutherfordton Elementary School",
        "district": "Rutherford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001650",
    },
    {
        "school": "R-S Central High School",
        "district": "Rutherford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001651",
    },
    {
        "school": "Spindale Elementary School",
        "district": "Rutherford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001653",
    },
    {
        "school": "Sunshine Elementary School",
        "district": "Rutherford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408001654",
    },
    {
        "school": "Pinnacle Elementary School",
        "district": "Rutherford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370408002479",
    },
    {
        "school": "Rutherford Opportunity Center",
        "district": "Rutherford County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370408002607",
    },
    {
        "school": "Dillard Academy",
        "district": "Dillard Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370007402420",
    },
    {
        "school": "Carver Heights Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488000349",
    },
    {
        "school": "Dillard Middle",
        "district": "Wayne County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488000398",
    },
    {
        "school": "Edgewood Cmty Developmental",
        "district": "Wayne County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370488000413",
    },
    {
        "school": "Goldsboro High",
        "district": "Wayne County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488000502",
    },
    {
        "school": "North Drive Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488000677",
    },
    {
        "school": "Brogden Middle",
        "district": "Wayne County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001945",
    },
    {
        "school": "Brogden Primary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001946",
    },
    {
        "school": "Carver Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001947",
    },
    {
        "school": "Charles B Aycock High",
        "district": "Wayne County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001948",
    },
    {
        "school": "Eastern Wayne Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001949",
    },
    {
        "school": "Eastern Wayne High",
        "district": "Wayne County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001950",
    },
    {
        "school": "Eastern Wayne Middle",
        "district": "Wayne County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001951",
    },
    {
        "school": "Fremont STARS Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001953",
    },
    {
        "school": "Grantham Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001954",
    },
    {
        "school": "Greenwood Middle",
        "district": "Wayne County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001955",
    },
    {
        "school": "Meadow Lane Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001956",
    },
    {
        "school": "Mount Olive Middle",
        "district": "Wayne County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001957",
    },
    {
        "school": "Norwayne Middle",
        "district": "Wayne County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001959",
    },
    {
        "school": "Rosewood High",
        "district": "Wayne County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001961",
    },
    {
        "school": "Southern Wayne High",
        "district": "Wayne County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488001963",
    },
    {
        "school": "Rosewood Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488002058",
    },
    {
        "school": "Northeast Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488002319",
    },
    {
        "school": "Northwest Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488002320",
    },
    {
        "school": "Rosewood Middle",
        "district": "Wayne County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488002497",
    },
    {
        "school": "Spring Creek Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488002498",
    },
    {
        "school": "Spring Creek High",
        "district": "Wayne County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488002499",
    },
    {
        "school": "Tommy's Road Elementary",
        "district": "Wayne County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488002563",
    },
    {
        "school": "Early College at Guilford",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002629",
    },
    {
        "school": "Middle College High at Bennett",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002667",
    },
    {
        "school": "Gillespie Park Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002668",
    },
    {
        "school": "Middle College at NC A&T",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002669",
    },
    {
        "school": "Brown Summit Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002732",
    },
    {
        "school": "Middle College at GTCC-Greensboro",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002771",
    },
    {
        "school": "Middle College at GTCC-High Point",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002772",
    },
    {
        "school": "Lincoln Academy",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002773",
    },
    {
        "school": "McLeansville Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002774",
    },
    {
        "school": "Pruette SCALE Academy",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370192002775",
    },
    {
        "school": "Doris Henderson Newcomers Sch",
        "district": "Guilford County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002988",
    },
    {
        "school": "Northern Guilford Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002990",
    },
    {
        "school": "Uwharrie Ridge Six-Twelve",
        "district": "Randolph County School System",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378002647",
    },
    {
        "school": "Huntsville Elementary",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399002680",
    },
    {
        "school": "Bethany Community  School",
        "district": "Bethany Community Middle",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370011002541",
    },
    {
        "school": "Central Elementary",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001066",
    },
    {
        "school": "Douglass Elementary",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001067",
    },
    {
        "school": "J E Holmes Middle",
        "district": "Rockingham County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001069",
    },
    {
        "school": "John M Morehead High",
        "district": "Rockingham County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001072",
    },
    {
        "school": "Western Rockingham Middle",
        "district": "Rockingham County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001150",
    },
    {
        "school": "Leaksville-Spray Elementary",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001242",
    },
    {
        "school": "Reidsville Middle",
        "district": "Rockingham County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001542",
    },
    {
        "school": "Reidsville High",
        "district": "Rockingham County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001543",
    },
    {
        "school": "South End Elementary",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001544",
    },
    {
        "school": "Williamsburg Elementary",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001545",
    },
    {
        "school": "Bethany Elementary",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001591",
    },
    {
        "school": "Monroeton Elementary",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001594",
    },
    {
        "school": "Rockingham County High",
        "district": "Rockingham County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001595",
    },
    {
        "school": "Wentworth Elementary",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399001599",
    },
    {
        "school": "Stoneville Elementary",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399002227",
    },
    {
        "school": "Dalton McMichael High",
        "district": "Rockingham County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399002306",
    },
    {
        "school": "John W Dillard Academy",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399002307",
    },
    {
        "school": "Rockingham County Middle",
        "district": "Rockingham County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399002476",
    },
    {
        "school": "The SCORE Center",
        "district": "Rockingham County Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370399002477",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Rockingham County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399002542",
    },
    {
        "school": "Greensboro Academy",
        "district": "Greensboro Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370008402454",
    },
    {
        "school": "Phoenix Academy-  Primary Elem. IB MYP",
        "district": "Phoenix Academy Inc",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370010502522",
    },
    {
        "school": "Guilford Preparatory Academy",
        "district": "Guilford Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370012102582",
    },
    {
        "school": "Southwest Guilford Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000577",
    },
    {
        "school": "Edwin A Alderman Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000756",
    },
    {
        "school": "Allen Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000757",
    },
    {
        "school": "Archer Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000758",
    },
    {
        "school": "Swann Middle School",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000759",
    },
    {
        "school": "Bessemer Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000760",
    },
    {
        "school": "Bluford Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000761",
    },
    {
        "school": "Gateway Education Center",
        "district": "Guilford County Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370192000764",
    },
    {
        "school": "Claxton Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000765",
    },
    {
        "school": "Ceasar Cone Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000766",
    },
    {
        "school": "James B Dudley High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000768",
    },
    {
        "school": "Erwin Montessori",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000769",
    },
    {
        "school": "Julius I Foust Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000770",
    },
    {
        "school": "Cyrus P Frazier Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000771",
    },
    {
        "school": "General Greene Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000773",
    },
    {
        "school": "Grimsley High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000774",
    },
    {
        "school": "Hunter Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000776",
    },
    {
        "school": "Irving Park Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000777",
    },
    {
        "school": "David D Jones Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000779",
    },
    {
        "school": "James Y Joyner Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000781",
    },
    {
        "school": "Kiser Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000782",
    },
    {
        "school": "John Van Lindley Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000784",
    },
    {
        "school": "Herbin Metz Education Center",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370192000786",
    },
    {
        "school": "Mendenhall Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000787",
    },
    {
        "school": "Morehead Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000789",
    },
    {
        "school": "Murphey Traditional Academy",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000791",
    },
    {
        "school": "Page High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000793",
    },
    {
        "school": "Clara J Peck Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000794",
    },
    {
        "school": "Peeler Open Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000795",
    },
    {
        "school": "Ben L. Smith High School",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000798",
    },
    {
        "school": "Sternberger Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000799",
    },
    {
        "school": "Vandalia Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000800",
    },
    {
        "school": "Washington Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000801",
    },
    {
        "school": "Philip J Weaver Ed Center",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000802",
    },
    {
        "school": "Wiley Accel/Enrichment",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000803",
    },
    {
        "school": "Alamance Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000814",
    },
    {
        "school": "Southern Guilford Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000816",
    },
    {
        "school": "Allen Jay Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000817",
    },
    {
        "school": "Brightwood Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000818",
    },
    {
        "school": "Monticello-Brown Summit Elem",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000819",
    },
    {
        "school": "Colfax Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000820",
    },
    {
        "school": "Eastern Guilford High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000821",
    },
    {
        "school": "Florence Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000822",
    },
    {
        "school": "Gibsonville Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000823",
    },
    {
        "school": "Western Guilford Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000824",
    },
    {
        "school": "Guilford Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000825",
    },
    {
        "school": "Jamestown Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000826",
    },
    {
        "school": "Jamestown Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000827",
    },
    {
        "school": "Jesse Wharton Elem",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000828",
    },
    {
        "school": "Lucy Ragsdale High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000830",
    },
    {
        "school": "Madison Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000831",
    },
    {
        "school": "Eastern Guilford Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000832",
    },
    {
        "school": "Millis Road Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000833",
    },
    {
        "school": "Northeast Guilford Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000835",
    },
    {
        "school": "Northeast Guilford High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000836",
    },
    {
        "school": "Northwest Guilford Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000837",
    },
    {
        "school": "Northwest Guilford High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000838",
    },
    {
        "school": "Nathanael Greene Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000839",
    },
    {
        "school": "Oak Ridge Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000840",
    },
    {
        "school": "Pleasant Garden Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000841",
    },
    {
        "school": "Rankin Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000843",
    },
    {
        "school": "Southeast Guilford Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000845",
    },
    {
        "school": "Southeast Guilford High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000846",
    },
    {
        "school": "Sedalia Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000847",
    },
    {
        "school": "Sedgefield Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000848",
    },
    {
        "school": "Southern Guilford High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000849",
    },
    {
        "school": "Southern Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000850",
    },
    {
        "school": "Stokesdale Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000851",
    },
    {
        "school": "Summerfield Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000852",
    },
    {
        "school": "Sumner Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000853",
    },
    {
        "school": "Union Hill Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000854",
    },
    {
        "school": "Western Guilford High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000855",
    },
    {
        "school": "Penn-Griffin Schools",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000951",
    },
    {
        "school": "Fairview Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000954",
    },
    {
        "school": "Ferndale Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000955",
    },
    {
        "school": "High Point Central High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000956",
    },
    {
        "school": "Johnson Street Global Studies",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000957",
    },
    {
        "school": "Kirkman Park Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000958",
    },
    {
        "school": "Montlieu Academy of Technology",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000960",
    },
    {
        "school": "Welborn Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000961",
    },
    {
        "school": "Northwood Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000962",
    },
    {
        "school": "Oak Hill Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000963",
    },
    {
        "school": "Oak View Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000964",
    },
    {
        "school": "Parkview Village Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000965",
    },
    {
        "school": "Shadybrook Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000966",
    },
    {
        "school": "T Wingate Andrews High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192000967",
    },
    {
        "school": "Jackson Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192001127",
    },
    {
        "school": "Pilot Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192001865",
    },
    {
        "school": "SCALE School",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370192001875",
    },
    {
        "school": "Southwest Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002041",
    },
    {
        "school": "Southwest Guilford High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002042",
    },
    {
        "school": "Brooks Global Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002295",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002453",
    },
    {
        "school": "Kernodle Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002523",
    },
    {
        "school": "Triangle Lake Montessori Elem",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002524",
    },
    {
        "school": "Waldo C Falkener Sr Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002583",
    },
    {
        "school": "GC Middle College High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002584",
    },
    {
        "school": "GTCC Middle College High",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002585",
    },
    {
        "school": "Otis L Hairston Sr Middle",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002586",
    },
    {
        "school": "Asheboro High",
        "district": "Asheboro City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370024000062",
    },
    {
        "school": "South Asheboro Middle",
        "district": "Asheboro City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370024000063",
    },
    {
        "school": "Balfour Elementary",
        "district": "Asheboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370024000064",
    },
    {
        "school": "Charles W McCrary Elementary",
        "district": "Asheboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370024000065",
    },
    {
        "school": "Donna L Loflin Elementary",
        "district": "Asheboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370024000066",
    },
    {
        "school": "Guy B Teachey Elementary",
        "district": "Asheboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370024000067",
    },
    {
        "school": "Lindley Park Elementary",
        "district": "Asheboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370024000068",
    },
    {
        "school": "North Asheboro Middle",
        "district": "Asheboro City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370024000069",
    },
    {
        "school": "John R Lawrence Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378000904",
    },
    {
        "school": "Southeastern Randolph Middle",
        "district": "Randolph County School System",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378000905",
    },
    {
        "school": "Archdale Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001514",
    },
    {
        "school": "Archdale-Trinity Middle",
        "district": "Randolph County School System",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001515",
    },
    {
        "school": "Coleridge Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001518",
    },
    {
        "school": "Eastern Randolph High",
        "district": "Randolph County School System",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001519",
    },
    {
        "school": "Farmer Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001520",
    },
    {
        "school": "Franklinville Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001521",
    },
    {
        "school": "Grays Chapel Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001522",
    },
    {
        "school": "Liberty Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001523",
    },
    {
        "school": "New Market Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001524",
    },
    {
        "school": "Ramseur Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001525",
    },
    {
        "school": "Randleman Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001526",
    },
    {
        "school": "Randleman High",
        "district": "Randolph County School System",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001527",
    },
    {
        "school": "Randleman Middle",
        "district": "Randolph County School System",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001528",
    },
    {
        "school": "Seagrove Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001529",
    },
    {
        "school": "Southwestern Randolph High",
        "district": "Randolph County School System",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001530",
    },
    {
        "school": "Tabernacle Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001531",
    },
    {
        "school": "Trindale Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001532",
    },
    {
        "school": "Trinity Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001533",
    },
    {
        "school": "Trinity High",
        "district": "Randolph County School System",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001534",
    },
    {
        "school": "Braxton Craven Middle",
        "district": "Randolph County School System",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378001976",
    },
    {
        "school": "Southwestern Randolph Middle",
        "district": "Randolph County School System",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378002276",
    },
    {
        "school": "Level Cross Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378002348",
    },
    {
        "school": "Northeastern Randolph Middle",
        "district": "Randolph County School System",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378002475",
    },
    {
        "school": "Hopewell Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378002605",
    },
    {
        "school": "Southmont Elementary",
        "district": "Randolph County School System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378002606",
    },
    {
        "school": "South Central",
        "district": "Pitt County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202616",
    },
    {
        "school": "Creekside Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202789",
    },
    {
        "school": "Greene Central High",
        "district": "Greene County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370183000750",
    },
    {
        "school": "Snow Hill Primary",
        "district": "Greene County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370183000754",
    },
    {
        "school": "West Greene Elementary",
        "district": "Greene County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370183000755",
    },
    {
        "school": "Greene County Middle",
        "district": "Greene County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370183002294",
    },
    {
        "school": "C M Eppes Middle",
        "district": "Pitt County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001200004",
    },
    {
        "school": "A G Cox Middle",
        "district": "Pitt County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201488",
    },
    {
        "school": "Ayden Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201489",
    },
    {
        "school": "Ayden Middle",
        "district": "Pitt County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201490",
    },
    {
        "school": "Ayden-Grifton High",
        "district": "Pitt County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201491",
    },
    {
        "school": "Belvoir Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201492",
    },
    {
        "school": "Bethel Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201493",
    },
    {
        "school": "Chicod",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201494",
    },
    {
        "school": "D H Conley High",
        "district": "Pitt County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201495",
    },
    {
        "school": "Falkland Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201496",
    },
    {
        "school": "Farmville Central High",
        "district": "Pitt County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201497",
    },
    {
        "school": "Farmville Middle",
        "district": "Pitt County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201498",
    },
    {
        "school": "G R Whitfield",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201499",
    },
    {
        "school": "Grifton",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201500",
    },
    {
        "school": "H B Sugg Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201501",
    },
    {
        "school": "North Pitt High",
        "district": "Pitt County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201502",
    },
    {
        "school": "Pactolus",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201503",
    },
    {
        "school": "Sam D Bundy Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201504",
    },
    {
        "school": "Stokes",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201505",
    },
    {
        "school": "W H Robinson Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201506",
    },
    {
        "school": "Wellcome Middle",
        "district": "Pitt County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001201507",
    },
    {
        "school": "Eastern Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202138",
    },
    {
        "school": "E B Aycock Middle",
        "district": "Pitt County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202139",
    },
    {
        "school": "Elmhurst Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202140",
    },
    {
        "school": "Junius H Rose High",
        "district": "Pitt County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202142",
    },
    {
        "school": "Vidant  Health",
        "district": "Pitt County Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370001202143",
    },
    {
        "school": "South Greenville Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202145",
    },
    {
        "school": "Wahl Coates Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202147",
    },
    {
        "school": "Wintergreen Intermediate",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202199",
    },
    {
        "school": "Wintergreen Primary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202408",
    },
    {
        "school": "Northwest Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001202604",
    },
    {
        "school": "Vance Charter School",
        "district": "Vance Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009602486",
    },
    {
        "school": "Aycock Elementary",
        "district": "Vance County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465001812",
    },
    {
        "school": "Carver Elementary",
        "district": "Vance County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465001813",
    },
    {
        "school": "Dabney Elementary",
        "district": "Vance County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465001815",
    },
    {
        "school": "Vance County Middle School",
        "district": "Vance County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465001816",
    },
    {
        "school": "New Hope Elementary",
        "district": "Vance County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465001819",
    },
    {
        "school": "Pinkston Street Elementary",
        "district": "Vance County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465001821",
    },
    {
        "school": "E M Rollins Elementary",
        "district": "Vance County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465001822",
    },
    {
        "school": "Vance County High School",
        "district": "Vance County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465001823",
    },
    {
        "school": "L B Yancey Elementary",
        "district": "Vance County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465001824",
    },
    {
        "school": "Zeb Vance Elementary",
        "district": "Vance County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465001825",
    },
    {
        "school": "AdVance Academy",
        "district": "Vance County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370465001993",
    },
    {
        "school": "E O Young Jr Elementary",
        "district": "Vance County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465002071",
    },
    {
        "school": "Jimmy C Draughn High School",
        "district": "Burke County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048002836",
    },
    {
        "school": "Walter R Johnson Middle",
        "district": "Burke County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048002662",
    },
    {
        "school": "Drexel Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048002705",
    },
    {
        "school": "Robert L. Patton High School",
        "district": "Burke County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048002832",
    },
    {
        "school": "Challenger Early College High",
        "district": "Catawba County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069002753",
    },
    {
        "school": "Discovery High School",
        "district": "Newton Conover City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370336002754",
    },
    {
        "school": "Alexander Central High",
        "district": "Alexander County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009000028",
    },
    {
        "school": "Bethlehem Elementary",
        "district": "Alexander County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009000029",
    },
    {
        "school": "Taylorsville Elementary",
        "district": "Alexander County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009000030",
    },
    {
        "school": "Hiddenite Elementary",
        "district": "Alexander County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009000031",
    },
    {
        "school": "Ellendale Elementary",
        "district": "Alexander County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009000032",
    },
    {
        "school": "Stony Point Elementary",
        "district": "Alexander County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009000033",
    },
    {
        "school": "Sugar Loaf Elementary",
        "district": "Alexander County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009000034",
    },
    {
        "school": "West Alexander Middle",
        "district": "Alexander County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009000035",
    },
    {
        "school": "Wittenburg Elementary",
        "district": "Alexander County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009000036",
    },
    {
        "school": "East Alexander Middle",
        "district": "Alexander County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009002148",
    },
    {
        "school": "New Dimensions",
        "district": "The New Dimensions School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370011802603",
    },
    {
        "school": "Heritage Middle",
        "district": "Burke County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000105",
    },
    {
        "school": "Table Rock Middle",
        "district": "Burke County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000108",
    },
    {
        "school": "East Burke High",
        "district": "Burke County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000174",
    },
    {
        "school": "Forest Hill Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000175",
    },
    {
        "school": "Freedom High",
        "district": "Burke County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000176",
    },
    {
        "school": "George Hildebrand Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000177",
    },
    {
        "school": "Glen Alpine Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000179",
    },
    {
        "school": "Hildebran Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000182",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000183",
    },
    {
        "school": "Icard Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000184",
    },
    {
        "school": "Mull Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000187",
    },
    {
        "school": "Oak Hill Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000188",
    },
    {
        "school": "Salem Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000191",
    },
    {
        "school": "Valdese Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048000193",
    },
    {
        "school": "Hallyburton Academy",
        "district": "Burke County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370048001005",
    },
    {
        "school": "North Liberty",
        "district": "Burke County Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370048001006",
    },
    {
        "school": "East Burke Middle",
        "district": "Burke County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048002193",
    },
    {
        "school": "Liberty Middle",
        "district": "Burke County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048002225",
    },
    {
        "school": "Ray Childers Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048002431",
    },
    {
        "school": "W A Young Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048002432",
    },
    {
        "school": "Baton Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000221",
    },
    {
        "school": "Collettsville School",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000222",
    },
    {
        "school": "Davenport A+ School",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000223",
    },
    {
        "school": "Dudley Shoals Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000224",
    },
    {
        "school": "Gamewell Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000226",
    },
    {
        "school": "Gamewell Middle",
        "district": "Caldwell County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000227",
    },
    {
        "school": "Granite Falls Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000228",
    },
    {
        "school": "Granite Falls Middle",
        "district": "Caldwell County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000229",
    },
    {
        "school": "Happy Valley Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000230",
    },
    {
        "school": "Hibriten High",
        "district": "Caldwell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000231",
    },
    {
        "school": "Hudson Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000232",
    },
    {
        "school": "Hudson Middle",
        "district": "Caldwell County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000233",
    },
    {
        "school": "Kings Creek Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000234",
    },
    {
        "school": "Lower Creek Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000235",
    },
    {
        "school": "Oak Hill Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000236",
    },
    {
        "school": "Sawmills Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000238",
    },
    {
        "school": "South Caldwell High",
        "district": "Caldwell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000239",
    },
    {
        "school": "Valmead Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000240",
    },
    {
        "school": "West Caldwell High",
        "district": "Caldwell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000241",
    },
    {
        "school": "West Lenoir Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000242",
    },
    {
        "school": "Whitnel Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000243",
    },
    {
        "school": "William Lenoir Middle",
        "district": "Caldwell County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058000244",
    },
    {
        "school": "Gateway School",
        "district": "Caldwell County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370058001010",
    },
    {
        "school": "Caldwell Applied Sciences Academy",
        "district": "Caldwell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370058002435",
    },
    {
        "school": "Horizons Elementary",
        "district": "Caldwell County Schools",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370058002571",
    },
    {
        "school": "Balls Creek Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000273",
    },
    {
        "school": "Bandys High",
        "district": "Catawba County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000274",
    },
    {
        "school": "Banoak Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000275",
    },
    {
        "school": "Blackburn Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000276",
    },
    {
        "school": "Bunker Hill High",
        "district": "Catawba County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000277",
    },
    {
        "school": "Catawba Elementary School",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000278",
    },
    {
        "school": "Charles H Tuttle Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000279",
    },
    {
        "school": "Claremont Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000280",
    },
    {
        "school": "Clyde Campbell Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000281",
    },
    {
        "school": "Fred T Foard High",
        "district": "Catawba County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000282",
    },
    {
        "school": "Harry M Arndt Middle",
        "district": "Catawba County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000283",
    },
    {
        "school": "Maiden Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000284",
    },
    {
        "school": "Maiden High",
        "district": "Catawba County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000285",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000286",
    },
    {
        "school": "Oxford Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000287",
    },
    {
        "school": "Sherrills Ford Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000288",
    },
    {
        "school": "Saint Stephens Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000289",
    },
    {
        "school": "Saint Stephens High",
        "district": "Catawba County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000290",
    },
    {
        "school": "Startown Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000291",
    },
    {
        "school": "Webb A Murray Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069000293",
    },
    {
        "school": "Jacobs Fork Middle",
        "district": "Catawba County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069001364",
    },
    {
        "school": "Mill Creek Middle",
        "district": "Catawba County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069002437",
    },
    {
        "school": "River Bend Middle",
        "district": "Catawba County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069002438",
    },
    {
        "school": "Lyle Creek Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069002573",
    },
    {
        "school": "Northview Middle",
        "district": "Hickory City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370219000940",
    },
    {
        "school": "Grandview Middle",
        "district": "Hickory City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370219000941",
    },
    {
        "school": "Hickory High",
        "district": "Hickory City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370219000943",
    },
    {
        "school": "W M Jenkins Elementary",
        "district": "Hickory City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370219000945",
    },
    {
        "school": "Longview Elementary",
        "district": "Hickory City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370219000947",
    },
    {
        "school": "Oakwood Elementary",
        "district": "Hickory City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370219000948",
    },
    {
        "school": "Southwest Primary",
        "district": "Hickory City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370219000949",
    },
    {
        "school": "Viewmont Elementary",
        "district": "Hickory City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370219000950",
    },
    {
        "school": "Hickory Career  Arts Magnet High School",
        "district": "Hickory City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370219002108",
    },
    {
        "school": "Conover Special Education",
        "district": "Newton Conover City Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370336001398",
    },
    {
        "school": "Newton-Conover High",
        "district": "Newton Conover City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370336001400",
    },
    {
        "school": "Newton-Conover Middle",
        "district": "Newton Conover City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370336001402",
    },
    {
        "school": "Shuford Elementary",
        "district": "Newton Conover City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370336001403",
    },
    {
        "school": "South Newton Elementary",
        "district": "Newton Conover City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370336001404",
    },
    {
        "school": "North Newton Elementary",
        "district": "Newton Conover City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370336001405",
    },
    {
        "school": "Carolina Forest Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002738",
    },
    {
        "school": "Southwest Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001233",
    },
    {
        "school": "Bell Fork Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001417",
    },
    {
        "school": "Blue Creek Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001418",
    },
    {
        "school": "Clyde Erwin Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001419",
    },
    {
        "school": "Dixon High",
        "district": "Onslow County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001421",
    },
    {
        "school": "Jacksonville High",
        "district": "Onslow County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001423",
    },
    {
        "school": "Morton Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001424",
    },
    {
        "school": "Northwoods Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001425",
    },
    {
        "school": "Northwoods Park Middle",
        "district": "Onslow County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001426",
    },
    {
        "school": "Parkwood Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001427",
    },
    {
        "school": "Richlands Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001428",
    },
    {
        "school": "Richlands High",
        "district": "Onslow County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001429",
    },
    {
        "school": "Silverdale Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001430",
    },
    {
        "school": "Southwest High",
        "district": "Onslow County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001431",
    },
    {
        "school": "Summersill Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001432",
    },
    {
        "school": "Swansboro High",
        "district": "Onslow County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001434",
    },
    {
        "school": "Swansboro Middle",
        "district": "Onslow County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001435",
    },
    {
        "school": "Swansboro Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001436",
    },
    {
        "school": "Trexler Middle",
        "district": "Onslow County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001438",
    },
    {
        "school": "White Oak High",
        "district": "Onslow County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001440",
    },
    {
        "school": "Jacksonville Commons Elem",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345001931",
    },
    {
        "school": "Dixon Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002270",
    },
    {
        "school": "Dixon Middle",
        "district": "Onslow County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002271",
    },
    {
        "school": "Hunters Creek Middle",
        "district": "Onslow County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002272",
    },
    {
        "school": "Southwest Middle",
        "district": "Onslow County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002273",
    },
    {
        "school": "Hunters Creek Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002338",
    },
    {
        "school": "Jacksonville Commons Middle",
        "district": "Onslow County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002339",
    },
    {
        "school": "New Bridge Middle",
        "district": "Onslow County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002402",
    },
    {
        "school": "Queens Creek Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002403",
    },
    {
        "school": "Sand Ridge Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002404",
    },
    {
        "school": "Northside High",
        "district": "Onslow County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002598",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345002599",
    },
    {
        "school": "First Flight High School",
        "district": "Dare County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370111002724",
    },
    {
        "school": "Nags Head Elementary School",
        "district": "Dare County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370111002758",
    },
    {
        "school": "Cape Hatteras Secondary School",
        "district": "Dare County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370111000454",
    },
    {
        "school": "Kitty Hawk Elementary School",
        "district": "Dare County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370111000455",
    },
    {
        "school": "Manteo Elementary School",
        "district": "Dare County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370111000456",
    },
    {
        "school": "Manteo High School",
        "district": "Dare County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370111000457",
    },
    {
        "school": "Cape Hatteras Elementary School",
        "district": "Dare County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370111002088",
    },
    {
        "school": "Dare Learning Academy",
        "district": "Dare County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370111002093",
    },
    {
        "school": "Manteo Middle School",
        "district": "Dare County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370111002107",
    },
    {
        "school": "First Flight Elementary School",
        "district": "Dare County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370111002290",
    },
    {
        "school": "First Flight Middle School",
        "district": "Dare County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370111002291",
    },
    {
        "school": "Lenoir County Early College High",
        "district": "Lenoir County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261002831",
    },
    {
        "school": "Children's Village Academy",
        "district": "Children's Village Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003102323",
    },
    {
        "school": "Kinston High",
        "district": "Lenoir County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261000585",
    },
    {
        "school": "Northwest Elementary",
        "district": "Lenoir County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261000586",
    },
    {
        "school": "Rochelle Middle",
        "district": "Lenoir County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261000589",
    },
    {
        "school": "Southeast Elementary",
        "district": "Lenoir County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261000596",
    },
    {
        "school": "Banks Elementary",
        "district": "Lenoir County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261001086",
    },
    {
        "school": "Contentnea-Savannah School",
        "district": "Lenoir County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261001087",
    },
    {
        "school": "E B Frink Middle",
        "district": "Lenoir County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261001088",
    },
    {
        "school": "La Grange Elementary",
        "district": "Lenoir County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261001089",
    },
    {
        "school": "Moss Hill Elementary",
        "district": "Lenoir County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261001090",
    },
    {
        "school": "North Lenoir High",
        "district": "Lenoir County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261001091",
    },
    {
        "school": "Pink Hill Elementary",
        "district": "Lenoir County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261001092",
    },
    {
        "school": "South Lenoir High",
        "district": "Lenoir County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261001094",
    },
    {
        "school": "Southwood Elementary",
        "district": "Lenoir County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261001095",
    },
    {
        "school": "Woodington Middle",
        "district": "Lenoir County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261001096",
    },
    {
        "school": "Lenoir County Learning Academy",
        "district": "Lenoir County Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370261001586",
    },
    {
        "school": "Carver Middle",
        "district": "Scotland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370420001684",
    },
    {
        "school": "Shaw Academy",
        "district": "Scotland County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370420001687",
    },
    {
        "school": "Laurel Hill Elementary",
        "district": "Scotland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370420001689",
    },
    {
        "school": "South Scotland Elementary",
        "district": "Scotland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370420001694",
    },
    {
        "school": "Wagram Elementary",
        "district": "Scotland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370420001695",
    },
    {
        "school": "Sycamore Lane Elementary",
        "district": "Scotland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370420001696",
    },
    {
        "school": "I E Johnson Elementary",
        "district": "Scotland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370420002544",
    },
    {
        "school": "Spring Hill Middle",
        "district": "Scotland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370420002546",
    },
    {
        "school": "Brier Creek Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114002664",
    },
    {
        "school": "Davidson Early College",
        "district": "Davidson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114002759",
    },
    {
        "school": "Friendship Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114002760",
    },
    {
        "school": "South Lexington Developmental Center",
        "district": "Lexington City Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370264002725",
    },
    {
        "school": "Central Davidson Middle",
        "district": "Davidson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000458",
    },
    {
        "school": "Central Davidson High",
        "district": "Davidson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000459",
    },
    {
        "school": "Stoner-Thomas School",
        "district": "Davidson County Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370114000460",
    },
    {
        "school": "Churchland Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000461",
    },
    {
        "school": "Davidson County High School",
        "district": "Davidson County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370114000462",
    },
    {
        "school": "Davis-Townsend Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000463",
    },
    {
        "school": "Denton Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000464",
    },
    {
        "school": "E Lawson Brown Middle",
        "district": "Davidson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000466",
    },
    {
        "school": "East Davidson High",
        "district": "Davidson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000467",
    },
    {
        "school": "Fair Grove Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000468",
    },
    {
        "school": "Hasty Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000469",
    },
    {
        "school": "Ledford Middle",
        "district": "Davidson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000470",
    },
    {
        "school": "Ledford Senior High",
        "district": "Davidson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000471",
    },
    {
        "school": "Midway Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000473",
    },
    {
        "school": "North Davidson Middle",
        "district": "Davidson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000474",
    },
    {
        "school": "North Davidson High",
        "district": "Davidson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000475",
    },
    {
        "school": "Northwest Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000476",
    },
    {
        "school": "Pilot Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000477",
    },
    {
        "school": "Reeds Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000478",
    },
    {
        "school": "Silver Valley Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000479",
    },
    {
        "school": "Tyro Middle",
        "district": "Davidson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000481",
    },
    {
        "school": "Wallburg Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000482",
    },
    {
        "school": "Welcome Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000483",
    },
    {
        "school": "West Davidson High",
        "district": "Davidson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114000484",
    },
    {
        "school": "Southwood Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114002036",
    },
    {
        "school": "South Davidson High",
        "district": "Davidson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114002216",
    },
    {
        "school": "South Davidson Middle",
        "district": "Davidson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114002515",
    },
    {
        "school": "Friedberg Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114002576",
    },
    {
        "school": "Charles England Elementary School",
        "district": "Lexington City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370264001098",
    },
    {
        "school": "Lexington Middle School",
        "district": "Lexington City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370264001101",
    },
    {
        "school": "Lexington Senior High School",
        "district": "Lexington City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370264001102",
    },
    {
        "school": "Pickett Elementary School",
        "district": "Lexington City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370264001103",
    },
    {
        "school": "Southwest Elementary School",
        "district": "Lexington City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370264001104",
    },
    {
        "school": "South Lexington School",
        "district": "Lexington City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370264001105",
    },
    {
        "school": "Thomasville Primary",
        "district": "Thomasville City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370450000792",
    },
    {
        "school": "Liberty Drive Elementary",
        "district": "Thomasville City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370450001774",
    },
    {
        "school": "Thomasville Middle",
        "district": "Thomasville City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370450001775",
    },
    {
        "school": "Thomasville High",
        "district": "Thomasville City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370450001776",
    },
    {
        "school": "North Lincoln High",
        "district": "Lincoln County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268002673",
    },
    {
        "school": "St James Elementary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268002674",
    },
    {
        "school": "Lincoln Charter School",
        "district": "Lincoln Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370006202393",
    },
    {
        "school": "Battleground Elementary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001108",
    },
    {
        "school": "GE Massey Elementary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001109",
    },
    {
        "school": "East Lincoln High",
        "district": "Lincoln County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001110",
    },
    {
        "school": "East Lincoln Middle",
        "district": "Lincoln County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001111",
    },
    {
        "school": "Iron Station Elementary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001113",
    },
    {
        "school": "Lincolnton High",
        "district": "Lincoln County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001114",
    },
    {
        "school": "Lincolnton Middle",
        "district": "Lincoln County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001115",
    },
    {
        "school": "Love Memorial Elementary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001116",
    },
    {
        "school": "Rock Springs Elementary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001121",
    },
    {
        "school": "S Ray Lowder Elementary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001122",
    },
    {
        "school": "Union Elementary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001123",
    },
    {
        "school": "West Lincoln High",
        "district": "Lincoln County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001124",
    },
    {
        "school": "West Lincoln Middle",
        "district": "Lincoln County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268001125",
    },
    {
        "school": "Catawba Springs Elementary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268002163",
    },
    {
        "school": "LCST",
        "district": "Lincoln County Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "NC",
        "nces_id": "370268002196",
    },
    {
        "school": "North Brook Elementary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268002197",
    },
    {
        "school": "Asbury Academy",
        "district": "Lincoln County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370268002392",
    },
    {
        "school": "Pumpkin Center Primary",
        "district": "Lincoln County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268002469",
    },
    {
        "school": "North Lincoln Middle",
        "district": "Lincoln County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370268002470",
    },
    {
        "school": "PSRC Early College at RCC",
        "district": "Public Schools of Robeson County",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002791",
    },
    {
        "school": "CIS Academy",
        "district": "CIS Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370004002349",
    },
    {
        "school": "Deep Branch Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001569",
    },
    {
        "school": "Fairgrove Elementary School",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001571",
    },
    {
        "school": "Littlefield Middle",
        "district": "Public Schools of Robeson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001572",
    },
    {
        "school": "Long Branch Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001573",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001574",
    },
    {
        "school": "Orrum Middle",
        "district": "Public Schools of Robeson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001575",
    },
    {
        "school": "Oxendine Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001576",
    },
    {
        "school": "Parkton Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001577",
    },
    {
        "school": "Pembroke Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001578",
    },
    {
        "school": "Pembroke Middle",
        "district": "Public Schools of Robeson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001579",
    },
    {
        "school": "Piney Grove Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001581",
    },
    {
        "school": "Prospect Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001583",
    },
    {
        "school": "Rex-Rennert Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001585",
    },
    {
        "school": "Union Chapel Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001589",
    },
    {
        "school": "Union Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393001590",
    },
    {
        "school": "Robeson Co Career Ctr",
        "district": "Public Schools of Robeson County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "NC",
        "nces_id": "370393002049",
    },
    {
        "school": "East Robeson Primary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002050",
    },
    {
        "school": "Townsend",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002052",
    },
    {
        "school": "Purnell Swett High",
        "district": "Public Schools of Robeson County",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002102",
    },
    {
        "school": "Fairmont High",
        "district": "Public Schools of Robeson County",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002232",
    },
    {
        "school": "Fairmont Middle",
        "district": "Public Schools of Robeson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002233",
    },
    {
        "school": "L Gilbert Carroll",
        "district": "Public Schools of Robeson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002235",
    },
    {
        "school": "Lumberton Junior",
        "district": "Public Schools of Robeson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002236",
    },
    {
        "school": "Lumberton Senior High",
        "district": "Public Schools of Robeson County",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002237",
    },
    {
        "school": "Peterson Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002238",
    },
    {
        "school": "Red Springs High",
        "district": "Public Schools of Robeson County",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002239",
    },
    {
        "school": "Red Springs Middle",
        "district": "Public Schools of Robeson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002240",
    },
    {
        "school": "Rosenwald Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002241",
    },
    {
        "school": "Rowland Norment Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002242",
    },
    {
        "school": "Saint Pauls Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002243",
    },
    {
        "school": "Saint Pauls High",
        "district": "Public Schools of Robeson County",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002244",
    },
    {
        "school": "Saint Pauls Middle",
        "district": "Public Schools of Robeson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002245",
    },
    {
        "school": "Tanglewood Elementary",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002246",
    },
    {
        "school": "W H Knuckles",
        "district": "Public Schools of Robeson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393002247",
    },
    {
        "school": "Tiller School",
        "district": "Tiller School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370005202371",
    },
    {
        "school": "Atlantic Elementary",
        "district": "Carteret County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063000249",
    },
    {
        "school": "Beaufort Elementary",
        "district": "Carteret County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063000250",
    },
    {
        "school": "Beaufort Middle",
        "district": "Carteret County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063000251",
    },
    {
        "school": "East Carteret High",
        "district": "Carteret County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063000253",
    },
    {
        "school": "Harkers Island Elementary",
        "district": "Carteret County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063000254",
    },
    {
        "school": "Morehead City Middle",
        "district": "Carteret County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063000255",
    },
    {
        "school": "Newport Elementary",
        "district": "Carteret County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063000257",
    },
    {
        "school": "Down East Middle and Smyrna Elementary",
        "district": "Carteret County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063000258",
    },
    {
        "school": "West Carteret High",
        "district": "Carteret County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063000259",
    },
    {
        "school": "White Oak Elementary",
        "district": "Carteret County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063000260",
    },
    {
        "school": "Morehead Elem at Camp Glenn",
        "district": "Carteret County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063001042",
    },
    {
        "school": "Morehead City Primary",
        "district": "Carteret County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063001044",
    },
    {
        "school": "Broad Creek Middle",
        "district": "Carteret County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063002205",
    },
    {
        "school": "Bogue Sound Elementary",
        "district": "Carteret County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063002368",
    },
    {
        "school": "Croatan High",
        "district": "Carteret County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063002369",
    },
    {
        "school": "Newport Middle",
        "district": "Carteret County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063002572",
    },
    {
        "school": "Elkin Middle",
        "district": "Elkin City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370138002797",
    },
    {
        "school": "Millennium Charter Academy",
        "district": "Millennium Charter Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370011102548",
    },
    {
        "school": "Elkin High",
        "district": "Elkin City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370138000562",
    },
    {
        "school": "Elkin Elementary",
        "district": "Elkin City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370138000563",
    },
    {
        "school": "Bruce H Tharrington Primary",
        "district": "Mount Airy City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370321001337",
    },
    {
        "school": "Jones Intermediate",
        "district": "Mount Airy City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370321001338",
    },
    {
        "school": "Mount Airy High",
        "district": "Mount Airy City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370321001339",
    },
    {
        "school": "Mount Airy Middle",
        "district": "Mount Airy City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370321001340",
    },
    {
        "school": "Cedar Ridge Elementary",
        "district": "Surry County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001663",
    },
    {
        "school": "Copeland Elementary",
        "district": "Surry County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001746",
    },
    {
        "school": "Dobson Elementary",
        "district": "Surry County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001747",
    },
    {
        "school": "East Surry High",
        "district": "Surry County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001748",
    },
    {
        "school": "Flat Rock Elementary",
        "district": "Surry County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001749",
    },
    {
        "school": "Franklin Elementary",
        "district": "Surry County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001750",
    },
    {
        "school": "J Sam Gentry Middle",
        "district": "Surry County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001751",
    },
    {
        "school": "Mountain Park Elementary",
        "district": "Surry County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001753",
    },
    {
        "school": "North Surry High",
        "district": "Surry County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001754",
    },
    {
        "school": "Pilot Mountain Middle",
        "district": "Surry County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001755",
    },
    {
        "school": "Shoals Elementary",
        "district": "Surry County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001756",
    },
    {
        "school": "Surry Central High",
        "district": "Surry County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001757",
    },
    {
        "school": "Westfield Elementary",
        "district": "Surry County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001758",
    },
    {
        "school": "White Plains Elementary",
        "district": "Surry County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441001759",
    },
    {
        "school": "Central Middle",
        "district": "Surry County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441002279",
    },
    {
        "school": "Meadowview Magnet Middle",
        "district": "Surry County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441002549",
    },
    {
        "school": "Albert H Bangert Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331000380",
    },
    {
        "school": "Bridgeton Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331000381",
    },
    {
        "school": "Graham A Barden Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331000382",
    },
    {
        "school": "H J MacDonald Middle",
        "district": "Craven County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331000383",
    },
    {
        "school": "Havelock High",
        "district": "Craven County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331000384",
    },
    {
        "school": "Havelock Middle",
        "district": "Craven County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331000386",
    },
    {
        "school": "J T Barber Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331000387",
    },
    {
        "school": "New Bern High",
        "district": "Craven County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331000388",
    },
    {
        "school": "West Craven Middle",
        "district": "Craven County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331000392",
    },
    {
        "school": "Tucker Creek Middle",
        "district": "Craven County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002084",
    },
    {
        "school": "Brinson Memorial Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002171",
    },
    {
        "school": "Vanceboro-Farm Life Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002173",
    },
    {
        "school": "Havelock Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002175",
    },
    {
        "school": "Oaks Road Academy",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002177",
    },
    {
        "school": "Roger Bell New Tech Academy",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002178",
    },
    {
        "school": "Trent Park Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002179",
    },
    {
        "school": "West Craven High",
        "district": "Craven County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002180",
    },
    {
        "school": "Arthur W Edwards Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002181",
    },
    {
        "school": "James W Smith Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002211",
    },
    {
        "school": "Ben D Quinn Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002310",
    },
    {
        "school": "Grover C Fields Middle",
        "district": "Craven County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002311",
    },
    {
        "school": "W Jesse Gurganus Elementary",
        "district": "Craven County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331002312",
    },
    {
        "school": "Comfort Elementary",
        "district": "Jones County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370240001033",
    },
    {
        "school": "Maysville Elementary",
        "district": "Jones County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370240001036",
    },
    {
        "school": "Pollocksville Elementary",
        "district": "Jones County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370240001037",
    },
    {
        "school": "Trenton Elementary",
        "district": "Jones County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370240001038",
    },
    {
        "school": "Arapahoe Charter School",
        "district": "Arapahoe Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003802343",
    },
    {
        "school": "Fred A Anderson Elementary",
        "district": "Pamlico County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370351001449",
    },
    {
        "school": "Pamlico County High",
        "district": "Pamlico County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370351001450",
    },
    {
        "school": "Pamlico County Middle",
        "district": "Pamlico County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370351001451",
    },
    {
        "school": "Pamlico County Primary",
        "district": "Pamlico County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370351002407",
    },
    {
        "school": "East Wilkes Middle School",
        "district": "Wilkes County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495002655",
    },
    {
        "school": "Millers Creek Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495002656",
    },
    {
        "school": "North Wilkes Middle School",
        "district": "Wilkes County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495002657",
    },
    {
        "school": "West Wilkes Middle School",
        "district": "Wilkes County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495002658",
    },
    {
        "school": "Bridges Academy",
        "district": "Bridges Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370004102350",
    },
    {
        "school": "Boomer-Ferguson Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001971",
    },
    {
        "school": "C B Eller Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001972",
    },
    {
        "school": "C C Wright Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001973",
    },
    {
        "school": "East Wilkes High School",
        "district": "Wilkes County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001974",
    },
    {
        "school": "Moravian Falls Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001977",
    },
    {
        "school": "Mount Pleasant Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001978",
    },
    {
        "school": "Mountain View Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001979",
    },
    {
        "school": "Mulberry Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001980",
    },
    {
        "school": "North Wilkes High School",
        "district": "Wilkes County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001981",
    },
    {
        "school": "North Wilkesboro Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001982",
    },
    {
        "school": "Roaring River Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001983",
    },
    {
        "school": "Ronda-Clingman Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001984",
    },
    {
        "school": "Traphill Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001985",
    },
    {
        "school": "West Wilkes High School",
        "district": "Wilkes County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001988",
    },
    {
        "school": "Wilkes Central High School",
        "district": "Wilkes County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001989",
    },
    {
        "school": "Wilkesboro Elementary School",
        "district": "Wilkes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495001990",
    },
    {
        "school": "Central Wilkes Middle School",
        "district": "Wilkes County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495002072",
    },
    {
        "school": "Sanford Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002813",
    },
    {
        "school": "Royal Elementary",
        "district": "Franklin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153002628",
    },
    {
        "school": "Neuse Charter School",
        "district": "Neuse Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370014402925",
    },
    {
        "school": "West Johnston High",
        "district": "Johnston County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002635",
    },
    {
        "school": "McGee's Crossroads Middle",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002671",
    },
    {
        "school": "River Dell Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002672",
    },
    {
        "school": "Casa Esperanza Montessori Charter School",
        "district": "Casa Esperanza Montessori",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370013102681",
    },
    {
        "school": "Ballentine Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002652",
    },
    {
        "school": "Middle Creek High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002653",
    },
    {
        "school": "Moore Square Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002654",
    },
    {
        "school": "Heritage Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002682",
    },
    {
        "school": "Holly Ridge Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002683",
    },
    {
        "school": "Holly Ridge Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002684",
    },
    {
        "school": "Forestville Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002742",
    },
    {
        "school": "Highcroft Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002743",
    },
    {
        "school": "Jones Dairy Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002744",
    },
    {
        "school": "Knightdale High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002745",
    },
    {
        "school": "Salem Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002746",
    },
    {
        "school": "Turner Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002747",
    },
    {
        "school": "Cedar Fork Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002802",
    },
    {
        "school": "Forest Pines Drive Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002803",
    },
    {
        "school": "River Oaks Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370472002804",
    },
    {
        "school": "Harris Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002805",
    },
    {
        "school": "Wakelon Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002806",
    },
    {
        "school": "North Forest Pines Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002824",
    },
    {
        "school": "Wendell Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002825",
    },
    {
        "school": "East Cary Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002830",
    },
    {
        "school": "East Garner Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002837",
    },
    {
        "school": "Crosscreek Charter School",
        "district": "Crosscreek Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370011902579",
    },
    {
        "school": "Laurel Mill Elementary",
        "district": "Franklin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153000574",
    },
    {
        "school": "Terrell Lane Middle",
        "district": "Franklin County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153000575",
    },
    {
        "school": "Bunn Elementary",
        "district": "Franklin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153000650",
    },
    {
        "school": "Bunn High",
        "district": "Franklin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153000651",
    },
    {
        "school": "Edward Best Elementary",
        "district": "Franklin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153000653",
    },
    {
        "school": "Louisburg Elementary",
        "district": "Franklin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153000657",
    },
    {
        "school": "Louisburg High",
        "district": "Franklin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153000658",
    },
    {
        "school": "Youngsville Elementary",
        "district": "Franklin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153000659",
    },
    {
        "school": "Franklinton Elementary",
        "district": "Franklin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153000660",
    },
    {
        "school": "Franklinton High",
        "district": "Franklin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153000661",
    },
    {
        "school": "Bunn Middle",
        "district": "Franklin County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153002382",
    },
    {
        "school": "Cedar Creek Middle",
        "district": "Franklin County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153002383",
    },
    {
        "school": "Benson Middle",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237000582",
    },
    {
        "school": "Cooper Academy",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237000810",
    },
    {
        "school": "Selma Middle School",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237000811",
    },
    {
        "school": "Benson Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001009",
    },
    {
        "school": "Clayton High",
        "district": "Johnston County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001012",
    },
    {
        "school": "West Clayton Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001013",
    },
    {
        "school": "Cleveland Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001014",
    },
    {
        "school": "Corinth-Holders Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001015",
    },
    {
        "school": "Four Oaks Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001016",
    },
    {
        "school": "North Johnston Middle",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001017",
    },
    {
        "school": "Glendale-Kenly Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001018",
    },
    {
        "school": "Meadow School",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001019",
    },
    {
        "school": "North Johnston High",
        "district": "Johnston County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001021",
    },
    {
        "school": "Pine Level Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001022",
    },
    {
        "school": "Princeton High",
        "district": "Johnston County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001023",
    },
    {
        "school": "Selma Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001025",
    },
    {
        "school": "West Smithfield Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001026",
    },
    {
        "school": "Smithfield Middle",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001027",
    },
    {
        "school": "Smithfield-Selma High",
        "district": "Johnston County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001028",
    },
    {
        "school": "South Johnston High",
        "district": "Johnston County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001029",
    },
    {
        "school": "South Smithfield Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001030",
    },
    {
        "school": "Clayton Middle",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001031",
    },
    {
        "school": "Wilson's Mills Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001032",
    },
    {
        "school": "Cleveland Middle",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237001173",
    },
    {
        "school": "Four Oaks Middle",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002304",
    },
    {
        "school": "East Clayton Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002322",
    },
    {
        "school": "McGee's Crossroads Elem",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002389",
    },
    {
        "school": "Riverwood Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002529",
    },
    {
        "school": "Riverwood Middle",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002587",
    },
    {
        "school": "Polenta Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237002588",
    },
    {
        "school": "The Exploris School",
        "district": "The Exploris School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370004302358",
    },
    {
        "school": "Magellan Charter",
        "district": "Magellan Charter",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370004502360",
    },
    {
        "school": "Sterling Montessori Academy",
        "district": "Sterling Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370004602361",
    },
    {
        "school": "Franklin Academy",
        "district": "Franklin Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370006902415",
    },
    {
        "school": "East Wake Academy",
        "district": "East Wake Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370007002416",
    },
    {
        "school": "Raleigh Charter High School",
        "district": "Raleigh Charter High School",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009702494",
    },
    {
        "school": "Torchlight Academy",
        "district": "Torchlight Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009802495",
    },
    {
        "school": "Quest Academy",
        "district": "Quest Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009902496",
    },
    {
        "school": "PreEminent Charter",
        "district": "PreEminent Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370011302553",
    },
    {
        "school": "Southern Wake Academy",
        "district": "Southern Wake Academy",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370011402554",
    },
    {
        "school": "Creech Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472000027",
    },
    {
        "school": "Durant Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472000075",
    },
    {
        "school": "Leesville Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472000077",
    },
    {
        "school": "Pleasant Union Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472000198",
    },
    {
        "school": "West Lake Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472000205",
    },
    {
        "school": "West Lake Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472000267",
    },
    {
        "school": "Durant Road Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472000942",
    },
    {
        "school": "Leesville Road High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472000944",
    },
    {
        "school": "Oak Grove Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001311",
    },
    {
        "school": "Davis Drive Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001669",
    },
    {
        "school": "Hodge Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001677",
    },
    {
        "school": "Weatherstone Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001681",
    },
    {
        "school": "Adams Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001826",
    },
    {
        "school": "Apex Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001827",
    },
    {
        "school": "Apex Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001828",
    },
    {
        "school": "Apex High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001829",
    },
    {
        "school": "Athens Drive High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001830",
    },
    {
        "school": "Aversboro Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001831",
    },
    {
        "school": "Baucom Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001834",
    },
    {
        "school": "Brentwood Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001836",
    },
    {
        "school": "Briarcliff Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001837",
    },
    {
        "school": "Brooks Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001838",
    },
    {
        "school": "Needham Broughton High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001839",
    },
    {
        "school": "Bugg Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001840",
    },
    {
        "school": "Carnage Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001841",
    },
    {
        "school": "Carroll Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001842",
    },
    {
        "school": "Cary Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001843",
    },
    {
        "school": "Cary High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001844",
    },
    {
        "school": "Combs Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001846",
    },
    {
        "school": "Conn Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001847",
    },
    {
        "school": "Daniels Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001849",
    },
    {
        "school": "Douglas Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001851",
    },
    {
        "school": "Reedy Creek Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001852",
    },
    {
        "school": "East Garner Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001853",
    },
    {
        "school": "East Millbrook Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001854",
    },
    {
        "school": "East Wake High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001855",
    },
    {
        "school": "Farmington Woods Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001857",
    },
    {
        "school": "Fuller Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001858",
    },
    {
        "school": "Fuquay-Varina Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001859",
    },
    {
        "school": "Fuquay-Varina Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001860",
    },
    {
        "school": "Fuquay-Varina High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001861",
    },
    {
        "school": "Garner High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001863",
    },
    {
        "school": "Green Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001864",
    },
    {
        "school": "Hunter Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001866",
    },
    {
        "school": "Jeffreys Grove Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001867",
    },
    {
        "school": "Joyner Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001868",
    },
    {
        "school": "Kingswood Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001869",
    },
    {
        "school": "Knightdale Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001870",
    },
    {
        "school": "Lacy Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001871",
    },
    {
        "school": "Ligon Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001872",
    },
    {
        "school": "Lincoln Heights Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001873",
    },
    {
        "school": "Lockhart Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001874",
    },
    {
        "school": "Lynn Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001876",
    },
    {
        "school": "Martin Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001877",
    },
    {
        "school": "Millbrook Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001878",
    },
    {
        "school": "Millbrook High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001879",
    },
    {
        "school": "North Garner Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001882",
    },
    {
        "school": "North Ridge Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001883",
    },
    {
        "school": "Northwoods Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001884",
    },
    {
        "school": "Olds Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001885",
    },
    {
        "school": "Poe Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001887",
    },
    {
        "school": "Powell Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001888",
    },
    {
        "school": "Rolesville Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001890",
    },
    {
        "school": "Root Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001891",
    },
    {
        "school": "Sanderson High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001892",
    },
    {
        "school": "Smith Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001894",
    },
    {
        "school": "Stough Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001895",
    },
    {
        "school": "Swift Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001896",
    },
    {
        "school": "Underwood Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001897",
    },
    {
        "school": "Vance Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001898",
    },
    {
        "school": "Vandora Springs Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001899",
    },
    {
        "school": "Wake Forest Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001900",
    },
    {
        "school": "Wake Forest High School",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001901",
    },
    {
        "school": "Wake Forest Middle School",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001902",
    },
    {
        "school": "Washington Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001903",
    },
    {
        "school": "Wendell Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001904",
    },
    {
        "school": "West Cary Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001905",
    },
    {
        "school": "West Millbrook Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001906",
    },
    {
        "school": "Wilburn Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001908",
    },
    {
        "school": "Wiley Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001909",
    },
    {
        "school": "Willow Springs Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001910",
    },
    {
        "school": "York Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001911",
    },
    {
        "school": "Zebulon Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001912",
    },
    {
        "school": "Zebulon Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472001913",
    },
    {
        "school": "Baileywick Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002006",
    },
    {
        "school": "Davis Drive Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002031",
    },
    {
        "school": "Hilburn Drive Academy",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002033",
    },
    {
        "school": "Holly Springs Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002035",
    },
    {
        "school": "Heritage Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002038",
    },
    {
        "school": "Enloe High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002055",
    },
    {
        "school": "Mount Vernon",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370472002104",
    },
    {
        "school": "Carver Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002187",
    },
    {
        "school": "Phillips High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370472002188",
    },
    {
        "school": "Brassfield Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002221",
    },
    {
        "school": "Fox Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002222",
    },
    {
        "school": "Penny Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002223",
    },
    {
        "school": "Longview",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370472002254",
    },
    {
        "school": "East Wake Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002255",
    },
    {
        "school": "Lead Mine Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002281",
    },
    {
        "school": "Rand Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002282",
    },
    {
        "school": "Leesville Road Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002317",
    },
    {
        "school": "Morrisville Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002318",
    },
    {
        "school": "Olive Chapel Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002354",
    },
    {
        "school": "Southeast Raleigh High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002355",
    },
    {
        "school": "Timber Drive Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002356",
    },
    {
        "school": "Partnership Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002414",
    },
    {
        "school": "Dillard Drive Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002487",
    },
    {
        "school": "Dillard Drive Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002488",
    },
    {
        "school": "Green Hope High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002489",
    },
    {
        "school": "Lufkin Road Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002490",
    },
    {
        "school": "Reedy Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002491",
    },
    {
        "school": "Wakefield Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002492",
    },
    {
        "school": "Wildwood Forest Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002493",
    },
    {
        "school": "Centennial Campus Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002555",
    },
    {
        "school": "Green Hope Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002556",
    },
    {
        "school": "Middle Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002557",
    },
    {
        "school": "Salem Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002558",
    },
    {
        "school": "Wakefield Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002559",
    },
    {
        "school": "Wakefield High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002560",
    },
    {
        "school": "Yates Mill Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472002561",
    },
    {
        "school": "Aurelian Springs Institute of Global Lea",
        "district": "Halifax County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370195000856",
    },
    {
        "school": "Scotland Neck Elementary Leadership Acad",
        "district": "Halifax County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370195000859",
    },
    {
        "school": "Enfield Middle S.T.E.A.M. Academy",
        "district": "Halifax County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370195000861",
    },
    {
        "school": "Everetts Elementary S.T.E.M. Academy",
        "district": "Halifax County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370195000862",
    },
    {
        "school": "Hollister Elementary Leadership Academy",
        "district": "Halifax County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370195000863",
    },
    {
        "school": "Inborden Elementary S.T.E.A.M. Academy",
        "district": "Halifax County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370195000864",
    },
    {
        "school": "Northwest Halifax Collegiate and Technic",
        "district": "Halifax County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370195000866",
    },
    {
        "school": "Pittman Elementary Leadership Academy",
        "district": "Halifax County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370195000867",
    },
    {
        "school": "William R Davie Middle S.T.E.M. Academy",
        "district": "Halifax County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370195000872",
    },
    {
        "school": "Southeast Halifax Collegiate Prep Academ",
        "district": "Halifax County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370195002157",
    },
    {
        "school": "Chaloner Middle School",
        "district": "Roanoke Rapids City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370390001562",
    },
    {
        "school": "Roanoke Rapids High School",
        "district": "Roanoke Rapids City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370390001564",
    },
    {
        "school": "Manning Elementary School",
        "district": "Roanoke Rapids City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370390001565",
    },
    {
        "school": "Belmont Elementary School",
        "district": "Roanoke Rapids City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370390002115",
    },
    {
        "school": "Weldon Elementary Global Academy",
        "district": "Weldon City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370489001965",
    },
    {
        "school": "Weldon Middle",
        "district": "Weldon City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370489002116",
    },
    {
        "school": "KIPP Gaston College Preparatory",
        "district": "Gaston College Preparatory",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370012302597",
    },
    {
        "school": "Conway Middle",
        "district": "Northampton County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370342001407",
    },
    {
        "school": "Gaston Elementary",
        "district": "Northampton County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370342001410",
    },
    {
        "school": "Northampton County High School",
        "district": "Northampton County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370342001412",
    },
    {
        "school": "Willis Hare Elementary",
        "district": "Northampton County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370342001414",
    },
    {
        "school": "Richmond Early College High",
        "district": "Richmond County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387002916",
    },
    {
        "school": "Ashley Chapel Educational Center",
        "district": "Richmond County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370387000788",
    },
    {
        "school": "Ellerbe Middle",
        "district": "Richmond County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387001549",
    },
    {
        "school": "Fairview Heights Elementary",
        "district": "Richmond County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387001550",
    },
    {
        "school": "Hamlet Middle",
        "district": "Richmond County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387001551",
    },
    {
        "school": "L J Bell Elementary",
        "district": "Richmond County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387001553",
    },
    {
        "school": "Mineral Springs Elementary",
        "district": "Richmond County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387001555",
    },
    {
        "school": "Monroe Avenue Elementary",
        "district": "Richmond County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387001556",
    },
    {
        "school": "Richmond Senior High",
        "district": "Richmond County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387001557",
    },
    {
        "school": "Rockingham Middle",
        "district": "Richmond County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387001558",
    },
    {
        "school": "Cordova Middle",
        "district": "Richmond County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387001559",
    },
    {
        "school": "West Rockingham Elementary",
        "district": "Richmond County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387001561",
    },
    {
        "school": "Washington Street Elementary",
        "district": "Richmond County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387002278",
    },
    {
        "school": "Edgecombe Early College High",
        "district": "Edgecombe County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132002762",
    },
    {
        "school": "Nash Central High",
        "district": "Nash-Rocky Mount Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327002643",
    },
    {
        "school": "NRM Early College High School",
        "district": "Nash-Rocky Mount Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327002644",
    },
    {
        "school": "G W Bulluck Elementary",
        "district": "Edgecombe County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132000551",
    },
    {
        "school": "G W Carver Elementary",
        "district": "Edgecombe County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132000552",
    },
    {
        "school": "Coker-Wimberly Elementary",
        "district": "Edgecombe County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132000553",
    },
    {
        "school": "North Edgecombe High",
        "district": "Edgecombe County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132000555",
    },
    {
        "school": "Phillips Middle",
        "district": "Edgecombe County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132000556",
    },
    {
        "school": "South Edgecombe Middle",
        "district": "Edgecombe County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132000558",
    },
    {
        "school": "SouthWest Edgecombe High",
        "district": "Edgecombe County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132000559",
    },
    {
        "school": "West Edgecombe Middle",
        "district": "Edgecombe County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132000560",
    },
    {
        "school": "Stocks Elementary",
        "district": "Edgecombe County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132001767",
    },
    {
        "school": "Princeville Elementary",
        "district": "Edgecombe County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132001769",
    },
    {
        "school": "Tarboro High",
        "district": "Edgecombe County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132001770",
    },
    {
        "school": "Baskerville Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327000703",
    },
    {
        "school": "D S Johnson Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327000725",
    },
    {
        "school": "J W Parker Middle",
        "district": "Nash-Rocky Mount Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327000752",
    },
    {
        "school": "Rocky Mount Preparatory",
        "district": "Rocky Mount Preparatory",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003402334",
    },
    {
        "school": "Englewood Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327000726",
    },
    {
        "school": "G R Edwards Middle",
        "district": "Nash-Rocky Mount Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327000736",
    },
    {
        "school": "Rocky Mount High",
        "district": "Nash-Rocky Mount Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327000763",
    },
    {
        "school": "Tar River Academy",
        "district": "Nash-Rocky Mount Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370327001218",
    },
    {
        "school": "Bailey Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001341",
    },
    {
        "school": "Benvenue Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001342",
    },
    {
        "school": "Cedar Grove Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001344",
    },
    {
        "school": "Nash Central Middle",
        "district": "Nash-Rocky Mount Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001345",
    },
    {
        "school": "Coopers Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001346",
    },
    {
        "school": "Middlesex Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001348",
    },
    {
        "school": "Nashville Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001349",
    },
    {
        "school": "Northern Nash High",
        "district": "Nash-Rocky Mount Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001351",
    },
    {
        "school": "Red Oak Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001352",
    },
    {
        "school": "Southern Nash Middle",
        "district": "Nash-Rocky Mount Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001353",
    },
    {
        "school": "Southern Nash High",
        "district": "Nash-Rocky Mount Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001354",
    },
    {
        "school": "Spring Hope Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001356",
    },
    {
        "school": "Swift Creek Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001357",
    },
    {
        "school": "Williford Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327001358",
    },
    {
        "school": "M B Hubbard Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327002100",
    },
    {
        "school": "Red Oak Middle",
        "district": "Nash-Rocky Mount Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327002400",
    },
    {
        "school": "Winstead Avenue Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327002401",
    },
    {
        "school": "Millbridge Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405002792",
    },
    {
        "school": "Shive Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405002835",
    },
    {
        "school": "Bostian Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001610",
    },
    {
        "school": "Erwin Middle",
        "district": "Rowan-Salisbury Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001611",
    },
    {
        "school": "China Grove Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001612",
    },
    {
        "school": "China Grove Middle",
        "district": "Rowan-Salisbury Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001613",
    },
    {
        "school": "Corriher Lipe Middle",
        "district": "Rowan-Salisbury Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001615",
    },
    {
        "school": "East Rowan High",
        "district": "Rowan-Salisbury Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001616",
    },
    {
        "school": "Enochville Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001617",
    },
    {
        "school": "Faith Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001618",
    },
    {
        "school": "Granite Quarry Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001619",
    },
    {
        "school": "Hurley Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001620",
    },
    {
        "school": "Knollwood Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001621",
    },
    {
        "school": "Landis Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001622",
    },
    {
        "school": "Morgan Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001623",
    },
    {
        "school": "Mt Ulla Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001624",
    },
    {
        "school": "North Rowan High",
        "district": "Rowan-Salisbury Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001625",
    },
    {
        "school": "North Rowan Middle",
        "district": "Rowan-Salisbury Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001626",
    },
    {
        "school": "North Rowan Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001627",
    },
    {
        "school": "Rockwell Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001628",
    },
    {
        "school": "South Rowan High",
        "district": "Rowan-Salisbury Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001629",
    },
    {
        "school": "West Rowan High",
        "district": "Rowan-Salisbury Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001630",
    },
    {
        "school": "West Rowan Middle",
        "district": "Rowan-Salisbury Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405001631",
    },
    {
        "school": "Overton Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405002249",
    },
    {
        "school": "Isenberg Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405002250",
    },
    {
        "school": "Dole Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405002251",
    },
    {
        "school": "Knox Middle",
        "district": "Rowan-Salisbury Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405002252",
    },
    {
        "school": "Salisbury High",
        "district": "Rowan-Salisbury Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405002253",
    },
    {
        "school": "Henderson High",
        "district": "Rowan-Salisbury Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370405002409",
    },
    {
        "school": "Southeast Middle",
        "district": "Rowan-Salisbury Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405002543",
    },
    {
        "school": "Southern Lee High School",
        "district": "Lee County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256002781",
    },
    {
        "school": "Broadway Elementary",
        "district": "Lee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256001074",
    },
    {
        "school": "Deep River Elementary",
        "district": "Lee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256001075",
    },
    {
        "school": "East Lee Middle",
        "district": "Lee County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256001076",
    },
    {
        "school": "Floyd L Knight Children Center",
        "district": "Lee County Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370256001077",
    },
    {
        "school": "Lee County High",
        "district": "Lee County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256001080",
    },
    {
        "school": "West Lee Middle",
        "district": "Lee County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256001085",
    },
    {
        "school": "Bragg Street Academy",
        "district": "Lee County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370256001584",
    },
    {
        "school": "J Glenn Edwards Elementary",
        "district": "Lee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256002209",
    },
    {
        "school": "J R Ingram Jr Elementary",
        "district": "Lee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256002210",
    },
    {
        "school": "Greenwood Elementary",
        "district": "Lee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256002305",
    },
    {
        "school": "BT Bullock Elementary",
        "district": "Lee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256002390",
    },
    {
        "school": "Tramway Elementary",
        "district": "Lee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256002391",
    },
    {
        "school": "Bethware Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002707",
    },
    {
        "school": "Turning Point Academy",
        "district": "Cleveland County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370090002708",
    },
    {
        "school": "East Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002709",
    },
    {
        "school": "Graham Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002710",
    },
    {
        "school": "Grover Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002711",
    },
    {
        "school": "James Love Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002712",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002713",
    },
    {
        "school": "Kings Mountain High",
        "district": "Cleveland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002714",
    },
    {
        "school": "Kings Mountain Intermediate",
        "district": "Cleveland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002715",
    },
    {
        "school": "Kings Mountain Middle",
        "district": "Cleveland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002716",
    },
    {
        "school": "Marion Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002717",
    },
    {
        "school": "North Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002718",
    },
    {
        "school": "North Shelby",
        "district": "Cleveland County Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370090002719",
    },
    {
        "school": "Shelby High",
        "district": "Cleveland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002720",
    },
    {
        "school": "Shelby Middle",
        "district": "Cleveland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002721",
    },
    {
        "school": "West Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002722",
    },
    {
        "school": "Boiling Springs Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090000335",
    },
    {
        "school": "Burns High",
        "district": "Cleveland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090000336",
    },
    {
        "school": "Burns Middle",
        "district": "Cleveland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090000337",
    },
    {
        "school": "Casar Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090000338",
    },
    {
        "school": "Crest High",
        "district": "Cleveland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090000340",
    },
    {
        "school": "Crest Middle",
        "district": "Cleveland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090000341",
    },
    {
        "school": "Shelby Intermediate",
        "district": "Cleveland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090000343",
    },
    {
        "school": "Fallston Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090000344",
    },
    {
        "school": "Township Three Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090000348",
    },
    {
        "school": "Washington Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090000350",
    },
    {
        "school": "Union Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002289",
    },
    {
        "school": "Springmore Elementary",
        "district": "Cleveland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090002509",
    },
    {
        "school": "Cameron Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001316",
    },
    {
        "school": "The Academy of Moore County",
        "district": "The Academy of Moore County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370003302332",
    },
    {
        "school": "STARS Charter",
        "district": "Sandhills Theatre Arts Renaiss",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009102473",
    },
    {
        "school": "Aberdeen Primary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001314",
    },
    {
        "school": "Aberdeen Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001315",
    },
    {
        "school": "Carthage Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001317",
    },
    {
        "school": "Elise Middle",
        "district": "Moore County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001318",
    },
    {
        "school": "Highfalls Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001319",
    },
    {
        "school": "North Moore High",
        "district": "Moore County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001320",
    },
    {
        "school": "Pinecrest High",
        "district": "Moore County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001321",
    },
    {
        "school": "Robbins Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001324",
    },
    {
        "school": "Sandhills Farm Life Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001325",
    },
    {
        "school": "Southern Pines Primary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001326",
    },
    {
        "school": "Southern Pines Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001327",
    },
    {
        "school": "Union Pines High",
        "district": "Moore County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001328",
    },
    {
        "school": "Vass-Lakeview Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001329",
    },
    {
        "school": "West End Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001330",
    },
    {
        "school": "The Community Learning Center @ Pinckney",
        "district": "Moore County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370309001929",
    },
    {
        "school": "New Century Middle",
        "district": "Moore County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309002329",
    },
    {
        "school": "Pinehurst Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309002330",
    },
    {
        "school": "West Pine Middle",
        "district": "Moore County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309002331",
    },
    {
        "school": "Southern Middle",
        "district": "Moore County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309002533",
    },
    {
        "school": "Westmoore Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309001331",
    },
    {
        "school": "Pine Lake Preparatory",
        "district": "Pine Lake Preparatory",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370014502926",
    },
    {
        "school": "Lake Norman High",
        "district": "Iredell-Statesville Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231002633",
    },
    {
        "school": "Third Creek Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231002634",
    },
    {
        "school": "Collaborative College for Technology",
        "district": "Iredell-Statesville Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231002776",
    },
    {
        "school": "Woodland Heights Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231002778",
    },
    {
        "school": "East Mooresville Intermediate",
        "district": "Mooresville Graded School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370312002779",
    },
    {
        "school": "American Renaissance School",
        "district": "American Renaissance School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370008602465",
    },
    {
        "school": "Success Institute Charter",
        "district": "Success Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370010602527",
    },
    {
        "school": "East Iredell Middle",
        "district": "Iredell-Statesville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000807",
    },
    {
        "school": "Brawley Middle",
        "district": "Iredell-Statesville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000981",
    },
    {
        "school": "Celeste Henkel Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000982",
    },
    {
        "school": "Central Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000983",
    },
    {
        "school": "Cool Spring Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000984",
    },
    {
        "school": "East Iredell Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000985",
    },
    {
        "school": "Harmony Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000987",
    },
    {
        "school": "Mount Mourne School",
        "district": "Iredell-Statesville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000989",
    },
    {
        "school": "North Iredell High",
        "district": "Iredell-Statesville Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000990",
    },
    {
        "school": "Scotts Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000991",
    },
    {
        "school": "Sharon Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000992",
    },
    {
        "school": "Shepherd Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000993",
    },
    {
        "school": "South Iredell High",
        "district": "Iredell-Statesville Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000994",
    },
    {
        "school": "Troutman Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000995",
    },
    {
        "school": "Troutman Middle",
        "district": "Iredell-Statesville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000996",
    },
    {
        "school": "Union Grove Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000997",
    },
    {
        "school": "West Iredell High",
        "district": "Iredell-Statesville Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231000999",
    },
    {
        "school": "West Iredell Middle",
        "district": "Iredell-Statesville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231001000",
    },
    {
        "school": "Lake Norman Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231001880",
    },
    {
        "school": "N B Mills Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231002298",
    },
    {
        "school": "Northview School",
        "district": "Iredell-Statesville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231002299",
    },
    {
        "school": "North Iredell Middle",
        "district": "Iredell-Statesville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231002300",
    },
    {
        "school": "Pressly School",
        "district": "Iredell-Statesville Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370231002301",
    },
    {
        "school": "Statesville Middle",
        "district": "Iredell-Statesville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231002302",
    },
    {
        "school": "Statesville High",
        "district": "Iredell-Statesville Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231002303",
    },
    {
        "school": "Lakeshore Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231002463",
    },
    {
        "school": "Lakeshore Middle",
        "district": "Iredell-Statesville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231002528",
    },
    {
        "school": "NF Woods Campus",
        "district": "Mooresville Graded School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370312000808",
    },
    {
        "school": "Mooresville Middle",
        "district": "Mooresville Graded School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370312001332",
    },
    {
        "school": "Mooresville High School",
        "district": "Mooresville Graded School District",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370312001333",
    },
    {
        "school": "Park View Elementary",
        "district": "Mooresville Graded School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370312001335",
    },
    {
        "school": "South Elementary",
        "district": "Mooresville Graded School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370312001336",
    },
    {
        "school": "Mooresville Intermediate",
        "district": "Mooresville Graded School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370312002464",
    },
    {
        "school": "Moyock Middle",
        "district": "Currituck County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370108002627",
    },
    {
        "school": "Central Elementary",
        "district": "Currituck County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370108000448",
    },
    {
        "school": "Currituck County High",
        "district": "Currituck County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370108000449",
    },
    {
        "school": "W T Griggs Elementary",
        "district": "Currituck County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370108000450",
    },
    {
        "school": "Currituck County Middle",
        "district": "Currituck County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370108000451",
    },
    {
        "school": "Knotts Island Elementary",
        "district": "Currituck County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370108000452",
    },
    {
        "school": "Moyock Elementary",
        "district": "Currituck County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370108000453",
    },
    {
        "school": "Shawboro Elementary School",
        "district": "Currituck County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370108002374",
    },
    {
        "school": "Washington Montessori",
        "district": "Washington Montessori",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370010102502",
    },
    {
        "school": "Bath Elementary",
        "district": "Beaufort County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033000091",
    },
    {
        "school": "S W Snowden Elementary",
        "district": "Beaufort County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033000098",
    },
    {
        "school": "B C Ed Tech Center",
        "district": "Beaufort County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370033001360",
    },
    {
        "school": "Eastern Elementary",
        "district": "Beaufort County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033001922",
    },
    {
        "school": "John C Tayloe Elementary",
        "district": "Beaufort County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033001923",
    },
    {
        "school": "John Small Elementary",
        "district": "Beaufort County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033001924",
    },
    {
        "school": "P S Jones Middle",
        "district": "Beaufort County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033001925",
    },
    {
        "school": "Washington High",
        "district": "Beaufort County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033001926",
    },
    {
        "school": "Chocowinity Primary",
        "district": "Beaufort County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033002106",
    },
    {
        "school": "Northside High",
        "district": "Beaufort County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033002224",
    },
    {
        "school": "Chocowinity Middle",
        "district": "Beaufort County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033002503",
    },
    {
        "school": "Southside High",
        "district": "Beaufort County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033002504",
    },
    {
        "school": "Northeast Elementary",
        "district": "Beaufort County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033002568",
    },
    {
        "school": "Jessie Mae Monroe Elementary",
        "district": "Brunswick County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042002621",
    },
    {
        "school": "Wilmington Preparatory Academy",
        "district": "Wilmington Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370014102927",
    },
    {
        "school": "Murrayville Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002787",
    },
    {
        "school": "Edwin A Anderson Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002822",
    },
    {
        "school": "Wilmington Early College High",
        "district": "New Hanover County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002915",
    },
    {
        "school": "Heide Trask High",
        "district": "Pender County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357002646",
    },
    {
        "school": "Malpass Corner Elementary",
        "district": "Pender County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357000895",
    },
    {
        "school": "Burgaw Elementary",
        "district": "Pender County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357001462",
    },
    {
        "school": "Burgaw Middle",
        "district": "Pender County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357001463",
    },
    {
        "school": "Pender High",
        "district": "Pender County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357001466",
    },
    {
        "school": "Penderlea Elementary",
        "district": "Pender County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357001467",
    },
    {
        "school": "Rocky Point Elementary",
        "district": "Pender County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357001468",
    },
    {
        "school": "Topsail High",
        "district": "Pender County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357001469",
    },
    {
        "school": "Topsail Middle",
        "district": "Pender County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357001470",
    },
    {
        "school": "West Pender Middle",
        "district": "Pender County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357001471",
    },
    {
        "school": "South Topsail Elementary",
        "district": "Pender County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357002046",
    },
    {
        "school": "North Topsail Elementary",
        "district": "Pender County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357002346",
    },
    {
        "school": "Cape Fear Elementary",
        "district": "Pender County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357002601",
    },
    {
        "school": "Cape Fear Middle",
        "district": "Pender County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357002602",
    },
    {
        "school": "Charter Day School",
        "district": "Charter Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370010202506",
    },
    {
        "school": "Supply Elementary",
        "district": "Brunswick County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042000053",
    },
    {
        "school": "Bolivia Elementary",
        "district": "Brunswick County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042000122",
    },
    {
        "school": "Leland Middle",
        "district": "Brunswick County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042000123",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Brunswick County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042000124",
    },
    {
        "school": "North Brunswick High",
        "district": "Brunswick County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042000125",
    },
    {
        "school": "Shallotte Middle",
        "district": "Brunswick County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042000126",
    },
    {
        "school": "South Brunswick High",
        "district": "Brunswick County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042000127",
    },
    {
        "school": "Southport Elementary",
        "district": "Brunswick County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042000129",
    },
    {
        "school": "Union Elementary",
        "district": "Brunswick County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042000130",
    },
    {
        "school": "Waccamaw",
        "district": "Brunswick County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042000131",
    },
    {
        "school": "West Brunswick High",
        "district": "Brunswick County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042000132",
    },
    {
        "school": "The COAST",
        "district": "Brunswick County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370042000980",
    },
    {
        "school": "Belville Elementary",
        "district": "Brunswick County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042001771",
    },
    {
        "school": "South Brunswick Middle",
        "district": "Brunswick County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042002152",
    },
    {
        "school": "Virginia Williamson Elem",
        "district": "Brunswick County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042002428",
    },
    {
        "school": "Cape Fear Center for Inquiry",
        "district": "Cape Fear Center for Inquiry",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370010802534",
    },
    {
        "school": "R Freeman Sch of Engineering",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001366",
    },
    {
        "school": "Bradley Creek Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001367",
    },
    {
        "school": "Carolina Beach Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001368",
    },
    {
        "school": "College Park Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001369",
    },
    {
        "school": "Edwin A Alderman Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001371",
    },
    {
        "school": "Emma B Trask Middle",
        "district": "New Hanover County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001372",
    },
    {
        "school": "Emsley A Laney High",
        "district": "New Hanover County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001373",
    },
    {
        "school": "Forest Hills Global Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001374",
    },
    {
        "school": "The International School at Gregory",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001375",
    },
    {
        "school": "John J Blair Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001378",
    },
    {
        "school": "John T Hoggard High",
        "district": "New Hanover County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001379",
    },
    {
        "school": "M C S Noble Middle",
        "district": "New Hanover County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001381",
    },
    {
        "school": "Mary C Williams Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001382",
    },
    {
        "school": "New Hanover High",
        "district": "New Hanover County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001384",
    },
    {
        "school": "Ogden Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001385",
    },
    {
        "school": "Pine Valley Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001387",
    },
    {
        "school": "Roland-Grise Middle",
        "district": "New Hanover County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001388",
    },
    {
        "school": "Sunset Park Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001390",
    },
    {
        "school": "A H Snipes Academy of Arts/Des",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001392",
    },
    {
        "school": "Williston Middle",
        "district": "New Hanover County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001394",
    },
    {
        "school": "Winter Park Model Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001395",
    },
    {
        "school": "Wrightsboro Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001396",
    },
    {
        "school": "Wrightsville Beach Elem",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333001397",
    },
    {
        "school": "Heyward C Bellamy Elem",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002101",
    },
    {
        "school": "Myrtle Grove Middle",
        "district": "New Hanover County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002212",
    },
    {
        "school": "J. C. Roe Center",
        "district": "New Hanover County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370333002213",
    },
    {
        "school": "Holly Tree Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002335",
    },
    {
        "school": "Dr Hubert Eaton Sr Elem",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002336",
    },
    {
        "school": "Dr John Codington Elem",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002337",
    },
    {
        "school": "Charles P Murray Middle",
        "district": "New Hanover County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002594",
    },
    {
        "school": "Eugene Ashley High",
        "district": "New Hanover County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002595",
    },
    {
        "school": "Walter L Parsley Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333002596",
    },
    {
        "school": "Sallie B Howard School",
        "district": "Sallie B Howard School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370004902365",
    },
    {
        "school": "B O Barnes Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502001992",
    },
    {
        "school": "Beddingfield High",
        "district": "Wilson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502001994",
    },
    {
        "school": "Frederick Douglass Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502001995",
    },
    {
        "school": "Elm City Middle",
        "district": "Wilson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502001996",
    },
    {
        "school": "Fike High",
        "district": "Wilson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502001998",
    },
    {
        "school": "Gardners Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502001999",
    },
    {
        "school": "James Hunt High",
        "district": "Wilson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002000",
    },
    {
        "school": "Lee Woodard Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002001",
    },
    {
        "school": "Lucama Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002002",
    },
    {
        "school": "Margaret Hearne Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002003",
    },
    {
        "school": "New Hope Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002004",
    },
    {
        "school": "Rock Ridge Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002005",
    },
    {
        "school": "Speight Middle",
        "district": "Wilson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002007",
    },
    {
        "school": "Springfield Middle",
        "district": "Wilson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002008",
    },
    {
        "school": "Stantonsburg Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002009",
    },
    {
        "school": "Vinson-Bynum Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002010",
    },
    {
        "school": "Wells Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002011",
    },
    {
        "school": "Winstead Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002012",
    },
    {
        "school": "Charles H Darden Middle",
        "district": "Wilson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002061",
    },
    {
        "school": "Forest Hills Middle",
        "district": "Wilson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002191",
    },
    {
        "school": "Toisnot Middle",
        "district": "Wilson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002200",
    },
    {
        "school": "Milton M Daniels Learning Center",
        "district": "Wilson County Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370502002423",
    },
    {
        "school": "Vick Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502002564",
    },
    {
        "school": "William Ellis Middle",
        "district": "Davie County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370117002816",
    },
    {
        "school": "Davie County Early College High",
        "district": "Davie County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370117002827",
    },
    {
        "school": "The Arts Based School",
        "district": "Arts Based School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370012602611",
    },
    {
        "school": "Middle College of Forsyth Cnty",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002666",
    },
    {
        "school": "Winston-Salem Preparatory Acad",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002729",
    },
    {
        "school": "East Forsyth Middle School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002763",
    },
    {
        "school": "Main Street Academy",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370150002764",
    },
    {
        "school": "Ronald W Reagan High School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002765",
    },
    {
        "school": "Yadkin Success Academy",
        "district": "Yadkin County Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370504002659",
    },
    {
        "school": "Yadkin Early College",
        "district": "Yadkin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504002912",
    },
    {
        "school": "Cooleemee Elementary",
        "district": "Davie County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370117000485",
    },
    {
        "school": "Davie County High",
        "district": "Davie County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370117000486",
    },
    {
        "school": "Mocksville Elementary",
        "district": "Davie County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370117000487",
    },
    {
        "school": "Pinebrook Elementary",
        "district": "Davie County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370117000489",
    },
    {
        "school": "Shady Grove Elementary",
        "district": "Davie County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370117000490",
    },
    {
        "school": "William R Davie Elementary",
        "district": "Davie County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370117000491",
    },
    {
        "school": "North Davie Middle",
        "district": "Davie County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370117002065",
    },
    {
        "school": "South Davie Middle",
        "district": "Davie County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370117002066",
    },
    {
        "school": "Cornatzer Elementary",
        "district": "Davie County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370117002516",
    },
    {
        "school": "Quality Education Academy",
        "district": "Quality Education Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370002502096",
    },
    {
        "school": "Carter G. Woodson School",
        "district": "Carter G Woodson School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370002702112",
    },
    {
        "school": "Forsyth Academy",
        "district": "Forsyth Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370008302452",
    },
    {
        "school": "Bolton Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000588",
    },
    {
        "school": "Brunson Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000590",
    },
    {
        "school": "Career Center",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NC",
        "nces_id": "370150000591",
    },
    {
        "school": "Carver High",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000592",
    },
    {
        "school": "Cash Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000593",
    },
    {
        "school": "Childrens Center",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370150000594",
    },
    {
        "school": "Clemmons Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000595",
    },
    {
        "school": "East Forsyth High",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000600",
    },
    {
        "school": "Easton Elementary School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000601",
    },
    {
        "school": "Forest Park Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000603",
    },
    {
        "school": "Robert B Glenn High School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000604",
    },
    {
        "school": "Griffith Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000605",
    },
    {
        "school": "Hall-Woodward Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000607",
    },
    {
        "school": "Hanes Magnet School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000608",
    },
    {
        "school": "Ibraham Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000610",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000611",
    },
    {
        "school": "Kernersville Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000613",
    },
    {
        "school": "Kimberley Park Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000615",
    },
    {
        "school": "Konnoak Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000616",
    },
    {
        "school": "Diggs-Latham Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000617",
    },
    {
        "school": "Lewisville Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000618",
    },
    {
        "school": "Lowrance Middle",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370150000619",
    },
    {
        "school": "Mineral Springs Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000620",
    },
    {
        "school": "Mineral Springs Middle",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000621",
    },
    {
        "school": "Moore Magnet Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000622",
    },
    {
        "school": "Mount Tabor High School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000623",
    },
    {
        "school": "North Forsyth High",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000624",
    },
    {
        "school": "Northwest Middle",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000625",
    },
    {
        "school": "Old Richmond Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000627",
    },
    {
        "school": "Old Town Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000628",
    },
    {
        "school": "Paisley IB Magnet School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000630",
    },
    {
        "school": "Parkland High",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000631",
    },
    {
        "school": "Philo-Hill Magnet Academy",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000633",
    },
    {
        "school": "R J Reynolds High",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000634",
    },
    {
        "school": "Rural Hall Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000635",
    },
    {
        "school": "Sedge Garden Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000636",
    },
    {
        "school": "Sherwood Forest Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000637",
    },
    {
        "school": "South Fork Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000639",
    },
    {
        "school": "Carter High School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370150000640",
    },
    {
        "school": "Southwest Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000641",
    },
    {
        "school": "Speas Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000642",
    },
    {
        "school": "Union Cross Traditional Acad",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000643",
    },
    {
        "school": "Vienna Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000644",
    },
    {
        "school": "Walkertown Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000645",
    },
    {
        "school": "Walkertown Middle",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000646",
    },
    {
        "school": "West Forsyth High",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000647",
    },
    {
        "school": "Whitaker Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000648",
    },
    {
        "school": "Wiley Magnet Middle",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150000649",
    },
    {
        "school": "North Hills Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002091",
    },
    {
        "school": "J F Kennedy High",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002194",
    },
    {
        "school": "Piney Grove Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002262",
    },
    {
        "school": "The Downtown School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002293",
    },
    {
        "school": "Kernersville Middle",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002378",
    },
    {
        "school": "Meadowlark Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002379",
    },
    {
        "school": "Southeast Middle",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002380",
    },
    {
        "school": "Ashley Academy",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002446",
    },
    {
        "school": "Clemmons Middle School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002447",
    },
    {
        "school": "Cook Literacy Model School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002448",
    },
    {
        "school": "Thomas Jefferson Middle",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002449",
    },
    {
        "school": "Meadowlark Middle",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002450",
    },
    {
        "school": "Petree Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002451",
    },
    {
        "school": "Homebound/ Hospital Education",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002518",
    },
    {
        "school": "Ward Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002519",
    },
    {
        "school": "Gibson Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150002578",
    },
    {
        "school": "Chestnut Grove Middle",
        "district": "Stokes County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001730",
    },
    {
        "school": "Germanton Elementary",
        "district": "Stokes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001732",
    },
    {
        "school": "King Elementary",
        "district": "Stokes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001733",
    },
    {
        "school": "Mount Olive Elementary",
        "district": "Stokes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001734",
    },
    {
        "school": "Lawsonville Elementary",
        "district": "Stokes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001735",
    },
    {
        "school": "Nancy Reynolds Elementary",
        "district": "Stokes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001736",
    },
    {
        "school": "North Stokes High",
        "district": "Stokes County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001737",
    },
    {
        "school": "Pine Hall Elementary",
        "district": "Stokes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001738",
    },
    {
        "school": "Pinnacle Elementary",
        "district": "Stokes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001739",
    },
    {
        "school": "Sandy Ridge  Elementary",
        "district": "Stokes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001740",
    },
    {
        "school": "South Stokes High",
        "district": "Stokes County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001741",
    },
    {
        "school": "Southeastern Middle",
        "district": "Stokes County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001742",
    },
    {
        "school": "London Elementary",
        "district": "Stokes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001743",
    },
    {
        "school": "Walnut Cove Elementary",
        "district": "Stokes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438001744",
    },
    {
        "school": "Meadowbrook Academy",
        "district": "Stokes County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370438002411",
    },
    {
        "school": "Piney Grove Middle",
        "district": "Stokes County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438002484",
    },
    {
        "school": "West Stokes High",
        "district": "Stokes County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438002485",
    },
    {
        "school": "Boonville Elementary",
        "district": "Yadkin County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504002013",
    },
    {
        "school": "Courtney Elementary",
        "district": "Yadkin County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504002014",
    },
    {
        "school": "East Bend Elementary",
        "district": "Yadkin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504002015",
    },
    {
        "school": "Fall Creek Elementary",
        "district": "Yadkin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504002016",
    },
    {
        "school": "Forbush High",
        "district": "Yadkin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504002018",
    },
    {
        "school": "Jonesville Elementary",
        "district": "Yadkin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504002019",
    },
    {
        "school": "Starmount High",
        "district": "Yadkin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504002020",
    },
    {
        "school": "West Yadkin Elementary",
        "district": "Yadkin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504002021",
    },
    {
        "school": "Yadkinville Elementary",
        "district": "Yadkin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504002022",
    },
    {
        "school": "Forbush Elementary",
        "district": "Yadkin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504002214",
    },
    {
        "school": "RHAME ELEMENTARY SCHOOL",
        "district": "BOWMAN CO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380320000548",
    },
    {
        "school": "CARL BEN EIELSON MIDDLE SCHOOL",
        "district": "FARGO 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000186",
    },
    {
        "school": "KENNEDY ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000206",
    },
    {
        "school": "NEW ROCKFORD-SHEYENNE ELEMENTARY SCHOOL",
        "district": "NEW ROCKFORD-SHEYENNE 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005900490",
    },
    {
        "school": "NEW ROCKFORD-SHEYENNE HIGH SCHOOL",
        "district": "NEW ROCKFORD-SHEYENNE 2",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005900491",
    },
    {
        "school": "LITCHVILLE-MARION ELEMENTARY SCHOOL",
        "district": "LITCHVILLE-MARION 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005700376",
    },
    {
        "school": "LITCHVILLE-MARION HIGH SCHOOL",
        "district": "LITCHVILLE-MARION 46",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005700399",
    },
    {
        "school": "CARRINGTON ELEMENTARY SCHOOL",
        "district": "CARRINGTON 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005300087",
    },
    {
        "school": "CARRINGTON HIGH SCHOOL",
        "district": "CARRINGTON 49",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005300088",
    },
    {
        "school": "GRIGGS COUNTY CENTRAL ELEMENTARY SCHOOL",
        "district": "GRIGGS COUNTY CENTRAL 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380456000164",
    },
    {
        "school": "CENTER-STANTON ELEMENTARY SCHOOL",
        "district": "CENTER-STANTON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005200096",
    },
    {
        "school": "CENTER-STANTON HIGH SCHOOL",
        "district": "CENTER-STANTON 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005200097",
    },
    {
        "school": "NORTH BORDER-PEMBINA ELEMENTARY SCHOOL",
        "district": "NORTH BORDER 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005400529",
    },
    {
        "school": "NORTH BORDER-PEMBINA HIGH SCHOOL",
        "district": "NORTH BORDER 100",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005400530",
    },
    {
        "school": "NORTH BORDER-WALHALLA ELEMENTARY SCHOOL",
        "district": "NORTH BORDER 100",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005400669",
    },
    {
        "school": "NORTH BORDER-WALHALLA HIGH SCHOOL",
        "district": "NORTH BORDER 100",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005400670",
    },
    {
        "school": "FORDVILLE-LANKIN ELEMENTARY SCHOOL",
        "district": "FORDVILLE-LANKIN 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005600224",
    },
    {
        "school": "FORDVILLE-LANKIN HIGH SCHOOL",
        "district": "FORDVILLE-LANKIN 5",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005600225",
    },
    {
        "school": "SQUAW GAP SCHOOL",
        "district": "EARL 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380567000826",
    },
    {
        "school": "EAST FAIRVIEW ELEMENTARY SCHOOL",
        "district": "YELLOWSTONE 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "382034000714",
    },
    {
        "school": "HETTINGER ELEMENTARY SCHOOL",
        "district": "HETTINGER 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380941000298",
    },
    {
        "school": "HETTINGER HIGH SCHOOL",
        "district": "HETTINGER 13",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380941000299",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "VALLEY CITY 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381885000654",
    },
    {
        "school": "VALLEY CITY HIGH SCHOOL",
        "district": "VALLEY CITY 2",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381885000655",
    },
    {
        "school": "VALLEY CITY JUNIOR HIGH SCHOOL",
        "district": "VALLEY CITY 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381885000656",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "VALLEY CITY 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381885000657",
    },
    {
        "school": "FOUR WINDS COMMUNITY HIGH SCHOOL",
        "district": "FT TOTTEN 30",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380717000227",
    },
    {
        "school": "LEEDS ELEMENTARY SCHOOL",
        "district": "LEEDS 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381098000357",
    },
    {
        "school": "LEEDS HIGH SCHOOL",
        "district": "LEEDS 6",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381098000358",
    },
    {
        "school": "MADDOCK ELEMENTARY SCHOOL",
        "district": "MADDOCK 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381170000381",
    },
    {
        "school": "MADDOCK HIGH SCHOOL",
        "district": "MADDOCK 9",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381170000382",
    },
    {
        "school": "MINNEWAUKAN ELEMENTARY SCHOOL",
        "district": "MINNEWAUKAN 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381299000430",
    },
    {
        "school": "MINNEWAUKAN HIGH SCHOOL",
        "district": "MINNEWAUKAN 5",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381299000431",
    },
    {
        "school": "OBERON ELEMENTARY SCHOOL",
        "district": "OBERON 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381452000515",
    },
    {
        "school": "WARWICK ELEMENTARY SCHOOL",
        "district": "WARWICK 29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381926000671",
    },
    {
        "school": "WARWICK HIGH SCHOOL",
        "district": "WARWICK 29",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381926000672",
    },
    {
        "school": "NEWBURG-UNITED ELEMENTARY SCHOOL",
        "district": "NEWBURG-UNITED 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380082500113",
    },
    {
        "school": "NEWBURG-UNITED HIGH SCHOOL",
        "district": "NEWBURG-UNITED 54",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380082500834",
    },
    {
        "school": "BOTTINEAU ELEMENTARY SCHOOL",
        "district": "BOTTINEAU 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380306000067",
    },
    {
        "school": "BOTTINEAU JUNIOR-SENIOR HIGH SCHOOL",
        "district": "BOTTINEAU 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380306000068",
    },
    {
        "school": "WESTHOPE ELEMENTARY SCHOOL",
        "district": "WESTHOPE 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381947000685",
    },
    {
        "school": "WESTHOPE HIGH SCHOOL",
        "district": "WESTHOPE 17",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381947000686",
    },
    {
        "school": "SCRANTON ELEMENTARY SCHOOL",
        "district": "SCRANTON 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002300571",
    },
    {
        "school": "SCRANTON HIGH SCHOOL",
        "district": "SCRANTON 33",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002300572",
    },
    {
        "school": "BOWMAN CO ELEMENTARY SCHOOL",
        "district": "BOWMAN CO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380320000074",
    },
    {
        "school": "BOWMAN CO HIGH SCHOOL",
        "district": "BOWMAN CO 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380320000075",
    },
    {
        "school": "POWERS LAKE ELEMENTARY SCHOOL",
        "district": "POWERS LAKE 27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002400541",
    },
    {
        "school": "POWERS LAKE HIGH SCHOOL",
        "district": "POWERS LAKE 27",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002400542",
    },
    {
        "school": "BOWBELLS ELEMENTARY SCHOOL",
        "district": "BOWBELLS 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380309000069",
    },
    {
        "school": "BOWBELLS HIGH SCHOOL",
        "district": "BOWBELLS 14",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380309000070",
    },
    {
        "school": "BURKE CENTRAL ELEMENTARY SCHOOL",
        "district": "BURKE CENTRAL 36",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380359000080",
    },
    {
        "school": "BURKE CENTRAL HIGH SCHOOL",
        "district": "BURKE CENTRAL 36",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380359000082",
    },
    {
        "school": "LANGDON AREA ELEMENTARY SCHOOL",
        "district": "LANGDON AREA 23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381081000347",
    },
    {
        "school": "LANGDON AREA HIGH SCHOOL",
        "district": "LANGDON AREA 23",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381081000348",
    },
    {
        "school": "MUNICH ELEMENTARY SCHOOL",
        "district": "MUNICH 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381344000466",
    },
    {
        "school": "MUNICH HIGH SCHOOL",
        "district": "MUNICH 19",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381344000467",
    },
    {
        "school": "ELLENDALE ELEMENTARY SCHOOL",
        "district": "ELLENDALE 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380609000177",
    },
    {
        "school": "ELLENDALE HIGH SCHOOL",
        "district": "ELLENDALE 40",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380609000178",
    },
    {
        "school": "MAPLE RIVER COLONY SCHOOL",
        "district": "ELLENDALE 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380609000179",
    },
    {
        "school": "OAKES ELEMENTARY SCHOOL",
        "district": "OAKES 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381450000513",
    },
    {
        "school": "OAKES HIGH SCHOOL",
        "district": "OAKES 41",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381450000514",
    },
    {
        "school": "DIVIDE COUNTY ELEMENTARY SCHOOL",
        "district": "DIVIDE COUNTY 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380516000139",
    },
    {
        "school": "DIVIDE COUNTY HIGH SCHOOL",
        "district": "DIVIDE COUNTY 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380516000140",
    },
    {
        "school": "HALLIDAY ELEMENTARY SCHOOL",
        "district": "HALLIDAY 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380861000277",
    },
    {
        "school": "KILLDEER ELEMENTARY SCHOOL",
        "district": "KILLDEER 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381027000331",
    },
    {
        "school": "KILLDEER HIGH SCHOOL",
        "district": "KILLDEER 16",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381027000332",
    },
    {
        "school": "TWIN BUTTES ELEMENTARY SCHOOL",
        "district": "TWIN BUTTES 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381860000757",
    },
    {
        "school": "STRASBURG ELEMENTARY SCHOOL",
        "district": "STRASBURG 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001600614",
    },
    {
        "school": "STRASBURG HIGH SCHOOL",
        "district": "STRASBURG 15",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001600615",
    },
    {
        "school": "LINTON ELEMENTARY SCHOOL",
        "district": "LINTON 36",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001700370",
    },
    {
        "school": "LINTON HIGH SCHOOL",
        "district": "LINTON 36",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001700371",
    },
    {
        "school": "BAKKER ELEMENTARY SCHOOL",
        "district": "BAKKER 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380224000016",
    },
    {
        "school": "HAZELTON-MOFFIT-BRADDOCK HIGH SCHOOL",
        "district": "HAZELTON-MOFFIT-BRADDOCK 6",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380913000141",
    },
    {
        "school": "HAZELTON-MOFFIT-BRADDOCK ELEMENTARY SCHOOL",
        "district": "HAZELTON-MOFFIT-BRADDOCK 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380913000291",
    },
    {
        "school": "MIDKOTA HIGH SCHOOL",
        "district": "MIDKOTA 7",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004200239",
    },
    {
        "school": "BEACH HIGH SCHOOL",
        "district": "BEACH 3",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380238000023",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "BEACH 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380238000024",
    },
    {
        "school": "GOLVA ELEMENTARY SCHOOL",
        "district": "LONE TREE 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381161000379",
    },
    {
        "school": "ELGIN-NEW LEIPZIG ELEMENTARY SCHOOL",
        "district": "ELGIN-NEW LEIPZIG 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004500174",
    },
    {
        "school": "ELGIN-NEW LEIPZIG HIGH SCHOOL",
        "district": "ELGIN-NEW LEIPZIG 49",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004500175",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "ROOSEVELT 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381609000560",
    },
    {
        "school": "MIDKOTA ELEMENTARY SCHOOL",
        "district": "MIDKOTA 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004200042",
    },
    {
        "school": "GRIGGS COUNTY CENTRAL HIGH SCHOOL",
        "district": "GRIGGS COUNTY CENTRAL 18",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380456000116",
    },
    {
        "school": "NEW ENGLAND ELEMENTARY SCHOOL",
        "district": "NEW ENGLAND 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002700486",
    },
    {
        "school": "NEW ENGLAND HIGH SCHOOL",
        "district": "NEW ENGLAND 9",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002700487",
    },
    {
        "school": "MOTT-REGENT ELEMENTARY SCHOOL",
        "district": "MOTT-REGENT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004600460",
    },
    {
        "school": "MOTT-REGENT HIGH SCHOOL",
        "district": "MOTT-REGENT 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004600461",
    },
    {
        "school": "EDGELEY ELEMENTARY SCHOOL",
        "district": "EDGELEY 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380585000093",
    },
    {
        "school": "EDGELEY HIGH SCHOOL",
        "district": "EDGELEY 3",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380585000166",
    },
    {
        "school": "WILLOW BANK COLONY SCHOOL",
        "district": "EDGELEY 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380585000729",
    },
    {
        "school": "KULM ELEMENTARY SCHOOL",
        "district": "KULM 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381050000338",
    },
    {
        "school": "KULM HIGH SCHOOL",
        "district": "KULM 7",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381050000339",
    },
    {
        "school": "LAMOURE ELEMENTARY SCHOOL",
        "district": "LAMOURE 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381074000343",
    },
    {
        "school": "LAMOURE HIGH SCHOOL",
        "district": "LAMOURE 8",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381074000345",
    },
    {
        "school": "LAMOURE COLONY SCHOOL",
        "district": "LAMOURE 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381074000346",
    },
    {
        "school": "GACKLE-STREETER ELEMENTARY SCHOOL",
        "district": "GACKLE-STREETER 56",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004300230",
    },
    {
        "school": "GACKLE-STREETER HIGH SCHOOL",
        "district": "GACKLE-STREETER 56",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004300231",
    },
    {
        "school": "NAPOLEON ELEMENTARY SCHOOL",
        "district": "NAPOLEON 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381351000468",
    },
    {
        "school": "NAPOLEON HIGH SCHOOL",
        "district": "NAPOLEON 2",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381351000469",
    },
    {
        "school": "ASHLEY ELEMENTARY SCHOOL",
        "district": "ASHLEY 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380217000013",
    },
    {
        "school": "ASHLEY HIGH SCHOOL",
        "district": "ASHLEY 9",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380217000014",
    },
    {
        "school": "WISHEK ELEMENTARY SCHOOL",
        "district": "WISHEK 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "382019000706",
    },
    {
        "school": "WISHEK HIGH SCHOOL",
        "district": "WISHEK 19",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "382019000707",
    },
    {
        "school": "ZEELAND ELEMENTARY SCHOOL",
        "district": "ZEELAND 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "382040000717",
    },
    {
        "school": "ZEELAND HIGH SCHOOL",
        "district": "ZEELAND 4",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "382040000718",
    },
    {
        "school": "ALEXANDER ELEMENTARY SCHOOL",
        "district": "ALEXANDER 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380176000003",
    },
    {
        "school": "ALEXANDER HIGH SCHOOL",
        "district": "ALEXANDER 2",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380176000004",
    },
    {
        "school": "HORSE CREEK SCHOOL",
        "district": "HORSE CREEK 32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380981000305",
    },
    {
        "school": "MANDAREE HIGH SCHOOL",
        "district": "MANDAREE 36",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381185000006",
    },
    {
        "school": "MANDAREE ELEMENTARY SCHOOL",
        "district": "MANDAREE 36",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381185000747",
    },
    {
        "school": "WATFORD CITY ELEMENTARY SCHOOL",
        "district": "MCKENZIE CO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381254000414",
    },
    {
        "school": "WATFORD CITY HIGH SCHOOL",
        "district": "MCKENZIE CO 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381254000415",
    },
    {
        "school": "BOB CALLIES ELEMENTARY SCHOOL",
        "district": "GARRISON 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380759000233",
    },
    {
        "school": "GARRISON HIGH SCHOOL",
        "district": "GARRISON 51",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380759000234",
    },
    {
        "school": "MAX ELEMENTARY SCHOOL",
        "district": "MAX 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381235000401",
    },
    {
        "school": "MAX HIGH SCHOOL",
        "district": "MAX 50",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381235000402",
    },
    {
        "school": "WILTON ELEMENTARY SCHOOL",
        "district": "WILTON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381320000456",
    },
    {
        "school": "WILTON HIGH SCHOOL",
        "district": "WILTON 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381320000457",
    },
    {
        "school": "TURTLE LAKE-MERCER ELEMENTARY SCHOOL",
        "district": "TURTLE LAKE-MERCER 72",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381850000640",
    },
    {
        "school": "TURTLE LAKE-MERCER HIGH SCHOOL",
        "district": "TURTLE LAKE-MERCER 72",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381850000641",
    },
    {
        "school": "UNDERWOOD ELEMENTARY SCHOOL",
        "district": "UNDERWOOD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381866000644",
    },
    {
        "school": "UNDERWOOD HIGH SCHOOL",
        "district": "UNDERWOOD 8",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381866000645",
    },
    {
        "school": "WASHBURN ELEMENTARY SCHOOL",
        "district": "WASHBURN 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381929000673",
    },
    {
        "school": "WASHBURN HIGH SCHOOL",
        "district": "WASHBURN 4",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381929000674",
    },
    {
        "school": "WHITE SHIELD ELEMENTARY SCHOOL",
        "district": "WHITE SHIELD 85",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381968000807",
    },
    {
        "school": "WHITE SHIELD HIGH SCHOOL",
        "district": "WHITE SHIELD 85",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381968000808",
    },
    {
        "school": "HAZEN ELEMENTARY SCHOOL",
        "district": "HAZEN 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003100293",
    },
    {
        "school": "HAZEN HIGH SCHOOL",
        "district": "HAZEN 3",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003100294",
    },
    {
        "school": "BEULAH ELEMENTARY SCHOOL",
        "district": "BEULAH 27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003200031",
    },
    {
        "school": "BEULAH HIGH SCHOOL",
        "district": "BEULAH 27",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003200032",
    },
    {
        "school": "BEULAH MIDDLE SCHOOL",
        "district": "BEULAH 27",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003200738",
    },
    {
        "school": "NEW TOWN HIGH SCHOOL",
        "district": "NEW TOWN 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381392000015",
    },
    {
        "school": "EDWIN LOE ELEMENTARY SCHOOL",
        "district": "NEW TOWN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381392000495",
    },
    {
        "school": "NEW TOWN MIDDLE SCHOOL",
        "district": "NEW TOWN 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381392000496",
    },
    {
        "school": "PARSHALL ELEMENTARY SCHOOL",
        "district": "PARSHALL 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381494000527",
    },
    {
        "school": "PARSHALL HIGH SCHOOL",
        "district": "PARSHALL 3",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381494000528",
    },
    {
        "school": "STANLEY ELEMENTARY SCHOOL",
        "district": "STANLEY 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381757000604",
    },
    {
        "school": "STANLEY HIGH SCHOOL",
        "district": "STANLEY 2",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381757000605",
    },
    {
        "school": "DAKOTA PRAIRIE ELEMENTARY SCHOOL",
        "district": "DAKOTA PRAIRIE 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004000416",
    },
    {
        "school": "DAKOTA PRAIRIE HIGH SCHOOL",
        "district": "DAKOTA PRAIRIE 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004000649",
    },
    {
        "school": "LAKOTA ELEMENTARY SCHOOL",
        "district": "LAKOTA 66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381060000341",
    },
    {
        "school": "LAKOTA HIGH SCHOOL",
        "district": "LAKOTA 66",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381060000342",
    },
    {
        "school": "CAVALIER HIGH SCHOOL",
        "district": "CAVALIER 6",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001800089",
    },
    {
        "school": "CAVALIER ELEMENTARY SCHOOL",
        "district": "CAVALIER 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001800094",
    },
    {
        "school": "DRAYTON ELEMENTARY SCHOOL",
        "district": "DRAYTON 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380534000150",
    },
    {
        "school": "DRAYTON HIGH SCHOOL",
        "district": "DRAYTON 19",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380534000151",
    },
    {
        "school": "SAINT THOMAS ELEMENTARY SCHOOL",
        "district": "ST THOMAS 43",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381752000602",
    },
    {
        "school": "SAINT THOMAS HIGH SCHOOL",
        "district": "ST THOMAS 43",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381752000603",
    },
    {
        "school": "RUGBY ELY ELEMENTARY SCHOOL",
        "district": "RUGBY 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381613000562",
    },
    {
        "school": "RUGBY HIGH SCHOOL",
        "district": "RUGBY 5",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381613000563",
    },
    {
        "school": "SCHOOL FOR THE DEAF PK-8",
        "district": "ND SCHOOL FOR THE DEAF",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380000600801",
    },
    {
        "school": "DEVILS LAKE HIGH SCHOOL",
        "district": "DEVILS LAKE 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380504000126",
    },
    {
        "school": "CENTRAL MIDDLE SCHOOL",
        "district": "DEVILS LAKE 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380504000127",
    },
    {
        "school": "MINNIE H KINDERGARTEN CENTER",
        "district": "DEVILS LAKE 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380504000128",
    },
    {
        "school": "PRAIRIE VIEW ELEMENTARY SCHOOL",
        "district": "DEVILS LAKE 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380504000129",
    },
    {
        "school": "SWEETWATER ELEMENTARY SCHOOL",
        "district": "DEVILS LAKE 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380504000130",
    },
    {
        "school": "EDMORE HIGH SCHOOL",
        "district": "EDMORE 2",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380595000170",
    },
    {
        "school": "STARKWEATHER ELEMENTARY SCHOOL",
        "district": "STARKWEATHER 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381767000608",
    },
    {
        "school": "STARKWEATHER HIGH SCHOOL",
        "district": "STARKWEATHER 44",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381767000609",
    },
    {
        "school": "FORT RANSOM ELEMENTARY SCHOOL",
        "district": "FT RANSOM 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003300226",
    },
    {
        "school": "LISBON ELEMENTARY SCHOOL",
        "district": "LISBON 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381143000373",
    },
    {
        "school": "LISBON HIGH SCHOOL",
        "district": "LISBON 19",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381143000374",
    },
    {
        "school": "LISBON MIDDLE SCHOOL",
        "district": "LISBON 19",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381143000375",
    },
    {
        "school": "SUNDALE COLONY ELEMENTARY SCHOOL",
        "district": "MILNOR 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381293000733",
    },
    {
        "school": "TURTLE MOUNTAIN COMMUNITY ELEMENTARY SCHOOL",
        "district": "BELCOURT 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380253000750",
    },
    {
        "school": "TURTLE MOUNTAIN COMMUNITY MIDDLE SCHOOL",
        "district": "BELCOURT 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380253000751",
    },
    {
        "school": "TURTLE MOUNTAIN COMMUNITY HIGH SCHOOL",
        "district": "BELCOURT 7",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380253000752",
    },
    {
        "school": "DUNSEITH ELEMENTARY SCHOOL",
        "district": "DUNSEITH 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380546000155",
    },
    {
        "school": "DUNSEITH HIGH SCHOOL",
        "district": "DUNSEITH 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380546000157",
    },
    {
        "school": "MT PLEASANT ELEMENTARY SCHOOL",
        "district": "MT PLEASANT 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381340000463",
    },
    {
        "school": "MT PLEASANT HIGH SCHOOL",
        "district": "MT PLEASANT 4",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381340000464",
    },
    {
        "school": "ROLETTE ELEMENTARY SCHOOL",
        "district": "ROLETTE 29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381605000558",
    },
    {
        "school": "ROLETTE HIGH SCHOOL",
        "district": "ROLETTE 29",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381605000559",
    },
    {
        "school": "SAINT JOHN ELEMENTARY SCHOOL",
        "district": "ST JOHN 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381746000599",
    },
    {
        "school": "SAINT JOHN HIGH SCHOOL",
        "district": "ST JOHN 3",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381746000600",
    },
    {
        "school": "MILNOR ELEMENTARY SCHOOL",
        "district": "MILNOR 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381293000426",
    },
    {
        "school": "MILNOR HIGH SCHOOL",
        "district": "MILNOR 2",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381293000427",
    },
    {
        "school": "NORTH SARGENT ELEMENTARY SCHOOL",
        "district": "NORTH SARGENT 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381429000504",
    },
    {
        "school": "NORTH SARGENT HIGH SCHOOL",
        "district": "NORTH SARGENT 3",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381429000505",
    },
    {
        "school": "SARGENT CENTRAL HIGH SCHOOL",
        "district": "SARGENT CENTRAL 6",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381643000568",
    },
    {
        "school": "SARGENT CENTRAL ELEMENTARY SCHOOL",
        "district": "SARGENT CENTRAL 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381643000756",
    },
    {
        "school": "GOODRICH ELEMENTARY SCHOOL",
        "district": "GOODRICH 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380795000242",
    },
    {
        "school": "GOODRICH HIGH SCHOOL",
        "district": "GOODRICH 16",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380795000243",
    },
    {
        "school": "MCCLUSKY ELEMENTARY SCHOOL",
        "district": "MCCLUSKY 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381243000407",
    },
    {
        "school": "MCCLUSKY HIGH SCHOOL",
        "district": "MCCLUSKY 19",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381243000408",
    },
    {
        "school": "FORT YATES MIDDLE SCHOOL",
        "district": "FT YATES 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380720000744",
    },
    {
        "school": "SELFRIDGE ELEMENTARY SCHOOL",
        "district": "SELFRIDGE 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381651000573",
    },
    {
        "school": "SELFRIDGE HIGH SCHOOL",
        "district": "SELFRIDGE 8",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381651000574",
    },
    {
        "school": "CANNON BALL ELEMENTARY SCHOOL",
        "district": "SOLEN 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381698000585",
    },
    {
        "school": "SOLEN HIGH SCHOOL",
        "district": "SOLEN 3",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381698000587",
    },
    {
        "school": "MARMARTH ELEMENTARY SCHOOL",
        "district": "MARMARTH 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381212000400",
    },
    {
        "school": "FINLEY-SHARON HIGH SCHOOL",
        "district": "FINLEY-SHARON 19",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380691000217",
    },
    {
        "school": "FINLEY-SHARON ELEMENTARY SCHOOL",
        "district": "FINLEY-SHARON 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380691000743",
    },
    {
        "school": "HOPE HIGH SCHOOL",
        "district": "HOPE 10",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380971000161",
    },
    {
        "school": "MAY-PORT CG MIDDLE SCHOOL",
        "district": "MAY-PORT CG 14",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004100019",
    },
    {
        "school": "PETER BOE JR ELEMENTARY SCHOOL",
        "district": "MAY-PORT CG 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004100405",
    },
    {
        "school": "MAY-PORT CG HIGH SCHOOL",
        "district": "MAY-PORT CG 14",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004100406",
    },
    {
        "school": "CENTRAL VALLEY ELEMENTARY SCHOOL",
        "district": "CENTRAL VALLEY 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380414000103",
    },
    {
        "school": "CENTRAL VALLEY HIGH SCHOOL",
        "district": "CENTRAL VALLEY 3",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380414000104",
    },
    {
        "school": "HATTON EIELSON ELEMENTARY SCHOOL",
        "district": "HATTON EIELSON 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380900000289",
    },
    {
        "school": "HATTON EIELSON HIGH SCHOOL",
        "district": "HATTON EIELSON 7",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380900000290",
    },
    {
        "school": "HILLSBORO ELEMENTARY SCHOOL",
        "district": "HILLSBORO 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380957000301",
    },
    {
        "school": "HILLSBORO HIGH SCHOOL",
        "district": "HILLSBORO 9",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380957000302",
    },
    {
        "school": "CENTURY ELEMENTARY SCHOOL",
        "district": "GRAFTON 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380806000143",
    },
    {
        "school": "GRAFTON JUNIOR HIGH SCHOOL",
        "district": "GRAFTON 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380806000247",
    },
    {
        "school": "GRAFTON HIGH SCHOOL",
        "district": "GRAFTON 3",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380806000248",
    },
    {
        "school": "MINTO ELEMENTARY SCHOOL",
        "district": "MINTO 20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381305000451",
    },
    {
        "school": "MINTO HIGH SCHOOL",
        "district": "MINTO 20",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381305000452",
    },
    {
        "school": "FESSENDEN-BOWDON ELEMENTARY SCHOOL",
        "district": "FESSENDEN-BOWDON 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004900212",
    },
    {
        "school": "FESSENDEN-BOWDON HIGH SCHOOL",
        "district": "FESSENDEN-BOWDON 25",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004900213",
    },
    {
        "school": "BM HANSON ELEMENTARY SCHOOL",
        "district": "HARVEY 38",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380889000287",
    },
    {
        "school": "HARVEY HIGH SCHOOL",
        "district": "HARVEY 38",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380889000288",
    },
    {
        "school": "BECEP CENTER",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400044",
    },
    {
        "school": "BISMARCK HIGH SCHOOL",
        "district": "BISMARCK 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400045",
    },
    {
        "school": "CENTURY HIGH SCHOOL",
        "district": "BISMARCK 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400047",
    },
    {
        "school": "DOROTHY MOSES ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400048",
    },
    {
        "school": "GRIMSRUD ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400049",
    },
    {
        "school": "HIGHLAND ACRES ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400050",
    },
    {
        "school": "HORIZON MIDDLE SCHOOL",
        "district": "BISMARCK 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400051",
    },
    {
        "school": "JEANNETTE MYHRE ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400052",
    },
    {
        "school": "NORTHRIDGE ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400053",
    },
    {
        "school": "PIONEER ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400054",
    },
    {
        "school": "RITA MURPHY ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400056",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400058",
    },
    {
        "school": "SIMLE MIDDLE SCHOOL",
        "district": "BISMARCK 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400060",
    },
    {
        "school": "WACHTER MIDDLE SCHOOL",
        "district": "BISMARCK 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400061",
    },
    {
        "school": "WILL-MOORE ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400062",
    },
    {
        "school": "ROBERT PLACE MILLER ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400727",
    },
    {
        "school": "SOUTH CENTRAL ALTERNATIVE HIGH SCHOOL",
        "district": "BISMARCK 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400739",
    },
    {
        "school": "PRAIRIE ROSE ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400810",
    },
    {
        "school": "VICTOR SOLHEIM ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400811",
    },
    {
        "school": "CENTENNIAL ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400821",
    },
    {
        "school": "NAUGHTON ELEMENTARY SCHOOL",
        "district": "NAUGHTON 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001500471",
    },
    {
        "school": "APPLE CREEK ELEMENTARY SCHOOL",
        "district": "APPLE CREEK 39",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380201400012",
    },
    {
        "school": "MANNING ELEMENTARY SCHOOL",
        "district": "MANNING 45",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381197000393",
    },
    {
        "school": "MENOKEN ELEMENTARY SCHOOL",
        "district": "MENOKEN 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381272000420",
    },
    {
        "school": "STERLING ELEMENTARY SCHOOL",
        "district": "STERLING 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381776000613",
    },
    {
        "school": "WING ELEMENTARY SCHOOL",
        "district": "WING 28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "382013000704",
    },
    {
        "school": "WING HIGH SCHOOL",
        "district": "WING 28",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "382013000705",
    },
    {
        "school": "MARMOT SCHOOL 9-12",
        "district": "MARMOT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380000500797",
    },
    {
        "school": "FLASHER ELEMENTARY SCHOOL",
        "district": "FLASHER 39",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380693000218",
    },
    {
        "school": "FLASHER HIGH SCHOOL",
        "district": "FLASHER 39",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380693000219",
    },
    {
        "school": "GLEN ULLIN ELEMENTARY SCHOOL",
        "district": "GLEN ULLIN 48",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380783000235",
    },
    {
        "school": "GLEN ULLIN HIGH SCHOOL",
        "district": "GLEN ULLIN 48",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380783000236",
    },
    {
        "school": "HEBRON ELEMENTARY SCHOOL",
        "district": "HEBRON 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380918000295",
    },
    {
        "school": "HEBRON HIGH SCHOOL",
        "district": "HEBRON 13",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380918000296",
    },
    {
        "school": "LITTLE HEART ELEMENTARY SCHOOL",
        "district": "LITTLE HEART 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381154000378",
    },
    {
        "school": "FT LINCOLN ELEMENTARY SCHOOL",
        "district": "MANDAN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381182000081",
    },
    {
        "school": "CUSTER ELEMENTARY SCHOOL",
        "district": "MANDAN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381182000384",
    },
    {
        "school": "LEWIS AND CLARK ELEMENTARY SCHOOL",
        "district": "MANDAN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381182000386",
    },
    {
        "school": "MANDAN HIGH SCHOOL",
        "district": "MANDAN 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381182000387",
    },
    {
        "school": "MANDAN MIDDLE SCHOOL",
        "district": "MANDAN 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381182000388",
    },
    {
        "school": "MARY STARK ELEMENTARY SCHOOL",
        "district": "MANDAN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381182000390",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "MANDAN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381182000391",
    },
    {
        "school": "SWEET BRIAR SCHOOL",
        "district": "SWEET BRIAR 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381794000620",
    },
    {
        "school": "SOUTHWEST COMMUNITY HIGH SCHOOL",
        "district": "DICKINSON 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003800156",
    },
    {
        "school": "DEMORES ELEMENTARY SCHOOL",
        "district": "BILLINGS CO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380284000033",
    },
    {
        "school": "PRAIRIE ELEMENTARY SCHOOL",
        "district": "BILLINGS CO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380284000816",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "DICKINSON 1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003800022",
    },
    {
        "school": "DICKINSON HIGH SCHOOL",
        "district": "DICKINSON 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003800132",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "DICKINSON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003800134",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "DICKINSON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003800135",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "DICKINSON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003800137",
    },
    {
        "school": "HEART RIVER ELEMENTARY SCHOOL",
        "district": "DICKINSON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003800742",
    },
    {
        "school": "RICHARDTON-TAYLOR HIGH SCHOOL",
        "district": "RICHARDTON-TAYLOR 34",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004800551",
    },
    {
        "school": "TAYLOR-RICHARDTON ELEMENTARY SCHOOL",
        "district": "RICHARDTON-TAYLOR 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004800626",
    },
    {
        "school": "BELFIELD ELEMENTARY SCHOOL",
        "district": "BELFIELD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380621000180",
    },
    {
        "school": "BELFIELD HIGH SCHOOL",
        "district": "BELFIELD 13",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380621000181",
    },
    {
        "school": "SOUTH HEART ELEMENTARY SCHOOL",
        "district": "SOUTH HEART 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381713000592",
    },
    {
        "school": "SOUTH HEART HIGH SCHOOL",
        "district": "SOUTH HEART 9",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381713000593",
    },
    {
        "school": "CENTRAL CASS MIDDLE SCHOOL",
        "district": "CENTRAL CASS 17",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380409000163",
    },
    {
        "school": "KINDRED ELEMENTARY SCHOOL",
        "district": "KINDRED 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002500334",
    },
    {
        "school": "KINDRED HIGH SCHOOL",
        "district": "KINDRED 2",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002500335",
    },
    {
        "school": "NORTHERN CASS ELEMENTARY SCHOOL",
        "district": "NORTHERN CASS 97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004400119",
    },
    {
        "school": "NORTHERN CASS MIDDLE SCHOOL",
        "district": "NORTHERN CASS 97",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004400120",
    },
    {
        "school": "NORTHERN CASS HIGH SCHOOL",
        "district": "NORTHERN CASS 97",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004400138",
    },
    {
        "school": "CENTRAL CASS ELEMENTARY SCHOOL",
        "district": "CENTRAL CASS 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380409000099",
    },
    {
        "school": "CENTRAL CASS HIGH SCHOOL",
        "district": "CENTRAL CASS 17",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380409000100",
    },
    {
        "school": "DISCOVERY MIDDLE SCHOOL",
        "district": "FARGO 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000079",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL EDUCATION SCHOOL",
        "district": "FARGO 1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000109",
    },
    {
        "school": "BENNETT ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000160",
    },
    {
        "school": "BEN FRANKLIN MIDDLE SCHOOL",
        "district": "FARGO 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000193",
    },
    {
        "school": "CLARA BARTON HAWTHORNE ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000195",
    },
    {
        "school": "HORACE MANN ROOSEVELT ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000198",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000199",
    },
    {
        "school": "LEWIS AND CLARK ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000200",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000201",
    },
    {
        "school": "LONGFELLOW ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000202",
    },
    {
        "school": "MADISON ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000203",
    },
    {
        "school": "MCKINLEY ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000204",
    },
    {
        "school": "NORTH HIGH SCHOOL",
        "district": "FARGO 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000205",
    },
    {
        "school": "SOUTH HIGH SCHOOL",
        "district": "FARGO 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000208",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000210",
    },
    {
        "school": "WOODROW WILSON ALTERNATIVE HIGH SCHOOL",
        "district": "FARGO 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000211",
    },
    {
        "school": "CENTENNIAL ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000823",
    },
    {
        "school": "MAPLE VALLEY HIGH SCHOOL",
        "district": "MAPLE VALLEY 4",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381202000395",
    },
    {
        "school": "MAPLETON ELEMENTARY SCHOOL",
        "district": "MAPLETON 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381203000397",
    },
    {
        "school": "PAGE ELEMENTARY SCHOOL",
        "district": "PAGE 80",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381473000521",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "WEST FARGO 6",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000026",
    },
    {
        "school": "EASTWOOD ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000677",
    },
    {
        "school": "HARWOOD ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000678",
    },
    {
        "school": "HORACE ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000679",
    },
    {
        "school": "CHENEY MIDDLE SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000680",
    },
    {
        "school": "SOUTH ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000682",
    },
    {
        "school": "WEST FARGO HIGH SCHOOL",
        "district": "WEST FARGO 6",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000683",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000684",
    },
    {
        "school": "L E BERGER ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000815",
    },
    {
        "school": "SCHOOL FOR THE BLIND",
        "district": "ND VISION SERVICES",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380000400803",
    },
    {
        "school": "EMERADO ELEMENTARY SCHOOL",
        "district": "EMERADO 127",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380636000182",
    },
    {
        "school": "PHOENIX ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000251",
    },
    {
        "school": "BEN FRANKLIN ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000252",
    },
    {
        "school": "CENTRAL HIGH SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000254",
    },
    {
        "school": "J NELSON KELLY ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000255",
    },
    {
        "school": "LAKE AGASSIZ ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000256",
    },
    {
        "school": "LEWIS AND CLARK ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000257",
    },
    {
        "school": "NATHAN TWINING ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000259",
    },
    {
        "school": "RED RIVER HIGH SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000261",
    },
    {
        "school": "SCHROEDER MIDDLE SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000263",
    },
    {
        "school": "SOUTH MIDDLE SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000264",
    },
    {
        "school": "VALLEY MIDDLE SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000265",
    },
    {
        "school": "VIKING ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000266",
    },
    {
        "school": "WEST ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000267",
    },
    {
        "school": "WILDER ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000268",
    },
    {
        "school": "WINSHIP ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000269",
    },
    {
        "school": "COMMUNITY ALTERNATIVE HIGH SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000755",
    },
    {
        "school": "NATHAN TWINING MIDDLE SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000814",
    },
    {
        "school": "CENTURY ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000824",
    },
    {
        "school": "LARIMORE ELEMENTARY SCHOOL",
        "district": "LARIMORE 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381086000354",
    },
    {
        "school": "LARIMORE HIGH SCHOOL",
        "district": "LARIMORE 44",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381086000355",
    },
    {
        "school": "MANVEL ELEMENTARY SCHOOL",
        "district": "MANVEL 125",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381200000394",
    },
    {
        "school": "MIDWAY HIGH SCHOOL",
        "district": "MIDWAY 128",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381292000110",
    },
    {
        "school": "MIDWAY ELEMENTARY SCHOOL",
        "district": "MIDWAY 128",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381292000424",
    },
    {
        "school": "NORTHWOOD ELEMENTARY SCHOOL",
        "district": "NORTHWOOD 129",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381434000508",
    },
    {
        "school": "NORTHWOOD HIGH SCHOOL",
        "district": "NORTHWOOD 129",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381434000509",
    },
    {
        "school": "THOMPSON ELEMENTARY SCHOOL",
        "district": "THOMPSON 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381828000629",
    },
    {
        "school": "THOMPSON HIGH SCHOOL",
        "district": "THOMPSON 61",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381828000630",
    },
    {
        "school": "JAMESTOWN HIGH SCHOOL",
        "district": "JAMESTOWN 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002100310",
    },
    {
        "school": "JAMESTOWN MIDDLE SCHOOL",
        "district": "JAMESTOWN 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002100311",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "JAMESTOWN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002100312",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "JAMESTOWN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002100313",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "JAMESTOWN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002100314",
    },
    {
        "school": "WILLIAM S GUSSNER ELEMENTARY SCHOOL",
        "district": "JAMESTOWN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002100315",
    },
    {
        "school": "LOUIS L'AMOUR ELEMENTARY SCHOOL",
        "district": "JAMESTOWN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002100825",
    },
    {
        "school": "KENSAL ELEMENTARY SCHOOL",
        "district": "KENSAL 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381026000329",
    },
    {
        "school": "MEDINA ELEMENTARY SCHOOL",
        "district": "MEDINA 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381266000418",
    },
    {
        "school": "MEDINA HIGH SCHOOL",
        "district": "MEDINA 3",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381266000419",
    },
    {
        "school": "MONTPELIER ELEMENTARY SCHOOL",
        "district": "MONTPELIER 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381323000458",
    },
    {
        "school": "MONTPELIER HIGH SCHOOL",
        "district": "MONTPELIER 14",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381323000459",
    },
    {
        "school": "PINGREE-BUCHANAN HIGH SCHOOL",
        "district": "PINGREE-BUCHANAN 10",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381515000534",
    },
    {
        "school": "PINGREE-BUCHANAN ELEMENTARY SCHOOL",
        "district": "PINGREE-BUCHANAN 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381515000818",
    },
    {
        "school": "MLS-MOHALL ELEMENTARY SCHOOL",
        "district": "MOHALL-LANSFORD-SHERWOOD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005000453",
    },
    {
        "school": "MLS-MOHALL HIGH SCHOOL",
        "district": "MOHALL-LANSFORD-SHERWOOD 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005000454",
    },
    {
        "school": "BERTHOLD ELEMENTARY SCHOOL",
        "district": "LEWIS AND CLARK 161",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005800029",
    },
    {
        "school": "BERTHOLD HIGH SCHOOL",
        "district": "LEWIS AND CLARK 161",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005800030",
    },
    {
        "school": "NORTH SHORE PLAZA HIGH SCHOOL",
        "district": "LEWIS AND CLARK 161",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005800507",
    },
    {
        "school": "NORTH SHORE PLAZA ELEMENTARY SCHOOL",
        "district": "LEWIS AND CLARK 161",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380005800537",
    },
    {
        "school": "DRAKE HIGH SCHOOL",
        "district": "DRAKE 57",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380002900149",
    },
    {
        "school": "TGU-GRANVILLE ELEMENTARY SCHOOL",
        "district": "TGU 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004700270",
    },
    {
        "school": "TGU-GRANVILLE HIGH SCHOOL",
        "district": "TGU 60",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004700271",
    },
    {
        "school": "TGU-TOWNER ELEMENTARY SCHOOL",
        "district": "TGU 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004700498",
    },
    {
        "school": "TGU-TOWNER HIGH SCHOOL",
        "district": "TGU 60",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004700499",
    },
    {
        "school": "ANAMOOSE ELEMENTARY SCHOOL",
        "district": "ANAMOOSE 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380195000007",
    },
    {
        "school": "VELVA ELEMENTARY SCHOOL",
        "district": "VELVA 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381704000590",
    },
    {
        "school": "VELVA HIGH SCHOOL",
        "district": "VELVA 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381704000591",
    },
    {
        "school": "GLENBURN ELEMENTARY SCHOOL",
        "district": "GLENBURN 26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380785000237",
    },
    {
        "school": "GLENBURN HIGH SCHOOL",
        "district": "GLENBURN 26",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380785000238",
    },
    {
        "school": "KENMARE HIGH SCHOOL",
        "district": "KENMARE 28",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381018000326",
    },
    {
        "school": "KENMARE ELEMENTARY SCHOOL",
        "district": "KENMARE 28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381018000731",
    },
    {
        "school": "SOURIS RIVER CAMPUS ALTERNATIVE HIGH SCHOOL",
        "district": "MINOT 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000066",
    },
    {
        "school": "BEL AIR ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000432",
    },
    {
        "school": "CENTRAL CAMPUS SCHOOL",
        "district": "MINOT 1",
        "level": "Secondary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000433",
    },
    {
        "school": "DAKOTA ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000434",
    },
    {
        "school": "EDISON ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000435",
    },
    {
        "school": "ERIK RAMSTAD MIDDLE SCHOOL",
        "district": "MINOT 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000436",
    },
    {
        "school": "JIM HILL MIDDLE SCHOOL",
        "district": "MINOT 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000439",
    },
    {
        "school": "LONGFELLOW ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000441",
    },
    {
        "school": "MAGIC CITY CAMPUS HIGH SCHOOL",
        "district": "MINOT 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000442",
    },
    {
        "school": "MCKINLEY ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000443",
    },
    {
        "school": "MEMORIAL MIDDLE SCHOOL",
        "district": "MINOT 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000444",
    },
    {
        "school": "LEWIS AND CLARK ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000445",
    },
    {
        "school": "NORTH PLAINS ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000446",
    },
    {
        "school": "PERKETT ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000447",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000448",
    },
    {
        "school": "SUNNYSIDE ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000449",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000450",
    },
    {
        "school": "NEDROSE ELEMENTARY SCHOOL",
        "district": "NEDROSE 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381366000474",
    },
    {
        "school": "SAWYER ELEMENTARY SCHOOL",
        "district": "SAWYER 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381647000569",
    },
    {
        "school": "SOUTH PRAIRIE ELEMENTARY SCHOOL",
        "district": "SOUTH PRAIRIE 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381717000594",
    },
    {
        "school": "SURREY ELEMENTARY SCHOOL",
        "district": "SURREY 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381791000618",
    },
    {
        "school": "SURREY HIGH SCHOOL",
        "district": "SURREY 41",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381791000619",
    },
    {
        "school": "BURLINGTON-DES LACS ELEMENTARY SCHOOL",
        "district": "UNITED 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381873000646",
    },
    {
        "school": "DES LACS-BURLINGTON HIGH SCHOOL",
        "district": "UNITED 7",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381873000647",
    },
    {
        "school": "RICHLAND ELEMENTARY SCHOOL",
        "district": "RICHLAND 44",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003600552",
    },
    {
        "school": "RICHLAND JUNIOR-SENIOR HIGH SCHOOL",
        "district": "RICHLAND 44",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003600553",
    },
    {
        "school": "FAIRMOUNT ELEMENTARY SCHOOL",
        "district": "FAIRMOUNT 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380669000190",
    },
    {
        "school": "FAIRMOUNT HIGH SCHOOL",
        "district": "FAIRMOUNT 18",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380669000191",
    },
    {
        "school": "HANKINSON ELEMENTARY SCHOOL",
        "district": "HANKINSON 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380871000281",
    },
    {
        "school": "HANKINSON HIGH SCHOOL",
        "district": "HANKINSON 8",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380871000283",
    },
    {
        "school": "LIDGERWOOD ELEMENTARY SCHOOL",
        "district": "LIDGERWOOD 28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381114000365",
    },
    {
        "school": "LIDGERWOOD HIGH SCHOOL",
        "district": "LIDGERWOOD 28",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381114000366",
    },
    {
        "school": "WAHPETON ELEMENTARY SCHOOL",
        "district": "WAHPETON 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381902000660",
    },
    {
        "school": "WAHPETON HIGH SCHOOL",
        "district": "WAHPETON 37",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381902000666",
    },
    {
        "school": "ZIMMERMAN ELEMENTARY SCHOOL",
        "district": "WAHPETON 37",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381902000668",
    },
    {
        "school": "WAHPETON MIDDLE SCHOOL",
        "district": "WAHPETON 37",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381902000749",
    },
    {
        "school": "WYNDMERE ELEMENTARY SCHOOL",
        "district": "WYNDMERE 42",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "382031000712",
    },
    {
        "school": "WYNDMERE HIGH SCHOOL",
        "district": "WYNDMERE 42",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "382031000713",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "TIOGA 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003900633",
    },
    {
        "school": "TIOGA HIGH SCHOOL",
        "district": "TIOGA 15",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003900635",
    },
    {
        "school": "EIGHT MILE ELEMENTARY SCHOOL",
        "district": "EIGHT MILE 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380601000171",
    },
    {
        "school": "EIGHT MILE HIGH SCHOOL",
        "district": "EIGHT MILE 6",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380601000172",
    },
    {
        "school": "GRENORA ELEMENTARY SCHOOL",
        "district": "GRENORA 99",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380846000273",
    },
    {
        "school": "GRENORA HIGH SCHOOL",
        "district": "GRENORA 99",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380846000274",
    },
    {
        "school": "RAY ELEMENTARY SCHOOL",
        "district": "NESSON 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381371000477",
    },
    {
        "school": "RAY HIGH SCHOOL",
        "district": "NESSON 2",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381371000478",
    },
    {
        "school": "ROUND PRAIRIE ELEMENTARY SCHOOL",
        "district": "WILLIAMS COUNTY 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381376000482",
    },
    {
        "school": "GARDEN VALLEY ELEMENTARY SCHOOL",
        "district": "WILLIAMS COUNTY 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381376000831",
    },
    {
        "school": "LEWIS AND CLARK ELEMENTARY SCHOOL",
        "district": "WILLISTON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381988000690",
    },
    {
        "school": "RICKARD ELEMENTARY SCHOOL",
        "district": "WILLISTON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381988000692",
    },
    {
        "school": "WILKINSON ELEMENTARY SCHOOL",
        "district": "WILLISTON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381988000694",
    },
    {
        "school": "WILLISTON HIGH SCHOOL",
        "district": "WILLISTON 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381988000695",
    },
    {
        "school": "WILLISTON MIDDLE SCHOOL",
        "district": "WILLISTON 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381988000696",
    },
    {
        "school": "HAGAN ELEMENTARY SCHOOL",
        "district": "WILLISTON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381988000758",
    },
    {
        "school": "NEBRASKA YOUTH ACADEMY",
        "district": "NEBRASKA YOUTH ACADEMY",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310017402004",
    },
    {
        "school": "ARTHUR COUNTY ELEMENTARY SCHOOL",
        "district": "ARTHUR COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310321000515",
    },
    {
        "school": "CUTCOMB LAKE SCHOOL",
        "district": "VALENTINE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317802000883",
    },
    {
        "school": "VALENTINE ELEMENTARY SCHOOL",
        "district": "VALENTINE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317802001672",
    },
    {
        "school": "VALENTINE MIDDLE SCHOOL",
        "district": "VALENTINE COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317802001673",
    },
    {
        "school": "KENNEDY SCHOOL",
        "district": "VALENTINE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317802001852",
    },
    {
        "school": "SCHUYLER ELEMENTARY-FISHER'S",
        "district": "SCHUYLER COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317645000446",
    },
    {
        "school": "SCHUYLER ELEMENTARY SCHOOL",
        "district": "SCHUYLER COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317645001576",
    },
    {
        "school": "JACKSON ELEMENTARY",
        "district": "PONCA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317577001097",
    },
    {
        "school": "PINK SCHOOL",
        "district": "SIOUX COUNTY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317680000600",
    },
    {
        "school": "MANCHESTER ELEMENTARY SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011002006",
    },
    {
        "school": "GARDEN COUNTY ELEMENTARY SCH",
        "district": "GARDEN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317080001806",
    },
    {
        "school": "BURWELL ELEMENTARY SCHOOL",
        "district": "BURWELL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310464000111",
    },
    {
        "school": "HYANNIS ELEMENTARY SCHOOL",
        "district": "HYANNIS AREA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317221000216",
    },
    {
        "school": "GRAND ISLAND INTERVENTION AND ASSESSMENT SHELTER",
        "district": "BOYS TOWN INTERIM PRG SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310014602010",
    },
    {
        "school": "1R ELEMENTARY",
        "district": "NORTHWEST PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317458000209",
    },
    {
        "school": "CEDAR HOLLOW SCHOOL",
        "district": "NORTHWEST PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317458000253",
    },
    {
        "school": "WOOD RIVER ELEMENTARY SCHOOL",
        "district": "WOOD RIVER RURAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317894001743",
    },
    {
        "school": "STRATTON ELEMENTARY SCHOOL",
        "district": "DUNDY CO STRATTON PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007701999",
    },
    {
        "school": "ATKINSON ELEMENTARY SCHOOL",
        "district": "WEST HOLT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017200037",
    },
    {
        "school": "UNION ELEMENTARY SCHOOL",
        "district": "WEST HOLT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017200725",
    },
    {
        "school": "WEST HOLT HIGH SCHOOL",
        "district": "WEST HOLT PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017202008",
    },
    {
        "school": "ST LIBORY ELEMENTARY SCHOOL",
        "district": "NORTHWEST PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317458000965",
    },
    {
        "school": "JOHNSON CO CENTRAL HIGH SCHOOL",
        "district": "JOHNSON CO CENTRAL PUBLIC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017602009",
    },
    {
        "school": "JOHNSON CO CENTRAL MIDDLE SCH",
        "district": "JOHNSON CO CENTRAL PUBLIC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017602022",
    },
    {
        "school": "JOHNSON CO CENTRAL EL-TECUMSEH",
        "district": "JOHNSON CO CENTRAL PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017602030",
    },
    {
        "school": "JOHNSON CO CENTRAL ELEM-COOK",
        "district": "JOHNSON CO CENTRAL PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017602038",
    },
    {
        "school": "SPRING VIEW ELEMENTARY SCHOOL",
        "district": "KEYA PAHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317248000661",
    },
    {
        "school": "LAKE MALONEY ELEMENTARY SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002200601",
    },
    {
        "school": "TRYON ELEMENTARY",
        "district": "MC PHERSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317356000256",
    },
    {
        "school": "CHAPMAN ELEMENTARY SCHOOL",
        "district": "NORTHWEST PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317458000144",
    },
    {
        "school": "SUPERIOR JR/SR HIGH SCHOOL",
        "district": "SUPERIOR PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002902032",
    },
    {
        "school": "RICHLAND ELEMENTARY SCHOOL",
        "district": "SCHUYLER COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317645000215",
    },
    {
        "school": "BASSETT GRADE SCHOOL",
        "district": "ROCK COUNTY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317617000212",
    },
    {
        "school": "PONY LAKE SCHOOL",
        "district": "ROCK COUNTY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317617000498",
    },
    {
        "school": "LAKE MINATARE SCHOOL",
        "district": "SCOTTSBLUFF PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317647001119",
    },
    {
        "school": "CHALK BUTTE SCHOOL",
        "district": "SIOUX COUNTY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317680001907",
    },
    {
        "school": "GORDON-RUSHVILLE ELEM-GORDON",
        "district": "GORDON-RUSHVILLE PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017001840",
    },
    {
        "school": "GORDON-RUSHVILLE ELE-RUSHVILLE",
        "district": "GORDON-RUSHVILLE PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017001847",
    },
    {
        "school": "GORDON-RUSHVILLE MIDDLE SCHOOL",
        "district": "GORDON-RUSHVILLE PUBLIC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017001850",
    },
    {
        "school": "HAY SPRINGS EARLY CHILDHOOD",
        "district": "HAY SPRINGS PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317161002017",
    },
    {
        "school": "HARRISON GRADE SCHOOL",
        "district": "SIOUX COUNTY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317680001045",
    },
    {
        "school": "THEDFORD ELEM ATTENDANCE CNTR",
        "district": "THEDFORD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317773000263",
    },
    {
        "school": "CHASE COUNTY HIGH SCHOOL",
        "district": "CHASE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310016301772",
    },
    {
        "school": "CHASE COUNTY ELEMENTARY SCHOOL",
        "district": "CHASE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310016301773",
    },
    {
        "school": "CREEK VALLEY HIGH SCHOOL",
        "district": "CREEK VALLEY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310014001419",
    },
    {
        "school": "CREEK VALLEY ELEMENTARY SCHOOL",
        "district": "CREEK VALLEY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310014001423",
    },
    {
        "school": "EXETER-MILLIGAN HIGH SCHOOL",
        "district": "EXETER-MILLIGAN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310013301344",
    },
    {
        "school": "EXETER-MILLIGAN ELEM-EXETER",
        "district": "EXETER-MILLIGAN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310013301346",
    },
    {
        "school": "EXETER-MILLIGAN ELEM-MILLIGAN",
        "district": "EXETER-MILLIGAN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310013301350",
    },
    {
        "school": "HITCHCOCK CO JR/SR HIGH SCHOOL",
        "district": "HITCHCOCK CO SCH SYSTEM",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012001562",
    },
    {
        "school": "NIOBRARA SECONDARY SCHOOL",
        "district": "NIOBRARA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317437001604",
    },
    {
        "school": "NIOBRARA ELEMENTARY SCHOOL",
        "district": "NIOBRARA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317437001655",
    },
    {
        "school": "HTRS MIDDLE SCHOOL",
        "district": "HUMBOLDT TABLE ROCK STEINAUER",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017902190",
    },
    {
        "school": "PERKINS COUNTY JUNIOR- SENIOR HIGH SCHOOL",
        "district": "PERKINS COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310015701827",
    },
    {
        "school": "PERKINS COUNTY ELEMENTARY SCH",
        "district": "PERKINS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310015701831",
    },
    {
        "school": "HOLDREGE PUBLIC SCHOOLS EARLY CHILDHOOD ED CTR",
        "district": "HOLDREGE PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317194001749",
    },
    {
        "school": "SOUTHWEST JR/SR HIGH SCHOOL",
        "district": "SOUTHWEST PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017801758",
    },
    {
        "school": "SOUTHWEST ELEMENTARY-INDIANOLA",
        "district": "SOUTHWEST PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017802188",
    },
    {
        "school": "HTRS HIGH SCHOOL",
        "district": "HUMBOLDT TABLE ROCK STEINAUER",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017902189",
    },
    {
        "school": "HTRS ELEMENTARY SCHOOL",
        "district": "HUMBOLDT TABLE ROCK STEINAUER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017902191",
    },
    {
        "school": "CRETE MIDDLE SCHOOL",
        "district": "CRETE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009501759",
    },
    {
        "school": "GORDON-RUSHVILLE HIGH SCHOOL",
        "district": "GORDON-RUSHVILLE PUBLIC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017001839",
    },
    {
        "school": "HAY SPRINGS MIDDLE SCHOOL",
        "district": "HAY SPRINGS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317161002193",
    },
    {
        "school": "UMO N HO N NATION MIDDLE SCH",
        "district": "UMO N HO N NATION PUBLIC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "311956002194",
    },
    {
        "school": "CLEARWATER ELEMENTARY SCHOOL",
        "district": "NEBRASKA UNIFIED DISTRICT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011900154",
    },
    {
        "school": "CLEARWATER HIGH SCHOOL",
        "district": "NEBRASKA UNIFIED DISTRICT 1",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011900155",
    },
    {
        "school": "ORCHARD ELEMENTARY SCHOOL",
        "district": "NEBRASKA UNIFIED DISTRICT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011901450",
    },
    {
        "school": "ORCHARD HIGH SCHOOL",
        "district": "NEBRASKA UNIFIED DISTRICT 1",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011901451",
    },
    {
        "school": "ELGIN ELEMENTARY SCHOOL",
        "district": "ELGIN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317005000922",
    },
    {
        "school": "ELGIN HIGH SCHOOL",
        "district": "ELGIN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317005000923",
    },
    {
        "school": "NELIGH-OAKDALE HIGH SCHOOL",
        "district": "NELIGH-OAKDALE SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317422001292",
    },
    {
        "school": "CENTRAL LEARNING CENTER",
        "district": "EDUCATIONAL SERVICE UNIT 08",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "318008001971",
    },
    {
        "school": "ARTHUR COUNTY HIGH SCHOOL",
        "district": "ARTHUR COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310321000033",
    },
    {
        "school": "ELEMENTARY SCHOOL AT HALSEY",
        "district": "SANDHILLS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317638001569",
    },
    {
        "school": "HIGH SCHOOL AT DUNNING",
        "district": "SANDHILLS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317638001570",
    },
    {
        "school": "BOONE CENTRAL ELEM-ALBION",
        "district": "BOONE CENTRAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310282000007",
    },
    {
        "school": "BOONE CENTRAL HIGH SCHOOL",
        "district": "BOONE CENTRAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310282000008",
    },
    {
        "school": "BOONE CENTRAL MIDDLE SCHOOL",
        "district": "BOONE CENTRAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310282000701",
    },
    {
        "school": "ST EDWARD ELEMENTARY SCHOOL",
        "district": "ST EDWARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317698001621",
    },
    {
        "school": "ST EDWARD HIGH SCHOOL",
        "district": "ST EDWARD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317698001622",
    },
    {
        "school": "ALLIANCE HIGH SCHOOL",
        "district": "ALLIANCE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310291000011",
    },
    {
        "school": "ALLIANCE MIDDLE SCHOOL",
        "district": "ALLIANCE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310291000012",
    },
    {
        "school": "EMERSON ELEMENTARY SCHOOL",
        "district": "ALLIANCE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310291000014",
    },
    {
        "school": "GRANDVIEW ELEMENTARY SCHOOL",
        "district": "ALLIANCE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310291000015",
    },
    {
        "school": "ALLIANCE EARLY CHILD ED PROG",
        "district": "ALLIANCE PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310291001854",
    },
    {
        "school": "HEMINGFORD ELEMENTARY SCHOOL",
        "district": "HEMINGFORD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317173001062",
    },
    {
        "school": "HEMINGFORD HIGH SCHOOL",
        "district": "HEMINGFORD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317173001063",
    },
    {
        "school": "AINSWORTH ELEMENTARY SCHOOL",
        "district": "AINSWORTH COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310279000005",
    },
    {
        "school": "AINSWORTH HIGH SCHOOL",
        "district": "AINSWORTH COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310279000006",
    },
    {
        "school": "AINSWORTH MIDDLE SCHOOL",
        "district": "AINSWORTH COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310279000202",
    },
    {
        "school": "NORTHEAST ELEMENTARY AT LYONS",
        "district": "LYONS-DECATUR NORTHEAST SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317321001203",
    },
    {
        "school": "NORTHEAST SECONDARY SCHOOL",
        "district": "LYONS-DECATUR NORTHEAST SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317321001204",
    },
    {
        "school": "OAKLAND CRAIG JUNIOR-SENIOR HIGH",
        "district": "OAKLAND CRAIG PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317464001336",
    },
    {
        "school": "OAKLAND CRAIG ELEMENTARY",
        "district": "OAKLAND CRAIG PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317464001337",
    },
    {
        "school": "DAVID CITY ELEMENTARY SCHOOL",
        "district": "DAVID CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000200191",
    },
    {
        "school": "DAVID CITY SECONDARY SCHOOL",
        "district": "DAVID CITY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000200192",
    },
    {
        "school": "BELLWOOD ELEMENTARY SCHOOL",
        "district": "DAVID CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000200975",
    },
    {
        "school": "ELEMENTARY SCHOOL AT BRAINARD",
        "district": "EAST BUTLER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000300916",
    },
    {
        "school": "ELEMENTARY SCHOOL AT DWIGHT",
        "district": "EAST BUTLER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000300917",
    },
    {
        "school": "HIGH SCHOOL AT BRAINARD",
        "district": "EAST BUTLER PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000300918",
    },
    {
        "school": "LAUREL-CONCORD-COLERIDGE ELEMENTARY SCHOOL",
        "district": "LAUREL-CONCORD-COLERIDGE SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000401121",
    },
    {
        "school": "LAUREL-CONCORD-COLERIDGE HIGH SCHOOL",
        "district": "LAUREL-CONCORD-COLERIDGE SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000401122",
    },
    {
        "school": "HARTINGTON-NEWCASTLE ELEM AT HARTINGTON",
        "district": "HARTINGTON NEWCASTLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317152001046",
    },
    {
        "school": "HARTINGTON NEWCASTLE HIGH SCHOOL",
        "district": "HARTINGTON NEWCASTLE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317152001047",
    },
    {
        "school": "RANDOLPH ELEMENTARY SCHOOL",
        "district": "RANDOLPH PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317593001545",
    },
    {
        "school": "RANDOLPH HIGH SCHOOL",
        "district": "RANDOLPH PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317593001546",
    },
    {
        "school": "WYNOT ELEMENTARY SCHOOL",
        "district": "WYNOT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317899001745",
    },
    {
        "school": "WYNOT HIGH SCHOOL",
        "district": "WYNOT PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317899001746",
    },
    {
        "school": "WYNOT MIDDLE SCHOOL",
        "district": "WYNOT PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317899002117",
    },
    {
        "school": "WAUNETA-PALISADE HIGH SCHOOL",
        "district": "WAUNETA-PALISADE PUBLIC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001800059",
    },
    {
        "school": "WAUNETA PALISADE MIDDLE SCHOOL",
        "district": "WAUNETA-PALISADE PUBLIC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001800075",
    },
    {
        "school": "CODY-KILGORE ELEMENTARY SCHOOL",
        "district": "CODY-KILGORE PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310528000156",
    },
    {
        "school": "CODY-KILGORE HIGH SCHOOL",
        "district": "CODY-KILGORE PUBLIC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310528000157",
    },
    {
        "school": "VALENTINE HIGH SCHOOL",
        "district": "VALENTINE COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317802001674",
    },
    {
        "school": "LEYTON HIGH SCHOOL",
        "district": "LEYTON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007200188",
    },
    {
        "school": "LEYTON ELEMENTARY/JUNIOR HIGH SCHOOL",
        "district": "LEYTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007201879",
    },
    {
        "school": "POTTER-DIX JR/SR HIGH SCHOOL",
        "district": "POTTER-DIX PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317581001533",
    },
    {
        "school": "WEST ELEMENTARY SCHOOL",
        "district": "SIDNEY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317671000076",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "SIDNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317671001599",
    },
    {
        "school": "NORTH WARD ELEMENTARY SCHOOL",
        "district": "SIDNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317671001600",
    },
    {
        "school": "SIDNEY HIGH SCHOOL",
        "district": "SIDNEY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317671001601",
    },
    {
        "school": "SIDNEY MIDDLE SCHOOL",
        "district": "SIDNEY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317671001602",
    },
    {
        "school": "SOUTH WARD ELEMENTARY SCHOOL",
        "district": "SIDNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317671001603",
    },
    {
        "school": "CLARKSON ELEMENTARY SCHOOL",
        "district": "CLARKSON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310516000150",
    },
    {
        "school": "CLARKSON JR-SR HIGH SCHOOL",
        "district": "CLARKSON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310516000151",
    },
    {
        "school": "LEIGH ELEMENTARY SCHOOL",
        "district": "LEIGH COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317272001125",
    },
    {
        "school": "LEIGH HIGH SCHOOL",
        "district": "LEIGH COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317272001126",
    },
    {
        "school": "SCHUYLER CENTRAL HIGH SCHOOL",
        "district": "SCHUYLER COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317645001575",
    },
    {
        "school": "WEST POINT ELEMENTARY SCHOOL",
        "district": "WEST POINT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000601706",
    },
    {
        "school": "WEST POINT-BEEMER HIGH SCHOOL",
        "district": "WEST POINT PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000601707",
    },
    {
        "school": "WISNER-PILGER ELEM SCHOOL",
        "district": "WISNER-PILGER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000801733",
    },
    {
        "school": "WISNER-PILGER HIGH SCHOOL",
        "district": "WISNER-PILGER PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000801734",
    },
    {
        "school": "BANCROFT-ROSALIE JR/SR HIGH SCHOOL",
        "district": "BANCROFT-ROSALIE COMM SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310344000049",
    },
    {
        "school": "BANCROFT-ROSALIE ELEMENTARY SCHOOL",
        "district": "BANCROFT-ROSALIE COMM SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310344000657",
    },
    {
        "school": "ANSELMO-MERNA ELEMENTARY-MERNA",
        "district": "ANSELMO-MERNA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001000021",
    },
    {
        "school": "ANSELMO-MERNA HIGH SCHOOL",
        "district": "ANSELMO-MERNA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001000022",
    },
    {
        "school": "BROKEN BOW HIGH SCHOOL",
        "district": "BROKEN BOW PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001100103",
    },
    {
        "school": "EARLY CHILDHOOD SERVICES",
        "district": "BROKEN BOW PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001101855",
    },
    {
        "school": "NORTH PARK ELEMENTARY SCHOOL",
        "district": "BROKEN BOW PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001101861",
    },
    {
        "school": "BROKEN BOW MIDDLE SCHOOL",
        "district": "BROKEN BOW PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001101882",
    },
    {
        "school": "CALLAWAY ELEMENTARY SCHOOL",
        "district": "CALLAWAY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001200119",
    },
    {
        "school": "CALLAWAY HIGH SCHOOL",
        "district": "CALLAWAY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001200120",
    },
    {
        "school": "ARNOLD ELEMENTARY SCHOOL",
        "district": "ARNOLD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007300031",
    },
    {
        "school": "ARNOLD HIGH SCHOOL",
        "district": "ARNOLD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007300032",
    },
    {
        "school": "ANSLEY ELEMENTARY SCHOOL",
        "district": "ANSLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310306000023",
    },
    {
        "school": "ANSLEY HIGH SCHOOL",
        "district": "ANSLEY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310306000024",
    },
    {
        "school": "SARGENT ELEMENTARY SCHOOL",
        "district": "SARGENT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317641001573",
    },
    {
        "school": "SARGENT HIGH SCHOOL",
        "district": "SARGENT PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317641001574",
    },
    {
        "school": "PINE RIDGE JOB CORPS",
        "district": "PINE RIDGE JOB CORPS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310004701868",
    },
    {
        "school": "CHADRON SENIOR HIGH SCHOOL",
        "district": "CHADRON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310498000138",
    },
    {
        "school": "CHADRON PRIMARY",
        "district": "CHADRON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310498000139",
    },
    {
        "school": "CHADRON INTERMEDIATE",
        "district": "CHADRON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310498000140",
    },
    {
        "school": "CHADRON MIDDLE SCHOOL",
        "district": "CHADRON PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310498000141",
    },
    {
        "school": "CRAWFORD ELEMENTARY SCHOOL",
        "district": "CRAWFORD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310552000177",
    },
    {
        "school": "CRAWFORD HIGH SCHOOL",
        "district": "CRAWFORD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310552000178",
    },
    {
        "school": "SOUTH PLATTE HIGH SCHOOL",
        "district": "SOUTH PLATTE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011000348",
    },
    {
        "school": "SO PLATTE ELEM AT BIG SPRINGS",
        "district": "SOUTH PLATTE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011000353",
    },
    {
        "school": "DUNDY CO STRATTON HIGH SCHOOL",
        "district": "DUNDY CO STRATTON PUBLIC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007701885",
    },
    {
        "school": "BENKELMAN ELEMENTARY SCHOOL",
        "district": "DUNDY CO STRATTON PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007701886",
    },
    {
        "school": "GENEVA NORTH HIGH SCHOOL",
        "district": "GENEVA NORTH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310005101872",
    },
    {
        "school": "GENEVA NORTH ELEMENTARY SCHOOL",
        "district": "GENEVA NORTH SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310005101873",
    },
    {
        "school": "FILLMORE CENTRAL MIDDLE SCHOOL",
        "district": "FILLMORE CENTRAL PUBLIC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011800734",
    },
    {
        "school": "FILLMORE CENTRAL ELEMENTARY",
        "district": "FILLMORE CENTRAL PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011800992",
    },
    {
        "school": "FILLMORE CENTRAL HIGH SCHOOL",
        "district": "FILLMORE CENTRAL PUBLIC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011800993",
    },
    {
        "school": "SHICKLEY ELEMENTARY SCHOOL",
        "district": "SHICKLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317665001597",
    },
    {
        "school": "SHICKLEY HIGH SCHOOL",
        "district": "SHICKLEY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317665001598",
    },
    {
        "school": "FRANKLIN ELEMENTARY SCHOOL",
        "district": "FRANKLIN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310006500970",
    },
    {
        "school": "FRANKLIN SECONDARY SCHOOL",
        "district": "FRANKLIN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310006500971",
    },
    {
        "school": "EUSTIS-FARNAM HIGH SCHOOL",
        "district": "EUSTIS-FARNAM PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011100470",
    },
    {
        "school": "ELEMENTARY SCHOOL AT EUSTIS",
        "district": "EUSTIS-FARNAM PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011100481",
    },
    {
        "school": "MAYWOOD ELEMENTARY SCHOOL",
        "district": "MAYWOOD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317344001216",
    },
    {
        "school": "MAYWOOD HIGH SCHOOL",
        "district": "MAYWOOD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317344001217",
    },
    {
        "school": "MEDICINE VALLEY ELEMENTARY",
        "district": "MEDICINE VALLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317360001810",
    },
    {
        "school": "MEDICINE VALLEY JR-SR HIGH SCHOOL",
        "district": "MEDICINE VALLEY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317360001812",
    },
    {
        "school": "CAMBRIDGE ELEMENTARY SCHOOL",
        "district": "CAMBRIDGE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001500121",
    },
    {
        "school": "CAMBRIDGE HIGH SCHOOL",
        "district": "CAMBRIDGE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001500122",
    },
    {
        "school": "SOUTHERN VALLEY JR/SR HIGH",
        "district": "SOUTHERN VALLEY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310010901464",
    },
    {
        "school": "ARAPAHOE ELEMENTARY SCHOOL",
        "district": "ARAPAHOE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310309000025",
    },
    {
        "school": "ARAPAHOE HIGH SCHOOL",
        "district": "ARAPAHOE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310309000026",
    },
    {
        "school": "GARDEN COUNTY JUNIOR/SENIOR HIGH SCHOOL",
        "district": "GARDEN COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317080000991",
    },
    {
        "school": "BURWELL JR-SR HIGH SCHOOL",
        "district": "BURWELL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310464000112",
    },
    {
        "school": "HYANNIS HIGH SCHOOL",
        "district": "HYANNIS AREA SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317221001096",
    },
    {
        "school": "AURORA ELEMENTARY SCHOOL",
        "district": "AURORA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310336000043",
    },
    {
        "school": "AURORA HIGH SCHOOL",
        "district": "AURORA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310336000044",
    },
    {
        "school": "AURORA MIDDLE SCHOOL",
        "district": "AURORA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310336000045",
    },
    {
        "school": "GILTNER ELEMENTARY SCHOOL",
        "district": "GILTNER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317101001007",
    },
    {
        "school": "GILTNER HIGH SCHOOL",
        "district": "GILTNER PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317101001008",
    },
    {
        "school": "HAMPTON ELEMENTARY SCHOOL",
        "district": "HAMPTON PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317137001041",
    },
    {
        "school": "HAMPTON HIGH SCHOOL",
        "district": "HAMPTON PUBLIC SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317137001042",
    },
    {
        "school": "ALMA ELEMENTARY AT ALMA",
        "district": "ALMA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008000016",
    },
    {
        "school": "ALMA HIGH SCHOOL",
        "district": "ALMA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008000017",
    },
    {
        "school": "HAYES CENTER ELEMENTARY SCHOOL",
        "district": "HAYES CENTER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310912000258",
    },
    {
        "school": "HAYES CENTER SECONDARY SCHOOL",
        "district": "HAYES CENTER PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310912000259",
    },
    {
        "school": "PALISADE ATTENDANCE CENTER",
        "district": "WAUNETA-PALISADE PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001800068",
    },
    {
        "school": "HITCHCOCK CO ELEMENTARY",
        "district": "HITCHCOCK CO SCH SYSTEM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012000185",
    },
    {
        "school": "EWING ELEMENTARY SCHOOL",
        "district": "EWING PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002000942",
    },
    {
        "school": "EWING HIGH SCHOOL",
        "district": "EWING PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002000943",
    },
    {
        "school": "STUART ELEMENTARY SCHOOL",
        "district": "STUART PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008201639",
    },
    {
        "school": "STUART HIGH SCHOOL",
        "district": "STUART PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008201640",
    },
    {
        "school": "CHAMBERS ELEMENTARY SCHOOL",
        "district": "CHAMBERS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310501000142",
    },
    {
        "school": "CHAMBERS HIGH SCHOOL",
        "district": "CHAMBERS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310501000143",
    },
    {
        "school": "O'NEILL ELEMENTARY SCHOOL",
        "district": "O'NEILL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317485001447",
    },
    {
        "school": "O'NEILL HIGH SCHOOL",
        "district": "O'NEILL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317485001448",
    },
    {
        "school": "MULLEN ELEMENTARY SCHOOL",
        "district": "MULLEN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317404001275",
    },
    {
        "school": "MULLEN HIGH SCHOOL",
        "district": "MULLEN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317404001276",
    },
    {
        "school": "TRI COUNTY JR-SR HIGH SCHOOL",
        "district": "TRI COUNTY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310597000201",
    },
    {
        "school": "TRI COUNTY ELEMENTARY SCHOOL",
        "district": "TRI COUNTY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310597001848",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "FAIRBURY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317044000946",
    },
    {
        "school": "FAIRBURY JR-SR HIGH SCHOOL",
        "district": "FAIRBURY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317044000948",
    },
    {
        "school": "JEFFERSON INTERMEDIATE SCHOOL",
        "district": "FAIRBURY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317044001928",
    },
    {
        "school": "MERIDIAN ELEMENTARY SCHOOL",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317366001235",
    },
    {
        "school": "MERIDIAN HIGH SCHOOL",
        "district": "MERIDIAN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317366001236",
    },
    {
        "school": "STERLING ELEMENTARY SCHOOL",
        "district": "STERLING PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317719001633",
    },
    {
        "school": "STERLING HIGH SCHOOL",
        "district": "STERLING PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317719001634",
    },
    {
        "school": "OGALLALA HIGH SCHOOL",
        "district": "OGALLALA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317476001341",
    },
    {
        "school": "PAXTON ELEMENTARY SCHOOL",
        "district": "PAXTON CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317536001486",
    },
    {
        "school": "PAXTON HIGH SCHOOL",
        "district": "PAXTON CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317536001487",
    },
    {
        "school": "KEYA PAHA COUNTY HIGH SCHOOL",
        "district": "KEYA PAHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317248001113",
    },
    {
        "school": "KIMBALL JR/SR HIGH SCHOOL",
        "district": "KIMBALL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317257001117",
    },
    {
        "school": "MARY LYNCH ELEMENTARY",
        "district": "KIMBALL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317257001932",
    },
    {
        "school": "POTTER-DIX ELEMENTARY SCHOOL",
        "district": "POTTER-DIX PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317581001914",
    },
    {
        "school": "VERDIGRE HIGH SCHOOL",
        "district": "NEBRASKA UNIFIED DISTRICT 1",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011901679",
    },
    {
        "school": "VERDIGRE ELEMENTARY SCHOOL",
        "district": "NEBRASKA UNIFIED DISTRICT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011901680",
    },
    {
        "school": "BLOOMFIELD ELEMENTARY SCHOOL",
        "district": "BLOOMFIELD COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310414000092",
    },
    {
        "school": "BLOOMFIELD JR-SR HIGH SCHOOL",
        "district": "BLOOMFIELD COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310414000093",
    },
    {
        "school": "CREIGHTON COMMUNITY HIGH SCH",
        "district": "CREIGHTON COMMUNITY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310555000179",
    },
    {
        "school": "CREIGHTON ELEMENTARY SCHOOL",
        "district": "CREIGHTON COMMUNITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310555000180",
    },
    {
        "school": "CROFTON ELEMENTARY SCHOOL",
        "district": "CROFTON COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310563000183",
    },
    {
        "school": "CROFTON HIGH SCHOOL",
        "district": "CROFTON COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310563000184",
    },
    {
        "school": "SANTEE ELEMENTARY SCHOOL",
        "district": "SANTEE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317640001571",
    },
    {
        "school": "SANTEE HIGH SCHOOL",
        "district": "SANTEE COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317640001572",
    },
    {
        "school": "WAUSA ELEMENTARY SCHOOL",
        "district": "WAUSA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317845001695",
    },
    {
        "school": "WAUSA HIGH SCHOOL",
        "district": "WAUSA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317845001696",
    },
    {
        "school": "LOUP COUNTY ELEMENTARY SCHOOL",
        "district": "LOUP COUNTY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317312001197",
    },
    {
        "school": "LOUP COUNTY HIGH SCHOOL",
        "district": "LOUP COUNTY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317312001198",
    },
    {
        "school": "EASTERN LEARNING CENTER",
        "district": "EDUCATIONAL SERVICE UNIT 08",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "318008001970",
    },
    {
        "school": "HIGH PLAINS COMMUNITY ELEMENTARY SCHOOL",
        "district": "HIGH PLAINS COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012300816",
    },
    {
        "school": "BAYARD ELEMENTARY SCHOOL",
        "district": "BAYARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009000056",
    },
    {
        "school": "BAYARD SECONDARY SCHOOL",
        "district": "BAYARD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009000057",
    },
    {
        "school": "BRIDGEPORT ELEMENTARY SCHOOL",
        "district": "BRIDGEPORT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310010500100",
    },
    {
        "school": "BRIDGEPORT HIGH SCHOOL",
        "district": "BRIDGEPORT PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310010500101",
    },
    {
        "school": "FULLERTON ELEMENTARY SCHOOL",
        "district": "FULLERTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009100989",
    },
    {
        "school": "FULLERTON HIGH SCHOOL",
        "district": "FULLERTON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009100990",
    },
    {
        "school": "TWIN RIVER SR HIGH SCHOOL",
        "district": "TWIN RIVER PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012901076",
    },
    {
        "school": "TWIN RIVER ELEM-GENOA",
        "district": "TWIN RIVER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012901079",
    },
    {
        "school": "AUBURN HIGH SCHOOL",
        "district": "AUBURN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310333000038",
    },
    {
        "school": "AUBURN MIDDLE SCHOOL",
        "district": "AUBURN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310333000039",
    },
    {
        "school": "CALVERT ELEMENTARY",
        "district": "AUBURN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310333000040",
    },
    {
        "school": "HIGH SCHOOL AT JOHNSON",
        "district": "JOHNSON-BROCK PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317233501099",
    },
    {
        "school": "ELEMENTARY SCHOOL AT JOHNSON",
        "district": "JOHNSON-BROCK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317233501911",
    },
    {
        "school": "LEARNING CENTER",
        "district": "EDUCATIONAL SERVICE UNIT 04",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "318004001960",
    },
    {
        "school": "HAYWARD ELEMENTARY SCHOOL",
        "district": "NEBRASKA CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317416001283",
    },
    {
        "school": "NEBRASKA CITY MIDDLE SCHOOL",
        "district": "NEBRASKA CITY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317416001284",
    },
    {
        "school": "NEBRASKA CITY NORTHSIDE ELEM",
        "district": "NEBRASKA CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317416001285",
    },
    {
        "school": "NEBRASKA CITY HIGH SCHOOL",
        "district": "NEBRASKA CITY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317416001286",
    },
    {
        "school": "ELEMENTARY SCHOOL AT SYRACUSE",
        "district": "SYRACUSE-DUNBAR-AVOCA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317755001653",
    },
    {
        "school": "HIGH SCHOOL AT SYRACUSE",
        "district": "SYRACUSE-DUNBAR-AVOCA SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317755001654",
    },
    {
        "school": "NE CENTER FOR EDUC OF BLIND",
        "district": "EDUCATIONAL SERVICE UNIT 04",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "318004000628",
    },
    {
        "school": "LEWISTON ELEMENTARY SCHOOL",
        "district": "LEWISTON CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317278001128",
    },
    {
        "school": "LEWISTON HIGH SCHOOL",
        "district": "LEWISTON CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317278001129",
    },
    {
        "school": "PAWNEE CITY ELEMENTARY SCH",
        "district": "PAWNEE CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317533001484",
    },
    {
        "school": "PAWNEE CITY SECONDARY SCHOOL",
        "district": "PAWNEE CITY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317533001485",
    },
    {
        "school": "BERTRAND ELEMENTARY SCHOOL",
        "district": "BERTRAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310402000079",
    },
    {
        "school": "BERTRAND HIGH SCHOOL",
        "district": "BERTRAND PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310402000080",
    },
    {
        "school": "HOLDREGE HIGH SCHOOL",
        "district": "HOLDREGE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317194001074",
    },
    {
        "school": "HOLDREGE MIDDLE SCHOOL",
        "district": "HOLDREGE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317194001075",
    },
    {
        "school": "LOOMIS ELEMENTARY SCHOOL",
        "district": "LOOMIS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317299001189",
    },
    {
        "school": "LOOMIS SECONDARY SCHOOL",
        "district": "LOOMIS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317299001190",
    },
    {
        "school": "HIGH PLAINS COMMUNITY JR/SR HIGH SCHOOL",
        "district": "HIGH PLAINS COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012300815",
    },
    {
        "school": "CROSS COUNTY MIDDLE SCHOOL",
        "district": "CROSS COUNTY COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310013001180",
    },
    {
        "school": "CROSS COUNTY HIGH SCHOOL",
        "district": "CROSS COUNTY COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310013001182",
    },
    {
        "school": "CROSS COUNTY ELEMENTARY SCHOOL",
        "district": "CROSS COUNTY COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310013001224",
    },
    {
        "school": "OSCEOLA MIDDLE SCHOOL",
        "district": "OSCEOLA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317500001228",
    },
    {
        "school": "OSCEOLA ELEMENTARY SCHOOL",
        "district": "OSCEOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317500001457",
    },
    {
        "school": "OSCEOLA HIGH SCHOOL",
        "district": "OSCEOLA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317500001458",
    },
    {
        "school": "SHELBY - RISING CITY ELEMENTARY SCHOOL",
        "district": "SHELBY - RISING CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317659001593",
    },
    {
        "school": "SHELBY - RISING CITY  HIGH SCHOOL",
        "district": "SHELBY - RISING CITY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317659001594",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "MC COOK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317347001219",
    },
    {
        "school": "MC COOK JUNIOR HIGH SCHOOL",
        "district": "MC COOK PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317347001221",
    },
    {
        "school": "MC COOK SENIOR HIGH SCHOOL",
        "district": "MC COOK PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317347001222",
    },
    {
        "school": "MC COOK ELEMENTARY SCHOOL",
        "district": "MC COOK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317347001223",
    },
    {
        "school": "MC COOK ALTERNATIVE EDUCATION",
        "district": "MC COOK PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317347001233",
    },
    {
        "school": "STEP SCHOOL",
        "district": "EDUCATIONAL SERVICE UNIT 15",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "318015000645",
    },
    {
        "school": "FALLS CITY SENIOR HIGH",
        "district": "FALLS CITY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317053000959",
    },
    {
        "school": "FALLS CITY NORTH ELEMENTARY",
        "district": "FALLS CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317053000960",
    },
    {
        "school": "FALLS CITY SOUTH ELEMENTARY",
        "district": "FALLS CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317053000961",
    },
    {
        "school": "FALLS CITY MIDDLE SCHOOL",
        "district": "FALLS CITY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317053001804",
    },
    {
        "school": "ROCK COUNTY HIGH SCHOOL",
        "district": "ROCK COUNTY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317617001559",
    },
    {
        "school": "CRETE ELEMENTARY SCHOOL",
        "district": "CRETE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009500181",
    },
    {
        "school": "CRETE HIGH SCHOOL",
        "district": "CRETE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009500182",
    },
    {
        "school": "FRIEND ELEMENTARY SCHOOL",
        "district": "FRIEND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009600987",
    },
    {
        "school": "FRIEND HIGH SCHOOLS",
        "district": "FRIEND PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009600988",
    },
    {
        "school": "DORCHESTER ELEMENTARY SCHOOL",
        "district": "DORCHESTER PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "316984000912",
    },
    {
        "school": "DORCHESTER HIGH SCHOOL",
        "district": "DORCHESTER PUBLIC SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "316984000913",
    },
    {
        "school": "ELEMENTARY SCHOOL AT WILBER",
        "district": "WILBER-CLATONIA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317872001727",
    },
    {
        "school": "WILBER-CLATONIA HIGH SCHOOL",
        "district": "WILBER-CLATONIA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317872001729",
    },
    {
        "school": "HAY SPRINGS ELEMENTARY SCHOOL",
        "district": "HAY SPRINGS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317161001058",
    },
    {
        "school": "HAY SPRINGS HIGH SCHOOL",
        "district": "HAY SPRINGS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317161001059",
    },
    {
        "school": "LITCHFIELD ELEMENTARY SCHOOL",
        "district": "LITCHFIELD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317291001185",
    },
    {
        "school": "LITCHFIELD HIGH SCHOOL",
        "district": "LITCHFIELD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317291001186",
    },
    {
        "school": "LOUP CITY ELEMENTARY SCHOOL",
        "district": "LOUP CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317309001194",
    },
    {
        "school": "LOUP CITY HIGH SCHOOL",
        "district": "LOUP CITY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317309001195",
    },
    {
        "school": "SIOUX COUNTY HIGH SCHOOL",
        "district": "SIOUX COUNTY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317680001607",
    },
    {
        "school": "BRUNING-DAVENPORT HIGH SCHOOL",
        "district": "BRUNING-DAVENPORT UNIFIED SYS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012400853",
    },
    {
        "school": "BRUNING-DAVENPORT MIDDLE SCH",
        "district": "BRUNING-DAVENPORT UNIFIED SYS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012400865",
    },
    {
        "school": "BRUNING-DAVENPORT ELEM/BRUNING",
        "district": "BRUNING-DAVENPORT UNIFIED SYS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012400868",
    },
    {
        "school": "BRUNING-DAVENPORT ELEM/DAVENPT",
        "district": "BRUNING-DAVENPORT UNIFIED SYS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012400877",
    },
    {
        "school": "THAYER CENTRAL HIGH SCHOOL",
        "district": "THAYER CENTRAL COMMUNITY SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310013201258",
    },
    {
        "school": "THAYER CENTRAL ELEMENTARY",
        "district": "THAYER CENTRAL COMMUNITY SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310013201273",
    },
    {
        "school": "DESHLER ELEMENTARY SCHOOL",
        "district": "DESHLER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310591000197",
    },
    {
        "school": "DESHLER HIGH SCHOOL",
        "district": "DESHLER PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310591000198",
    },
    {
        "school": "THEDFORD HIGH SCHOOL",
        "district": "THEDFORD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317773001663",
    },
    {
        "school": "UMO N HO N NATION ELEM SCHOOL",
        "district": "UMO N HO N NATION PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "311956000376",
    },
    {
        "school": "UMO N HO N NATION HIGH SCHOOL",
        "district": "UMO N HO N NATION PUBLIC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "311956000377",
    },
    {
        "school": "PENDER HIGH SCHOOL",
        "district": "PENDER PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317539001489",
    },
    {
        "school": "PENDER ELEMENTARY SCHOOL",
        "district": "PENDER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317539001490",
    },
    {
        "school": "WALTHILL ELEMENTARY SCHOOL",
        "district": "WALTHILL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317830001689",
    },
    {
        "school": "WALTHILL HIGH SCHOOL",
        "district": "WALTHILL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317830001690",
    },
    {
        "school": "WINNEBAGO ELEMENTARY SCHOOL",
        "district": "WINNEBAGO PUBLIC SCHOOLS DISTRICT 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317881001737",
    },
    {
        "school": "WINNEBAGO HIGH SCHOOL",
        "district": "WINNEBAGO PUBLIC SCHOOLS DISTRICT 17",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317881001738",
    },
    {
        "school": "ARCADIA ELEMENTARY SCHOOL",
        "district": "ARCADIA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310312000027",
    },
    {
        "school": "ARCADIA HIGH SCHOOL",
        "district": "ARCADIA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310312000028",
    },
    {
        "school": "ORD ELEMENTARY SCHOOL",
        "district": "ORD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317494001453",
    },
    {
        "school": "ORD JR-SR HIGH SCHOOL",
        "district": "ORD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317494001454",
    },
    {
        "school": "WAKEFIELD ELEMENTARY SCHOOL",
        "district": "WAKEFIELD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317824001685",
    },
    {
        "school": "WAKEFIELD HIGH SCHOOL",
        "district": "WAKEFIELD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317824001686",
    },
    {
        "school": "WAYNE JUNIOR HIGH SCHOOL",
        "district": "WAYNE COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317852001701",
    },
    {
        "school": "WAYNE HIGH SCHOOL",
        "district": "WAYNE COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317852001702",
    },
    {
        "school": "WINSIDE ELEMENTARY SCHOOL",
        "district": "WINSIDE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317884001739",
    },
    {
        "school": "WINSIDE HIGH SCHOOL",
        "district": "WINSIDE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317884001740",
    },
    {
        "school": "TOWER SCHOOL",
        "district": "EDUCATIONAL SERVICE UNIT 01",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "318001000134",
    },
    {
        "school": "BLUE HILL ELEMENTARY SCHOOL",
        "district": "BLUE HILL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310420000094",
    },
    {
        "school": "BLUE HILL HIGH SCHOOL",
        "district": "BLUE HILL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310420000095",
    },
    {
        "school": "RED CLOUD ELEMENTARY SCHOOL",
        "district": "RED CLOUD COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317599001550",
    },
    {
        "school": "RED CLOUD HIGH SCHOOL",
        "district": "RED CLOUD COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317599001551",
    },
    {
        "school": "WHEELER CENTRAL ELEMENTARY #45",
        "district": "WHEELER CENTRAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317867001725",
    },
    {
        "school": "WHEELER CENTRAL HIGH",
        "district": "WHEELER CENTRAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317867001726",
    },
    {
        "school": "HEARTLAND COMMUNITY HIGH SCH",
        "district": "HEARTLAND COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011700602",
    },
    {
        "school": "HEARTLAND COMMUNITY ELEMENTARY",
        "district": "HEARTLAND COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011700615",
    },
    {
        "school": "MC COOL JUNCTION ELEM SCHOOL",
        "district": "MC COOL JUNCTION PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317350001226",
    },
    {
        "school": "MCCOOL JUNCTION JR-SR HIGH SCH",
        "district": "MC COOL JUNCTION PUBLIC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317350001227",
    },
    {
        "school": "YORK ELEMENTARY SCHOOL",
        "district": "YORK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317905000405",
    },
    {
        "school": "YORK HIGH SCHOOL",
        "district": "YORK PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317905001917",
    },
    {
        "school": "YORK MIDDLE SCHOOL",
        "district": "YORK PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317905001919",
    },
    {
        "school": "ELEMENTARY AT BENNET",
        "district": "PALMYRA DISTRICT O R 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317521001469",
    },
    {
        "school": "JR-SR HIGH SCHOOL AT PALMYRA",
        "district": "PALMYRA DISTRICT O R 1",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317521001470",
    },
    {
        "school": "ELEMENTARY SCHOOL AT TEKAMAH",
        "district": "TEKAMAH-HERMAN COMMUNITY SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007101661",
    },
    {
        "school": "HIGH SCHOOL AT TEKAMAH",
        "district": "TEKAMAH-HERMAN COMMUNITY SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007101662",
    },
    {
        "school": "FREEMAN HIGH SCHOOL",
        "district": "FREEMAN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011600593",
    },
    {
        "school": "FREEMAN ELEMENTARY-ADAMS",
        "district": "FREEMAN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011600594",
    },
    {
        "school": "DILLER-ODELL SECONDARY SCHOOL",
        "district": "DILLER-ODELL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012500744",
    },
    {
        "school": "BEATRICE HIGH SCHOOL",
        "district": "BEATRICE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310360000058",
    },
    {
        "school": "BEATRICE MIDDLE SCHOOL",
        "district": "BEATRICE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310360000061",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "BEATRICE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310360000062",
    },
    {
        "school": "PADDOCK LANE SCHOOL",
        "district": "BEATRICE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310360000063",
    },
    {
        "school": "STODDARD ELEMENTARY SCHOOL",
        "district": "BEATRICE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310360000064",
    },
    {
        "school": "SOUTHERN ELEMENTARY SCHOOL",
        "district": "SOUTHERN SCHOOL DISTRICT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317718001631",
    },
    {
        "school": "SOUTHERN JR-SR HIGH SCHOOL",
        "district": "SOUTHERN SCHOOL DISTRICT 1",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317718001632",
    },
    {
        "school": "EDUCATIONAL SERVICE UNIT 5",
        "district": "EDUCATIONAL SERVICE UNIT 05",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "318005001964",
    },
    {
        "school": "DILLER-ODELL ELEM SCHOOL",
        "district": "DILLER-ODELL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012500746",
    },
    {
        "school": "LAKEVIEW HIGH SCHOOL",
        "district": "LAKEVIEW COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011200483",
    },
    {
        "school": "SHELL CREEK ELEMENTARY SCHOOL",
        "district": "LAKEVIEW COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011200492",
    },
    {
        "school": "PLATTE CENTER ELEMENTARY SCHOOL",
        "district": "LAKEVIEW COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011200494",
    },
    {
        "school": "EMERSON ELEMENTARY SCHOOL",
        "district": "COLUMBUS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310534000161",
    },
    {
        "school": "COLUMBUS MIDDLE SCHOOL",
        "district": "COLUMBUS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310534000165",
    },
    {
        "school": "LOST CREEK ELEMENTARY SCH",
        "district": "COLUMBUS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310534000166",
    },
    {
        "school": "NORTH PARK ELEMENTARY",
        "district": "COLUMBUS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310534000167",
    },
    {
        "school": "COLUMBUS HIGH SCHOOL",
        "district": "COLUMBUS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310534000168",
    },
    {
        "school": "WEST PARK ELEMENTARY",
        "district": "COLUMBUS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310534000170",
    },
    {
        "school": "CENTENNIAL ELEMENTARY SCHOOL",
        "district": "COLUMBUS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310534001139",
    },
    {
        "school": "LINDSAY ATTENDANCE CENTER",
        "district": "HUMPHREY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317215000308",
    },
    {
        "school": "HUMPHREY ELEMENTARY SCHOOL",
        "district": "HUMPHREY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317215001093",
    },
    {
        "school": "HUMPHREY JR-SR HIGH SCHOOL",
        "district": "HUMPHREY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317215001094",
    },
    {
        "school": "BELL FIELD ELEMENTARY SCHOOL",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071001331",
    },
    {
        "school": "ELEMENTARY SCHOOL AT SCRIBNER",
        "district": "SCRIBNER-SNYDER COMMUNITY SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007601584",
    },
    {
        "school": "SCRIBNER-SNYDER SECONDARY SCH",
        "district": "SCRIBNER-SNYDER COMMUNITY SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007601585",
    },
    {
        "school": "LOGAN VIEW JR/SR HIGH SCHOOL",
        "district": "LOGAN VIEW PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011400547",
    },
    {
        "school": "NORTH BEND CENTRAL HIGH SCHOOL",
        "district": "NORTH BEND CENTRAL PUBLIC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011500572",
    },
    {
        "school": "NORTH BEND CENTRAL ELEMENTARY SCHOOL",
        "district": "NORTH BEND CENTRAL PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011500578",
    },
    {
        "school": "CLARMAR ELEMENTARY SCHOOL",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071000973",
    },
    {
        "school": "DAVENPORT SCHOOL",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071000974",
    },
    {
        "school": "GRANT ELEMENTARY SCHOOL",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071000976",
    },
    {
        "school": "HOWARD ELEMENTARY SCHOOL",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071000977",
    },
    {
        "school": "FREMONT MIDDLE SCHOOL",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071000978",
    },
    {
        "school": "FREMONT LEARNING CENTER",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317071000979",
    },
    {
        "school": "LINDEN ELEMENTARY SCHOOL",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071000981",
    },
    {
        "school": "FREMONT SENIOR HIGH SCHOOL",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071000984",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071000986",
    },
    {
        "school": "MILLIKEN PARK ELEMENTARY SCH",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071001805",
    },
    {
        "school": "WOOD RIVER RURAL MIDDLE SCHOOL",
        "district": "WOOD RIVER RURAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317894001560",
    },
    {
        "school": "NEWELL ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601013",
    },
    {
        "school": "BARR MIDDLE SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601014",
    },
    {
        "school": "GATES ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601015",
    },
    {
        "school": "DODGE ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601016",
    },
    {
        "school": "STARR ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601017",
    },
    {
        "school": "HOWARD ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601018",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601019",
    },
    {
        "school": "KNICKREHM ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601020",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601021",
    },
    {
        "school": "SEEDLING MILE ELEM SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601022",
    },
    {
        "school": "GRAND ISLAND SENIOR HIGH SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601023",
    },
    {
        "school": "STOLLEY PARK ELEM SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601025",
    },
    {
        "school": "WALNUT MIDDLE SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601027",
    },
    {
        "school": "WASMER ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601028",
    },
    {
        "school": "WEST LAWN ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601029",
    },
    {
        "school": "SHOEMAKER ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601862",
    },
    {
        "school": "ENGLEMAN ELEMENTARY SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601863",
    },
    {
        "school": "WESTRIDGE MIDDLE SCHOOL",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001601864",
    },
    {
        "school": "DONIPHAN-TRUMBULL SECONDARY",
        "district": "DONIPHAN-TRUMBULL PUBLIC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012100750",
    },
    {
        "school": "DONIPHAN-TRUMBULL ELEMENTARY",
        "district": "DONIPHAN-TRUMBULL PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012100752",
    },
    {
        "school": "CENTURA ELEMENTARY SCHOOL",
        "district": "CENTURA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "316295000817",
    },
    {
        "school": "CENTURA SECONDARY SCHOOL",
        "district": "CENTURA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "316295000818",
    },
    {
        "school": "NORTHWEST HIGH SCHOOL",
        "district": "NORTHWEST PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317458001333",
    },
    {
        "school": "WOOD RIVER RURAL HIGH SCHOOL",
        "district": "WOOD RIVER RURAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317894001744",
    },
    {
        "school": "ST PAUL ELEMENTARY SCHOOL",
        "district": "ST PAUL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008501623",
    },
    {
        "school": "ELBA ELEMENTARY SCHOOL",
        "district": "ELBA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317002000920",
    },
    {
        "school": "ELBA SECONDARY SCHOOL",
        "district": "ELBA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317002000921",
    },
    {
        "school": "PALMER ELEMENTARY SCHOOL",
        "district": "PALMER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008901467",
    },
    {
        "school": "PALMER JUNIOR-SENIOR HIGH",
        "district": "PALMER PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008901468",
    },
    {
        "school": "CENTRAL CITY HIGH SCHOOL",
        "district": "CENTRAL CITY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310492000129",
    },
    {
        "school": "CENTRAL CITY MIDDLE SCHOOL",
        "district": "CENTRAL CITY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310492000130",
    },
    {
        "school": "CENTRAL CITY ELEMENTARY SCHOOL",
        "district": "CENTRAL CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310492000133",
    },
    {
        "school": "SILVER LAKE HIGH SCHOOL",
        "district": "SILVER LAKE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310006601883",
    },
    {
        "school": "ADAMS CENTRAL JR-SR HIGH SCH",
        "district": "ADAMS CENTRAL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310277000003",
    },
    {
        "school": "ALCOTT ELEMENTARY SCHOOL",
        "district": "HASTINGS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317158001050",
    },
    {
        "school": "HASTINGS SENIOR HIGH SCHOOL",
        "district": "HASTINGS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317158001051",
    },
    {
        "school": "HAWTHORNE ELEMENTARY SCHOOL",
        "district": "HASTINGS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317158001052",
    },
    {
        "school": "HASTINGS MIDDLE SCHOOL",
        "district": "HASTINGS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317158001053",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "HASTINGS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317158001054",
    },
    {
        "school": "LONGFELLOW ELEMENTARY SCHOOL",
        "district": "HASTINGS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317158001055",
    },
    {
        "school": "RAYMOND A WATSON ELEM SCHOOL",
        "district": "HASTINGS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317158001057",
    },
    {
        "school": "KENESAW ELEMENTARY SCHOOL",
        "district": "KENESAW PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317242001111",
    },
    {
        "school": "KENESAW SECONDARY SCHOOL",
        "district": "KENESAW PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317242001112",
    },
    {
        "school": "ESU #9 PRESCHOOL HOME BASE PRG",
        "district": "EDUCATIONAL SERVICE UNIT 09",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318009000050",
    },
    {
        "school": "SANDY CREEK HIGH SCHOOL",
        "district": "SOUTH CENTRAL NEBRASKA UNIFIED 5",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012200762",
    },
    {
        "school": "SANDY CREEK ELEMENTARY SCHOOL",
        "district": "SOUTH CENTRAL NEBRASKA UNIFIED 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012200770",
    },
    {
        "school": "HARVARD ELEMENTARY SCHOOL",
        "district": "HARVARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317155001048",
    },
    {
        "school": "HARVARD HIGH SCHOOL",
        "district": "HARVARD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317155001049",
    },
    {
        "school": "SUTTON ELEMENTARY SCHOOL",
        "district": "SUTTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317752001649",
    },
    {
        "school": "SUTTON SECONDARY SCHOOL",
        "district": "SUTTON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317752001650",
    },
    {
        "school": "LAWRENCE/NELSON HIGH SCH",
        "district": "SOUTH CENTRAL NEBRASKA UNIFIED 5",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012200806",
    },
    {
        "school": "LAWRENCE/NELSON ELEMENTARY SCH",
        "district": "SOUTH CENTRAL NEBRASKA UNIFIED 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012200807",
    },
    {
        "school": "SILVER LAKE ELEM SCH-BLADEN",
        "district": "SILVER LAKE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310006601884",
    },
    {
        "school": "WILCOX-HILDRETH UPPER ELEMENTARY",
        "district": "WILCOX-HILDRETH PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310013401371",
    },
    {
        "school": "WILCOX-HILDRETH JR/SR HIGH SCHOOL",
        "district": "WILCOX-HILDRETH PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310013401368",
    },
    {
        "school": "WILCOX-HILDRETH ELEMENTARY SCHOOL",
        "district": "WILCOX-HILDRETH PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310013401373",
    },
    {
        "school": "MINDEN PUBLIC SCH PRE-SCHOOL",
        "district": "MINDEN PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317383001589",
    },
    {
        "school": "WEST KEARNEY HIGH SCHOOL",
        "district": "WEST KEARNEY HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310004601867",
    },
    {
        "school": "AMHERST ELEMENTARY SCHOOL",
        "district": "AMHERST PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007000018",
    },
    {
        "school": "AMHERST HIGH SCHOOL",
        "district": "AMHERST PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310007000019",
    },
    {
        "school": "ELM CREEK ELEMENTARY SCHOOL",
        "district": "ELM CREEK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317014000929",
    },
    {
        "school": "ELM CREEK HIGH SCHOOL",
        "district": "ELM CREEK PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317014000930",
    },
    {
        "school": "GIBBON ELEMENTARY SCHOOL",
        "district": "GIBBON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317098001005",
    },
    {
        "school": "GIBBON HIGH SCHOOL",
        "district": "GIBBON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317098001006",
    },
    {
        "school": "MEADOWLARK ELEMENTARY SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239000329",
    },
    {
        "school": "SUNRISE MIDDLE SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239000425",
    },
    {
        "school": "BRYANT ELEMENTARY SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239001101",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239001102",
    },
    {
        "school": "EMERSON ELEMENTARY SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239001103",
    },
    {
        "school": "HORIZON MIDDLE SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239001104",
    },
    {
        "school": "KEARNEY HIGH SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239001105",
    },
    {
        "school": "KENWOOD ELEMENTARY SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239001107",
    },
    {
        "school": "NORTHEAST ELEMENTARY SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239001108",
    },
    {
        "school": "PARK ELEMENTARY SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239001109",
    },
    {
        "school": "WINDY HILLS ELEMENTARY SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239001833",
    },
    {
        "school": "GLENWOOD ELEMENTARY SCHOOL",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239001947",
    },
    {
        "school": "PLEASANTON ELEMENTARY SCHOOL",
        "district": "PLEASANTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317569001526",
    },
    {
        "school": "PLEASANTON HIGH SCHOOL",
        "district": "PLEASANTON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317569001527",
    },
    {
        "school": "RAVENNA SENIOR HIGH",
        "district": "RAVENNA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317596001549",
    },
    {
        "school": "RAVENNA ELEMENTARY SCHOOL",
        "district": "RAVENNA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317596001823",
    },
    {
        "school": "SHELTON ELEMENTARY SCHOOL",
        "district": "SHELTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317662001595",
    },
    {
        "school": "SHELTON HIGH SCHOOL",
        "district": "SHELTON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317662001596",
    },
    {
        "school": "AXTELL ELEMENTARY SCHOOL",
        "district": "AXTELL COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310342000046",
    },
    {
        "school": "AXTELL HIGH SCHOOL",
        "district": "AXTELL COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310342000047",
    },
    {
        "school": "C L JONES MIDDLE SCHOOL",
        "district": "MINDEN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317383001264",
    },
    {
        "school": "MINDEN EAST ELEMENTARY SCHOOL",
        "district": "MINDEN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317383001265",
    },
    {
        "school": "MINDEN HIGH SCHOOL",
        "district": "MINDEN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317383001266",
    },
    {
        "school": "EARLY INTERVENTION/HOMEBOUND",
        "district": "LEXINGTON PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317281002027",
    },
    {
        "school": "COZAD HIGH SCHOOL",
        "district": "COZAD COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310546000173",
    },
    {
        "school": "COZAD MIDDLE SCHOOL",
        "district": "COZAD COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310546000174",
    },
    {
        "school": "COZAD ELEMENTARY SCHOOL",
        "district": "COZAD COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310546000175",
    },
    {
        "school": "COZAD EARLY EDUCATION CENTER",
        "district": "COZAD COMMUNITY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310546000176",
    },
    {
        "school": "DUDLEY ELEMENTARY SCHOOL",
        "district": "GOTHENBURG PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317110001011",
    },
    {
        "school": "GOTHENBURG SECONDARY SCHOOL",
        "district": "GOTHENBURG PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317110001012",
    },
    {
        "school": "EARLY LEARNING ACADEMY",
        "district": "LEXINGTON PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317281000539",
    },
    {
        "school": "BRYAN ELEMENTARY SCHOOL",
        "district": "LEXINGTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317281001130",
    },
    {
        "school": "LEXINGTON HIGH SCHOOL",
        "district": "LEXINGTON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317281001131",
    },
    {
        "school": "LEXINGTON MIDDLE SCHOOL",
        "district": "LEXINGTON PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317281001132",
    },
    {
        "school": "MORTON ELEMENTARY SCHOOL",
        "district": "LEXINGTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317281001133",
    },
    {
        "school": "PERSHING ELEMENTARY SCHOOL",
        "district": "LEXINGTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317281001134",
    },
    {
        "school": "SANDOZ ELEMENTARY SCHOOL",
        "district": "LEXINGTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317281001135",
    },
    {
        "school": "OVERTON ELEMENTARY SCHOOL",
        "district": "OVERTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317506001461",
    },
    {
        "school": "OVERTON HIGH SCHOOL",
        "district": "OVERTON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317506001462",
    },
    {
        "school": "ELEMENTARY SCHOOL AT SUMNER",
        "district": "SUMNER-EDDYVILLE-MILLER SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317734001641",
    },
    {
        "school": "JUNIOR-SENIOR HIGH AT SUMNER",
        "district": "SUMNER-EDDYVILLE-MILLER SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317734001642",
    },
    {
        "school": "ELWOOD ELEMENTARY SCHOOL",
        "district": "ELWOOD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317022000933",
    },
    {
        "school": "ELWOOD HIGH SCHOOL",
        "district": "ELWOOD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317022000934",
    },
    {
        "school": "WAVERLY INTERMEDIATE SCHOOL",
        "district": "WAVERLY SCHOOL DISTRICT 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002102029",
    },
    {
        "school": "MORTON SCHOOL",
        "district": "MORTON SCHOOL",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310015001698",
    },
    {
        "school": "PATHFINDER ED PRG-LANCASTER CO",
        "district": "PATHFINDER ED PRG-LANCASTER CO",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310015101708",
    },
    {
        "school": "CHILD GUIDANCE CNTR TGH SCHOOL",
        "district": "CHILD GUIDANCE CTR TGH SCHOOL",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310015201717",
    },
    {
        "school": "CENTENNIAL ELEMENTARY SCHOOL",
        "district": "CENTENNIAL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009901670",
    },
    {
        "school": "CENTENNIAL JR-SR HIGH SCHOOL",
        "district": "CENTENNIAL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009901671",
    },
    {
        "school": "MILFORD ELEMENTARY SCHOOL",
        "district": "MILFORD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317371001238",
    },
    {
        "school": "MILFORD HIGH SCHOOL",
        "district": "MILFORD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317371001239",
    },
    {
        "school": "SEWARD ELEMENTARY SCHOOL",
        "district": "SEWARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317656001590",
    },
    {
        "school": "SEWARD HIGH SCHOOL",
        "district": "SEWARD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317656001591",
    },
    {
        "school": "SEWARD MIDDLE SCHOOL",
        "district": "SEWARD PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317656001592",
    },
    {
        "school": "EAGLE ELEMENTARY SCHOOL",
        "district": "WAVERLY SCHOOL DISTRICT 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002101697",
    },
    {
        "school": "WAVERLY HIGH SCHOOL",
        "district": "WAVERLY SCHOOL DISTRICT 145",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002101699",
    },
    {
        "school": "WAVERLY MIDDLE SCHOOL",
        "district": "WAVERLY SCHOOL DISTRICT 145",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002101853",
    },
    {
        "school": "EVELYN HAMLOW ELEMENTARY",
        "district": "WAVERLY SCHOOL DISTRICT 145",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002101865",
    },
    {
        "school": "UNIVERSITY OF NEBRASKA HIGH SCHOOL",
        "district": "UNIVERSITY OF NEBRASKA HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310005901875",
    },
    {
        "school": "NORRIS ELEMENTARY SCHOOL",
        "district": "NORRIS SCHOOL DIST 160",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008801316",
    },
    {
        "school": "NORRIS MIDDLE SCHOOL",
        "district": "NORRIS SCHOOL DIST 160",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008801317",
    },
    {
        "school": "NORRIS HIGH SCHOOL",
        "district": "NORRIS SCHOOL DIST 160",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008801318",
    },
    {
        "school": "SECONDARY SCH AT RAYMOND",
        "district": "RAYMOND CENTRAL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310495000137",
    },
    {
        "school": "CAMPBELL ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284000373",
    },
    {
        "school": "CAVETT ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284000379",
    },
    {
        "school": "MAXEY ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284000389",
    },
    {
        "school": "ROPER ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284000391",
    },
    {
        "school": "LUX MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284000392",
    },
    {
        "school": "SCOTT MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284000393",
    },
    {
        "school": "SCIENCE FOCUS PROGRAM",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317284000482",
    },
    {
        "school": "ARTS & HUMANITIES FOCUS PRGM",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317284000681",
    },
    {
        "school": "ECSE - HOMEBASED",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284000695",
    },
    {
        "school": "SPECIAL ED YANKEE HILL PROGRAM",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317284000755",
    },
    {
        "school": "NORTH STAR HIGH SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001032",
    },
    {
        "school": "SOUTHWEST HIGH SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001033",
    },
    {
        "school": "HIGH SCHOOL STUDENT SUPPORT PROGRAM",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317284001039",
    },
    {
        "school": "ARNOLD ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001136",
    },
    {
        "school": "BEATTIE ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001137",
    },
    {
        "school": "BELMONT ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001138",
    },
    {
        "school": "BROWNELL ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001140",
    },
    {
        "school": "CULLER MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001141",
    },
    {
        "school": "CALVERT ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001142",
    },
    {
        "school": "CLINTON ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001143",
    },
    {
        "school": "DAWES MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001145",
    },
    {
        "school": "EASTRIDGE ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001146",
    },
    {
        "school": "ELLIOTT ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001147",
    },
    {
        "school": "GOODRICH MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001149",
    },
    {
        "school": "HARTLEY ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001150",
    },
    {
        "school": "HOLMES ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001154",
    },
    {
        "school": "HUNTINGTON ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001155",
    },
    {
        "school": "IRVING MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001156",
    },
    {
        "school": "KAHOA ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001157",
    },
    {
        "school": "LAKEVIEW ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001158",
    },
    {
        "school": "LINCOLN EAST HIGH SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001159",
    },
    {
        "school": "LINCOLN HIGH SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001160",
    },
    {
        "school": "LINCOLN NORTHEAST HIGH SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001161",
    },
    {
        "school": "LINCOLN SOUTHEAST HIGH SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001162",
    },
    {
        "school": "MCPHEE ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001163",
    },
    {
        "school": "MEADOW LANE ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001164",
    },
    {
        "school": "LEFLER MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001165",
    },
    {
        "school": "MORLEY ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001166",
    },
    {
        "school": "NORWOOD PARK ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001167",
    },
    {
        "school": "EVERETT ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001168",
    },
    {
        "school": "PERSHING ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001169",
    },
    {
        "school": "POUND MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001170",
    },
    {
        "school": "PRESCOTT ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001171",
    },
    {
        "school": "PYRTLE ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001172",
    },
    {
        "school": "RANDOLPH ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001173",
    },
    {
        "school": "RILEY ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001174",
    },
    {
        "school": "MICKLE MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001175",
    },
    {
        "school": "ROUSSEAU ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001176",
    },
    {
        "school": "HILL ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001177",
    },
    {
        "school": "SARATOGA ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001178",
    },
    {
        "school": "SHERIDAN ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001179",
    },
    {
        "school": "WEST LINCOLN ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001181",
    },
    {
        "school": "ZEMAN ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001183",
    },
    {
        "school": "BRYAN COMMUNITY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317284001808",
    },
    {
        "school": "FREDSTROM ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001851",
    },
    {
        "school": "HUMANN ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284001995",
    },
    {
        "school": "DONALD D SHERRILL EDUCATION CNTR - ELEM",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317284002120",
    },
    {
        "school": "NUERNBERGER EDUCATION CENTER",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317284002121",
    },
    {
        "school": "PARK MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002122",
    },
    {
        "school": "MALCOLM ELEMENTARY SCHOOL",
        "district": "MALCOLM PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317329001209",
    },
    {
        "school": "MALCOLM JR/SR HIGH SCHOOL",
        "district": "MALCOLM PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317329001210",
    },
    {
        "school": "ELEMENTARY SCHOOL AT CERESCO",
        "district": "RAYMOND CENTRAL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310495000135",
    },
    {
        "school": "ELEMENTARY SCH AT VALPARAISO",
        "district": "RAYMOND CENTRAL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310495000136",
    },
    {
        "school": "NORTHEAST NE JUVENILE SERVICES",
        "district": "NORTHEAST NE JUVENILE SERVICES",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310015401728",
    },
    {
        "school": "ELKHORN VALLEY ELEMENTARY SCH",
        "district": "ELKHORN VALLEY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002501664",
    },
    {
        "school": "ELKHORN VALLEY HIGH SCHOOL",
        "district": "ELKHORN VALLEY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002501665",
    },
    {
        "school": "BATTLE CREEK ELEMENTARY SCHOOL",
        "district": "BATTLE CREEK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310354000054",
    },
    {
        "school": "BATTLE CREEK HIGH SCHOOL",
        "district": "BATTLE CREEK PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310354000055",
    },
    {
        "school": "MADISON MIDDLE SCHOOL",
        "district": "MADISON PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317323000599",
    },
    {
        "school": "MADISON ELEMENTARY SCHOOL",
        "district": "MADISON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317323001205",
    },
    {
        "school": "MADISON HIGH SCHOOL",
        "district": "MADISON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317323001206",
    },
    {
        "school": "NEWMAN GROVE ELEMENTARY SCHOOL",
        "district": "NEWMAN GROVE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317434001299",
    },
    {
        "school": "NEWMAN GROVE HIGH SCHOOL",
        "district": "NEWMAN GROVE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317434001300",
    },
    {
        "school": "NORFOLK MIDDLE SCHOOL",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317443000303",
    },
    {
        "school": "ALTERNATIVES FOR SUCCESS SCH",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317443001040",
    },
    {
        "school": "BEL AIR ELEMENTARY SCHOOL",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317443001305",
    },
    {
        "school": "GRANT ELEMENTARY SCHOOL",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317443001306",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317443001307",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317443001308",
    },
    {
        "school": "NORFOLK JR HIGH SCHOOL",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317443001310",
    },
    {
        "school": "NORFOLK SENIOR HIGH SCHOOL",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317443001311",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317443001314",
    },
    {
        "school": "WESTSIDE ELEMENTARY SCHOOL",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317443001315",
    },
    {
        "school": "OSMOND ELEMENTARY SCHOOL",
        "district": "OSMOND COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317503001459",
    },
    {
        "school": "OSMOND HIGH SCHOOL",
        "district": "OSMOND COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317503001460",
    },
    {
        "school": "PIERCE ELEMENTARY SCHOOL",
        "district": "PIERCE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317551001494",
    },
    {
        "school": "PIERCE JR/SR HIGH SCHOOL",
        "district": "PIERCE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317551001495",
    },
    {
        "school": "PLAINVIEW ELEMENTARY SCHOOL",
        "district": "PLAINVIEW PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317557001497",
    },
    {
        "school": "PLAINVIEW SECONDARY SCHOOL",
        "district": "PLAINVIEW PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317557001498",
    },
    {
        "school": "STANTON ELEMENTARY SCHOOL",
        "district": "STANTON COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310004101625",
    },
    {
        "school": "STANTON HIGH SCHOOL",
        "district": "STANTON COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310004101626",
    },
    {
        "school": "WOODLAND PARK ELEMENTARY SCH",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317443001950",
    },
    {
        "school": "ADAMS MIDDLE SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002201321",
    },
    {
        "school": "BUFFALO ELEMENTARY SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002201322",
    },
    {
        "school": "CODY ELEMENTARY SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002201323",
    },
    {
        "school": "EISENHOWER ELEMENTARY SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002201324",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002201325",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002201326",
    },
    {
        "school": "MADISON MIDDLE SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002201327",
    },
    {
        "school": "MCDONALD ELEMENTARY SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002201328",
    },
    {
        "school": "NORTH PLATTE HIGH SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002201330",
    },
    {
        "school": "WASHINGTON ELEMENTARY SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002201332",
    },
    {
        "school": "OSGOOD ELEMENTARY SCHOOL",
        "district": "NORTH PLATTE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002201837",
    },
    {
        "school": "MAXWELL ELEMENTARY SCHOOL",
        "district": "MAXWELL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002301214",
    },
    {
        "school": "MAXWELL HIGH SCHOOL",
        "district": "MAXWELL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002301215",
    },
    {
        "school": "SUTHERLAND ELEMENTARY SCHOOL",
        "district": "SUTHERLAND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002401647",
    },
    {
        "school": "SUTHERLAND HIGH SCHOOL",
        "district": "SUTHERLAND PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002401648",
    },
    {
        "school": "BRADY ELEMENTARY SCHOOL",
        "district": "BRADY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310429000098",
    },
    {
        "school": "BRADY HIGH SCHOOL",
        "district": "BRADY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310429000099",
    },
    {
        "school": "HERSHEY ELEMENTARY SCHOOL",
        "district": "HERSHEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317182001066",
    },
    {
        "school": "HERSHEY HIGH SCHOOL",
        "district": "HERSHEY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317182001067",
    },
    {
        "school": "WALLACE ELEMENTARY SCHOOL",
        "district": "WALLACE PUBLIC SCH DIST 65 R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317826001687",
    },
    {
        "school": "WALLACE HIGH SCHOOL",
        "district": "WALLACE PUBLIC SCH DIST 65 R",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317826001688",
    },
    {
        "school": "STAPLETON ELEMENTARY SCHOOL",
        "district": "STAPLETON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317710001627",
    },
    {
        "school": "STAPLETON HIGH SCHOOL",
        "district": "STAPLETON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317710001628",
    },
    {
        "school": "MC PHERSON COUNTY SECONDARY SCHOOL",
        "district": "MC PHERSON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317356001229",
    },
    {
        "school": "PALISADES ELEMENTARY SCHOOL",
        "district": "GRETNA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317122002021",
    },
    {
        "school": "NOVA ALTERNATIVE SCHOOL",
        "district": "NOVA ALTERNATIVE SCHOOL",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310014501480",
    },
    {
        "school": "RTC SCHOOL",
        "district": "BOYS TOWN INTERIM PRG SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310014601515",
    },
    {
        "school": "DOUGLAS COUNTY YOUTH CENTER",
        "district": "DOUGLAS COUNTY YOUTH CENTER",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310014701538",
    },
    {
        "school": "DOUGLAS CO WEST HIGH SCHOOL",
        "district": "DOUGLAS CO WEST COMMUNITY SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310016501786",
    },
    {
        "school": "DOUGLAS CO WEST MIDDLE SCHOOL",
        "district": "DOUGLAS CO WEST COMMUNITY SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310016501787",
    },
    {
        "school": "DOUGLAS CO WEST ELEMENTARY SCH",
        "district": "DOUGLAS CO WEST COMMUNITY SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310016501790",
    },
    {
        "school": "UTA HALEE ACADEMY PROGRAM",
        "district": "UTA HALEE ACADEMY PROGRAM",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310016601796",
    },
    {
        "school": "NCYF COMMUNITY HIGH SCHOOL",
        "district": "NCYF COMMUNITY HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017702019",
    },
    {
        "school": "FIRE RIDGE ELEMENTARY SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011001784",
    },
    {
        "school": "ELKHORN RIDGE MIDDLE SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011002182",
    },
    {
        "school": "REAGAN ELEMENTARY",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374002018",
    },
    {
        "school": "LIBERTY ELEMENTARY SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001334",
    },
    {
        "school": "ALICE BUFFETT MAGNET MS",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001431",
    },
    {
        "school": "R M MARRS MAGNET MIDDLE SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001438",
    },
    {
        "school": "GOMEZ HERITAGE ELEMENTARY SCH",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001439",
    },
    {
        "school": "STANDING BEAR ELEMENTARY SCH",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001783",
    },
    {
        "school": "EARLY CHILDHOOD CENTER AT EDUCARE - KELLOM",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482002007",
    },
    {
        "school": "EARLY CHILDHOOD CENTER AT GATEWAY",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482002015",
    },
    {
        "school": "WESTBROOK ELEMENTARY SCHOOL",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001793",
    },
    {
        "school": "WESTSIDE HIGH SCHOOL WEST CAMPUS",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317866001794",
    },
    {
        "school": "PATRICK J THOMAS JUVENILE CNTR",
        "district": "PATRICK J THOMAS JUVENILE JUSTICE CNTR",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310016001762",
    },
    {
        "school": "LEWIS & CLARK MIDDLE SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381002001",
    },
    {
        "school": "SQUIRE JOHN THOMAS ELEMENTARY",
        "district": "GRETNA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317122001760",
    },
    {
        "school": "REEDER ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001792",
    },
    {
        "school": "PAPILLION LA VISTA SOUTH HS",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001389",
    },
    {
        "school": "PORTAL ELEMENTARY SCHOOL",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527002192",
    },
    {
        "school": "ASHLAND-GREENWOOD ELEMENTARY SCHOOL",
        "district": "ASHLAND-GREENWOOD PUBLIC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310003400034",
    },
    {
        "school": "ASHLAND-GREENWOOD HIGH SCHOOL",
        "district": "ASHLAND-GREENWOOD PUBLIC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310003400035",
    },
    {
        "school": "ASHLAND-GREENWOOD MIDDLE SCHOOL",
        "district": "ASHLAND-GREENWOOD PUBLIC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310003401927",
    },
    {
        "school": "CEDAR BLUFFS ELEMENTARY SCHOOL",
        "district": "CEDAR BLUFFS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310487000125",
    },
    {
        "school": "CEDAR BLUFFS SECONDARY SCHOOL",
        "district": "CEDAR BLUFFS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310487000126",
    },
    {
        "school": "MEAD ELEMENTARY SCHOOL",
        "district": "MEAD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317359001230",
    },
    {
        "school": "MEAD HIGH SCHOOL",
        "district": "MEAD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317359001231",
    },
    {
        "school": "WAHOO PRE-SCHOOL",
        "district": "WAHOO PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317821000312",
    },
    {
        "school": "WAHOO HIGH SCHOOL",
        "district": "WAHOO PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317821001682",
    },
    {
        "school": "WAHOO MIDDLE SCHOOL",
        "district": "WAHOO PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317821001683",
    },
    {
        "school": "WAHOO ELEMENTARY SCHOOL",
        "district": "WAHOO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317821001684",
    },
    {
        "school": "YUTAN ELEMENTARY SCHOOL",
        "district": "YUTAN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317908001753",
    },
    {
        "school": "YUTAN HIGH SCHOOL",
        "district": "YUTAN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317908001754",
    },
    {
        "school": "ELMWOOD-MURDOCK JR/SR HIGH SCH",
        "district": "ELMWOOD-MURDOCK PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310199201992",
    },
    {
        "school": "ELMWOOD-MURDOCK ELEM SCHOOL",
        "district": "ELMWOOD-MURDOCK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310199202107",
    },
    {
        "school": "LOUISVILLE MIDDLE SCHOOL",
        "district": "LOUISVILLE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317305000717",
    },
    {
        "school": "LOUISVILLE ELEMENTARY SCHOOL",
        "district": "LOUISVILLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317305001191",
    },
    {
        "school": "LOUISVILLE HIGH SCHOOL",
        "district": "LOUISVILLE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317305001192",
    },
    {
        "school": "CONESTOGA JR/SR HIGH SCHOOL",
        "district": "CONESTOGA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317420001290",
    },
    {
        "school": "CONESTOGA ELEMENTARY SCHOOL",
        "district": "CONESTOGA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317420001818",
    },
    {
        "school": "PLATTSMOUTH ELEMENTARY SCHOOL",
        "district": "PLATTSMOUTH COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317566000426",
    },
    {
        "school": "PLATTSMOUTH EARLY CHILDHOOD",
        "district": "PLATTSMOUTH COMMUNITY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317566000429",
    },
    {
        "school": "PLATTSMOUTH HIGH SCHOOL",
        "district": "PLATTSMOUTH COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317566001523",
    },
    {
        "school": "PLATTSMOUTH MIDDLE SCHOOL",
        "district": "PLATTSMOUTH COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317566001524",
    },
    {
        "school": "WEEPING WATER ELEMENTARY SCHOOL",
        "district": "WEEPING WATER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317854001704",
    },
    {
        "school": "WEEPING WATER HIGH SCHOOL",
        "district": "WEEPING WATER PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317854001705",
    },
    {
        "school": "BENNINGTON ELEMENTARY SCHOOL",
        "district": "BENNINGTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310399000077",
    },
    {
        "school": "BENNINGTON HIGH SCHOOL",
        "district": "BENNINGTON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310399000078",
    },
    {
        "school": "SPRING RIDGE ELEMENTARY",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011000719",
    },
    {
        "school": "ELKHORN HIGH SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011000927",
    },
    {
        "school": "SKYLINE ELEMENTARY SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011000928",
    },
    {
        "school": "ELKHORN MIDDLE SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011001800",
    },
    {
        "school": "HILLRISE ELEMENTARY SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011001801",
    },
    {
        "school": "WESTRIDGE ELEMENTARY SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011001802",
    },
    {
        "school": "WILLOWDALE ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374000089",
    },
    {
        "school": "RUSSELL MIDDLE SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374000240",
    },
    {
        "school": "MILLARD WEST HIGH SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374000242",
    },
    {
        "school": "ALDRICH ELEMENTARY",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374000244",
    },
    {
        "school": "BLACK ELK ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374000372",
    },
    {
        "school": "ROHWER ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374000667",
    },
    {
        "school": "WHEELER ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374000669",
    },
    {
        "school": "BEADLE MIDDLE SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374000723",
    },
    {
        "school": "YOUNG ADULT PROGRAM",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317374000995",
    },
    {
        "school": "BRYAN ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001241",
    },
    {
        "school": "WILLA CATHER ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001242",
    },
    {
        "school": "CODY ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001244",
    },
    {
        "school": "COTTONWOOD ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001245",
    },
    {
        "school": "HITCHCOCK ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001247",
    },
    {
        "school": "HOLLING HEIGHTS ELEM SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001248",
    },
    {
        "school": "J STERLING MORTON ELEM SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001249",
    },
    {
        "school": "MILLARD CENTRAL MIDDLE SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001250",
    },
    {
        "school": "MILLARD SOUTH HIGH SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001251",
    },
    {
        "school": "MILLARD NORTH HIGH SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001252",
    },
    {
        "school": "MILLARD NORTH MIDDLE SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001253",
    },
    {
        "school": "MONTCLAIR ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001254",
    },
    {
        "school": "NEIHARDT ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001255",
    },
    {
        "school": "NORRIS ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001256",
    },
    {
        "school": "SANDOZ ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001257",
    },
    {
        "school": "WALT DISNEY ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001259",
    },
    {
        "school": "HARVEY OAKS ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001813",
    },
    {
        "school": "NORMAN ROCKWELL ELEM SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001816",
    },
    {
        "school": "ACKERMAN ELEMENTARY SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001834",
    },
    {
        "school": "GRACE ABBOTT ELEM SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001835",
    },
    {
        "school": "HARRY ANDERSEN MIDDLE SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001896",
    },
    {
        "school": "KIEWIT MIDDLE SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001934",
    },
    {
        "school": "EZRA MILLARD ELEMENTARY SCH",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374001935",
    },
    {
        "school": "PICOTTE ELEMENTARY SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482000084",
    },
    {
        "school": "PRAIRIE WIND ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482000288",
    },
    {
        "school": "ASHLAND PARK/ROBBINS ELEM SCH",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482000289",
    },
    {
        "school": "OMAHA PUBLIC SCHOOLS HOMEBASED",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482000300",
    },
    {
        "school": "SKINNER MAGNET CENTER",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482000439",
    },
    {
        "school": "FULLERTON MAGNET CENTER",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482000591",
    },
    {
        "school": "CASTELAR ELEMENTARY SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482000662",
    },
    {
        "school": "DRUID HILL ELEMENTARY SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482000666",
    },
    {
        "school": "ADAMS ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001348",
    },
    {
        "school": "BEALS ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001351",
    },
    {
        "school": "BELLE RYAN ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001352",
    },
    {
        "school": "BELVEDERE ELEMENTARY SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001353",
    },
    {
        "school": "BENSON MAGNET HIGH SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001354",
    },
    {
        "school": "BENSON WEST ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001355",
    },
    {
        "school": "BEVERIDGE MAGNET MIDDLE SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001356",
    },
    {
        "school": "BOYD ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001357",
    },
    {
        "school": "BURKE HIGH SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001360",
    },
    {
        "school": "CATLIN MAGNET CENTER",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001362",
    },
    {
        "school": "CENTRAL HIGH SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001363",
    },
    {
        "school": "CENTRAL PARK ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001364",
    },
    {
        "school": "COLUMBIAN ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001367",
    },
    {
        "school": "PARRISH PROGRAM",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482001369",
    },
    {
        "school": "CONESTOGA MAGNET ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001370",
    },
    {
        "school": "CRESTRIDGE MAGNET CENTER",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001372",
    },
    {
        "school": "DODGE ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001374",
    },
    {
        "school": "DUNDEE ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001376",
    },
    {
        "school": "EDISON ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001377",
    },
    {
        "school": "FIELD CLUB ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001378",
    },
    {
        "school": "FLORENCE ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001379",
    },
    {
        "school": "FONTENELLE ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001380",
    },
    {
        "school": "FRANKLIN ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001381",
    },
    {
        "school": "NATHAN HALE MAGNET MIDDLE SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001384",
    },
    {
        "school": "HARRISON ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001385",
    },
    {
        "school": "HARTMAN ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001386",
    },
    {
        "school": "HIGHLAND ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001387",
    },
    {
        "school": "INDIAN HILL ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001388",
    },
    {
        "school": "BLACKBURN ALTERNATIVE PROGRAM",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482001391",
    },
    {
        "school": "MASTERS ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001394",
    },
    {
        "school": "JEFFERSON ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001396",
    },
    {
        "school": "KELLOM ELEMENTARY SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001397",
    },
    {
        "school": "KENNEDY ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001398",
    },
    {
        "school": "LEWIS & CLARK MIDDLE SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001399",
    },
    {
        "school": "J P LORD PROGRAM",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317482001401",
    },
    {
        "school": "LOTHROP MAGNET CENTER",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001402",
    },
    {
        "school": "MC MILLAN MAGNET MIDDLE SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001408",
    },
    {
        "school": "MILLER PARK ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001409",
    },
    {
        "school": "MINNE LUSA ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001410",
    },
    {
        "school": "MONROE MIDDLE SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001412",
    },
    {
        "school": "MORTON MAGNET MIDDLE SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001413",
    },
    {
        "school": "MOUNT VIEW ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001414",
    },
    {
        "school": "NORRIS MIDDLE SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001415",
    },
    {
        "school": "OMAHA NORTH MAGNET HIGH SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001416",
    },
    {
        "school": "OMAHA NORTHWEST HIGH MAGNET SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001417",
    },
    {
        "school": "OAK VALLEY ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001418",
    },
    {
        "school": "PINEWOOD ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001422",
    },
    {
        "school": "PONCA ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001424",
    },
    {
        "school": "ROSE HILL ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001427",
    },
    {
        "school": "JOSLYN ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001429",
    },
    {
        "school": "SHERMAN ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001432",
    },
    {
        "school": "OMAHA SOUTH MAGNET HIGH SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001433",
    },
    {
        "school": "SPRING LAKE MAGNET CENTER",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001435",
    },
    {
        "school": "SPRINGVILLE ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001436",
    },
    {
        "school": "SUNNY SLOPE ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001437",
    },
    {
        "school": "WAKONDA ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001441",
    },
    {
        "school": "WALNUT HILL ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001442",
    },
    {
        "school": "WASHINGTON ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001443",
    },
    {
        "school": "WESTERN HILLS MAGNET CENTER",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001444",
    },
    {
        "school": "CAREER CENTER",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482001859",
    },
    {
        "school": "JACKSON ELEMENTARY SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001897",
    },
    {
        "school": "BANCROFT ELEMENTARY",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001937",
    },
    {
        "school": "KING ELEMENTARY SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001938",
    },
    {
        "school": "KING SCIENCE/TECH MAGNET M S",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001940",
    },
    {
        "school": "BLUMFIELD ELEMENTARY SCHOOL",
        "district": "RALSTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317590001536",
    },
    {
        "school": "KAREN WESTERN ELEMENTARY SCH",
        "district": "RALSTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317590001537",
    },
    {
        "school": "MEADOWS ELEMENTARY SCHOOL",
        "district": "RALSTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317590001539",
    },
    {
        "school": "RALSTON MIDDLE SCHOOL",
        "district": "RALSTON PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317590001540",
    },
    {
        "school": "MOCKINGBIRD ELEMENTARY SCHOOL",
        "district": "RALSTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317590001541",
    },
    {
        "school": "RALSTON HIGH SCHOOL",
        "district": "RALSTON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317590001542",
    },
    {
        "school": "SEYMOUR ELEMENTARY SCHOOL",
        "district": "RALSTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317590001543",
    },
    {
        "school": "WILDEWOOD ELEMENTARY SCHOOL",
        "district": "RALSTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317590001544",
    },
    {
        "school": "CARL A SWANSON ELEMENTARY SCH",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001710",
    },
    {
        "school": "HILLSIDE ELEMENTARY SCHOOL",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001711",
    },
    {
        "school": "LOVELAND ELEMENTARY SCHOOL",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001712",
    },
    {
        "school": "OAKDALE ELEMENTARY SCHOOL",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001713",
    },
    {
        "school": "PADDOCK ROAD ELEMENTARY SCHOOL",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001714",
    },
    {
        "school": "PRAIRIE LANE ELEMENTARY SCHOOL",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001715",
    },
    {
        "school": "ROCKBROOK ELEMENTARY SCHOOL",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001716",
    },
    {
        "school": "SUNSET HILLS ELEMENTARY SCHOOL",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001718",
    },
    {
        "school": "WESTGATE ELEMENTARY SCHOOL",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001723",
    },
    {
        "school": "WESTSIDE HIGH SCHOOL",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001724",
    },
    {
        "school": "WESTSIDE MIDDLE SCHOOL",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866001915",
    },
    {
        "school": "TWO SPRINGS ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381000402",
    },
    {
        "school": "FAIRVIEW ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381000838",
    },
    {
        "school": "AVERY ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001499",
    },
    {
        "school": "BELLEAIRE ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001500",
    },
    {
        "school": "BELLEVUE EAST SR HIGH SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001501",
    },
    {
        "school": "BELLEVUE WEST SR HIGH SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001502",
    },
    {
        "school": "BERTHA BARBER ELEMENTARY SCH",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001503",
    },
    {
        "school": "BETZ ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001504",
    },
    {
        "school": "BIRCHCREST ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001505",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001506",
    },
    {
        "school": "CHAP CENTER",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "310381001507",
    },
    {
        "school": "FORT CROOK ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001508",
    },
    {
        "school": "LEMAY ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001510",
    },
    {
        "school": "LOGAN FONTENELLE MIDDLE SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001511",
    },
    {
        "school": "BELLEVUE MISSION MIDDLE SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001512",
    },
    {
        "school": "PETER SARPY ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001513",
    },
    {
        "school": "TWIN RIDGE ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001517",
    },
    {
        "school": "WAKE ROBIN ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001518",
    },
    {
        "school": "LEONARD LAWRENCE ELEM SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381001878",
    },
    {
        "school": "GRETNA MIDDLE SCHOOL",
        "district": "GRETNA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317122000257",
    },
    {
        "school": "GRETNA ELEMENTARY SCHOOL",
        "district": "GRETNA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317122001034",
    },
    {
        "school": "GRETNA HIGH SCHOOL",
        "district": "GRETNA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317122001035",
    },
    {
        "school": "BRYAN MIDDLE SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001358",
    },
    {
        "school": "BRYAN HIGH SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001359",
    },
    {
        "school": "CHANDLER VIEW ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001365",
    },
    {
        "school": "GILDER ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001382",
    },
    {
        "school": "PAWNEE ELEM SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482001420",
    },
    {
        "school": "RUMSEY STATION ELEMENTARY SCH",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527000403",
    },
    {
        "school": "WALNUT CREEK ELEMENTARY",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527000846",
    },
    {
        "school": "CARRIAGE HILL ELEMENTARY SCH",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001472",
    },
    {
        "school": "G STANLEY HALL ELEMENTARY SCH",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001473",
    },
    {
        "school": "GOLDEN HILLS ELEMENTARY SCHOOL",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001474",
    },
    {
        "school": "LA VISTA MIDDLE SCHOOL",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001475",
    },
    {
        "school": "LA VISTA WEST ELEMENTARY SCH",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001476",
    },
    {
        "school": "PAPILLION MIDDLE SCHOOL",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001477",
    },
    {
        "school": "PAPILLION LA VISTA SENIOR HIGH",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001478",
    },
    {
        "school": "PARKVIEW HEIGHTS ELEM SCHOOL",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001479",
    },
    {
        "school": "TARA HEIGHTS ELEMENTARY SCHOOL",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001481",
    },
    {
        "school": "TRUMBLE PARK ELEMENTARY SCHOOL",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001482",
    },
    {
        "school": "ANDERSON GROVE ELEMENTARY SCH",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001900",
    },
    {
        "school": "HICKORY HILL ELEMENTARY SCH",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527001901",
    },
    {
        "school": "WESTMONT ELEMENTARY SCHOOL",
        "district": "SPRINGFIELD PLATTEVIEW COMMUNITY SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317563001483",
    },
    {
        "school": "PLATTEVIEW SENIOR HIGH SCHOOL",
        "district": "SPRINGFIELD PLATTEVIEW COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317563001514",
    },
    {
        "school": "SPRINGFIELD ELEMENTARY SCHOOL",
        "district": "SPRINGFIELD PLATTEVIEW COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317563001516",
    },
    {
        "school": "PLATTEVIEW CENTRAL JR HIGH SCHOOL",
        "district": "SPRINGFIELD PLATTEVIEW COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317563001902",
    },
    {
        "school": "BROOK VALLEY SCHOOL",
        "district": "EDUCATIONAL SERVICE UNIT 03",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "318003000409",
    },
    {
        "school": "ARLINGTON ELEMENTARY SCHOOL",
        "district": "ARLINGTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310313000029",
    },
    {
        "school": "ARLINGTON HIGH SCHOOL",
        "district": "ARLINGTON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310313000030",
    },
    {
        "school": "BLAIR ARBOR PARK INTERMEDIATE SCHOOL",
        "district": "BLAIR COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310410000085",
    },
    {
        "school": "BLAIR HIGH SCHOOL",
        "district": "BLAIR COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310410000086",
    },
    {
        "school": "BLAIR NORTH ELEMENTARY SCHOOL",
        "district": "BLAIR COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310410000087",
    },
    {
        "school": "BLAIR SOUTH ELEMENTARY SCHOOL",
        "district": "BLAIR COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310410000088",
    },
    {
        "school": "GERALD OTTE BLAIR MIDDLE SCH",
        "district": "BLAIR COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310410000516",
    },
    {
        "school": "FORT CALHOUN ELEMENTARY SCHOOL",
        "district": "FORT CALHOUN COMMUNITY SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317065000968",
    },
    {
        "school": "FORT CALHOUN JR-SR HIGH SCHOOL",
        "district": "FORT CALHOUN COMMUNITY SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317065000969",
    },
    {
        "school": "LIFELINKS-NEBRASKA",
        "district": "EDUCATIONAL SERVICE UNIT 13",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "318013002025",
    },
    {
        "school": "GERING EARLY CHILDHOOD PROGRAM",
        "district": "GERING PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009801763",
    },
    {
        "school": "BANNER COUNTY ELEMENTARY SCHOOL",
        "district": "BANNER COUNTY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310006701043",
    },
    {
        "school": "BANNER COUNTY HIGH SCHOOL",
        "district": "BANNER COUNTY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310006701044",
    },
    {
        "school": "MORRILL HIGH SCHOOL",
        "district": "MORRILL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009701274",
    },
    {
        "school": "MORRILL ELEMENTARY",
        "district": "MORRILL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009701881",
    },
    {
        "school": "GEIL ELEMENTARY SCHOOL",
        "district": "GERING PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009800998",
    },
    {
        "school": "GERING HIGH SCHOOL",
        "district": "GERING PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009800999",
    },
    {
        "school": "GERING JUNIOR HIGH SCHOOL",
        "district": "GERING PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009801000",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "GERING PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009801001",
    },
    {
        "school": "NORTHFIELD ELEMENTARY SCHOOL",
        "district": "GERING PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009801003",
    },
    {
        "school": "MINATARE ELEMENTARY SCHOOL",
        "district": "MINATARE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317380001262",
    },
    {
        "school": "MINATARE HIGH SCHOOL",
        "district": "MINATARE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317380001263",
    },
    {
        "school": "MITCHELL ELEMENTARY SCHOOL",
        "district": "MITCHELL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317389001268",
    },
    {
        "school": "MITCHELL SECONDARY SCHOOL",
        "district": "MITCHELL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317389001269",
    },
    {
        "school": "LINCOLN HEIGHTS ELEMENTARY SCH",
        "district": "SCOTTSBLUFF PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317647001578",
    },
    {
        "school": "LONGFELLOW ELEMENTARY SCHOOL",
        "district": "SCOTTSBLUFF PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317647001579",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "SCOTTSBLUFF PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317647001580",
    },
    {
        "school": "BLUFFS MIDDLE SCHOOL",
        "district": "SCOTTSBLUFF PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317647001581",
    },
    {
        "school": "SCOTTSBLUFF SENIOR HIGH SCHOOL",
        "district": "SCOTTSBLUFF PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317647001582",
    },
    {
        "school": "WESTMOOR ELEMENTARY SCHOOL",
        "district": "SCOTTSBLUFF PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317647001583",
    },
    {
        "school": "MERIDIAN SCHOOL",
        "district": "EDUCATIONAL SERVICE UNIT 13",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "318013001986",
    },
    {
        "school": "COVINGTON ELEMENTARY SCHOOL",
        "district": "SO SIOUX CITY COMMUNITY SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317686001313",
    },
    {
        "school": "EMERSON-HUBBARD HIGH SCHOOL",
        "district": "EMERSON-HUBBARD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310014101425",
    },
    {
        "school": "EMERSON-HUBBARD ELEMENTARY SCH",
        "district": "EMERSON-HUBBARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310014101428",
    },
    {
        "school": "ALLEN ELEMENTARY SCHOOL",
        "district": "ALLEN CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310288000009",
    },
    {
        "school": "ALLEN HIGH SCHOOL",
        "district": "ALLEN CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310288000010",
    },
    {
        "school": "PONCA ELEMENTARY SCHOOL",
        "district": "PONCA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317577001530",
    },
    {
        "school": "PONCA HIGH SCHOOL",
        "district": "PONCA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317577001531",
    },
    {
        "school": "HOMER ELEMENTARY SCHOOL",
        "district": "HOMER COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317200001082",
    },
    {
        "school": "HOMER HIGH SCHOOL",
        "district": "HOMER COMMUNITY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317200001083",
    },
    {
        "school": "CARDINAL ELEMENTARY SCHOOL",
        "district": "SO SIOUX CITY COMMUNITY SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317686000236",
    },
    {
        "school": "DAKOTA CITY ELEMENTARY SCHOOL",
        "district": "SO SIOUX CITY COMMUNITY SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317686001610",
    },
    {
        "school": "HARNEY ELEMENTARY SCHOOL",
        "district": "SO SIOUX CITY COMMUNITY SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317686001612",
    },
    {
        "school": "LEWIS & CLARK ELEMENTARY SCH",
        "district": "SO SIOUX CITY COMMUNITY SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317686001614",
    },
    {
        "school": "SOUTH SIOUX CITY MIDDLE SCHOOL",
        "district": "SO SIOUX CITY COMMUNITY SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317686001615",
    },
    {
        "school": "SOUTH SIOUX HIGH SCHOOL",
        "district": "SO SIOUX CITY COMMUNITY SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317686001616",
    },
    {
        "school": "Surry Village Charter School",
        "district": "Surry Village Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330003900617",
    },
    {
        "school": "Gorham Middle School",
        "district": "Gorham Randolph Shelburne Coop School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330003500047",
    },
    {
        "school": "Edward Fenn School",
        "district": "Gorham Randolph Shelburne Coop School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330003500141",
    },
    {
        "school": "Gorham High School",
        "district": "Gorham Randolph Shelburne Coop School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330003500142",
    },
    {
        "school": "Glen Lake School",
        "district": "Goffstown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330324000620",
    },
    {
        "school": "Great Bay Charter School (H)",
        "district": "Great Bay Elearning Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330004800609",
    },
    {
        "school": "Berlin Middle School",
        "district": "Berlin School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330186000024",
    },
    {
        "school": "Berlin Senior High School",
        "district": "Berlin School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330186000027",
    },
    {
        "school": "Berlin Elementary School",
        "district": "Berlin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330186000163",
    },
    {
        "school": "Broken Ground School",
        "district": "Concord School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330246000053",
    },
    {
        "school": "Abbot-Downing School",
        "district": "Concord School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330246000054",
    },
    {
        "school": "Concord High School",
        "district": "Concord School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330246000055",
    },
    {
        "school": "Mill Brook School",
        "district": "Concord School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330246000056",
    },
    {
        "school": "Christa McAuliffe School",
        "district": "Concord School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330246000060",
    },
    {
        "school": "Rundlett Middle School",
        "district": "Concord School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330246000063",
    },
    {
        "school": "Beaver Meadow School",
        "district": "Concord School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330246000496",
    },
    {
        "school": "Chesterfield Central School",
        "district": "Chesterfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330228000036",
    },
    {
        "school": "Wells Memorial School",
        "district": "Harrisville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330363000156",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Keene School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330405000200",
    },
    {
        "school": "Fuller Elementary School",
        "district": "Keene School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330405000201",
    },
    {
        "school": "Keene High School",
        "district": "Keene School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330405000202",
    },
    {
        "school": "Keene Middle School",
        "district": "Keene School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330405000203",
    },
    {
        "school": "Symonds Elementary School",
        "district": "Keene School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330405000206",
    },
    {
        "school": "Wheelock Elementary School",
        "district": "Keene School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330405000207",
    },
    {
        "school": "Marlborough Elementary School",
        "district": "Marlborough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330462000264",
    },
    {
        "school": "John D. Perkins Academy",
        "district": "Marlow School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330465000266",
    },
    {
        "school": "Nelson Elementary School",
        "district": "Nelson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330501000328",
    },
    {
        "school": "Westmoreland School",
        "district": "Westmoreland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330702000450",
    },
    {
        "school": "Elm Street School",
        "district": "Laconia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330414000209",
    },
    {
        "school": "Laconia High School",
        "district": "Laconia School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330414000210",
    },
    {
        "school": "Laconia Middle School",
        "district": "Laconia School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330414000211",
    },
    {
        "school": "Pleasant Street School",
        "district": "Laconia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330414000212",
    },
    {
        "school": "Woodland Heights Elementary School",
        "district": "Laconia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330414000213",
    },
    {
        "school": "Hanover Street School",
        "district": "Lebanon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330423000217",
    },
    {
        "school": "Lebanon High School",
        "district": "Lebanon School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330423000218",
    },
    {
        "school": "Lebanon Middle School",
        "district": "Lebanon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330423000219",
    },
    {
        "school": "Mt. Lebanon School",
        "district": "Lebanon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330423000220",
    },
    {
        "school": "North Country Charter Academy (H)",
        "district": "North Country Charter Academy",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330003000605",
    },
    {
        "school": "North Country Charter Academy (M)",
        "district": "North Country Charter Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330003000613",
    },
    {
        "school": "Colebrook Academy and Elementary School (H)",
        "district": "Colebrook School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330240000049",
    },
    {
        "school": "Colebrook Academy and Elementary School (E)",
        "district": "Colebrook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330240000050",
    },
    {
        "school": "Errol Consolidated Elementary School",
        "district": "Errol School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330294000105",
    },
    {
        "school": "Milan Village Elementary School",
        "district": "Milan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330480000289",
    },
    {
        "school": "Groveton Elementary School",
        "district": "Northumberland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330540000346",
    },
    {
        "school": "Groveton High School",
        "district": "Northumberland School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330540000347",
    },
    {
        "school": "Groveton High School (Middle)",
        "district": "Northumberland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330540000529",
    },
    {
        "school": "Pittsburg School (Elem)",
        "district": "Pittsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330570000363",
    },
    {
        "school": "Pittsburg School (High)",
        "district": "Pittsburg School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330570000528",
    },
    {
        "school": "Stark Village School",
        "district": "Stark School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330633000423",
    },
    {
        "school": "Stewartstown Community School",
        "district": "Stewartstown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330636000579",
    },
    {
        "school": "Stratford Public School",
        "district": "Stratford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330645000428",
    },
    {
        "school": "Whitefield Elementary School",
        "district": "White Mountain Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330705000004",
    },
    {
        "school": "Lancaster Elementary School",
        "district": "White Mountain Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330705000453",
    },
    {
        "school": "White Mountains Regional High School",
        "district": "White Mountain Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330705000454",
    },
    {
        "school": "Merrimack Middle School",
        "district": "Merrimack School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330474000602",
    },
    {
        "school": "Nashua High School North",
        "district": "Nashua School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000598",
    },
    {
        "school": "Pelham Elementary School",
        "district": "Pelham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330555000600",
    },
    {
        "school": "Seacoast Charter School",
        "district": "Seacoast Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330003100606",
    },
    {
        "school": "Ernest P. Barka Elementary School",
        "district": "Derry School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330261000607",
    },
    {
        "school": "Seabrook Middle School",
        "district": "Seabrook School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330615000601",
    },
    {
        "school": "Deerfield Community School",
        "district": "Deerfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330258000082",
    },
    {
        "school": "Nottingham Elementary School",
        "district": "Nottingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330546000349",
    },
    {
        "school": "Coe-Brown Northwood Academy",
        "district": "Coe Brown Academy School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330733000519",
    },
    {
        "school": "Auburn Village School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330159000011",
    },
    {
        "school": "Henry W. Moore School",
        "district": "Candia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330213000033",
    },
    {
        "school": "Derry Village School",
        "district": "Derry School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330261000083",
    },
    {
        "school": "Grinnell School",
        "district": "Derry School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330261000085",
    },
    {
        "school": "Gilbert H. Hood Middle School",
        "district": "Derry School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330261000086",
    },
    {
        "school": "South Range Elementary School",
        "district": "Derry School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330261000087",
    },
    {
        "school": "West Running Brook Middle School",
        "district": "Derry School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330261000194",
    },
    {
        "school": "East Derry Memorial Elementary School",
        "district": "Derry School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330261000497",
    },
    {
        "school": "Hampstead Central School",
        "district": "Hampstead School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330348000153",
    },
    {
        "school": "Hampstead Middle School",
        "district": "Hampstead School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330348000468",
    },
    {
        "school": "Northwood Elementary School",
        "district": "Northwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330543000348",
    },
    {
        "school": "Lamprey River Elementary School",
        "district": "Raymond School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330588000384",
    },
    {
        "school": "Raymond High School",
        "district": "Raymond School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330588000385",
    },
    {
        "school": "Iber Holmes Gove Middle School",
        "district": "Raymond School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330588000521",
    },
    {
        "school": "William T. Barron Elementary School",
        "district": "Salem School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330606000400",
    },
    {
        "school": "Dr. L. F. Soule School",
        "district": "Salem School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330606000401",
    },
    {
        "school": "William E. Lancaster School",
        "district": "Salem School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330606000403",
    },
    {
        "school": "Mary A. Fisk Elementary School",
        "district": "Salem School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330606000404",
    },
    {
        "school": "North Salem Elementary School",
        "district": "Salem School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330606000406",
    },
    {
        "school": "Salem High School",
        "district": "Salem School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330606000407",
    },
    {
        "school": "Woodbury School",
        "district": "Salem School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330606000409",
    },
    {
        "school": "Sanborn Regional Middle School",
        "district": "Sanborn Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330608000476",
    },
    {
        "school": "Memorial School",
        "district": "Sanborn Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330608000477",
    },
    {
        "school": "Daniel J. Bakie School",
        "district": "Sanborn Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330608000478",
    },
    {
        "school": "Sanborn Regional High School",
        "district": "Sanborn Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330608000479",
    },
    {
        "school": "Atkinson Academy",
        "district": "Timberlane Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330672000434",
    },
    {
        "school": "Danville Elementary School",
        "district": "Timberlane Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330672000435",
    },
    {
        "school": "Pollard Elementary School",
        "district": "Timberlane Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330672000436",
    },
    {
        "school": "Sandown Central School",
        "district": "Timberlane Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330672000438",
    },
    {
        "school": "Timberlane Regional High School",
        "district": "Timberlane Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330672000439",
    },
    {
        "school": "Timberlane Regional Middle School",
        "district": "Timberlane Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330672000440",
    },
    {
        "school": "Sandown North Elementary School",
        "district": "Timberlane Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330672000596",
    },
    {
        "school": "Windham Center School",
        "district": "Windham School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330717000460",
    },
    {
        "school": "Golden Brook Elementary School",
        "district": "Windham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330717000461",
    },
    {
        "school": "Windham Middle School",
        "district": "Windham School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330717000495",
    },
    {
        "school": "Pinkerton Academy",
        "district": "Pinkerton Academy School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330736000510",
    },
    {
        "school": "Dublin Consolidated School",
        "district": "Contoocook Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330248000068",
    },
    {
        "school": "Antrim Elementary School",
        "district": "Contoocook Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330248000065",
    },
    {
        "school": "Great Brook School",
        "district": "Contoocook Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330248000066",
    },
    {
        "school": "Conval Regional High School",
        "district": "Contoocook Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330248000067",
    },
    {
        "school": "Francestown Elementary School",
        "district": "Contoocook Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330248000069",
    },
    {
        "school": "Greenfield Elementary School",
        "district": "Contoocook Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330248000070",
    },
    {
        "school": "Hancock Elementary School",
        "district": "Contoocook Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330248000071",
    },
    {
        "school": "Peterborough Elementary School",
        "district": "Contoocook Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330248000072",
    },
    {
        "school": "South Meadow School",
        "district": "Contoocook Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330248000073",
    },
    {
        "school": "Pierce Elementary School",
        "district": "Contoocook Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330248000074",
    },
    {
        "school": "Temple Elementary School",
        "district": "Contoocook Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330248000075",
    },
    {
        "school": "Hillsboro-Deering Elementary School",
        "district": "Hillsboro Deering Coop School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330375000165",
    },
    {
        "school": "Hillsboro-Deering High School",
        "district": "Hillsboro Deering Coop School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330375000166",
    },
    {
        "school": "Hillsboro-Deering Middle School",
        "district": "Hillsboro Deering Coop School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330375000481",
    },
    {
        "school": "New Boston Central School",
        "district": "New Boston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330504000329",
    },
    {
        "school": "Londonderry Middle School",
        "district": "Londonderry School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330441000232",
    },
    {
        "school": "Matthew Thornton Elementary School",
        "district": "Londonderry School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330441000233",
    },
    {
        "school": "North Londonderry Elementary School",
        "district": "Londonderry School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330441000234",
    },
    {
        "school": "South Londonderry Elementary School",
        "district": "Londonderry School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330441000473",
    },
    {
        "school": "Londonderry Senior High School",
        "district": "Londonderry School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330441000484",
    },
    {
        "school": "Moose Hill School",
        "district": "Londonderry School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330441000594",
    },
    {
        "school": "John Stark Regional High School",
        "district": "John Stark Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330000300500",
    },
    {
        "school": "Clark-Wilkins School",
        "district": "Amherst School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330147000006",
    },
    {
        "school": "Amherst Middle School",
        "district": "Amherst School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330147000007",
    },
    {
        "school": "Richard Maghakian Memorial School",
        "district": "Brookline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330207000031",
    },
    {
        "school": "Captain Samuel Douglass Academy",
        "district": "Brookline School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330207000670",
    },
    {
        "school": "Hollis Primary School",
        "district": "Hollis School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330384000171",
    },
    {
        "school": "Hollis Upper Elementary School",
        "district": "Hollis School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330384000566",
    },
    {
        "school": "Hollis-Brookline High School",
        "district": "Hollis/Brookline Coop School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330385000170",
    },
    {
        "school": "Hollis-Brookline Middle School",
        "district": "Hollis/Brookline Coop School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330385000172",
    },
    {
        "school": "Alvirne High School",
        "district": "Hudson School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330393000179",
    },
    {
        "school": "Dr. H. O. Smith Elementary School",
        "district": "Hudson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330393000180",
    },
    {
        "school": "Hudson Memorial School",
        "district": "Hudson School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330393000181",
    },
    {
        "school": "Nottingham West Elementary School",
        "district": "Hudson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330393000513",
    },
    {
        "school": "Hills Garrison Elementary School",
        "district": "Hudson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330393000593",
    },
    {
        "school": "Griffin Memorial School",
        "district": "Litchfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330435000228",
    },
    {
        "school": "Litchfield Middle School",
        "district": "Litchfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330435000514",
    },
    {
        "school": "Campbell High School",
        "district": "Litchfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330435000674",
    },
    {
        "school": "Mascenic Regional High School",
        "district": "Mascenic Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330467000270",
    },
    {
        "school": "Boynton Middle School",
        "district": "Mascenic Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330467000515",
    },
    {
        "school": "James Mastricola Elementary School",
        "district": "Merrimack School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330474000276",
    },
    {
        "school": "James Mastricola Upper Elementary School",
        "district": "Merrimack School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330474000277",
    },
    {
        "school": "Merrimack High School",
        "district": "Merrimack School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330474000278",
    },
    {
        "school": "Reeds Ferry School",
        "district": "Merrimack School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330474000279",
    },
    {
        "school": "Thorntons Ferry School",
        "district": "Merrimack School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330474000280",
    },
    {
        "school": "Milford Middle School",
        "district": "Milford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330483000293",
    },
    {
        "school": "Milford High School",
        "district": "Milford School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330483000294",
    },
    {
        "school": "Jacques Memorial Elementary School",
        "district": "Milford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330483000507",
    },
    {
        "school": "Heron Pond Elementary School",
        "district": "Milford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330483000595",
    },
    {
        "school": "Mont Vernon Village School",
        "district": "Mont Vernon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330495000309",
    },
    {
        "school": "Amherst Street School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000310",
    },
    {
        "school": "Bicentennial Elementary School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000312",
    },
    {
        "school": "Birch Hill Elementary School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000313",
    },
    {
        "school": "Broad Street Elementary School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000314",
    },
    {
        "school": "Charlotte Ave Elementary School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000315",
    },
    {
        "school": "Elm Street Middle School",
        "district": "Nashua School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000317",
    },
    {
        "school": "Fairgrounds Middle School",
        "district": "Nashua School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000319",
    },
    {
        "school": "Ledge Street School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000320",
    },
    {
        "school": "Main Dunstable School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000321",
    },
    {
        "school": "Mt. Pleasant School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000322",
    },
    {
        "school": "Nashua High School South",
        "district": "Nashua School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000323",
    },
    {
        "school": "New Searles School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000324",
    },
    {
        "school": "Pennichuck Middle School",
        "district": "Nashua School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000325",
    },
    {
        "school": "Sunset Heights School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000326",
    },
    {
        "school": "Dr. Norman W. Crisp School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000486",
    },
    {
        "school": "Fairgrounds Elementary School",
        "district": "Nashua School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000508",
    },
    {
        "school": "Pelham Memorial School",
        "district": "Pelham School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330555000357",
    },
    {
        "school": "Pelham High School",
        "district": "Pelham School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330555000358",
    },
    {
        "school": "Souhegan Coop High School",
        "district": "Souhegan Cooperative School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330626000034",
    },
    {
        "school": "Weare Middle School",
        "district": "Weare School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330693000023",
    },
    {
        "school": "Center Woods School",
        "district": "Weare School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330693000025",
    },
    {
        "school": "Wilton-Lyndeboro Middle School",
        "district": "Wilton-Lyndeboro School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330711500110",
    },
    {
        "school": "Wilton-Lyndeboro Senior High School",
        "district": "Wilton-Lyndeboro School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330711500457",
    },
    {
        "school": "Exeter High School",
        "district": "Exeter Region Coop School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330001700106",
    },
    {
        "school": "Cooperative Middle School",
        "district": "Exeter Region Coop School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330001700107",
    },
    {
        "school": "Swasey Central School",
        "district": "Brentwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330201000030",
    },
    {
        "school": "Chester Academy",
        "district": "Chester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330225000035",
    },
    {
        "school": "East Kingston Elementary School",
        "district": "East Kingston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330279000100",
    },
    {
        "school": "Epping Elementary School",
        "district": "Epping School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330288000102",
    },
    {
        "school": "Epping High School",
        "district": "Epping School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330288000103",
    },
    {
        "school": "Epping Middle School",
        "district": "Epping School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330288000540",
    },
    {
        "school": "Lincoln Street Elementary School",
        "district": "Exeter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330297000108",
    },
    {
        "school": "Main Street School",
        "district": "Exeter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330297000109",
    },
    {
        "school": "Ellis School",
        "district": "Fremont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330315000132",
    },
    {
        "school": "Greenland Central School",
        "district": "Greenland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330342000152",
    },
    {
        "school": "Lincoln Akerman School",
        "district": "Hampton Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330354000154",
    },
    {
        "school": "Kensington Elementary School",
        "district": "Kensington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330408000208",
    },
    {
        "school": "Maude H. Trefethen School",
        "district": "New Castle School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330507000330",
    },
    {
        "school": "Newfields Elementary School",
        "district": "Newfields School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330519000331",
    },
    {
        "school": "Newington Public School",
        "district": "Newington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330525000339",
    },
    {
        "school": "Newmarket Elementary School",
        "district": "Newmarket School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330528000340",
    },
    {
        "school": "Newmarket Jr.-Sr. High School",
        "district": "Newmarket School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330528000518",
    },
    {
        "school": "Newmarket Jr.-Sr. High (Elem)",
        "district": "Newmarket School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330528000542",
    },
    {
        "school": "North Hampton School",
        "district": "North Hampton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330537000345",
    },
    {
        "school": "Rye Elementary School",
        "district": "Rye School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330603000398",
    },
    {
        "school": "Rye Junior High School",
        "district": "Rye School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330603000399",
    },
    {
        "school": "Seabrook Elementary School",
        "district": "Seabrook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330615000410",
    },
    {
        "school": "South Hampton Barnard School",
        "district": "South Hampton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330627000422",
    },
    {
        "school": "Stratham Memorial School",
        "district": "Stratham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330648000429",
    },
    {
        "school": "Allenstown Elementary School",
        "district": "Allenstown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330138000001",
    },
    {
        "school": "Armand R. Dupont School",
        "district": "Allenstown School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330138000002",
    },
    {
        "school": "Andover Elementary School",
        "district": "Andover School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330150000008",
    },
    {
        "school": "Bow Memorial School",
        "district": "Bow School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330195000029",
    },
    {
        "school": "Bow Elementary School",
        "district": "Bow School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330195000480",
    },
    {
        "school": "Bow High School",
        "district": "Bow School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330195000563",
    },
    {
        "school": "Chichester Central School",
        "district": "Chichester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330231000037",
    },
    {
        "school": "Dunbarton Elementary School",
        "district": "Dunbarton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330276000098",
    },
    {
        "school": "Epsom Central School",
        "district": "Epsom School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330291000104",
    },
    {
        "school": "Henniker Community School",
        "district": "Henniker School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330369000161",
    },
    {
        "school": "Jennie D. Blake School",
        "district": "Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330372000164",
    },
    {
        "school": "Hopkinton Middle School",
        "district": "Hopkinton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330390000052",
    },
    {
        "school": "Harold Martin School",
        "district": "Hopkinton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330390000176",
    },
    {
        "school": "Hopkinton High School",
        "district": "Hopkinton School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330390000177",
    },
    {
        "school": "Maple Street Elementary School",
        "district": "Hopkinton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330390000178",
    },
    {
        "school": "Kearsarge Reg. Elementary School - Bradford",
        "district": "Kearsarge Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330404000192",
    },
    {
        "school": "Kearsarge Regional High School",
        "district": "Kearsarge Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330404000193",
    },
    {
        "school": "Kearsarge Reg. Elem. School at New London",
        "district": "Kearsarge Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330404000195",
    },
    {
        "school": "Simonds Elementary School",
        "district": "Kearsarge Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330404000197",
    },
    {
        "school": "Sutton Central Elementary School",
        "district": "Kearsarge Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330404000198",
    },
    {
        "school": "Kearsarge Regional Middle School",
        "district": "Kearsarge Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330404000503",
    },
    {
        "school": "Boscawen Elementary School",
        "district": "Merrimack Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330476000281",
    },
    {
        "school": "Loudon Elementary School",
        "district": "Merrimack Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330476000282",
    },
    {
        "school": "Penacook Elementary School",
        "district": "Merrimack Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330476000283",
    },
    {
        "school": "Merrimack Valley High School",
        "district": "Merrimack Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330476000284",
    },
    {
        "school": "Salisbury Elementary School",
        "district": "Merrimack Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330476000285",
    },
    {
        "school": "Webster Elementary School",
        "district": "Merrimack Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330476000287",
    },
    {
        "school": "Merrimack Valley Middle School",
        "district": "Merrimack Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330476000506",
    },
    {
        "school": "Three Rivers School",
        "district": "Pembroke School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330558000042",
    },
    {
        "school": "Pembroke Academy",
        "district": "Pembroke School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330558000359",
    },
    {
        "school": "Pembroke Hill School",
        "district": "Pembroke School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330558000361",
    },
    {
        "school": "Pittsfield High School",
        "district": "Pittsfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330573000366",
    },
    {
        "school": "Pittsfield Elementary School",
        "district": "Pittsfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330573000509",
    },
    {
        "school": "Pittsfield Middle School",
        "district": "Pittsfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330573000539",
    },
    {
        "school": "Franklin High School",
        "district": "Franklin School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330309000128",
    },
    {
        "school": "Paul A. Smith School",
        "district": "Franklin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330309000130",
    },
    {
        "school": "Franklin Middle School",
        "district": "Franklin School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330309000511",
    },
    {
        "school": "Hinsdale Middle High School",
        "district": "Hinsdale School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330378000048",
    },
    {
        "school": "Hinsdale Elementary School",
        "district": "Hinsdale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330378000167",
    },
    {
        "school": "Hinsdale High School",
        "district": "Hinsdale School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330378000168",
    },
    {
        "school": "Conant High School",
        "district": "Jaffrey-Rindge Coop School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330403000188",
    },
    {
        "school": "Jaffrey Grade School",
        "district": "Jaffrey-Rindge Coop School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330403000189",
    },
    {
        "school": "Jaffrey-Rindge Middle School",
        "district": "Jaffrey-Rindge Coop School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330403000190",
    },
    {
        "school": "Rindge Memorial School",
        "district": "Jaffrey-Rindge Coop School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330403000191",
    },
    {
        "school": "Monadnock Regional Middle School",
        "district": "Monadnock Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330489000061",
    },
    {
        "school": "Cutler Elementary School",
        "district": "Monadnock Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330489000298",
    },
    {
        "school": "Dr. George S. Emerson Elementary School",
        "district": "Monadnock Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330489000299",
    },
    {
        "school": "Gilsum STEAM Academy",
        "district": "Monadnock Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330489000300",
    },
    {
        "school": "Monadnock Regional High School",
        "district": "Monadnock Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330489000301",
    },
    {
        "school": "Mt. Caesar Elementary School",
        "district": "Monadnock Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330489000302",
    },
    {
        "school": "Troy Elementary School",
        "district": "Monadnock Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330489000305",
    },
    {
        "school": "James Faulkner Elementary School",
        "district": "Stoddard School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330639000426",
    },
    {
        "school": "Winchester School",
        "district": "Winchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330714000459",
    },
    {
        "school": "Prospect Mountain High School",
        "district": "Prospect Mountain School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330004900619",
    },
    {
        "school": "Alton Central School (Elem)",
        "district": "Alton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330144000003",
    },
    {
        "school": "Barnstead Elementary School",
        "district": "Barnstead School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330162000012",
    },
    {
        "school": "Gilford Middle School",
        "district": "Gilford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330318000044",
    },
    {
        "school": "Gilford Elementary School",
        "district": "Gilford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330318000133",
    },
    {
        "school": "Gilford High School",
        "district": "Gilford School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330318000135",
    },
    {
        "school": "Gilmanton Elementary School",
        "district": "Gilmanton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330321000136",
    },
    {
        "school": "Inter-Lakes High School",
        "district": "Inter-lakes School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330396000185",
    },
    {
        "school": "Belmont High School",
        "district": "Shaker Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330618000411",
    },
    {
        "school": "Belmont Middle School",
        "district": "Shaker Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330618000413",
    },
    {
        "school": "Belmont Elementary School",
        "district": "Shaker Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330618000490",
    },
    {
        "school": "Southwick School",
        "district": "Winnisquam Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330730000204",
    },
    {
        "school": "Sanbornton Central School",
        "district": "Winnisquam Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330730000464",
    },
    {
        "school": "Winnisquam Regional High School",
        "district": "Winnisquam Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330730000465",
    },
    {
        "school": "Winnisquam Regional Middle School",
        "district": "Winnisquam Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330730000466",
    },
    {
        "school": "Sandwich Central School",
        "district": "Inter-lakes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330396000183",
    },
    {
        "school": "Canterbury Elementary School",
        "district": "Shaker Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330618000412",
    },
    {
        "school": "Union Sanborn School",
        "district": "Winnisquam Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330730000467",
    },
    {
        "school": "New Hampton Community School",
        "district": "Newfound Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330522000337",
    },
    {
        "school": "Alstead Primary School",
        "district": "Fall Mountain Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000113",
    },
    {
        "school": "North Walpole School",
        "district": "Fall Mountain Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000118",
    },
    {
        "school": "Vilas Elementary School",
        "district": "Fall Mountain Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000120",
    },
    {
        "school": "Walpole Primary School",
        "district": "Fall Mountain Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000121",
    },
    {
        "school": "Walpole Elementary School",
        "district": "Fall Mountain Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000122",
    },
    {
        "school": "Ashland Elementary School",
        "district": "Ashland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330156000010",
    },
    {
        "school": "Bath Village School",
        "district": "Bath School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330171000016",
    },
    {
        "school": "Bethlehem Elementary School",
        "district": "Bethlehem School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330189000028",
    },
    {
        "school": "Campton Elementary School",
        "district": "Campton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330210000032",
    },
    {
        "school": "Frances C. Richmond School",
        "district": "Dresden School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330267000095",
    },
    {
        "school": "Hanover High School",
        "district": "Dresden School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330267000096",
    },
    {
        "school": "Bernice A. Ray School",
        "district": "Hanover School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330360000155",
    },
    {
        "school": "Haverhill Cooperative Middle School",
        "district": "Haverhill Cooperative School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330366000020",
    },
    {
        "school": "Woodsville Elementary School",
        "district": "Haverhill Cooperative School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330366000159",
    },
    {
        "school": "Woodsville High School",
        "district": "Haverhill Cooperative School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330366000160",
    },
    {
        "school": "Holderness Central School",
        "district": "Holderness School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330381000169",
    },
    {
        "school": "Lafayette Regional School",
        "district": "Lafayette Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330415000215",
    },
    {
        "school": "Landaff Blue School",
        "district": "Landaff School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330417000216",
    },
    {
        "school": "Lin-Wood Public School (Elem)",
        "district": "Lincoln-Woodstock School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330426000493",
    },
    {
        "school": "Lin-Wood Public School (Middle)",
        "district": "Lincoln-Woodstock School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330426000531",
    },
    {
        "school": "Lin-Wood Public School (High)",
        "district": "Lincoln-Woodstock School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330426000532",
    },
    {
        "school": "Lisbon Regional School (High)",
        "district": "Lisbon Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330429000227",
    },
    {
        "school": "Lisbon Regional School (Elem)",
        "district": "Lisbon Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330429000533",
    },
    {
        "school": "Lisbon Regional School (Middle)",
        "district": "Lisbon Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330429000534",
    },
    {
        "school": "Littleton High School",
        "district": "Littleton School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330438000229",
    },
    {
        "school": "Mildred C. Lakeway School",
        "district": "Littleton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330438000230",
    },
    {
        "school": "Daisy Bronson Junior High School",
        "district": "Littleton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330438000231",
    },
    {
        "school": "Canaan Elementary School",
        "district": "Mascoma Valley Reg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330468000273",
    },
    {
        "school": "Enfield Village School",
        "district": "Mascoma Valley Reg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330468000274",
    },
    {
        "school": "Mascoma Valley Regional High School",
        "district": "Mascoma Valley Reg School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330468000275",
    },
    {
        "school": "Indian River School",
        "district": "Mascoma Valley Reg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330468000498",
    },
    {
        "school": "Monroe Consolidated School",
        "district": "Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330492000307",
    },
    {
        "school": "Bristol Elementary School",
        "district": "Newfound Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330522000332",
    },
    {
        "school": "Newfound Regional High School",
        "district": "Newfound Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330522000336",
    },
    {
        "school": "Newfound Memorial Middle School",
        "district": "Newfound Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330522000517",
    },
    {
        "school": "Bridgewater-Hebron Village School",
        "district": "Newfound Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330522000590",
    },
    {
        "school": "Piermont Village School",
        "district": "Piermont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330567000362",
    },
    {
        "school": "Plymouth Elementary School",
        "district": "Plymouth School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330579000370",
    },
    {
        "school": "Profile Junior High School",
        "district": "Profile School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330583000097",
    },
    {
        "school": "Profile Senior High School",
        "district": "Profile School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330583000382",
    },
    {
        "school": "Russell Elementary School",
        "district": "Rumney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330600000397",
    },
    {
        "school": "Thornton Central School",
        "district": "Thornton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330666000433",
    },
    {
        "school": "Warren Village School",
        "district": "Warren School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330687000444",
    },
    {
        "school": "Waterville Valley Elementary School",
        "district": "Waterville Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330691000446",
    },
    {
        "school": "Wentworth Elementary School",
        "district": "Wentworth School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330699000449",
    },
    {
        "school": "Plymouth Regional High School",
        "district": "Pemi-baker Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "339996500369",
    },
    {
        "school": "Danbury Elementary School",
        "district": "Newfound Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330522000334",
    },
    {
        "school": "Bluff School",
        "district": "Claremont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330234000038",
    },
    {
        "school": "Claremont Middle School",
        "district": "Claremont School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330234000039",
    },
    {
        "school": "Maple Avenue School",
        "district": "Claremont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330234000040",
    },
    {
        "school": "Stevens High School",
        "district": "Claremont School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330234000045",
    },
    {
        "school": "Disnard Elementary School",
        "district": "Claremont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330234000488",
    },
    {
        "school": "Cornish Elementary School",
        "district": "Cornish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330252000080",
    },
    {
        "school": "Croydon Village School",
        "district": "Croydon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330255000081",
    },
    {
        "school": "Acworth Elementary School",
        "district": "Fall Mountain Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000112",
    },
    {
        "school": "Charlestown Middle School",
        "district": "Fall Mountain Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000114",
    },
    {
        "school": "Charlestown Primary School",
        "district": "Fall Mountain Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000115",
    },
    {
        "school": "Fall Mountain Regional High School",
        "district": "Fall Mountain Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000116",
    },
    {
        "school": "N. Charlestown Community School",
        "district": "Fall Mountain Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000117",
    },
    {
        "school": "Sarah Porter School",
        "district": "Fall Mountain Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000119",
    },
    {
        "school": "Fall Mountain Regional -Pre School Program",
        "district": "Fall Mountain Regional School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330299000259",
    },
    {
        "school": "Grantham Village School",
        "district": "Grantham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330336000151",
    },
    {
        "school": "Lyme Elementary School",
        "district": "Lyme School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330450000236",
    },
    {
        "school": "Newport Middle School",
        "district": "Newport School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330531000093",
    },
    {
        "school": "Newport Middle High School (High)",
        "district": "Newport School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330531000342",
    },
    {
        "school": "Richards Elementary School",
        "district": "Newport School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330531000343",
    },
    {
        "school": "Plainfield Elementary School",
        "district": "Plainfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330576000368",
    },
    {
        "school": "Sunapee Middle High School",
        "district": "Sunapee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330654000101",
    },
    {
        "school": "Sunapee Central School",
        "district": "Sunapee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330654000430",
    },
    {
        "school": "Sunapee Sr. High School",
        "district": "Sunapee School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330654000431",
    },
    {
        "school": "Unity Elementary School",
        "district": "Unity School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330675000441",
    },
    {
        "school": "Washington Elementary School",
        "district": "Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330690000445",
    },
    {
        "school": "David R. Cawley Middle School",
        "district": "Hooksett School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330387000618",
    },
    {
        "school": "McKelvie Intermediate School",
        "district": "Bedford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330174000017",
    },
    {
        "school": "Memorial School",
        "district": "Bedford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330174000018",
    },
    {
        "school": "Peter Woodbury School",
        "district": "Bedford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330174000019",
    },
    {
        "school": "Riddle Brook School",
        "district": "Bedford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330174000580",
    },
    {
        "school": "Goffstown High School",
        "district": "Goffstown School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330324000137",
    },
    {
        "school": "Bartlett Elementary School",
        "district": "Goffstown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330324000138",
    },
    {
        "school": "Maple Avenue School",
        "district": "Goffstown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330324000139",
    },
    {
        "school": "Mountain View Middle School",
        "district": "Goffstown School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330324000536",
    },
    {
        "school": "Bakersville School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000240",
    },
    {
        "school": "Beech Street School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000241",
    },
    {
        "school": "Manchester Central High School",
        "district": "Manchester School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000244",
    },
    {
        "school": "Gossler Park School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000246",
    },
    {
        "school": "Green Acres School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000248",
    },
    {
        "school": "Hallsville School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000249",
    },
    {
        "school": "Highland-Goffes Falls School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000250",
    },
    {
        "school": "Hillside Middle School",
        "district": "Manchester School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000251",
    },
    {
        "school": "Jewett School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000252",
    },
    {
        "school": "Manchester Memorial High School",
        "district": "Manchester School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000253",
    },
    {
        "school": "Parker-Varney School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000254",
    },
    {
        "school": "Middle School At Parkside",
        "district": "Manchester School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000255",
    },
    {
        "school": "Smyth Road School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000257",
    },
    {
        "school": "Southside Middle School",
        "district": "Manchester School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000258",
    },
    {
        "school": "Webster School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000260",
    },
    {
        "school": "Manchester West High School",
        "district": "Manchester School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000261",
    },
    {
        "school": "Weston Elementary School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000262",
    },
    {
        "school": "Henry Wilson Elementary School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000263",
    },
    {
        "school": "McDonough School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000485",
    },
    {
        "school": "Northwest Elementary School",
        "district": "Manchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000505",
    },
    {
        "school": "Henry J. McLaughlin Jr. Middle School",
        "district": "Manchester School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000576",
    },
    {
        "school": "Fred C. Underhill School",
        "district": "Hooksett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330387000173",
    },
    {
        "school": "Hooksett Memorial School",
        "district": "Hooksett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330387000175",
    },
    {
        "school": "Hampton Centre School",
        "district": "Hampton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330351000469",
    },
    {
        "school": "Adeline C. Marston School",
        "district": "Hampton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330351000470",
    },
    {
        "school": "Hampton Academy",
        "district": "Hampton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330351000471",
    },
    {
        "school": "Mary C. Dondero Elementary School",
        "district": "Portsmouth School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330582000373",
    },
    {
        "school": "Little Harbour School",
        "district": "Portsmouth School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330582000376",
    },
    {
        "school": "New Franklin School",
        "district": "Portsmouth School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330582000377",
    },
    {
        "school": "Portsmouth Middle School",
        "district": "Portsmouth School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330582000378",
    },
    {
        "school": "Portsmouth High School",
        "district": "Portsmouth School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330582000379",
    },
    {
        "school": "PEEP School - Pre School Program",
        "district": "Portsmouth School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330582000547",
    },
    {
        "school": "Winnacunnet High School",
        "district": "Winnacunnet Coop School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330723000463",
    },
    {
        "school": "Cocheco Academy for the Arts",
        "district": "Cocheco Arts And Technology Academy",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330003600614",
    },
    {
        "school": "Valley View Community School",
        "district": "Farmington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330300000597",
    },
    {
        "school": "Josiah Bartlett Elementary School",
        "district": "Bartlett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330168000015",
    },
    {
        "school": "A. Crosby Kennett Middle School",
        "district": "Conway School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330249000043",
    },
    {
        "school": "Kennett High School",
        "district": "Conway School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330249000076",
    },
    {
        "school": "Conway Elementary School",
        "district": "Conway School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330249000077",
    },
    {
        "school": "John H. Fuller School",
        "district": "Conway School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330249000078",
    },
    {
        "school": "Pine Tree Elementary School",
        "district": "Conway School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330249000079",
    },
    {
        "school": "Freedom Elementary School",
        "district": "Freedom School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330312000131",
    },
    {
        "school": "Jackson Grammar School",
        "district": "Jackson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330399000187",
    },
    {
        "school": "Madison Elementary School",
        "district": "Madison School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330456000238",
    },
    {
        "school": "Moultonborough Middle Level",
        "district": "Moultonborough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330496000092",
    },
    {
        "school": "Moultonborough Central School",
        "district": "Moultonborough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330496000147",
    },
    {
        "school": "Moultonborough Academy",
        "district": "Moultonborough School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330496000527",
    },
    {
        "school": "Kenneth A. Brett School",
        "district": "Tamworth School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330660000432",
    },
    {
        "school": "Paul Elementary School",
        "district": "Wakefield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330678000442",
    },
    {
        "school": "Carpenter Elementary School",
        "district": "Governor Wentworth Reg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330333000144",
    },
    {
        "school": "Effingham Elementary School",
        "district": "Governor Wentworth Reg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330333000145",
    },
    {
        "school": "Kingswood Regional High School",
        "district": "Governor Wentworth Reg School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330333000146",
    },
    {
        "school": "Ossipee Central School",
        "district": "Governor Wentworth Reg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330333000149",
    },
    {
        "school": "Tuftonboro Central School",
        "district": "Governor Wentworth Reg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330333000150",
    },
    {
        "school": "Kingswood Regional Middle School",
        "district": "Governor Wentworth Reg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330333000512",
    },
    {
        "school": "Crescent Lake School",
        "district": "Governor Wentworth Reg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330333000565",
    },
    {
        "school": "Milton Elementary School",
        "district": "Milton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330061600295",
    },
    {
        "school": "Nute Junior High School",
        "district": "Milton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330061600296",
    },
    {
        "school": "Nute High School",
        "district": "Milton School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330061600544",
    },
    {
        "school": "Barrington Elementary School",
        "district": "Barrington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330165000013",
    },
    {
        "school": "Barrington Middle School",
        "district": "Barrington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330165000014",
    },
    {
        "school": "Dover Senior High School",
        "district": "Dover School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330264000088",
    },
    {
        "school": "Dover Middle School",
        "district": "Dover School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330264000089",
    },
    {
        "school": "Garrison School",
        "district": "Dover School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330264000090",
    },
    {
        "school": "Horne Street School",
        "district": "Dover School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330264000091",
    },
    {
        "school": "Woodman Park School",
        "district": "Dover School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330264000094",
    },
    {
        "school": "Farmington Senior High School",
        "district": "Farmington School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330300000123",
    },
    {
        "school": "Henry Wilson Memorial School",
        "district": "Farmington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330300000124",
    },
    {
        "school": "New Durham Elementary School",
        "district": "Governor Wentworth Reg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330333000148",
    },
    {
        "school": "Mast Way School",
        "district": "Oyster River Coop School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330552000352",
    },
    {
        "school": "Oyster River High School",
        "district": "Oyster River Coop School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330552000354",
    },
    {
        "school": "Oyster River Middle School",
        "district": "Oyster River Coop School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330552000355",
    },
    {
        "school": "Moharimet School",
        "district": "Oyster River Coop School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330552000520",
    },
    {
        "school": "William Allen School",
        "district": "Rochester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330594000386",
    },
    {
        "school": "Chamberlain Street School",
        "district": "Rochester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330594000388",
    },
    {
        "school": "Gonic School",
        "district": "Rochester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330594000389",
    },
    {
        "school": "McClelland School",
        "district": "Rochester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330594000391",
    },
    {
        "school": "East Rochester School",
        "district": "Rochester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330594000392",
    },
    {
        "school": "School Street School",
        "district": "Rochester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330594000393",
    },
    {
        "school": "Spaulding High School",
        "district": "Rochester School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330594000394",
    },
    {
        "school": "Rochester Middle School",
        "district": "Rochester School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330594000395",
    },
    {
        "school": "Nancy Loud School",
        "district": "Rochester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330594000522",
    },
    {
        "school": "Rollinsford Grade School",
        "district": "Rollinsford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330597000396",
    },
    {
        "school": "Somersworth High School",
        "district": "Somersworth School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330624000418",
    },
    {
        "school": "Somersworth Middle School",
        "district": "Somersworth School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330624000420",
    },
    {
        "school": "Strafford School",
        "district": "Strafford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330642000427",
    },
    {
        "school": "Carlstadt Public School",
        "district": "Carlstadt PublicSchool District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340279000813",
    },
    {
        "school": "Charles R Smith Early Chilhood Center",
        "district": "Palisades Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341236000789",
    },
    {
        "school": "Bordentown Regional Middle School",
        "district": "Bordentown Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340203000801",
    },
    {
        "school": "Fairfield Township School",
        "district": "Fairfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340504000811",
    },
    {
        "school": "Pauline J. Petway Elementary School",
        "district": "Vineland Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680000807",
    },
    {
        "school": "Thomas W. Wallace Jr. Middle School",
        "district": "Vineland Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680000823",
    },
    {
        "school": "Union Township Elementary School",
        "district": "Union Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341644000805",
    },
    {
        "school": "Central Jersey College Prep Charter School",
        "district": "Central Jersey College Prep Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340009000829",
    },
    {
        "school": "NuView Academy",
        "district": "Educational Services Commission of New Jersey",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348018000799",
    },
    {
        "school": "Benedict A. Cucinella School",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341713000815",
    },
    {
        "school": "Jackson Liberty High School",
        "district": "Jackson Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340774000787",
    },
    {
        "school": "Ronald L. Meinders Primary Learning Center",
        "district": "Stafford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341569000796",
    },
    {
        "school": "URBAN Leadership Academy",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269000803",
    },
    {
        "school": "International High School",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269000809",
    },
    {
        "school": "LaMonte-Annex Elementary School",
        "district": "Bound Brook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340210000790",
    },
    {
        "school": "Dr. Albert Einstein Academy School No. 29",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459000806",
    },
    {
        "school": "Chessie Dentley Roberts Academy School No. 30",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459000825",
    },
    {
        "school": "Ridge and Valley Charter School",
        "district": "Ridge and Valley Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340008200569",
    },
    {
        "school": "Lopatcong Township Middle School",
        "district": "Lopatcong Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340900000731",
    },
    {
        "school": "Central Elementary School",
        "district": "GREAT MEADOWS REGIONAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340000800107",
    },
    {
        "school": "Great Meadows Regional Middle School",
        "district": "GREAT MEADOWS REGIONAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340000800248",
    },
    {
        "school": "Allamuchy Township School",
        "district": "Allamuchy Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340072005788",
    },
    {
        "school": "Alpha Borough School",
        "district": "Alpha Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340084005790",
    },
    {
        "school": "Belvidere High School",
        "district": "Belvidere School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340144005794",
    },
    {
        "school": "Oxford Street Elementary School",
        "district": "Belvidere School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340144005796",
    },
    {
        "school": "Blairstown Elementary School",
        "district": "Blairstown Elementary Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340180005800",
    },
    {
        "school": "Franklin Township School",
        "district": "Franklin Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340552005802",
    },
    {
        "school": "Frelinghuysen Township Elementary School",
        "district": "FRELINGHUYSEN TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340567005804",
    },
    {
        "school": "Greenwich School",
        "district": "Greenwich Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340621000471",
    },
    {
        "school": "Stewartsville Middle School",
        "district": "Greenwich Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340621005810",
    },
    {
        "school": "Hackettstown High School",
        "district": "Hackettstown Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340630005814",
    },
    {
        "school": "Hackettstown Middle School",
        "district": "Hackettstown Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340630005816",
    },
    {
        "school": "Hatchery Hill Elementary School",
        "district": "Hackettstown Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340630005818",
    },
    {
        "school": "Willow Grove Elementary School",
        "district": "Hackettstown Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340630005820",
    },
    {
        "school": "Harmony Township School",
        "district": "HARMONY TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340681005824",
    },
    {
        "school": "Hope Township School",
        "district": "Hope Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340747005826",
    },
    {
        "school": "Knowlton Township Board of Education",
        "district": "Knowlton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340807005832",
    },
    {
        "school": "Lopatcong Elementary School",
        "district": "Lopatcong Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340900005840",
    },
    {
        "school": "Mansfield Township Elementary",
        "district": "Mansfield Township Elementary School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340954005842",
    },
    {
        "school": "North Warren Regional School",
        "district": "North Warren Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340955005844",
    },
    {
        "school": "Oxford Central School",
        "district": "Oxford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341230005846",
    },
    {
        "school": "Phillipsburg High School",
        "district": "Phillipsburg School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341296005852",
    },
    {
        "school": "Philipsburg Primary School",
        "district": "Phillipsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341296005856",
    },
    {
        "school": "Phillipsburg Elementary School",
        "district": "Phillipsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341296005860",
    },
    {
        "school": "Phillipsburg Middle School",
        "district": "Phillipsburg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341296005862",
    },
    {
        "school": "Pohatcong Township School",
        "district": "Pohatcong Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341326000366",
    },
    {
        "school": "Warren Hills Regional High School",
        "district": "Warren Hills Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341697005878",
    },
    {
        "school": "Warren Hills Regional Middle School",
        "district": "Warren Hills Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341697005880",
    },
    {
        "school": "Washington Memorial Elementary School",
        "district": "Washington Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341701005884",
    },
    {
        "school": "Taylor Street Elementary School",
        "district": "Washington Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341701005886",
    },
    {
        "school": "Brass Castle School",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341716005890",
    },
    {
        "school": "Port Colden School",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341716005892",
    },
    {
        "school": "White Township Consolidated School",
        "district": "White Township Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341791005894",
    },
    {
        "school": "Warren County Vocational Technical School",
        "district": "Warren County Vocational Technical School",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341792005872",
    },
    {
        "school": "Atlantic County Elementary and Middle Schools",
        "district": "Atlantic County Special Services School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340000600695",
    },
    {
        "school": "Atlantic County High School",
        "district": "Atlantic County Special Services School District",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340000600697",
    },
    {
        "school": "Dr. Joyanne D. Miller Elementary School",
        "district": "Egg Harbor Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340456000698",
    },
    {
        "school": "Hammonton Early Childhood Eductional Center",
        "district": "Hammonton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340657000699",
    },
    {
        "school": "New York Avenue Elementary School",
        "district": "Somers Point School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341503000533",
    },
    {
        "school": "Emma C Attales",
        "district": "Absecon Public Schools District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340066000004",
    },
    {
        "school": "H Ashton Marsh",
        "district": "Absecon Public Schools District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340066000006",
    },
    {
        "school": "Atlantic City High School",
        "district": "Atlantic City School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340096000010",
    },
    {
        "school": "Sovereign Avenue School",
        "district": "Atlantic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340096000012",
    },
    {
        "school": "Chelsea Heights School",
        "district": "Atlantic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340096000016",
    },
    {
        "school": "Texas Avenue School",
        "district": "Atlantic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340096000018",
    },
    {
        "school": "New York Avenue School",
        "district": "Atlantic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340096000020",
    },
    {
        "school": "Uptown School Complex",
        "district": "Atlantic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340096000022",
    },
    {
        "school": "Pennsylvania Ave School",
        "district": "Atlantic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340096000026",
    },
    {
        "school": "Richmond Avenue School",
        "district": "Atlantic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340096000028",
    },
    {
        "school": "Venice Park School",
        "district": "Atlantic City School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340096000030",
    },
    {
        "school": "Dr Martin Luther King Jr School Complex",
        "district": "Atlantic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340096000032",
    },
    {
        "school": "Atlantic County Institute of Technology",
        "district": "Atlantic County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340099000034",
    },
    {
        "school": "Buena Regional High School",
        "district": "Buena Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340240000044",
    },
    {
        "school": "Buena Regional Middle School",
        "district": "Buena Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340240000046",
    },
    {
        "school": "Collings Lakes Elementary School",
        "district": "Buena Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340240000048",
    },
    {
        "school": "John C. Milanesi Elementary School",
        "district": "Buena Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340240000052",
    },
    {
        "school": "Charles L. Spragg School",
        "district": "Egg Harbor City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340453000074",
    },
    {
        "school": "Egg Harbor City Community School",
        "district": "Egg Harbor City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340453000076",
    },
    {
        "school": "E. H. Slaybaugh Elementary School",
        "district": "Egg Harbor Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340456000051",
    },
    {
        "school": "Clayton J. Davenport Elementary School",
        "district": "Egg Harbor Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340456000086",
    },
    {
        "school": "H. Russel Swift Elementary School",
        "district": "Egg Harbor Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340456000092",
    },
    {
        "school": "Egg Harbor Township High School",
        "district": "Egg Harbor Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340456005961",
    },
    {
        "school": "Estell Manor Elementary School",
        "district": "Estell Manor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340486000102",
    },
    {
        "school": "Folsom Elementary School",
        "district": "Folsom Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340528000104",
    },
    {
        "school": "Arthur Rann Elementary School",
        "district": "GALLOWAY TOWNSHIP PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340573000108",
    },
    {
        "school": "Pomona Preschool",
        "district": "GALLOWAY TOWNSHIP PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340573000114",
    },
    {
        "school": "Galloway Township Middle School",
        "district": "GALLOWAY TOWNSHIP PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340573000383",
    },
    {
        "school": "Reeds Road Elementary School",
        "district": "GALLOWAY TOWNSHIP PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340573006028",
    },
    {
        "school": "Roland Rogers Elementary School",
        "district": "GALLOWAY TOWNSHIP PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340573006088",
    },
    {
        "school": "Smithville Elementary School",
        "district": "GALLOWAY TOWNSHIP PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340573006089",
    },
    {
        "school": "Absegami High School",
        "district": "Greater Egg Harbor Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340606000122",
    },
    {
        "school": "Oakcrest High School",
        "district": "Greater Egg Harbor Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340606000124",
    },
    {
        "school": "George L. Hess Educational Complex",
        "district": "Hamilton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340651000015",
    },
    {
        "school": "Joseph C Shaner Memorial Elementary School",
        "district": "Hamilton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340651000130",
    },
    {
        "school": "William Davies Middle School",
        "district": "Hamilton Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340651006029",
    },
    {
        "school": "Hammonton High School",
        "district": "Hammonton School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340657000136",
    },
    {
        "school": "Warren E. Sooy Jr. Elementary School",
        "district": "Hammonton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340657000138",
    },
    {
        "school": "Hammonton Middle School",
        "district": "Hammonton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340657000140",
    },
    {
        "school": "Belhaven Middle School",
        "district": "Linwood City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340867000144",
    },
    {
        "school": "Seaview Elementary School",
        "district": "Linwood City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340867000150",
    },
    {
        "school": "Mainland Regional High School",
        "district": "Mainland Regional High School",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340936000158",
    },
    {
        "school": "Eugene A. Tighe Middle School",
        "district": "Margate City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340969000162",
    },
    {
        "school": "William H. Ross III School",
        "district": "Margate City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340969000393",
    },
    {
        "school": "Mullica Township Primary School",
        "district": "Mullica Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341107000172",
    },
    {
        "school": "Mullica Township Middle School",
        "district": "Mullica Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341107000174",
    },
    {
        "school": "Northfield Community Middle School",
        "district": "Northfield City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341179000215",
    },
    {
        "school": "Northfield Community Elementary School",
        "district": "Northfield City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341179000217",
    },
    {
        "school": "Pleasantville High School",
        "district": "Pleasantville Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341320000192",
    },
    {
        "school": "Washington Avenue Elementary School",
        "district": "Pleasantville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341320000194",
    },
    {
        "school": "Leeds Avenue Elementary School",
        "district": "Pleasantville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341320000198",
    },
    {
        "school": "North Main Street Elementary School",
        "district": "Pleasantville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341320000200",
    },
    {
        "school": "South Main Street Elementary School",
        "district": "Pleasantville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341320000202",
    },
    {
        "school": "Pleasantville Middle School",
        "district": "Pleasantville Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341320000219",
    },
    {
        "school": "Port Republic Elementary School",
        "district": "Port Republic School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341338000204",
    },
    {
        "school": "Dawes Avenue Elementary School",
        "district": "Somers Point School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341503000208",
    },
    {
        "school": "Jordan Road Elementary School",
        "district": "Somers Point School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341503000210",
    },
    {
        "school": "Ventnor Middle School",
        "district": "Ventnor City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341668000216",
    },
    {
        "school": "Ventnor Elementary School",
        "district": "Ventnor City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341668000407",
    },
    {
        "school": "Weymouth Township Elementary School",
        "district": "Weymouth Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341785000220",
    },
    {
        "school": "Lodi MS HS",
        "district": "South  Bergen Jointure Commission School District",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340000700578",
    },
    {
        "school": "McKenzie School",
        "district": "East Rutherford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340429000474",
    },
    {
        "school": "Colonial Road School",
        "district": "Franklin Lakes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340537000532",
    },
    {
        "school": "Garfield Early Childhood Learning Center",
        "district": "Garfield Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576006110",
    },
    {
        "school": "ALEXANDER HAMILTON SCHOOL",
        "district": "Glen Rock Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340597000482",
    },
    {
        "school": "Hasbrouck Heights Middle School",
        "district": "Hasbrouck Heights School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340693000491",
    },
    {
        "school": "Lenape Meadows",
        "district": "Mahwah Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340933000492",
    },
    {
        "school": "Waldwick Middle School",
        "district": "Waldwick School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341686000537",
    },
    {
        "school": "TEAM Academy Charter School",
        "district": "TEAM Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340007000529",
    },
    {
        "school": "University Heights Charter School",
        "district": "University Heights Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340008400575",
    },
    {
        "school": "East Orange Campus High School",
        "district": "East Orange School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423000494",
    },
    {
        "school": "American History High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134000791",
    },
    {
        "school": "Rosa Parks /Central Community School",
        "district": "ORANGE BOARD OF EDUCATION School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341227006117",
    },
    {
        "school": "Liberty Middle School",
        "district": "West Orange Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761006112",
    },
    {
        "school": "Essex Campus Academy",
        "district": "Essex Regional Educational Services Commission",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "348030000543",
    },
    {
        "school": "University Academy Charter High School",
        "district": "University Academy Charter High School",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340007300531",
    },
    {
        "school": "Middle School # 4",
        "district": "Jersey City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783000539",
    },
    {
        "school": "Franklin L. Williams School",
        "district": "Jersey City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783006114",
    },
    {
        "school": "Emerson Middle School",
        "district": "Union City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638000546",
    },
    {
        "school": "Veterans' Memorial Elementary School",
        "district": "Union City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638000715",
    },
    {
        "school": "Eugenio Maria de Hostos Center for Early Childhood Education",
        "district": "Union City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638000819",
    },
    {
        "school": "West New York Middle School",
        "district": "West New York Board of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341758000547",
    },
    {
        "school": "Hunterdon Polytech Bartles Corner Campus",
        "district": "Hunterdon County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340005000716",
    },
    {
        "school": "J.P. Case Middle School",
        "district": "Flemington-Raritan Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340519000541",
    },
    {
        "school": "Tewksbury Elementary School",
        "district": "Tewksbury Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341617000545",
    },
    {
        "school": "ESC Academy",
        "district": "Hunterdon County Educational Services Commission",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348036006116",
    },
    {
        "school": "Highland Park Middle School",
        "district": "Highland Park Boro School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340717006118",
    },
    {
        "school": "Ignacio Cruz Early Childhood Center",
        "district": "Perth Amboy Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293000551",
    },
    {
        "school": "Samsel Upper Elementary School",
        "district": "Sayreville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341464000553",
    },
    {
        "school": "Brooks Crossing Elementary School",
        "district": "South Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341521000509",
    },
    {
        "school": "South River Primary School",
        "district": "South River Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341539000548",
    },
    {
        "school": "Developmental Learning Center",
        "district": "Bayshore Jointure Commission School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340006900719",
    },
    {
        "school": "Conover Road Primary School",
        "district": "Colts Neck Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340345000513",
    },
    {
        "school": "Early Childhood Learning Center",
        "district": "Freehold Township School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340564006120",
    },
    {
        "school": "Adelphia Elementary School",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756000721",
    },
    {
        "school": "Greenville Elementary School",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756000722",
    },
    {
        "school": "Memorial Elementary School",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756006123",
    },
    {
        "school": "Marlboro Memorial Middle School",
        "district": "Marlboro Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340972000515",
    },
    {
        "school": "Cambridge Park Elementary School",
        "district": "Matawan-Aberdeen Regional School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340975000723",
    },
    {
        "school": "Biotechnology High School",
        "district": "Monmouth County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341750006121",
    },
    {
        "school": "Academy for Mathematics Science and Engineering",
        "district": "Morris County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341072000522",
    },
    {
        "school": "Central Park School",
        "district": "Educational Services Commission of Morris County",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348026000519",
    },
    {
        "school": "Berkeley Township Elementary School",
        "district": "Berkeley Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340156006125",
    },
    {
        "school": "Elms Elementary School",
        "district": "Jackson Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340774000725",
    },
    {
        "school": "Marine Academy of Technology and Environmental Science",
        "district": "Ocean County Vocational Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341198000559",
    },
    {
        "school": "Performing Arts Academy of the Ocean County Vocational Tech",
        "district": "Ocean County Vocational Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341198006122",
    },
    {
        "school": "New Egypt Primary School",
        "district": "Plumsted Township School District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341323000560",
    },
    {
        "school": "Toms River Intermediate School South",
        "district": "Toms River Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623000555",
    },
    {
        "school": "Barnegat High School",
        "district": "Barnegat Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341647000557",
    },
    {
        "school": "Paterson Charter School for Science/Technology",
        "district": "Paterson Charter School for Science and Technology",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340008700735",
    },
    {
        "school": "School #17",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330006132",
    },
    {
        "school": "Little Falls Township Public School # 3",
        "district": "Little Falls Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340873000525",
    },
    {
        "school": "Anthony Wayne Middle School",
        "district": "Wayne Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728000558",
    },
    {
        "school": "Developmental Learning Center Warren",
        "district": "Morris-Union Jointure Commisson School District",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340000500817",
    },
    {
        "school": "Milltown Primary School",
        "district": "Bridgewater-Raritan Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340228006126",
    },
    {
        "school": "Franklin Middle School at Sampson G. Smith Campus",
        "district": "Franklin Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340549000563",
    },
    {
        "school": "Montgomery Lower Middle School",
        "district": "Montgomery Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341059006130",
    },
    {
        "school": "Byram Lakes Elementary School",
        "district": "Byram Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340255000728",
    },
    {
        "school": "Hardyston Township Middle School",
        "district": "Hardyston Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340678000729",
    },
    {
        "school": "Union County TEAMS Charter School",
        "district": "Union County TEAMS Charter School-High School/College LA",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340008300573",
    },
    {
        "school": "Dr. Martin Luther King Jr. Early Childhood Center No 52",
        "district": "Elizabeth Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459000567",
    },
    {
        "school": "Donald Stewart Early Childhood Center No 51",
        "district": "Elizabeth Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459006131",
    },
    {
        "school": "Beechwood School",
        "district": "MOUNTAINSIDE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341104000527",
    },
    {
        "school": "Hillcrest Academy-South",
        "district": "Union County Educational Services Commission",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "341640006127",
    },
    {
        "school": "Academy For Allied Health Sciences",
        "district": "Union County Vocational-Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341804000584",
    },
    {
        "school": "Academy For Information Technology",
        "district": "Union County Vocational-Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341804006134",
    },
    {
        "school": "Maywood Campus",
        "district": "South  Bergen Jointure Commission School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340000700081",
    },
    {
        "school": "Moonachie Campus",
        "district": "South  Bergen Jointure Commission School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340000700083",
    },
    {
        "school": "Englewood on the Palisades Charter School",
        "district": "Englewood on the Palisades Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340001400258",
    },
    {
        "school": "Teaneck Community Charter school",
        "district": "Teaneck Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340001500259",
    },
    {
        "school": "Brookside School",
        "district": "Allendale Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340075000224",
    },
    {
        "school": "Hillside Elementary School",
        "district": "Allendale Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340075000226",
    },
    {
        "school": "Alpine Elementary School",
        "district": "Alpine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340087000228",
    },
    {
        "school": "AUTISTIC",
        "district": "Bergen County Special Services School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340145000073",
    },
    {
        "school": "HEARING IMPAIRED",
        "district": "Bergen County Special Services School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340145000234",
    },
    {
        "school": "EMOTIONALLY DISTURBED",
        "district": "Bergen County Special Services School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340145000238",
    },
    {
        "school": "LIFE SKILLS",
        "district": "Bergen County Special Services School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340145000240",
    },
    {
        "school": "N. A. Bleshman Regional Day School",
        "district": "Bergen County Special Services School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340145005978",
    },
    {
        "school": "Multiply Handicapped",
        "district": "Bergen County Special Services School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340145006020",
    },
    {
        "school": "Bergen County Academies",
        "district": "Bergen County Vocational Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340147000250",
    },
    {
        "school": "Bergen County Technical High School - Paramus",
        "district": "Bergen County Vocational Technical School District",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340147000252",
    },
    {
        "school": "Bergen County Technical High School - Teterboro",
        "district": "Bergen County Vocational Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340147000262",
    },
    {
        "school": "Bergen County Technical High School - Paramus",
        "district": "Bergen County Vocational Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340147000264",
    },
    {
        "school": "Bergenfield High School",
        "district": "Bergenfield Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340150000268",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Bergenfield Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340150000270",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Bergenfield Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340150000272",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Bergenfield Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340150000274",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Bergenfield Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340150000276",
    },
    {
        "school": "Roy W. Brown Middle School",
        "district": "Bergenfield Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340150000278",
    },
    {
        "school": "Washington Elementary School",
        "district": "Bergenfield Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340150000280",
    },
    {
        "school": "Bogota Jr./Sr. High School",
        "district": "Bogota Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340192000284",
    },
    {
        "school": "E. Roy Bixby",
        "district": "Bogota Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340192000286",
    },
    {
        "school": "Lillian M. Steen",
        "district": "Bogota Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340192000290",
    },
    {
        "school": "Henry P. Becton Regional High School",
        "district": "Carlstadt-East Rutherford Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340280000300",
    },
    {
        "school": "Cliffside Park High School",
        "district": "Cliffside Park School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340327000304",
    },
    {
        "school": "School #3",
        "district": "Cliffside Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340327000306",
    },
    {
        "school": "School #4",
        "district": "Cliffside Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340327000308",
    },
    {
        "school": "School #5",
        "district": "Cliffside Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340327000310",
    },
    {
        "school": "School #6/Middle School",
        "district": "Cliffside Park School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340327000312",
    },
    {
        "school": "Hillside Elementary School",
        "district": "Closter Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340339000316",
    },
    {
        "school": "Tenakill Middle School",
        "district": "Closter Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340339000318",
    },
    {
        "school": "Cresskill High School",
        "district": "Cresskill Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340360000324",
    },
    {
        "school": "Edward H. Bryan",
        "district": "Cresskill Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340360000326",
    },
    {
        "school": "Merritt Memorial",
        "district": "Cresskill Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340360000328",
    },
    {
        "school": "County Road School",
        "district": "Demarest School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340381000332",
    },
    {
        "school": "Demarest Middle School",
        "district": "Demarest School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340381000334",
    },
    {
        "school": "Luther Lee Emerson School",
        "district": "Demarest School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340381006085",
    },
    {
        "school": "Dumont High School",
        "district": "Dumont Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340399000340",
    },
    {
        "school": "Grant Elementary School",
        "district": "Dumont Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340399000342",
    },
    {
        "school": "Honiss Elementary\Middle School",
        "district": "Dumont Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340399000344",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Dumont Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340399000346",
    },
    {
        "school": "Selzer Elementary\Middle School",
        "district": "Dumont Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340399000348",
    },
    {
        "school": "Alfred S. Faust",
        "district": "East Rutherford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340429000352",
    },
    {
        "school": "Eleanor Van Gelder",
        "district": "Edgewater School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340444000362",
    },
    {
        "school": "Memorial Middle School",
        "district": "Elmwood Park School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340466000075",
    },
    {
        "school": "Memorial Senior High School",
        "district": "Elmwood Park School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340466000368",
    },
    {
        "school": "Gantner Avenue School",
        "district": "Elmwood Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340466000372",
    },
    {
        "school": "Gilbert Avenue School",
        "district": "Elmwood Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340466000374",
    },
    {
        "school": "Sixteenth Avenue School",
        "district": "Elmwood Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340466000376",
    },
    {
        "school": "Emerson Jr Sr High",
        "district": "Emerson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340471000380",
    },
    {
        "school": "Patrick M Villano School",
        "district": "Emerson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340471000382",
    },
    {
        "school": "Memorial School",
        "district": "Emerson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340471000384",
    },
    {
        "school": "Dwight Morrow High School/Academies@Englewood",
        "district": "Englewood Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340474000388",
    },
    {
        "school": "Dr. Leroy McCloud Elementary School",
        "district": "Englewood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340474000390",
    },
    {
        "school": "Donald A. Quarles Early Childhood Center",
        "district": "Englewood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340474000392",
    },
    {
        "school": "Janis E. Dismus Middle School",
        "district": "Englewood Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340474000394",
    },
    {
        "school": "North Cliff School",
        "district": "Englewood Cliffs School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340477000402",
    },
    {
        "school": "Upper School",
        "district": "Englewood Cliffs School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340477000406",
    },
    {
        "school": "Thomas Jefferson Middle School",
        "district": "Fair Lawn Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340498000053",
    },
    {
        "school": "Fair Lawn High School",
        "district": "Fair Lawn Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340498000410",
    },
    {
        "school": "Memorial Middle School",
        "district": "Fair Lawn Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340498000414",
    },
    {
        "school": "Henry B. Milnes Elementary School",
        "district": "Fair Lawn Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340498000416",
    },
    {
        "school": "John A. Forrest Elementary School",
        "district": "Fair Lawn Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340498000418",
    },
    {
        "school": "Lyncrest Elementary School",
        "district": "Fair Lawn Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340498000420",
    },
    {
        "school": "Radburn Elementary School",
        "district": "Fair Lawn Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340498000422",
    },
    {
        "school": "Warren Point Elementary School",
        "district": "Fair Lawn Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340498000426",
    },
    {
        "school": "Westmoreland Elementary School",
        "district": "Fair Lawn Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340498000430",
    },
    {
        "school": "Lincoln School Annex",
        "district": "Fairview Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340507000256",
    },
    {
        "school": "Lincoln School",
        "district": "Fairview Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340507000436",
    },
    {
        "school": "Number Three School",
        "district": "Fairview Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340507000438",
    },
    {
        "school": "Fort Lee High School",
        "district": "Fort Lee School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340531000442",
    },
    {
        "school": "School No. 1",
        "district": "Fort Lee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340531000444",
    },
    {
        "school": "School No. 2",
        "district": "Fort Lee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340531000446",
    },
    {
        "school": "School No. 3",
        "district": "Fort Lee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340531000448",
    },
    {
        "school": "School No. 4",
        "district": "Fort Lee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340531000450",
    },
    {
        "school": "Lewis F. Cole Middle School",
        "district": "Fort Lee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340531000452",
    },
    {
        "school": "Franklin Avenue Middle School",
        "district": "Franklin Lakes School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340537000117",
    },
    {
        "school": "High Mountain Road School",
        "district": "Franklin Lakes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340537000460",
    },
    {
        "school": "Woodside Avenue School",
        "district": "Franklin Lakes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340537000462",
    },
    {
        "school": "GARFIELD PUBLIC PRESCHOOL ANNEX",
        "district": "Garfield Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576000386",
    },
    {
        "school": "James Madison School #10",
        "district": "Garfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576000387",
    },
    {
        "school": "Garfield High School",
        "district": "Garfield Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576000466",
    },
    {
        "school": "Christopher Columbus School #8",
        "district": "Garfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576000468",
    },
    {
        "school": "Garfield Middle School",
        "district": "Garfield Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576000470",
    },
    {
        "school": "Abraham Lincoln School #6",
        "district": "Garfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576000472",
    },
    {
        "school": "Roosevelt School #7",
        "district": "Garfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576000476",
    },
    {
        "school": "Washington Irving School #4",
        "district": "Garfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576000478",
    },
    {
        "school": "Woodrow Wilson School  #5",
        "district": "Garfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576000480",
    },
    {
        "school": "GLEN ROCK MIDDLE SCHOOL",
        "district": "Glen Rock Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340597000077",
    },
    {
        "school": "GLEN ROCK HIGH SCHOOL",
        "district": "Glen Rock Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340597000484",
    },
    {
        "school": "Richard Byrd",
        "district": "Glen Rock Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340597000486",
    },
    {
        "school": "CENTRAL SCHOOL",
        "district": "Glen Rock Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340597000488",
    },
    {
        "school": "CLARA E COLEMAN SCHOOL",
        "district": "Glen Rock Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340597000490",
    },
    {
        "school": "Hackensack High School",
        "district": "Hackensack School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340627000496",
    },
    {
        "school": "Nellie K. Parker",
        "district": "Hackensack School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340627000498",
    },
    {
        "school": "Fairmount",
        "district": "Hackensack School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340627000500",
    },
    {
        "school": "Fanny Meyer Hillers",
        "district": "Hackensack School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340627000502",
    },
    {
        "school": "Jackson Avenue",
        "district": "Hackensack School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340627000504",
    },
    {
        "school": "Harrington Park School",
        "district": "Harrington Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340684000508",
    },
    {
        "school": "Hasbrouck Heights High School",
        "district": "Hasbrouck Heights School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340693000512",
    },
    {
        "school": "Euclid Elementary School",
        "district": "Hasbrouck Heights School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340693000514",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Hasbrouck Heights School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340693000518",
    },
    {
        "school": "Haworth Public School",
        "district": "Haworth Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340696000520",
    },
    {
        "school": "Ann Blanche Smith",
        "district": "Hillsdale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340726000524",
    },
    {
        "school": "George G White",
        "district": "Hillsdale School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340726000526",
    },
    {
        "school": "Meadowbrook",
        "district": "Hillsdale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340726000528",
    },
    {
        "school": "Ho-Ho-Kus Public School",
        "district": "Ho-Ho-Kus School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340732000530",
    },
    {
        "school": "Leonia High School",
        "district": "Leonia Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340852000534",
    },
    {
        "school": "Leonia Middle School",
        "district": "Leonia Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340852000536",
    },
    {
        "school": "Anna C. Scott Elementary School",
        "district": "Leonia Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340852000538",
    },
    {
        "school": "Memorial Elementary School",
        "district": "Little Ferry Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340876000542",
    },
    {
        "school": "Washington Elementary School",
        "district": "Little Ferry Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340876000544",
    },
    {
        "school": "Lodi High School",
        "district": "Lodi School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340885000550",
    },
    {
        "school": "Columbus School",
        "district": "Lodi School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340885000552",
    },
    {
        "school": "Hilltop School",
        "district": "Lodi School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340885000554",
    },
    {
        "school": "Thomas Jefferson Middle School",
        "district": "Lodi School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340885000556",
    },
    {
        "school": "Washington School",
        "district": "Lodi School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340885000562",
    },
    {
        "school": "Wilson School",
        "district": "Lodi School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340885000564",
    },
    {
        "school": "Roosevelt School",
        "district": "Lodi School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340885005975",
    },
    {
        "school": "Lyndhurst High School",
        "district": "Lyndhurst School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340921000568",
    },
    {
        "school": "Columbus School",
        "district": "Lyndhurst School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340921000570",
    },
    {
        "school": "Franklin School",
        "district": "Lyndhurst School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340921000572",
    },
    {
        "school": "Jefferson School",
        "district": "Lyndhurst School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340921000574",
    },
    {
        "school": "Lincoln School",
        "district": "Lyndhurst School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340921000576",
    },
    {
        "school": "Roosevelt School",
        "district": "Lyndhurst School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340921000580",
    },
    {
        "school": "Washington School",
        "district": "Lyndhurst School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340921000582",
    },
    {
        "school": "Mahwah High School",
        "district": "Mahwah Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340933000586",
    },
    {
        "school": "Betsy Ross Elementary",
        "district": "Mahwah Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340933000588",
    },
    {
        "school": "Joyce Kilmer School",
        "district": "Mahwah Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340933000592",
    },
    {
        "school": "Ramapo Ridge",
        "district": "Mahwah Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340933000594",
    },
    {
        "school": "George Washington School",
        "district": "Mahwah Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340933000596",
    },
    {
        "school": "MAYWOOD AVENUE SCHOOL",
        "district": "Maywood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340981000602",
    },
    {
        "school": "Memorial School",
        "district": "Maywood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340981000604",
    },
    {
        "school": "Midland Park Jr./Sr. High School",
        "district": "Midland Park School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341014000608",
    },
    {
        "school": "Highland Elementary School",
        "district": "Midland Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341014000612",
    },
    {
        "school": "Fieldstone Middle School",
        "district": "Montvale Board of Education School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341062000616",
    },
    {
        "school": "Memorial Elementary School",
        "district": "Montvale Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341062000618",
    },
    {
        "school": "Robert L. Craig School",
        "district": "Moonachie School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341068000620",
    },
    {
        "school": "New Milford High School",
        "district": "New Milford Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341128000624",
    },
    {
        "school": "Berkley Street School",
        "district": "New Milford Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341128000626",
    },
    {
        "school": "Bertrand F. Gibbs Elementary School",
        "district": "New Milford Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341128000628",
    },
    {
        "school": "David E. Owens Middle School",
        "district": "New Milford Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341128000632",
    },
    {
        "school": "North Arlington High School",
        "district": "North Arlington School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341143000636",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "North Arlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341143000638",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "North Arlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341143000640",
    },
    {
        "school": "Washington Elementary School",
        "district": "North Arlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341143000642",
    },
    {
        "school": "North Arlington Middle School",
        "district": "North Arlington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341143000644",
    },
    {
        "school": "Northern Highlands Regional High School",
        "district": "Northern Highlands Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341173000646",
    },
    {
        "school": "Northern Valley Regional High School at Demarest",
        "district": "Northern Valley Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341176000650",
    },
    {
        "school": "Northern Valley Regional High School at Old Tappan",
        "district": "Northern Valley Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341176000652",
    },
    {
        "school": "Northvale Public School",
        "district": "Northvale Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341182000656",
    },
    {
        "school": "Norwood Public School",
        "district": "Norwood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341185000660",
    },
    {
        "school": "Dogwood Hill Elementary School",
        "district": "Oakland Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341191000664",
    },
    {
        "school": "Heights Elementary School",
        "district": "Oakland Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341191000666",
    },
    {
        "school": "Manito Elementary School",
        "district": "Oakland Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341191000668",
    },
    {
        "school": "Valley Middle School",
        "district": "Oakland Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341191000670",
    },
    {
        "school": "Charles DeWolf Middle School",
        "district": "OLD TAPPAN PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341218000674",
    },
    {
        "school": "T. Baldwin Demarest Elementary School",
        "district": "OLD TAPPAN PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341218000676",
    },
    {
        "school": "Oradell Public School",
        "district": "Oradell Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341224000678",
    },
    {
        "school": "River Dell Regional High School",
        "district": "River Dell Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341226000786",
    },
    {
        "school": "River Dell Middle School",
        "district": "River Dell Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341226000788",
    },
    {
        "school": "Palisades Park Jr-Sr High School",
        "district": "Palisades Park School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341236000682",
    },
    {
        "school": "Lindbergh Elementary School",
        "district": "Palisades Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341236000684",
    },
    {
        "school": "Midland Elementary School",
        "district": "Paramus Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341242000400",
    },
    {
        "school": "Paramus High School",
        "district": "Paramus Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341242000688",
    },
    {
        "school": "West Brook Middle School",
        "district": "Paramus Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341242000690",
    },
    {
        "school": "East Brook Middle School",
        "district": "Paramus Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341242000692",
    },
    {
        "school": "Memorial Elementary School",
        "district": "Paramus Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341242000696",
    },
    {
        "school": "Parkway Elementary School",
        "district": "Paramus Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341242000700",
    },
    {
        "school": "Ridge Ranch Elementary School",
        "district": "Paramus Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341242000702",
    },
    {
        "school": "Stony Lane Elementary School",
        "district": "Paramus Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341242000706",
    },
    {
        "school": "Park Ridge High School",
        "district": "Park Ridge School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341245000710",
    },
    {
        "school": "East Brook Elementary School",
        "district": "Park Ridge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341245000712",
    },
    {
        "school": "West Ridge Elementary School",
        "district": "Park Ridge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341245000714",
    },
    {
        "school": "Pascack Hills High School",
        "district": "Pascack Valley Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341251000718",
    },
    {
        "school": "Pascack Valley High School",
        "district": "Pascack Valley Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341251000720",
    },
    {
        "school": "Indian Hills High School",
        "district": "Ramapo Indian Hills Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341356000724",
    },
    {
        "school": "Ramapo High School",
        "district": "Ramapo Indian Hills Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341356000726",
    },
    {
        "school": "Ramsey High School",
        "district": "Ramsey School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341359000730",
    },
    {
        "school": "Eric S. Smith Middle School",
        "district": "Ramsey School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341359000732",
    },
    {
        "school": "John Y Dater Elementary School",
        "district": "Ramsey School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341359000734",
    },
    {
        "school": "Mary A. Hubbard Elementary School",
        "district": "Ramsey School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341359000736",
    },
    {
        "school": "Wesley D Tisdale Elementary School",
        "district": "Ramsey School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341359000738",
    },
    {
        "school": "Shaler Academy",
        "district": "Ridgefield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341377000078",
    },
    {
        "school": "Ridgefield Memorial High School",
        "district": "Ridgefield School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341377000742",
    },
    {
        "school": "Slocum Skewes School",
        "district": "Ridgefield School District",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341377000750",
    },
    {
        "school": "Bergen Boulevard School",
        "district": "Ridgefield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341377006057",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Ridgefield Park Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341380000257",
    },
    {
        "school": "Ridgefield Park Jr Sr High School",
        "district": "Ridgefield Park Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341380000754",
    },
    {
        "school": "Grant Elementary School",
        "district": "Ridgefield Park Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341380000756",
    },
    {
        "school": "Roosevelt  Elementary School",
        "district": "Ridgefield Park Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341380000760",
    },
    {
        "school": "Glen School",
        "district": "Ridgewood Public School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341383000221",
    },
    {
        "school": "Ridgewood High School",
        "district": "Ridgewood Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341383000764",
    },
    {
        "school": "Benjamin Franklin Middle School",
        "district": "Ridgewood Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341383000766",
    },
    {
        "school": "George Washington Middle School",
        "district": "Ridgewood Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341383000768",
    },
    {
        "school": "Hawes Elementary School",
        "district": "Ridgewood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341383000772",
    },
    {
        "school": "Ridge Elementary School",
        "district": "Ridgewood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341383000774",
    },
    {
        "school": "Somerville Elementary School",
        "district": "Ridgewood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341383000776",
    },
    {
        "school": "Travell Elementary School",
        "district": "Ridgewood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341383000778",
    },
    {
        "school": "Orchard Elementary School",
        "district": "Ridgewood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341383000780",
    },
    {
        "school": "Willard Elementary School",
        "district": "Ridgewood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341383000782",
    },
    {
        "school": "Cherry Hill School",
        "district": "River Edge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341389000792",
    },
    {
        "school": "Roosevelt School",
        "district": "River Edge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341389000794",
    },
    {
        "school": "Holdrum Middle School",
        "district": "River Vale Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341395000798",
    },
    {
        "school": "Roberge Elementary School",
        "district": "River Vale Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341395000800",
    },
    {
        "school": "Woodside Elementary School",
        "district": "River Vale Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341395000802",
    },
    {
        "school": "Midland School #1",
        "district": "Rochelle Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341407000804",
    },
    {
        "school": "Rutherford High School",
        "district": "Rutherford School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341446000810",
    },
    {
        "school": "Lincoln School",
        "district": "Rutherford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341446000812",
    },
    {
        "school": "Pierrepont School",
        "district": "Rutherford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341446000814",
    },
    {
        "school": "Union School",
        "district": "Rutherford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341446000818",
    },
    {
        "school": "Washington School",
        "district": "Rutherford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341446000820",
    },
    {
        "school": "Washington School",
        "district": "Saddle Brook School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341449000119",
    },
    {
        "school": "SADDLE BROOK MIDDLE/HIGH SCHOOL",
        "district": "Saddle Brook School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341449000824",
    },
    {
        "school": "FRANKLIN SCHOOL",
        "district": "Saddle Brook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341449000826",
    },
    {
        "school": "HELEN I. SMITH SCHOOL",
        "district": "Saddle Brook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341449000828",
    },
    {
        "school": "SALOME H. LONG MEMORIAL SCHOOL",
        "district": "Saddle Brook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341449000830",
    },
    {
        "school": "Wandell School",
        "district": "Saddle River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341452000834",
    },
    {
        "school": "Memorial School",
        "district": "South Hackensack School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341524000836",
    },
    {
        "school": "Teaneck High School",
        "district": "Teaneck School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341608000840",
    },
    {
        "school": "Benjamin Franklin Middle School",
        "district": "Teaneck School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341608000842",
    },
    {
        "school": "Thomas Jefferson Middle School",
        "district": "Teaneck School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341608000844",
    },
    {
        "school": "William Cullen Bryant School",
        "district": "Teaneck School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341608000846",
    },
    {
        "school": "Nathaniel Hawthorne Elementary School",
        "district": "Teaneck School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341608000852",
    },
    {
        "school": "James Russell Lowell Elementary School",
        "district": "Teaneck School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341608000856",
    },
    {
        "school": "John Greenleaf Whittier Elementary School",
        "district": "Teaneck School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341608000860",
    },
    {
        "school": "Tenafly High School",
        "district": "Tenafly Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341611000864",
    },
    {
        "school": "J Spencer Smith School",
        "district": "Tenafly Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341611000866",
    },
    {
        "school": "Malcolm S Mackay School",
        "district": "Tenafly Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341611000868",
    },
    {
        "school": "Ralph S Maugham School",
        "district": "Tenafly Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341611000870",
    },
    {
        "school": "Tenafly Middle School",
        "district": "Tenafly Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341611000872",
    },
    {
        "school": "Walter Stillman School",
        "district": "Tenafly Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341611000874",
    },
    {
        "school": "Emil A. Cavallini Middle School",
        "district": "Upper Saddle River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341662000880",
    },
    {
        "school": "Edith A. Bogert Elementary School",
        "district": "Upper Saddle River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341662000882",
    },
    {
        "school": "Robert D Reynolds Primary School",
        "district": "Upper Saddle River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341662000884",
    },
    {
        "school": "Waldwick High School",
        "district": "Waldwick School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341686000888",
    },
    {
        "school": "Crescent Elementary School",
        "district": "Waldwick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341686000890",
    },
    {
        "school": "Julia A Traphagen School",
        "district": "Waldwick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341686000892",
    },
    {
        "school": "Wallington Junior Senior High School",
        "district": "Wallington Boro School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341692000898",
    },
    {
        "school": "Frank W. Gavlak Elementary School",
        "district": "Wallington Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341692000900",
    },
    {
        "school": "Jefferson (Annex) Elementary School",
        "district": "Wallington Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341692000902",
    },
    {
        "school": "Westwood Junior/Senior High School",
        "district": "Westwood Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341782000906",
    },
    {
        "school": "Berkeley Elementary",
        "district": "Westwood Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341782000910",
    },
    {
        "school": "Westwood Regional Middle School",
        "district": "Westwood Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341782000912",
    },
    {
        "school": "Jessie F. George Elementary",
        "district": "Westwood Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341782000914",
    },
    {
        "school": "Brookside Elementary School",
        "district": "Westwood Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341782000916",
    },
    {
        "school": "Washington Elementary School",
        "district": "Westwood Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341782000918",
    },
    {
        "school": "Dorchester Elementary School",
        "district": "Woodcliff Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341821000934",
    },
    {
        "school": "Woodcliff Middle School",
        "district": "Woodcliff Lake School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341821000936",
    },
    {
        "school": "Wood-Ridge Jr/Sr High School",
        "district": "Wood-Ridge School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341830000922",
    },
    {
        "school": "Catherine E. Doyle Elementary School",
        "district": "Wood-Ridge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341830000924",
    },
    {
        "school": "Abraham Lincoln Elementary School",
        "district": "Wyckoff Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341836000940",
    },
    {
        "school": "Calvin Coolidge Elementary School",
        "district": "Wyckoff Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341836000942",
    },
    {
        "school": "Dwight D. Eisenhower Middle School",
        "district": "Wyckoff Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341836000944",
    },
    {
        "school": "George Washington Elementary School",
        "district": "Wyckoff Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341836000946",
    },
    {
        "school": "Sicomac Elementary School",
        "district": "Wyckoff Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341836000948",
    },
    {
        "school": "Classical Academy Charter School of Clifton",
        "district": "Classical Academy Charter School of Clifton",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340005200351",
    },
    {
        "school": "Martha B. Day Elementary School",
        "district": "Bloomingdale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340186004754",
    },
    {
        "school": "Samuel R. Donald Elementary School",
        "district": "Bloomingdale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340186004756",
    },
    {
        "school": "Walter T. Bergen Middle School",
        "district": "Bloomingdale School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340186004758",
    },
    {
        "school": "Clifton High School",
        "district": "Clifton Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004762",
    },
    {
        "school": "Christopher Columbus Middle School",
        "district": "Clifton Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004764",
    },
    {
        "school": "Woodrow Wilson Middle School",
        "district": "Clifton Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004766",
    },
    {
        "school": "School #1",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004768",
    },
    {
        "school": "School #2",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004770",
    },
    {
        "school": "School #3",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004772",
    },
    {
        "school": "School #4",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004774",
    },
    {
        "school": "School #5",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004776",
    },
    {
        "school": "School #8",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004778",
    },
    {
        "school": "School #9",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004780",
    },
    {
        "school": "School #11",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004782",
    },
    {
        "school": "School #12",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004784",
    },
    {
        "school": "School #13",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004786",
    },
    {
        "school": "School #14",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004788",
    },
    {
        "school": "School #15",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004790",
    },
    {
        "school": "School #16",
        "district": "Clifton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330004792",
    },
    {
        "school": "Haledon Public School",
        "district": "Haledon Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340645005904",
    },
    {
        "school": "Hawthorne High School",
        "district": "Hawthorne Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340699004806",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Hawthorne Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340699004810",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Hawthorne Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340699004812",
    },
    {
        "school": "Thomas Jefferson Elementary School",
        "district": "Hawthorne Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340699004814",
    },
    {
        "school": "Washington Elementary School",
        "district": "Hawthorne Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340699004816",
    },
    {
        "school": "Lakeland Regional High School",
        "district": "Lakeland Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340819004818",
    },
    {
        "school": "Little Falls Township Public School # 1",
        "district": "Little Falls Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340873004822",
    },
    {
        "school": "Little Falls Township Public School # 2",
        "district": "Little Falls Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340873004824",
    },
    {
        "school": "High Mountain School",
        "district": "North Haledon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341155004830",
    },
    {
        "school": "Memorial Elementary School",
        "district": "North Haledon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341155004832",
    },
    {
        "school": "School No. 5",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254000168",
    },
    {
        "school": "Vincent Capuana School No. 15",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254000347",
    },
    {
        "school": "School No.16",
        "district": "Passaic City School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254000403",
    },
    {
        "school": "Passaic High School No. 12",
        "district": "Passaic City School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254004836",
    },
    {
        "school": "Thomas Jefferson School No. 1",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254004838",
    },
    {
        "school": "Mario Drago School No. 3",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254004840",
    },
    {
        "school": "Martin Luther King Jr. School No. 6",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254004844",
    },
    {
        "school": "Ulysses S. Grant School No. 7",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254004846",
    },
    {
        "school": "Casimir Pulaski School No. 8",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254004848",
    },
    {
        "school": "Etta Gero School No. 9",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254004850",
    },
    {
        "school": "Theodore Roosevelt School No. 10",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254004852",
    },
    {
        "school": "William B. Cruise Memorial School No. 11",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254004854",
    },
    {
        "school": "Passaic Valley Regional High School",
        "district": "Passaic Valley Regional High School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341257004858",
    },
    {
        "school": "Passaic County-Manchester Regional High School",
        "district": "Passaic County Manchester Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341260004856",
    },
    {
        "school": "Passaic County Technical Institute",
        "district": "Passaic County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341263004860",
    },
    {
        "school": "Alexander Hamilton Academy",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269000353",
    },
    {
        "school": "Dale Avenue",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004870",
    },
    {
        "school": "Edward W. Kilpatrick",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004872",
    },
    {
        "school": "School 2",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004876",
    },
    {
        "school": "School 3",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004878",
    },
    {
        "school": "Rev. Dr. Frank Napier Jr. School",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004880",
    },
    {
        "school": "School 5",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004882",
    },
    {
        "school": "Senator Frank Lautenberg School",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004884",
    },
    {
        "school": "School 7",
        "district": "Paterson Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004886",
    },
    {
        "school": "School 8",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004888",
    },
    {
        "school": "Charles J. Riley School 9",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004890",
    },
    {
        "school": "School 10",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004892",
    },
    {
        "school": "Newcomers",
        "district": "Paterson Public School District",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004894",
    },
    {
        "school": "School 12",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004896",
    },
    {
        "school": "School 13",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004898",
    },
    {
        "school": "School 14",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004900",
    },
    {
        "school": "School 15",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004902",
    },
    {
        "school": "School 18",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004908",
    },
    {
        "school": "School 19",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004910",
    },
    {
        "school": "School 20",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004912",
    },
    {
        "school": "School 21",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004914",
    },
    {
        "school": "School 24",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004916",
    },
    {
        "school": "School 25",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004918",
    },
    {
        "school": "School 26",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004920",
    },
    {
        "school": "School 27",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004922",
    },
    {
        "school": "School 28",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004924",
    },
    {
        "school": "Roberto Clemente",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269004926",
    },
    {
        "school": "Dr. Martin Luther King Jr. Educational Complex",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269005916",
    },
    {
        "school": "Norman S. Weir",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269005942",
    },
    {
        "school": "Rosa L. Parks School of Fine and Performing Arts",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269005998",
    },
    {
        "school": "School 29",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269006072",
    },
    {
        "school": "School 1",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269006099",
    },
    {
        "school": "Pompton Lakes High School",
        "district": "Pompton Lakes School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341335004930",
    },
    {
        "school": "Lakeside School",
        "district": "Pompton Lakes School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341335004932",
    },
    {
        "school": "Lenox School",
        "district": "Pompton Lakes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341335004934",
    },
    {
        "school": "Lincoln School",
        "district": "Pompton Lakes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341335004936",
    },
    {
        "school": "Prospect Park School No. 1",
        "district": "Prospect Park Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341347004938",
    },
    {
        "school": "Eleanor G. Hewitt",
        "district": "Ringwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341386004942",
    },
    {
        "school": "Martin J. Ryerson School",
        "district": "Ringwood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341386004944",
    },
    {
        "school": "Peter Cooper School",
        "district": "Ringwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341386004946",
    },
    {
        "school": "Robert Erskine School",
        "district": "Ringwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341386004948",
    },
    {
        "school": "Memorial School",
        "district": "Totowa Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341626004952",
    },
    {
        "school": "Washington Park School",
        "district": "Totowa Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341626004954",
    },
    {
        "school": "Haskell Elementary School",
        "district": "Wanaque School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341695004958",
    },
    {
        "school": "Wanaque Elementary School",
        "district": "Wanaque School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341695004960",
    },
    {
        "school": "James Fallon Elementary School",
        "district": "Wayne Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728000408",
    },
    {
        "school": "Wayne Valley High School",
        "district": "Wayne Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004964",
    },
    {
        "school": "Wayne Hills High School",
        "district": "Wayne Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004966",
    },
    {
        "school": "Albert Payson Terhune Elementary",
        "district": "Wayne Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004970",
    },
    {
        "school": "George Washington Middle School",
        "district": "Wayne Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004972",
    },
    {
        "school": "John F. Kennedy Elementary School",
        "district": "Wayne Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004976",
    },
    {
        "school": "Lafayette Elementary School",
        "district": "Wayne Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004978",
    },
    {
        "school": "Packanack Elementary School",
        "district": "Wayne Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004982",
    },
    {
        "school": "Pines Lake Elementary School",
        "district": "Wayne Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004984",
    },
    {
        "school": "Randall Carter Elementary School",
        "district": "Wayne Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004986",
    },
    {
        "school": "Ryerson Elementary School",
        "district": "Wayne Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004988",
    },
    {
        "school": "Schuyler Colfax Middle School",
        "district": "Wayne Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004990",
    },
    {
        "school": "Theunis Dey Elementary School",
        "district": "Wayne Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341728004992",
    },
    {
        "school": "West Milford High School",
        "district": "West Milford Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341752004996",
    },
    {
        "school": "Apshawa Elementary School",
        "district": "West Milford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341752004998",
    },
    {
        "school": "Macopin Middle School",
        "district": "West Milford Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341752005002",
    },
    {
        "school": "Maple Road Elementary School",
        "district": "West Milford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341752005004",
    },
    {
        "school": "Marshall Hill Elementary School",
        "district": "West Milford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341752005006",
    },
    {
        "school": "Paradise Knoll Elementary School",
        "district": "West Milford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341752005008",
    },
    {
        "school": "Upper Greenwood Lake Elementary School",
        "district": "West Milford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341752005010",
    },
    {
        "school": "Westbrook Elementary School",
        "district": "West Milford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341752005012",
    },
    {
        "school": "Beatrice Gilmore School",
        "district": "Woodland Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341764005018",
    },
    {
        "school": "Charles Olbon School",
        "district": "Woodland Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341764005020",
    },
    {
        "school": "Memorial Middle School",
        "district": "Woodland Park School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341764005022",
    },
    {
        "school": "Skylands School for the Exceptional",
        "district": "Northern Region Educational Services Commission",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348036400103",
    },
    {
        "school": "Elysian Charter School of Hoboken",
        "district": "Elysian Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340002900297",
    },
    {
        "school": "Hoboken Charter School",
        "district": "Hoboken Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340003200302",
    },
    {
        "school": "Jersey City Community Charter School",
        "district": "Jersey City Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340003300303",
    },
    {
        "school": "Jersey City Golden Door Charter School",
        "district": "Jersey City Golden Door Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340003400305",
    },
    {
        "school": "Learning Community Charter School",
        "district": "The Learning Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340003500307",
    },
    {
        "school": "Soaring Heights Charter School",
        "district": "Soaraing Heights Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340003600309",
    },
    {
        "school": "William Shemin Midtown Community School #8",
        "district": "Bayonne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126000001",
    },
    {
        "school": "Nicholas Oresko Community School",
        "district": "Bayonne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126000141",
    },
    {
        "school": "Bayonne High School",
        "district": "Bayonne School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126002704",
    },
    {
        "school": "Walter F. Robinson Community School",
        "district": "Bayonne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126002710",
    },
    {
        "school": "John M. Bailey Community School",
        "district": "Bayonne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126002712",
    },
    {
        "school": "Henry E. Harris Community School",
        "district": "Bayonne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126002714",
    },
    {
        "school": "Horace Mann Community School",
        "district": "Bayonne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126002716",
    },
    {
        "school": "Lincoln Community School #5",
        "district": "Bayonne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126002718",
    },
    {
        "school": "Mary J Donohoe Community School",
        "district": "Bayonne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126002720",
    },
    {
        "school": "Philip G. Vroom Community School",
        "district": "Bayonne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126002722",
    },
    {
        "school": "Washington Community School #9",
        "district": "Bayonne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126002728",
    },
    {
        "school": "Woodrow Wilson Community School",
        "district": "Bayonne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126002730",
    },
    {
        "school": "East Newark Public School",
        "district": "East Newark School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340420002732",
    },
    {
        "school": "Anna L. Klein",
        "district": "Guttenberg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340624002734",
    },
    {
        "school": "Harrison High School",
        "district": "Harrison Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340687002738",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Harrison Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340687002740",
    },
    {
        "school": "Washington Middle School",
        "district": "Harrison Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340687002742",
    },
    {
        "school": "Thomas G. Connors Elementary School",
        "district": "Hoboken Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340735000065",
    },
    {
        "school": "Hoboken High School",
        "district": "Hoboken Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340735002746",
    },
    {
        "school": "Joseph F Brandt Elementary School",
        "district": "Hoboken Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340735002756",
    },
    {
        "school": "Early Childhood Learning Center at Calabro School",
        "district": "Hoboken Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340735002760",
    },
    {
        "school": "Wallace Elementary School",
        "district": "Hoboken Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340735002764",
    },
    {
        "school": "Explore Middle School",
        "district": "Hudson County Schools of Technology School District",
        "level": "Middle",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340757000189",
    },
    {
        "school": "High Tech High School",
        "district": "Hudson County Schools of Technology School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340757002766",
    },
    {
        "school": "County Prep High School",
        "district": "Hudson County Schools of Technology School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340757005906",
    },
    {
        "school": "Academy I",
        "district": "Jersey City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783000142",
    },
    {
        "school": "Liberty High School",
        "district": "Jersey City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783000391",
    },
    {
        "school": "Henry Snyder High School",
        "district": "Jersey City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002772",
    },
    {
        "school": "James J Ferris High School",
        "district": "Jersey City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002774",
    },
    {
        "school": "Lincoln High School",
        "district": "Jersey City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002776",
    },
    {
        "school": "Dr Ronald McNair High School",
        "district": "Jersey City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002778",
    },
    {
        "school": "William L Dickinson High School",
        "district": "Jersey City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002780",
    },
    {
        "school": "Frank R Conwell School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002784",
    },
    {
        "school": "Dr. Michael Conti School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002786",
    },
    {
        "school": "Charles E. Trefurt School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002788",
    },
    {
        "school": "Martin Luther King Jr. School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002792",
    },
    {
        "school": "Julia A. Barnes School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002794",
    },
    {
        "school": "Ollie Culbreth Jr. School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002796",
    },
    {
        "school": "Whitney M. Young Jr. School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002798",
    },
    {
        "school": "Dr. Maya Angelou Elementary School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002802",
    },
    {
        "school": "Rev. Dr. Ercel F. Webb School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002804",
    },
    {
        "school": "Mahatma K. Gandhi School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002806",
    },
    {
        "school": "Chaplain Charles Watters School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002808",
    },
    {
        "school": "Nicolaus Copernicus School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002810",
    },
    {
        "school": "Alfred Zampella School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002812",
    },
    {
        "school": "Christa McAuliffe School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002814",
    },
    {
        "school": "Gladys Nunery School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002816",
    },
    {
        "school": "Dr. Paul Rafalides School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002822",
    },
    {
        "school": "President Barack Obama Elementary School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002824",
    },
    {
        "school": "Rafael Cordero y Molina",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002828",
    },
    {
        "school": "Alexander D. Sullivan School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002830",
    },
    {
        "school": "Dr. Charles P. DeFuccio School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002832",
    },
    {
        "school": "Cornelia F. Bradford School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002834",
    },
    {
        "school": "Ezra L. Nolan School",
        "district": "Jersey City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002836",
    },
    {
        "school": "Martin Center for the Arts",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002838",
    },
    {
        "school": "James F. Murray School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002842",
    },
    {
        "school": "Joseph H. Brensinger School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002846",
    },
    {
        "school": "Jotham W. Wakeman School",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783002848",
    },
    {
        "school": "Regional Day School",
        "district": "Jersey City Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340783005980",
    },
    {
        "school": "Kearny High School",
        "district": "Kearny",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340789002866",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Kearny",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340789002868",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Kearny",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340789002870",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Kearny",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340789002872",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Kearny",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340789002874",
    },
    {
        "school": "Schuyler Elementary School",
        "district": "Kearny",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340789002876",
    },
    {
        "school": "Washington Elementary School",
        "district": "Kearny",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340789002878",
    },
    {
        "school": "North Bergen High School",
        "district": "North Bergen School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341146002882",
    },
    {
        "school": "Franklin Elementary School",
        "district": "North Bergen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341146002884",
    },
    {
        "school": "Horace Mann Elementary School",
        "district": "North Bergen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341146002886",
    },
    {
        "school": "John F Kennedy Elementary School",
        "district": "North Bergen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341146002888",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "North Bergen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341146002890",
    },
    {
        "school": "McKinley Elementary School",
        "district": "North Bergen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341146002892",
    },
    {
        "school": "Robert Fulton Elementary School",
        "district": "North Bergen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341146002894",
    },
    {
        "school": "Secaucus High School",
        "district": "Secaucus School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341485002900",
    },
    {
        "school": "Clarendon School",
        "district": "Secaucus School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341485002902",
    },
    {
        "school": "Huber Street School",
        "district": "Secaucus School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341485002904",
    },
    {
        "school": "Secaucus Middle School",
        "district": "Secaucus School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341485006059",
    },
    {
        "school": "Sara M. Gilmore Academy",
        "district": "Union City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638000143",
    },
    {
        "school": "Thomas A Edison Elementary School",
        "district": "Union City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638002912",
    },
    {
        "school": "Hudson Elementary School",
        "district": "Union City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638002916",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Union City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638002918",
    },
    {
        "school": "Theodore Roosevelt Elementary School",
        "district": "Union City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638002920",
    },
    {
        "school": "George Washington Elementary School",
        "district": "Union City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638002922",
    },
    {
        "school": "Robert Waters Elementary School",
        "district": "Union City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638002924",
    },
    {
        "school": "Weehawken High School",
        "district": "Weehawken Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341731002928",
    },
    {
        "school": "Daniel Webster School",
        "district": "Weehawken Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341731002930",
    },
    {
        "school": "Theodore Roosevelt School",
        "district": "Weehawken Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341731002932",
    },
    {
        "school": "Early Childhood School",
        "district": "West New York Board of Education",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341758000445",
    },
    {
        "school": "Memorial High School",
        "district": "West New York Board of Education",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341758002938",
    },
    {
        "school": "Public School Number One",
        "district": "West New York Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341758002940",
    },
    {
        "school": "Public School Number Two",
        "district": "West New York Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341758002942",
    },
    {
        "school": "Robert Menendez Elementary School",
        "district": "West New York Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341758002944",
    },
    {
        "school": "Albio Sires Elementary School",
        "district": "West New York Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341758002946",
    },
    {
        "school": "Public School Number Five",
        "district": "West New York Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341758002948",
    },
    {
        "school": "Harry L Bain",
        "district": "West New York Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341758002950",
    },
    {
        "school": "Hunterdon County Vocational School District Central Campus",
        "district": "Hunterdon County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340005000021",
    },
    {
        "school": "Alexandria Middle School",
        "district": "Alexandria Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340069002954",
    },
    {
        "school": "Lester D. Wilson Elementary School",
        "district": "Alexandria Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340069002956",
    },
    {
        "school": "Ethel Hoppock Middle School",
        "district": "Bethlehem Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340171002958",
    },
    {
        "school": "Thomas B. Conley Elementary School",
        "district": "Bethlehem Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340171005895",
    },
    {
        "school": "Bloomsbury Borough School",
        "district": "Bloomsbury Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340189002960",
    },
    {
        "school": "Califon Public School",
        "district": "Califon Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340261002962",
    },
    {
        "school": "Clinton Public School",
        "district": "Clinton-Glen Gardner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340333002964",
    },
    {
        "school": "Spruce Run",
        "district": "Clinton Township School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340336002968",
    },
    {
        "school": "Round Valley",
        "district": "Clinton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340336002970",
    },
    {
        "school": "Patrick McGaheran",
        "district": "Clinton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340336006027",
    },
    {
        "school": "Delaware Township School",
        "district": "Delaware Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340372002974",
    },
    {
        "school": "Delaware Valley Regional High School",
        "district": "Delaware Valley Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340375002978",
    },
    {
        "school": "East Amwell Township",
        "district": "East Amwell Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340408002980",
    },
    {
        "school": "Copper Hill Elementary School",
        "district": "Flemington-Raritan Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340519000145",
    },
    {
        "school": "Barley Sheaf Elementary School",
        "district": "Flemington-Raritan Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340519002984",
    },
    {
        "school": "Reading-Fleming Intermediate School",
        "district": "Flemington-Raritan Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340519002986",
    },
    {
        "school": "Robert Hunter Elementary School",
        "district": "Flemington-Raritan Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340519002988",
    },
    {
        "school": "Francis A. Desmares Elementary School",
        "district": "Flemington-Raritan Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340519006086",
    },
    {
        "school": "Franklin Township School",
        "district": "Franklin Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340546002990",
    },
    {
        "school": "Frenchtown Elementary",
        "district": "Frenchtown Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340570002992",
    },
    {
        "school": "Hampton Borough School",
        "district": "Hampton Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340660002996",
    },
    {
        "school": "High Bridge Middle School",
        "district": "High Bridge Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340711003000",
    },
    {
        "school": "High Bridge Elementary School",
        "district": "High Bridge Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340711003002",
    },
    {
        "school": "Holland Township Elementary School",
        "district": "Holland Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340738003004",
    },
    {
        "school": "Hunterdon Central Regional High School District",
        "district": "Hunterdon Central Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340759003006",
    },
    {
        "school": "Kingwood Township School",
        "district": "Kingwood Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340801003008",
    },
    {
        "school": "Lebanon Borough School",
        "district": "Lebanon Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340843003012",
    },
    {
        "school": "Woodglen School",
        "district": "Lebanon Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340846003016",
    },
    {
        "school": "Valley View School",
        "district": "Lebanon Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340846003018",
    },
    {
        "school": "Milford Public School",
        "district": "Milford Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341017003020",
    },
    {
        "school": "North Hunterdon High School",
        "district": "North Hunterdon-Voorhees Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341161003024",
    },
    {
        "school": "Voorhees High School",
        "district": "North Hunterdon-Voorhees Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341161003026",
    },
    {
        "school": "Holland Brook School",
        "district": "Readington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341371000311",
    },
    {
        "school": "Readington Middle School",
        "district": "Readington Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341371003030",
    },
    {
        "school": "Three Bridges School",
        "district": "Readington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341371003032",
    },
    {
        "school": "Whitehouse School",
        "district": "Readington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341371003034",
    },
    {
        "school": "Old Turnpike School",
        "district": "Tewksbury Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341617003042",
    },
    {
        "school": "Union Township Middle School",
        "district": "Union Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341644003046",
    },
    {
        "school": "Greater Brunswick Charter School",
        "district": "Greater Brunswick Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340004700330",
    },
    {
        "school": "Nathan Hale Elementary School",
        "district": "Carteret Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340282000451",
    },
    {
        "school": "Carteret High School",
        "district": "Carteret Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340282003268",
    },
    {
        "school": "Columbus Elementary School",
        "district": "Carteret Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340282003272",
    },
    {
        "school": "Carteret Middle School",
        "district": "Carteret Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340282003274",
    },
    {
        "school": "Private Nicholas Minue Elementary School",
        "district": "Carteret Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340282003276",
    },
    {
        "school": "Cranbury School",
        "district": "Cranbury Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340354003282",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Dunellen Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340402000149",
    },
    {
        "school": "Dunellen High School",
        "district": "Dunellen Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340402003286",
    },
    {
        "school": "John P. Faber Elementary School",
        "district": "Dunellen Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340402003288",
    },
    {
        "school": "East Brunswick High School",
        "district": "East Brunswick Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340411003294",
    },
    {
        "school": "Churchill Jr High School",
        "district": "East Brunswick Township School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340411003296",
    },
    {
        "school": "Hammarskjold Middle School",
        "district": "East Brunswick Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340411003298",
    },
    {
        "school": "Bowne-Munro Elementary School",
        "district": "East Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340411003300",
    },
    {
        "school": "Central Elementary School",
        "district": "East Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340411003302",
    },
    {
        "school": "Lawrence Brook Elementary School",
        "district": "East Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340411003306",
    },
    {
        "school": "Memorial Elementary School",
        "district": "East Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340411003310",
    },
    {
        "school": "Chittick Elementary School",
        "district": "East Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340411003312",
    },
    {
        "school": "Frost Elementary School",
        "district": "East Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340411003314",
    },
    {
        "school": "Warnsdorfer Elementary School",
        "district": "East Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340411003318",
    },
    {
        "school": "Irwin Elementary School",
        "district": "East Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340411005994",
    },
    {
        "school": "Edison High School",
        "district": "Edison Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003324",
    },
    {
        "school": "John P. Stevens High School",
        "district": "Edison Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003326",
    },
    {
        "school": "John Adams Middle School",
        "district": "Edison Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003328",
    },
    {
        "school": "Herbert Hoover Middle School",
        "district": "Edison Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003330",
    },
    {
        "school": "Thomas Jefferson Middle School",
        "district": "Edison Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003332",
    },
    {
        "school": "Woodrow Wilson Middle School",
        "district": "Edison Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003334",
    },
    {
        "school": "Benjamin Franklin Elementary School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003336",
    },
    {
        "school": "James Madison Intermediate School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003342",
    },
    {
        "school": "James Madison Primary School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003344",
    },
    {
        "school": "James Monroe Elementary School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003346",
    },
    {
        "school": "John Marshall Elementary School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003348",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003350",
    },
    {
        "school": "Lindeneau Elementary School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003352",
    },
    {
        "school": "Martin Luther King Elementary School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003354",
    },
    {
        "school": "Menlo Park Elementary School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003356",
    },
    {
        "school": "Washington Elementary School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003364",
    },
    {
        "school": "Woodbrook Elementary School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003366",
    },
    {
        "school": "Highland Park High School",
        "district": "Highland Park Boro School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340717003372",
    },
    {
        "school": "Irving Primary School",
        "district": "Highland Park Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340717003376",
    },
    {
        "school": "Bartle Elementary School",
        "district": "Highland Park Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340717003380",
    },
    {
        "school": "Grace M. Breckwedel Middle School",
        "district": "Jamesburg Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340777003386",
    },
    {
        "school": "John F. Kennedy Elementary School",
        "district": "Jamesburg Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340777003388",
    },
    {
        "school": "William A. Miller Elementary School",
        "district": "Old Bridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927000195",
    },
    {
        "school": "Old Bridge High School",
        "district": "Old Bridge Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003496",
    },
    {
        "school": "Alan B. Shepard Elementary School",
        "district": "Old Bridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003498",
    },
    {
        "school": "Carl Sandburg Middle School",
        "district": "Old Bridge Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003500",
    },
    {
        "school": "James A. McDivitt Elementary School",
        "district": "Old Bridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003504",
    },
    {
        "school": "Jonas Salk Middle School",
        "district": "Old Bridge Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003508",
    },
    {
        "school": "Leroy Gordon Cooper Elementary School",
        "district": "Old Bridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003510",
    },
    {
        "school": "Madison Park Elementary School",
        "district": "Old Bridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003512",
    },
    {
        "school": "Memorial Elementary School",
        "district": "Old Bridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003514",
    },
    {
        "school": "M. Scott Carpenter Elementary School",
        "district": "Old Bridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003516",
    },
    {
        "school": "Raymond E. Voorhees Elementary School",
        "district": "Old Bridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003518",
    },
    {
        "school": "Southwood Elementary School",
        "district": "Old Bridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003520",
    },
    {
        "school": "Virgil I. Grissom Elementary School",
        "district": "Old Bridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003522",
    },
    {
        "school": "Walter M. Schirra Elementary School",
        "district": "Old Bridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340927003524",
    },
    {
        "school": "Metuchen High School",
        "district": "Metuchen Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340999003392",
    },
    {
        "school": "Campbell Elementary School",
        "district": "Metuchen Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340999003394",
    },
    {
        "school": "Edgar Middle School",
        "district": "Metuchen Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340999003396",
    },
    {
        "school": "Mildred B. Moss Elementary School",
        "district": "Metuchen Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340999003400",
    },
    {
        "school": "Middlesex High School",
        "district": "Middlesex Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341005003404",
    },
    {
        "school": "Hazelwood Elementary School",
        "district": "Middlesex Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341005003406",
    },
    {
        "school": "Parker Elementary School",
        "district": "Middlesex Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341005003408",
    },
    {
        "school": "Von E. Mauger Middle School",
        "district": "Middlesex Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341005003412",
    },
    {
        "school": "Watchung Elementary School",
        "district": "Middlesex Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341005003414",
    },
    {
        "school": "Middlesex County Voc Academy Math Science &Engineering Techn",
        "district": "Middlesex County Vocational and Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341008000395",
    },
    {
        "school": "Middlesex County Vocational School  East  Brunswick",
        "district": "Middlesex County Vocational and Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341008003420",
    },
    {
        "school": "Middlesex County Vocational School Perth Amboy",
        "district": "Middlesex County Vocational and Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341008003424",
    },
    {
        "school": "Middlesex County Vocational School Piscataway",
        "district": "Middlesex County Vocational and Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341008003426",
    },
    {
        "school": "Middlesex County Voc Acad Allied Health & Biomedical Science",
        "district": "Middlesex County Vocational and Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341008003428",
    },
    {
        "school": "Joyce Kilmer School",
        "district": "Milltown School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341029003432",
    },
    {
        "school": "Parkview  School",
        "district": "Milltown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341029003434",
    },
    {
        "school": "Monroe Township High School",
        "district": "Monroe Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341050003438",
    },
    {
        "school": "Barclay Brook School",
        "district": "Monroe Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341050003440",
    },
    {
        "school": "Monroe Township Middle School",
        "district": "Monroe Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341050003442",
    },
    {
        "school": "Woodland School",
        "district": "Monroe Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341050003444",
    },
    {
        "school": "Mill Lake",
        "district": "Monroe Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341050003446",
    },
    {
        "school": "Brookside Elementary School",
        "district": "Monroe Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341050006096",
    },
    {
        "school": "New Brunswick High School",
        "district": "New Brunswick School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341122003454",
    },
    {
        "school": "A Chester Redshaw School",
        "district": "New Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341122003456",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "New Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341122003460",
    },
    {
        "school": "Livingston Elementary School",
        "district": "New Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341122003462",
    },
    {
        "school": "Lord Stirling Elementary School",
        "district": "New Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341122003464",
    },
    {
        "school": "Mckinley Community School",
        "district": "New Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341122003466",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "New Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341122003472",
    },
    {
        "school": "Woodrow Wilson Elementary School",
        "district": "New Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341122003476",
    },
    {
        "school": "Paul Robeson Community School for the Arts",
        "district": "New Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341122005940",
    },
    {
        "school": "North Brunswick Township High School",
        "district": "North Brunswick Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341149003480",
    },
    {
        "school": "Arthur M. Judd",
        "district": "North Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341149003482",
    },
    {
        "school": "John Adams",
        "district": "North Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341149003484",
    },
    {
        "school": "Linwood Middle School",
        "district": "North Brunswick Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341149003486",
    },
    {
        "school": "Livingston Park",
        "district": "North Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341149003488",
    },
    {
        "school": "Parsons",
        "district": "North Brunswick Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341149003490",
    },
    {
        "school": "Edward J. Patten Elementary School",
        "district": "Perth Amboy Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293000152",
    },
    {
        "school": "Robert N. Wilentz Elementary School",
        "district": "Perth Amboy Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293000404",
    },
    {
        "school": "Perth Amboy High School",
        "district": "Perth Amboy Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293003530",
    },
    {
        "school": "Anthony V. Ceres Elementary School",
        "district": "Perth Amboy Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293003534",
    },
    {
        "school": "Herbert N. Richardson 21st Century School",
        "district": "Perth Amboy Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293003540",
    },
    {
        "school": "William C. McGinnis Middle School",
        "district": "Perth Amboy Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293003542",
    },
    {
        "school": "James J. Flynn Elementary School",
        "district": "Perth Amboy Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293003544",
    },
    {
        "school": "Samuel E. Shull Middle School",
        "district": "Perth Amboy Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293003548",
    },
    {
        "school": "Knollwood Elementary School",
        "district": "Piscataway Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341305000042",
    },
    {
        "school": "Piscataway Township High School",
        "district": "Piscataway Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341305003554",
    },
    {
        "school": "Conackamack Middle School",
        "district": "Piscataway Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341305003556",
    },
    {
        "school": "Quibbletown Middle School",
        "district": "Piscataway Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341305003558",
    },
    {
        "school": "Theodore Schor Middle School",
        "district": "Piscataway Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341305003560",
    },
    {
        "school": "Arbor Elementary School",
        "district": "Piscataway Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341305003562",
    },
    {
        "school": "Dwight D. Eisenhower Elementary School",
        "district": "Piscataway Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341305003564",
    },
    {
        "school": "Grandview Elementary School",
        "district": "Piscataway Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341305003568",
    },
    {
        "school": "Martin Luther King Elementary School",
        "district": "Piscataway Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341305003572",
    },
    {
        "school": "Randolphville Elementary School",
        "district": "Piscataway Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341305003576",
    },
    {
        "school": "Sayreville War Memorial High School",
        "district": "Sayreville School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341464003580",
    },
    {
        "school": "Sayreville Middle School",
        "district": "Sayreville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341464003582",
    },
    {
        "school": "Emma Arleth Elementary School",
        "district": "Sayreville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341464003584",
    },
    {
        "school": "Dwight D. Eisenhower Elementary School",
        "district": "Sayreville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341464003586",
    },
    {
        "school": "Harry S. Truman Elementary School",
        "district": "Sayreville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341464003588",
    },
    {
        "school": "Woodrow Wilson Elementary School",
        "district": "Sayreville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341464003598",
    },
    {
        "school": "South Amboy Middle/High School",
        "district": "South Amboy School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341512000154",
    },
    {
        "school": "South Amboy Elementary",
        "district": "South Amboy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341512003604",
    },
    {
        "school": "Indian Fields Elementary School",
        "district": "South Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341521000043",
    },
    {
        "school": "Crossroads North Middle School",
        "district": "South Brunswick School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341521000196",
    },
    {
        "school": "South Brunswick High School",
        "district": "South Brunswick School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341521003610",
    },
    {
        "school": "Brunswick Acres Elementary School",
        "district": "South Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341521003612",
    },
    {
        "school": "Cambridge Elementary School",
        "district": "South Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341521003614",
    },
    {
        "school": "Constable Elementary School",
        "district": "South Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341521003616",
    },
    {
        "school": "Crossroads South Middle School",
        "district": "South Brunswick School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341521003618",
    },
    {
        "school": "Monmouth Junction Elementary School",
        "district": "South Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341521003628",
    },
    {
        "school": "Greenbrook Elementary School",
        "district": "South Brunswick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341521006007",
    },
    {
        "school": "South Plainfield High School",
        "district": "South Plainfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341536003632",
    },
    {
        "school": "South Plainfield Middle School",
        "district": "South Plainfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341536003634",
    },
    {
        "school": "John F Kennedy Elementary School",
        "district": "South Plainfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341536003636",
    },
    {
        "school": "John E Riley Elementary School",
        "district": "South Plainfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341536003638",
    },
    {
        "school": "Franklin Elementary School",
        "district": "South Plainfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341536003640",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "South Plainfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341536003644",
    },
    {
        "school": "Grant Elementary School",
        "district": "South Plainfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341536005999",
    },
    {
        "school": "South River Elementary School",
        "district": "South River Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341539000236",
    },
    {
        "school": "South River High School",
        "district": "South River Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341539003648",
    },
    {
        "school": "South River Middle School",
        "district": "South River Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341539003650",
    },
    {
        "school": "Spotswood Memorial Middle School",
        "district": "Spotswood Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341554000068",
    },
    {
        "school": "Spotswood High School",
        "district": "Spotswood Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341554003660",
    },
    {
        "school": "E Raymond Appleby Elementary School",
        "district": "Spotswood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341554003662",
    },
    {
        "school": "G Austin Schoenly Elementary School",
        "district": "Spotswood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341554003664",
    },
    {
        "school": "Colonia High School",
        "district": "Woodbridge Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003668",
    },
    {
        "school": "John F. Kennedy Memorial High School",
        "district": "Woodbridge Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003670",
    },
    {
        "school": "Woodbridge High School",
        "district": "Woodbridge Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003672",
    },
    {
        "school": "Colonia Middle School",
        "district": "Woodbridge Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003678",
    },
    {
        "school": "Fords Middle School",
        "district": "Woodbridge Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003680",
    },
    {
        "school": "Iselin Middle School",
        "district": "Woodbridge Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003682",
    },
    {
        "school": "Woodbridge Middle School",
        "district": "Woodbridge Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003684",
    },
    {
        "school": "Avenel Street Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003686",
    },
    {
        "school": "Robert Mascenik Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003688",
    },
    {
        "school": "Claremont Avenue Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003690",
    },
    {
        "school": "Ford Avenue Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003692",
    },
    {
        "school": "Matthew Jago Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003694",
    },
    {
        "school": "Indiana Avenue Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003698",
    },
    {
        "school": "Kennedy Park Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003702",
    },
    {
        "school": "Lafayette Estates Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003706",
    },
    {
        "school": "Lynn Crest Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003708",
    },
    {
        "school": "Mawbey Street Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003710",
    },
    {
        "school": "Menlo Park Terrace Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003712",
    },
    {
        "school": "Oak Ridge Heights Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003714",
    },
    {
        "school": "Pennsylvania Avenue Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003718",
    },
    {
        "school": "Port Reading Avenue Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003720",
    },
    {
        "school": "Ross Street Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003722",
    },
    {
        "school": "Woodbine Avenue Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003726",
    },
    {
        "school": "Avenel Middle School",
        "district": "Woodbridge Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812005972",
    },
    {
        "school": "Bright Beginnings Learning Center",
        "district": "Educational Services Commission of New Jersey",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348018000235",
    },
    {
        "school": "Academy Learning Center",
        "district": "Educational Services Commission of New Jersey",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348018005951",
    },
    {
        "school": "Piscataway Regional Day School",
        "district": "Educational Services Commission of New Jersey",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348018005991",
    },
    {
        "school": "Bernards High School",
        "district": "Somerset Hills Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340000900176",
    },
    {
        "school": "Marion T. Bedwell Elementary School",
        "district": "Somerset Hills Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340000900177",
    },
    {
        "school": "Bernardsville Middle School",
        "district": "Somerset Hills Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340000900178",
    },
    {
        "school": "Bedminster Township Public School",
        "district": "Bedminster Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340132005120",
    },
    {
        "school": "Mount Prospect Elementary School",
        "district": "Bernards Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340165000355",
    },
    {
        "school": "Ridge High School",
        "district": "Bernards Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340165005124",
    },
    {
        "school": "William Annin Middle School",
        "district": "Bernards Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340165005126",
    },
    {
        "school": "Oak Street School",
        "district": "Bernards Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340165005128",
    },
    {
        "school": "Liberty Corner School",
        "district": "Bernards Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340165005132",
    },
    {
        "school": "Cedar Hill School",
        "district": "Bernards Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340165006021",
    },
    {
        "school": "Bound Brook High School",
        "district": "Bound Brook School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340210005144",
    },
    {
        "school": "Whiton Elementary School",
        "district": "Branchburg Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340216000199",
    },
    {
        "school": "Branchburg Central Middle School",
        "district": "Branchburg Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340216005154",
    },
    {
        "school": "Stony Brook School",
        "district": "Branchburg Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340216005158",
    },
    {
        "school": "Bridgewater-Raritan High School",
        "district": "Bridgewater-Raritan Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340228000173",
    },
    {
        "school": "Bridgewater-Raritan Middle School",
        "district": "Bridgewater-Raritan Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340228005162",
    },
    {
        "school": "Adamsville Primary School",
        "district": "Bridgewater-Raritan Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340228005166",
    },
    {
        "school": "Bradley Gardens Primary School",
        "district": "Bridgewater-Raritan Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340228005168",
    },
    {
        "school": "Crim Primary School",
        "district": "Bridgewater-Raritan Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340228005170",
    },
    {
        "school": "Eisenhower Intermediate School",
        "district": "Bridgewater-Raritan Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340228005172",
    },
    {
        "school": "Hillside Intermediate School",
        "district": "Bridgewater-Raritan Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340228005178",
    },
    {
        "school": "John F. Kennedy Primary School",
        "district": "Bridgewater-Raritan Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340228005180",
    },
    {
        "school": "Van Holten Primary School",
        "district": "Bridgewater-Raritan Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340228005186",
    },
    {
        "school": "Hamilton Primary School",
        "district": "Bridgewater-Raritan Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340228006047",
    },
    {
        "school": "Franklin High School",
        "district": "Franklin Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340549005194",
    },
    {
        "school": "Conerly Road School",
        "district": "Franklin Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340549005196",
    },
    {
        "school": "Elizabeth Avenue School",
        "district": "Franklin Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340549005198",
    },
    {
        "school": "Franklin Park School",
        "district": "Franklin Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340549005200",
    },
    {
        "school": "Hillcrest School",
        "district": "Franklin Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340549005202",
    },
    {
        "school": "MacAfee Road School",
        "district": "Franklin Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340549005206",
    },
    {
        "school": "Pine Grove Manor School",
        "district": "Franklin Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340549005210",
    },
    {
        "school": "Franklin Middle School at Hamilton Street Campus",
        "district": "Franklin Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340549005212",
    },
    {
        "school": "Green Brook Middle School",
        "district": "Green Brook Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340612005216",
    },
    {
        "school": "Irene E. Feldkirchner Elementary School",
        "district": "Green Brook Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340612005218",
    },
    {
        "school": "Auten Road Intermediate School",
        "district": "Hillsborough Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340723000357",
    },
    {
        "school": "Hillsborough High School",
        "district": "Hillsborough Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340723005222",
    },
    {
        "school": "Hillsborough Township Middle School",
        "district": "Hillsborough Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340723005224",
    },
    {
        "school": "Hillsborough Township Elementary School",
        "district": "Hillsborough Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340723005226",
    },
    {
        "school": "Sunnymead Elementary School",
        "district": "Hillsborough Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340723005228",
    },
    {
        "school": "Triangle Elementary Shcool",
        "district": "Hillsborough Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340723005230",
    },
    {
        "school": "Woodfern Elementary School",
        "district": "Hillsborough Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340723005232",
    },
    {
        "school": "Woods Road Elementary School",
        "district": "Hillsborough Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340723005234",
    },
    {
        "school": "Amsterdam Elementary School",
        "district": "Hillsborough Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340723006068",
    },
    {
        "school": "Roosevelt School",
        "district": "Manville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340963000175",
    },
    {
        "school": "Manville High School",
        "district": "Manville School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340963005238",
    },
    {
        "school": "Alexander Batcho Intermediate School",
        "district": "Manville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340963005240",
    },
    {
        "school": "Weston Elementary School",
        "district": "Manville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340963005244",
    },
    {
        "school": "Village Elementary School",
        "district": "Montgomery Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341059000398",
    },
    {
        "school": "Montgomery High School",
        "district": "Montgomery Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341059005250",
    },
    {
        "school": "Orchard Hill Elementary School",
        "district": "Montgomery Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341059005254",
    },
    {
        "school": "Montgomery Upper Middle School",
        "district": "Montgomery Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341059006031",
    },
    {
        "school": "North Plainfield High School",
        "district": "North Plainfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341164005258",
    },
    {
        "school": "East End School",
        "district": "North Plainfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341164005260",
    },
    {
        "school": "Somerset School",
        "district": "North Plainfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341164005262",
    },
    {
        "school": "Stony Brook School",
        "district": "North Plainfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341164005264",
    },
    {
        "school": "West End School",
        "district": "North Plainfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341164005268",
    },
    {
        "school": "Somerset County Vocational Technical High School",
        "district": "Somerset County Vocational and Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341506005278",
    },
    {
        "school": "Somerville High School",
        "district": "Somerville Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341509005284",
    },
    {
        "school": "Somerville Middle School",
        "district": "Somerville Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341509005288",
    },
    {
        "school": "Van Derveer Elementary School",
        "district": "Somerville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341509005296",
    },
    {
        "school": "Robert Morris School",
        "district": "South Bound Brook Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341518000465",
    },
    {
        "school": "Woodland School",
        "district": "Warren Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341698000244",
    },
    {
        "school": "Central School",
        "district": "Warren Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341698005306",
    },
    {
        "school": "Warren Middle School",
        "district": "Warren Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341698005308",
    },
    {
        "school": "Mt. Horeb School",
        "district": "Warren Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341698005310",
    },
    {
        "school": "Angelo L. Tomaso School",
        "district": "Warren Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341698006106",
    },
    {
        "school": "Bayberry School",
        "district": "Watchung Borough Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341719005316",
    },
    {
        "school": "Valley View School",
        "district": "Watchung Borough Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341719005318",
    },
    {
        "school": "Watchung Hills Regional High School",
        "district": "Watchung Hills Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341722005320",
    },
    {
        "school": "Somerset Elementary Academy",
        "district": "Somerset County Educational Services Commission",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348028000070",
    },
    {
        "school": "Somerset Secondary Academy",
        "district": "Somerset County Educational Services Commission",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348028005918",
    },
    {
        "school": "Lenna W. Conrow Elementary School",
        "district": "LONG BRANCH PUBLIC SCHOOL District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340894003918",
    },
    {
        "school": "Academy Charter High School",
        "district": "Academy Charter High School",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340004800335",
    },
    {
        "school": "Red Bank Charter School",
        "district": "Red Bank Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340004900336",
    },
    {
        "school": "Hope Academy Charter School",
        "district": "Hope Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340007600483",
    },
    {
        "school": "Thurgood Marshall Elementary School",
        "district": "Asbury Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340093000157",
    },
    {
        "school": "Asbury Park High School",
        "district": "Asbury Park School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340093003732",
    },
    {
        "school": "Bradley Elementary School",
        "district": "Asbury Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340093003740",
    },
    {
        "school": "Dr. Martin Luther King Middle School",
        "district": "Asbury Park School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340093003742",
    },
    {
        "school": "Atlantic Highlands Elementary School",
        "district": "Atlantic Highlands School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340102003746",
    },
    {
        "school": "Avon Elementary School",
        "district": "AVON BORO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340114003748",
    },
    {
        "school": "Belmar Elementary",
        "district": "Belmar Elementary School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340141003750",
    },
    {
        "school": "Bradley Beach Elementary School",
        "district": "Bradley Beach School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340213003752",
    },
    {
        "school": "Brielle Elementary School",
        "district": "Brielle Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340231003754",
    },
    {
        "school": "Cedar Drive Middle School",
        "district": "Colts Neck Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340345003760",
    },
    {
        "school": "Conover Road Elementary School",
        "district": "Colts Neck Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340345003762",
    },
    {
        "school": "Deal Elementary School",
        "district": "Deal Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340363003764",
    },
    {
        "school": "Margaret L Vetter",
        "district": "Eatontown Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340441003768",
    },
    {
        "school": "Memorial Middle School",
        "district": "Eatontown Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340441003770",
    },
    {
        "school": "Meadowbrook",
        "district": "Eatontown Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340441003772",
    },
    {
        "school": "Woodmere",
        "district": "Eatontown Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340441003774",
    },
    {
        "school": "Knollwood School",
        "district": "Fair Haven School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340495003778",
    },
    {
        "school": "Viola L Sickles School",
        "district": "Fair Haven School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340495003780",
    },
    {
        "school": "Farmingdale Elementary",
        "district": "Farmingdale Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340513003782",
    },
    {
        "school": "Freehold Learning Center",
        "district": "Freehold Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340558003788",
    },
    {
        "school": "Freehold Intermediate School",
        "district": "Freehold Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340558003790",
    },
    {
        "school": "Park Avenue Elementary School",
        "district": "Freehold Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340558003792",
    },
    {
        "school": "Colts Neck High School",
        "district": "Freehold Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340561000237",
    },
    {
        "school": "Freehold Borough High School",
        "district": "Freehold Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340561003796",
    },
    {
        "school": "Freehold Township High School",
        "district": "Freehold Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340561003798",
    },
    {
        "school": "Howell High School",
        "district": "Freehold Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340561003800",
    },
    {
        "school": "Manalapan High School",
        "district": "Freehold Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340561003802",
    },
    {
        "school": "Marlboro High School",
        "district": "Freehold Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340561003804",
    },
    {
        "school": "Joseph J Catena School",
        "district": "Freehold Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340564003810",
    },
    {
        "school": "C. Richard Applegate School",
        "district": "Freehold Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340564003812",
    },
    {
        "school": "Clifton T. Barkalow School",
        "district": "Freehold Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340564003814",
    },
    {
        "school": "Dwight D. Eisenhower School",
        "district": "Freehold Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340564003816",
    },
    {
        "school": "Marshall W. Errickson School",
        "district": "Freehold Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340564003818",
    },
    {
        "school": "Laura Donovan School",
        "district": "Freehold Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340564003820",
    },
    {
        "school": "West Freehold School",
        "district": "Freehold Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340564003822",
    },
    {
        "school": "Henry Hudson Regional School",
        "district": "Henry Hudson Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340705003844",
    },
    {
        "school": "Highlands Elementary School",
        "district": "Highlands Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340720003846",
    },
    {
        "school": "Holmdel High School",
        "district": "Holmdel Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340741003850",
    },
    {
        "school": "William R. Satz School",
        "district": "Holmdel Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340741003852",
    },
    {
        "school": "Indian Hill School",
        "district": "Holmdel Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340741003854",
    },
    {
        "school": "Village School",
        "district": "Holmdel Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340741003856",
    },
    {
        "school": "Howell Township Middle School North",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756000097",
    },
    {
        "school": "Howell Township Middle School South",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756000331",
    },
    {
        "school": "Aldrich Elementary School",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756003860",
    },
    {
        "school": "Ardena Elementary School",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756003862",
    },
    {
        "school": "Edith M. Griebling Elementary School",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756003864",
    },
    {
        "school": "Land O'Pines Elementary School",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756003866",
    },
    {
        "school": "Newbury Elementary School",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756003868",
    },
    {
        "school": "Ramtown Elementary School",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756003870",
    },
    {
        "school": "Taunton Elementary School",
        "district": "HOWELL TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340756003874",
    },
    {
        "school": "Joseph R. Bolger Middle School",
        "district": "Keansburg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340786000027",
    },
    {
        "school": "Keansburg High School",
        "district": "Keansburg School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340786003880",
    },
    {
        "school": "Port Monmouth Road School",
        "district": "Keansburg School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340786003882",
    },
    {
        "school": "Joseph C. Caruso School",
        "district": "Keansburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340786003884",
    },
    {
        "school": "Keyport High School",
        "district": "Keyport School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340795003888",
    },
    {
        "school": "Keyport Central School",
        "district": "Keyport School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340795003890",
    },
    {
        "school": "Markham Place School",
        "district": "Little Silver Boro School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340879003898",
    },
    {
        "school": "Point Road School",
        "district": "Little Silver Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340879003900",
    },
    {
        "school": "Joseph M. Ferraina Early Childhood Learning Center",
        "district": "LONG BRANCH PUBLIC SCHOOL District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340894000333",
    },
    {
        "school": "Long Branch High School",
        "district": "LONG BRANCH PUBLIC SCHOOL District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340894003904",
    },
    {
        "school": "Long Branch Middle School",
        "district": "LONG BRANCH PUBLIC SCHOOL District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340894003906",
    },
    {
        "school": "A A Anastasia Elementary School",
        "district": "LONG BRANCH PUBLIC SCHOOL District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340894003908",
    },
    {
        "school": "Morris Avenue Elementry School",
        "district": "LONG BRANCH PUBLIC SCHOOL District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340894003912",
    },
    {
        "school": "Gregory Elementary School",
        "district": "LONG BRANCH PUBLIC SCHOOL District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340894003916",
    },
    {
        "school": "Manalapan-Englishtown Middle School",
        "district": "Manalapan-Englishtown Regional Schools School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340939000029",
    },
    {
        "school": "Wemrock Brook School",
        "district": "Manalapan-Englishtown Regional Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340939000453",
    },
    {
        "school": "Clark Mills School",
        "district": "Manalapan-Englishtown Regional Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340939003926",
    },
    {
        "school": "Lafayette Mills School",
        "district": "Manalapan-Englishtown Regional Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340939003928",
    },
    {
        "school": "Milford Brook School",
        "district": "Manalapan-Englishtown Regional Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340939003930",
    },
    {
        "school": "Pine Brook School",
        "district": "Manalapan-Englishtown Regional Schools School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340939003932",
    },
    {
        "school": "Taylor Mills School",
        "district": "Manalapan-Englishtown Regional Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340939003936",
    },
    {
        "school": "Manasquan High School",
        "district": "Manasquan School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340942003940",
    },
    {
        "school": "Manasquan Elementary School",
        "district": "Manasquan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340942003942",
    },
    {
        "school": "David C Abbott Early Learning Center",
        "district": "Marlboro Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340972000454",
    },
    {
        "school": "Frank Defino Central Elementary School",
        "district": "Marlboro Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340972003946",
    },
    {
        "school": "Marlboro Elementary School",
        "district": "Marlboro Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340972003948",
    },
    {
        "school": "Marlboro Middle School",
        "district": "Marlboro Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340972003950",
    },
    {
        "school": "Robertsville Elementary School",
        "district": "Marlboro Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340972003952",
    },
    {
        "school": "Asher Holmes Elementary School",
        "district": "Marlboro Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340972003954",
    },
    {
        "school": "Frank J. Dugan Elementary School",
        "district": "Marlboro Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340972006030",
    },
    {
        "school": "Matawan Regional High School",
        "district": "Matawan-Aberdeen Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340975003958",
    },
    {
        "school": "Lloyd Road Elementary School",
        "district": "Matawan-Aberdeen Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340975003960",
    },
    {
        "school": "Matawan-Aberdeen Middle School",
        "district": "Matawan-Aberdeen Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340975003962",
    },
    {
        "school": "Cliffwood Elementary School",
        "district": "Matawan-Aberdeen Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340975003968",
    },
    {
        "school": "Ravine Drive Elementary School",
        "district": "Matawan-Aberdeen Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340975003970",
    },
    {
        "school": "Strathmore Elementary School",
        "district": "Matawan-Aberdeen Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340975003972",
    },
    {
        "school": "Middletown High School North",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003976",
    },
    {
        "school": "Middletown High School South",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003978",
    },
    {
        "school": "Bayshore Middle School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003980",
    },
    {
        "school": "Thompson Middle School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003982",
    },
    {
        "school": "Thorne Middle School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003984",
    },
    {
        "school": "Bayview Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003986",
    },
    {
        "school": "Ocean Avenue Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003988",
    },
    {
        "school": "Fairview Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003990",
    },
    {
        "school": "Harmony Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003992",
    },
    {
        "school": "Leonardo Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003994",
    },
    {
        "school": "Lincroft Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003996",
    },
    {
        "school": "Middletown Village Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011003998",
    },
    {
        "school": "Navesink Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011004000",
    },
    {
        "school": "New Monmouth Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011004002",
    },
    {
        "school": "Nut Swamp Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011004004",
    },
    {
        "school": "Port Monmouth Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011004006",
    },
    {
        "school": "River Plaza Elementary School",
        "district": "MIDDLETOWN TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341011004008",
    },
    {
        "school": "Millstone Township Elementary School",
        "district": "Millstone Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341023000159",
    },
    {
        "school": "Millstone Township Middle School",
        "district": "Millstone Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341023004014",
    },
    {
        "school": "Monmouth Beach Elementary School",
        "district": "Monmouth Beach School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341038004018",
    },
    {
        "school": "Monmouth Regional High School",
        "district": "Monmouth Regional High School",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341044004026",
    },
    {
        "school": "Woodrow Wilson",
        "district": "Neptune City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341113004028",
    },
    {
        "school": "Early Childhood Center",
        "district": "Neptune Township School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341116000457",
    },
    {
        "school": "Neptune High School",
        "district": "Neptune Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341116004032",
    },
    {
        "school": "Neptune Middle School",
        "district": "Neptune Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341116004036",
    },
    {
        "school": "Gables Elementary School",
        "district": "Neptune Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341116004040",
    },
    {
        "school": "Green Grove Elementary School",
        "district": "Neptune Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341116004042",
    },
    {
        "school": "Midtown Community Elementary School",
        "district": "Neptune Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341116004048",
    },
    {
        "school": "Shark River Hills Elementary School",
        "district": "Neptune Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341116004050",
    },
    {
        "school": "Summerfiled Elementary School",
        "district": "Neptune Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341116004052",
    },
    {
        "school": "Ocean Township High School",
        "district": "Township of Ocean School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341206004058",
    },
    {
        "school": "Township of Ocean Intermediate School",
        "district": "Township of Ocean School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341206004060",
    },
    {
        "school": "Ocean Township Elementary School",
        "district": "Township of Ocean School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341206004064",
    },
    {
        "school": "Wanamassa Elementary School",
        "district": "Township of Ocean School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341206004066",
    },
    {
        "school": "Wayside Elementary School",
        "district": "Township of Ocean School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341206004068",
    },
    {
        "school": "Maple  Place Middle School",
        "district": "Oceanport School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341212004072",
    },
    {
        "school": "Wolf Hill School",
        "district": "Oceanport School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341212004074",
    },
    {
        "school": "Raritan High School",
        "district": "Hazlet Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341368003826",
    },
    {
        "school": "Beers Street School",
        "district": "Hazlet Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341368003828",
    },
    {
        "school": "Cove Road School",
        "district": "Hazlet Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341368003830",
    },
    {
        "school": "Lillian Drive School",
        "district": "Hazlet Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341368003832",
    },
    {
        "school": "Middle Road School",
        "district": "Hazlet Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341368003834",
    },
    {
        "school": "Raritan Valley School",
        "district": "Hazlet Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341368003836",
    },
    {
        "school": "Sycamore Drive Early Childhood Learning Center",
        "district": "Hazlet Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341368003838",
    },
    {
        "school": "Hazlet Middle School",
        "district": "Hazlet Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341368003840",
    },
    {
        "school": "Red Bank Middle School",
        "district": "Red Bank Borough Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341374004078",
    },
    {
        "school": "Red Bank Primary School",
        "district": "Red Bank Borough Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341374004080",
    },
    {
        "school": "Red Bank Regional High School",
        "district": "Red Bank Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341375004084",
    },
    {
        "school": "Roosevelt Public School",
        "district": "Roosevelt Borough Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341422004086",
    },
    {
        "school": "Deane-Porter Elementary School",
        "district": "Rumson Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341437004090",
    },
    {
        "school": "Forrestdale School",
        "district": "Rumson Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341437004092",
    },
    {
        "school": "Rumson-Fair Haven Regional High School",
        "district": "Rumson-Fair Haven Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341440004094",
    },
    {
        "school": "Sea Girt Elementary School",
        "district": "Sea Girt Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341473004098",
    },
    {
        "school": "Shore Regional High School",
        "district": "SHORE REGIONAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341494004100",
    },
    {
        "school": "Shrewsbury Borough Elementary School",
        "district": "SHREWSBURY BOROUGH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341497004102",
    },
    {
        "school": "H W Mountz Elementary School",
        "district": "Spring Lake Borough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341557004106",
    },
    {
        "school": "Spring Lake Heights Elementary School",
        "district": "Spring Lake Heights School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341560004108",
    },
    {
        "school": "Mahala F. Atchison School",
        "district": "Tinton Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341620004112",
    },
    {
        "school": "Swimming River School",
        "district": "Tinton Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341620004114",
    },
    {
        "school": "Tinton Falls Middle School",
        "district": "Tinton Falls School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341620004116",
    },
    {
        "school": "Memorial School",
        "district": "Union Beach Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341635004120",
    },
    {
        "school": "Allentown High School",
        "district": "Upper Freehold Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341656004124",
    },
    {
        "school": "Newell Elementary School",
        "district": "Upper Freehold Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341656004126",
    },
    {
        "school": "Wall Primary School",
        "district": "Wall Township Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341689000099",
    },
    {
        "school": "Wall High School",
        "district": "Wall Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341689004132",
    },
    {
        "school": "Allenwood Elementary School",
        "district": "Wall Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341689004134",
    },
    {
        "school": "Central Elementary School",
        "district": "Wall Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341689004136",
    },
    {
        "school": "Wall Intermediate School",
        "district": "Wall Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341689004140",
    },
    {
        "school": "Old Mill Elementary School",
        "district": "Wall Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341689004142",
    },
    {
        "school": "West Belmar Elementary School",
        "district": "Wall Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341689004144",
    },
    {
        "school": "Frank Antonides School",
        "district": "West Long Branch School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341749004148",
    },
    {
        "school": "Betty McElmon Elementary School",
        "district": "West Long Branch School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341749006107",
    },
    {
        "school": "Class Academy",
        "district": "Monmouth County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341750000161",
    },
    {
        "school": "Monmouth County Academy of Allied Health and Science",
        "district": "Monmouth County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341750000163",
    },
    {
        "school": "Communications High School",
        "district": "Monmouth County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341750000409",
    },
    {
        "school": "Monmouth County Vocational Technical High School",
        "district": "Monmouth County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341750004024",
    },
    {
        "school": "Marine Academy of Science and Technology",
        "district": "Monmouth County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341750005989",
    },
    {
        "school": "Monmouth County Career Center",
        "district": "Monmouth County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341750005990",
    },
    {
        "school": "High Technology High School",
        "district": "Monmouth County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341750006095",
    },
    {
        "school": "Regional Alternative School",
        "district": "Monmouth-Ocean Educational Services Commission School Distri",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "348024006080",
    },
    {
        "school": "Bay Head Elementary",
        "district": "Bay Head Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340123004568",
    },
    {
        "school": "Beach Haven School",
        "district": "Beach Haven School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340129004570",
    },
    {
        "school": "Bayville Elementary School",
        "district": "Berkeley Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340156004574",
    },
    {
        "school": "Clara B. Worth Elementary School",
        "district": "Berkeley Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340156004576",
    },
    {
        "school": "H & M Potter School",
        "district": "Berkeley Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340156004578",
    },
    {
        "school": "Warren H. Wolf Early Childhood Development Center",
        "district": "Brick Township Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222000166",
    },
    {
        "school": "Brick Township High School",
        "district": "Brick Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222004582",
    },
    {
        "school": "Drum Point Road Elementary School",
        "district": "Brick Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222004584",
    },
    {
        "school": "Emma Havens Young Elementary School",
        "district": "Brick Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222004586",
    },
    {
        "school": "Herbertsville Elementary School",
        "district": "Brick Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222004588",
    },
    {
        "school": "Lake Riviera Middle School",
        "district": "Brick Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222004590",
    },
    {
        "school": "Lanes Mill Elementary School",
        "district": "Brick Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222004592",
    },
    {
        "school": "Midstreams Elementary School",
        "district": "Brick Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222004596",
    },
    {
        "school": "Osbornville Elementary School",
        "district": "Brick Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222004598",
    },
    {
        "school": "Veterans Memorial Elementary School",
        "district": "Brick Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222004600",
    },
    {
        "school": "Veterans Memorial Middle School",
        "district": "Brick Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222004602",
    },
    {
        "school": "Brick Township Memorial High School",
        "district": "Brick Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340222005896",
    },
    {
        "school": "Central Regional High School",
        "district": "Central Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340291004604",
    },
    {
        "school": "Central Regional Middle School",
        "district": "Central Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340291005928",
    },
    {
        "school": "Eagleswood Elementary School",
        "district": "Eagleswood Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340405004606",
    },
    {
        "school": "Island Heights Elementary School",
        "district": "Island Heights School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340771004608",
    },
    {
        "school": "Christa McAuliffe Middle School",
        "district": "Jackson Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340774000069",
    },
    {
        "school": "Crawford-Rodriguez Elementary School",
        "district": "Jackson Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340774000463",
    },
    {
        "school": "Jackson Memorial High School",
        "district": "Jackson Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340774004612",
    },
    {
        "school": "Sylvia Rosenauer Elementary School",
        "district": "Jackson Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340774004614",
    },
    {
        "school": "Howard C. Johnson Elementary School",
        "district": "Jackson Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340774004618",
    },
    {
        "school": "Lucy N. Holman Elementary School",
        "district": "Jackson Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340774004620",
    },
    {
        "school": "Switlik Elementary School",
        "district": "Jackson Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340774004622",
    },
    {
        "school": "Carl W. Goetz Middle School",
        "district": "Jackson Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340774004624",
    },
    {
        "school": "Lacey Township Middle School",
        "district": "Lacey Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340810000242",
    },
    {
        "school": "Forked River Elementary School",
        "district": "Lacey Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340810004628",
    },
    {
        "school": "Lanoka Harbor Elementary School",
        "district": "Lacey Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340810004630",
    },
    {
        "school": "Mill Pond Elementary School",
        "district": "Lacey Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340810005908",
    },
    {
        "school": "Lacey Township High School",
        "district": "Lacey Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340810005935",
    },
    {
        "school": "Cedar Creek Elementary School",
        "district": "Lacey Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340810006050",
    },
    {
        "school": "Lakehurst Elementary School",
        "district": "Lakehurst School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340816004632",
    },
    {
        "school": "Lakewood High School",
        "district": "Lakewood Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340822004636",
    },
    {
        "school": "Clifton Ave Grade School",
        "district": "Lakewood Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340822004638",
    },
    {
        "school": "Ella G Clarke Elementary School",
        "district": "Lakewood Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340822004640",
    },
    {
        "school": "Lakewood Middle School",
        "district": "Lakewood Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340822004642",
    },
    {
        "school": "Spruce Street Elementary School",
        "district": "Lakewood Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340822004646",
    },
    {
        "school": "Oak Street Elem School",
        "district": "Lakewood Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340822005981",
    },
    {
        "school": "Lavallette Elementary School",
        "district": "Lavallette Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340831004648",
    },
    {
        "school": "George J. Mitchell Elementary School",
        "district": "Little Egg Harbor Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340870004650",
    },
    {
        "school": "Frog Pond Elementary School",
        "district": "Little Egg Harbor Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340870006051",
    },
    {
        "school": "Ethel A. Jacobsen Elementary School",
        "district": "Long Beach Island Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340891004654",
    },
    {
        "school": "Long Beach Island Grade School",
        "district": "Long Beach Island Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340891004656",
    },
    {
        "school": "Manchester Township Elementary School",
        "district": "Manchester Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340945000031",
    },
    {
        "school": "Manchester Township High School",
        "district": "Manchester Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340945004660",
    },
    {
        "school": "Ridgeway Elementary School",
        "district": "Manchester Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340945004662",
    },
    {
        "school": "Whiting Elementary School",
        "district": "Manchester Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340945004664",
    },
    {
        "school": "Manchester Township Middle School",
        "district": "Manchester Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340945005967",
    },
    {
        "school": "Manchester Regional Day School",
        "district": "Manchester Township School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340945005983",
    },
    {
        "school": "Ocean County Vocational Technical School Brick Center",
        "district": "Ocean County Vocational Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341198004670",
    },
    {
        "school": "Ocean County Vocational Technical School Jackson Center",
        "district": "Ocean County Vocational Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341198004672",
    },
    {
        "school": "Ocean County Vocational Technical School Toms River Center",
        "district": "Ocean County Vocational Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341198004674",
    },
    {
        "school": "Ocean County Vocational Technical School Waretown Center",
        "district": "Ocean County Vocational Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341198004676",
    },
    {
        "school": "Ocean Gate Elementary School",
        "district": "Ocean Gate School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341203004678",
    },
    {
        "school": "Frederic A. Priff Elementary School",
        "district": "Ocean Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341209004682",
    },
    {
        "school": "Waretown Elementary School",
        "district": "Ocean Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341209004684",
    },
    {
        "school": "Pinelands Regional High School",
        "district": "Pinelands Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341300005917",
    },
    {
        "school": "Pinelands Regional Jr. High School",
        "district": "Pinelands Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341300006101",
    },
    {
        "school": "New Egypt Middle School",
        "district": "Plumsted Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341323000167",
    },
    {
        "school": "New Egypt High School",
        "district": "Plumsted Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341323000341",
    },
    {
        "school": "Dr. Gerald H. Woehr Elementary School",
        "district": "Plumsted Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341323004688",
    },
    {
        "school": "Point Pleasant Borough High School",
        "district": "Point Pleasant Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341329004692",
    },
    {
        "school": "Memorial Middle School",
        "district": "Point Pleasant Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341329004694",
    },
    {
        "school": "Nellie F. Bennett Elementary School",
        "district": "Point Pleasant Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341329004696",
    },
    {
        "school": "Ocean Road Elementary School",
        "district": "Point Pleasant Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341329004698",
    },
    {
        "school": "Point Pleasant Beach High School",
        "district": "Point Pleasant Beach School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341332004702",
    },
    {
        "school": "G. Harold Antrim Elementary School",
        "district": "Point Pleasant Beach School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341332004704",
    },
    {
        "school": "Hugh J. Boyd Jr. Elementary School",
        "district": "Seaside Heights School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341479004706",
    },
    {
        "school": "Southern Regional High School",
        "district": "Southern Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341548004710",
    },
    {
        "school": "Southern Regional Middle School",
        "district": "Southern Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341548005944",
    },
    {
        "school": "Ocean Acres Elementary School",
        "district": "Stafford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341569000343",
    },
    {
        "school": "Oxycocus Elementary School",
        "district": "Stafford Township School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341569004716",
    },
    {
        "school": "McKinley Avenue Elementary School",
        "district": "Stafford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341569004718",
    },
    {
        "school": "Stafford Intermediate School",
        "district": "Stafford Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341569006073",
    },
    {
        "school": "Joseph A. Citta Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623000345",
    },
    {
        "school": "Toms River High School North",
        "district": "Toms River Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004722",
    },
    {
        "school": "Toms River High School South",
        "district": "Toms River Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004724",
    },
    {
        "school": "Toms River Intermediate School East",
        "district": "Toms River Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004726",
    },
    {
        "school": "Toms River Intermediate School North",
        "district": "Toms River Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004728",
    },
    {
        "school": "Cedar Grove Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004730",
    },
    {
        "school": "East Dover Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004732",
    },
    {
        "school": "Hooper Avenue Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004734",
    },
    {
        "school": "North Dover Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004736",
    },
    {
        "school": "Pine Beach Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004738",
    },
    {
        "school": "Silver Bay Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004740",
    },
    {
        "school": "South Toms River Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004742",
    },
    {
        "school": "Walnut Street Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004744",
    },
    {
        "school": "Washington Street Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004746",
    },
    {
        "school": "West Dover Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623004748",
    },
    {
        "school": "Toms River High School East",
        "district": "Toms River Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623005919",
    },
    {
        "school": "Beachwood Elementary School",
        "district": "Toms River Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341623006037",
    },
    {
        "school": "Tuckerton Elementary School",
        "district": "Tuckerton Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341632004750",
    },
    {
        "school": "Robert L. Horbelt Elementary School",
        "district": "Barnegat Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341647000461",
    },
    {
        "school": "Lillian M. Dunfee Elementary",
        "district": "Barnegat Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341647004564",
    },
    {
        "school": "Cecil S. Collins Elementary",
        "district": "Barnegat Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341647005947",
    },
    {
        "school": "Russell O. Brackman Middle School",
        "district": "Barnegat Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341647006074",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "CALDWELL-WEST CALDWELL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340258002014",
    },
    {
        "school": "Discovery Charter School",
        "district": "Discovery Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340002000282",
    },
    {
        "school": "East Orange Community Charter School",
        "district": "EAST ORANGE COMMUNITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340002100283",
    },
    {
        "school": "Marion P. Thomas Charter School",
        "district": "Marion P. Thomas Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340002200285",
    },
    {
        "school": "New Horizons Community Charter School",
        "district": "New Horizons Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340002300287",
    },
    {
        "school": "North Star Academy Charter School",
        "district": "North Star Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340002400289",
    },
    {
        "school": "Robert Treat Academy Charter School",
        "district": "Robert Treat Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340002500291",
    },
    {
        "school": "Maria Varisco Rogers Charter School",
        "district": "Maria L. Varisco-Rogers Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340002600292",
    },
    {
        "school": "The Gray Charter School",
        "district": "Gray Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340006400373",
    },
    {
        "school": "Belleville High School",
        "district": "Belleville Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340135001954",
    },
    {
        "school": "Belleville Middle School",
        "district": "Belleville Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340135001956",
    },
    {
        "school": "Belleville PS3",
        "district": "Belleville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340135001962",
    },
    {
        "school": "Belleville PS4",
        "district": "Belleville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340135001964",
    },
    {
        "school": "Belleville PS5",
        "district": "Belleville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340135001966",
    },
    {
        "school": "Belleville PS7",
        "district": "Belleville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340135001968",
    },
    {
        "school": "Belleville PS8",
        "district": "Belleville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340135001970",
    },
    {
        "school": "Belleville PS9",
        "district": "Belleville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340135001972",
    },
    {
        "school": "Belleville PS10",
        "district": "Belleville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340135001974",
    },
    {
        "school": "The Early Childhood Center @ Forest Glen",
        "district": "Bloomfield Township School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340183000133",
    },
    {
        "school": "Bloomfield High School",
        "district": "Bloomfield Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340183001980",
    },
    {
        "school": "Bloomfield Middle School",
        "district": "Bloomfield Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340183001982",
    },
    {
        "school": "Berkeley Elementary School",
        "district": "Bloomfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340183001986",
    },
    {
        "school": "Brookdale Elementary School",
        "district": "Bloomfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340183001988",
    },
    {
        "school": "Carteret Elementary School",
        "district": "Bloomfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340183001992",
    },
    {
        "school": "Demarest Elementary School",
        "district": "Bloomfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340183001994",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Bloomfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340183001996",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Bloomfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340183002000",
    },
    {
        "school": "Oak View Elementary School",
        "district": "Bloomfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340183002002",
    },
    {
        "school": "Watsessing Elementary School",
        "district": "Bloomfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340183002004",
    },
    {
        "school": "James Caldwell High School",
        "district": "CALDWELL-WEST CALDWELL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340258002008",
    },
    {
        "school": "Grover Cleveland Middle School",
        "district": "CALDWELL-WEST CALDWELL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340258002010",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "CALDWELL-WEST CALDWELL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340258002016",
    },
    {
        "school": "Washington Elementary School",
        "district": "CALDWELL-WEST CALDWELL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340258002020",
    },
    {
        "school": "Wilson Elementary School",
        "district": "CALDWELL-WEST CALDWELL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340258002022",
    },
    {
        "school": "Cedar Grove High School",
        "district": "Cedar Grove Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340285002026",
    },
    {
        "school": "North End Elementary School",
        "district": "Cedar Grove Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340285002030",
    },
    {
        "school": "South End Elementary School",
        "district": "Cedar Grove Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340285002036",
    },
    {
        "school": "Memorial Middle School",
        "district": "Cedar Grove Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340285006025",
    },
    {
        "school": "Johnnie L. Cochran Jr. Academy",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423000134",
    },
    {
        "school": "Benjamin Banneker Academy",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423000273",
    },
    {
        "school": "Althea Gibson Academy",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423000275",
    },
    {
        "school": "Wahlstrom Early Childhood Academy",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423000381",
    },
    {
        "school": "East Orange STEM Academy High School",
        "district": "East Orange School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423002040",
    },
    {
        "school": "Edward T. Bowser Sr. School of Excellence",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423002044",
    },
    {
        "school": "George Washington Carver Institute",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423002046",
    },
    {
        "school": "Langston Hughes Elementary School",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423002048",
    },
    {
        "school": "Whitney E. Houston Academy",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423002050",
    },
    {
        "school": "Mildred Barry Garvin Elementary",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423002052",
    },
    {
        "school": "Dionne Warwick Institute",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423002054",
    },
    {
        "school": "Ecole Toussaint Louverture",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423002058",
    },
    {
        "school": "Gordon Parks Academy",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423002060",
    },
    {
        "school": "Cicely L. Tyson Community Elementary School",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423002062",
    },
    {
        "school": "Cicely L. Tyson Community Middle/High School",
        "district": "East Orange School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423002064",
    },
    {
        "school": "J. Garfield Jackson Sr. Academy",
        "district": "East Orange School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423005901",
    },
    {
        "school": "John L. Costley Middle School",
        "district": "East Orange School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423005930",
    },
    {
        "school": "Patrick F. Healy Middle School",
        "district": "East Orange School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423005931",
    },
    {
        "school": "Sojourner Truth Middle School",
        "district": "East Orange School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340423005932",
    },
    {
        "school": "Essex County Newark Tech",
        "district": "Essex County Schools of Technology",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340480000137",
    },
    {
        "school": "Essex County Donald M. Payne Sr. School of Technology",
        "district": "Essex County Schools of Technology",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340480002074",
    },
    {
        "school": "Essex County West Caldwell Tech",
        "district": "Essex County Schools of Technology",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340480002080",
    },
    {
        "school": "Essex Fells Elementary School",
        "district": "ESSEX FELLS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340483002082",
    },
    {
        "school": "Stevenson",
        "district": "Fairfield Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340501002086",
    },
    {
        "school": "Winston Churchill",
        "district": "Fairfield Public Schools School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340501002088",
    },
    {
        "school": "Glen Ridge High School",
        "district": "Glen Ridge Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340594002092",
    },
    {
        "school": "Forest Avenue School",
        "district": "Glen Ridge Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340594002096",
    },
    {
        "school": "Ridgewood Avenue School",
        "district": "Glen Ridge Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340594002098",
    },
    {
        "school": "Linden Avenue School",
        "district": "Glen Ridge Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340594005963",
    },
    {
        "school": "Thurgood Marshall Elementary School",
        "district": "Irvington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768000089",
    },
    {
        "school": "Irvington High School",
        "district": "Irvington Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768002104",
    },
    {
        "school": "Berkeley Terrace Elementary School",
        "district": "Irvington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768002108",
    },
    {
        "school": "Chancellor Avenue Elementary School",
        "district": "Irvington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768002110",
    },
    {
        "school": "Grove Street Elementary School",
        "district": "Irvington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768002114",
    },
    {
        "school": "Madison Avenue",
        "district": "Irvington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768002116",
    },
    {
        "school": "University Middle School",
        "district": "Irvington Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768002120",
    },
    {
        "school": "Union Avenue Middle School",
        "district": "Irvington Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768002122",
    },
    {
        "school": "Florence Avenue Elementary School",
        "district": "Irvington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768005965",
    },
    {
        "school": "Livingston High School",
        "district": "Livingston Board of Education School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340882002126",
    },
    {
        "school": "Heritage Middle School",
        "district": "Livingston Board of Education School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340882002128",
    },
    {
        "school": "Mount Pleasant Middle School",
        "district": "Livingston Board of Education School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340882002130",
    },
    {
        "school": "Collins Elementary School",
        "district": "Livingston Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340882002134",
    },
    {
        "school": "Harrison Elementary School",
        "district": "Livingston Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340882002136",
    },
    {
        "school": "Hillside Elementary School",
        "district": "Livingston Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340882002138",
    },
    {
        "school": "Mount Pleasant Elementary School",
        "district": "Livingston Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340882002140",
    },
    {
        "school": "Riker Hill Elementary School",
        "district": "Livingston Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340882002142",
    },
    {
        "school": "Burnet Hill Elementary School",
        "district": "Livingston Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340882006052",
    },
    {
        "school": "South Mountain School",
        "district": "Millburn Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341020000230",
    },
    {
        "school": "Millburn High School",
        "district": "Millburn Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341020002148",
    },
    {
        "school": "Millburn Middle School",
        "district": "Millburn Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341020002150",
    },
    {
        "school": "Deerfield School",
        "district": "Millburn Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341020002152",
    },
    {
        "school": "Glenwood School",
        "district": "Millburn Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341020002154",
    },
    {
        "school": "Hartshorn School",
        "district": "Millburn Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341020002156",
    },
    {
        "school": "Wyoming School",
        "district": "Millburn Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341020002162",
    },
    {
        "school": "Renaissance Middle School at the Rand Building",
        "district": "Montclair Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341056000181",
    },
    {
        "school": "Montclair High School",
        "district": "Montclair Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341056002166",
    },
    {
        "school": "Bradford Elementary School",
        "district": "Montclair Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341056002168",
    },
    {
        "school": "Edgemont Elementary School",
        "district": "Montclair Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341056002170",
    },
    {
        "school": "Glenfield Middle School",
        "district": "Montclair Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341056002172",
    },
    {
        "school": "Hillside Elementary School",
        "district": "Montclair Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341056002176",
    },
    {
        "school": "Buzz Aldrin Middle School",
        "district": "Montclair Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341056002178",
    },
    {
        "school": "Nishuane Elementary School",
        "district": "Montclair Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341056002180",
    },
    {
        "school": "Northeast Elementary School",
        "district": "Montclair Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341056002182",
    },
    {
        "school": "Watchung Elementary School",
        "district": "Montclair Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341056002184",
    },
    {
        "school": "Charles H. Bullock School",
        "district": "Montclair Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341056005984",
    },
    {
        "school": "Rafael Hernandez School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134000091",
    },
    {
        "school": "Technology High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134000139",
    },
    {
        "school": "Arts High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002188",
    },
    {
        "school": "Barringer High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002190",
    },
    {
        "school": "Central High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002192",
    },
    {
        "school": "East Side High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002194",
    },
    {
        "school": "Malcolm X Shabazz High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002198",
    },
    {
        "school": "Science Park High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002200",
    },
    {
        "school": "University High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002202",
    },
    {
        "school": "Weequahic High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002206",
    },
    {
        "school": "West Side High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002208",
    },
    {
        "school": "Abington Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002222",
    },
    {
        "school": "Ann Street School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002228",
    },
    {
        "school": "Avon Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002232",
    },
    {
        "school": "Belmont Runyon Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002234",
    },
    {
        "school": "Branch Brook School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002244",
    },
    {
        "school": "Bruce Street School For The Deaf",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341134002248",
    },
    {
        "school": "Camden Street Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002252",
    },
    {
        "school": "Chancellor Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002256",
    },
    {
        "school": "Cleveland Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002262",
    },
    {
        "school": "Peshine Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002266",
    },
    {
        "school": "Elliott Street Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002270",
    },
    {
        "school": "First Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002274",
    },
    {
        "school": "Fourteenth Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341134002276",
    },
    {
        "school": "Benjamin Franklin Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002278",
    },
    {
        "school": "Dr William H. Horton Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002280",
    },
    {
        "school": "Harriet Tubman Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002282",
    },
    {
        "school": "Hawkins Street School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002284",
    },
    {
        "school": "Hawthorne Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002288",
    },
    {
        "school": "John F. Kennedy School",
        "district": "Newark Public School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341134002296",
    },
    {
        "school": "Lafayette Street School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002298",
    },
    {
        "school": "Lincoln",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002302",
    },
    {
        "school": "Louise A. Spencer Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002304",
    },
    {
        "school": "McKinley Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002318",
    },
    {
        "school": "Mt Vernon Place School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002326",
    },
    {
        "school": "Oliver Street School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002330",
    },
    {
        "school": "Quitman Street School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002334",
    },
    {
        "school": "Ridge Street School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002338",
    },
    {
        "school": "Roberto Clemente Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002342",
    },
    {
        "school": "South Street Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002352",
    },
    {
        "school": "South Seventeenth Street School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002354",
    },
    {
        "school": "Speedway Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002356",
    },
    {
        "school": "Sussex Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002360",
    },
    {
        "school": "Thirteenth Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002364",
    },
    {
        "school": "Wilson Avenue School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002368",
    },
    {
        "school": "George Washington Carver Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134005912",
    },
    {
        "school": "Dr. E. Alma Flagg School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134005976",
    },
    {
        "school": "NJ Regional Day School  - Newark",
        "district": "Newark Public School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341134005985",
    },
    {
        "school": "Gould/Mountain Elementary School",
        "district": "North Caldwell School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341152002372",
    },
    {
        "school": "Grandview Elementary School",
        "district": "North Caldwell School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341152002374",
    },
    {
        "school": "Nutley High School",
        "district": "Nutley Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341188002378",
    },
    {
        "school": "John H. Walker Middle School",
        "district": "Nutley Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341188002380",
    },
    {
        "school": "Lincoln School",
        "district": "Nutley Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341188002382",
    },
    {
        "school": "Radcliffe School",
        "district": "Nutley Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341188002384",
    },
    {
        "school": "Spring Garden School",
        "district": "Nutley Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341188002388",
    },
    {
        "school": "Washington School",
        "district": "Nutley Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341188002390",
    },
    {
        "school": "Yantacaw School",
        "district": "Nutley Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341188002392",
    },
    {
        "school": "Orange High School",
        "district": "ORANGE BOARD OF EDUCATION School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341227002396",
    },
    {
        "school": "Cleveland Street Elementary SCchool",
        "district": "ORANGE BOARD OF EDUCATION School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341227002400",
    },
    {
        "school": "Forest Street Elementary School",
        "district": "ORANGE BOARD OF EDUCATION School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341227002402",
    },
    {
        "school": "Heywood Avenue Elementary School",
        "district": "ORANGE BOARD OF EDUCATION School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341227002404",
    },
    {
        "school": "Lincoln Avenue Elementary School",
        "district": "ORANGE BOARD OF EDUCATION School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341227002406",
    },
    {
        "school": "Oakwood Avenue Elementary School",
        "district": "ORANGE BOARD OF EDUCATION School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341227002408",
    },
    {
        "school": "Orange Preparatory Academy",
        "district": "ORANGE BOARD OF EDUCATION School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341227002410",
    },
    {
        "school": "Park  Avenue Elementary School",
        "district": "ORANGE BOARD OF EDUCATION School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341227002412",
    },
    {
        "school": "Lester C Noecker",
        "district": "Roseland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341425002418",
    },
    {
        "school": "Columbia High School",
        "district": "South Orange-Maplewood School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341533002422",
    },
    {
        "school": "Maplewood Middle School",
        "district": "South Orange-Maplewood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341533002424",
    },
    {
        "school": "South Orange Middle School",
        "district": "South Orange-Maplewood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341533002426",
    },
    {
        "school": "Clinton Elementary School",
        "district": "South Orange-Maplewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341533002428",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "South Orange-Maplewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341533002432",
    },
    {
        "school": "Marshall Elementary School",
        "district": "South Orange-Maplewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341533002434",
    },
    {
        "school": "Seth Boyden Elementary Demonstration School",
        "district": "South Orange-Maplewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341533002440",
    },
    {
        "school": "South Mountain Elementary School",
        "district": "South Orange-Maplewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341533002442",
    },
    {
        "school": "Tuscan Elementary School",
        "district": "South Orange-Maplewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341533002444",
    },
    {
        "school": "Verona High School",
        "district": "Verona Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341674002448",
    },
    {
        "school": "Brookdale Avenue School",
        "district": "Verona Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341674002450",
    },
    {
        "school": "Frederic N. Brown Elementary School",
        "district": "Verona Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341674002452",
    },
    {
        "school": "Forest Avenue School",
        "district": "Verona Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341674002454",
    },
    {
        "school": "Henry B. Whitehorne Middle School",
        "district": "Verona Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341674002456",
    },
    {
        "school": "Laning Avenue School",
        "district": "Verona Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341674002458",
    },
    {
        "school": "West Essex High School",
        "district": "West Essex Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341746002462",
    },
    {
        "school": "West Essex Middle School",
        "district": "West Essex Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341746002464",
    },
    {
        "school": "Mount Pleasant Elementary School",
        "district": "West Orange Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761000182",
    },
    {
        "school": "West Orange High School",
        "district": "West Orange Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761002468",
    },
    {
        "school": "Edison Middle School",
        "district": "West Orange Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761002472",
    },
    {
        "school": "Roosevelt Middle School",
        "district": "West Orange Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761002476",
    },
    {
        "school": "Gregory Elementary School",
        "district": "West Orange Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761002482",
    },
    {
        "school": "Hazel Avenue Elementary School",
        "district": "West Orange Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761002484",
    },
    {
        "school": "Kelly Elementary School",
        "district": "West Orange Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761002488",
    },
    {
        "school": "Redwood Elementary School",
        "district": "West Orange Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761002490",
    },
    {
        "school": "St. Cloud Elementary School",
        "district": "West Orange Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761002492",
    },
    {
        "school": "Washington Elementary School",
        "district": "West Orange Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761002494",
    },
    {
        "school": "Essex Junior Academy",
        "district": "Essex Regional Educational Services Commission",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348030006040",
    },
    {
        "school": "Chatham High School",
        "district": "School District of the Chathams",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340000406014",
    },
    {
        "school": "Chatham Middle School",
        "district": "School District of the Chathams",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340000406015",
    },
    {
        "school": "Lafayette Avenue School",
        "district": "School District of the Chathams",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340000406016",
    },
    {
        "school": "Milton Avenue School",
        "district": "School District of the Chathams",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340000406017",
    },
    {
        "school": "Washington Avenue School",
        "district": "School District of the Chathams",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340000406018",
    },
    {
        "school": "Southern Boulevard School",
        "district": "School District of the Chathams",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340000406019",
    },
    {
        "school": "Unity Charter School",
        "district": "Unity Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340005100339",
    },
    {
        "school": "Boonton High School",
        "district": "Boonton Town School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340195004154",
    },
    {
        "school": "John Hill School",
        "district": "Boonton Town School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340195004156",
    },
    {
        "school": "School Street School",
        "district": "Boonton Town School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340195004158",
    },
    {
        "school": "Rockaway Valley School",
        "district": "Boonton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340198004162",
    },
    {
        "school": "Butler High School",
        "district": "Butler Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340252004166",
    },
    {
        "school": "Aaron Decker School",
        "district": "Butler Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340252004168",
    },
    {
        "school": "Richard Butler School",
        "district": "Butler Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340252004170",
    },
    {
        "school": "Black River Middle School",
        "district": "Chester School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340306004194",
    },
    {
        "school": "Bragg Elementary School",
        "district": "Chester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340306004196",
    },
    {
        "school": "Dickerson Elementary School",
        "district": "Chester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340306006026",
    },
    {
        "school": "Lakeview Elementary School",
        "district": "Denville Township K-8 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340387004202",
    },
    {
        "school": "Riverview Elementary School",
        "district": "Denville Township K-8 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340387004206",
    },
    {
        "school": "Valleyview Middle School",
        "district": "Denville Township K-8 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340387004208",
    },
    {
        "school": "Dover Middle School",
        "district": "Dover Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340393000005",
    },
    {
        "school": "Dover High School",
        "district": "Dover Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340393004212",
    },
    {
        "school": "Academy Street Elementary School",
        "district": "Dover Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340393004214",
    },
    {
        "school": "East Dover Elementary School",
        "district": "Dover Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340393004216",
    },
    {
        "school": "North Dover Elementary School",
        "district": "Dover Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340393004220",
    },
    {
        "school": "Central Elementary School",
        "district": "East Hanover Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340417004224",
    },
    {
        "school": "Frank J Smith Elementary",
        "district": "East Hanover Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340417004226",
    },
    {
        "school": "East Hanover Middle School",
        "district": "East Hanover Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340417004230",
    },
    {
        "school": "Briarwood School",
        "district": "Florham Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340525004234",
    },
    {
        "school": "Brooklake School",
        "district": "Florham Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340525004236",
    },
    {
        "school": "Ridgedale Middle School",
        "district": "Florham Park School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340525004238",
    },
    {
        "school": "Hanover Park High School",
        "district": "Hanover Park Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340666004244",
    },
    {
        "school": "Whippany Park High School",
        "district": "Hanover Park Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340666004246",
    },
    {
        "school": "Bee Meadow School",
        "district": "Hanover Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340669004250",
    },
    {
        "school": "Memorial Junior School",
        "district": "Hanover Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340669004254",
    },
    {
        "school": "Mountview Road School",
        "district": "Hanover Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340669004256",
    },
    {
        "school": "Salem Drive School",
        "district": "Hanover Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340669004258",
    },
    {
        "school": "Harding Township School",
        "district": "Harding Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340672004260",
    },
    {
        "school": "Jefferson Township High School",
        "district": "Jefferson Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340780004264",
    },
    {
        "school": "Arthur Stanlick Elementary School",
        "district": "Jefferson Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340780004266",
    },
    {
        "school": "Cozy Lake Elementary School",
        "district": "Jefferson Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340780004270",
    },
    {
        "school": "Ellen T. Briggs Elementary School",
        "district": "Jefferson Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340780004272",
    },
    {
        "school": "Jefferson Township Middle School",
        "district": "Jefferson Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340780004274",
    },
    {
        "school": "Milton Elementary School",
        "district": "Jefferson Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340780004276",
    },
    {
        "school": "White Rock Elementary School",
        "district": "Jefferson Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340780004278",
    },
    {
        "school": "Kinnelon High School",
        "district": "Kinnelon School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340804004282",
    },
    {
        "school": "Kiel Elementary School",
        "district": "Kinnelon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340804004284",
    },
    {
        "school": "Pearl R. Miller Middle School",
        "district": "Kinnelon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340804004286",
    },
    {
        "school": "Stonybrook Elementary School",
        "district": "Kinnelon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340804004288",
    },
    {
        "school": "Lincoln Park Elementary School",
        "district": "Lincoln Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340858004294",
    },
    {
        "school": "Lincoln Park Middle School",
        "district": "Lincoln Park School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340858004296",
    },
    {
        "school": "Madison High School",
        "district": "Madison Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340924004300",
    },
    {
        "school": "Central Avenue School",
        "district": "Madison Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340924004302",
    },
    {
        "school": "Kings Road School",
        "district": "Madison Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340924004304",
    },
    {
        "school": "Madison Junior School",
        "district": "Madison Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340924004308",
    },
    {
        "school": "Torey J. Sabatini School",
        "district": "Madison Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340924004310",
    },
    {
        "school": "Hilltop School",
        "district": "Mendham Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340990004314",
    },
    {
        "school": "Mountain View School",
        "district": "Mendham Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340990004316",
    },
    {
        "school": "Mendham Township Elementary School",
        "district": "Mendham Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340993004320",
    },
    {
        "school": "Mendham Township Middle School",
        "district": "Mendham Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340993004322",
    },
    {
        "school": "Canfield Avenue School",
        "district": "Mine Hill Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341035004326",
    },
    {
        "school": "Montville Township High School",
        "district": "Montville Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341065004332",
    },
    {
        "school": "Cedar Hill School",
        "district": "Montville Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341065004334",
    },
    {
        "school": "Robert R Lazar Middle School",
        "district": "Montville Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341065004336",
    },
    {
        "school": "Hilldale School",
        "district": "Montville Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341065004338",
    },
    {
        "school": "Valley View School",
        "district": "Montville Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341065004340",
    },
    {
        "school": "William Mason School",
        "district": "Montville Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341065004342",
    },
    {
        "school": "Woodmont School",
        "district": "Montville Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341065004344",
    },
    {
        "school": "Morris County School of Technology",
        "district": "Morris County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341072004348",
    },
    {
        "school": "Morris Hills High School",
        "district": "Morris Hills Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341074004352",
    },
    {
        "school": "Morris Knolls High School",
        "district": "Morris Hills Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341074004354",
    },
    {
        "school": "Morris Plains Borough School",
        "district": "Morris Plains School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341077004358",
    },
    {
        "school": "Mountain Way School",
        "district": "Morris Plains School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341077004362",
    },
    {
        "school": "Normandy Park School",
        "district": "Morris School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341081000337",
    },
    {
        "school": "Morristown High School",
        "district": "Morris School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341081004366",
    },
    {
        "school": "Alexander Hamilton",
        "district": "Morris School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341081004368",
    },
    {
        "school": "Alfred Vail School",
        "district": "Morris School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341081004370",
    },
    {
        "school": "Frelinghuysen Middle School",
        "district": "Morris School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341081004372",
    },
    {
        "school": "Lafayette Learning Center",
        "district": "Morris School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341081004376",
    },
    {
        "school": "Hillcrest School",
        "district": "Morris School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341081004378",
    },
    {
        "school": "Sussex Avenue School",
        "district": "Morris School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341081004384",
    },
    {
        "school": "Thomas Jefferson School",
        "district": "Morris School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341081004386",
    },
    {
        "school": "Woodland School",
        "district": "Morris School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341081004388",
    },
    {
        "school": "Edith M. Decker Elementary School",
        "district": "Mount Arlington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341086004392",
    },
    {
        "school": "Mount Arlington Public School",
        "district": "Mount Arlington Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341086004394",
    },
    {
        "school": "Mount Olive Middle School",
        "district": "Mount Olive Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341098000459",
    },
    {
        "school": "Mount Olive High School",
        "district": "Mount Olive Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341098004398",
    },
    {
        "school": "Chester M. Stephens Elementary School",
        "district": "Mount Olive Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341098004404",
    },
    {
        "school": "Mountain View Elementary School",
        "district": "Mount Olive Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341098004406",
    },
    {
        "school": "Sandshore Rd. Elementary School",
        "district": "Mount Olive Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341098004410",
    },
    {
        "school": "Tinc Rd. Elementary School",
        "district": "Mount Olive Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341098004412",
    },
    {
        "school": "Mountain Lakes High School",
        "district": "Mountain Lakes Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341101004416",
    },
    {
        "school": "Briarcliff Middle School",
        "district": "Mountain Lakes Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341101004418",
    },
    {
        "school": "Lake Drive Program for Hearing Impared",
        "district": "Mountain Lakes Public School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341101004420",
    },
    {
        "school": "Wildwood Elementary School",
        "district": "Mountain Lakes Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341101004422",
    },
    {
        "school": "Netcong Elementary School",
        "district": "Netcong School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341119004426",
    },
    {
        "school": "Mount Tabor Elementary School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248000241",
    },
    {
        "school": "Lake Hiawatha Elementary School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248000401",
    },
    {
        "school": "Parsippany High School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004430",
    },
    {
        "school": "Parsippany Hills High School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004432",
    },
    {
        "school": "Brooklawn Middle School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004434",
    },
    {
        "school": "Central Middle School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004436",
    },
    {
        "school": "Eastlake Elementary School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004438",
    },
    {
        "school": "Intervale Elementary School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004440",
    },
    {
        "school": "Knollwood Elementary School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004442",
    },
    {
        "school": "Lake Parsippany Elementary School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004446",
    },
    {
        "school": "Littleton Elementary School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004448",
    },
    {
        "school": "Northvail Elementary School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004452",
    },
    {
        "school": "Rockaway Meadow Elementary School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004454",
    },
    {
        "school": "Troy Hills Elementary School",
        "district": "Parsippany-Troy Hills Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341248004458",
    },
    {
        "school": "Central Middle School",
        "district": "Long Hill Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341266004462",
    },
    {
        "school": "Gillette Elementary School",
        "district": "Long Hill Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341266004464",
    },
    {
        "school": "Millington Elementary School",
        "district": "Long Hill Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341266004466",
    },
    {
        "school": "Pequannock Township High School",
        "district": "Pequannock Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341290004470",
    },
    {
        "school": "Hillview School",
        "district": "Pequannock Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341290004472",
    },
    {
        "school": "North Boulevard School",
        "district": "Pequannock Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341290004474",
    },
    {
        "school": "Pequannock Valley School",
        "district": "Pequannock Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341290004478",
    },
    {
        "school": "Stephen J. Gerace School",
        "district": "Pequannock Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341290004482",
    },
    {
        "school": "Randolph High School",
        "district": "Randolph Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341365004486",
    },
    {
        "school": "Center Grove School",
        "district": "Randolph Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341365004488",
    },
    {
        "school": "Fernbrook School",
        "district": "Randolph Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341365004490",
    },
    {
        "school": "Ironia School",
        "district": "Randolph Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341365004492",
    },
    {
        "school": "Randolph Middle School",
        "district": "Randolph Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341365004494",
    },
    {
        "school": "Shongum School",
        "district": "Randolph Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341365004496",
    },
    {
        "school": "Riverdale School",
        "district": "Riverdale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341398004498",
    },
    {
        "school": "Thomas Jefferson Middle School",
        "district": "Rockaway Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341410004502",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Rockaway Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341410004504",
    },
    {
        "school": "Birchwood Elementary School",
        "district": "Rockaway Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341413004510",
    },
    {
        "school": "Copeland Middle School",
        "district": "Rockaway Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341413004512",
    },
    {
        "school": "Catherine A Dwyer Elementary School",
        "district": "Rockaway Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341413004514",
    },
    {
        "school": "Dennis B O'Brien Elementary School",
        "district": "Rockaway Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341413004516",
    },
    {
        "school": "Katharine D Malone Elementary School",
        "district": "Rockaway Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341413004518",
    },
    {
        "school": "Stony Brook Elementary School",
        "district": "Rockaway Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341413004520",
    },
    {
        "school": "Roxbury High School",
        "district": "Roxbury Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341434004524",
    },
    {
        "school": "Eisenhower Middle School",
        "district": "Roxbury Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341434004526",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Roxbury Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341434004528",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Roxbury Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341434004530",
    },
    {
        "school": "Kennedy Elementary School",
        "district": "Roxbury Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341434004532",
    },
    {
        "school": "Lincoln/Roosevelt School",
        "district": "Roxbury Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341434004534",
    },
    {
        "school": "Nixon Elementary School",
        "district": "Roxbury Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341434004536",
    },
    {
        "school": "Flocktown-Kossmann Elementary School",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341713004542",
    },
    {
        "school": "Long Valley Middle School",
        "district": "Washington Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341713004544",
    },
    {
        "school": "Old Farmers Road School",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341713004546",
    },
    {
        "school": "West Morris Central High School",
        "district": "West Morris Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341755004550",
    },
    {
        "school": "West Morris Mendham High School",
        "district": "West Morris Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341755004552",
    },
    {
        "school": "Alfred C. MacKinnon Middle School",
        "district": "WHARTON BOROUGH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341788004558",
    },
    {
        "school": "Marie V. Duffy Elementary School",
        "district": "WHARTON BOROUGH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341788004560",
    },
    {
        "school": "Essex High School",
        "district": "Essex Regional Educational Services Commission",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "348030000135",
    },
    {
        "school": "Sussex County Technology Charter School",
        "district": "Sussex County Technology Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340005500361",
    },
    {
        "school": "Florence M. Burd",
        "district": "Andover Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340090005324",
    },
    {
        "school": "Long Pond School",
        "district": "Andover Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340090005326",
    },
    {
        "school": "Byram Intermediate School",
        "district": "Byram Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340255005334",
    },
    {
        "school": "Frankford Township School",
        "district": "Frankford Township Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340534005336",
    },
    {
        "school": "Franklin Borough School",
        "district": "Franklin Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340540005342",
    },
    {
        "school": "Fredon Township School",
        "district": "Fredon Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340555005344",
    },
    {
        "school": "Green Hills School",
        "district": "Green Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340609005350",
    },
    {
        "school": "Hamburg School",
        "district": "Hamburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340648005352",
    },
    {
        "school": "Marian E. McKeown Elementary  School",
        "district": "Hampton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340663005354",
    },
    {
        "school": "Hardyston Township Elementary School",
        "district": "Hardyston Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340678005356",
    },
    {
        "school": "High Point Regional High School District",
        "district": "High Point Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340714005358",
    },
    {
        "school": "Hopatcong High School",
        "district": "Hopatcong Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340744005362",
    },
    {
        "school": "Durban Avenue Elementary School",
        "district": "Hopatcong Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340744005366",
    },
    {
        "school": "Tulsa Trail Elementary School",
        "district": "Hopatcong Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340744005370",
    },
    {
        "school": "Hopatcong Middle School",
        "district": "Hopatcong Borough School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340744005905",
    },
    {
        "school": "Kittatinny Regional High School",
        "district": "Kittatinny Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340806005372",
    },
    {
        "school": "Lafayette Township School",
        "district": "Lafayette Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340813005374",
    },
    {
        "school": "Lenape Valley Regional High School",
        "district": "Lenape Valley Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340850005378",
    },
    {
        "school": "Montague Township School",
        "district": "MONTAGUE TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341053005380",
    },
    {
        "school": "Newton High School",
        "district": "NEWTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341140005384",
    },
    {
        "school": "Halsted Middle School",
        "district": "NEWTON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341140005386",
    },
    {
        "school": "Merriam Avenue School",
        "district": "NEWTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341140005388",
    },
    {
        "school": "Ogdensburg Borough School",
        "district": "Ogdensburg Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341215005390",
    },
    {
        "school": "Sandyston Walpack Consolidated School",
        "district": "Sandyston-Walpack Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341461005392",
    },
    {
        "school": "Sparta Middle School",
        "district": "SPARTA TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341551000360",
    },
    {
        "school": "Sparta High School",
        "district": "SPARTA TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341551005396",
    },
    {
        "school": "Helen Morgan School",
        "district": "SPARTA TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341551005400",
    },
    {
        "school": "Alpine Elementary School",
        "district": "SPARTA TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341551005402",
    },
    {
        "school": "Valley Road School",
        "district": "Stanhope School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341572005404",
    },
    {
        "school": "Stillwater Township School",
        "district": "Stillwater Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341575005406",
    },
    {
        "school": "Sussex County Technical School",
        "district": "Sussex County Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341593005416",
    },
    {
        "school": "Sussex Middle School",
        "district": "Sussex-Wantage Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341596005410",
    },
    {
        "school": "Wantage Elementary School",
        "district": "Sussex-Wantage Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341596005412",
    },
    {
        "school": "Clifton E. Lawrence",
        "district": "Sussex-Wantage Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341596005945",
    },
    {
        "school": "Vernon Township High School",
        "district": "Vernon Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341671005422",
    },
    {
        "school": "Lounsberry Hollow School",
        "district": "Vernon Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341671005424",
    },
    {
        "school": "Rolling Hills Primary School",
        "district": "Vernon Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341671005426",
    },
    {
        "school": "Walnut Ridge Primary School",
        "district": "Vernon Township School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341671005428",
    },
    {
        "school": "Glen Meadow Middle School",
        "district": "Vernon Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341671005948",
    },
    {
        "school": "Cedar Mountain Primary School",
        "district": "Vernon Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341671006009",
    },
    {
        "school": "WALLKILL VALLEY REGIONAL HIGH SCHOOL",
        "district": "Wallkill Valley Regional High School",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341687005949",
    },
    {
        "school": "Northern Hills Academy",
        "district": "Northern Hills Academy School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348032005960",
    },
    {
        "school": "Developmental Learning Center New Providence",
        "district": "Morris-Union Jointure Commisson School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340000506063",
    },
    {
        "school": "The Queen City Academy Charter School",
        "district": "The Queen City Academy Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340006100378",
    },
    {
        "school": "Governor Livingston High School",
        "district": "Berkeley Heights School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340153000201",
    },
    {
        "school": "Mary Kay McMillin Early Childhood Center",
        "district": "Berkeley Heights School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340153000203",
    },
    {
        "school": "Thomas P. Hughes School",
        "district": "Berkeley Heights School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340153005434",
    },
    {
        "school": "Columbia Middle School",
        "district": "Berkeley Heights School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340153005436",
    },
    {
        "school": "Mountain Park School",
        "district": "Berkeley Heights School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340153005440",
    },
    {
        "school": "William Woodruff School",
        "district": "Berkeley Heights School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340153005442",
    },
    {
        "school": "Arthur L. Johnson High School",
        "district": "Clark Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340315000205",
    },
    {
        "school": "Frank K. Hehnly",
        "district": "Clark Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340315005450",
    },
    {
        "school": "Carl H. Kumpf School",
        "district": "Clark Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340315005452",
    },
    {
        "school": "Valley Road School",
        "district": "Clark Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340315005454",
    },
    {
        "school": "Bloomingdale Avenue School",
        "district": "Cranford Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340357000206",
    },
    {
        "school": "Cranford High School",
        "district": "Cranford Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340357005458",
    },
    {
        "school": "Hillside Avenue School",
        "district": "Cranford Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340357005460",
    },
    {
        "school": "Orange Avenue School",
        "district": "Cranford Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340357005462",
    },
    {
        "school": "Brookside Place School",
        "district": "Cranford Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340357005466",
    },
    {
        "school": "Livingston Avenue School",
        "district": "Cranford Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340357005470",
    },
    {
        "school": "Walnut Avenue School",
        "district": "Cranford Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340357005474",
    },
    {
        "school": "Terence C. Reilly School No 7",
        "district": "Elizabeth Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459000013",
    },
    {
        "school": "Mabel G. Homes School No. 5",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459000071",
    },
    {
        "school": "Sonia Sotomayor School No 25",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459000207",
    },
    {
        "school": "Dr. Orlando Edreira Academy School No. 26",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459000245",
    },
    {
        "school": "Frances C. Smith Early Childhood Center No 50",
        "district": "Elizabeth Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459000467",
    },
    {
        "school": "Elizabeth High School - Frank J Cicarell Academy",
        "district": "Elizabeth Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005478",
    },
    {
        "school": "Joseph Battin School No 4",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005482",
    },
    {
        "school": "George Washington Academy School No. 1",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005492",
    },
    {
        "school": "Winfield Scott School No. 2",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005494",
    },
    {
        "school": "Toussaint Louverture-Marquis de Lafayette School No. 6",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005498",
    },
    {
        "school": "Elmora School No. 12",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005504",
    },
    {
        "school": "Benjamin Franklin School No. 13",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005506",
    },
    {
        "school": "Abraham Lincoln School No. 14",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005508",
    },
    {
        "school": "Christopher Columbus School No. 15",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005510",
    },
    {
        "school": "Madison Monroe School No. 16",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005512",
    },
    {
        "school": "Robert Morris School No. 18",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005516",
    },
    {
        "school": "Woodrow Wilson School No. 19",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005518",
    },
    {
        "school": "John Marshal School No. 20",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005520",
    },
    {
        "school": "Victor Mravlag School No. 21",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005522",
    },
    {
        "school": "William F. Halloran School No.22",
        "district": "Elizabeth Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005524",
    },
    {
        "school": "Nicholas Murray Butler Academy School No. 23",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005526",
    },
    {
        "school": "Nicholas S. Lacorte-Peterstown School No. 3",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459005962",
    },
    {
        "school": "Lincoln",
        "district": "Garwood Boro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340579005532",
    },
    {
        "school": "Hillside High School",
        "district": "Hillside Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340729005540",
    },
    {
        "school": "Calvin Coolidge School",
        "district": "Hillside Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340729005542",
    },
    {
        "school": "Hurden Looker School",
        "district": "Hillside Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340729005544",
    },
    {
        "school": "Walter O. Krumbiegel Middle School",
        "district": "Hillside Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340729005546",
    },
    {
        "school": "A.P. Morris Early Childhood Center",
        "district": "Hillside Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340729005548",
    },
    {
        "school": "George Washington School",
        "district": "Hillside Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340729005550",
    },
    {
        "school": "David Brearley Middle/High School",
        "district": "Kenilworth School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340792000209",
    },
    {
        "school": "Warren G. Harding Elementary School",
        "district": "Kenilworth School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340792005552",
    },
    {
        "school": "Linden High School",
        "district": "Linden Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340861005556",
    },
    {
        "school": "Myles J. McManus MIddle School",
        "district": "Linden Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340861005558",
    },
    {
        "school": "Joseph E. Soehl Middle School",
        "district": "Linden Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340861005560",
    },
    {
        "school": "Number 1",
        "district": "Linden Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340861005562",
    },
    {
        "school": "Number 2",
        "district": "Linden Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340861005564",
    },
    {
        "school": "Number 4",
        "district": "Linden Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340861005570",
    },
    {
        "school": "Number 5",
        "district": "Linden Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340861005572",
    },
    {
        "school": "Number 6",
        "district": "Linden Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340861005574",
    },
    {
        "school": "Number 8",
        "district": "Linden Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340861005578",
    },
    {
        "school": "Number 9",
        "district": "Linden Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340861005580",
    },
    {
        "school": "Number 10",
        "district": "Linden Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340861005582",
    },
    {
        "school": "Deerfield Elementary School",
        "district": "MOUNTAINSIDE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341104005588",
    },
    {
        "school": "New Providence High School",
        "district": "New Providence School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341131005592",
    },
    {
        "school": "Allen W. Roberts School",
        "district": "New Providence School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341131005594",
    },
    {
        "school": "Salt Brook School",
        "district": "New Providence School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341131005600",
    },
    {
        "school": "New Providence Middle School",
        "district": "New Providence School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341131006097",
    },
    {
        "school": "Plainfield High School",
        "district": "Plainfield Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005604",
    },
    {
        "school": "Hubbard Middle School",
        "district": "Plainfield Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005606",
    },
    {
        "school": "Maxson Middle School",
        "district": "Plainfield Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005608",
    },
    {
        "school": "Dewitt D. Barlow Elementary School",
        "district": "Plainfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005610",
    },
    {
        "school": "Cedarbrook Elementary School",
        "district": "Plainfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005612",
    },
    {
        "school": "Clinton Elementary School",
        "district": "Plainfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005614",
    },
    {
        "school": "Frederic W. Cook Elementary School",
        "district": "Plainfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005616",
    },
    {
        "school": "Emerson Elementary School",
        "district": "Plainfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005618",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Plainfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005620",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Plainfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005622",
    },
    {
        "school": "Charles H. Stillman Elementary School",
        "district": "Plainfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005626",
    },
    {
        "school": "Washington Community School",
        "district": "Plainfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314005628",
    },
    {
        "school": "Rahway High School",
        "district": "Rahway Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341353005634",
    },
    {
        "school": "Rahway 7th & 8th Grade Academy",
        "district": "Rahway Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341353005636",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Rahway Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341353005640",
    },
    {
        "school": "Grover Cleveland Elementary School",
        "district": "Rahway Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341353005642",
    },
    {
        "school": "Madison Elementary",
        "district": "Rahway Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341353005644",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Rahway Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341353005646",
    },
    {
        "school": "Abraham Clark High School",
        "district": "ROSELLE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341428005650",
    },
    {
        "school": "Harrison Elementary School",
        "district": "ROSELLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341428005652",
    },
    {
        "school": "Dr. Charles C. Polk School",
        "district": "ROSELLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341428005654",
    },
    {
        "school": "Leonard V Moore Middle School",
        "district": "ROSELLE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341428005656",
    },
    {
        "school": "Washington Elementary School",
        "district": "ROSELLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341428005658",
    },
    {
        "school": "Grace Wilday Junior High School",
        "district": "ROSELLE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341428005660",
    },
    {
        "school": "Roselle Park High School",
        "district": "Roselle Park Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341431005664",
    },
    {
        "school": "Ernest J. Finizio Jr. - Aldene School",
        "district": "Roselle Park Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341431005666",
    },
    {
        "school": "Robert Gordon Elementary School",
        "district": "Roselle Park Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341431005668",
    },
    {
        "school": "Roselle Park Middle School",
        "district": "Roselle Park Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341431005670",
    },
    {
        "school": "Sherman Elementary School",
        "district": "Roselle Park Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341431005672",
    },
    {
        "school": "Scotch Plains-Fanwood High School",
        "district": "Scotch Plains-Fanwood School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341467005676",
    },
    {
        "school": "Park Middle School",
        "district": "Scotch Plains-Fanwood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341467005678",
    },
    {
        "school": "Terrill Middle School",
        "district": "Scotch Plains-Fanwood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341467005680",
    },
    {
        "school": "School One Elementary",
        "district": "Scotch Plains-Fanwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341467005682",
    },
    {
        "school": "Howard B. Brunner Elementary School",
        "district": "Scotch Plains-Fanwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341467005684",
    },
    {
        "school": "J. Ackerman Coles Elementary School",
        "district": "Scotch Plains-Fanwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341467005686",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Scotch Plains-Fanwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341467005688",
    },
    {
        "school": "William J. McGinn Elementary School",
        "district": "Scotch Plains-Fanwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341467005692",
    },
    {
        "school": "Jonathan Dayton High School",
        "district": "Springfield Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341563000213",
    },
    {
        "school": "Florence M. Gaudineer Middle School",
        "district": "Springfield Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341563005700",
    },
    {
        "school": "James Caldwell Elementary School",
        "district": "Springfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341563005702",
    },
    {
        "school": "Thelma L. Sandmeier Elementary School",
        "district": "Springfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341563005704",
    },
    {
        "school": "Edward V. Walton Primary School",
        "district": "Springfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341563006036",
    },
    {
        "school": "Summit High School",
        "district": "Summit Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341590005708",
    },
    {
        "school": "Lawton C. Johnson Summit Middle School",
        "district": "Summit Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341590005710",
    },
    {
        "school": "Brayton Elementary School",
        "district": "Summit Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341590005712",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Summit Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341590005714",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Summit Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341590005716",
    },
    {
        "school": "Lincoln-Hubbard Elementary School",
        "district": "Summit Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341590005718",
    },
    {
        "school": "Washington Elementary School",
        "district": "Summit Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341590005722",
    },
    {
        "school": "Crossroads School",
        "district": "Union County Educational Services Commission",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341640000469",
    },
    {
        "school": "Westlake",
        "district": "Union County Educational Services Commission",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341640005726",
    },
    {
        "school": "Lamberts Mill Academy",
        "district": "Union County Educational Services Commission",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341640005988",
    },
    {
        "school": "Hillcrest Academy-North",
        "district": "Union County Educational Services Commission",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "341640006008",
    },
    {
        "school": "Hannah Caldwell Elementary",
        "district": "Township of Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341650000247",
    },
    {
        "school": "Union High School",
        "district": "Township of Union School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341650005742",
    },
    {
        "school": "Burnet Middle School",
        "district": "Township of Union School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341650005744",
    },
    {
        "school": "Kawameeh Middle School",
        "district": "Township of Union School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341650005746",
    },
    {
        "school": "Battle Hill Elementary",
        "district": "Township of Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341650005748",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Township of Union School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341650005750",
    },
    {
        "school": "Connecticut Farms Elementary",
        "district": "Township of Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341650005752",
    },
    {
        "school": "Franklin Elementary",
        "district": "Township of Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341650005754",
    },
    {
        "school": "Livingston Elementary",
        "district": "Township of Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341650005758",
    },
    {
        "school": "Washington Elementary",
        "district": "Township of Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341650005760",
    },
    {
        "school": "Westfield Senior High School",
        "district": "Westfield Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341776005764",
    },
    {
        "school": "Roosevelt Intermediate School",
        "district": "Westfield Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341776005766",
    },
    {
        "school": "Thomas Edison Intermediate School",
        "district": "Westfield Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341776005768",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Westfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341776005770",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Westfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341776005774",
    },
    {
        "school": "McKinley Elementary School",
        "district": "Westfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341776005778",
    },
    {
        "school": "Tamaques Elementary School",
        "district": "Westfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341776005780",
    },
    {
        "school": "Washington Elementary School",
        "district": "Westfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341776005782",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Westfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341776005784",
    },
    {
        "school": "Winfield Township",
        "district": "Winfield Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341803005786",
    },
    {
        "school": "Union County Magnet High School",
        "district": "Union County Vocational-Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341804000214",
    },
    {
        "school": "Union County Tech",
        "district": "Union County Vocational-Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341804005738",
    },
    {
        "school": "Dennis Township Elementary/Middle Schools",
        "district": "Dennis Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340384006115",
    },
    {
        "school": "Chartertech High School for the Performing Arts",
        "district": "Chartertech High School for the Performing Arts",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340001900269",
    },
    {
        "school": "Avalon Elementary School",
        "district": "Avalon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340111001702",
    },
    {
        "school": "Cape May City Elementary School",
        "district": "Cape May City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340270001704",
    },
    {
        "school": "Cape May County Technical High SChool",
        "district": "Cape May County Technical High School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340273001712",
    },
    {
        "school": "Cape May County High School",
        "district": "Cape May County Special Services School District",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340274001708",
    },
    {
        "school": "Ocean Academy",
        "district": "Cape May County Special Services School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340274001710",
    },
    {
        "school": "Dennis Township Primary School",
        "district": "Dennis Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340384001716",
    },
    {
        "school": "Lower Cape May Regional High School",
        "district": "Lower Cape May Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340909001720",
    },
    {
        "school": "Richard M. Teitelman Middle School",
        "district": "Lower Cape May Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340909001722",
    },
    {
        "school": "Sandman Consolidated School",
        "district": "Lower Township Elementary School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340915001726",
    },
    {
        "school": "Maud Abrams School",
        "district": "Lower Township Elementary School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340915001728",
    },
    {
        "school": "David C. Douglass Memorial School",
        "district": "Lower Township Elementary School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340915005909",
    },
    {
        "school": "Carl T. Mitnick School",
        "district": "Lower Township Elementary School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340915006054",
    },
    {
        "school": "Middle Township Elementary #2",
        "district": "Middle Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341002000033",
    },
    {
        "school": "Middle Township High School",
        "district": "Middle Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341002001732",
    },
    {
        "school": "Middle Township Elementary #1",
        "district": "Middle Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341002001734",
    },
    {
        "school": "Middle Township Elementary #4",
        "district": "Middle Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341002001738",
    },
    {
        "school": "Margaret Mace Elementary School",
        "district": "North Wildwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341167001742",
    },
    {
        "school": "Ocean City High School",
        "district": "Ocean City School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341197001746",
    },
    {
        "school": "Ocean City Intermediate School",
        "district": "Ocean City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341197001748",
    },
    {
        "school": "Ocean City Primary School",
        "district": "Ocean City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341197001750",
    },
    {
        "school": "Stone Harbor Elementary School",
        "district": "Stone Harbor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341581001754",
    },
    {
        "school": "Upper Township Middle School",
        "district": "Upper Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341665001758",
    },
    {
        "school": "Upper Township Elementary School",
        "district": "Upper Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341665001760",
    },
    {
        "school": "Upper Township Primary School",
        "district": "Upper Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341665006104",
    },
    {
        "school": "West Cape May Elementary School",
        "district": "WEST CAPE MAY ELEMENTARY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341740001762",
    },
    {
        "school": "Wildwood High School",
        "district": "Wildwood City School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341794001768",
    },
    {
        "school": "Glenwood Avenue Elementary School",
        "district": "Wildwood City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341794001770",
    },
    {
        "school": "Wildwood Middle School",
        "district": "Wildwood City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341794006039",
    },
    {
        "school": "Crest Memorial School",
        "district": "WILDWOOD CREST BOROUGH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341797001776",
    },
    {
        "school": "Woodbine Elementary School",
        "district": "Woodbine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341809001780",
    },
    {
        "school": "Seneca High School",
        "district": "Lenape Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340849000701",
    },
    {
        "school": "Mansfield Township Elementary School",
        "district": "Mansfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340951000704",
    },
    {
        "school": "Kirby's Mill Elementary School",
        "district": "Medford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340987000540",
    },
    {
        "school": "Chairville Elementary School",
        "district": "Medford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340987006113",
    },
    {
        "school": "Environment Community Opportunity (ECO) Charter School",
        "district": "Environment Community Opportunity (ECO) Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340007906129",
    },
    {
        "school": "Freedom Prep Charter School",
        "district": "Freedom Prep Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340008000566",
    },
    {
        "school": "Camden Big Picture Learning Academy",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264000579",
    },
    {
        "school": "Octavio V. Catto Community Family School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264000793",
    },
    {
        "school": "William G. Rohrer Middle School",
        "district": "HADDON TOWNSHIP SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340636000707",
    },
    {
        "school": "Pennsauken Intermediate School",
        "district": "Pennsauken Township Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341287000493",
    },
    {
        "school": "Central Early Childhood Center",
        "district": "Deptford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340390000708",
    },
    {
        "school": "Governor Charles C. Stratton",
        "district": "SWEDESBORO-WOOLWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341599000709",
    },
    {
        "school": "BASS RIVER TOWNSHIP ELEMENTARY SCHOOL",
        "district": "Bass River Township Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340120000950",
    },
    {
        "school": "Beverly City School District",
        "district": "BEVERLY CITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340174000952",
    },
    {
        "school": "Bordentown Regional High School",
        "district": "Bordentown Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340203000960",
    },
    {
        "school": "Clara Barton Elementary",
        "district": "Bordentown Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340203005925",
    },
    {
        "school": "Mac Farland Intermediate",
        "district": "Bordentown Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340203005926",
    },
    {
        "school": "Peter Muschal Elementary",
        "district": "Bordentown Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340203005927",
    },
    {
        "school": "Burlington City High School",
        "district": "Burlington City Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340243000966",
    },
    {
        "school": "Captain James Lawrence Elementary School",
        "district": "Burlington City Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340243000968",
    },
    {
        "school": "Samuel Smith Elementary School",
        "district": "Burlington City Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340243000974",
    },
    {
        "school": "Wilbur Watts Intermediate School",
        "district": "Burlington City Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340243000976",
    },
    {
        "school": "Lumberton Campus",
        "district": "Burlington County Special Services School District",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340244000121",
    },
    {
        "school": "Westampton Campus",
        "district": "Burlington County Special Services School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340244000982",
    },
    {
        "school": "Fountain Woods Elementary School",
        "district": "Burlington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340246000260",
    },
    {
        "school": "Burlington Township High School",
        "district": "Burlington Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340246001004",
    },
    {
        "school": "B. Bernice Young Elementary School",
        "district": "Burlington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340246001010",
    },
    {
        "school": "Burlington County Institute of Technology - Westampton",
        "district": "Burlington County Institute of Technology School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340249000996",
    },
    {
        "school": "Burlington County Institute of Technology - Medford",
        "district": "Burlington County Institute of Technology School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340249000998",
    },
    {
        "school": "Cinnaminson High School",
        "district": "Cinnaminson Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340312001020",
    },
    {
        "school": "Cinnaminson Middle School",
        "district": "Cinnaminson Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340312001024",
    },
    {
        "school": "New Albany Elementary School",
        "district": "Cinnaminson Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340312001026",
    },
    {
        "school": "Eleanor Rush Intermediate School",
        "district": "Cinnaminson Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340312001028",
    },
    {
        "school": "M. Joan Pearson Elementary School",
        "district": "Delanco Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340369001032",
    },
    {
        "school": "Walnut Street School",
        "district": "Delanco Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340369001036",
    },
    {
        "school": "Delran Intermediate School",
        "district": "Delran Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340378000123",
    },
    {
        "school": "Delran High School",
        "district": "Delran Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340378001040",
    },
    {
        "school": "Delran Middle School",
        "district": "Delran Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340378001042",
    },
    {
        "school": "Millbridge Elementary School",
        "district": "Delran Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340378001050",
    },
    {
        "school": "Eastampton Township Community School",
        "district": "Eastampton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340435001056",
    },
    {
        "school": "Mildred Magowan Elementary School",
        "district": "Edgewater Park Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340447001062",
    },
    {
        "school": "Samuel M Ridgway Middle School",
        "district": "Edgewater Park Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340447001064",
    },
    {
        "school": "Frances DeMasi Elementary School",
        "district": "Evesham Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340489000056",
    },
    {
        "school": "Frances DeMasi Middle School",
        "district": "Evesham Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340489000057",
    },
    {
        "school": "Marlton Elementary",
        "district": "Evesham Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340489000058",
    },
    {
        "school": "Helen L Beeler",
        "district": "Evesham Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340489001070",
    },
    {
        "school": "J Harold Van Zant",
        "district": "Evesham Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340489001072",
    },
    {
        "school": "Marlton Middle",
        "district": "Evesham Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340489001074",
    },
    {
        "school": "Robert B Jaggard School",
        "district": "Evesham Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340489001076",
    },
    {
        "school": "Richard L Rice School",
        "district": "Evesham Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340489006065",
    },
    {
        "school": "Florence Township Memorial High School",
        "district": "Florence Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340522001082",
    },
    {
        "school": "Roebling Elementary School",
        "district": "Florence Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340522001086",
    },
    {
        "school": "Florence Riverfront School",
        "district": "Florence Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340522006066",
    },
    {
        "school": "Hainesport Township School",
        "district": "Hainesport Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340642001088",
    },
    {
        "school": "Cherokee High School",
        "district": "Lenape Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340849001092",
    },
    {
        "school": "Lenape High School",
        "district": "Lenape Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340849001094",
    },
    {
        "school": "Shawnee High School",
        "district": "Lenape Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340849001096",
    },
    {
        "school": "Bobby's Run Elementary School",
        "district": "Lumberton Township Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340918000222",
    },
    {
        "school": "Florence L. Walther School",
        "district": "Lumberton Township Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340918001098",
    },
    {
        "school": "Lumberton Middle School",
        "district": "Lumberton Township Board of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340918006092",
    },
    {
        "school": "John Hydock Elementary School",
        "district": "Mansfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340951001100",
    },
    {
        "school": "Maple Shade High School",
        "district": "Maple Shade School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340966001104",
    },
    {
        "school": "Maude M. Wilkins Elementary School",
        "district": "Maple Shade School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340966001106",
    },
    {
        "school": "Howard R. Yocum Elementary School",
        "district": "Maple Shade School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340966001108",
    },
    {
        "school": "Ralph J. Steinhauer Elementary School",
        "district": "Maple Shade School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340966001110",
    },
    {
        "school": "Neeta School",
        "district": "Medford Lakes School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340984001114",
    },
    {
        "school": "Nokomis School",
        "district": "Medford Lakes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340984001116",
    },
    {
        "school": "Cranberry Pines Elementary",
        "district": "Medford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340987001120",
    },
    {
        "school": "Haines Sixth Grade Center",
        "district": "Medford Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340987001122",
    },
    {
        "school": "Medford Memorial Middle School",
        "district": "Medford Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340987001124",
    },
    {
        "school": "Milton H. Allen Elementary School",
        "district": "Medford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340987001126",
    },
    {
        "school": "Taunton Forge Elementary School",
        "district": "Medford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340987001128",
    },
    {
        "school": "Moorestown Upper Elementary School",
        "district": "Moorestown Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341071000421",
    },
    {
        "school": "Moorestown High School",
        "district": "Moorestown Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341071001132",
    },
    {
        "school": "George C. Baker Elementary School",
        "district": "Moorestown Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341071001134",
    },
    {
        "school": "Mary E. Roberts Elementary School",
        "district": "Moorestown Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341071001138",
    },
    {
        "school": "William Allen Middle School",
        "district": "Moorestown Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341071001140",
    },
    {
        "school": "South Valley Elementary School",
        "district": "Moorestown Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341071001142",
    },
    {
        "school": "John Brainerd Elementary School",
        "district": "Mount Holly Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341092001148",
    },
    {
        "school": "Gertrude C. Folwell Elementary School",
        "district": "Mount Holly Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341092001150",
    },
    {
        "school": "F. W. Holbein Middle School",
        "district": "Mount Holly Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341092001152",
    },
    {
        "school": "Hartford Upper Elementary School",
        "district": "Mount Laurel Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341095000125",
    },
    {
        "school": "Springville Elementary School",
        "district": "Mount Laurel Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341095000423",
    },
    {
        "school": "Countryside Elementary School",
        "district": "Mount Laurel Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341095001156",
    },
    {
        "school": "Fleetwood Elementary School",
        "district": "Mount Laurel Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341095001158",
    },
    {
        "school": "Hillside Elementary School",
        "district": "Mount Laurel Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341095001160",
    },
    {
        "school": "T. E. Harrington Middle School",
        "district": "Mount Laurel Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341095001164",
    },
    {
        "school": "Parkway Elementary School",
        "district": "Mount Laurel Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341095001166",
    },
    {
        "school": "Larchmont Elementary School",
        "district": "Mount Laurel Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341095006070",
    },
    {
        "school": "New Hanover Township School",
        "district": "New Hanover Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341125001168",
    },
    {
        "school": "Clarence B. Lamb Elementary School",
        "district": "North Hanover Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341158001178",
    },
    {
        "school": "Northern Burlington County Regional High School",
        "district": "Northern Burlington County Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341170001182",
    },
    {
        "school": "Northern Burlington County Regional Middle School",
        "district": "Northern Burlington County Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341170001184",
    },
    {
        "school": "Palmyra High School",
        "district": "Palmyra Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341239001188",
    },
    {
        "school": "Charles Street School",
        "district": "Palmyra Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341239001190",
    },
    {
        "school": "Helen A. Fort Middle School",
        "district": "Pemberton Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341281001200",
    },
    {
        "school": "Pemberton Township High School",
        "district": "Pemberton Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341281001202",
    },
    {
        "school": "Howard L. Emmons",
        "district": "Pemberton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341281001208",
    },
    {
        "school": "Harker-Wylie School",
        "district": "Pemberton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341281001210",
    },
    {
        "school": "Fort Dix Elementary School",
        "district": "Pemberton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341281001216",
    },
    {
        "school": "Alexander Denbo",
        "district": "Pemberton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341281001220",
    },
    {
        "school": "Samuel T. Busansky School",
        "district": "Pemberton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341281001222",
    },
    {
        "school": "Joseph S. Stackhouse School",
        "district": "Pemberton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341281001224",
    },
    {
        "school": "Rancocas Valley Regional High School",
        "district": "Rancocas Valley Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341362001230",
    },
    {
        "school": "Riverside Middle School",
        "district": "Riverside Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341401000085",
    },
    {
        "school": "Riverside High School",
        "district": "Riverside Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341401001234",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Riverside Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341401001236",
    },
    {
        "school": "Riverton School District",
        "district": "Riverton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341404001238",
    },
    {
        "school": "Indian Mills Elementary School",
        "district": "Shamong Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341488001240",
    },
    {
        "school": "Indian Mills Memorial School",
        "district": "Shamong Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341488006103",
    },
    {
        "school": "Southampton Township School #3",
        "district": "Southampton Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341542000127",
    },
    {
        "school": "Southampton Township School #1",
        "district": "Southampton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341542001242",
    },
    {
        "school": "Southampton Township School #2",
        "district": "Southampton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341542006035",
    },
    {
        "school": "Springfield Township School",
        "district": "Springfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341566001244",
    },
    {
        "school": "Tabernacle Elementary School",
        "district": "Tabernacle Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341602001250",
    },
    {
        "school": "Kenneth R. Olson Middle School",
        "district": "Tabernacle Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341602005946",
    },
    {
        "school": "Holly Hills Elementary School",
        "district": "Westampton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341773001256",
    },
    {
        "school": "Westampton Township Middle School",
        "district": "Westampton Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341773001258",
    },
    {
        "school": "Willingboro High School",
        "district": "Willingboro Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341800001264",
    },
    {
        "school": "Hawthorne Park Elementary School",
        "district": "Willingboro Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341800001276",
    },
    {
        "school": "W. R. James Sr. Elementary School",
        "district": "Willingboro Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341800001282",
    },
    {
        "school": "Twin Hills Elementary School",
        "district": "Willingboro Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341800001288",
    },
    {
        "school": "Willingboro Memorial Middle School",
        "district": "Willingboro Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341800006108",
    },
    {
        "school": "Chatsworth Elementary School",
        "district": "Woodland Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341824001294",
    },
    {
        "school": "Leap Academy University Charter School",
        "district": "LEAP Academy University Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340007800487",
    },
    {
        "school": "Audubon Junior/Senior High School",
        "district": "Audubon Public School Disrict",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340105001298",
    },
    {
        "school": "Haviland Avenue School",
        "district": "Audubon Public School Disrict",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340105001300",
    },
    {
        "school": "Mansion Avenue School",
        "district": "Audubon Public School Disrict",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340105001302",
    },
    {
        "school": "Avon Elementary School",
        "district": "BARRINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340117001308",
    },
    {
        "school": "Woodland Middle School",
        "district": "BARRINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340117001312",
    },
    {
        "school": "Bell Oaks Upper Elementary School",
        "district": "Bellmawr Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340138001316",
    },
    {
        "school": "Bellmawr Park Elementary School",
        "district": "Bellmawr Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340138001318",
    },
    {
        "school": "Ethel M Burke Elementary School",
        "district": "Bellmawr Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340138001320",
    },
    {
        "school": "Berlin Community School",
        "district": "Berlin Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340159001324",
    },
    {
        "school": "Dwight D Eisenhower Middle School",
        "district": "Berlin Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340162001328",
    },
    {
        "school": "John F Kennedy Elementary School",
        "district": "Berlin Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340162001332",
    },
    {
        "school": "Timber Creek Regional High School",
        "district": "Black Horse Pike Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340177000425",
    },
    {
        "school": "Highland Regional High School",
        "district": "Black Horse Pike Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340177001336",
    },
    {
        "school": "Triton Regional High School",
        "district": "Black Horse Pike Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340177001338",
    },
    {
        "school": "Alice Costello Elementary School",
        "district": "Brooklawn Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340237001340",
    },
    {
        "school": "Dr. Charles E. Brimm Medical Arts High School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264000087",
    },
    {
        "school": "Early Childhood Development Center",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001344",
    },
    {
        "school": "Camden High School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001346",
    },
    {
        "school": "Woodrow Wilson High School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001348",
    },
    {
        "school": "Veterans Memorial Family School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001354",
    },
    {
        "school": "Cooper's Poynt Family School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001364",
    },
    {
        "school": "Alfred Cramer College Preparatory Lab School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001366",
    },
    {
        "school": "Dr. Henry H. Davis Elementary School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001368",
    },
    {
        "school": "Forest Hill School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001374",
    },
    {
        "school": "Creative Arts Morgan Village Academy",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001384",
    },
    {
        "school": "Harry C. Sharp Elementary School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001394",
    },
    {
        "school": "Dr. Ulysses S. Wiggins College Preparatory Lab Schoo",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001400",
    },
    {
        "school": "Henry B. Wilson Family School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001406",
    },
    {
        "school": "Yorkship Elementary School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264001408",
    },
    {
        "school": "Riletta Twyne Cream Family School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264006084",
    },
    {
        "school": "Camden County Technical School-Pennsauken",
        "district": "Camden County Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340267001412",
    },
    {
        "school": "Camden County Technical School-GTC",
        "district": "Camden County Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340267001414",
    },
    {
        "school": "Sterling High School",
        "district": "Sterling Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340288001662",
    },
    {
        "school": "Alternative High School",
        "district": "Cherry Hill School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300000223",
    },
    {
        "school": "Barclay Early Childhood Center",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300000263",
    },
    {
        "school": "Rosa International Middle School",
        "district": "Cherry Hill School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300000265",
    },
    {
        "school": "Cherry Hill High School East",
        "district": "Cherry Hill School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001418",
    },
    {
        "school": "Cherry Hill High School West",
        "district": "Cherry Hill School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001420",
    },
    {
        "school": "A. Russell Knight Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001422",
    },
    {
        "school": "John A. Carusi Middle School",
        "district": "Cherry Hill School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001426",
    },
    {
        "school": "Bret Harte Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001428",
    },
    {
        "school": "Clara Barton Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001430",
    },
    {
        "school": "Henry C. Beck Middle School",
        "district": "Cherry Hill School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001436",
    },
    {
        "school": "Horace Mann Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001440",
    },
    {
        "school": "James F. Cooper Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001444",
    },
    {
        "school": "James Johnson Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001446",
    },
    {
        "school": "Joseph D. Sharp Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001450",
    },
    {
        "school": "Joyce Kilmer Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001452",
    },
    {
        "school": "Kingston Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001454",
    },
    {
        "school": "Richard Stockton Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001456",
    },
    {
        "school": "Thomas Paine Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001458",
    },
    {
        "school": "Woodcrest Elementary School",
        "district": "Cherry Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340300001462",
    },
    {
        "school": "Clementon Elementary School",
        "district": "Clementon Elementary School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340324005899",
    },
    {
        "school": "Collingswood High School",
        "district": "Collingswood Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340342001474",
    },
    {
        "school": "Collingswood Middle School",
        "district": "Collingswood Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340342001476",
    },
    {
        "school": "James A. Garfield Elementary School",
        "district": "Collingswood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340342001478",
    },
    {
        "school": "Mark Newbie Elementary School",
        "district": "Collingswood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340342001480",
    },
    {
        "school": "Thomas Sharp Elementary School",
        "district": "Collingswood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340342001482",
    },
    {
        "school": "William P Tatem Elementary School",
        "district": "Collingswood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340342001484",
    },
    {
        "school": "Zane North Elementary School",
        "district": "Collingswood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340342001486",
    },
    {
        "school": "Eastern Regional High School",
        "district": "Eastern Camden County Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340438001488",
    },
    {
        "school": "Gibbsboro Elementary School",
        "district": "Gibbsboro Elementary School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340585001490",
    },
    {
        "school": "Cold Springs School",
        "district": "GLOUCESTER CITY PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340600000129",
    },
    {
        "school": "Gloucester City Jr. Sr. High School",
        "district": "GLOUCESTER CITY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340600001494",
    },
    {
        "school": "Ann A. Mullen Middle School",
        "district": "Gloucester Township Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340603000131",
    },
    {
        "school": "Union Valley Elementary School",
        "district": "Gloucester Township Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340603000428",
    },
    {
        "school": "Blackwood Elementary School",
        "district": "Gloucester Township Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340603001508",
    },
    {
        "school": "Charles W. Lewis Middle School",
        "district": "Gloucester Township Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340603001510",
    },
    {
        "school": "Chews Elementary School",
        "district": "Gloucester Township Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340603001512",
    },
    {
        "school": "Erial Elementary School",
        "district": "Gloucester Township Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340603001514",
    },
    {
        "school": "Glen Landing Middle School",
        "district": "Gloucester Township Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340603001516",
    },
    {
        "school": "Glendora Elementary School",
        "district": "Gloucester Township Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340603001518",
    },
    {
        "school": "Gloucester Township Elementary School",
        "district": "Gloucester Township Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340603001520",
    },
    {
        "school": "Loring Flemming Elementary School",
        "district": "Gloucester Township Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340603001524",
    },
    {
        "school": "James W. Lilley Jr. Elementary School",
        "district": "Gloucester Township Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340603005995",
    },
    {
        "school": "Haddon Heights Jr./Sr. High School",
        "district": "HADDON HEIGHTS School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340633001528",
    },
    {
        "school": "Glenview Avenue",
        "district": "HADDON HEIGHTS School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340633001530",
    },
    {
        "school": "Atlantic Avenue",
        "district": "HADDON HEIGHTS School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340633001534",
    },
    {
        "school": "Seventh Avenue",
        "district": "HADDON HEIGHTS School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340633001536",
    },
    {
        "school": "Haddon Township High School",
        "district": "HADDON TOWNSHIP SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340636001540",
    },
    {
        "school": "Thomas A. Edison Elementary School",
        "district": "HADDON TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340636001542",
    },
    {
        "school": "Clyde S. Jennings Elementary School",
        "district": "HADDON TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340636001544",
    },
    {
        "school": "Stoy Elementary School",
        "district": "HADDON TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340636001546",
    },
    {
        "school": "Strawbridge Elementary School",
        "district": "HADDON TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340636001548",
    },
    {
        "school": "Van Sciver Elementary School",
        "district": "HADDON TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340636001550",
    },
    {
        "school": "Haddonfield Memorial High School",
        "district": "Haddonfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340639001554",
    },
    {
        "school": "Central School",
        "district": "Haddonfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340639001556",
    },
    {
        "school": "Haddonfield Middle School",
        "district": "Haddonfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340639001558",
    },
    {
        "school": "Elizabeth Haddon School",
        "district": "Haddonfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340639001560",
    },
    {
        "school": "J. Fithian Tatem School",
        "district": "Haddonfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340639001562",
    },
    {
        "school": "Laurel Springs School",
        "district": "LAUREL SPRINGS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340828001566",
    },
    {
        "school": "Lawnside School",
        "district": "Lawnside School Distric",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340834001572",
    },
    {
        "school": "Lindenwold High School",
        "district": "Lindenwold Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340864000429",
    },
    {
        "school": "Lindenwold Middle School",
        "district": "Lindenwold Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340864000431",
    },
    {
        "school": "Lindenwold School Four",
        "district": "Lindenwold Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340864001578",
    },
    {
        "school": "Lindenwold School Five",
        "district": "Lindenwold Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340864001580",
    },
    {
        "school": "Magnolia",
        "district": "Magnolia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340930001592",
    },
    {
        "school": "Merchantville Elementary School",
        "district": "Merchantville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340996001594",
    },
    {
        "school": "Raymond W. Kershaw School",
        "district": "Mt. Ephraim School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341089001598",
    },
    {
        "school": "Mary Bray Elementary School",
        "district": "Mt. Ephraim School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341089001600",
    },
    {
        "school": "Oaklyn Public School",
        "district": "Oaklyn Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341194001604",
    },
    {
        "school": "Pennsauken High School",
        "district": "Pennsauken Township Board of Education School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341287001610",
    },
    {
        "school": "Howard M. Phifer Middle School",
        "district": "Pennsauken Township Board of Education School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341287001612",
    },
    {
        "school": "Baldwin Elementary School",
        "district": "Pennsauken Township Board of Education School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341287001622",
    },
    {
        "school": "Benjamin Franklin Elementary School",
        "district": "Pennsauken Township Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341287001624",
    },
    {
        "school": "Delair Elementary School",
        "district": "Pennsauken Township Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341287001630",
    },
    {
        "school": "G.H. Carson Elementary School",
        "district": "Pennsauken Township Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341287001632",
    },
    {
        "school": "George",
        "district": "Pennsauken Township Board of Education School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341287001634",
    },
    {
        "school": "Overbrook Senior High School",
        "district": "PINE HILL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341299000432",
    },
    {
        "school": "Pine Hill Middle School",
        "district": "PINE HILL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341299000433",
    },
    {
        "school": "Dr. Albert M. Bean School",
        "district": "PINE HILL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341299001642",
    },
    {
        "school": "John H. Glenn School",
        "district": "PINE HILL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341299001644",
    },
    {
        "school": "Aline Bingham Elementary School",
        "district": "RUNNEMEDE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341443001650",
    },
    {
        "school": "Grade Downing Elementary School",
        "district": "RUNNEMEDE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341443001652",
    },
    {
        "school": "Mary E. Volz Elementary School",
        "district": "RUNNEMEDE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341443001654",
    },
    {
        "school": "Somerdale Park School",
        "district": "SOMERDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341500001660",
    },
    {
        "school": "Parkivew Elementary School",
        "district": "Stratford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341587001666",
    },
    {
        "school": "Samuel S. Yellin Elementary School",
        "district": "Stratford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341587001670",
    },
    {
        "school": "Edward T. Hamilton",
        "district": "Voorhees Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341683001676",
    },
    {
        "school": "Kresson School",
        "district": "Voorhees Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341683001678",
    },
    {
        "school": "Osage School",
        "district": "Voorhees Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341683001680",
    },
    {
        "school": "Voorhees Middle School",
        "district": "Voorhees Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341683001682",
    },
    {
        "school": "Signal Hill School",
        "district": "Voorhees Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341683006061",
    },
    {
        "school": "Atco Elementary School",
        "district": "WATERFORD TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341725001686",
    },
    {
        "school": "Thomas Richards Elementary School",
        "district": "WATERFORD TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341725005924",
    },
    {
        "school": "Waterford Elementary School",
        "district": "WATERFORD TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341725006011",
    },
    {
        "school": "Winslow Township Elementary School Six",
        "district": "Winslow Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341806000060",
    },
    {
        "school": "Winslow Township High School",
        "district": "Winslow Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341806000437",
    },
    {
        "school": "Winslow Township Middle School",
        "district": "Winslow Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341806000439",
    },
    {
        "school": "Winslow Township Elementary School One",
        "district": "Winslow Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341806001692",
    },
    {
        "school": "Winslow Township Elementary School Two",
        "district": "Winslow Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341806001694",
    },
    {
        "school": "Winslow Township Elementary School Three",
        "district": "Winslow Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341806001696",
    },
    {
        "school": "Winslow Township Elementary School Four",
        "district": "Winslow Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341806001698",
    },
    {
        "school": "Winslow Township Elementary School Five",
        "district": "Winslow Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341806006062",
    },
    {
        "school": "Woodlynne Boro Public School",
        "district": "Woodlynne School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341827001700",
    },
    {
        "school": "Clayton High School",
        "district": "Clayton Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340318002498",
    },
    {
        "school": "Herma S. Simmons Elementary School",
        "district": "Clayton Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340318002500",
    },
    {
        "school": "Clayton Middle School",
        "district": "Clayton Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340318002502",
    },
    {
        "school": "Clearview Regional High School",
        "district": "Clearview Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340321002506",
    },
    {
        "school": "Clearview Regional Middle School",
        "district": "Clearview Regional High School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340321002508",
    },
    {
        "school": "Deptford Township High School",
        "district": "Deptford Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340390002512",
    },
    {
        "school": "Monongahela Middle School",
        "district": "Deptford Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340390002514",
    },
    {
        "school": "Good Intent Elementary School",
        "district": "Deptford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340390002518",
    },
    {
        "school": "Lake Tract Elementary School",
        "district": "Deptford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340390002520",
    },
    {
        "school": "Oak Valley Elementary School",
        "district": "Deptford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340390002524",
    },
    {
        "school": "Pine Acres Early Childhood Center",
        "district": "Deptford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340390002526",
    },
    {
        "school": "Shady Lane Elementary School",
        "district": "Deptford Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340390002528",
    },
    {
        "school": "Samuel Mickle School",
        "district": "East Greenwich Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340414000007",
    },
    {
        "school": "Jeffrey Clark School",
        "district": "East Greenwich Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340414000063",
    },
    {
        "school": "Aura Elementary School",
        "district": "Elk Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340462002538",
    },
    {
        "school": "Caroline L. Reutter School",
        "district": "Township of Franklin School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340543002544",
    },
    {
        "school": "Mary F. Janvier School",
        "district": "Township of Franklin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340543002546",
    },
    {
        "school": "Main Road School",
        "district": "Township of Franklin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340543002550",
    },
    {
        "school": "Gateway Regional High School",
        "district": "Gateway Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340582002554",
    },
    {
        "school": "Dorthy L. Bullock School",
        "district": "Glassboro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340588000064",
    },
    {
        "school": "Glassboro High School",
        "district": "Glassboro School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340588002558",
    },
    {
        "school": "Glassboro Intermediate School",
        "district": "Glassboro School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340588002564",
    },
    {
        "school": "J. Harvey Rodgers School",
        "district": "Glassboro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340588002566",
    },
    {
        "school": "Thomas E. Bowe School",
        "district": "Glassboro School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340588002568",
    },
    {
        "school": "Gloucester County Institute of Technology",
        "district": "Gloucester County Vocational-Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340604002570",
    },
    {
        "school": "Broad Street Elementary School",
        "district": "Greenwich Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340618002574",
    },
    {
        "school": "Nehaunsey Middle School",
        "district": "Greenwich Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340618006091",
    },
    {
        "school": "Pleasant Valley School",
        "district": "Harrison Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340690000441",
    },
    {
        "school": "Harrison Township Elementary School",
        "district": "Harrison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340690002578",
    },
    {
        "school": "Kingsway Regional Middle School",
        "district": "Kingsway Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340798000093",
    },
    {
        "school": "Kingsway Regional High School",
        "district": "Kingsway Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340798002580",
    },
    {
        "school": "Center Square School",
        "district": "Logan Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340888000443",
    },
    {
        "school": "Logan Township Elementary School",
        "district": "Logan Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340888002582",
    },
    {
        "school": "Centre City Elementary School",
        "district": "Mantua Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340960002586",
    },
    {
        "school": "J. Mason Tomlin Elementary School",
        "district": "Mantua Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340960002588",
    },
    {
        "school": "Sewell Elementary School",
        "district": "Mantua Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340960002590",
    },
    {
        "school": "Williamstown Middle School",
        "district": "Monroe Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341047000183",
    },
    {
        "school": "Oak Knoll Elementary School",
        "district": "Monroe Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341047000397",
    },
    {
        "school": "Willliamstown High School",
        "district": "Monroe Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341047002594",
    },
    {
        "school": "Holly Glen Elementary School",
        "district": "Monroe Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341047002596",
    },
    {
        "school": "Whitehall Elementary School",
        "district": "Monroe Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341047002600",
    },
    {
        "school": "Radix Elementary",
        "district": "Monroe Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341047005938",
    },
    {
        "school": "National Park School",
        "district": "National Park Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341110002602",
    },
    {
        "school": "Paulsboro High School",
        "district": "Paulsboro School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341272002608",
    },
    {
        "school": "Billingsport Elementary School",
        "district": "Paulsboro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341272002610",
    },
    {
        "school": "Loudenslager Elementary School",
        "district": "Paulsboro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341272002612",
    },
    {
        "school": "Pitman Middle School",
        "district": "Pitman Boro School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341308000095",
    },
    {
        "school": "Pitman High School",
        "district": "Pitman Boro School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341308002616",
    },
    {
        "school": "Elwood Kindle Elementary School",
        "district": "Pitman Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341308002618",
    },
    {
        "school": "Memorial Elementary School",
        "district": "Pitman Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341308002620",
    },
    {
        "school": "W.C.K. Walls Elementary School",
        "district": "Pitman Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341308002626",
    },
    {
        "school": "South Harrison Elementary School",
        "district": "South Harrison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341527002628",
    },
    {
        "school": "Delsea Regional High School",
        "district": "DELSEA REGIONAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341545002630",
    },
    {
        "school": "Delsea Regional Middle School",
        "district": "DELSEA REGIONAL HIGH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341545006060",
    },
    {
        "school": "Margaret C. Clifford School",
        "district": "SWEDESBORO-WOOLWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341599000184",
    },
    {
        "school": "WALTER HILL SCHOOL",
        "district": "SWEDESBORO-WOOLWICH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341599002634",
    },
    {
        "school": "Bunker Hill Middle School",
        "district": "Washington Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341707000185",
    },
    {
        "school": "Washington Township High School",
        "district": "Washington Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341707002640",
    },
    {
        "school": "Bells Elementary School",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341707002644",
    },
    {
        "school": "Birches Elementary School",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341707002646",
    },
    {
        "school": "Hurffville Elementary School",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341707002650",
    },
    {
        "school": "Wedgwood Elementary School",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341707002654",
    },
    {
        "school": "Whitman Elementary School",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341707002656",
    },
    {
        "school": "Thomas Jefferson Elementary School",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341707005922",
    },
    {
        "school": "Grenloch Terrace Early Childhood Center",
        "district": "Washington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341707006038",
    },
    {
        "school": "Chestnut Ridge Middle School",
        "district": "Washington Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341707006075",
    },
    {
        "school": "Orchard Valley Middle School",
        "district": "Washington Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341707006076",
    },
    {
        "school": "Wenonah Elementary School",
        "district": "Wenonah  Boro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341734002658",
    },
    {
        "school": "West Deptford High School",
        "district": "West Deptford Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341743002662",
    },
    {
        "school": "Green-Fields Elementary School",
        "district": "West Deptford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341743002666",
    },
    {
        "school": "Oakview Elementary School",
        "district": "West Deptford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341743002670",
    },
    {
        "school": "Red Bank Elementary School",
        "district": "West Deptford Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341743002672",
    },
    {
        "school": "West Deptford Middle School",
        "district": "West Deptford Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341743002676",
    },
    {
        "school": "Parkview Elementary School",
        "district": "Westville Boro Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341779002684",
    },
    {
        "school": "Woodbury Jr-Sr High School",
        "district": "Woodbury City Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341815002688",
    },
    {
        "school": "Evergreen Avenue Elementary School",
        "district": "Woodbury City Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341815002692",
    },
    {
        "school": "Walnut Street School",
        "district": "Woodbury City Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341815002694",
    },
    {
        "school": "West End Memorial Elementary School",
        "district": "Woodbury City Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341815002696",
    },
    {
        "school": "Woodbury Heights Elementary",
        "district": "Woodbury Heights Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341818002698",
    },
    {
        "school": "Bankbridge Regional School",
        "district": "Gloucester County Special Services School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348036300413",
    },
    {
        "school": "Alloway Township School",
        "district": "Alloway Twp School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340081005028",
    },
    {
        "school": "Elsinboro Township School",
        "district": "Elsinboro Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340468005032",
    },
    {
        "school": "Lower Alloways Creek Elementary School",
        "district": "The Lower Alloways Creek School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340903005034",
    },
    {
        "school": "Pennsville Memorial High School",
        "district": "PENNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340912005064",
    },
    {
        "school": "Pennsville Middle School",
        "district": "PENNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340912005066",
    },
    {
        "school": "Central Park Elementary School",
        "district": "PENNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340912005068",
    },
    {
        "school": "Penn Beach Elementary",
        "district": "PENNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340912005072",
    },
    {
        "school": "Valley Park Elementary School",
        "district": "PENNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340912005076",
    },
    {
        "school": "Mannington Township Elementary School",
        "district": "Mannington Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340948005036",
    },
    {
        "school": "Oldmans Township School",
        "district": "Oldmans Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341221005042",
    },
    {
        "school": "Penns Grove High School",
        "district": "Penns Grove-Carneys Point Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341284005048",
    },
    {
        "school": "Paul W Carleton",
        "district": "Penns Grove-Carneys Point Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341284005052",
    },
    {
        "school": "Field Street School",
        "district": "Penns Grove-Carneys Point Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341284005054",
    },
    {
        "school": "Lafayette - Pershing",
        "district": "Penns Grove-Carneys Point Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341284005056",
    },
    {
        "school": "Penns Grove Middle School",
        "district": "Penns Grove-Carneys Point Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341284005058",
    },
    {
        "school": "Arthur P. Schalick High School",
        "district": "Pittsgrove Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341311005080",
    },
    {
        "school": "Norma Elementary School",
        "district": "Pittsgrove Township School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341311005082",
    },
    {
        "school": "Olivet Elementary School",
        "district": "Pittsgrove Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341311005084",
    },
    {
        "school": "Pittsgrove Township Middle School",
        "district": "Pittsgrove Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341311006056",
    },
    {
        "school": "Quinton Township School",
        "district": "Quinton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341350005086",
    },
    {
        "school": "Salem High School",
        "district": "Salem City School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341455005090",
    },
    {
        "school": "John Fenwick Academy",
        "district": "Salem City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341455005092",
    },
    {
        "school": "Salem Middle School",
        "district": "Salem City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341455005094",
    },
    {
        "school": "Salem County Career and Technical High School",
        "district": "Salem County Vocational Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341458005098",
    },
    {
        "school": "Upper Pittsgrove School",
        "district": "UPPER PITTSGROVE TWP School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341659005110",
    },
    {
        "school": "Woodstown High School",
        "district": "Woodstown-Pilesgrove Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341833005114",
    },
    {
        "school": "Mary S. Shoemaker School",
        "district": "Woodstown-Pilesgrove Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341833005116",
    },
    {
        "school": "Woodstown Middle School",
        "district": "Woodstown-Pilesgrove Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341833005118",
    },
    {
        "school": "Daretown School",
        "district": "Salem County Special Services School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348036106102",
    },
    {
        "school": "Atlantic Regional School",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500741",
    },
    {
        "school": "Bergen Regional School",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500743",
    },
    {
        "school": "Burlington Regional School",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500744",
    },
    {
        "school": "ALBERT C WAGNER CORRECTIONAL FACILITY",
        "district": "OFFICE OF EDUCATIONAL SERVICES DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008800610",
    },
    {
        "school": "DOVES RCH",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008900630",
    },
    {
        "school": "PINELANDS RCH",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008900648",
    },
    {
        "school": "JUVENILE FEMALE SECURE UNIT",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008900657",
    },
    {
        "school": "JUVENILE MEDIUM SECURE FACILITY",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008900659",
    },
    {
        "school": "JUVENILE MEDIUM SECURE FACILITY SOUTH",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008900661",
    },
    {
        "school": "Ancora Psychiatric Hospital",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500694",
    },
    {
        "school": "Camden Virtua",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500739",
    },
    {
        "school": "Cherry Hill Regional School",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500746",
    },
    {
        "school": "Cape May Regional School",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500745",
    },
    {
        "school": "Cumberland Regional School",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500748",
    },
    {
        "school": "NORTHERN STATE PRISON",
        "district": "OFFICE OF EDUCATIONAL SERVICES DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008800603",
    },
    {
        "school": "ESSEX RCH",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008900634",
    },
    {
        "school": "EDNA MAHAN CORRECTIONAL FACILITY FOR WOMEN",
        "district": "OFFICE OF EDUCATIONAL SERVICES DEPARTMENT OF CORRECTIONS",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008800597",
    },
    {
        "school": "MOUNTAINVIEW CORRECTIONAL FACILITY",
        "district": "OFFICE OF EDUCATIONAL SERVICES DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008800600",
    },
    {
        "school": "VOORHEES RCH",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008900653",
    },
    {
        "school": "Ann Klein Forensic Center",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500737",
    },
    {
        "school": "Capital Academy",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500740",
    },
    {
        "school": "Trenton Psychiatric Hospital",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500775",
    },
    {
        "school": "GARDEN STATE CORRECTIONAL FACILITY",
        "district": "OFFICE OF EDUCATIONAL SERVICES DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008800598",
    },
    {
        "school": "NEW JERSEY STATE PRISON",
        "district": "OFFICE OF EDUCATIONAL SERVICES DEPARTMENT OF CORRECTIONS",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008800601",
    },
    {
        "school": "Stony Brook Elementary School",
        "district": "Hopewell Valley Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340753000503",
    },
    {
        "school": "Robbinsville High School",
        "district": "Robbinsville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341710000549",
    },
    {
        "school": "Mercer Elementary School",
        "district": "Mercer County Special Services School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348020006119",
    },
    {
        "school": "ADULT DIAGNOSTIC AND TREATMENT CENTER",
        "district": "OFFICE OF EDUCATIONAL SERVICES DEPARTMENT OF CORRECTIONS",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008800589",
    },
    {
        "school": "NEW JERSEY TRAINING SCHOOL",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008900662",
    },
    {
        "school": "Town Center Elementary School at Plainsboro",
        "district": "West Windsor-Plainsboro Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341770000505",
    },
    {
        "school": "Monmouth Regional School",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500763",
    },
    {
        "school": "Greystone Park Psychiatric Hospital",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500753",
    },
    {
        "school": "Morris Regional School",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500765",
    },
    {
        "school": "Ocean Regional School",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500767",
    },
    {
        "school": "OCEAN RCH",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008900645",
    },
    {
        "school": "Passaic Regional School",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500771",
    },
    {
        "school": "GREEN RCH",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008900637",
    },
    {
        "school": "WARREN REGIONAL SCHOOL",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008500783",
    },
    {
        "school": "International Charter School",
        "district": "International Charter School of Trenton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340004100321",
    },
    {
        "school": "Pace Charter School of Hamilton",
        "district": "Pace Charter School of Hamilton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340004200322",
    },
    {
        "school": "Princeton Charter School",
        "district": "Princeton Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340004300323",
    },
    {
        "school": "The Village Charter School",
        "district": "The Village Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340004600329",
    },
    {
        "school": "Hightstown High School",
        "district": "East Windsor Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340432003054",
    },
    {
        "school": "Ethel McKnight Elementary School",
        "district": "East Windsor Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340432003056",
    },
    {
        "school": "Grace N. Rogers Elementary School",
        "district": "East Windsor Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340432003058",
    },
    {
        "school": "Melvin H. Kreps Middle School",
        "district": "East Windsor Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340432003060",
    },
    {
        "school": "Perry L. Drew Elementary School",
        "district": "East Windsor Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340432003062",
    },
    {
        "school": "Walter C. Black Elementary School",
        "district": "East Windsor Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340432003064",
    },
    {
        "school": "Ewing High School",
        "district": "Ewing Township School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340492003068",
    },
    {
        "school": "Gilmore J Fisher Middle School",
        "district": "Ewing Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340492003070",
    },
    {
        "school": "Francis Lore Elementary School",
        "district": "Ewing Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340492003076",
    },
    {
        "school": "Parkway Elementary School",
        "district": "Ewing Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340492003082",
    },
    {
        "school": "William L Antheil Elementary School",
        "district": "Ewing Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340492003086",
    },
    {
        "school": "Hamilton East - Steinert",
        "district": "Hamilton Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003090",
    },
    {
        "school": "Hamilton West-Watson",
        "district": "Hamilton Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003092",
    },
    {
        "school": "Albert E Grice Middle School",
        "district": "Hamilton Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003094",
    },
    {
        "school": "Emily C. Reynolds Middle School",
        "district": "Hamilton Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003096",
    },
    {
        "school": "Alexander Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003100",
    },
    {
        "school": "George E. Wilson Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003102",
    },
    {
        "school": "Greenwood Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003104",
    },
    {
        "school": "Kisthardt Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003106",
    },
    {
        "school": "Klockner Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003108",
    },
    {
        "school": "Kuser Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003110",
    },
    {
        "school": "Lalor Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003112",
    },
    {
        "school": "Langtree Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003114",
    },
    {
        "school": "McGalliard Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003116",
    },
    {
        "school": "Mercerville Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003118",
    },
    {
        "school": "Morgan Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003120",
    },
    {
        "school": "Robinson Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003122",
    },
    {
        "school": "Sayen Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003124",
    },
    {
        "school": "Sunnybrae Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003126",
    },
    {
        "school": "University Heights Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003128",
    },
    {
        "school": "Yardville Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003130",
    },
    {
        "school": "Yardville Heights Elementary School",
        "district": "Hamilton Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654003132",
    },
    {
        "school": "Hamilton North - Nottingham",
        "district": "Hamilton Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654005933",
    },
    {
        "school": "Richard C Crockett Middle School",
        "district": "Hamilton Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340654006049",
    },
    {
        "school": "Hopewell Valley Central High School",
        "district": "Hopewell Valley Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340753003136",
    },
    {
        "school": "Bear Tavern Elementary School",
        "district": "Hopewell Valley Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340753003138",
    },
    {
        "school": "Toll Gate Grammar School",
        "district": "Hopewell Valley Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340753003140",
    },
    {
        "school": "Hopewell Elementary School",
        "district": "Hopewell Valley Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340753003142",
    },
    {
        "school": "Timberlane Middle School",
        "district": "Hopewell Valley Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340753003146",
    },
    {
        "school": "Lawrence High School",
        "district": "Lawrence Township Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340840003152",
    },
    {
        "school": "Lawrence Middle School",
        "district": "Lawrence Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340840003154",
    },
    {
        "school": "Ben Franklin Elementary",
        "district": "Lawrence Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340840003156",
    },
    {
        "school": "Lawrence Intermediate School",
        "district": "Lawrence Township Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340840003160",
    },
    {
        "school": "Lawrenceville Elementary School",
        "district": "Lawrence Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340840003162",
    },
    {
        "school": "Slackwood Elementary School",
        "district": "Lawrence Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340840003164",
    },
    {
        "school": "Eldridge Park School",
        "district": "Lawrence Township Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340840006069",
    },
    {
        "school": "MCVS Assunpink Center",
        "district": "Area Vocational Technical Schools of Mercer County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340995003174",
    },
    {
        "school": "MCVS Arthur R. Sypek Center",
        "district": "Area Vocational Technical Schools of Mercer County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340995003178",
    },
    {
        "school": "Johnson Park School",
        "district": "Princeton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341341000067",
    },
    {
        "school": "Princeton High School",
        "district": "Princeton Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341341003182",
    },
    {
        "school": "John Witherspoon Middle School",
        "district": "Princeton Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341341003188",
    },
    {
        "school": "Riverside School",
        "district": "Princeton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341341003190",
    },
    {
        "school": "Community Park School",
        "district": "Princeton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341341003192",
    },
    {
        "school": "Littlebrook School",
        "district": "Princeton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341341006034",
    },
    {
        "school": "Daylight/Twilight High School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629000449",
    },
    {
        "school": "Trenton Central High School - Main Campus",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003200",
    },
    {
        "school": "Dunn Middle School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003210",
    },
    {
        "school": "Columbus Elementary School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003216",
    },
    {
        "school": "Franklin Elementary School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003218",
    },
    {
        "school": "Grant Elementary School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003220",
    },
    {
        "school": "Gregory Elementary School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003222",
    },
    {
        "school": "Joyce Kilmer School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003228",
    },
    {
        "school": "Luis Munoz-Rivera MS",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003230",
    },
    {
        "school": "Mott Elementary School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003234",
    },
    {
        "school": "P.J. Hill Elementary",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003236",
    },
    {
        "school": "Parker Elementary",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003238",
    },
    {
        "school": "Robbins Elementary School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003242",
    },
    {
        "school": "Washington Elementary School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003246",
    },
    {
        "school": "Wilson Elementary School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003248",
    },
    {
        "school": "Pond Road Middle School",
        "district": "Robbinsville Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341710000146",
    },
    {
        "school": "Sharon School",
        "district": "Robbinsville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341710003252",
    },
    {
        "school": "Village Elementary School",
        "district": "West Windsor-Plainsboro Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341770000147",
    },
    {
        "school": "Thomas R Grover Middle School",
        "district": "West Windsor-Plainsboro Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341770000313",
    },
    {
        "school": "West Windsor-Plainsboro High School South",
        "district": "West Windsor-Plainsboro Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341770003258",
    },
    {
        "school": "Dutch Neck Elementary School",
        "district": "West Windsor-Plainsboro Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341770003260",
    },
    {
        "school": "Maurice Hawk Elementary School",
        "district": "West Windsor-Plainsboro Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341770003262",
    },
    {
        "school": "J.V.B. Wicoff Elementary School",
        "district": "West Windsor-Plainsboro Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341770003264",
    },
    {
        "school": "Joseph F. Cappello School",
        "district": "Mercer County Special Services School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348020005952",
    },
    {
        "school": "Regional Day School",
        "district": "Mercer County Special Services School District",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348020005992",
    },
    {
        "school": "Mercer High School",
        "district": "Mercer County Special Services School District",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348020006013",
    },
    {
        "school": "West Windsor-Plainsboro High School North",
        "district": "West Windsor-Plainsboro Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341770000191",
    },
    {
        "school": "Community Middle School",
        "district": "West Windsor-Plainsboro Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341770006012",
    },
    {
        "school": "Millstone River School",
        "district": "West Windsor-Plainsboro Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341770006077",
    },
    {
        "school": "Chesterfield Township Elementary School",
        "district": "Chesterfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340309001016",
    },
    {
        "school": "Geraldine O Foster Early Childhood Center",
        "district": "Bridgeton City School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340225000581",
    },
    {
        "school": "Bridgeton High School",
        "district": "Bridgeton City School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340225001784",
    },
    {
        "school": "Broad Street School",
        "district": "Bridgeton City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340225001786",
    },
    {
        "school": "Buckshutem Road School",
        "district": "Bridgeton City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340225001788",
    },
    {
        "school": "Cherry Street School",
        "district": "Bridgeton City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340225001790",
    },
    {
        "school": "Indian Ave School",
        "district": "Bridgeton City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340225001794",
    },
    {
        "school": "Quarter Mile Lane School",
        "district": "Bridgeton City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340225001800",
    },
    {
        "school": "West Avenue School",
        "district": "Bridgeton City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340225001804",
    },
    {
        "school": "Haleyville-Mauricetown Elementary School",
        "district": "Commercial Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340348001810",
    },
    {
        "school": "Port Norris Middle School",
        "district": "Commercial Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340348001812",
    },
    {
        "school": "Cumberland County Technical Education Center",
        "district": "Cumberland County Board of Vocational Education",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340361001816",
    },
    {
        "school": "Cumberland Regional High School",
        "district": "CUMBERLAND REGIONAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340362001820",
    },
    {
        "school": "Deerfield Township School District",
        "district": "Deerfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340366001826",
    },
    {
        "school": "Downe Township Elementary School",
        "district": "Downe Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340396001832",
    },
    {
        "school": "Morris Goodwin School",
        "district": "GREENWICH TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340615001848",
    },
    {
        "school": "Hopewell Crest",
        "district": "Hopewell Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340750001854",
    },
    {
        "school": "Myron L. Powell Elementary School",
        "district": "Lawrence Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340837001856",
    },
    {
        "school": "Maurice River Township School",
        "district": "Maurice River Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340978001862",
    },
    {
        "school": "Silver Run Elementary School",
        "district": "Millville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341032000061",
    },
    {
        "school": "Lakeside Middle School",
        "district": "Millville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341032000271",
    },
    {
        "school": "Millville Senior High School",
        "district": "Millville School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341032001868",
    },
    {
        "school": "Memorial High School",
        "district": "Millville School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341032001870",
    },
    {
        "school": "R. M. Bacon Elementary School",
        "district": "Millville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341032001872",
    },
    {
        "school": "Child Family Center",
        "district": "Millville School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341032001874",
    },
    {
        "school": "Holly Heights Elementary School",
        "district": "Millville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341032001878",
    },
    {
        "school": "Mount Pleasant Elementary School",
        "district": "Millville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341032001880",
    },
    {
        "school": "Rieck Avenue Elementary School",
        "district": "Millville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341032001882",
    },
    {
        "school": "Stow Creek Township School",
        "district": "STOW CREEK TOWNSHIP SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341584001890",
    },
    {
        "school": "Charles F. Seabrook School",
        "district": "Upper Deerfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341653001894",
    },
    {
        "school": "Elizabeth F. Moore School",
        "district": "Upper Deerfield Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341653001896",
    },
    {
        "school": "Woodruff Middle School",
        "district": "Upper Deerfield Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341653001898",
    },
    {
        "school": "Casimer M. Dallago Jr. Impact Center",
        "district": "Vineland Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680000225",
    },
    {
        "school": "Vineland Senior High School",
        "district": "Vineland Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680001902",
    },
    {
        "school": "Veterans Memorial Middle",
        "district": "Vineland Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680001908",
    },
    {
        "school": "Anthony Rossi Elementary School",
        "district": "Vineland Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680001910",
    },
    {
        "school": "Dane Barse Elementary School",
        "district": "Vineland Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680001916",
    },
    {
        "school": "John H. Winslow Elementary School",
        "district": "Vineland Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680001924",
    },
    {
        "school": "Johnstone Elementary School",
        "district": "Vineland Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680001928",
    },
    {
        "school": "Marie Durand Elementary School",
        "district": "Vineland Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680001930",
    },
    {
        "school": "Solve D'Ippolito Elementary School",
        "district": "Vineland Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680001948",
    },
    {
        "school": "Dr. William Mennies Elementary School",
        "district": "Vineland Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680005921",
    },
    {
        "school": "FOOTHILL HIGH SCHOOL",
        "district": "JUVENILE JUSTICE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001100985",
    },
    {
        "school": "SEQUOYAH",
        "district": "SEQUOYAH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001500971",
    },
    {
        "school": "CHILDRENS PSYCHIATRY",
        "district": "CHILDRENS PSYC",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001600983",
    },
    {
        "school": "NATIVE AMERICAN COMM ACADEMY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000918",
    },
    {
        "school": "ALICE KING COMMUNITY SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000924",
    },
    {
        "school": "CHRISTINE DUNCAN HERITAGE ACADEMY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000925",
    },
    {
        "school": "NORTH STAR ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000964",
    },
    {
        "school": "ROSWELL CORRECTIONS",
        "district": "NM CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001200970",
    },
    {
        "school": "WESTERN NM CORRECTIONS",
        "district": "NM CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001200979",
    },
    {
        "school": "NORTHWESTERN NM CORRECTIONS",
        "district": "NM CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001200987",
    },
    {
        "school": "AZTEC YOUTH ACADEMY",
        "district": "JUVENILE JUSTICE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001100973",
    },
    {
        "school": "SOUTHERN NM CORRECTIONS",
        "district": "NM CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001200982",
    },
    {
        "school": "SONOMA ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000959",
    },
    {
        "school": "GUADALUPE COUNTY CORRECTIONS",
        "district": "NM CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001200976",
    },
    {
        "school": "LAE COUNTY CORRECTIONS",
        "district": "NM CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001200974",
    },
    {
        "school": "DEMING CESAR CHAVEZ",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069000963",
    },
    {
        "school": "NM SCHOOL FOR THE BLIND AND VISUALLY IMPAIRED",
        "district": "NM SCHOOL FOR THE BLIND AND VISUALLY IMPAIRED",
        "level": "Other",
        "type": "Special education school",
        "state": "NM",
        "nces_id": "350001300980",
    },
    {
        "school": "TULAROSA INTERMEDIATE",
        "district": "TULAROSA MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350267000968",
    },
    {
        "school": "LINDRITH AREA HERITAGE",
        "district": "JEMEZ MOUNTAIN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350138000992",
    },
    {
        "school": "PENITENTIARY OF NM-SANTA FE",
        "district": "NM CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001200977",
    },
    {
        "school": "NM SCHOOL FOR THE DEAF",
        "district": "NM SCHOOL FOR THE DEAF",
        "level": "Other",
        "type": "Special education school",
        "state": "NM",
        "nces_id": "350001400972",
    },
    {
        "school": "CENTRAL NM CORRECTIONS",
        "district": "NM CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001200986",
    },
    {
        "school": "VALENCIA HIGH",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000989",
    },
    {
        "school": "MORENO VALLEY HIGH",
        "district": "CIMARRON MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350048000857",
    },
    {
        "school": "HOUSE JUNIOR HIGH",
        "district": "HOUSE MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350132000909",
    },
    {
        "school": "LOGAN MIDDLE",
        "district": "LOGAN MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350159000885",
    },
    {
        "school": "DATIL ELEMENTARY",
        "district": "QUEMADO INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350213000491",
    },
    {
        "school": "QUEMADO ELEMENTARY",
        "district": "QUEMADO INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350213000492",
    },
    {
        "school": "QUEMADO HIGH",
        "district": "QUEMADO INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350213000493",
    },
    {
        "school": "RESERVE ELEMENTARY",
        "district": "RESERVE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350222000503",
    },
    {
        "school": "RESERVE HIGH",
        "district": "RESERVE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350222000504",
    },
    {
        "school": "CIMARRON ELEMENTARY",
        "district": "CIMARRON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350048000197",
    },
    {
        "school": "CIMARRON HIGH",
        "district": "CIMARRON MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350048000198",
    },
    {
        "school": "EAGLE NEST ELEMENTARY",
        "district": "CIMARRON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350048000199",
    },
    {
        "school": "EAGLE NEST MIDDLE",
        "district": "CIMARRON MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350048000302",
    },
    {
        "school": "CIMARRON MIDDLE",
        "district": "CIMARRON MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350048000699",
    },
    {
        "school": "MAXWELL MIDDLE",
        "district": "MAXWELL MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350180000458",
    },
    {
        "school": "MAXWELL ELEMENTARY",
        "district": "MAXWELL MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350180000460",
    },
    {
        "school": "MAXWELL HIGH",
        "district": "MAXWELL MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350180000461",
    },
    {
        "school": "LONGFELLOW ELEMENTARY",
        "district": "RATON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350219000499",
    },
    {
        "school": "RATON HIGH",
        "district": "RATON PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350219000500",
    },
    {
        "school": "RATON INTERMEDIATE",
        "district": "RATON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350219000501",
    },
    {
        "school": "FORRESTER ELEMENTARY",
        "district": "SPRINGER MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350249000574",
    },
    {
        "school": "SPRINGER HIGH",
        "district": "SPRINGER MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350249000575",
    },
    {
        "school": "WILFERTH ELEMENTARY",
        "district": "SPRINGER MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350249000576",
    },
    {
        "school": "FORT SUMNER ELEMENTARY",
        "district": "FORT SUMNER MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350105000296",
    },
    {
        "school": "FORT SUMNER HIGH",
        "district": "FORT SUMNER MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350105000297",
    },
    {
        "school": "FORT SUMNER MIDDLE",
        "district": "FORT SUMNER MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350105000718",
    },
    {
        "school": "VAUGHN ELEMENTARY",
        "district": "VAUGHN MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350000100607",
    },
    {
        "school": "VAUGHN HIGH",
        "district": "VAUGHN MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350000100608",
    },
    {
        "school": "ANTON CHICO MIDDLE",
        "district": "SANTA ROSA CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350240000324",
    },
    {
        "school": "RITA A. MARQUEZ ELEMENTARY",
        "district": "SANTA ROSA CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350240000555",
    },
    {
        "school": "SANTA ROSA ELEMENTARY",
        "district": "SANTA ROSA CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350240000556",
    },
    {
        "school": "SANTA ROSA HIGH",
        "district": "SANTA ROSA CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350240000557",
    },
    {
        "school": "SANTA ROSA MIDDLE",
        "district": "SANTA ROSA CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350240000558",
    },
    {
        "school": "MOSQUERO ELEMENTARY",
        "district": "MOSQUERO MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350192000470",
    },
    {
        "school": "MOSQUERO HIGH",
        "district": "MOSQUERO MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350192000471",
    },
    {
        "school": "ROY ELEMENTARY",
        "district": "ROY MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350228000526",
    },
    {
        "school": "ROY HIGH",
        "district": "ROY MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350228000527",
    },
    {
        "school": "ANIMAS ELEMENTARY",
        "district": "ANIMAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350009000618",
    },
    {
        "school": "ANIMAS 7-12 SCHOOL",
        "district": "ANIMAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350009000619",
    },
    {
        "school": "ANIMAS MIDDLE",
        "district": "ANIMAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350009030019",
    },
    {
        "school": "CENTRAL ELEMENTARY",
        "district": "LORDSBURG MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350162000422",
    },
    {
        "school": "DUGAN-TARANGO MIDDLE",
        "district": "LORDSBURG MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350162000423",
    },
    {
        "school": "LORDSBURG HIGH",
        "district": "LORDSBURG MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350162000424",
    },
    {
        "school": "R.V.TRAYLOR ELEMENTARY",
        "district": "LORDSBURG MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350162000426",
    },
    {
        "school": "CAPITAN ELEMENTARY",
        "district": "CAPITAN MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350027000160",
    },
    {
        "school": "CAPITAN HIGH",
        "district": "CAPITAN MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350027000161",
    },
    {
        "school": "CAPITAN MIDDLE",
        "district": "CAPITAN MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350027000544",
    },
    {
        "school": "CARRIZOZO ELEMENTARY",
        "district": "CARRIZOZO MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350033000176",
    },
    {
        "school": "CARRIZOZO HIGH",
        "district": "CARRIZOZO MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350033000177",
    },
    {
        "school": "CARRIZOZO MIDDLE",
        "district": "CARRIZOZO MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350033000178",
    },
    {
        "school": "CORONA ELEMENTARY",
        "district": "CORONA MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350063000231",
    },
    {
        "school": "CORONA HIGH",
        "district": "CORONA MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350063000232",
    },
    {
        "school": "HONDO ELEMENTARY",
        "district": "HONDO VALLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350129000359",
    },
    {
        "school": "HONDO HIGH",
        "district": "HONDO VALLEY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350129000360",
    },
    {
        "school": "SIERRA VISTA PRIMARY",
        "district": "RUIDOSO MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350231000464",
    },
    {
        "school": "RUIDOSO HIGH",
        "district": "RUIDOSO MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350231000529",
    },
    {
        "school": "WHITE MOUNTAIN ELEMENTARY",
        "district": "RUIDOSO MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350231000530",
    },
    {
        "school": "RUIDOSO MIDDLE",
        "district": "RUIDOSO MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350231000531",
    },
    {
        "school": "HOLMAN ELEMENTARY",
        "district": "MORA INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350186000636",
    },
    {
        "school": "MORA ELEMENTARY",
        "district": "MORA INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350186000637",
    },
    {
        "school": "MORA HIGH",
        "district": "MORA INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350186000638",
    },
    {
        "school": "LAZARO LARRY GARCIA MIDDLE",
        "district": "MORA INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350186000784",
    },
    {
        "school": "WAGON MOUND ELEMENTARY",
        "district": "WAGON MOUND PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350273000611",
    },
    {
        "school": "WAGON MOUND HIGH",
        "district": "WAGON MOUND PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350273000612",
    },
    {
        "school": "HOUSE ELEMENTARY",
        "district": "HOUSE MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350132000361",
    },
    {
        "school": "HOUSE HIGH",
        "district": "HOUSE MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350132000362",
    },
    {
        "school": "LOGAN ELEMENTARY",
        "district": "LOGAN MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350159000420",
    },
    {
        "school": "LOGAN HIGH",
        "district": "LOGAN MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350159000421",
    },
    {
        "school": "SAN JON ELEMENTARY",
        "district": "SAN JON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350234000532",
    },
    {
        "school": "SAN JON HIGH",
        "district": "SAN JON MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350234000533",
    },
    {
        "school": "SAN JON MIDDLE SCHOOL",
        "district": "SAN JON MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350234000835",
    },
    {
        "school": "TUCUMCARI HIGH",
        "district": "TUCUMCARI PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350264000599",
    },
    {
        "school": "TUCUMCARI MIDDLE",
        "district": "TUCUMCARI PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350264000600",
    },
    {
        "school": "TUCUMCARI ELEMENTARY",
        "district": "TUCUMCARI PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350264000602",
    },
    {
        "school": "SIERRA ELEMENTARY",
        "district": "T OR C MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350261000435",
    },
    {
        "school": "ARREY ELEMENTARY",
        "district": "T OR C MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350261000591",
    },
    {
        "school": "HOT SPRINGS HIGH",
        "district": "T OR C MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350261000593",
    },
    {
        "school": "T OR C ELEMENTARY",
        "district": "T OR C MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350261000594",
    },
    {
        "school": "T OR C MIDDLE",
        "district": "T OR C MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350261000595",
    },
    {
        "school": "MAGDALENA HIGH",
        "district": "MAGDALENA MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350177000452",
    },
    {
        "school": "MAGDALENA ELEMENTARY",
        "district": "MAGDALENA MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350177000453",
    },
    {
        "school": "MAGDALENA MIDDLE",
        "district": "MAGDALENA MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350177000694",
    },
    {
        "school": "MIDWAY ELEMENTARY",
        "district": "SOCORRO CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350246000568",
    },
    {
        "school": "SAN ANTONIO ELEMENTARY",
        "district": "SOCORRO CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350246000569",
    },
    {
        "school": "SOCORRO HIGH",
        "district": "SOCORRO CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350246000571",
    },
    {
        "school": "R. SARRACINO MIDDLE",
        "district": "SOCORRO CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350246000572",
    },
    {
        "school": "PARKVIEW ELEMENTARY",
        "district": "SOCORRO CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350246000789",
    },
    {
        "school": "COTTONWOOD VALLEY CHARTER",
        "district": "SOCORRO CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350246000843",
    },
    {
        "school": "ALVIS ELEMENTARY",
        "district": "CLAYTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350051000200",
    },
    {
        "school": "CLAYTON HIGH",
        "district": "CLAYTON MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350051000203",
    },
    {
        "school": "CLAYTON JUNIOR HIGH",
        "district": "CLAYTON MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350051000204",
    },
    {
        "school": "KISER ELEMENTARY",
        "district": "CLAYTON MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350051000205",
    },
    {
        "school": "DES MOINES ELEMENTARY",
        "district": "DES MOINES MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350072000245",
    },
    {
        "school": "DES MOINES HIGH",
        "district": "DES MOINES MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350072000246",
    },
    {
        "school": "ALAMOGORDO HIGH",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000001",
    },
    {
        "school": "BUENA VISTA ELEMENTARY",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000002",
    },
    {
        "school": "CHAPARRAL MIDDLE",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000003",
    },
    {
        "school": "HEIGHTS ELEMENTARY",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000004",
    },
    {
        "school": "HIGH ROLLS MOUNTAIN PARK ELEMENTARY",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000005",
    },
    {
        "school": "HOLLOMAN ELEMENTARY",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000006",
    },
    {
        "school": "HOLLOMAN MIDDLE",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000007",
    },
    {
        "school": "LA LUZ ELEMENTARY",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000008",
    },
    {
        "school": "NORTH ELEMENTARY",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000010",
    },
    {
        "school": "DESERT STAR ELEMENTARY",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000012",
    },
    {
        "school": "SIERRA ELEMENTARY",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000013",
    },
    {
        "school": "YUCCA ELEMENTARY",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000016",
    },
    {
        "school": "MOUNTAIN VIEW MIDDLE",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350003000798",
    },
    {
        "school": "ACADEMY DEL SOL ALT.",
        "district": "ALAMOGORDO PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350003000799",
    },
    {
        "school": "CLOUDCROFT ELEMENTARY",
        "district": "CLOUDCROFT MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350054000206",
    },
    {
        "school": "CLOUDCROFT HIGH",
        "district": "CLOUDCROFT MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350054000207",
    },
    {
        "school": "CLOUDCROFT MIDDLE",
        "district": "CLOUDCROFT MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350054030005",
    },
    {
        "school": "TULAROSA ELEMENTARY",
        "district": "TULAROSA MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350267000604",
    },
    {
        "school": "TULAROSA HIGH",
        "district": "TULAROSA MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350267000605",
    },
    {
        "school": "TULAROSA MIDDLE",
        "district": "TULAROSA MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350267000606",
    },
    {
        "school": "VOLCANO VISTA HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000966",
    },
    {
        "school": "LOS PUENTES CHARTER",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000852",
    },
    {
        "school": "DIGITAL ARTS AND TECHNOLOGY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000853",
    },
    {
        "school": "EL CAMINO REAL ACADEMY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000854",
    },
    {
        "school": "VISION QUEST ALTERNATIVE MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350006000856",
    },
    {
        "school": "LA ACADEMIA DE ESPERANZA",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000875",
    },
    {
        "school": "GILBERT L SENA CHARTER HS",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000890",
    },
    {
        "school": "ABQ CHARTER ACADEMY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000893",
    },
    {
        "school": "MONTESSORI OF THE RIO GRANDE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000894",
    },
    {
        "school": "MANZANO MESA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000895",
    },
    {
        "school": "EDWARD GONZALES ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000896",
    },
    {
        "school": "VENTANA RANCH ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000897",
    },
    {
        "school": "EARLY COLLEGE ACADEMY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350006000916",
    },
    {
        "school": "MOUNTAIN MAHOGANY COMMUNITY SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000920",
    },
    {
        "school": "VISTA GRANDE ELEMENTARY",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000864",
    },
    {
        "school": "RIO RANCHO MIDDLE SCHOOL",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000865",
    },
    {
        "school": "MAGGIE CORDOVA ELEMENTARY SCHOOL",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000952",
    },
    {
        "school": "SHINING STARS PRESCHOOL",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NM",
        "nces_id": "350001000953",
    },
    {
        "school": "RIO RANCHO CYBER ACADEMY",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001000954",
    },
    {
        "school": "MOUNTAINAIR JR HIGH",
        "district": "MOUNTAINAIR PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350195000915",
    },
    {
        "school": "THE FAMILY SCHOOL",
        "district": "BELEN CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350018000867",
    },
    {
        "school": "LOS LUNAS FAMILY SCHOOL",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350168000866",
    },
    {
        "school": "LOWER ELEMENTARY",
        "district": "ESTANCIA MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350093000278",
    },
    {
        "school": "ESTANCIA HIGH",
        "district": "ESTANCIA MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350093000279",
    },
    {
        "school": "VANSTONE ELEMENTARY",
        "district": "ESTANCIA MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350093000613",
    },
    {
        "school": "ESTANCIA MIDDLE",
        "district": "ESTANCIA MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350093000717",
    },
    {
        "school": "UPPER ELEMENTARY",
        "district": "ESTANCIA MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350093000791",
    },
    {
        "school": "MOUNTAINAIR ELEMENTARY",
        "district": "MOUNTAINAIR PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350195000472",
    },
    {
        "school": "MOUNTAINAIR HIGH",
        "district": "MOUNTAINAIR PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350195000473",
    },
    {
        "school": "A. MONTOYA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000017",
    },
    {
        "school": "JOHN ADAMS MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000019",
    },
    {
        "school": "ADOBE ACRES ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000020",
    },
    {
        "school": "ALAMEDA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000021",
    },
    {
        "school": "ALAMOSA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000022",
    },
    {
        "school": "ALBUQUERQUE HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000024",
    },
    {
        "school": "ALVARADO ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000025",
    },
    {
        "school": "APACHE ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000026",
    },
    {
        "school": "ARMIJO ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000027",
    },
    {
        "school": "ARROYO DEL OSO ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000028",
    },
    {
        "school": "ATRISCO ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000029",
    },
    {
        "school": "BANDELIER ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000030",
    },
    {
        "school": "BARCELONA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000031",
    },
    {
        "school": "BEL-AIR ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000032",
    },
    {
        "school": "BELLEHAVEN ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000033",
    },
    {
        "school": "CARLOS REY ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000035",
    },
    {
        "school": "CHAPARRAL ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000036",
    },
    {
        "school": "CHELWOOD ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000037",
    },
    {
        "school": "CIBOLA HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000038",
    },
    {
        "school": "PETROGLYPH ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000039",
    },
    {
        "school": "COCHITI ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000040",
    },
    {
        "school": "COLLET PARK ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000041",
    },
    {
        "school": "COMANCHE ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000042",
    },
    {
        "school": "LEW WALLACE ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000043",
    },
    {
        "school": "DEL NORTE HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000044",
    },
    {
        "school": "DOLORES GONZALES ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000045",
    },
    {
        "school": "MACARTHUR ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000046",
    },
    {
        "school": "DURANES ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000047",
    },
    {
        "school": "EAST SAN JOSE ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000048",
    },
    {
        "school": "EISENHOWER MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000049",
    },
    {
        "school": "ELDORADO HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000050",
    },
    {
        "school": "EMERSON ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000051",
    },
    {
        "school": "ERNIE PYLE MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000052",
    },
    {
        "school": "JANET KAHN FINE ARTS ACADEMY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000053",
    },
    {
        "school": "EUGENE FIELD ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000054",
    },
    {
        "school": "FREEDOM HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350006000055",
    },
    {
        "school": "GARFIELD MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000056",
    },
    {
        "school": "GOV BENT ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000057",
    },
    {
        "school": "GRANT MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000058",
    },
    {
        "school": "GRIEGOS ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000059",
    },
    {
        "school": "HARRISON MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000060",
    },
    {
        "school": "HAWTHORNE ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000061",
    },
    {
        "school": "HAYES MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000062",
    },
    {
        "school": "HIGHLAND HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000063",
    },
    {
        "school": "HODGIN ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000064",
    },
    {
        "school": "L.B. JOHNSON MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000065",
    },
    {
        "school": "HOOVER MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000066",
    },
    {
        "school": "INEZ ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000067",
    },
    {
        "school": "JACKSON MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000068",
    },
    {
        "school": "JEFFERSON MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000069",
    },
    {
        "school": "JOHN BAKER ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000070",
    },
    {
        "school": "KENNEDY MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000071",
    },
    {
        "school": "KIRTLAND ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000072",
    },
    {
        "school": "KIT CARSON ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000073",
    },
    {
        "school": "LA LUZ ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000074",
    },
    {
        "school": "LA MESA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000075",
    },
    {
        "school": "LAVALAND ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000077",
    },
    {
        "school": "LONGFELLOW ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000078",
    },
    {
        "school": "LOS PADILLAS ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000079",
    },
    {
        "school": "LOWELL ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000080",
    },
    {
        "school": "MADISON MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000081",
    },
    {
        "school": "MANZANO HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000082",
    },
    {
        "school": "MARK TWAIN ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000083",
    },
    {
        "school": "MATHESON PARK ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000084",
    },
    {
        "school": "MCCOLLUM ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000085",
    },
    {
        "school": "MISSION AVENUE ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000087",
    },
    {
        "school": "MITCHELL ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000088",
    },
    {
        "school": "MONTE VISTA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000089",
    },
    {
        "school": "MONTEZUMA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000090",
    },
    {
        "school": "MOUNTAIN VIEW ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000092",
    },
    {
        "school": "NAVAJO ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000093",
    },
    {
        "school": "REGINALD CHAVEZ ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000094",
    },
    {
        "school": "ONATE ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000095",
    },
    {
        "school": "OSUNA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000096",
    },
    {
        "school": "PAJARITO ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000097",
    },
    {
        "school": "POLK MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000098",
    },
    {
        "school": "LOS RANCHOS ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000099",
    },
    {
        "school": "RIO GRANDE HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000100",
    },
    {
        "school": "ROOSEVELT MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000102",
    },
    {
        "school": "S. Y. JACKSON ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000103",
    },
    {
        "school": "SAN ANTONITO ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000104",
    },
    {
        "school": "SANDIA BASE ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000105",
    },
    {
        "school": "SANDIA HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000106",
    },
    {
        "school": "SCHOOL ON WHEELS HIGH SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350006000108",
    },
    {
        "school": "SIERRA VISTA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000109",
    },
    {
        "school": "SOMBRA DEL MONTE ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000110",
    },
    {
        "school": "TAFT MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000111",
    },
    {
        "school": "TAYLOR MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000112",
    },
    {
        "school": "TOMASITA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000113",
    },
    {
        "school": "TRUMAN MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000114",
    },
    {
        "school": "VALLE VISTA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000115",
    },
    {
        "school": "VALLEY HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000116",
    },
    {
        "school": "VAN BUREN MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000117",
    },
    {
        "school": "WASHINGTON MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000118",
    },
    {
        "school": "WEST MESA HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000119",
    },
    {
        "school": "WHERRY ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000120",
    },
    {
        "school": "WHITTIER ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000121",
    },
    {
        "school": "WILSON MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000122",
    },
    {
        "school": "NEW FUTURES HIGH SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350006000123",
    },
    {
        "school": "ZIA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000124",
    },
    {
        "school": "ZUNI ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000125",
    },
    {
        "school": "DESERT WILLOW FAMILY SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350006000273",
    },
    {
        "school": "CAREER ENRICHMENT",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350006000456",
    },
    {
        "school": "SIERRA ALTERNATIVE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350006000457",
    },
    {
        "school": "MCKINLEY MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000615",
    },
    {
        "school": "HUBERT H HUMPHREY ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000616",
    },
    {
        "school": "CLEVELAND MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000617",
    },
    {
        "school": "CHAMIZA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000642",
    },
    {
        "school": "EDMUND G ROSS ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000647",
    },
    {
        "school": "DENNIS CHAVEZ ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000681",
    },
    {
        "school": "MARIE M HUGHES ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000683",
    },
    {
        "school": "MARYANN BINFORD ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000692",
    },
    {
        "school": "LA CUEVA HIGH",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000698",
    },
    {
        "school": "CONTINUATION SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Special education school",
        "state": "NM",
        "nces_id": "350006000709",
    },
    {
        "school": "SUSIE RAYOS MARMON ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000725",
    },
    {
        "school": "GEORGIA O'KEEFFE ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000726",
    },
    {
        "school": "DOUBLE EAGLE ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000752",
    },
    {
        "school": "DESERT RIDGE MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000764",
    },
    {
        "school": "PAINTED SKY ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000782",
    },
    {
        "school": "EAST MOUNTAIN HIGH SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000808",
    },
    {
        "school": "SOUTH VALLEY ACADEMY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000809",
    },
    {
        "school": "TWENTY-FIRST CENTURY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000811",
    },
    {
        "school": "JIMMY CARTER MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000812",
    },
    {
        "school": "MARK ARMIJO ACADEMY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000821",
    },
    {
        "school": "PUBLIC ACADEMY FOR PERFORMING ARTS",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000822",
    },
    {
        "school": "ROBERT F. KENNEDY CHARTER",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000823",
    },
    {
        "school": "SEVEN BAR ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000824",
    },
    {
        "school": "JAMES MONROE MIDDLE",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000825",
    },
    {
        "school": "RIO RANCHO ELEMENTARY",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000101",
    },
    {
        "school": "PUESTA DEL SOL ELEMENTARY",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000650",
    },
    {
        "school": "LINCOLN MIDDLE",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000682",
    },
    {
        "school": "MARTIN KING JR ELEMENTARY",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000710",
    },
    {
        "school": "ERNEST STAPLETON ELEMENTARY",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000736",
    },
    {
        "school": "MOUNTAIN VIEW MIDDLE",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000739",
    },
    {
        "school": "COLINAS DEL NORTE ELEMENTARY",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000750",
    },
    {
        "school": "EAGLE RIDGE MIDDLE",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000761",
    },
    {
        "school": "RIO RANCHO HIGH",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001000779",
    },
    {
        "school": "INDEPENDENCE HIGH SCHOOL",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001000805",
    },
    {
        "school": "ENCHANTED HILLS ELEMENTARY",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001030011",
    },
    {
        "school": "CORRALES ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006000107",
    },
    {
        "school": "ALGODONES ELEMENTARY",
        "district": "BERNALILLO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350021000147",
    },
    {
        "school": "BERNALILLO HIGH",
        "district": "BERNALILLO PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350021000148",
    },
    {
        "school": "BERNALILLO MIDDLE",
        "district": "BERNALILLO PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350021000149",
    },
    {
        "school": "COCHITI ELEMENTARY",
        "district": "BERNALILLO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350021000150",
    },
    {
        "school": "PLACITAS ELEMENTARY",
        "district": "BERNALILLO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350021000151",
    },
    {
        "school": "BERNALILLO ELEMENTARY",
        "district": "BERNALILLO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350021000152",
    },
    {
        "school": "SANTO DOMINGO ELEMENTARY",
        "district": "BERNALILLO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350021000153",
    },
    {
        "school": "SANTO DOMINGO MIDDLE",
        "district": "BERNALILLO PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350021000154",
    },
    {
        "school": "COCHITI MIDDLE",
        "district": "BERNALILLO PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350021000727",
    },
    {
        "school": "WD CARROLL ELEMENTARY",
        "district": "BERNALILLO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350021000728",
    },
    {
        "school": "CUBA ELEMENTARY",
        "district": "CUBA INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350066000233",
    },
    {
        "school": "CUBA HIGH",
        "district": "CUBA INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350066000234",
    },
    {
        "school": "CUBA MIDDLE",
        "district": "CUBA INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350066000235",
    },
    {
        "school": "JEMEZ VALLEY ELEMENTARY",
        "district": "JEMEZ VALLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350141000372",
    },
    {
        "school": "JEMEZ VALLEY HIGH",
        "district": "JEMEZ VALLEY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350141000373",
    },
    {
        "school": "JEMEZ VALLEY MIDDLE",
        "district": "JEMEZ VALLEY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350141000729",
    },
    {
        "school": "SAN DIEGO RIVERSIDE",
        "district": "JEMEZ VALLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350141000800",
    },
    {
        "school": "LA PROMESA ELEMENTARY",
        "district": "BELEN CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018000849",
    },
    {
        "school": "BELEN HIGH",
        "district": "BELEN CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018000140",
    },
    {
        "school": "BELEN MIDDLE",
        "district": "BELEN CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018000141",
    },
    {
        "school": "CENTRAL ELEMENTARY",
        "district": "BELEN CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018000142",
    },
    {
        "school": "DENNIS CHAVEZ ELEMENTARY",
        "district": "BELEN CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018000143",
    },
    {
        "school": "GIL SANCHEZ ELEMENTARY",
        "district": "BELEN CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018000144",
    },
    {
        "school": "JARAMILLO ELEMENTARY",
        "district": "BELEN CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018000145",
    },
    {
        "school": "RIO GRANDE ELEMENTARY",
        "district": "BELEN CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018000146",
    },
    {
        "school": "BELEN INFINITY HIGH",
        "district": "BELEN CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350018000848",
    },
    {
        "school": "LA MERCED ELEMENTARY",
        "district": "BELEN CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018030003",
    },
    {
        "school": "LOS LUNAS ELEMENTARY",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000258",
    },
    {
        "school": "BOSQUE FARMS ELEMENTARY",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000436",
    },
    {
        "school": "RAYMOND GABALDON ELEMENTARY",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000438",
    },
    {
        "school": "LOS LUNAS HIGH",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000439",
    },
    {
        "school": "LOS LUNAS MIDDLE",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000440",
    },
    {
        "school": "PERALTA ELEMENTARY",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000441",
    },
    {
        "school": "VALENCIA MIDDLE SCHOOL",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000614",
    },
    {
        "school": "ANN PARISH ELEMENTARY",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000703",
    },
    {
        "school": "KATHERINE GALLEGOS ELEMENTARY",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000722",
    },
    {
        "school": "VALENCIA ELEMENTARY",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000762",
    },
    {
        "school": "DESERT VIEW ELEMENTARY",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168000792",
    },
    {
        "school": "CENTURY ALT HIGH",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350168000807",
    },
    {
        "school": "TOME ELEMENTARY",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168030007",
    },
    {
        "school": "SOUTH MOUNTAIN ELEMENTARY",
        "district": "MORIARTY-EDGEWOOD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350189000749",
    },
    {
        "school": "EDGEWOOD MIDDLE",
        "district": "MORIARTY-EDGEWOOD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350189000818",
    },
    {
        "school": "MORIARTY ELEMENTARY",
        "district": "MORIARTY-EDGEWOOD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350189000467",
    },
    {
        "school": "MORIARTY HIGH",
        "district": "MORIARTY-EDGEWOOD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350189000468",
    },
    {
        "school": "MORIARTY MIDDLE",
        "district": "MORIARTY-EDGEWOOD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350189000469",
    },
    {
        "school": "ROUTE 66 ELEMENTARY",
        "district": "MORIARTY-EDGEWOOD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350189000760",
    },
    {
        "school": "JEFFERSON MONTESSORI",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030000859",
    },
    {
        "school": "ARTESIA HIGH",
        "district": "ARTESIA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012000127",
    },
    {
        "school": "CENTRAL ELEMENTARY",
        "district": "ARTESIA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012000128",
    },
    {
        "school": "HERMOSA ELEMENTARY",
        "district": "ARTESIA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012000129",
    },
    {
        "school": "ARTESIA PARK JUNIOR HIGH",
        "district": "ARTESIA PUBLIC SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012000130",
    },
    {
        "school": "PENASCO ELEMENTARY",
        "district": "ARTESIA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012000131",
    },
    {
        "school": "ROSELAWN ELEMENTARY",
        "district": "ARTESIA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012000132",
    },
    {
        "school": "YUCCA ELEMENTARY",
        "district": "ARTESIA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012000133",
    },
    {
        "school": "ARTESIA ZIA INTERMEDIATE",
        "district": "ARTESIA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012000134",
    },
    {
        "school": "GRAND HEIGHTS EARLY CHILDHOOD",
        "district": "ARTESIA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012000620",
    },
    {
        "school": "YESO ELEMENTARY",
        "district": "ARTESIA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012000672",
    },
    {
        "school": "CARLSBAD SIXTH GRADE ACADEMY",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030000162",
    },
    {
        "school": "CARLSBAD HIGH",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030000163",
    },
    {
        "school": "EARLY CHILDHOOD EDUCATION CENTER",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030000166",
    },
    {
        "school": "CARLSBAD INTERMEDIATE SCHOOL",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030000169",
    },
    {
        "school": "MONTERREY ELEMENTARY",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030000170",
    },
    {
        "school": "JOE STANLEY SMITH ELEMENTARY",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030000174",
    },
    {
        "school": "SUNSET ELEMENTARY",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030000175",
    },
    {
        "school": "CRAFT ELEMENTARY",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030000463",
    },
    {
        "school": "LOVING ELEMENTARY",
        "district": "LOVING MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350171000442",
    },
    {
        "school": "LOVING HIGH",
        "district": "LOVING MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350171000443",
    },
    {
        "school": "LOVING MIDDLE",
        "district": "LOVING MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350171000731",
    },
    {
        "school": "GRADY MIDDLE SCHOOL",
        "district": "GRADY MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350114000899",
    },
    {
        "school": "MELROSE JUNIOR",
        "district": "MELROSE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350183000898",
    },
    {
        "school": "BARRY ELEMENTARY",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000208",
    },
    {
        "school": "ARTS ACADEMY AT BELLA VISTA",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000209",
    },
    {
        "school": "JAMES BICKLEY ELEMENTARY",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000210",
    },
    {
        "school": "CAMEO ELEMENTARY",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000211",
    },
    {
        "school": "CLOVIS HIGH",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000213",
    },
    {
        "school": "HIGHLAND ELEMENTARY",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000214",
    },
    {
        "school": "LA CASITA ELEMENTARY",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000215",
    },
    {
        "school": "LOCKWOOD ELEMENTARY",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000217",
    },
    {
        "school": "MARSHALL MIDDLE",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000218",
    },
    {
        "school": "PARKVIEW ELEMENTARY",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000219",
    },
    {
        "school": "SANDIA ELEMENTARY",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000221",
    },
    {
        "school": "CLOVIS HS FRESHMAN ACADEMY",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000222",
    },
    {
        "school": "YUCCA MIDDLE",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000223",
    },
    {
        "school": "ZIA ELEMENTARY",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000224",
    },
    {
        "school": "LOS NINOS",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057000793",
    },
    {
        "school": "MESA ELEMENTARY",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057030016",
    },
    {
        "school": "GRADY ELEMENTARY",
        "district": "GRADY MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350114000325",
    },
    {
        "school": "GRADY HIGH",
        "district": "GRADY MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350114000326",
    },
    {
        "school": "MELROSE ELEMENTARY",
        "district": "MELROSE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350183000465",
    },
    {
        "school": "MELROSE HIGH",
        "district": "MELROSE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350183000466",
    },
    {
        "school": "TEXICO ELEMENTARY",
        "district": "TEXICO MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350258000588",
    },
    {
        "school": "TEXICO HIGH",
        "district": "TEXICO MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350258000589",
    },
    {
        "school": "TEXICO MIDDLE",
        "district": "TEXICO MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350258000590",
    },
    {
        "school": "BATAAN ELEMENTARY",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069000941",
    },
    {
        "school": "BELL ELEMENTARY",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069000236",
    },
    {
        "school": "CHAPARRAL ELEMENTARY",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069000237",
    },
    {
        "school": "COLUMBUS ELEMENTARY",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069000238",
    },
    {
        "school": "DEMING HIGH",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069000239",
    },
    {
        "school": "DEMING INTERMEDIATE",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069000240",
    },
    {
        "school": "MEMORIAL ELEMENTARY",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069000242",
    },
    {
        "school": "MY LITTLE SCHOOL",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NM",
        "nces_id": "350069000758",
    },
    {
        "school": "CHAMA ELEMENTARY",
        "district": "CHAMA VALLEY INDEP. SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350042000192",
    },
    {
        "school": "CHAMA MIDDLE",
        "district": "CHAMA VALLEY INDEP. SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350042000193",
    },
    {
        "school": "ESCALANTE MIDDLE/HIGH SCHOOL",
        "district": "CHAMA VALLEY INDEP. SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350042000194",
    },
    {
        "school": "TIERRA AMARILLA ELEMENTARY",
        "district": "CHAMA VALLEY INDEP. SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350042000195",
    },
    {
        "school": "DULCE ELEMENTARY",
        "district": "DULCE INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350081000252",
    },
    {
        "school": "DULCE HIGH",
        "district": "DULCE INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350081000253",
    },
    {
        "school": "DULCE MIDDLE",
        "district": "DULCE INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350081000716",
    },
    {
        "school": "ABIQUIU ELEMENTARY",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000259",
    },
    {
        "school": "ALCALDE ELEMENTARY",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000260",
    },
    {
        "school": "CHIMAYO ELEMENTARY",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000264",
    },
    {
        "school": "DIXON ELEMENTARY",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000265",
    },
    {
        "school": "JAMES RODRIGUEZ ELEMENTARY",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000266",
    },
    {
        "school": "ESPANOLA VALLEY HIGH",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000268",
    },
    {
        "school": "EUTIMIO SALAZAR ELEMENTARY",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000270",
    },
    {
        "school": "HERNANDEZ ELEMENTARY",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000271",
    },
    {
        "school": "SAN JUAN ELEMENTARY",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000275",
    },
    {
        "school": "TONY QUINTANA ELEMENTARY",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000276",
    },
    {
        "school": "VELARDE ELEMENTARY",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000277",
    },
    {
        "school": "LOS NINOS ELEMENTARY",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000685",
    },
    {
        "school": "CARLOS F. VIGIL MIDDLE",
        "district": "ESPANOLA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350090000814",
    },
    {
        "school": "EL RITO ELEMENTARY",
        "district": "MESA VISTA CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350198000474",
    },
    {
        "school": "MESA VISTA HIGH",
        "district": "MESA VISTA CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350198000475",
    },
    {
        "school": "OJO CALIENTE ELEMENTARY",
        "district": "MESA VISTA CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350198000476",
    },
    {
        "school": "MESA VISTA MIDDLE",
        "district": "MESA VISTA CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350198000705",
    },
    {
        "school": "CORONADO HIGH",
        "district": "JEMEZ MOUNTAIN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350138000366",
    },
    {
        "school": "GALLINA ELEMENTARY",
        "district": "JEMEZ MOUNTAIN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350138000368",
    },
    {
        "school": "LYBROOK ELEMENTARY",
        "district": "JEMEZ MOUNTAIN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350138000371",
    },
    {
        "school": "CORONADO MIDDLE",
        "district": "JEMEZ MOUNTAIN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350138000409",
    },
    {
        "school": "KIRTLAND PRE-K EARLY",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000947",
    },
    {
        "school": "MOSAIC ACADEMY CHARTER",
        "district": "AZTEC MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015000785",
    },
    {
        "school": "AZTEC HIGH",
        "district": "AZTEC MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015000135",
    },
    {
        "school": "C.V. KOOGLER MIDDLE",
        "district": "AZTEC MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015000136",
    },
    {
        "school": "MCCOY AVENUE ELEMENTARY",
        "district": "AZTEC MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015000137",
    },
    {
        "school": "PARK AVENUE ELEMENTARY",
        "district": "AZTEC MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015000138",
    },
    {
        "school": "LYDIA RIPPEY ELEMENTARY",
        "district": "AZTEC MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015000139",
    },
    {
        "school": "VISTA NUEVA HIGH",
        "district": "AZTEC MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350015000801",
    },
    {
        "school": "BLANCO ELEMENTARY",
        "district": "BLOOMFIELD SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350024000155",
    },
    {
        "school": "BLOOMFIELD HIGH",
        "district": "BLOOMFIELD SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350024000156",
    },
    {
        "school": "CENTRAL PRIMARY",
        "district": "BLOOMFIELD SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350024000157",
    },
    {
        "school": "MESA ALTA JR HIGH",
        "district": "BLOOMFIELD SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350024000158",
    },
    {
        "school": "BLOOMFIELD EARLY CHILDHOOD CENTER",
        "district": "BLOOMFIELD SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350024000609",
    },
    {
        "school": "NAABA ANI ELEMENTARY",
        "district": "BLOOMFIELD SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350024000651",
    },
    {
        "school": "CHARLIE Y. BROWN ALT",
        "district": "BLOOMFIELD SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350024000771",
    },
    {
        "school": "CENTRAL HIGH",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000179",
    },
    {
        "school": "KIRTLAND MIDDLE",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000180",
    },
    {
        "school": "MESA ELEMENTARY",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000181",
    },
    {
        "school": "NASCHITTI ELEMENTARY",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000182",
    },
    {
        "school": "NEWCOMB ELEMENTARY",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000183",
    },
    {
        "school": "NIZHONI ELEMENTARY",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000184",
    },
    {
        "school": "SHIPROCK HIGH",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000186",
    },
    {
        "school": "OJO AMARILLO ELEMENTARY",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000187",
    },
    {
        "school": "TSE'BIT'AI MIDDLE",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000189",
    },
    {
        "school": "NEWCOMB HIGH",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000654",
    },
    {
        "school": "NEWCOMB MIDDLE",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000684",
    },
    {
        "school": "KIRTLAND ELEMENTARY",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000712",
    },
    {
        "school": "CAREER PREP ALTERNATIVE",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350039000772",
    },
    {
        "school": "EVA B STOKELY ELEMENTARY",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039000773",
    },
    {
        "school": "ANIMAS ELEMENTARY",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000280",
    },
    {
        "school": "APACHE ELEMENTARY",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000281",
    },
    {
        "school": "BLUFFVIEW ELEMENTARY",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000282",
    },
    {
        "school": "COUNTRY CLUB ELEMENTARY",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000283",
    },
    {
        "school": "FARMINGTON HIGH",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000284",
    },
    {
        "school": "HEIGHTS MIDDLE SCHOOL",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000285",
    },
    {
        "school": "HERMOSA MIDDLE SCHOOL",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000286",
    },
    {
        "school": "LADERA DEL NORTE ELEMENTARY",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000287",
    },
    {
        "school": "MCCORMICK ELEMENTARY",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000288",
    },
    {
        "school": "MCKINLEY ELEMENTARY",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000289",
    },
    {
        "school": "MESA VERDE ELEMENTARY",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000290",
    },
    {
        "school": "NORTHEAST ELEMENTARY",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000291",
    },
    {
        "school": "TIBBETTS MIDDLE SCHOOL",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000293",
    },
    {
        "school": "MESA VIEW MIDDLE SCHOOL",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000601",
    },
    {
        "school": "ESPERANZA ELEMENTARY",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000693",
    },
    {
        "school": "ROCINANTE HIGH",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350099000740",
    },
    {
        "school": "PIEDRA VISTA HIGH",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099000787",
    },
    {
        "school": "FARMINGTON PRESCHOOL ACADEMY EAST",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NM",
        "nces_id": "350099030006",
    },
    {
        "school": "NAVAJO MIDDLE SCHOOL",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000861",
    },
    {
        "school": "CROWNPOINT MIDDLE",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000881",
    },
    {
        "school": "TSE'YI'GAI HIGH",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000907",
    },
    {
        "school": "CATHERINE A. MILLER ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000299",
    },
    {
        "school": "CROWNPOINT ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000300",
    },
    {
        "school": "CROWNPOINT HIGH",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000301",
    },
    {
        "school": "GALLUP HIGH",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000303",
    },
    {
        "school": "GALLUP MIDDLE",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000304",
    },
    {
        "school": "INDIAN HILLS ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000305",
    },
    {
        "school": "JEFFERSON ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000306",
    },
    {
        "school": "LINCOLN ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000308",
    },
    {
        "school": "NAVAJO ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000309",
    },
    {
        "school": "NAVAJO PINE HIGH",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000310",
    },
    {
        "school": "RAMAH ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000311",
    },
    {
        "school": "RED ROCK ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000312",
    },
    {
        "school": "THOREAU ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000315",
    },
    {
        "school": "THOREAU HIGH",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000316",
    },
    {
        "school": "TOHATCHI ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000317",
    },
    {
        "school": "TOHATCHI HIGH",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000318",
    },
    {
        "school": "TWIN LAKES ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000321",
    },
    {
        "school": "GALLUP CENTRAL ALTERNATIVE",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350111000545",
    },
    {
        "school": "ROCKY VIEW ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000546",
    },
    {
        "school": "JOHN F. KENNEDY MIDDLE",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000661",
    },
    {
        "school": "RAMAH HIGH",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000662",
    },
    {
        "school": "THOREAU MIDDLE",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000663",
    },
    {
        "school": "TOHATCHI MIDDLE",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000664",
    },
    {
        "school": "CHEE DODGE ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000732",
    },
    {
        "school": "MIYAMURA HIGH SCHOOL",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000768",
    },
    {
        "school": "TOBE TURPEN ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111000797",
    },
    {
        "school": "EDUCATION DEV CENTER",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Other",
        "type": "Special education school",
        "state": "NM",
        "nces_id": "350111000833",
    },
    {
        "school": "STAGECOACH ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111030020",
    },
    {
        "school": "DAVID SKEET ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111030021",
    },
    {
        "school": "ZUNI HIGH",
        "district": "ZUNI PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350280000676",
    },
    {
        "school": "TWIN BUTTES CYBER ACADEMY",
        "district": "ZUNI PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350280000677",
    },
    {
        "school": "ZUNI MIDDLE",
        "district": "ZUNI PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350280000678",
    },
    {
        "school": "BLUEWATER ELEMENTARY",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117000327",
    },
    {
        "school": "CUBERO ELEMENTARY",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117000328",
    },
    {
        "school": "GRANTS HIGH",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117000329",
    },
    {
        "school": "LAGUNA-ACOMA HIGH",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117000330",
    },
    {
        "school": "LOS ALAMITOS MIDDLE",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117000331",
    },
    {
        "school": "MESA VIEW ELEMENTARY",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117000332",
    },
    {
        "school": "MILAN ELEMENTARY",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117000333",
    },
    {
        "school": "MOUNT TAYLOR ELEMENTARY",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117000334",
    },
    {
        "school": "SAN RAFAEL ELEMENTARY",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117000336",
    },
    {
        "school": "SEBOYETA ELEMENTARY",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117000337",
    },
    {
        "school": "LAGUNA-ACOMA MIDDLE",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117000665",
    },
    {
        "school": "EUNICE HIGH",
        "district": "EUNICE MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350096000622",
    },
    {
        "school": "CATON MIDDLE",
        "district": "EUNICE MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350096000623",
    },
    {
        "school": "METTIE JORDAN ELEMENTARY",
        "district": "EUNICE MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350096000624",
    },
    {
        "school": "BROADMOOR ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000345",
    },
    {
        "school": "CORONADO ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000346",
    },
    {
        "school": "EDISON ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000347",
    },
    {
        "school": "HOBBS FRESHMAN HIGH",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000348",
    },
    {
        "school": "HIGHLAND MIDDLE SCHOOL",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000349",
    },
    {
        "school": "HOBBS HIGH",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000350",
    },
    {
        "school": "HOUSTON MIDDLE SCHOOL",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000351",
    },
    {
        "school": "JEFFERSON ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000352",
    },
    {
        "school": "MILLS ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000353",
    },
    {
        "school": "SANGER ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000354",
    },
    {
        "school": "SOUTHERN HEIGHTS ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000355",
    },
    {
        "school": "TAYLOR ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000356",
    },
    {
        "school": "B.T. WASHINGTON ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000357",
    },
    {
        "school": "WILL ROGERS ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000358",
    },
    {
        "school": "STONE ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000667",
    },
    {
        "school": "COLLEGE LANE ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126000686",
    },
    {
        "school": "JAL JR HIGH",
        "district": "JAL PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350135000363",
    },
    {
        "school": "JAL ELEMENTARY",
        "district": "JAL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350135000364",
    },
    {
        "school": "JAL HIGH",
        "district": "JAL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350135000365",
    },
    {
        "school": "LOVINGTON 6TH GRADE ACADEMY",
        "district": "LOVINGTON MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350174000444",
    },
    {
        "school": "JEFFERSON ELEMENTARY",
        "district": "LOVINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350174000445",
    },
    {
        "school": "LEA ELEMENTARY",
        "district": "LOVINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350174000446",
    },
    {
        "school": "LLANO ELEMENTARY",
        "district": "LOVINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350174000447",
    },
    {
        "school": "LOVINGTON HIGH",
        "district": "LOVINGTON MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350174000448",
    },
    {
        "school": "BEN ALEXANDER ELEMENTARY",
        "district": "LOVINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350174000449",
    },
    {
        "school": "TAYLOR MIDDLE",
        "district": "LOVINGTON MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350174000450",
    },
    {
        "school": "YARBRO ELEMENTARY",
        "district": "LOVINGTON MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350174000451",
    },
    {
        "school": "NEW HOPE ALTERNATIVE HIGH",
        "district": "LOVINGTON MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350174000796",
    },
    {
        "school": "TATUM ELEMENTARY",
        "district": "TATUM MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350255000585",
    },
    {
        "school": "TATUM HIGH",
        "district": "TATUM MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350255000586",
    },
    {
        "school": "TATUM JR HIGH",
        "district": "TATUM MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350255000587",
    },
    {
        "school": "SANTA TERESA ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000904",
    },
    {
        "school": "SUNRISE ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000905",
    },
    {
        "school": "VADO ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000934",
    },
    {
        "school": "CHAPARRAL HIGH",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000935",
    },
    {
        "school": "COLUMBIA ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000884",
    },
    {
        "school": "RIO GRANDE PREPARATORY INSTITUTE",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350150000932",
    },
    {
        "school": "CHAPARRAL MIDDLE",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000202",
    },
    {
        "school": "SANTA TERESA HIGH",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000323",
    },
    {
        "school": "ANTHONY ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000625",
    },
    {
        "school": "SUNLAND PARK ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000626",
    },
    {
        "school": "MESQUITE ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000628",
    },
    {
        "school": "LA UNION ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000629",
    },
    {
        "school": "GADSDEN MIDDLE",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000631",
    },
    {
        "school": "GADSDEN HIGH",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000632",
    },
    {
        "school": "DESERT TRAIL ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000655",
    },
    {
        "school": "LOMA LINDA ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000656",
    },
    {
        "school": "CHAPARRAL ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000659",
    },
    {
        "school": "SANTA TERESA MIDDLE",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000660",
    },
    {
        "school": "DESERT VIEW ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000700",
    },
    {
        "school": "RIVERSIDE ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108000719",
    },
    {
        "school": "BERINO ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108030017",
    },
    {
        "school": "GARFIELD ELEMENTARY",
        "district": "HATCH VALLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350123000342",
    },
    {
        "school": "HATCH VALLEY ELEMENTARY",
        "district": "HATCH VALLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350123000343",
    },
    {
        "school": "HATCH VALLEY HIGH",
        "district": "HATCH VALLEY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350123000344",
    },
    {
        "school": "HATCH VALLEY MIDDLE",
        "district": "HATCH VALLEY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350123000666",
    },
    {
        "school": "RIO GRANDE ELEMENTARY",
        "district": "HATCH VALLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350123000753",
    },
    {
        "school": "ALAMEDA ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000376",
    },
    {
        "school": "VISTA MIDDLE",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000377",
    },
    {
        "school": "CENTRAL ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000379",
    },
    {
        "school": "CONLEE ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000380",
    },
    {
        "school": "DONA ANA ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000382",
    },
    {
        "school": "FAIRACRES ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000383",
    },
    {
        "school": "HERMOSA HGTS ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000384",
    },
    {
        "school": "JORNADA ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000385",
    },
    {
        "school": "LAS CRUCES HIGH",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000386",
    },
    {
        "school": "LOMA HEIGHTS ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000387",
    },
    {
        "school": "LYNN MIDDLE",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000388",
    },
    {
        "school": "MAC ARTHUR ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000389",
    },
    {
        "school": "MAYFIELD HIGH",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000390",
    },
    {
        "school": "MESILLA ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000392",
    },
    {
        "school": "MESILLA PARK ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000393",
    },
    {
        "school": "UNIVERSITY HILLS ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000394",
    },
    {
        "school": "VALLEY VIEW ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000395",
    },
    {
        "school": "BOOKER T. WASHINGTON",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000396",
    },
    {
        "school": "WHITE SANDS ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000397",
    },
    {
        "school": "ZIA MIDDLE",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000399",
    },
    {
        "school": "SIERRA MIDDLE",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000455",
    },
    {
        "school": "DESERT HILLS ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000649",
    },
    {
        "school": "PICACHO MIDDLE",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000669",
    },
    {
        "school": "EAST PICACHO ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000688",
    },
    {
        "school": "HILLRISE ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000689",
    },
    {
        "school": "HIGHLAND ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000702",
    },
    {
        "school": "ONATE HIGH",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000720",
    },
    {
        "school": "SUNRISE ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000730",
    },
    {
        "school": "CAMINO REAL MIDDLE",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000765",
    },
    {
        "school": "CESAR CHAVEZ ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150000794",
    },
    {
        "school": "TOMBAUGH ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150030009",
    },
    {
        "school": "LVCS EARLY CHILDHOOD",
        "district": "LAS VEGAS CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350153000863",
    },
    {
        "school": "RIO GALLINAS SCHOOL",
        "district": "WEST LAS VEGAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350156000911",
    },
    {
        "school": "LOS NINOS ELEMENTARY",
        "district": "LAS VEGAS CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350153000402",
    },
    {
        "school": "7TH AND 8TH GRADE ACADEMY",
        "district": "LAS VEGAS CITY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350153000403",
    },
    {
        "school": "ROBERTSON HIGH",
        "district": "LAS VEGAS CITY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350153000406",
    },
    {
        "school": "MIKE SENA ELEMENTARY",
        "district": "LAS VEGAS CITY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350153000407",
    },
    {
        "school": "SIERRA VISTA ELEMENTARY",
        "district": "LAS VEGAS CITY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350153000721",
    },
    {
        "school": "LUIS E. ARMIJO ELEMENTARY",
        "district": "WEST LAS VEGAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350156000408",
    },
    {
        "school": "DON CECILIO MARTINEZ ELEMENTARY",
        "district": "WEST LAS VEGAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350156000411",
    },
    {
        "school": "TONY SERNA JR. ELEMENTARY",
        "district": "WEST LAS VEGAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350156000412",
    },
    {
        "school": "VALLEY ELEMENTARY",
        "district": "WEST LAS VEGAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350156000415",
    },
    {
        "school": "VALLEY MIDDLE",
        "district": "WEST LAS VEGAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350156000416",
    },
    {
        "school": "WEST LAS VEGAS HIGH SCHOOL",
        "district": "WEST LAS VEGAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350156000418",
    },
    {
        "school": "WEST LAS VEGAS MIDDLE SCHOOL",
        "district": "WEST LAS VEGAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350156000419",
    },
    {
        "school": "UNION ELEMENTARY",
        "district": "WEST LAS VEGAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350156000635",
    },
    {
        "school": "WLV FAMILY PARTNERSHIP",
        "district": "WEST LAS VEGAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350156000815",
    },
    {
        "school": "PECOS HIGH",
        "district": "PECOS INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350201000478",
    },
    {
        "school": "PECOS ELEMENTARY",
        "district": "PECOS INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350201000479",
    },
    {
        "school": "PECOS MIDDLE",
        "district": "PECOS INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350201000706",
    },
    {
        "school": "ASPEN ELEMENTARY",
        "district": "LOS ALAMOS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350165000427",
    },
    {
        "school": "BARRANCA MESA ELEMENTARY",
        "district": "LOS ALAMOS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350165000428",
    },
    {
        "school": "CHAMISA ELEMENTARY",
        "district": "LOS ALAMOS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350165000429",
    },
    {
        "school": "LOS ALAMOS MIDDLE",
        "district": "LOS ALAMOS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350165000430",
    },
    {
        "school": "LOS ALAMOS HIGH",
        "district": "LOS ALAMOS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350165000431",
    },
    {
        "school": "MOUNTAIN ELEMENTARY",
        "district": "LOS ALAMOS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350165000433",
    },
    {
        "school": "PINON ELEMENTARY",
        "district": "LOS ALAMOS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350165000434",
    },
    {
        "school": "DORA ELEMENTARY",
        "district": "DORA MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350079000250",
    },
    {
        "school": "DORA HIGH",
        "district": "DORA MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350079000251",
    },
    {
        "school": "ELIDA ELEMENTARY",
        "district": "ELIDA MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350084000255",
    },
    {
        "school": "ELIDA HIGH",
        "district": "ELIDA MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350084000256",
    },
    {
        "school": "FLOYD ELEMENTARY",
        "district": "FLOYD MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350102000294",
    },
    {
        "school": "FLOYD HIGH",
        "district": "FLOYD MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350102000295",
    },
    {
        "school": "FLOYD MIDDLE",
        "district": "FLOYD MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350102000770",
    },
    {
        "school": "VALENCIA ELEMENTARY",
        "district": "PORTALES MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350210000417",
    },
    {
        "school": "BROWN EARLY CHILDHOOD CENTER",
        "district": "PORTALES MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350210000485",
    },
    {
        "school": "JAMES ELEMENTARY",
        "district": "PORTALES MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350210000486",
    },
    {
        "school": "PORTALES HIGH",
        "district": "PORTALES MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350210000488",
    },
    {
        "school": "PORTALES JR HIGH",
        "district": "PORTALES MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350210000489",
    },
    {
        "school": "DEXTER ELEMENTARY",
        "district": "DEXTER CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350075000247",
    },
    {
        "school": "DEXTER HIGH",
        "district": "DEXTER CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350075000248",
    },
    {
        "school": "DEXTER MIDDLE",
        "district": "DEXTER CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350075000249",
    },
    {
        "school": "HAGERMAN ELEMENTARY",
        "district": "HAGERMAN MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350120000339",
    },
    {
        "school": "HAGERMAN HIGH",
        "district": "HAGERMAN MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350120000340",
    },
    {
        "school": "HAGERMAN MIDDLE",
        "district": "HAGERMAN MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350120000341",
    },
    {
        "school": "LAKE ARTHUR ELEMENTARY",
        "district": "LAKE ARTHUR MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350147000374",
    },
    {
        "school": "LAKE ARTHUR HIGH",
        "district": "LAKE ARTHUR MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350147000375",
    },
    {
        "school": "LAKE ARTHUR MIDDLE",
        "district": "LAKE ARTHUR MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350147000701",
    },
    {
        "school": "BERRENDO ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000505",
    },
    {
        "school": "BERRENDO MIDDLE",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000506",
    },
    {
        "school": "DEL NORTE ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000508",
    },
    {
        "school": "EAST GRAND PLAINS ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000509",
    },
    {
        "school": "EL CAPITAN ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000511",
    },
    {
        "school": "NANCY LOPEZ ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000512",
    },
    {
        "school": "GODDARD HIGH",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000513",
    },
    {
        "school": "MESA MIDDLE",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000514",
    },
    {
        "school": "MILITARY HGTS ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000515",
    },
    {
        "school": "MISSOURI AVE ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000516",
    },
    {
        "school": "MONTERREY ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000517",
    },
    {
        "school": "MOUNTAIN VIEW MIDDLE",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000518",
    },
    {
        "school": "PARKVIEW EARLY LITERACY CENTER",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000519",
    },
    {
        "school": "PECOS ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000520",
    },
    {
        "school": "ROSWELL HIGH",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000521",
    },
    {
        "school": "SIERRA MIDDLE",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000522",
    },
    {
        "school": "SUNSET ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000523",
    },
    {
        "school": "VALLEY VIEW ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000524",
    },
    {
        "school": "WASHINGTON AVE ELEMENTARY",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000525",
    },
    {
        "school": "UNIVERSITY HIGH",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350225000696",
    },
    {
        "school": "SIDNEY GUTIERREZ MIDDLE",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225000826",
    },
    {
        "school": "RAMIREZ THOMAS ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000887",
    },
    {
        "school": "PABLO ROYBAL ELEMENTARY",
        "district": "POJOAQUE VALLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350207000482",
    },
    {
        "school": "POJOAQUE HIGH",
        "district": "POJOAQUE VALLEY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350207000483",
    },
    {
        "school": "POJOAQUE MIDDLE",
        "district": "POJOAQUE VALLEY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350207000484",
    },
    {
        "school": "POJOAQUE INTERMEDIATE",
        "district": "POJOAQUE VALLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350207000723",
    },
    {
        "school": "ACEQUIA MADRE ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000534",
    },
    {
        "school": "EL CAMINO REAL ACADEMY COMMUNITY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000535",
    },
    {
        "school": "ATALAYA ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000537",
    },
    {
        "school": "CARLOS GILBERT ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000538",
    },
    {
        "school": "CHAPARRAL ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000539",
    },
    {
        "school": "E.J. MARTINEZ ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000541",
    },
    {
        "school": "FRANCIS X. NAVA ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000542",
    },
    {
        "school": "GONZALES ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000543",
    },
    {
        "school": "KEARNY ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000548",
    },
    {
        "school": "SALAZAR ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000550",
    },
    {
        "school": "SANTA FE HIGH",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000551",
    },
    {
        "school": "TESUQUE ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000552",
    },
    {
        "school": "WOOD-GORMLEY ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000553",
    },
    {
        "school": "EDWARD ORTIZ MIDDLE",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000610",
    },
    {
        "school": "PINON ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000641",
    },
    {
        "school": "EL DORADO COMMUNITY SCHOOL",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000644",
    },
    {
        "school": "R.M. SWEENEY ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000645",
    },
    {
        "school": "CAPITAL HIGH",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000724",
    },
    {
        "school": "CESAR CHAVEZ ELEMENTARY",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000759",
    },
    {
        "school": "ACADEMY AT LARRAGOITE",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350237000788",
    },
    {
        "school": "ACADEMY FOR TECH & CLASS",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237000841",
    },
    {
        "school": "NYE EARLY CHILDHOOD",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237030025",
    },
    {
        "school": "BAYARD ELEMENTARY",
        "district": "COBRE CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350060000225",
    },
    {
        "school": "CENTRAL ELEMENTARY",
        "district": "COBRE CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350060000226",
    },
    {
        "school": "COBRE HIGH",
        "district": "COBRE CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350060000227",
    },
    {
        "school": "HURLEY ELEMENTARY",
        "district": "COBRE CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350060000228",
    },
    {
        "school": "SAN LORENZO ELEMENTARY",
        "district": "COBRE CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350060000229",
    },
    {
        "school": "SNELL MIDDLE",
        "district": "COBRE CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350060000230",
    },
    {
        "school": "CLIFF ELEMENTARY",
        "district": "SILVER CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350243000559",
    },
    {
        "school": "CLIFF HIGH",
        "district": "SILVER CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350243000560",
    },
    {
        "school": "HARRISON SCHMITT ELEMENTARY",
        "district": "SILVER CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350243000561",
    },
    {
        "school": "JOSE BARRIOS ELEMENTARY",
        "district": "SILVER CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350243000562",
    },
    {
        "school": "LA PLATA MIDDLE",
        "district": "SILVER CONSOLIDATED SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350243000563",
    },
    {
        "school": "SILVER HIGH",
        "district": "SILVER CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350243000564",
    },
    {
        "school": "SIXTH STREET ELEMENTARY",
        "district": "SILVER CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350243000565",
    },
    {
        "school": "G.W.STOUT ELEMENTARY",
        "district": "SILVER CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350243000566",
    },
    {
        "school": "CHRYSALIS ALTERNATIVE",
        "district": "TAOS MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350252000914",
    },
    {
        "school": "TAOS CYBER MAGNET",
        "district": "TAOS MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350252000951",
    },
    {
        "school": "PENASCO ELEMENTARY",
        "district": "PENASCO INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350204000480",
    },
    {
        "school": "PENASCO HIGH",
        "district": "PENASCO INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350204000481",
    },
    {
        "school": "PENASCO MIDDLE",
        "district": "PENASCO INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350204000695",
    },
    {
        "school": "RIO COSTILLA SW LEARNING ACADEMY",
        "district": "QUESTA INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350216000494",
    },
    {
        "school": "ALTA VISTA INTERMEDIATE",
        "district": "QUESTA INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350216000495",
    },
    {
        "school": "QUESTA HIGH",
        "district": "QUESTA INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350216000496",
    },
    {
        "school": "QUESTA JR HIGH",
        "district": "QUESTA INDEPENDENT SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350216000687",
    },
    {
        "school": "ALTA VISTA ELEMENTARY",
        "district": "QUESTA INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350216000804",
    },
    {
        "school": "ENOS GARCIA ELEMENTARY",
        "district": "TAOS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350252000579",
    },
    {
        "school": "RANCHOS DE TAOS ELEMENTARY",
        "district": "TAOS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350252000580",
    },
    {
        "school": "TAOS HIGH",
        "district": "TAOS MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350252000583",
    },
    {
        "school": "TAOS MIDDLE",
        "district": "TAOS MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350252000584",
    },
    {
        "school": "ARROYO DEL NORTE ELEMENTARY",
        "district": "TAOS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350252000790",
    },
    {
        "school": "TAOS MUNICIPAL CHARTER",
        "district": "TAOS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350252000817",
    },
    {
        "school": "ANANSI CHARTER SCHOOL",
        "district": "TAOS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350252000844",
    },
    {
        "school": "Imagine 100 Academy of Excellence",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000670",
    },
    {
        "school": "Carroll M Johnston Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000672",
    },
    {
        "school": "Don E Hayden Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000679",
    },
    {
        "school": "Steve Schorr Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000689",
    },
    {
        "school": "Sandra L Thompson Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000690",
    },
    {
        "school": "Kitty McDonough Ward Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000695",
    },
    {
        "school": "Lois & Jerry Tarkanian Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000700",
    },
    {
        "school": "Legacy High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000714",
    },
    {
        "school": "William V Wright Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000716",
    },
    {
        "school": "Innovations International Charter School of NV",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000717",
    },
    {
        "school": "Judith D Steele Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000722",
    },
    {
        "school": "Carlin Junior High School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000674",
    },
    {
        "school": "Owyhee Junior High School (all NV & Idaho only)",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000684",
    },
    {
        "school": "Wells Junior High School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000685",
    },
    {
        "school": "Jackpot Junior High School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000692",
    },
    {
        "school": "Owyhee Elementary School (all NV & Idaho only)",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000727",
    },
    {
        "school": "West Wendover Middle School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000728",
    },
    {
        "school": "Mc Dermitt Junior High School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000708",
    },
    {
        "school": "East Valley Elementary",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000704",
    },
    {
        "school": "Cold Springs Middle Schools",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000673",
    },
    {
        "school": "Coral Academy Elementary",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000682",
    },
    {
        "school": "Miguel Sepulveda Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000706",
    },
    {
        "school": "Jesse Hall Elementery School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000723",
    },
    {
        "school": "Lund Elementary School",
        "district": "WHITE PINE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320051000720",
    },
    {
        "school": "Silver Stage High School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000555",
    },
    {
        "school": "Lund High School",
        "district": "WHITE PINE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320051000606",
    },
    {
        "school": "Dyer Elementary School",
        "district": "ESMERALDA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320015000143",
    },
    {
        "school": "Goldfield Elementary School",
        "district": "ESMERALDA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320015000144",
    },
    {
        "school": "Silver Peak Elementary School",
        "district": "ESMERALDA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320015000145",
    },
    {
        "school": "Albert M Lowry High School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000149",
    },
    {
        "school": "Denio Elementary School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000150",
    },
    {
        "school": "Kings River Elementary School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000151",
    },
    {
        "school": "Mc Dermitt Elementary School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000153",
    },
    {
        "school": "Mc Dermitt High School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000154",
    },
    {
        "school": "Orovada Elementary School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000155",
    },
    {
        "school": "Paradise Valley Elementary School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000156",
    },
    {
        "school": "Sonoma Heights Elementary School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000157",
    },
    {
        "school": "Winnemucca Grammar School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000158",
    },
    {
        "school": "Winnemucca Junior High School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000159",
    },
    {
        "school": "Grass Valley Elementary School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000325",
    },
    {
        "school": "French Ford Middle School",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320021000416",
    },
    {
        "school": "Austin School",
        "district": "LANDER COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320024000162",
    },
    {
        "school": "Battle Mountain High School",
        "district": "LANDER COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320024000163",
    },
    {
        "school": "Battle Mountain Elementary School",
        "district": "LANDER COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320024000165",
    },
    {
        "school": "Caliente Elementary School",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320027000166",
    },
    {
        "school": "Lincoln County High School",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320027000168",
    },
    {
        "school": "C O Bastian (Caliente Youth Center)",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320027000169",
    },
    {
        "school": "Pahranagat Valley Elementary School",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320027000170",
    },
    {
        "school": "Pahranagat Valley High School",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320027000171",
    },
    {
        "school": "Panaca Elementary School",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320027000172",
    },
    {
        "school": "Pioche Elementary School",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320027000173",
    },
    {
        "school": "Meadow Valley Middle School",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320027000410",
    },
    {
        "school": "Pahranagat Valley Middle School",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320027000423",
    },
    {
        "school": "Dayton Elementary School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000174",
    },
    {
        "school": "Fernley Elementary School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000175",
    },
    {
        "school": "Fernley High School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000176",
    },
    {
        "school": "Smith Valley Schools",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000178",
    },
    {
        "school": "Yerington Elementary School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000179",
    },
    {
        "school": "Yerington High School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000180",
    },
    {
        "school": "Silver Stage Elementary School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000299",
    },
    {
        "school": "Dayton High School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000310",
    },
    {
        "school": "Fernley Intermediate School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000311",
    },
    {
        "school": "Yerington Intermediate School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000312",
    },
    {
        "school": "Dayton Intermediate School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000386",
    },
    {
        "school": "Cottonwood Elementary School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000387",
    },
    {
        "school": "Silver Stage Middle School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000424",
    },
    {
        "school": "Sutro Elementary School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000450",
    },
    {
        "school": "Mineral County High School",
        "district": "MINERAL COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320033000183",
    },
    {
        "school": "Schurz Elementary School",
        "district": "MINERAL COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320033000184",
    },
    {
        "school": "Hawthorne Junior High School",
        "district": "MINERAL COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320033000479",
    },
    {
        "school": "Pershing County Middle School",
        "district": "PERSHING COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320042000167",
    },
    {
        "school": "Imlay Elementary School",
        "district": "PERSHING COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320042000196",
    },
    {
        "school": "Lovelock Elementary School",
        "district": "PERSHING COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320042000197",
    },
    {
        "school": "Pershing County High School (and alternative ed)",
        "district": "PERSHING COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320042000198",
    },
    {
        "school": "Baker Elementary School",
        "district": "WHITE PINE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320051000254",
    },
    {
        "school": "David E Norman Elementary School",
        "district": "WHITE PINE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320051000255",
    },
    {
        "school": "White Pine Middle School",
        "district": "WHITE PINE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320051000256",
    },
    {
        "school": "McGill Elementary School",
        "district": "WHITE PINE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320051000263",
    },
    {
        "school": "White Pine High School",
        "district": "WHITE PINE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320051000267",
    },
    {
        "school": "Steptoe Valley High School",
        "district": "WHITE PINE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320051000483",
    },
    {
        "school": "Nevada State High School Henderson",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100608",
    },
    {
        "school": "Carson City Montessori Charter School",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320039000569",
    },
    {
        "school": "Mark Twain Elementary School",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320039000160",
    },
    {
        "school": "Carson High School",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320039000280",
    },
    {
        "school": "Carson Middle School",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320039000281",
    },
    {
        "school": "Al Seeliger Elementary School",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320039000282",
    },
    {
        "school": "J C  Fremont Elementary School",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320039000285",
    },
    {
        "school": "Edith West Fritsch Elementary School",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320039000286",
    },
    {
        "school": "Grace Bordewich Mildred Bray Elementary",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320039000288",
    },
    {
        "school": "Eagle Valley Middle School",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320039000315",
    },
    {
        "school": "Empire Elementary School",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320039000364",
    },
    {
        "school": "Pioneer (Alternative) High School",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320039000480",
    },
    {
        "school": "Carlin High School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000568",
    },
    {
        "school": "Jackpot High School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000579",
    },
    {
        "school": "Owyhee High School (all NV & Idaho only)",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000610",
    },
    {
        "school": "Wells High School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000622",
    },
    {
        "school": "Carlin Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000125",
    },
    {
        "school": "Jackpot Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000132",
    },
    {
        "school": "Wells Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000141",
    },
    {
        "school": "Elko Grammar School #2",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000129",
    },
    {
        "school": "Elko High School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000130",
    },
    {
        "school": "Independence Valley Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000131",
    },
    {
        "school": "Mound Valley Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000134",
    },
    {
        "school": "Northside Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000135",
    },
    {
        "school": "Ruby Valley Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000139",
    },
    {
        "school": "Southside Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000140",
    },
    {
        "school": "West Wendover Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000308",
    },
    {
        "school": "Adobe Middle School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000326",
    },
    {
        "school": "Spring Creek High",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000330",
    },
    {
        "school": "Mountain View Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000349",
    },
    {
        "school": "Spring Creek Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000350",
    },
    {
        "school": "Sage Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000385",
    },
    {
        "school": "West Wendover High School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000449",
    },
    {
        "school": "Spring Creek Middle School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000464",
    },
    {
        "school": "Crescent Valley Elementary School",
        "district": "EUREKA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320018000146",
    },
    {
        "school": "Eureka Elementary School",
        "district": "EUREKA COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320018000147",
    },
    {
        "school": "Eureka County High School",
        "district": "EUREKA COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320018000148",
    },
    {
        "school": "Churchill County High School",
        "district": "CHURCHILL COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320003000001",
    },
    {
        "school": "Churchill County Middle School",
        "district": "CHURCHILL COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320003000003",
    },
    {
        "school": "E C  Best Elementary School",
        "district": "CHURCHILL COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320003000004",
    },
    {
        "school": "Lahontan Elementary School",
        "district": "CHURCHILL COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320003000021",
    },
    {
        "school": "Numa Elementary",
        "district": "CHURCHILL COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320003000431",
    },
    {
        "school": "Northside Early Learning Center",
        "district": "CHURCHILL COUNTY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320003000005",
    },
    {
        "school": "Carson Valley Middle School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320009000119",
    },
    {
        "school": "Douglas County High School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320009000120",
    },
    {
        "school": "Gardnerville Elementary School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320009000121",
    },
    {
        "school": "George Whittell High School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320009000122",
    },
    {
        "school": "Zephyr Cove Elementary School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320009000124",
    },
    {
        "school": "C C Meneley Elementary School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320009000293",
    },
    {
        "school": "Jacks Valley Elementary School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320009000307",
    },
    {
        "school": "Gene Scarselli Elementary School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320009000347",
    },
    {
        "school": "Jacobsen High (China Spring YC)",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320009000348",
    },
    {
        "school": "Pau Wa Lu Middle School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320009000422",
    },
    {
        "school": "Pinon Hills Elementary",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320009000447",
    },
    {
        "school": "Minden Elementary School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320009000448",
    },
    {
        "school": "Tony Alamo Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000547",
    },
    {
        "school": "Eileen Brookman Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000548",
    },
    {
        "school": "Steve Cozine Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000549",
    },
    {
        "school": "Roger D Gehring Academy of Science and Technology",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000550",
    },
    {
        "school": "Mervin Iverson Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000551",
    },
    {
        "school": "Marlan J. Walker Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000552",
    },
    {
        "school": "Kathleen & Tim Harney Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000553",
    },
    {
        "school": "Victoria Fertitta Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000554",
    },
    {
        "school": "Anthony Saville Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000565",
    },
    {
        "school": "Canyon Springs High School and the Leadership and Law Prepar",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000567",
    },
    {
        "school": "Clifford O Findlay Middle",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000570",
    },
    {
        "school": "Del Sol Academy of the Performing Arts",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000571",
    },
    {
        "school": "Desert Willow Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320006000572",
    },
    {
        "school": "Eileen Conners Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000573",
    },
    {
        "school": "Eva G Simmons Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000574",
    },
    {
        "school": "Indian Springs Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000577",
    },
    {
        "school": "Jack & Terry Mannion Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000578",
    },
    {
        "school": "John R Hummel Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000580",
    },
    {
        "school": "Judy & John L Goolsby Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000581",
    },
    {
        "school": "Child Haven",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000582",
    },
    {
        "school": "Glen C. Taylor Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000583",
    },
    {
        "school": "Richard C. Priest Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000584",
    },
    {
        "school": "James Bilbray Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000585",
    },
    {
        "school": "Charles & Phyllis Frias Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000586",
    },
    {
        "school": "Howard E Hollingsworth Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000587",
    },
    {
        "school": "Sandy Searles Miller Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000588",
    },
    {
        "school": "Dean Petersen Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000589",
    },
    {
        "school": "Ralph Cadwallader Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000590",
    },
    {
        "school": "Lawrence & Heidi Canarelli Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000591",
    },
    {
        "school": "Charles Arthur Hughes Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000592",
    },
    {
        "school": "Shadow Ridge High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000595",
    },
    {
        "school": "Explore Knowledge Academy Charter Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000596",
    },
    {
        "school": "Cowan Academic Center",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000597",
    },
    {
        "school": "Peterson Academic Center",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000598",
    },
    {
        "school": "Liberty High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000604",
    },
    {
        "school": "Linda Rankin Givens Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000605",
    },
    {
        "school": "Miley Achievement Center ES",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320006000607",
    },
    {
        "school": "Odyssey Charter High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000609",
    },
    {
        "school": "Sandy Valley Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000612",
    },
    {
        "school": "Spring Valley High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000616",
    },
    {
        "school": "Variety Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320006000619",
    },
    {
        "school": "Wayne N Tanaka Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000621",
    },
    {
        "school": "William & Mary Scherkenbach Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000623",
    },
    {
        "school": "John Tartan Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000652",
    },
    {
        "school": "Joseph E Thiriot Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000653",
    },
    {
        "school": "Kathy L. Batterman Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000654",
    },
    {
        "school": "Aldeane Comito Ries Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000655",
    },
    {
        "school": "Liliam Lujan Hickey Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000656",
    },
    {
        "school": "Jay W. Jeffers Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000657",
    },
    {
        "school": "Theron H & Naomi D Goynes Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000658",
    },
    {
        "school": "Del E Webb Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000659",
    },
    {
        "school": "Jerome Mack Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000660",
    },
    {
        "school": "Arbor View High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000661",
    },
    {
        "school": "Dr. William (Bob) H  Bailey Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000663",
    },
    {
        "school": "Variety School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320006000108",
    },
    {
        "school": "Sandy Valley Jr/Sr High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000304",
    },
    {
        "school": "Harry Reid Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000099",
    },
    {
        "school": "Basic Academy of Int'l Studies HS",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000007",
    },
    {
        "school": "Bertha Ronzone Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000008",
    },
    {
        "school": "Bill Y Tomiyasu Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000009",
    },
    {
        "school": "Blue Diamond Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000010",
    },
    {
        "school": "Bonanza High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000011",
    },
    {
        "school": "Andrew Mitchell Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000012",
    },
    {
        "school": "Boulder City High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000013",
    },
    {
        "school": "C C Ronnow Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000014",
    },
    {
        "school": "C P Squires Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000015",
    },
    {
        "school": "C V T  Gilbert Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000016",
    },
    {
        "school": "C W Woodbury Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000017",
    },
    {
        "school": "Chaparral High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000018",
    },
    {
        "school": "C T Sewell Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000019",
    },
    {
        "school": "Juvenile Detention",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000020",
    },
    {
        "school": "C H Decker Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000022",
    },
    {
        "school": "Crestwood Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000023",
    },
    {
        "school": "Cyril Wengert Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000024",
    },
    {
        "school": "Dell H Robison Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000025",
    },
    {
        "school": "Doris French Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000026",
    },
    {
        "school": "Doris Hancock Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000027",
    },
    {
        "school": "E W Griffith Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000028",
    },
    {
        "school": "Ed Von Tobel Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000029",
    },
    {
        "school": "Ed W Clark High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000030",
    },
    {
        "school": "Elbert Edwards Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000031",
    },
    {
        "school": "Eldorado High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000032",
    },
    {
        "school": "Fay Herron Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000033",
    },
    {
        "school": "Frank F Garside Junior High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000034",
    },
    {
        "school": "Gene Ward Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000035",
    },
    {
        "school": "George E Harris Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000036",
    },
    {
        "school": "Goodsprings Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000037",
    },
    {
        "school": "Gordon McCaw Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000038",
    },
    {
        "school": "Halle Hewetson Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000039",
    },
    {
        "school": "Harley Harmon Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000040",
    },
    {
        "school": "Harvey N  Dondero Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000041",
    },
    {
        "school": "Helen C Cannon Junior High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000042",
    },
    {
        "school": "Helen M Smith Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000044",
    },
    {
        "school": "Selma F Bartlett Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000045",
    },
    {
        "school": "Howard Wasden Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000046",
    },
    {
        "school": "Hyde Park Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000047",
    },
    {
        "school": "Ira J Earl Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000050",
    },
    {
        "school": "J D Smith Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000051",
    },
    {
        "school": "J. E. Manch Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000052",
    },
    {
        "school": "J  Harold Brinley Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000053",
    },
    {
        "school": "J M Ullom Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000054",
    },
    {
        "school": "J T McWilliams Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000055",
    },
    {
        "school": "James Cashman Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000056",
    },
    {
        "school": "Jim Bridger Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000057",
    },
    {
        "school": "Jo Mackey Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000058",
    },
    {
        "school": "John C  Fremont MS",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000059",
    },
    {
        "school": "Patricia A Bendorf Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000060",
    },
    {
        "school": "John S Park Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000061",
    },
    {
        "school": "K O Knudson Junior High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000062",
    },
    {
        "school": "Kermit R Booker Sr Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000063",
    },
    {
        "school": "Kit Carson Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000064",
    },
    {
        "school": "Las Vegas High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000065",
    },
    {
        "school": "Laura Dearing Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000066",
    },
    {
        "school": "Lewis E Rowe Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000067",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000068",
    },
    {
        "school": "Lois Craig Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000069",
    },
    {
        "school": "Mabel Hoggard Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000072",
    },
    {
        "school": "Wendell P. Williams Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000073",
    },
    {
        "school": "Marion E  Cahlan Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000074",
    },
    {
        "school": "Matt Kelly Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000075",
    },
    {
        "school": "Jim Thorpe Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000076",
    },
    {
        "school": "Lee Antonello Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000077",
    },
    {
        "school": "Moapa Valley High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000078",
    },
    {
        "school": "Mountain View Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000079",
    },
    {
        "school": "Earl B Lundy Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000080",
    },
    {
        "school": "Myrtle Tate Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000081",
    },
    {
        "school": "O K Adcock Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000082",
    },
    {
        "school": "Theron L Swainston Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000084",
    },
    {
        "school": "Paradise Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000085",
    },
    {
        "school": "P A  Diskin Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000086",
    },
    {
        "school": "Paul E Culley Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000087",
    },
    {
        "school": "Quannah McCall Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000088",
    },
    {
        "school": "Rancho High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000089",
    },
    {
        "school": "Red Rock Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000090",
    },
    {
        "school": "Rex Bell Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000091",
    },
    {
        "school": "Robert E Lake Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000092",
    },
    {
        "school": "Robert L Taylor Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000093",
    },
    {
        "school": "Robert O Gibson Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000094",
    },
    {
        "school": "Rose Warren Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000095",
    },
    {
        "school": "Roy West Martin Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000096",
    },
    {
        "school": "Ruby S Thomas Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000097",
    },
    {
        "school": "Ruth Fyfe Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000098",
    },
    {
        "school": "Spring Mountain J/SHS",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000101",
    },
    {
        "school": "Sunrise Acres Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000102",
    },
    {
        "school": "Morris Sunset East High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000103",
    },
    {
        "school": "Tom Williams Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000104",
    },
    {
        "school": "Twin Lakes Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000105",
    },
    {
        "school": "Vail Pittman Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000106",
    },
    {
        "school": "Valley High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000107",
    },
    {
        "school": "Vegas Verdes Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000109",
    },
    {
        "school": "Virgin Valley Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000110",
    },
    {
        "school": "Virgin Valley High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000111",
    },
    {
        "school": "Walter Bracken Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000112",
    },
    {
        "school": "Walter V Long Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000113",
    },
    {
        "school": "Western High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000114",
    },
    {
        "school": "Whitney Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000115",
    },
    {
        "school": "Will Beckley Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000116",
    },
    {
        "school": "William E Orr Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000117",
    },
    {
        "school": "WIlliam E  Ferron Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000118",
    },
    {
        "school": "Thurman White Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000127",
    },
    {
        "school": "James B McMillan Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000259",
    },
    {
        "school": "Dorothy Eisenberg Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000260",
    },
    {
        "school": "Marc Kahre Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000264",
    },
    {
        "school": "Edythe & Lloyd Katz Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000265",
    },
    {
        "school": "William Lummis Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000266",
    },
    {
        "school": "Louis Wiener Jr Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000268",
    },
    {
        "school": "H P Fitzgerald Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000269",
    },
    {
        "school": "Zel & Mary Lowman Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000270",
    },
    {
        "school": "Piggott Academy of International Studies",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000271",
    },
    {
        "school": "Ulis Newton Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000272",
    },
    {
        "school": "Ernest Becker Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000273",
    },
    {
        "school": "Grant Sawyer Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000274",
    },
    {
        "school": "Mack Lyon Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000275",
    },
    {
        "school": "Durango High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000276",
    },
    {
        "school": "Las Vegas Academy of Arts",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000277",
    },
    {
        "school": "Kenny C Guinn Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000289",
    },
    {
        "school": "Fay Galloway Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000290",
    },
    {
        "school": "Elton M Garrett Junior High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000291",
    },
    {
        "school": "Oran K Gragson Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000292",
    },
    {
        "school": "Clark County Detention Center",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000294",
    },
    {
        "school": "Nate Mack Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000297",
    },
    {
        "school": "R Guild Gray Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000298",
    },
    {
        "school": "B  Mahlon Brown Junior High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000301",
    },
    {
        "school": "Grant Bowler Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000302",
    },
    {
        "school": "R E Tobler Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000303",
    },
    {
        "school": "Burk Horizon Southwest Sunset HS",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000313",
    },
    {
        "school": "Global Community HS at Morris Hall",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000328",
    },
    {
        "school": "Cowan Sunset Southeast HS",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000329",
    },
    {
        "school": "William G Bennett Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000331",
    },
    {
        "school": "Clyde C Cox Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000337",
    },
    {
        "school": "Stanford Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000338",
    },
    {
        "school": "Doris M Reed Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000339",
    },
    {
        "school": "Marion B Earl Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000340",
    },
    {
        "school": "Edna F Hinman Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000341",
    },
    {
        "school": "Estes M McDoniel Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000342",
    },
    {
        "school": "Martin Luther King Jr Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000343",
    },
    {
        "school": "Ruthe Deskin Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000344",
    },
    {
        "school": "Frank Kim Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000345",
    },
    {
        "school": "John R  Beatty Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000346",
    },
    {
        "school": "M  J  Christensen Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000354",
    },
    {
        "school": "Claude & Stella Parson Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000355",
    },
    {
        "school": "John Dooley Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000356",
    },
    {
        "school": "John F Mendoza Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000357",
    },
    {
        "school": "Ute Perkins Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000359",
    },
    {
        "school": "Ann Lynch Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000371",
    },
    {
        "school": "Gwendolyn Woolley Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000372",
    },
    {
        "school": "Robert Lunt Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000373",
    },
    {
        "school": "Lilly & Wing Fong Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000375",
    },
    {
        "school": "James Gibson Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000376",
    },
    {
        "school": "Elaine Wynn Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000377",
    },
    {
        "school": "Charlotte Hill Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000378",
    },
    {
        "school": "Walter Jacobson Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000379",
    },
    {
        "school": "Herbert A Derfelt Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000380",
    },
    {
        "school": "Cynthia Cunningham Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000381",
    },
    {
        "school": "David M Cox Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000382",
    },
    {
        "school": "Harriet Treem Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000383",
    },
    {
        "school": "John F Miller School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320006000384",
    },
    {
        "school": "Kirk Adams Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000395",
    },
    {
        "school": "Jack Dailey Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000396",
    },
    {
        "school": "Helen Herr Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000397",
    },
    {
        "school": "Helen Jydstrup Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000398",
    },
    {
        "school": "Martha P King Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000399",
    },
    {
        "school": "Ernest May Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000400",
    },
    {
        "school": "Richard J Rundle Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000401",
    },
    {
        "school": "Barbara and Hank Greenspun Junior High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000402",
    },
    {
        "school": "Walter Johnson Junior High School Academy of International S",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000403",
    },
    {
        "school": "Mike OCallaghan Middle School i3 Learn Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000404",
    },
    {
        "school": "Cheyenne High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000405",
    },
    {
        "school": "Cimarron Memorial High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000406",
    },
    {
        "school": "Green Valley High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000407",
    },
    {
        "school": "Laughlin Jr/Sr High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000408",
    },
    {
        "school": "Lucile Bruner Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000417",
    },
    {
        "school": "Advanced Technologies Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000419",
    },
    {
        "school": "Silverado High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000420",
    },
    {
        "school": "Richard H Bryan Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000434",
    },
    {
        "school": "Elizabeth Wilhelm Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000435",
    },
    {
        "school": "Aggie Roberts Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000436",
    },
    {
        "school": "Dean LaMar Allen Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000437",
    },
    {
        "school": "Eva Wolfe Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000438",
    },
    {
        "school": "Dan Goldfarb Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000439",
    },
    {
        "school": "John Vanderburg Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000440",
    },
    {
        "school": "Arturo Cambeiro Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000441",
    },
    {
        "school": "Roger M Bryan Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000442",
    },
    {
        "school": "College of So. NV HS East",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000443",
    },
    {
        "school": "College of So. NV HS West",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000444",
    },
    {
        "school": "Mojave High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000445",
    },
    {
        "school": "Palo Verde High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000446",
    },
    {
        "school": "John W Bonner Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000454",
    },
    {
        "school": "Roberta C Cartwright Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000455",
    },
    {
        "school": "Joseph L Bowler Sr  Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000456",
    },
    {
        "school": "Betsy A Rhodes Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000457",
    },
    {
        "school": "Addeliar Guy Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000458",
    },
    {
        "school": "Sue H Morrow Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000459",
    },
    {
        "school": "West Prepatory Academy at Charlles I West Hall Sec",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000460",
    },
    {
        "school": "Lied STEM Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000461",
    },
    {
        "school": "Duane D Keller Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000462",
    },
    {
        "school": "College of So. NV HS South",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000463",
    },
    {
        "school": "Berkeley L Bunker Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000469",
    },
    {
        "school": "Raul P Elizondo Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000470",
    },
    {
        "school": "Manuel J Cortez Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000471",
    },
    {
        "school": "Frank S Lamping Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000472",
    },
    {
        "school": "Edith Garehime Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000473",
    },
    {
        "school": "Irwin & Susan Molasky Junior High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000474",
    },
    {
        "school": "Charles Silvestri Junior High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000475",
    },
    {
        "school": "Francis H Cortney Junior High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000476",
    },
    {
        "school": "Keith C & Karen W Hayes Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000485",
    },
    {
        "school": "Lorna J Kesterson Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000486",
    },
    {
        "school": "Joseph M Neal Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000487",
    },
    {
        "school": "Odyssey Charter School K-5",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000488",
    },
    {
        "school": "Ollie Detwiler Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000489",
    },
    {
        "school": "Clifford J Lawrence Junior High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000490",
    },
    {
        "school": "Centennial High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000493",
    },
    {
        "school": "Foothill High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000494",
    },
    {
        "school": "Desert Pines High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000495",
    },
    {
        "school": "South Academic Center",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000499",
    },
    {
        "school": "John C. Bass Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000506",
    },
    {
        "school": "Reynaldo Martinez Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000507",
    },
    {
        "school": "William K. Moore Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000508",
    },
    {
        "school": "D'Vorre & Hall Ober Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000509",
    },
    {
        "school": "Hal Smith Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000510",
    },
    {
        "school": "Sheila R. Tarr  Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000511",
    },
    {
        "school": "Ethel W. Staton Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000512",
    },
    {
        "school": "Elise L. Wolff  Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000513",
    },
    {
        "school": "Bob Miller Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000514",
    },
    {
        "school": "Sig Rogich Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000515",
    },
    {
        "school": "Summit School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320006000517",
    },
    {
        "school": "Summit View J/SHS",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000518",
    },
    {
        "school": "Kay Carl Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000526",
    },
    {
        "school": "Marshall C Darnell Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000527",
    },
    {
        "school": "Howard E Heckethorn Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000528",
    },
    {
        "school": "Lucille S Rogers Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000529",
    },
    {
        "school": "William E Snyder Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000530",
    },
    {
        "school": "Neil C Twitchell Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000531",
    },
    {
        "school": "Fredric W Watson Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000532",
    },
    {
        "school": "Andre Agassi College Preparatory Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000533",
    },
    {
        "school": "Justice Myron E Leavitt Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000534",
    },
    {
        "school": "Brian & Teri Cram Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000535",
    },
    {
        "school": "Mario C & Joanne Monaco Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000536",
    },
    {
        "school": "Jack Lund Schofield Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000537",
    },
    {
        "school": "Marvin M Sedway Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000538",
    },
    {
        "school": "Sierra Vista High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000539",
    },
    {
        "school": "Coronado High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000540",
    },
    {
        "school": "Pathways Middle School (Alternative)",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320036000556",
    },
    {
        "school": "Pathways High (Alternative)",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320036000557",
    },
    {
        "school": "Amargosa Middle School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000564",
    },
    {
        "school": "Beatty Middle School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000566",
    },
    {
        "school": "Gabbs Middle School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000575",
    },
    {
        "school": "Round Mountain Middle School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000611",
    },
    {
        "school": "Tonopah Middle School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000618",
    },
    {
        "school": "Amargosa Valley Elementary School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000185",
    },
    {
        "school": "Beatty Elementary School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000186",
    },
    {
        "school": "Beatty High School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000187",
    },
    {
        "school": "Duckwater Elementary School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000188",
    },
    {
        "school": "Gabbs Elementary School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000189",
    },
    {
        "school": "Gabbs High School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000190",
    },
    {
        "school": "Manse Elementary School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000191",
    },
    {
        "school": "Pahrump Valley High School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000192",
    },
    {
        "school": "Round Mountain Elementary School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000193",
    },
    {
        "school": "Tonopah Elementary School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000194",
    },
    {
        "school": "Tonopah High School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000195",
    },
    {
        "school": "J G Johnson Elementary School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000351",
    },
    {
        "school": "Round Mountain High School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000363",
    },
    {
        "school": "Rosemary Clarke Middle School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000412",
    },
    {
        "school": "Mt Charleston Elementary School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000425",
    },
    {
        "school": "Hafen Elementary",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000543",
    },
    {
        "school": "Rollan D. Melton Ellementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000558",
    },
    {
        "school": "Double Diamond Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000559",
    },
    {
        "school": "Mariposa Dual Language Academy Charter School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000560",
    },
    {
        "school": "High Desert Montessori Charter School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000561",
    },
    {
        "school": "Academy of Career Education Charter School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000562",
    },
    {
        "school": "Damonte Ranch High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000602",
    },
    {
        "school": "enCompass Academy",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000603",
    },
    {
        "school": "Yvonne Shaw Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000624",
    },
    {
        "school": "Academy of Art  Careers and Technology",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000664",
    },
    {
        "school": "Virginia City High School",
        "district": "STOREY COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320045000199",
    },
    {
        "school": "Hugh Gallagher Elementary School",
        "district": "STOREY COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320045000200",
    },
    {
        "school": "Virginia City Middle School",
        "district": "STOREY COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320045000365",
    },
    {
        "school": "Hillside Elementary School",
        "district": "STOREY COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320045000413",
    },
    {
        "school": "Agnes Risley Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000201",
    },
    {
        "school": "Alice Maxwell Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000202",
    },
    {
        "school": "Anderson Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000203",
    },
    {
        "school": "Archie Clayton PRE-AP Academy Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000204",
    },
    {
        "school": "Brown Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000205",
    },
    {
        "school": "Darrell C Swope Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000206",
    },
    {
        "school": "E Otis Vaughn Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000207",
    },
    {
        "school": "Earl Wooster High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000208",
    },
    {
        "school": "Echo Loder Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000209",
    },
    {
        "school": "Edward C Reed High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000210",
    },
    {
        "school": "Edward L Pine Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000211",
    },
    {
        "school": "Elmcrest Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000212",
    },
    {
        "school": "Florence Drake Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000214",
    },
    {
        "school": "Fred W Traner Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000215",
    },
    {
        "school": "George L Dilworth Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000216",
    },
    {
        "school": "Gerlach K-12",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000217",
    },
    {
        "school": "Glenn Duncan STEM Academy",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000218",
    },
    {
        "school": "Grace Warner Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000219",
    },
    {
        "school": "Greenbrae Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000220",
    },
    {
        "school": "Marvin Moss Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000221",
    },
    {
        "school": "Huffaker Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000222",
    },
    {
        "school": "Hunter Lake Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000223",
    },
    {
        "school": "Incline Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000224",
    },
    {
        "school": "Incline High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000225",
    },
    {
        "school": "Jessie Beck Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000226",
    },
    {
        "school": "Kate M Smith Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000227",
    },
    {
        "school": "Lemmon Valley Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000228",
    },
    {
        "school": "Lena Juniper Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000229",
    },
    {
        "school": "Libby C Booth Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000230",
    },
    {
        "school": "Lincoln Park Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000231",
    },
    {
        "school": "Mamie Towles Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000232",
    },
    {
        "school": "Marvin Picollo School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320048000233",
    },
    {
        "school": "Natchez Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000234",
    },
    {
        "school": "William O'Brien Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000235",
    },
    {
        "school": "Peavine Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000236",
    },
    {
        "school": "Pleasant Valley Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000237",
    },
    {
        "school": "Procter R Hug High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000238",
    },
    {
        "school": "Reno High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000239",
    },
    {
        "school": "Rita Cannan Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000240",
    },
    {
        "school": "Robert Mitchell Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000241",
    },
    {
        "school": "Roger Corbett Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000242",
    },
    {
        "school": "Roy Gomm Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000243",
    },
    {
        "school": "Smithridge STEM Academy",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000245",
    },
    {
        "school": "Sparks High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000246",
    },
    {
        "school": "Sparks Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000247",
    },
    {
        "school": "Stead Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000248",
    },
    {
        "school": "Sun Valley Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000249",
    },
    {
        "school": "Verdi Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000250",
    },
    {
        "school": "Veterans Memorial STEM Academy",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000251",
    },
    {
        "school": "Galena High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000257",
    },
    {
        "school": "Edwin S Dodson Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000316",
    },
    {
        "school": "Elizabeth Lenz Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000317",
    },
    {
        "school": "Incline Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000318",
    },
    {
        "school": "Katherine Dunn Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000319",
    },
    {
        "school": "Lloyd Diedrichsen Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000320",
    },
    {
        "school": "Mount Rose K-8 Academy of Languages Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000321",
    },
    {
        "school": "Nancy Gomes Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000322",
    },
    {
        "school": "Robert Mc Queen High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000323",
    },
    {
        "school": "Virginia Palmer Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000324",
    },
    {
        "school": "Jerry Whitehead Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000336",
    },
    {
        "school": "Hidden Valley Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000366",
    },
    {
        "school": "Silver Lake Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000367",
    },
    {
        "school": "George Westergard Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000368",
    },
    {
        "school": "Alice L Smith Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000388",
    },
    {
        "school": "Caughlin Ranch Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000389",
    },
    {
        "school": "Alyce Savage Taylor Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000390",
    },
    {
        "school": "B D Billinghurst Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000391",
    },
    {
        "school": "Lois Allen Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000414",
    },
    {
        "school": "Desert Heights Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000426",
    },
    {
        "school": "Spanish Springs Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000427",
    },
    {
        "school": "Sarah Winnemucca Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000428",
    },
    {
        "school": "Bud Beasley Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000432",
    },
    {
        "school": "Lou Mendive Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000433",
    },
    {
        "school": "Donner Springs Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000452",
    },
    {
        "school": "Bernice Mathews Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000466",
    },
    {
        "school": "Ted Hunsberger Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000467",
    },
    {
        "school": "TMCC Magnet High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000468",
    },
    {
        "school": "Esther Bennett Elementary",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000481",
    },
    {
        "school": "I Can Do Anything Charter High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000482",
    },
    {
        "school": "Sierra Nevada Academy Charter School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000503",
    },
    {
        "school": "Van Gorder Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000523",
    },
    {
        "school": "Coral Academy High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000525",
    },
    {
        "school": "Bailey Charter School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000544",
    },
    {
        "school": "Spanish Springs High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000545",
    },
    {
        "school": "North Valleys High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000546",
    },
    {
        "school": "ALBANY COMMUNITY CHARTER SCHOOL",
        "district": "ALBANY COMMUNITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360016205855",
    },
    {
        "school": "ACADEMY OF APPLIED MATHEMATICS AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405920",
    },
    {
        "school": "VALIDUS PREPARATORY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605861",
    },
    {
        "school": "DREAMYARD PREPARATORY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605882",
    },
    {
        "school": "INTERNATIONAL SCHOOL FOR LIBERAL ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705938",
    },
    {
        "school": "BRONX GREEN MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805953",
    },
    {
        "school": "VIDA BOGART SCHOOL FOR ALL CHILDREN (THE)",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013505853",
    },
    {
        "school": "SOUTH BRONX CLASSICAL CHARTER SCHOOL",
        "district": "SOUTH BRONX CLASSICAL CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360016105893",
    },
    {
        "school": "INTERNATIONAL LEADERSHIP CHARTER  HIGH SCHOOL",
        "district": "INTERNATIONAL LEADERSHIP CHARTER  HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360016305923",
    },
    {
        "school": "HYDE LEADERSHIP CHARTER SCHOOL",
        "district": "HYDE LEADERSHIP CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360016505889",
    },
    {
        "school": "MILLBROOK HIGH SCHOOL",
        "district": "MILLBROOK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361938005859",
    },
    {
        "school": "EUGENE BROOKS MIDDLE SCHOOL",
        "district": "NORTHEAST CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363039005848",
    },
    {
        "school": "ELMWOOD VILLAGE CHARTER SCHOOL DAYS PARK",
        "district": "ELMWOOD VILLAGE CHARTER SCHOOL DAYS PARK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360016005851",
    },
    {
        "school": "MATH SCIENCE TECHNOLOGY PREPARATORY SCHOOL AT 197",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585005857",
    },
    {
        "school": "FRANK A SEDITA SCHOOL #30",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585005858",
    },
    {
        "school": "ACADEMY OF ARTS AND LETTERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009105901",
    },
    {
        "school": "BROOKLYN COMMUNITY ARTS AND MEDIA HIGH SCHOOL (BCAM)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009105962",
    },
    {
        "school": "RONALD EDMONDS LEARNING CENTER II",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505870",
    },
    {
        "school": "ACADEMY OF HOSPITALITY AND TOURISM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505885",
    },
    {
        "school": "ACAD FOR COLLEGE PREP AND CAREER EXP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505916",
    },
    {
        "school": "ACADEMY FOR EXCELLENCE IN LEADERSHIP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009705866",
    },
    {
        "school": "WILLIAMSBURG HIGH SCHOOL OF ART AND TECHNOLOGY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011905896",
    },
    {
        "school": "BROOKLYN LATIN SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011905929",
    },
    {
        "school": "FREDERICK DOUGLASS ACADEMY VIII MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012005895",
    },
    {
        "school": "PS 506 SCHOOL OF JOURNALISM AND TECHNOLOGY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015105877",
    },
    {
        "school": "PS 503 SCHOOL OF DISCOVERY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015105908",
    },
    {
        "school": "PS 245",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015300800",
    },
    {
        "school": "COMMUNITY ROOTS CHARTER SCHOOL",
        "district": "COMMUNITY ROOTS CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015905898",
    },
    {
        "school": "ACHIEVEMENT FIRST-BUSHWICK CHARTER SCHOOL",
        "district": "ACHIEVEMENT FIRST-BUSHWICK CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360016605902",
    },
    {
        "school": "ACHIEVEMENT FIRST ENDEAVOR CHARTER SCHOOL",
        "district": "ACHIEVEMENT FIRST ENDEAVOR CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360017005867",
    },
    {
        "school": "LEADERSHIP PREPARATORY BEDFORD STUYVESANT CHARTER SCHOOL",
        "district": "LEADERSHIP PREPARATORY BEDFORD STUYVESANT CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360017205868",
    },
    {
        "school": "TRUE NORTH ROCHESTER PREPARATORY CHARTER SCHOOL",
        "district": "TRUE NORTH ROCHESTER PREPARATORY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360017305854",
    },
    {
        "school": "CALKINS ROAD MIDDLE SCHOOL",
        "district": "PITTSFORD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362316005850",
    },
    {
        "school": "NORTHWEST COLLEGE PREPARATORY HIGH SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475005849",
    },
    {
        "school": "NORTHEAST COLLEGE PREPARATORY HIGH SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475005856",
    },
    {
        "school": "HARBOR HEIGHTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305871",
    },
    {
        "school": "COMMUNITY HEALTH ACADEMY OF THE HEIGHTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305878",
    },
    {
        "school": "WASHINGTON HEIGHTS EXPEDITIONARY LEARNING SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305909",
    },
    {
        "school": "DEMOCRACY PREPARATORY CHARTER SCHOOL",
        "district": "DEMOCRACY PREPARATORY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015805847",
    },
    {
        "school": "NEW HEIGHTS ACADEMY CHARTER SCHOOL",
        "district": "NEW HEIGHTS ACADEMY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360016705891",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 1",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 1",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360016905862",
    },
    {
        "school": "NIAGARA CHARTER SCHOOL",
        "district": "NIAGARA CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360016405887",
    },
    {
        "school": "YORK EARLY COLLEGE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010005935",
    },
    {
        "school": "PREPARATORY ACADEMY FOR WRITERS:  A COLLEGE BOARD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010105875",
    },
    {
        "school": "YOUNG WOMENS LEADERSHIP SCHOOL - ASTORIA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010205948",
    },
    {
        "school": "WORLD JOURNALISM PREPARATORY:  A COLLEGE BOARD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012205869",
    },
    {
        "school": "EAST-WEST SCHOOL OF INTERNATIONAL STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012205879",
    },
    {
        "school": "GOLDIE MAPLE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012305883",
    },
    {
        "school": "KNOWLEDGE AND POWER PREPARATORY ACADEMY VI",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012305890",
    },
    {
        "school": "HIGH SCHOOL-CONSTRUCTION TRADES ENGINEERING & ARCHITECTURE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360012305899",
    },
    {
        "school": "FELIX FESTA CHARACTER MIDDLE SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034005874",
    },
    {
        "school": "FELIX FESTA DETERMINATION MIDDLE SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034005897",
    },
    {
        "school": "FELIX FESTA ACHIEVEMENT MIDDLE SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034005918",
    },
    {
        "school": "SLEEPY HOLLOW MIDDLE SCHOOL",
        "district": "UNION FREE SCHOOL DISTRICT OF THE TARRYTOWNS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362865005886",
    },
    {
        "school": "CATSKILL ELEMENTARY SCHOOL",
        "district": "CATSKILL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360672005040",
    },
    {
        "school": "CAPTAIN VERNON A RICHARDS HS-FIRE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012005716",
    },
    {
        "school": "HIGH SCHOOL FOR CIVIL RIGHTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012005717",
    },
    {
        "school": "PERFORMING ARTS AND TECHNOLOGY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012005718",
    },
    {
        "school": "WORLD ACADEMY FOR TOTAL COMMUNITY HEALTH HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012005719",
    },
    {
        "school": "BROOKLYN COLLEGIATE: A COLLEGE BOARD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012105721",
    },
    {
        "school": "FREDERICK DOUGLASS ACADEMY VII HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012105722",
    },
    {
        "school": "KAPPA V (KNOWLEDGE AND POWER PREP ACADEMY)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012105723",
    },
    {
        "school": "MOTT HALL IV",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012105724",
    },
    {
        "school": "PS 253",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012305728",
    },
    {
        "school": "PS 254 ROSA PARKS SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012305729",
    },
    {
        "school": "FREDERICK DOUGLASS ACADEMY VI HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012305730",
    },
    {
        "school": "CHANNEL VIEW SCHOOL FOR RESEARCH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012305731",
    },
    {
        "school": "EASTPORT ELEMENTARY SCHOOL",
        "district": "EASTPORT-SOUTH MANOR CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012500788",
    },
    {
        "school": "SOUTH STREET SCHOOL",
        "district": "EASTPORT-SOUTH MANOR CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012503736",
    },
    {
        "school": "EASTPORT-SOUTH MANOR JUNIOR SENIOR HIGH SCHOOL",
        "district": "EASTPORT-SOUTH MANOR CSD",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012504241",
    },
    {
        "school": "DAYTON AVENUE SCHOOL",
        "district": "EASTPORT-SOUTH MANOR CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012504330",
    },
    {
        "school": "BOLIVAR-RICHBURG JUNIOR-SENIOR HIGH SCHOOL",
        "district": "BOLIVAR-RICHBURG CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001201092",
    },
    {
        "school": "BOLIVAR-RICHBURG ELEMENTARY SCHOOL",
        "district": "BOLIVAR-RICHBURG CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001201101",
    },
    {
        "school": "BOLIVAR-RICHBURG PRE-K PROGRAM",
        "district": "BOLIVAR-RICHBURG CENTRAL SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001201103",
    },
    {
        "school": "GENESEE VALLEY CENTRAL SCHOOL",
        "district": "GENESEE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001701925",
    },
    {
        "school": "ALFRED-ALMOND ELEMENTARY SCHOOL",
        "district": "ALFRED-ALMOND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360270000045",
    },
    {
        "school": "ALFRED-ALMOND JUNIOR-SENIOR HIGH SCHOOL",
        "district": "ALFRED-ALMOND CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360270000046",
    },
    {
        "school": "ANDOVER SCHOOL",
        "district": "ANDOVER CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360303000077",
    },
    {
        "school": "BELFAST SCHOOL",
        "district": "BELFAST CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360435000187",
    },
    {
        "school": "CANASERAGA SCHOOL",
        "district": "CANASERAGA CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360636000418",
    },
    {
        "school": "FILLMORE CENTRAL SCHOOL",
        "district": "FILLMORE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361107004552",
    },
    {
        "school": "FRIENDSHIP CENTRAL SCHOOL",
        "district": "FRIENDSHIP CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361164000919",
    },
    {
        "school": "SCIO CENTRAL SCHOOL",
        "district": "SCIO CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362619003604",
    },
    {
        "school": "WELLSVILLE ELEMENTARY SCHOOL",
        "district": "WELLSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363048004098",
    },
    {
        "school": "WELLSVILLE SECONDARY SCHOOL",
        "district": "WELLSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363048004099",
    },
    {
        "school": "WHITESVILLE CENTRAL SCHOOL",
        "district": "WHITESVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363135004575",
    },
    {
        "school": "CUBA-RUSHFORD HIGH SCHOOL",
        "district": "CUBA-RUSHFORD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363201000050",
    },
    {
        "school": "CUBA-RUSHFORD ELEMENTARY SCHOOL",
        "district": "CUBA-RUSHFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363201000051",
    },
    {
        "school": "CUBA-RUSHFORD MIDDLE SCHOOL",
        "district": "CUBA-RUSHFORD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363201004855",
    },
    {
        "school": "UNADILLA VALLEY SECONDARY SCHOOL",
        "district": "UNADILLA VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001901976",
    },
    {
        "school": "AFTON ELEMENTARY SCHOOL",
        "district": "AFTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360240000010",
    },
    {
        "school": "AFTON JUNIOR/SENIOR HIGH SCHOOL",
        "district": "AFTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360240000011",
    },
    {
        "school": "BAINBRIDGE-GUILFORD HIGH SCHOOL",
        "district": "BAINBRIDGE-GUILFORD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360381000123",
    },
    {
        "school": "GREENLAWN ELEMENTARY SCHOOL",
        "district": "BAINBRIDGE-GUILFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360381000124",
    },
    {
        "school": "GUILFORD ELEMENTARY SCHOOL",
        "district": "BAINBRIDGE-GUILFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360381000125",
    },
    {
        "school": "GREENE INTERMEDIATE SCHOOL",
        "district": "GREENE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361275001051",
    },
    {
        "school": "GREENE HIGH SCHOOL",
        "district": "GREENE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361275001052",
    },
    {
        "school": "GREENE PRIMARY SCHOOL",
        "district": "GREENE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361275001546",
    },
    {
        "school": "GREENE MIDDLE SCHOOL",
        "district": "GREENE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361275004686",
    },
    {
        "school": "NORWICH HIGH SCHOOL",
        "district": "NORWICH CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362133003039",
    },
    {
        "school": "NORWICH MIDDLE SCHOOL",
        "district": "NORWICH CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362133003040",
    },
    {
        "school": "PERRY BROWNE INTERMEDIATE SCHOOL",
        "district": "NORWICH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362133003041",
    },
    {
        "school": "STANFORD J GIBSON PRIMARY SCHOOL",
        "district": "NORWICH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362133003042",
    },
    {
        "school": "OTSELIC VALLEY CENTRAL SCHOOL",
        "district": "GEORGETOWN-SOUTH OTSELIC CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362210003132",
    },
    {
        "school": "OXFORD ACADEMY HIGH SCHOOL",
        "district": "OXFORD ACADEMY AND CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362226003143",
    },
    {
        "school": "OXFORD ACADEMY MIDDLE SCHOOL",
        "district": "OXFORD ACADEMY AND CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362226003144",
    },
    {
        "school": "OXFORD ACADEMY PRIMARY SCHOOL",
        "district": "OXFORD ACADEMY AND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362226003145",
    },
    {
        "school": "SHERBURNE-EARLVILLE ELEMENTARY SCHOOL",
        "district": "SHERBURNE-EARLVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362670001984",
    },
    {
        "school": "SHERBURNE-EARLVILLE MIDDLE SCHOOL",
        "district": "SHERBURNE-EARLVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362670003644",
    },
    {
        "school": "SHERBURNE-EARLVILLE SENIOR HIGH SCHOOL",
        "district": "SHERBURNE-EARLVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362670003645",
    },
    {
        "school": "DELAWARE-CHENANGO-MADISON-OTSEGO BOCES",
        "district": "DELAWARE-CHENANGO-MADISON-OTSEGO BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368026004629",
    },
    {
        "school": "ANDES CENTRAL SCHOOL",
        "district": "ANDES CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360300000076",
    },
    {
        "school": "CHARLOTTE VALLEY SCHOOL",
        "district": "CHARLOTTE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360705000497",
    },
    {
        "school": "DELAWARE ACADEMY ELEMENTARY SCHOOL",
        "district": "DELAWARE ACADEMY CENTRAL SCHOOL DISTRICT AT DELHI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360891000680",
    },
    {
        "school": "DELAWARE ACADEMY HIGH SCHOOL",
        "district": "DELAWARE ACADEMY CENTRAL SCHOOL DISTRICT AT DELHI",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360891000681",
    },
    {
        "school": "DOWNSVILLE CENTRAL SCHOOL",
        "district": "DOWNSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360924000709",
    },
    {
        "school": "FRANKLIN CENTRAL SCHOOL",
        "district": "FRANKLIN CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361143000900",
    },
    {
        "school": "HANCOCK ELEMENTARY SCHOOL",
        "district": "HANCOCK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361356001109",
    },
    {
        "school": "HANCOCK JUNIOR-SENIOR HIGH SCHOOL",
        "district": "HANCOCK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361356001110",
    },
    {
        "school": "MARGARETVILLE CENTRAL SCHOOL",
        "district": "MARGARETVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361851001667",
    },
    {
        "school": "ROXBURY CENTRAL SCHOOL",
        "district": "ROXBURY CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362511003473",
    },
    {
        "school": "SIDNEY ELEMENTARY SCHOOL",
        "district": "SIDNEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362685003662",
    },
    {
        "school": "SIDNEY HIGH SCHOOL",
        "district": "SIDNEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362685003663",
    },
    {
        "school": "SIDNEY MIDDLE SCHOOL",
        "district": "SIDNEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362685003664",
    },
    {
        "school": "SOUTH KORTRIGHT CENTRAL SCHOOL",
        "district": "SOUTH KORTRIGHT CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362733003730",
    },
    {
        "school": "STAMFORD CENTRAL SCHOOL",
        "district": "STAMFORD CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362802003796",
    },
    {
        "school": "TOWNSEND ELEMENTARY SCHOOL",
        "district": "WALTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362982004005",
    },
    {
        "school": "WALTON HIGH SCHOOL",
        "district": "WALTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362982004006",
    },
    {
        "school": "WALTON MIDDLE SCHOOL",
        "district": "WALTON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362982004791",
    },
    {
        "school": "OTSEGO-DELAWARE-SCHOHARIE-GREENE BOCES",
        "district": "OTSEGO-DELAWARE-SCHOHARIE-GREENE BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368038004635",
    },
    {
        "school": "CROWN POINT CENTRAL SCHOOL",
        "district": "CROWN POINT CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360861000661",
    },
    {
        "school": "KEENE CENTRAL SCHOOL",
        "district": "KEENE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361614001394",
    },
    {
        "school": "LAKE PLACID ELEMENTARY SCHOOL",
        "district": "LAKE PLACID CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361650001459",
    },
    {
        "school": "LAKE PLACID JUNIOR-SENIOR HIGH SCHOOL",
        "district": "LAKE PLACID CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361650001460",
    },
    {
        "school": "MINERVA CENTRAL SCHOOL",
        "district": "MINERVA CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361953001782",
    },
    {
        "school": "MORIAH ELEMENTARY SCHOOL",
        "district": "MORIAH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361983001814",
    },
    {
        "school": "MORIAH JUNIOR-SENIOR HIGH SCHOOL",
        "district": "MORIAH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361983001815",
    },
    {
        "school": "NEWCOMB CENTRAL SCHOOL",
        "district": "NEWCOMB CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362073002918",
    },
    {
        "school": "SCHROON LAKE CENTRAL SCHOOL",
        "district": "SCHROON LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362613003599",
    },
    {
        "school": "TICONDEROGA ELEMENTARY SCHOOL",
        "district": "TICONDEROGA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362868003893",
    },
    {
        "school": "TICONDEROGA MIDDLE SCHOOL",
        "district": "TICONDEROGA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362868003894",
    },
    {
        "school": "TICONDEROGA SENIOR HIGH SCHOOL",
        "district": "TICONDEROGA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362868003895",
    },
    {
        "school": "WILLSBORO CENTRAL SCHOOL",
        "district": "WILLSBORO CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363150004220",
    },
    {
        "school": "CAIRO-DURHAM ELEMENTARY SCHOOL",
        "district": "CAIRO-DURHAM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360616000395",
    },
    {
        "school": "CAIRO-DURHAM HIGH SCHOOL",
        "district": "CAIRO-DURHAM CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360616000396",
    },
    {
        "school": "CAIRO-DURHAM MIDDLE SCHOOL",
        "district": "CAIRO-DURHAM CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360616001568",
    },
    {
        "school": "CATSKILL MIDDLE SCHOOL",
        "district": "CATSKILL CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360672000458",
    },
    {
        "school": "CATSKILL SENIOR HIGH SCHOOL",
        "district": "CATSKILL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360672000459",
    },
    {
        "school": "EDWARD J ARTHUR ELEMENTARY SCHOOL",
        "district": "COXSACKIE-ATHENS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360849000655",
    },
    {
        "school": "COXSACKIE-ATHENS HIGH SCHOOL",
        "district": "COXSACKIE-ATHENS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360849000656",
    },
    {
        "school": "COXSACKIE ELEMENTARY SCHOOL",
        "district": "COXSACKIE-ATHENS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360849000657",
    },
    {
        "school": "COXSACKIE-ATHENS MIDDLE SCHOOL",
        "district": "COXSACKIE-ATHENS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360849004765",
    },
    {
        "school": "SCOTT M ELLIS ELEMENTARY SCHOOL",
        "district": "GREENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361287001055",
    },
    {
        "school": "GREENVILLE HIGH SCHOOL",
        "district": "GREENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361287001056",
    },
    {
        "school": "GREENVILLE MIDDLE SCHOOL",
        "district": "GREENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361287003484",
    },
    {
        "school": "HUNTER ELEMENTARY SCHOOL",
        "district": "HUNTER-TANNERSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361506001258",
    },
    {
        "school": "HUNTER-TANNERSVILLE MIDDLE SCHOOL HIGH SCHOOL",
        "district": "HUNTER-TANNERSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361506001259",
    },
    {
        "school": "WINDHAM ASHLAND CENTRAL SCHOOL",
        "district": "WINDHAM-ASHLAND-JEWETT CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363159004225",
    },
    {
        "school": "INDIAN LAKE CENTRAL SCHOOL",
        "district": "INDIAN LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361527001285",
    },
    {
        "school": "INLET ELEMENTARY SCHOOL",
        "district": "INLET COMMON SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361533001291",
    },
    {
        "school": "LAKE PLEASANT SCHOOL",
        "district": "LAKE PLEASANT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361653001461",
    },
    {
        "school": "LONG LAKE CENTRAL SCHOOL",
        "district": "LONG LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361776001601",
    },
    {
        "school": "WELLS SCHOOL",
        "district": "WELLS CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363045004096",
    },
    {
        "school": "BEAVER RIVER ELEMENTARY SCHOOL",
        "district": "BEAVER RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360420004503",
    },
    {
        "school": "BEAVER RIVER SENIOR HIGH SCHOOL",
        "district": "BEAVER RIVER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360420004504",
    },
    {
        "school": "COPENHAGEN CENTRAL SCHOOL",
        "district": "COPENHAGEN CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360828000608",
    },
    {
        "school": "HARRISVILLE ELEMENTARY SCHOOL",
        "district": "HARRISVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361377001127",
    },
    {
        "school": "HARRISVILLE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "HARRISVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361377001128",
    },
    {
        "school": "LOWVILLE ELEMENTARY SCHOOL",
        "district": "LOWVILLE ACADEMY & CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361782001602",
    },
    {
        "school": "LOWVILLE HIGH SCHOOL",
        "district": "LOWVILLE ACADEMY & CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361782001603",
    },
    {
        "school": "LOWVILLE MIDDLE SCHOOL",
        "district": "LOWVILLE ACADEMY & CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361782004350",
    },
    {
        "school": "SOUTH LEWIS MIDDLE SCHOOL",
        "district": "SOUTH LEWIS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362736001137",
    },
    {
        "school": "GLENFIELD ELEMENTARY SCHOOL",
        "district": "SOUTH LEWIS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362736003732",
    },
    {
        "school": "PORT LEYDEN ELEMENTARY SCHOOL",
        "district": "SOUTH LEWIS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362736003734",
    },
    {
        "school": "SOUTH LEWIS HIGH SCHOOL",
        "district": "SOUTH LEWIS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362736003735",
    },
    {
        "school": "B C CATE ELEMENTARY SCHOOL",
        "district": "ODESSA-MONTOUR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362163003066",
    },
    {
        "school": "HOWARD A HANLON ELEMENTARY SCHOOL",
        "district": "ODESSA-MONTOUR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362163003067",
    },
    {
        "school": "ODESSA-MONTOUR JUNIOR/SENIOR HIGH SCHOOL",
        "district": "ODESSA-MONTOUR CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362163003068",
    },
    {
        "school": "WATKINS GLEN CENTRAL HIGH SCHOOL",
        "district": "WATKINS GLEN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363024004062",
    },
    {
        "school": "WATKINS GLEN ELEMENTARY SCHOOL",
        "district": "WATKINS GLEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363024004063",
    },
    {
        "school": "SULLIVAN WEST HIGH SCHOOL AT LAKE HUNTINGTON",
        "district": "SULLIVAN WEST CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002301358",
    },
    {
        "school": "SULLIVAN WEST ELEMENTARY SCHOOL",
        "district": "SULLIVAN WEST CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002301493",
    },
    {
        "school": "ELDRED JUNIOR-SENIOR HIGH SCHOOL",
        "district": "ELDRED CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361041000803",
    },
    {
        "school": "GEORGE ROSS MACKENZIE ELEMENTARY SCHOOL",
        "district": "ELDRED CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361041001902",
    },
    {
        "school": "BENJAMIN COSOR ELEMENTARY SCHOOL",
        "district": "FALLSBURG CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361095000873",
    },
    {
        "school": "FALLSBURG JUNIOR SENIOR HIGH SCHOOL",
        "district": "FALLSBURG CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361095000874",
    },
    {
        "school": "LIBERTY ELEMENTARY SCHOOL",
        "district": "LIBERTY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361722001538",
    },
    {
        "school": "LIBERTY HIGH SCHOOL",
        "district": "LIBERTY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361722001539",
    },
    {
        "school": "LIVINGSTON MANOR ELEMENTARY SCHOOL",
        "district": "LIVINGSTON MANOR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361758001574",
    },
    {
        "school": "LIVINGSTON MANOR HIGH SCHOOL",
        "district": "LIVINGSTON MANOR CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361758001575",
    },
    {
        "school": "EMMA C CHASE SCHOOL",
        "district": "MONTICELLO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361974001807",
    },
    {
        "school": "GEORGE L COOKE SCHOOL",
        "district": "MONTICELLO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361974001808",
    },
    {
        "school": "KENNETH L RUTHERFORD SCHOOL",
        "district": "MONTICELLO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361974001809",
    },
    {
        "school": "MONTICELLO HIGH SCHOOL",
        "district": "MONTICELLO CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361974001810",
    },
    {
        "school": "ROBERT J KAISER MIDDLE SCHOOL",
        "district": "MONTICELLO CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361974001811",
    },
    {
        "school": "ROSCOE CENTRAL SCHOOL",
        "district": "ROSCOE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362502003466",
    },
    {
        "school": "TRI-VALLEY ELEMENTARY SCHOOL",
        "district": "TRI-VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362889003909",
    },
    {
        "school": "TRI-VALLEY SECONDARY SCHOOL",
        "district": "TRI-VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362889003910",
    },
    {
        "school": "SULLIVAN BOCES",
        "district": "SULLIVAN BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368088004660",
    },
    {
        "school": "ATTICA ELEMENTARY SCHOOL",
        "district": "ATTICA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360342000097",
    },
    {
        "school": "ATTICA JUNIOR HIGH SCHOOL",
        "district": "ATTICA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360342000098",
    },
    {
        "school": "ATTICA SENIOR HIGH SCHOOL",
        "district": "ATTICA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360342000099",
    },
    {
        "school": "LETCHWORTH SENIOR HIGH SCHOOL",
        "district": "LETCHWORTH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361713001516",
    },
    {
        "school": "LETCHWORTH MIDDLE SCHOOL",
        "district": "LETCHWORTH CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361713003229",
    },
    {
        "school": "LETCHWORTH ELEMENTARY SCHOOL",
        "district": "LETCHWORTH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361713004301",
    },
    {
        "school": "PERRY ELEMENTARY SCHOOL",
        "district": "PERRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362277003203",
    },
    {
        "school": "PERRY JUNIOR-SENIOR HIGH SCHOOL",
        "district": "PERRY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362277003204",
    },
    {
        "school": "WARSAW ELEMENTARY SCHOOL",
        "district": "WARSAW CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362994004029",
    },
    {
        "school": "WARSAW MIDDLE/SENIOR HIGH SCHOOL",
        "district": "WARSAW CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362994004030",
    },
    {
        "school": "WYOMING CENTRAL SCHOOL",
        "district": "WYOMING CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363186004240",
    },
    {
        "school": "DUNDEE ELEMENTARY SCHOOL",
        "district": "DUNDEE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360939000716",
    },
    {
        "school": "DUNDEE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "DUNDEE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360939000717",
    },
    {
        "school": "PENN YAN ACADEMY",
        "district": "PENN YAN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362274003200",
    },
    {
        "school": "PENN YAN ELEMENTARY SCHOOL",
        "district": "PENN YAN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362274003201",
    },
    {
        "school": "PENN YAN MIDDLE SCHOOL",
        "district": "PENN YAN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362274003202",
    },
    {
        "school": "KIPP TECH VALLEY CHARTER SCHOOL",
        "district": "KIPP TECH VALLEY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012805750",
    },
    {
        "school": "PHILIP J SCHUYLER ACHIEVEMENT ACADEMY",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246005592",
    },
    {
        "school": "SHERIDAN PREPARATORY ACADEMY",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246005593",
    },
    {
        "school": "STEPHEN AND HARRIET MYERS MIDDLE SCHOOL",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246005747",
    },
    {
        "school": "BRIGHTER CHOICE CHARTER SCHOOL FOR BOYS",
        "district": "BRIGHTER CHOICE CHARTER SCHOOL FOR BOYS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360003204307",
    },
    {
        "school": "BRIGHTER CHOICE CHARTER SCHOOL FOR GIRLS",
        "district": "BRIGHTER CHOICE CHARTER SCHOOL FOR GIRLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360003304311",
    },
    {
        "school": "ALBANY HIGH SCHOOL",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246000014",
    },
    {
        "school": "ARBOR HILL ELEMENTARY SCHOOL",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246000015",
    },
    {
        "school": "GIFFEN MEMORIAL ELEMENTARY SCHOOL",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246000016",
    },
    {
        "school": "PINE HILLS ELEMENTARY SCHOOL",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246000020",
    },
    {
        "school": "DELAWARE COMMUNITY SCHOOL",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246000022",
    },
    {
        "school": "NEW SCOTLAND ELEMENTARY SCHOOL",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246000023",
    },
    {
        "school": "ALBANY SCHOOL OF HUMANITIES",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246000026",
    },
    {
        "school": "EAGLE POINT ELEMENTARY SCHOOL",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246000028",
    },
    {
        "school": "THOMAS S O'BRIEN ACADEMY OF SCIENCE & TECHNOLOGY",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246000031",
    },
    {
        "school": "WILLIAM S HACKETT MIDDLE SCHOOL",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246000032",
    },
    {
        "school": "MONTESSORI MAGNET SCHOOL",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246000222",
    },
    {
        "school": "BERNE-KNOX-WESTERLO ELEMENTARY SCHOOL",
        "district": "BERNE-KNOX-WESTERLO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360465000207",
    },
    {
        "school": "BERNE-KNOX-WESTERLO JUNIOR-SENIOR HIGH SCHOOL",
        "district": "BERNE-KNOX-WESTERLO CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360465000208",
    },
    {
        "school": "BETHLEHEM CENTRAL MIDDLE SCHOOL",
        "district": "BETHLEHEM CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360471000210",
    },
    {
        "school": "BETHLEHEM CENTRAL SENIOR HIGH SCHOOL",
        "district": "BETHLEHEM CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360471000211",
    },
    {
        "school": "ELSMERE ELEMENTARY SCHOOL",
        "district": "BETHLEHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360471000213",
    },
    {
        "school": "GLENMONT ELEMENTARY SCHOOL",
        "district": "BETHLEHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360471000214",
    },
    {
        "school": "HAMAGRAEL ELEMENTARY SCHOOL",
        "district": "BETHLEHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360471000215",
    },
    {
        "school": "SLINGERLANDS ELEMENTARY SCHOOL",
        "district": "BETHLEHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360471000216",
    },
    {
        "school": "ABRAM LANSING SCHOOL",
        "district": "COHOES CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360798000568",
    },
    {
        "school": "COHOES HIGH SCHOOL",
        "district": "COHOES CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360798000569",
    },
    {
        "school": "COHOES MIDDLE SCHOOL",
        "district": "COHOES CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360798000570",
    },
    {
        "school": "VAN SCHAICK ISLAND SCHOOL",
        "district": "COHOES CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360798000572",
    },
    {
        "school": "HARMONY HILL SCHOOL",
        "district": "COHOES CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360798004584",
    },
    {
        "school": "HEATLY SCHOOL",
        "district": "GREEN ISLAND UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361266001043",
    },
    {
        "school": "ALTAMONT ELEMENTARY SCHOOL",
        "district": "GUILDERLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361308001069",
    },
    {
        "school": "GUILDERLAND HIGH SCHOOL",
        "district": "GUILDERLAND CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361308001070",
    },
    {
        "school": "FARNSWORTH MIDDLE SCHOOL",
        "district": "GUILDERLAND CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361308001071",
    },
    {
        "school": "LYNNWOOD ELEMENTARY SCHOOL",
        "district": "GUILDERLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361308001072",
    },
    {
        "school": "WESTMERE ELEMENTARY SCHOOL",
        "district": "GUILDERLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361308001073",
    },
    {
        "school": "PINE BUSH ELEMENTARY SCHOOL",
        "district": "GUILDERLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361308001087",
    },
    {
        "school": "GUILDERLAND ELEMENTARY SCHOOL",
        "district": "GUILDERLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361308004589",
    },
    {
        "school": "MENANDS SCHOOL",
        "district": "MENANDS UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361899001719",
    },
    {
        "school": "BLUE CREEK SCHOOL",
        "district": "NORTH COLONIE CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362100002979",
    },
    {
        "school": "BOGHT HILLS SCHOOL",
        "district": "NORTH COLONIE CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362100002980",
    },
    {
        "school": "FORTS FERRY SCHOOL",
        "district": "NORTH COLONIE CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362100002981",
    },
    {
        "school": "LATHAM RIDGE SCHOOL",
        "district": "NORTH COLONIE CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362100002983",
    },
    {
        "school": "LOUDONVILLE SCHOOL",
        "district": "NORTH COLONIE CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362100002984",
    },
    {
        "school": "SHAKER HIGH SCHOOL",
        "district": "NORTH COLONIE CSD",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362100002985",
    },
    {
        "school": "SHAKER JUNIOR HIGH SCHOOL",
        "district": "NORTH COLONIE CSD",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362100002986",
    },
    {
        "school": "SOUTHGATE SCHOOL",
        "district": "NORTH COLONIE CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362100002987",
    },
    {
        "school": "ALBERTUS W BECKER SCHOOL",
        "district": "RAVENA-COEYMANS-SELKIRK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362415003323",
    },
    {
        "school": "PIETER B COEYMANS SCHOOL",
        "district": "RAVENA-COEYMANS-SELKIRK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362415003324",
    },
    {
        "school": "RAVENA-COEYMANS-SELKIRK MIDDLE SCHOOL",
        "district": "RAVENA-COEYMANS-SELKIRK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362415003326",
    },
    {
        "school": "RAVENA-COEYMANS-SELKIRK SENIOR HIGH SCHOOL",
        "district": "RAVENA-COEYMANS-SELKIRK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362415003327",
    },
    {
        "school": "COLONIE CENTRAL HIGH SCHOOL",
        "district": "SOUTH COLONIE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362721003704",
    },
    {
        "school": "SAND CREEK MIDDLE SCHOOL",
        "district": "SOUTH COLONIE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362721003710",
    },
    {
        "school": "SHAKER ROAD ELEMENTARY SCHOOL",
        "district": "SOUTH COLONIE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362721003711",
    },
    {
        "school": "VEEDER ELEMENTARY SCHOOL",
        "district": "SOUTH COLONIE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362721004494",
    },
    {
        "school": "LISHA KILL MIDDLE SCHOOL",
        "district": "SOUTH COLONIE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362721004496",
    },
    {
        "school": "FOREST PARK ELEMENTARY SCHOOL",
        "district": "SOUTH COLONIE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362721004568",
    },
    {
        "school": "ROESSLEVILLE SCHOOL",
        "district": "SOUTH COLONIE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362721004750",
    },
    {
        "school": "SADDLEWOOD ELEMENTARY SCHOOL",
        "district": "SOUTH COLONIE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362721004788",
    },
    {
        "school": "CLAYTON A BOUTON HIGH SCHOOL",
        "district": "VOORHEESVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362967003997",
    },
    {
        "school": "VOORHEESVILLE ELEMENTARY SCHOOL",
        "district": "VOORHEESVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362967003998",
    },
    {
        "school": "WATERVLIET ELEMENTARY SCHOOL",
        "district": "WATERVLIET CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363021004060",
    },
    {
        "school": "WATERVLIET JUNIOR-SENIOR HIGH SCHOOL",
        "district": "WATERVLIET CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363021004061",
    },
    {
        "school": "ALBANY-SCHOHARIE-SCHENECTADY-SARATOGA BOCES",
        "district": "ALBANY-SCHOHARIE-SCHENECTADY-SARATOGA BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368010004624",
    },
    {
        "school": "ALGONQUIN MIDDLE SCHOOL",
        "district": "AVERILL PARK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001600110",
    },
    {
        "school": "AVERILL PARK HIGH SCHOOL",
        "district": "AVERILL PARK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001600111",
    },
    {
        "school": "POESTENKILL ELEMENTARY SCHOOL",
        "district": "AVERILL PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001600113",
    },
    {
        "school": "SAND LAKE-MILLER HILL SCHOOL",
        "district": "AVERILL PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001600114",
    },
    {
        "school": "WEST SAND LAKE ELEMENTARY SCHOOL",
        "district": "AVERILL PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001600115",
    },
    {
        "school": "BERLIN MIDDLE SCHOOL/HIGH SCHOOL",
        "district": "BERLIN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360462000203",
    },
    {
        "school": "BERLIN ELEMENTARY SCHOOL",
        "district": "BERLIN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360462000204",
    },
    {
        "school": "TAMARAC ELEMENTARY SCHOOL",
        "district": "BRUNSWICK CENTRAL SCHOOL DISTRICT (BRITTONKILL)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360552000279",
    },
    {
        "school": "TAMARAC MIDDLE SCHOOL HIGH SCHOOL",
        "district": "BRUNSWICK CENTRAL SCHOOL DISTRICT (BRITTONKILL)",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360552000281",
    },
    {
        "school": "BELL TOP SCHOOL",
        "district": "EAST GREENBUSH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360963000729",
    },
    {
        "school": "CITIZEN EDMOND GENET SCHOOL",
        "district": "EAST GREENBUSH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360963000730",
    },
    {
        "school": "COLUMBIA HIGH SCHOOL",
        "district": "EAST GREENBUSH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360963000731",
    },
    {
        "school": "DONALD P SUTHERLAND SCHOOL",
        "district": "EAST GREENBUSH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360963000732",
    },
    {
        "school": "GREEN MEADOW SCHOOL",
        "district": "EAST GREENBUSH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360963000733",
    },
    {
        "school": "HOWARD L GOFF SCHOOL",
        "district": "EAST GREENBUSH CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360963000734",
    },
    {
        "school": "RED MILL SCHOOL",
        "district": "EAST GREENBUSH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360963000735",
    },
    {
        "school": "HOOSIC VALLEY ELEMENTARY SCHOOL",
        "district": "HOOSIC VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361473001226",
    },
    {
        "school": "HOOSIC VALLEY JUNIOR SENIOR HIGH SCHOOL",
        "district": "HOOSIC VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361473001227",
    },
    {
        "school": "HOOSICK FALLS ELEMENTARY SCHOOL",
        "district": "HOOSICK FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361476001228",
    },
    {
        "school": "HOOSICK FALLS JUNIOR/SENIOR HIGH SCHOOL",
        "district": "HOOSICK FALLS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361476001229",
    },
    {
        "school": "KNICKERBACKER MIDDLE SCHOOL",
        "district": "LANSINGBURGH CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361674001492",
    },
    {
        "school": "LANSINGBURGH SENIOR HIGH SCHOOL",
        "district": "LANSINGBURGH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361674001494",
    },
    {
        "school": "RENSSELAER PARK ELEMENTARY SCHOOL",
        "district": "LANSINGBURGH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361674001495",
    },
    {
        "school": "TURNPIKE ELEMENTARY SCHOOL",
        "district": "LANSINGBURGH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361674001496",
    },
    {
        "school": "RENSSELAER JUNIOR/SENIOR HIGH SCHOOL",
        "district": "RENSSELAER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362445003341",
    },
    {
        "school": "VAN RENSSELAER ELEMENTARY SCHOOL",
        "district": "RENSSELAER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362445003342",
    },
    {
        "school": "CASTLETON ELEMENTARY SCHOOL",
        "district": "SCHODACK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362607003594",
    },
    {
        "school": "MAPLE HILL JUNIOR/SENIOR HIGH SCHOOL",
        "district": "SCHODACK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362607003596",
    },
    {
        "school": "CARROLL HILL SCHOOL",
        "district": "TROY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362895003912",
    },
    {
        "school": "PS 2",
        "district": "TROY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362895003913",
    },
    {
        "school": "PS 14",
        "district": "TROY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362895003915",
    },
    {
        "school": "PS 16",
        "district": "TROY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362895003916",
    },
    {
        "school": "PS 18",
        "district": "TROY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362895003917",
    },
    {
        "school": "TROY HIGH SCHOOL",
        "district": "TROY CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362895003918",
    },
    {
        "school": "TROY MIDDLE SCHOOL",
        "district": "TROY CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362895003919",
    },
    {
        "school": "NORTH GREENBUSH SCHOOL",
        "district": "NORTH GREENBUSH COMMON SCHOOL DISTRICT (WILLIAMS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363141004203",
    },
    {
        "school": "GARDNER-DICKINSON SCHOOL",
        "district": "WYNANTSKILL UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363183004238",
    },
    {
        "school": "RENSSELAER-COLUMBIA-GREENE BOCES",
        "district": "RENSSELAER-COLUMBIA-GREENE BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368070004651",
    },
    {
        "school": "BALLSTON SPA MIDDLE SCHOOL",
        "district": "BALLSTON SPA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360393000148",
    },
    {
        "school": "BALLSTON SPA SENIOR HIGH SCHOOL",
        "district": "BALLSTON SPA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360393000149",
    },
    {
        "school": "MALTA AVENUE ELEMENTARY SCHOOL",
        "district": "BALLSTON SPA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360393000150",
    },
    {
        "school": "WOOD ROAD ELEMENTARY SCHOOL",
        "district": "BALLSTON SPA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360393000153",
    },
    {
        "school": "GORDON CREEK ELEMENTARY SCHOOL",
        "district": "BALLSTON SPA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360393003409",
    },
    {
        "school": "BURNT HILLS-BALLSTON LAKE SENIOR HIGH SCHOOL",
        "district": "BURNT HILLS-BALLSTON LAKE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360594000384",
    },
    {
        "school": "CHARLTON HEIGHTS ELEMENTARY SCHOOL",
        "district": "BURNT HILLS-BALLSTON LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360594000385",
    },
    {
        "school": "FRANCIS L STEVENS ELEMENTARY SCHOOL",
        "district": "BURNT HILLS-BALLSTON LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360594000386",
    },
    {
        "school": "CORINTH HIGH SCHOOL",
        "district": "CORINTH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360837000618",
    },
    {
        "school": "CORINTH MIDDLE SCHOOL",
        "district": "CORINTH CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360837002624",
    },
    {
        "school": "CORINTH ELEMENTARY SCHOOL",
        "district": "CORINTH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360837002644",
    },
    {
        "school": "EDINBURG COMMON SCHOOL",
        "district": "EDINBURG COMMON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361023000796",
    },
    {
        "school": "GALWAY JUNIOR/SENIOR HIGH SCHOOL",
        "district": "GALWAY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361173000938",
    },
    {
        "school": "JOSEPH HENRY ELEMENTARY SCHOOL",
        "district": "GALWAY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361173000939",
    },
    {
        "school": "MECHANICVILLE ELEMENTARY SCHOOL",
        "district": "MECHANICVILLE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361890001712",
    },
    {
        "school": "MECHANICVILLE JUNIOR/SENIOR HIGH SCHOOL",
        "district": "MECHANICVILLE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361890001714",
    },
    {
        "school": "GLENCLIFF SCHOOL",
        "district": "NISKAYUNA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362088002956",
    },
    {
        "school": "MAPLE AVENUE MIDDLE SCHOOL",
        "district": "SARATOGA SPRINGS CITY SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362577000269",
    },
    {
        "school": "CAROLINE STREET ELEMENTARY SCHOOL",
        "district": "SARATOGA SPRINGS CITY SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362577003536",
    },
    {
        "school": "DIVISION STREET ELEMENTARY SCHOOL",
        "district": "SARATOGA SPRINGS CITY SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362577003537",
    },
    {
        "school": "DOROTHY NOLAN ELEMENTARY SCHOOL",
        "district": "SARATOGA SPRINGS CITY SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362577003538",
    },
    {
        "school": "GEYSER ROAD ELEMENTARY SCHOOL",
        "district": "SARATOGA SPRINGS CITY SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362577003539",
    },
    {
        "school": "GREENFIELD ELEMENTARY SCHOOL",
        "district": "SARATOGA SPRINGS CITY SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362577003540",
    },
    {
        "school": "LAKE AVENUE ELEMENTARY SCHOOL",
        "district": "SARATOGA SPRINGS CITY SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362577003541",
    },
    {
        "school": "SARATOGA SPRINGS HIGH SCHOOL",
        "district": "SARATOGA SPRINGS CITY SD",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362577003543",
    },
    {
        "school": "SCHUYLERVILLE ELEMENTARY SCHOOL",
        "district": "SCHUYLERVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362616003600",
    },
    {
        "school": "SCHUYLERVILLE HIGH SCHOOL",
        "district": "SCHUYLERVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362616003602",
    },
    {
        "school": "ACADIA MIDDLE SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667001421",
    },
    {
        "school": "ARONGEN ELEMENTARY SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667003633",
    },
    {
        "school": "CHANGO ELEMENTARY SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667003634",
    },
    {
        "school": "GOWANA MIDDLE SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667003635",
    },
    {
        "school": "KARIGON ELEMENTARY SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667003636",
    },
    {
        "school": "KODA MIDDLE SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667003637",
    },
    {
        "school": "OKTE ELEMENTARY SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667003638",
    },
    {
        "school": "ORENDA ELEMENTARY SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667003639",
    },
    {
        "school": "SHENENDEHOWA HIGH SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667003640",
    },
    {
        "school": "SKANO ELEMENTARY SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667003641",
    },
    {
        "school": "TESAGO ELEMENTARY SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667003642",
    },
    {
        "school": "BALLARD ELEMENTARY SCHOOL",
        "district": "SOUTH GLENS FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362724003714",
    },
    {
        "school": "HARRISON AVENUE ELEMENTARY SCHOOL",
        "district": "SOUTH GLENS FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362724003715",
    },
    {
        "school": "MOREAU ELEMENTARY SCHOOL",
        "district": "SOUTH GLENS FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362724003716",
    },
    {
        "school": "OLIVER W WINCH MIDDLE SCHOOL",
        "district": "SOUTH GLENS FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362724003717",
    },
    {
        "school": "SOUTH GLENS FALLS SENIOR HIGH SCHOOL",
        "district": "SOUTH GLENS FALLS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362724003718",
    },
    {
        "school": "TANGLEWOOD ELEMENTARY SCHOOL",
        "district": "SOUTH GLENS FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362724003719",
    },
    {
        "school": "STILLWATER ELEMENTARY SCHOOL",
        "district": "STILLWATER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362811003799",
    },
    {
        "school": "STILLWATER MIDDLE SCHOOL HIGH SCHOOL",
        "district": "STILLWATER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362811003800",
    },
    {
        "school": "WATERFORD-HALFMOON ELEMENTARY SCHOOL",
        "district": "WATERFORD-HALFMOON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363006004041",
    },
    {
        "school": "WATERFORD-HALFMOON JUNIOR-SENIOR HIGH SCHOOL",
        "district": "WATERFORD-HALFMOON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363006004042",
    },
    {
        "school": "DRAPER MIDDLE SCHOOL",
        "district": "ROTTERDAM-MOHONASEN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000404544",
    },
    {
        "school": "MOHONASEN SENIOR HIGH SCHOOL",
        "district": "ROTTERDAM-MOHONASEN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000404545",
    },
    {
        "school": "HERMAN L BRADT ELEMENTARY SCHOOL",
        "district": "ROTTERDAM-MOHONASEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000404576",
    },
    {
        "school": "PINEWOOD ELEMENTARY SCHOOL",
        "district": "ROTTERDAM-MOHONASEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000404577",
    },
    {
        "school": "RICHARD H O'ROURKE MIDDLE SCHOOL",
        "district": "BURNT HILLS-BALLSTON LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360594000383",
    },
    {
        "school": "PASHLEY ELEMENTARY SCHOOL",
        "district": "BURNT HILLS-BALLSTON LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360594000388",
    },
    {
        "school": "DUANESBURG ELEMENTARY SCHOOL",
        "district": "DUANESBURG CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360936000714",
    },
    {
        "school": "DUANESBURG HIGH SCHOOL",
        "district": "DUANESBURG CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360936000715",
    },
    {
        "school": "BIRCHWOOD ELEMENTARY SCHOOL",
        "district": "NISKAYUNA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362088000276",
    },
    {
        "school": "VAN ANTWERP MIDDLE SCHOOL",
        "district": "NISKAYUNA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362088000304",
    },
    {
        "school": "CRAIG ELEMENTARY SCHOOL",
        "district": "NISKAYUNA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362088002955",
    },
    {
        "school": "HILLSIDE SCHOOL",
        "district": "NISKAYUNA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362088002957",
    },
    {
        "school": "NISKAYUNA HIGH SCHOOL",
        "district": "NISKAYUNA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362088002959",
    },
    {
        "school": "ROSENDALE SCHOOL",
        "district": "NISKAYUNA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362088002960",
    },
    {
        "school": "IROQUOIS MIDDLE SCHOOL",
        "district": "NISKAYUNA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362088004488",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "SCHALMONT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362598003567",
    },
    {
        "school": "SCHALMONT MIDDLE SCHOOL",
        "district": "SCHALMONT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362598003570",
    },
    {
        "school": "SCHALMONT HIGH SCHOOL",
        "district": "SCHALMONT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362598003571",
    },
    {
        "school": "HAMILTON ELEMENTARY SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003578",
    },
    {
        "school": "HOWE ELEMENTARY SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003580",
    },
    {
        "school": "JESSIE T ZOLLER ELEMENTARY SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003581",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003582",
    },
    {
        "school": "SCHENECTADY HIGH SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003583",
    },
    {
        "school": "DR MARTIN LUTHER KING SCHOOL JR ELEMENTARY SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003584",
    },
    {
        "school": "MONT PLEASANT MIDDLE SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003585",
    },
    {
        "school": "PAIGE ELEMENTARY SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003587",
    },
    {
        "school": "PLEASANT VALLEY ELEMENTARY SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003588",
    },
    {
        "school": "VAN CORLAER ELEMENTARY SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003591",
    },
    {
        "school": "WOODLAWN ELEMENTARY SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003592",
    },
    {
        "school": "YATES ELEMENTARY SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601003593",
    },
    {
        "school": "GLENDAAL SCHOOL",
        "district": "SCOTIA-GLENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362631003605",
    },
    {
        "school": "LINCOLN SCHOOL",
        "district": "SCOTIA-GLENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362631003606",
    },
    {
        "school": "SACANDAGA SCHOOL",
        "district": "SCOTIA-GLENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362631003608",
    },
    {
        "school": "SCOTIA-GLENVILLE SENIOR HIGH SCHOOL",
        "district": "SCOTIA-GLENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362631003609",
    },
    {
        "school": "SCOTIA-GLENVILLE MIDDLE SCHOOL",
        "district": "SCOTIA-GLENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362631003610",
    },
    {
        "school": "GLEN-WORDEN ELEMENTARY SCHOOL",
        "district": "SCOTIA-GLENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362631004749",
    },
    {
        "school": "WILLIAM H GOLDING MIDDLE SCHOOL",
        "district": "COBLESKILL-RICHMONDVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001000277",
    },
    {
        "school": "GEORGE D RYDER ELEMENTARY SCHOOL",
        "district": "COBLESKILL-RICHMONDVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001000564",
    },
    {
        "school": "COBLESKILL-RICHMONDVILLE HIGH SCHOOL",
        "district": "COBLESKILL-RICHMONDVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001000566",
    },
    {
        "school": "JOSEPH B RADEZ ELEMENTARY SCHOOL",
        "district": "COBLESKILL-RICHMONDVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001001014",
    },
    {
        "school": "GILBOA-CONESVILLE CENTRAL SCHOOL",
        "district": "GILBOA-CONESVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361212000970",
    },
    {
        "school": "JEFFERSON CENTRAL SCHOOL",
        "district": "JEFFERSON CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361572001359",
    },
    {
        "school": "MIDDLEBURGH ELEMENTARY SCHOOL",
        "district": "MIDDLEBURGH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361926001757",
    },
    {
        "school": "MIDDLEBURGH JUNIOR/SENIOR HIGH SCHOOL",
        "district": "MIDDLEBURGH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361926001758",
    },
    {
        "school": "SCHOHARIE ELEMENTARY SCHOOL",
        "district": "SCHOHARIE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362610003597",
    },
    {
        "school": "SCHOHARIE HIGH SCHOOL",
        "district": "SCHOHARIE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362610003598",
    },
    {
        "school": "SHARON SPRINGS CENTRAL SCHOOL",
        "district": "SHARON SPRINGS CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362658003631",
    },
    {
        "school": "AMSTERDAM HIGH SCHOOL",
        "district": "AMSTERDAM CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360297000068",
    },
    {
        "school": "WILBUR H LYNCH LITERACY ACADEMY",
        "district": "AMSTERDAM CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360297000071",
    },
    {
        "school": "MARIE CURIE INSTITUTE OF ENGINEERING AND COMMUNICATION",
        "district": "AMSTERDAM CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360297000072",
    },
    {
        "school": "RAPHAEL J MCNULTY ACADEMY FOR INTERN STUDIES & LITERACY",
        "district": "AMSTERDAM CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360297000073",
    },
    {
        "school": "WILLIAM B TECLER ARTS IN EDUCATION",
        "district": "AMSTERDAM CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360297000074",
    },
    {
        "school": "WILLIAM H BARKLEY MICROSOCIETY",
        "district": "AMSTERDAM CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360297000075",
    },
    {
        "school": "CANAJOHARIE MIDDLE SCHOOL",
        "district": "CANAJOHARIE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360630000410",
    },
    {
        "school": "CANAJOHARIE SENIOR HIGH SCHOOL",
        "district": "CANAJOHARIE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360630000411",
    },
    {
        "school": "EAST HILL SCHOOL",
        "district": "CANAJOHARIE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360630000412",
    },
    {
        "school": "FONDA-FULTONVILLE SENIOR HIGH SCHOOL",
        "district": "FONDA-FULTONVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361119000887",
    },
    {
        "school": "FONDA-FULTONVILLE K-4 SCHOOL",
        "district": "FONDA-FULTONVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361119000888",
    },
    {
        "school": "FONDA-FULTONVILLE 5-8 SCHOOL",
        "district": "FONDA-FULTONVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361119004586",
    },
    {
        "school": "HARRY HOAG SCHOOL",
        "district": "FORT PLAIN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361137000894",
    },
    {
        "school": "FORT PLAIN JUNIOR-SENIOR HIGH SCHOOL",
        "district": "FORT PLAIN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361137000895",
    },
    {
        "school": "AUBURN HIGH SCHOOL",
        "district": "AUBURN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360348000101",
    },
    {
        "school": "CASEY PARK ELEMENTARY SCHOOL",
        "district": "AUBURN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360348000102",
    },
    {
        "school": "AUBURN JUNIOR HIGH SCHOOL",
        "district": "AUBURN CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360348000103",
    },
    {
        "school": "GENESEE STREET ELEMENTARY SCHOOL",
        "district": "AUBURN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360348000104",
    },
    {
        "school": "HERMAN AVENUE ELEMENTARY SCHOOL",
        "district": "AUBURN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360348000105",
    },
    {
        "school": "OWASCO ELEMENTARY SCHOOL",
        "district": "AUBURN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360348000107",
    },
    {
        "school": "WILLIAM H SEWARD ELEMENTARY SCHOOL",
        "district": "AUBURN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360348000109",
    },
    {
        "school": "CATO-MERIDIAN SENIOR HIGH SCHOOL",
        "district": "CATO-MERIDIAN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360669000455",
    },
    {
        "school": "CATO-MERIDIAN ELEMENTARY SCHOOL",
        "district": "CATO-MERIDIAN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360669004434",
    },
    {
        "school": "CATO-MERIDIAN MIDDLE SCHOOL",
        "district": "CATO-MERIDIAN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360669004435",
    },
    {
        "school": "MILLARD FILLMORE ELEMENTARY SCHOOL",
        "district": "MORAVIA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361980001812",
    },
    {
        "school": "MORAVIA JUNIOR-SENIOR HIGH SCHOOL",
        "district": "MORAVIA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361980001813",
    },
    {
        "school": "A A GATES ELEMENTARY SCHOOL",
        "district": "PORT BYRON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362343003270",
    },
    {
        "school": "PORT BYRON SENIOR HIGH SCHOOL",
        "district": "PORT BYRON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362343003272",
    },
    {
        "school": "SOUTHERN CAYUGA  7-12 SECONDARY SCHOOL",
        "district": "SOUTHERN CAYUGA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362757003749",
    },
    {
        "school": "SOUTHERN CAYUGA ELEMENTARY SCHOOL",
        "district": "SOUTHERN CAYUGA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362757004789",
    },
    {
        "school": "ANDREW J SMITH ELEMENTARY SCHOOL",
        "district": "UNION SPRINGS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362925003935",
    },
    {
        "school": "UNION SPRINGS HIGH SCHOOL",
        "district": "UNION SPRINGS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362925003937",
    },
    {
        "school": "WEEDSPORT ELEMENTARY SCHOOL",
        "district": "WEEDSPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363042004094",
    },
    {
        "school": "WEEDSPORT JUNIOR-SENIOR HIGH SCHOOL",
        "district": "WEEDSPORT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363042004095",
    },
    {
        "school": "CAYUGA-ONONDAGA BOCES",
        "district": "CAYUGA-ONONDAGA BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368018004627",
    },
    {
        "school": "NEW YORK STATE SCHOOL FOR THE BLIND",
        "district": "NEW YORK STATE SCHOOL FOR THE BLIND",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013305035",
    },
    {
        "school": "ALEXANDER ELEMENTARY SCHOOL",
        "district": "ALEXANDER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360258000042",
    },
    {
        "school": "ALEXANDER MIDDLE SCHOOL-HIGH SCHOOL",
        "district": "ALEXANDER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360258000043",
    },
    {
        "school": "BATAVIA HIGH SCHOOL",
        "district": "BATAVIA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360399000156",
    },
    {
        "school": "BATAVIA MIDDLE SCHOOL",
        "district": "BATAVIA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360399000157",
    },
    {
        "school": "JACKSON SCHOOL",
        "district": "BATAVIA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360399000159",
    },
    {
        "school": "JOHN KENNEDY SCHOOL",
        "district": "BATAVIA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360399000160",
    },
    {
        "school": "BYRON-BERGEN ELEMENTARY SCHOOL",
        "district": "BYRON-BERGEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360609000393",
    },
    {
        "school": "BYRON-BERGEN JUNIOR/SENIOR HIGH SCHOOL",
        "district": "BYRON-BERGEN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360609000394",
    },
    {
        "school": "PEMBROKE INTERMEDIATE SCHOOL",
        "district": "PEMBROKE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360834000615",
    },
    {
        "school": "PEMBROKE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "PEMBROKE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360834000616",
    },
    {
        "school": "PEMBROKE PRIMARY SCHOOL",
        "district": "PEMBROKE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360834000617",
    },
    {
        "school": "ELBA ELEMENTARY SCHOOL",
        "district": "ELBA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361038000801",
    },
    {
        "school": "ELBA JUNIOR-SENIOR HIGH SCHOOL",
        "district": "ELBA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361038000802",
    },
    {
        "school": "LE ROY JUNIOR-SENIOR HIGH SCHOOL",
        "district": "LE ROY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361695001506",
    },
    {
        "school": "WOLCOTT STREET SCHOOL",
        "district": "LE ROY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361695001507",
    },
    {
        "school": "OAKFIELD-ALABAMA ELEMENTARY SCHOOL",
        "district": "OAKFIELD-ALABAMA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362151003054",
    },
    {
        "school": "OAKFIELD-ALABAMA MIDDLE SCHOOL HIGH SCHOOL",
        "district": "OAKFIELD-ALABAMA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362151003055",
    },
    {
        "school": "D B BUNCE ELEMENTARY SCHOOL",
        "district": "PAVILION CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362250003170",
    },
    {
        "school": "PAVILION JUNIOR-SENIOR HIGH SCHOOL",
        "district": "PAVILION CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362250003171",
    },
    {
        "school": "GENESEE VALLEY BOCES",
        "district": "GENESEE VALLEY BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368046004639",
    },
    {
        "school": "CHENANGO VALLEY MIDDLE SCHOOL",
        "district": "CHENANGO VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360729004924",
    },
    {
        "school": "WAVERLY MIDDLE SCHOOL",
        "district": "WAVERLY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363027005437",
    },
    {
        "school": "C R WEEKS ELEMENTARY SCHOOL",
        "district": "WINDSOR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360273000047",
    },
    {
        "school": "A F PALMER ELEMENTARY SCHOOL / WINDSOR CENTRAL MIDDLE SCHOOL",
        "district": "WINDSOR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360273000048",
    },
    {
        "school": "FLOYD BELL ELEMENTARY SCHOOL",
        "district": "WINDSOR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360273004334",
    },
    {
        "school": "WINDSOR CENTRAL HIGH SCHOOL",
        "district": "WINDSOR CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360273004430",
    },
    {
        "school": "BENJAMIN FRANKLIN ELEMENTARY SCHOOL",
        "district": "BINGHAMTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360487000223",
    },
    {
        "school": "CALVIN COOLIDGE SCHOOL",
        "district": "BINGHAMTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360487000224",
    },
    {
        "school": "EAST MIDDLE SCHOOL",
        "district": "BINGHAMTON CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360487000228",
    },
    {
        "school": "HORACE MANN SCHOOL",
        "district": "BINGHAMTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360487000229",
    },
    {
        "school": "MACARTHUR SCHOOL",
        "district": "BINGHAMTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360487000230",
    },
    {
        "school": "THEODORE ROOSEVELT SCHOOL",
        "district": "BINGHAMTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360487000232",
    },
    {
        "school": "THOMAS JEFFERSON SCHOOL",
        "district": "BINGHAMTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360487000233",
    },
    {
        "school": "WEST MIDDLE SCHOOL",
        "district": "BINGHAMTON CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360487000234",
    },
    {
        "school": "WOODROW WILSON SCHOOL",
        "district": "BINGHAMTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360487000235",
    },
    {
        "school": "BINGHAMTON HIGH SCHOOL",
        "district": "BINGHAMTON CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360487004380",
    },
    {
        "school": "CHENANGO FORKS ELEMENTARY SCHOOL",
        "district": "CHENANGO FORKS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360726000512",
    },
    {
        "school": "CHENANGO FORKS HIGH SCHOOL",
        "district": "CHENANGO FORKS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360726000513",
    },
    {
        "school": "CHENANGO FORKS MIDDLE SCHOOL",
        "district": "CHENANGO FORKS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360726000514",
    },
    {
        "school": "PORT DICKINSON ELEMENTARY SCHOOL",
        "district": "CHENANGO VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360729000040",
    },
    {
        "school": "CHENANGO VALLEY HIGH SCHOOL",
        "district": "CHENANGO VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360729000517",
    },
    {
        "school": "CHENANGO BRIDGE ELEMENTARY SCHOOL",
        "district": "CHENANGO VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360729000518",
    },
    {
        "school": "ANN G MCGUINNESS ELEMENTAR SCHOOL",
        "district": "UNION-ENDICOTT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361071000845",
    },
    {
        "school": "CHARLES F JOHNSON JR ELEMENTARY SCHOOL",
        "district": "UNION-ENDICOTT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361071000846",
    },
    {
        "school": "JENNIE F SNAPP MIDDLE SCHOOL",
        "district": "UNION-ENDICOTT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361071000851",
    },
    {
        "school": "UNION-ENDICOTT HIGH SCHOOL",
        "district": "UNION-ENDICOTT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361071000854",
    },
    {
        "school": "GEORGE F JOHNSON ELEMENTARY SCHOOL",
        "district": "UNION-ENDICOTT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361071004314",
    },
    {
        "school": "HARPURSVILLE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "HARPURSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361371001119",
    },
    {
        "school": "W A OLMSTED ELEMENTARY SCHOOL",
        "district": "HARPURSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361371001120",
    },
    {
        "school": "JOHNSON CITY MIDDLE SCHOOL",
        "district": "JOHNSON CITY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361590001373",
    },
    {
        "school": "JOHNSON CITY ELEMENTARY/PRIMARY SCHOOL",
        "district": "JOHNSON CITY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361590001374",
    },
    {
        "school": "JOHNSON CITY SENIOR HIGH SCHOOL",
        "district": "JOHNSON CITY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361590001375",
    },
    {
        "school": "JOHNSON CITY ELEMENTARY/INTERMEDIATE SCHOOL",
        "district": "JOHNSON CITY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361590001376",
    },
    {
        "school": "HOMER BRINK SCHOOL",
        "district": "MAINE-ENDWELL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361815001627",
    },
    {
        "school": "MAINE-ENDWELL MIDDLE SCHOOL",
        "district": "MAINE-ENDWELL CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361815001629",
    },
    {
        "school": "MAINE-ENDWELL SENIOR HIGH SCHOOL",
        "district": "MAINE-ENDWELL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361815001630",
    },
    {
        "school": "MAINE MEMORIAL SCHOOL",
        "district": "MAINE-ENDWELL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361815001631",
    },
    {
        "school": "BROOKSIDE ELEMENTARY SCHOOL",
        "district": "SUSQUEHANNA VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362838003821",
    },
    {
        "school": "RICHARD T STANK MIDDLE SCHOOL",
        "district": "SUSQUEHANNA VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362838003824",
    },
    {
        "school": "SUSQUEHANNA VALLEY SENIOR HIGH SCHOOL",
        "district": "SUSQUEHANNA VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362838003825",
    },
    {
        "school": "F P DONNELLY SCHOOL",
        "district": "SUSQUEHANNA VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362838004570",
    },
    {
        "school": "AFRICAN ROAD ELEMENTARY SCHOOL",
        "district": "VESTAL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362961003984",
    },
    {
        "school": "VESTAL MIDDLE SCHOOL",
        "district": "VESTAL CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362961003985",
    },
    {
        "school": "CLAYTON AVENUE ELEMENTARY SCHOOL",
        "district": "VESTAL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362961003986",
    },
    {
        "school": "GLENWOOD ELEMENTARY SCHOOL",
        "district": "VESTAL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362961003987",
    },
    {
        "school": "VESTAL HILLS ELEMENTARY SCHOOL",
        "district": "VESTAL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362961003990",
    },
    {
        "school": "VESTAL SENIOR HIGH SCHOOL",
        "district": "VESTAL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362961003992",
    },
    {
        "school": "CARYL E ADAMS PRIMARY SCHOOL",
        "district": "WHITNEY POINT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363138004199",
    },
    {
        "school": "TIOUGHNIOGA RIVERSIDE ACADEMY",
        "district": "WHITNEY POINT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363138004201",
    },
    {
        "school": "WHITNEY POINT SENIOR HIGH SCHOOL",
        "district": "WHITNEY POINT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363138004202",
    },
    {
        "school": "BROOME-DELAWARE-TIOGA BOCES",
        "district": "BROOME-DELAWARE-TIOGA BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368014004625",
    },
    {
        "school": "SPENCER-VAN ETTEN ELEMENTARY SCHOOL",
        "district": "SPENCER-VAN ETTEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362775003760",
    },
    {
        "school": "DEPOSIT ELEMENTARY SCHOOL",
        "district": "DEPOSIT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360906000693",
    },
    {
        "school": "DEPOSIT MIDDLE-SENIOR HIGH SCHOOL",
        "district": "DEPOSIT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360906000694",
    },
    {
        "school": "CANDOR ELEMENTARY SCHOOL",
        "district": "CANDOR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360642000423",
    },
    {
        "school": "CANDOR JUNIOR-SENIOR HIGH SCHOOL",
        "district": "CANDOR CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360642000424",
    },
    {
        "school": "THOMAS J WATSON SR ELEMENTARY SCHOOL",
        "district": "UNION-ENDICOTT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361071000853",
    },
    {
        "school": "NATHAN T HALL SCHOOL",
        "district": "NEWARK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362067002898",
    },
    {
        "school": "NEWARK VALLEY MIDDLE SCHOOL",
        "district": "NEWARK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362067002899",
    },
    {
        "school": "NEWARK VALLEY SENIOR HIGH SCHOOL",
        "district": "NEWARK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362067002900",
    },
    {
        "school": "APALACHIN ELEMENTARY SCHOOL",
        "district": "OWEGO-APALACHIN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362217003136",
    },
    {
        "school": "OWEGO FREE ACADEMY",
        "district": "OWEGO-APALACHIN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362217003138",
    },
    {
        "school": "OWEGO-APALACHIN MIDDLE SCHOOL",
        "district": "OWEGO-APALACHIN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362217003139",
    },
    {
        "school": "OWEGO ELEMENTARY SCHOOL",
        "district": "OWEGO-APALACHIN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362217003140",
    },
    {
        "school": "SPENCER-VAN ETTEN MIDDLE SCHOOL",
        "district": "SPENCER-VAN ETTEN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362775003758",
    },
    {
        "school": "SPENCER-VAN ETTEN HIGH SCHOOL",
        "district": "SPENCER-VAN ETTEN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362775003759",
    },
    {
        "school": "TIOGA ELEMENTARY SCHOOL",
        "district": "TIOGA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362871003897",
    },
    {
        "school": "TIOGA MIDDLE SCHOOL",
        "district": "TIOGA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362871003898",
    },
    {
        "school": "TIOGA SENIOR HIGH SCHOOL",
        "district": "TIOGA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362871003899",
    },
    {
        "school": "TIOGA HILLS ELEMENTARY SCHOOL",
        "district": "VESTAL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362961003989",
    },
    {
        "school": "ELM STREET ELEMENTARY SCHOOL",
        "district": "WAVERLY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363027004066",
    },
    {
        "school": "LINCOLN STREET ELEMENTARY SCHOOL",
        "district": "WAVERLY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363027004068",
    },
    {
        "school": "WAVERLY HIGH SCHOOL",
        "district": "WAVERLY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363027004069",
    },
    {
        "school": "BUFFALO UNITED CHARTER SCHOOL",
        "district": "BUFFALO UNITED CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007105538",
    },
    {
        "school": "ENTERPRISE CHARTER SCHOOL",
        "district": "ENTERPRISE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007305551",
    },
    {
        "school": "BUFFALO ACADEMY OF SCIENCE CHARTER SCHOOL",
        "district": "BUFFALO ACADEMY OF SCIENCE CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010505602",
    },
    {
        "school": "WESTERN NEW YORK MARITIME CHARTER SCHOOL",
        "district": "WESTERN NEW YORK MARITIME CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010605603",
    },
    {
        "school": "WESTMINSTER COMMUNITY CHARTER SCHOOL",
        "district": "WESTMINSTER COMMUNITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010705604",
    },
    {
        "school": "AKRON MIDDLE SCHOOL",
        "district": "AKRON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360243005012",
    },
    {
        "school": "HARVEY AUSTIN SCHOOL #97",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585005600",
    },
    {
        "school": "CHEEKTOWAGA MIDDLE SCHOOL",
        "district": "CHEEKTOWAGA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360723005572",
    },
    {
        "school": "MARTIN ROAD ELEMENTARY SCHOOL",
        "district": "LACKAWANNA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361644005578",
    },
    {
        "school": "ROYALTON-HARTLAND MIDDLE SCHOOL",
        "district": "ROYALTON-HARTLAND CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362514005836",
    },
    {
        "school": "STARPOINT MIDDLE SCHOOL",
        "district": "STARPOINT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362805005590",
    },
    {
        "school": "CHARTER SCHOOL FOR APPLIED TECHNOLOGIES",
        "district": "CHARTER SCHOOL FOR APPLIED TECHNOLOGIES",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002504349",
    },
    {
        "school": "KING CENTER CHARTER SCHOOL",
        "district": "KING CENTER CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360003504336",
    },
    {
        "school": "SOUTH BUFFALO CHARTER SCHOOL",
        "district": "SOUTH BUFFALO CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360003604337",
    },
    {
        "school": "TAPESTRY CHARTER SCHOOL",
        "district": "TAPESTRY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360003804346",
    },
    {
        "school": "GLOBAL CONCEPTS CHARTER SCHOOL",
        "district": "GLOBAL CONCEPTS CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360006704861",
    },
    {
        "school": "AKRON ELEMENTARY SCHOOL",
        "district": "AKRON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360243000012",
    },
    {
        "school": "AKRON HIGH SCHOOL",
        "district": "AKRON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360243000013",
    },
    {
        "school": "ALDEN MIDDLE SCHOOL",
        "district": "ALDEN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360255000038",
    },
    {
        "school": "ALDEN SENIOR HIGH SCHOOL",
        "district": "ALDEN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360255000039",
    },
    {
        "school": "ALDEN PRIMARY AT TOWNLINE",
        "district": "ALDEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360255000041",
    },
    {
        "school": "AMHERST CENTRAL HIGH SCHOOL",
        "district": "AMHERST CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360292000061",
    },
    {
        "school": "WINDERMERE BLVD SCHOOL",
        "district": "AMHERST CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360292004289",
    },
    {
        "school": "AMHERST MIDDLE SCHOOL",
        "district": "AMHERST CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360292004335",
    },
    {
        "school": "SMALLWOOD DRIVE SCHOOL",
        "district": "AMHERST CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360292004378",
    },
    {
        "school": "BUFFALO ELEMENTARY SCHOOL OF TECHNOLOGY",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000295",
    },
    {
        "school": "BUFFALO ACADEMY FOR THE VISUAL & PERFORMING ARTS",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000297",
    },
    {
        "school": "BURGARD HIGH SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360585000301",
    },
    {
        "school": "DR LYDIA T WRIGHT SCH OF EXCELLENCE",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000302",
    },
    {
        "school": "EMERSON SCHOOL OF HOSPITALITY",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000307",
    },
    {
        "school": "CITY HONORS SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000308",
    },
    {
        "school": "HERMAN BADILLO BILINGUAL ACADEMY",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000310",
    },
    {
        "school": "HUTCHINSON CENTRAL TECHNICAL HIGH SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000311",
    },
    {
        "school": "MCKINLEY VOCATIONAL HIGH SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360585000315",
    },
    {
        "school": "BENNETT PARK MONTESSORI SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000316",
    },
    {
        "school": "PS 17",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000317",
    },
    {
        "school": "D'YOUVILLE-PORTER CAMPUS",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000318",
    },
    {
        "school": "DR A PANTOJA COMM SCH EXCLLNCE -#18",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000323",
    },
    {
        "school": "NATIVE AMERICAN MAGNET",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000324",
    },
    {
        "school": "PS 27 HILLERY PARK ACADEMY",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000329",
    },
    {
        "school": "HARRIET ROSS TUBMAN ACADEMY",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000332",
    },
    {
        "school": "BILINGUAL CENTER",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000333",
    },
    {
        "school": "MARVA J DANIEL FUTURES PREPARATORY SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000335",
    },
    {
        "school": "PS 42 OCCUPATIONAL TRAINING CENTER",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360585000338",
    },
    {
        "school": "LOVEJOY DISCOVERY SCHOOL #43",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000339",
    },
    {
        "school": "INTERNATIONAL SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000341",
    },
    {
        "school": "COMMUNITY SCHOOL #53",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000346",
    },
    {
        "school": "DR GEORGE BLACKMAN ECC",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000347",
    },
    {
        "school": "FREDERICK OLMSTED #156",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000348",
    },
    {
        "school": "PS 59 DR CHARLES DREW SCIENCE MAGNET",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000350",
    },
    {
        "school": "PS 61 ARTHUR O EVE SCHOOL OF DISTINCTION",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000352",
    },
    {
        "school": "PS 64 FREDERICK LAW OLMSTED",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000355",
    },
    {
        "school": "PS 65 ROOSEVELT ECC",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000356",
    },
    {
        "school": "PS 66 NORTH PARK MIDDLE ACADEMY",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000357",
    },
    {
        "school": "PS 69 HOUGHTON ACADEMY",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000360",
    },
    {
        "school": "LORRAINE ELEMENTARY SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000363",
    },
    {
        "school": "PS 74 HAMLIN PARK - CLAUDE AND OUIDA CLAPP ACADEMY",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000364",
    },
    {
        "school": "HIGHGATE HEIGHTS",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000368",
    },
    {
        "school": "PS 81",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000369",
    },
    {
        "school": "PS 82",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000370",
    },
    {
        "school": "PS 84",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360585000371",
    },
    {
        "school": "SOUTH PARK HIGH SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000378",
    },
    {
        "school": "WATERFRONT ELEMENTARY SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000381",
    },
    {
        "school": "WEST HERTEL ELEMENTARY SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585000382",
    },
    {
        "school": "STANLEY MAKOWSKI EARLY CHILDHOOD CENTER",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585001549",
    },
    {
        "school": "LEONARDO DA VINCI HIGH SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585003275",
    },
    {
        "school": "DISCOVERY SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585003478",
    },
    {
        "school": "PFC WILLIAM J GRABIARZ #79",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585003481",
    },
    {
        "school": "SOUTHSIDE ELEMENTARY SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585004506",
    },
    {
        "school": "CHARLOTTE SIDWAY SCHOOL",
        "district": "GRAND ISLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360702000462",
    },
    {
        "school": "VERONICA E CONNOR MIDDLE SCHOOL",
        "district": "GRAND ISLAND CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360702000493",
    },
    {
        "school": "GRAND ISLAND SENIOR HIGH SCHOOL",
        "district": "GRAND ISLAND CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360702000494",
    },
    {
        "school": "HUTH ROAD SCHOOL",
        "district": "GRAND ISLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360702000495",
    },
    {
        "school": "KAEGEBEIN SCHOOL",
        "district": "GRAND ISLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360702000496",
    },
    {
        "school": "CHEEKTOWAGA HIGH SCHOOL",
        "district": "CHEEKTOWAGA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360723000509",
    },
    {
        "school": "UNION EAST ELEMENTARY SCHOOL",
        "district": "CHEEKTOWAGA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360723000511",
    },
    {
        "school": "CLARENCE CENTER ELEMENTARY SCHOOL",
        "district": "CLARENCE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360759000541",
    },
    {
        "school": "CLARENCE MIDDLE SCHOOL",
        "district": "CLARENCE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360759000542",
    },
    {
        "school": "CLARENCE SENIOR HIGH SCHOOL",
        "district": "CLARENCE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360759000543",
    },
    {
        "school": "HARRIS HILL ELEMENTARY SCHOOL",
        "district": "CLARENCE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360759000544",
    },
    {
        "school": "LEDGEVIEW ELEMENTARY SCHOOL",
        "district": "CLARENCE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360759000545",
    },
    {
        "school": "SHERIDAN HILL ELEMENTARY SCHOOL",
        "district": "CLARENCE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360759004680",
    },
    {
        "school": "CLEVELAND HILL HIGH SCHOOL",
        "district": "CLEVELAND HILL UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360768000549",
    },
    {
        "school": "CLEVELAND HILL ELEMENTARY SCHOOL",
        "district": "CLEVELAND HILL UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360768000550",
    },
    {
        "school": "CLEVELAND HILL MIDDLE SCHOOL",
        "district": "CLEVELAND HILL UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360768004583",
    },
    {
        "school": "CAYUGA HEIGHTS ELEMENTARY SCHOOL",
        "district": "DEPEW UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360903000688",
    },
    {
        "school": "DEPEW HIGH SCHOOL",
        "district": "DEPEW UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360903000689",
    },
    {
        "school": "DEPEW MIDDLE SCHOOL",
        "district": "DEPEW UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360903000690",
    },
    {
        "school": "EAST AURORA MIDDLE SCHOOL",
        "district": "EAST AURORA UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360954000725",
    },
    {
        "school": "EAST AURORA HIGH SCHOOL",
        "district": "EAST AURORA UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360954000726",
    },
    {
        "school": "PARKDALE ELEMENTARY SCHOOL",
        "district": "EAST AURORA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360954000727",
    },
    {
        "school": "EDEN ELEMENTARY SCHOOL",
        "district": "EDEN CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361017000790",
    },
    {
        "school": "EDEN MIDDLE & HIGH SCHOOL",
        "district": "EDEN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361017000791",
    },
    {
        "school": "G L PRIESS PRIMARY SCHOOL",
        "district": "EDEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361017004768",
    },
    {
        "school": "BIG TREE ELEMENTARY SCHOOL",
        "district": "FRONTIER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361167000468",
    },
    {
        "school": "FRONTIER MIDDLE SCHOOL",
        "district": "FRONTIER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361167000920",
    },
    {
        "school": "BLASDELL ELEMENTARY SCHOOL",
        "district": "FRONTIER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361167000923",
    },
    {
        "school": "CLOVERBANK ELEMENTARY SCHOOL",
        "district": "FRONTIER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361167000924",
    },
    {
        "school": "FRONTIER SENIOR HIGH SCHOOL",
        "district": "FRONTIER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361167000925",
    },
    {
        "school": "PINEHURST ELEMENTARY SCHOOL",
        "district": "FRONTIER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361167000926",
    },
    {
        "school": "COLDEN ELEMENTARY SCHOOL",
        "district": "SPRINGVILLE-GRIFFITH INSTITUTE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361299001062",
    },
    {
        "school": "GRIFFITH INSTITUTE HIGH SCHOOL",
        "district": "SPRINGVILLE-GRIFFITH INSTITUTE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361299001064",
    },
    {
        "school": "GRIFFITH INSTITUTE MIDDLE SCHOOL",
        "district": "SPRINGVILLE-GRIFFITH INSTITUTE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361299001065",
    },
    {
        "school": "SPRINGVILLE ELEMENTARY SCHOOL",
        "district": "SPRINGVILLE-GRIFFITH INSTITUTE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361299001066",
    },
    {
        "school": "ARMOR ELEMENTARY SCHOOL",
        "district": "HAMBURG CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361335001095",
    },
    {
        "school": "BOSTON VALLEY ELEMENTARY SCHOOL",
        "district": "HAMBURG CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361335001096",
    },
    {
        "school": "CHARLOTTE AVENUE ELEMENTARY SCHOOL",
        "district": "HAMBURG CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361335001097",
    },
    {
        "school": "HAMBURG MIDDLE SCHOOL",
        "district": "HAMBURG CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361335001098",
    },
    {
        "school": "HAMBURG HIGH SCHOOL",
        "district": "HAMBURG CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361335001099",
    },
    {
        "school": "UNION PLEASANT AVENUE ELEMENTARY SCHOOL",
        "district": "HAMBURG CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361335001100",
    },
    {
        "school": "HAROLD O BRUMSTED ELEMENTARY SCHOOL",
        "district": "HOLLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361455001204",
    },
    {
        "school": "HOLLAND HIGH SCHOOL",
        "district": "HOLLAND CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361455001205",
    },
    {
        "school": "IROQUOIS INTERMEDIATE SCHOOL",
        "district": "IROQUOIS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361536001292",
    },
    {
        "school": "IROQUOIS MIDDLE SCHOOL",
        "district": "IROQUOIS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361536001293",
    },
    {
        "school": "IROQUOIS SENIOR HIGH SCHOOL",
        "district": "IROQUOIS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361536001294",
    },
    {
        "school": "MARILLA PRIMARY SCHOOL",
        "district": "IROQUOIS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361536001295",
    },
    {
        "school": "WALES PRIMARY SCHOOL",
        "district": "IROQUOIS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361536001296",
    },
    {
        "school": "ELMA PRIMARY SCHOOL",
        "district": "IROQUOIS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361536004796",
    },
    {
        "school": "BEN FRANKLIN ELEMENTARY SCHOOL",
        "district": "KENMORE-TONAWANDA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361623001402",
    },
    {
        "school": "BEN FRANKLIN MIDDLE SCHOOL",
        "district": "KENMORE-TONAWANDA UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361623001403",
    },
    {
        "school": "CHARLES A LINDBERGH ELEMENTARY SCHOOL",
        "district": "KENMORE-TONAWANDA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361623001405",
    },
    {
        "school": "HERBERT HOOVER ELEMENTARY SCHOOL",
        "district": "KENMORE-TONAWANDA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361623001407",
    },
    {
        "school": "KENMORE EAST SENIOR HIGH SCHOOL",
        "district": "KENMORE-TONAWANDA UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361623001410",
    },
    {
        "school": "KENMORE WEST SENIOR HIGH SCHOOL",
        "district": "KENMORE-TONAWANDA UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361623001412",
    },
    {
        "school": "HERBERT HOOVER MIDDLE SCHOOL",
        "district": "KENMORE-TONAWANDA UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361623004392",
    },
    {
        "school": "HOLMES ELEMENTARY SCHOOL",
        "district": "KENMORE-TONAWANDA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361623004393",
    },
    {
        "school": "THOMAS A EDISON ELEMENTARY SCHOOL",
        "district": "KENMORE-TONAWANDA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361623004396",
    },
    {
        "school": "LACKAWANNA HIGH SCHOOL",
        "district": "LACKAWANNA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361644001452",
    },
    {
        "school": "TRUMAN ELEMENTARY SCHOOL",
        "district": "LACKAWANNA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361644001455",
    },
    {
        "school": "LACKAWANNA MIDDLE SCHOOL",
        "district": "LACKAWANNA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361644002836",
    },
    {
        "school": "A J SCHMIDT ELEMENTARY SCHOOL",
        "district": "EVANS-BRANT CENTRAL SCHOOL DISTRICT (LAKE SHORE)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361656001462",
    },
    {
        "school": "HIGHLAND ELEMENTARY SCHOOL",
        "district": "EVANS-BRANT CENTRAL SCHOOL DISTRICT (LAKE SHORE)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361656001465",
    },
    {
        "school": "JOHN T WAUGH ELEMENTARY SCHOOL",
        "district": "EVANS-BRANT CENTRAL SCHOOL DISTRICT (LAKE SHORE)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361656001467",
    },
    {
        "school": "LAKE SHORE MIDDLE SCHOOL",
        "district": "EVANS-BRANT CENTRAL SCHOOL DISTRICT (LAKE SHORE)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361656001468",
    },
    {
        "school": "LAKE SHORE SENIOR HIGH SCHOOL",
        "district": "EVANS-BRANT CENTRAL SCHOOL DISTRICT (LAKE SHORE)",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361656001469",
    },
    {
        "school": "JOHN A SCIOLE ELEMENTARY SCHOOL",
        "district": "LANCASTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361668001481",
    },
    {
        "school": "LANCASTER MIDDLE SCHOOL",
        "district": "LANCASTER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361668001482",
    },
    {
        "school": "COMO PARK ELEMENTARY SCHOOL",
        "district": "LANCASTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361668001485",
    },
    {
        "school": "COURT STREET ELEMENTARY SCHOOL",
        "district": "LANCASTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361668001486",
    },
    {
        "school": "HILLVIEW ELEMENTARY SCHOOL",
        "district": "LANCASTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361668001487",
    },
    {
        "school": "LANCASTER HIGH SCHOOL",
        "district": "LANCASTER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361668001488",
    },
    {
        "school": "WILLIAM STREET SCHOOL",
        "district": "LANCASTER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361668003289",
    },
    {
        "school": "MARYVALE MIDDLE SCHOOL",
        "district": "CHEEKTOWAGA-MARYVALE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361860001677",
    },
    {
        "school": "MARYVALE HIGH SCHOOL",
        "district": "CHEEKTOWAGA-MARYVALE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361860001678",
    },
    {
        "school": "MARYVALE PRIMARY SCHOOL",
        "district": "CHEEKTOWAGA-MARYVALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361860001679",
    },
    {
        "school": "MARYVALE INTERMEDIATE SCHOOL",
        "district": "CHEEKTOWAGA-MARYVALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361860004443",
    },
    {
        "school": "NORTH COLLINS ELEMENTARY SCHOOL",
        "district": "NORTH COLLINS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362097002977",
    },
    {
        "school": "NORTH COLLINS JUNIOR-SENIOR HIGH SCHOOL",
        "district": "NORTH COLLINS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362097002978",
    },
    {
        "school": "ELLICOTT ROAD ELEMENTARY SCHOOL",
        "district": "ORCHARD PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362190003109",
    },
    {
        "school": "ORCHARD PARK HIGH SCHOOL",
        "district": "ORCHARD PARK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362190003110",
    },
    {
        "school": "ORCHARD PARK MIDDLE SCHOOL",
        "district": "ORCHARD PARK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362190003111",
    },
    {
        "school": "SOUTH DAVIS ELEMENTARY SCHOOL",
        "district": "ORCHARD PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362190003112",
    },
    {
        "school": "WINDOM ELEMENTARY SCHOOL",
        "district": "ORCHARD PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362190003113",
    },
    {
        "school": "EGGERT ROAD ELEMENTARY SCHOOL",
        "district": "ORCHARD PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362190004529",
    },
    {
        "school": "JOHN F KENNEDY MIDDLE SCHOOL",
        "district": "CHEEKTOWAGA-SLOAN UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362700002831",
    },
    {
        "school": "JOHN F KENNEDY SENIOR HIGH SCHOOL",
        "district": "CHEEKTOWAGA-SLOAN UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362700003672",
    },
    {
        "school": "THEODORE ROOSEVELT SCHOOL",
        "district": "CHEEKTOWAGA-SLOAN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362700003673",
    },
    {
        "school": "WOODROW WILSON ELEMENTARY SCHOOL",
        "district": "CHEEKTOWAGA-SLOAN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362700003674",
    },
    {
        "school": "GLENDALE ELEMENTARY SCHOOL",
        "district": "SWEET HOME CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362850003827",
    },
    {
        "school": "HERITAGE HEIGHTS ELEMENTARY SCHOOL",
        "district": "SWEET HOME CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362850003828",
    },
    {
        "school": "MAPLEMERE ELEMENTARY SCHOOL",
        "district": "SWEET HOME CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362850003829",
    },
    {
        "school": "SWEET HOME MIDDLE SCHOOL",
        "district": "SWEET HOME CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362850003831",
    },
    {
        "school": "SWEET HOME SENIOR HIGH SCHOOL",
        "district": "SWEET HOME CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362850003832",
    },
    {
        "school": "WILLOW RIDGE ELEMENTARY SCHOOL",
        "district": "SWEET HOME CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362850003833",
    },
    {
        "school": "FLETCHER ELEMENTARY SCHOOL",
        "district": "TONAWANDA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362874003902",
    },
    {
        "school": "MULLEN ELEMENTARY SCHOOL",
        "district": "TONAWANDA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362874003904",
    },
    {
        "school": "RIVERVIEW ELEMENTARY SCHOOL",
        "district": "TONAWANDA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362874003905",
    },
    {
        "school": "TONAWANDA MIDDLE/HIGH SCHOOL",
        "district": "TONAWANDA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362874003907",
    },
    {
        "school": "ALLENDALE ELEMENTARY SCHOOL",
        "district": "WEST SENECA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363078004140",
    },
    {
        "school": "CLINTON ELEMENTARY SCHOOL",
        "district": "WEST SENECA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363078004142",
    },
    {
        "school": "EAST MIDDLE SCHOOL",
        "district": "WEST SENECA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363078004144",
    },
    {
        "school": "NORTHWOOD ELEMENTARY SCHOOL",
        "district": "WEST SENECA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363078004147",
    },
    {
        "school": "WEST SENECA EAST SENIOR HIGH SCHOOL",
        "district": "WEST SENECA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363078004149",
    },
    {
        "school": "WEST MIDDLE SCHOOL",
        "district": "WEST SENECA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363078004150",
    },
    {
        "school": "WEST SENECA WEST SENIOR HIGH SCHOOL",
        "district": "WEST SENECA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363078004151",
    },
    {
        "school": "WINCHESTER ELEMENTARY SCHOOL",
        "district": "WEST SENECA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363078004152",
    },
    {
        "school": "WEST ELEMENTARY SCHOOL",
        "district": "WEST SENECA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363078004754",
    },
    {
        "school": "TRANSIT MIDDLE SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147000457",
    },
    {
        "school": "COUNTRY PARKWAY ELEMENTARY SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004209",
    },
    {
        "school": "DODGE ELEMENTARY SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004210",
    },
    {
        "school": "FOREST ELEMENTARY SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004211",
    },
    {
        "school": "HEIM ELEMENTARY SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004212",
    },
    {
        "school": "HEIM MIDDLE SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004213",
    },
    {
        "school": "MAPLE EAST ELEMENTARY SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004214",
    },
    {
        "school": "MAPLE WEST ELEMENTARY SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004215",
    },
    {
        "school": "MILL MIDDLE SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004216",
    },
    {
        "school": "WILLIAMSVILLE EAST HIGH SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004217",
    },
    {
        "school": "WILLIAMSVILLE NORTH HIGH SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004218",
    },
    {
        "school": "WILLIAMSVILLE SOUTH HIGH SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004219",
    },
    {
        "school": "CASEY MIDDLE SCHOOL",
        "district": "WILLIAMSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363147004756",
    },
    {
        "school": "ERIE 1 BOCES",
        "district": "ERIE 1 BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368030004631",
    },
    {
        "school": "ERIE 2-CHAUTAUQUA-CATTARAUGUS BOCES",
        "district": "ERIE 2-CHAUTAUQUA-CATTARAUGUS BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368032004632",
    },
    {
        "school": "PRATT ELEMENTARY SCHOOL",
        "district": "BARKER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360396000154",
    },
    {
        "school": "BARKER JUNIOR/SENIOR HIGH SCHOOL",
        "district": "BARKER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360396000155",
    },
    {
        "school": "LEWISTON PORTER MIDDLE SCHOOL",
        "district": "LEWISTON-PORTER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361719001533",
    },
    {
        "school": "LEWISTON PORTER SENIOR HIGH SCHOOL",
        "district": "LEWISTON-PORTER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361719001534",
    },
    {
        "school": "PRIMARY EDUCATION CENTER",
        "district": "LEWISTON-PORTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361719004819",
    },
    {
        "school": "INTERMEDIATE EDUCATION CENTER",
        "district": "LEWISTON-PORTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361719004833",
    },
    {
        "school": "ANNA MERRITT ELEMENTARY SCHOOL",
        "district": "LOCKPORT CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361767001579",
    },
    {
        "school": "CHARLES A UPSON ELEMENTARY SCHOOL",
        "district": "LOCKPORT CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361767001580",
    },
    {
        "school": "EMMET BELKNAP INTERMEDIATE SCHOOL",
        "district": "LOCKPORT CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361767001583",
    },
    {
        "school": "GEORGE SOUTHARD ELEMENTARY SCHOOL",
        "district": "LOCKPORT CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361767001584",
    },
    {
        "school": "LOCKPORT HIGH SCHOOL",
        "district": "LOCKPORT CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361767001586",
    },
    {
        "school": "NORTH PARK JUNIOR HIGH SCHOOL",
        "district": "LOCKPORT CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361767001587",
    },
    {
        "school": "ROY KELLEY ELEMENTARY SCHOOL",
        "district": "LOCKPORT CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361767001588",
    },
    {
        "school": "NEWFANE EARLY CHILDHOOD CENTER",
        "district": "NEWFANE CENTRAL SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362076001415",
    },
    {
        "school": "NEWFANE ELEMENTARY SCHOOL",
        "district": "NEWFANE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362076002920",
    },
    {
        "school": "NEWFANE MIDDLE SCHOOL",
        "district": "NEWFANE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362076002921",
    },
    {
        "school": "NEWFANE SENIOR HIGH SCHOOL",
        "district": "NEWFANE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362076002922",
    },
    {
        "school": "HENRY J KALFAS MAGNET SCHOOL",
        "district": "NIAGARA FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362082002926",
    },
    {
        "school": "HARRY F ABATE ELEMENTARY SCHOOL",
        "district": "NIAGARA FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362082002930",
    },
    {
        "school": "HYDE PARK SCHOOL",
        "district": "NIAGARA FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362082002931",
    },
    {
        "school": "MAPLE AVENUE SCHOOL",
        "district": "NIAGARA FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362082002934",
    },
    {
        "school": "NIAGARA STREET SCHOOL",
        "district": "NIAGARA FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362082002936",
    },
    {
        "school": "GERALDINE J MANN SCHOOL",
        "district": "NIAGARA FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362082002937",
    },
    {
        "school": "SEVENTY NINTH STREET SCHOOL",
        "district": "NIAGARA FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362082002941",
    },
    {
        "school": "NIAGARA FALLS HIGH SCHOOL",
        "district": "NIAGARA FALLS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362082004834",
    },
    {
        "school": "COLONIAL VILLAGE ELEMENTARY SCHOOL",
        "district": "NIAGARA-WHEATFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362085002948",
    },
    {
        "school": "EDWARD TOWN MIDDLE SCHOOL",
        "district": "NIAGARA-WHEATFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362085002949",
    },
    {
        "school": "ERRICK ROAD ELEMENTARY SCHOOL",
        "district": "NIAGARA-WHEATFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362085002950",
    },
    {
        "school": "NIAGARA-WHEATFIELD SENIOR HIGH SCHOOL",
        "district": "NIAGARA-WHEATFIELD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362085002953",
    },
    {
        "school": "TUSCARORA ELEMENTARY SCHOOL",
        "district": "NIAGARA-WHEATFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362085002954",
    },
    {
        "school": "WEST STREET ELEMENTARY SCHOOL",
        "district": "NIAGARA-WHEATFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362085003395",
    },
    {
        "school": "NORTH TONAWANDA MIDDLE SCHOOL",
        "district": "NORTH TONAWANDA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362124003007",
    },
    {
        "school": "DRAKE SCHOOL",
        "district": "NORTH TONAWANDA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362124003008",
    },
    {
        "school": "NORTH TONAWANDA INTERMEDIATE SCHOOL",
        "district": "NORTH TONAWANDA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362124003012",
    },
    {
        "school": "NORTH TONAWANDA HIGH SCHOOL",
        "district": "NORTH TONAWANDA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362124003013",
    },
    {
        "school": "OHIO ELEMENTARY SCHOOL",
        "district": "NORTH TONAWANDA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362124003014",
    },
    {
        "school": "SPRUCE SCHOOL",
        "district": "NORTH TONAWANDA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362124003016",
    },
    {
        "school": "ROYALTON-HARTLAND ELEMENTARY SCHOOL",
        "district": "ROYALTON-HARTLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362514003474",
    },
    {
        "school": "ROYALTON-HARTLAND HIGH SCHOOL",
        "district": "ROYALTON-HARTLAND CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362514003476",
    },
    {
        "school": "REGAN INTERMEDIATE SCHOOL",
        "district": "STARPOINT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362805003797",
    },
    {
        "school": "STARPOINT HIGH SCHOOL",
        "district": "STARPOINT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362805003798",
    },
    {
        "school": "FRICANO PRIMARY SCHOOL",
        "district": "STARPOINT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362805004790",
    },
    {
        "school": "WILSON ELEMENTARY SCHOOL",
        "district": "WILSON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363156004221",
    },
    {
        "school": "WILSON MIDDLE/HIGH SCHOOL",
        "district": "WILSON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363156004223",
    },
    {
        "school": "CANISTEO-GREENWOOD ELEMENTARY SCHOOL",
        "district": "CANISTEO-GREENWOOD CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012400425",
    },
    {
        "school": "CANISTEO-GREENWOOD HIGH SCHOOL",
        "district": "CANISTEO-GREENWOOD CSD",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012400426",
    },
    {
        "school": "DANA L LYON MIDDLE SCHOOL",
        "district": "BATH CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360405005411",
    },
    {
        "school": "CORNING PAINTED POST HIGH SCHOOL LEARNING CENTER",
        "district": "CORNING CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360840005574",
    },
    {
        "school": "JASPER-TROUPSBURG JUNIOR-SENIOR HIGH SCHOOL",
        "district": "JASPER-TROUPSBURG CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000701357",
    },
    {
        "school": "JASPER-TROUPSBURG ELEMENTARY SCHOOL",
        "district": "JASPER-TROUPSBURG CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000703911",
    },
    {
        "school": "WAYLAND-COHOCTON HIGH SCHOOL",
        "district": "WAYLAND-COHOCTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001101020",
    },
    {
        "school": "WAYLAND ELEMENTARY SCHOOL",
        "district": "WAYLAND-COHOCTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001101026",
    },
    {
        "school": "WAYLAND-COHOCTON MIDDLE SCHOOL",
        "district": "WAYLAND-COHOCTON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001101042",
    },
    {
        "school": "COHOCTON ELEMENTARY SCHOOL",
        "district": "WAYLAND-COHOCTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001101445",
    },
    {
        "school": "CAMPBELL-SAVONA ELEMENTARY SCHOOL",
        "district": "CAMPBELL-SAVONA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002000325",
    },
    {
        "school": "CAMPBELL-SAVONA JUNIOR/SENIOR HIGH SCHOOL",
        "district": "CAMPBELL-SAVONA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002000326",
    },
    {
        "school": "ADDISON MIDDLE/HIGH SCHOOL",
        "district": "ADDISON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360237000007",
    },
    {
        "school": "TUSCARORA ELEMENTARY SCHOOL",
        "district": "ADDISON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360237000008",
    },
    {
        "school": "VALLEY EARLY CHILDHOOD SCHOOL",
        "district": "ADDISON CENTRAL SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360237000009",
    },
    {
        "school": "ARKPORT CENTRAL SCHOOL",
        "district": "ARKPORT CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360324000085",
    },
    {
        "school": "AVOCA CENTRAL SCHOOL",
        "district": "AVOCA CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360363000117",
    },
    {
        "school": "HAVERLING SENIOR HIGH SCHOOL",
        "district": "BATH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360405000163",
    },
    {
        "school": "VERNON E WIGHTMAN PRIMARY SCHOOL",
        "district": "BATH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360405000164",
    },
    {
        "school": "BRADFORD CENTRAL SCHOOL",
        "district": "BRADFORD CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360522000246",
    },
    {
        "school": "CALVIN U SMITH ELEMENTARY SCHOOL",
        "district": "CORNING CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360840000625",
    },
    {
        "school": "CORNING-PAINTED POST HIGH SCHOOL",
        "district": "CORNING CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360840000628",
    },
    {
        "school": "ERWIN VALLEY ELEMENTARY SCHOOL",
        "district": "CORNING CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360840000630",
    },
    {
        "school": "FREDERICK CARDER ELEMENTARY SCHOOL",
        "district": "CORNING CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360840000632",
    },
    {
        "school": "HUGH W GREGG ELEMENTARY SCHOOL",
        "district": "CORNING CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360840000633",
    },
    {
        "school": "WINFIELD STREET ELEMENTARY SCHOOL",
        "district": "CORNING CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360840000639",
    },
    {
        "school": "WILLIAM E SEVERN ELEMENTARY SCHOOL",
        "district": "CORNING CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360840000640",
    },
    {
        "school": "GLENN H CURTISS MEMORIAL SCHOOL",
        "district": "HAMMONDSPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361347001104",
    },
    {
        "school": "HAMMONDSPORT JUNIOR-SENIOR HIGH SCHOOL",
        "district": "HAMMONDSPORT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361347001105",
    },
    {
        "school": "BRYANT SCHOOL",
        "district": "HORNELL CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361482001230",
    },
    {
        "school": "HORNELL INTERMEDIATE SCHOOL",
        "district": "HORNELL CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361482001232",
    },
    {
        "school": "HORNELL JUNIOR-SENIOR HIGH SCHOOL",
        "district": "HORNELL CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361482001233",
    },
    {
        "school": "NORTH HORNELL SCHOOL",
        "district": "HORNELL CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361482004299",
    },
    {
        "school": "PRATTSBURGH CENTRAL SCHOOL",
        "district": "PRATTSBURGH CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362379003310",
    },
    {
        "school": "CINCINNATUS MIDDLE SCHOOL",
        "district": "CINCINNATUS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360756005573",
    },
    {
        "school": "CINCINNATUS ELEMENTARY SCHOOL",
        "district": "CINCINNATUS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360756000539",
    },
    {
        "school": "CINCINNATUS HIGH SCHOOL",
        "district": "CINCINNATUS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360756000540",
    },
    {
        "school": "CORTLAND HIGH SCHOOL",
        "district": "CORTLAND CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360846000646",
    },
    {
        "school": "FE SMITH INTERMEDIATE SCHOOL",
        "district": "CORTLAND CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360846000647",
    },
    {
        "school": "FRANKLYN S BARRY PRIMARY SCHOOL",
        "district": "CORTLAND CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360846000648",
    },
    {
        "school": "RANDALL MIDDLE SCHOOL",
        "district": "CORTLAND CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360846000650",
    },
    {
        "school": "HOMER ELEMENTARY SCHOOL",
        "district": "HOMER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361464001214",
    },
    {
        "school": "HOMER INTERMEDIATE SCHOOL",
        "district": "HOMER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361464001215",
    },
    {
        "school": "HOMER SENIOR HIGH SCHOOL",
        "district": "HOMER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361464001217",
    },
    {
        "school": "HOMER JUNIOR HIGH SCHOOL",
        "district": "HOMER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361464003477",
    },
    {
        "school": "WILLIAM APPLEBY ELEMENTARY SCHOOL",
        "district": "MARATHON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361845001660",
    },
    {
        "school": "MARATHON HIGH SCHOOL",
        "district": "MARATHON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361845001661",
    },
    {
        "school": "MCGRAW ELEMENTARY SCHOOL",
        "district": "MCGRAW CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361884001710",
    },
    {
        "school": "MCGRAW SECONDARY SCHOOL",
        "district": "MCGRAW CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361884001711",
    },
    {
        "school": "BROADWAY ELEMENTARY SCHOOL",
        "district": "ELMIRA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361056000810",
    },
    {
        "school": "BROADWAY ACADEMY",
        "district": "ELMIRA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361056000811",
    },
    {
        "school": "ERNIE DAVIS ACADEMY",
        "district": "ELMIRA CITY SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361056000814",
    },
    {
        "school": "DIVEN SCHOOL",
        "district": "ELMIRA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361056000816",
    },
    {
        "school": "FASSETT ELEMENTARY SCHOOL",
        "district": "ELMIRA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361056000817",
    },
    {
        "school": "HENDY AVENUE SCHOOL",
        "district": "ELMIRA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361056000818",
    },
    {
        "school": "PINE CITY SCHOOL",
        "district": "ELMIRA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361056000822",
    },
    {
        "school": "RIVERSIDE ELEMENTARY",
        "district": "ELMIRA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361056000823",
    },
    {
        "school": "ELMIRA HIGH SCHOOL",
        "district": "ELMIRA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361056000824",
    },
    {
        "school": "THOMAS K BEECHER SCHOOL",
        "district": "ELMIRA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361056000825",
    },
    {
        "school": "PARLEY COBURN SCHOOL",
        "district": "ELMIRA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361056004387",
    },
    {
        "school": "COHEN ELEMENTARY SCHOOL",
        "district": "ELMIRA HEIGHTS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361059000828",
    },
    {
        "school": "THOMAS A EDISON HIGH SCHOOL",
        "district": "ELMIRA HEIGHTS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361059000830",
    },
    {
        "school": "COHEN MIDDLE SCHOOL",
        "district": "ELMIRA HEIGHTS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361059002828",
    },
    {
        "school": "BIG FLATS SCHOOL",
        "district": "HORSEHEADS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361485001236",
    },
    {
        "school": "CENTER STREET SCHOOL",
        "district": "HORSEHEADS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361485001238",
    },
    {
        "school": "GARDNER ROAD ELEMENTARY SCHOOL",
        "district": "HORSEHEADS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361485001239",
    },
    {
        "school": "HORSEHEADS SENIOR HIGH SCHOOL",
        "district": "HORSEHEADS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361485001241",
    },
    {
        "school": "HORSEHEADS MIDDLE SCHOOL",
        "district": "HORSEHEADS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361485001242",
    },
    {
        "school": "RIDGE ROAD SCHOOL",
        "district": "HORSEHEADS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361485001243",
    },
    {
        "school": "HORSEHEADS INTERMEDIATE SCHOOL",
        "district": "HORSEHEADS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361485001244",
    },
    {
        "school": "SCHUYLER-STEUBEN-CHEMUNG-TIOGA-ALLEGANY BOCES",
        "district": "SCHUYLER-STEUBEN-CHEMUNG-TIOGA-ALLEGANY BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368078004655",
    },
    {
        "school": "ABRAHAM WING SCHOOL",
        "district": "GLENS FALLS COMMON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360231000002",
    },
    {
        "school": "BOLTON CENTRAL SCHOOL",
        "district": "BOLTON CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360501000240",
    },
    {
        "school": "BIG CROSS STREET SCHOOL",
        "district": "GLENS FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361224000978",
    },
    {
        "school": "GLENS FALLS MIDDLE SCHOOL",
        "district": "GLENS FALLS CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361224000980",
    },
    {
        "school": "GLENS FALLS SENIOR HIGH SCHOOL",
        "district": "GLENS FALLS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361224000981",
    },
    {
        "school": "JACKSON HEIGHTS SCHOOL",
        "district": "GLENS FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361224000982",
    },
    {
        "school": "KENSINGTON ROAD SCHOOL",
        "district": "GLENS FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361224000983",
    },
    {
        "school": "HADLEY-LUZERNE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "HADLEY-LUZERNE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361311001075",
    },
    {
        "school": "STUART M TOWNSEND ELEMENTARY SCHOOL",
        "district": "HADLEY-LUZERNE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361311001076",
    },
    {
        "school": "JOHNSBURG CENTRAL SCHOOL",
        "district": "JOHNSBURG CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361587001372",
    },
    {
        "school": "LAKE GEORGE ELEMENTARY SCHOOL",
        "district": "LAKE GEORGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361647001457",
    },
    {
        "school": "LAKE GEORGE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "LAKE GEORGE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361647001458",
    },
    {
        "school": "NORTH WARREN CENTRAL SCHOOL",
        "district": "NORTH WARREN CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361696001508",
    },
    {
        "school": "QUEENSBURY ELEMENTARY SCHOOL",
        "district": "QUEENSBURY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362403003316",
    },
    {
        "school": "QUEENSBURY MIDDLE SCHOOL",
        "district": "QUEENSBURY UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362403003317",
    },
    {
        "school": "QUEENSBURY SENIOR HIGH SCHOOL",
        "district": "QUEENSBURY UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362403003318",
    },
    {
        "school": "WILLIAM H BARTON INTERMEDIATE SCHOOL",
        "district": "QUEENSBURY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362403003428",
    },
    {
        "school": "WARRENSBURG ELEMENTARY SCHOOL",
        "district": "WARRENSBURG CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362991004027",
    },
    {
        "school": "WARRENSBURG JUNIOR-SENIOR HIGH SCHOOL",
        "district": "WARRENSBURG CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362991004028",
    },
    {
        "school": "ARGYLE JUNIOR/SENIOR HIGH SCHOOL",
        "district": "ARGYLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360321000083",
    },
    {
        "school": "ARGYLE ELEMENTARY SCHOOL",
        "district": "ARGYLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360321004850",
    },
    {
        "school": "CAMBRIDGE ELEMENTARY SCHOOL",
        "district": "CAMBRIDGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360621000400",
    },
    {
        "school": "CAMBRIDGE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "CAMBRIDGE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360621000401",
    },
    {
        "school": "FORT ANN MIDDLE/HIGH SCHOOL",
        "district": "FORT ANN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361128000891",
    },
    {
        "school": "FORT EDWARD SCHOOL",
        "district": "FORT EDWARD UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361131000893",
    },
    {
        "school": "GRANVILLE ELEMENTARY SCHOOL",
        "district": "GRANVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361245001010",
    },
    {
        "school": "GRANVILLE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "GRANVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361245001011",
    },
    {
        "school": "MARY J TANNER PRIMARY SCHOOL",
        "district": "GRANVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361245001012",
    },
    {
        "school": "GREENWICH ELEMENTARY SCHOOL",
        "district": "GREENWICH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361290001057",
    },
    {
        "school": "GREENWICH JUNIOR-SENIOR HIGH SCHOOL",
        "district": "GREENWICH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361290001058",
    },
    {
        "school": "HARTFORD MIDDLE/HIGH SCHOOL",
        "district": "HARTFORD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361383001129",
    },
    {
        "school": "HUDSON FALLS PRIMARY SCHOOL",
        "district": "HUDSON FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361497001252",
    },
    {
        "school": "HUDSON FALLS MIDDLE SCHOOL",
        "district": "HUDSON FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361497001253",
    },
    {
        "school": "HUDSON FALLS HIGH SCHOOL",
        "district": "HUDSON FALLS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361497001254",
    },
    {
        "school": "HUDSON FALLS INTERMEDIATE SCHOOL",
        "district": "HUDSON FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361497001255",
    },
    {
        "school": "MARGARET MURPHY KINDERGARTEN CENTER",
        "district": "HUDSON FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361497001256",
    },
    {
        "school": "PUTNAM CENTRAL SCHOOL",
        "district": "PUTNAM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362397003313",
    },
    {
        "school": "SALEM HIGH SCHOOL",
        "district": "SALEM CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362547003521",
    },
    {
        "school": "SALEM ELEMENTARY SCHOOL",
        "district": "SALEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362547004619",
    },
    {
        "school": "WHITEHALL ELEMENTARY SCHOOL",
        "district": "WHITEHALL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363129004189",
    },
    {
        "school": "WHITEHALL JUNIOR-SENIOR HIGH SCHOOL",
        "district": "WHITEHALL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363129004190",
    },
    {
        "school": "WASHINGTON-SARATOGA-WARREN-HAMILTON-ESSEX BOCES",
        "district": "WASHINGTON-SARATOGA-WARREN-HAMILTON-ESSEX BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368094004663",
    },
    {
        "school": "BOULEVARD SCHOOL",
        "district": "GLOVERSVILLE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361227000985",
    },
    {
        "school": "GLOVERSVILLE MIDDLE SCHOOL",
        "district": "GLOVERSVILLE CITY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361227000986",
    },
    {
        "school": "GLOVERSVILLE HIGH SCHOOL",
        "district": "GLOVERSVILLE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361227000987",
    },
    {
        "school": "KINGSBOROUGH SCHOOL",
        "district": "GLOVERSVILLE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361227000988",
    },
    {
        "school": "PARK TERRACE SCHOOL",
        "district": "GLOVERSVILLE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361227000991",
    },
    {
        "school": "GLEBE STREET ELEMENTARY SCHOOL",
        "district": "JOHNSTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361598001379",
    },
    {
        "school": "JOHNSTOWN SENIOR HIGH SCHOOL",
        "district": "JOHNSTOWN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361598001381",
    },
    {
        "school": "KNOX JUNIOR HIGH SCHOOL",
        "district": "JOHNSTOWN CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361598001382",
    },
    {
        "school": "PLEASANT AVENUE SCHOOL",
        "district": "JOHNSTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361598001383",
    },
    {
        "school": "WARREN STREET SCHOOL",
        "district": "JOHNSTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361598001384",
    },
    {
        "school": "MAYFIELD ELEMENTARY SCHOOL",
        "district": "MAYFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361875001706",
    },
    {
        "school": "MAYFIELD JR/SR HIGH SCHOOL",
        "district": "MAYFIELD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361875001707",
    },
    {
        "school": "NORTHVILLE ELEMENTARY SCHOOL",
        "district": "NORTHVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362130003037",
    },
    {
        "school": "NORTHVILLE HIGH SCHOOL",
        "district": "NORTHVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362130003038",
    },
    {
        "school": "WHEELERVILLE SCHOOL",
        "district": "WHEELERVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363120004173",
    },
    {
        "school": "HAMILTON-FULTON-MONTGOMERY BOCES",
        "district": "HAMILTON-FULTON-MONTGOMERY BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368040004636",
    },
    {
        "school": "BROADALBIN-PERTH HIGH SCHOOL",
        "district": "BROADALBIN-PERTH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000500282",
    },
    {
        "school": "LEARNING COMMUNITY AT BROADALBIN-PERTH (THE)",
        "district": "BROADALBIN-PERTH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000500283",
    },
    {
        "school": "BROADALBIN-PERTH MIDDLE SCHOOL",
        "district": "BROADALBIN-PERTH CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000503206",
    },
    {
        "school": "BROADALBIN-PERTH INTERMEDIATE SCHOOL",
        "district": "BROADALBIN-PERTH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000504421",
    },
    {
        "school": "BERKSHIRE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "BERKSHIRE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360459000202",
    },
    {
        "school": "CHATHAM HIGH SCHOOL",
        "district": "CHATHAM CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360711000500",
    },
    {
        "school": "MARY E DARDESS ELEMENTARY SCHOOL",
        "district": "CHATHAM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360711000502",
    },
    {
        "school": "CHATHAM MIDDLE SCHOOL",
        "district": "CHATHAM CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360711000503",
    },
    {
        "school": "MONTGOMERY C SMITH ELEMENTARY SCHOOL",
        "district": "HUDSON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361494001248",
    },
    {
        "school": "HUDSON HIGH SCHOOL",
        "district": "HUDSON CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361494001249",
    },
    {
        "school": "ICHABOD CRANE MIDDLE SCHOOL",
        "district": "KINDERHOOK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361521001277",
    },
    {
        "school": "ICHABOD CRANE ELEMENTARY SCHOOL",
        "district": "KINDERHOOK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361521001278",
    },
    {
        "school": "ICHABOD CRANE SENIOR HIGH SCHOOL",
        "district": "KINDERHOOK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361521001279",
    },
    {
        "school": "NEW LEBANON JUNIOR-SENIOR HIGH SCHOOL",
        "district": "NEW LEBANON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362043001886",
    },
    {
        "school": "WALTER B HOWARD ELEMENTARY SCHOOL",
        "district": "NEW LEBANON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362043001887",
    },
    {
        "school": "TACONIC HILLS ELEMENTARY SCHOOL",
        "district": "TACONIC HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362862003468",
    },
    {
        "school": "TACONIC HILLSJUNIOR/SENIOR HIGH SCHOOL",
        "district": "TACONIC HILLS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362862003886",
    },
    {
        "school": "DRYDEN HIGH SCHOOL",
        "district": "DRYDEN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360933000713",
    },
    {
        "school": "DRYDEN MIDDLE SCHOOL",
        "district": "DRYDEN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360933002719",
    },
    {
        "school": "DRYDEN ELEMENTARY SCHOOL",
        "district": "DRYDEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360933003423",
    },
    {
        "school": "CASSAVANT ELEMENTARY SCHOOL",
        "district": "DRYDEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360933004682",
    },
    {
        "school": "FREEVILLE ELEMENTARY SCHOOL",
        "district": "DRYDEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360933004683",
    },
    {
        "school": "GROTON ELEMENTARY SCHOOL",
        "district": "GROTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361302001067",
    },
    {
        "school": "GROTON JUNIOR/SENIOR HIGH SCHOOL",
        "district": "GROTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361302001068",
    },
    {
        "school": "GEORGE JUNIOR REPUBLIC SCHOOL",
        "district": "GEORGE JUNIOR REPUBLIC UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361503001257",
    },
    {
        "school": "LEHMAN ALTERNATIVE COMMUNITY SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557001328",
    },
    {
        "school": "BELLE SHERMAN SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557001329",
    },
    {
        "school": "BOYNTON MIDDLE SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557001330",
    },
    {
        "school": "CAROLINE ELEMENTARY SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557001331",
    },
    {
        "school": "BEVERLY J MARTIN ELEMENTARY SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557001333",
    },
    {
        "school": "DEWITT MIDDLE SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557001335",
    },
    {
        "school": "ENFIELD SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557001336",
    },
    {
        "school": "FALL CREEK ELEMENTARY SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557001337",
    },
    {
        "school": "ITHACA SENIOR HIGH SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557001340",
    },
    {
        "school": "NORTHEAST SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557001342",
    },
    {
        "school": "SOUTH HILL SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557001343",
    },
    {
        "school": "CAYUGA HEIGHTS ELEMENTARY SCHOOL",
        "district": "ITHACA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361557004687",
    },
    {
        "school": "RAYMOND C BUCKLEY ELEMENTARY SCHOOL",
        "district": "LANSING CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361671001489",
    },
    {
        "school": "LANSING HIGH SCHOOL",
        "district": "LANSING CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361671001490",
    },
    {
        "school": "LANSING MIDDLE SCHOOL",
        "district": "LANSING CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361671001491",
    },
    {
        "school": "NEWFIELD MIDDLE SCHOOL",
        "district": "NEWFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362079000373",
    },
    {
        "school": "NEWFIELD ELEMENTARY SCHOOL",
        "district": "NEWFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362079002924",
    },
    {
        "school": "NEWFIELD SENIOR HIGH SCHOOL",
        "district": "NEWFIELD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362079002925",
    },
    {
        "school": "TRUMANSBURG ELEMENTARY SCHOOL",
        "district": "TRUMANSBURG CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362898003920",
    },
    {
        "school": "CHARLES O DICKERSON HIGH SCHOOL",
        "district": "TRUMANSBURG CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362898003921",
    },
    {
        "school": "RUSSELL I DOIG MIDDLE SCHOOL",
        "district": "TRUMANSBURG CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362898003922",
    },
    {
        "school": "TOMPKINS-SENECA-TIOGA BOCES",
        "district": "TOMPKINS-SENECA-TIOGA BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368090004661",
    },
    {
        "school": "SHERMAN ELEMENTARY SCHOOL",
        "district": "SHERMAN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362673004940",
    },
    {
        "school": "SILVER CREEK MIDDLE SCHOOL",
        "district": "SILVER CREEK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362688005588",
    },
    {
        "school": "SOUTHWESTERN ELEMENTARY SCHOOL",
        "district": "SOUTHWESTERN CENTRAL SCHOOL DISTRICT AT JAMESTOWN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362766004936",
    },
    {
        "school": "CHAUTAUQUA LAKE SECONDARY SCHOOL",
        "district": "CHAUTAUQUA LAKE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001801936",
    },
    {
        "school": "CHAUTAUQUA LAKE ELEMENTARY SCHOOL",
        "district": "CHAUTAUQUA LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001801938",
    },
    {
        "school": "BEMUS POINT ELEMENTARY SCHOOL",
        "district": "BEMUS POINT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360453000199",
    },
    {
        "school": "MAPLE GROVE JUNIOR/SENIOR HIGH SCHOOL",
        "district": "BEMUS POINT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360453000201",
    },
    {
        "school": "BROCTON ELEMENTARY SCHOOL",
        "district": "BROCTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360561000288",
    },
    {
        "school": "BROCTON MIDDLE HIGH SCHOOL",
        "district": "BROCTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360561000289",
    },
    {
        "school": "CASSADAGA VALLEY MIDDLE/HIGH SCHOOL",
        "district": "CASSADAGA VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360666000451",
    },
    {
        "school": "SINCLAIRVILLE ELEMENTARY SCHOOL",
        "district": "CASSADAGA VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360666000453",
    },
    {
        "school": "CLYMER CENTRAL SCHOOL",
        "district": "CLYMER CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360789000562",
    },
    {
        "school": "DUNKIRK MIDDLE SCHOOL",
        "district": "DUNKIRK CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360942000718",
    },
    {
        "school": "DUNKIRK SENIOR HIGH SCHOOL",
        "district": "DUNKIRK CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360942000719",
    },
    {
        "school": "SCHOOL 3",
        "district": "DUNKIRK CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360942000720",
    },
    {
        "school": "SCHOOL 4",
        "district": "DUNKIRK CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360942000721",
    },
    {
        "school": "SCHOOL 5",
        "district": "DUNKIRK CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360942000722",
    },
    {
        "school": "SCHOOL 7",
        "district": "DUNKIRK CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360942000724",
    },
    {
        "school": "FALCONER MIDDLE/HIGH SCHOOL",
        "district": "FALCONER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361092000869",
    },
    {
        "school": "HARVEY C FENNER ELEMENTARY SCHOOL",
        "district": "FALCONER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361092000870",
    },
    {
        "school": "PAUL B D TEMPLE ELEMENTARY SCHOOL",
        "district": "FALCONER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361092000872",
    },
    {
        "school": "FORESTVILLE CENTRAL HIGH SCHOOL",
        "district": "FORESTVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361125000889",
    },
    {
        "school": "FORESTVILLE ELEMENTARY SCHOOL",
        "district": "FORESTVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361125000890",
    },
    {
        "school": "FREDONIA ELEMENTARY SCHOOL",
        "district": "FREDONIA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361152000906",
    },
    {
        "school": "FREDONIA HIGH SCHOOL",
        "district": "FREDONIA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361152000907",
    },
    {
        "school": "FREDONIA MIDDLE SCHOOL",
        "district": "FREDONIA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361152000908",
    },
    {
        "school": "FREWSBURG JUNIOR-SENIOR HIGH SCHOOL",
        "district": "FREWSBURG CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361161000917",
    },
    {
        "school": "ROBERT H JACKSON ELEMENTARY SCHOOL",
        "district": "FREWSBURG CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361161000918",
    },
    {
        "school": "CARLYLE C RING ELEMENTARY SCHOOL",
        "district": "JAMESTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361563001345",
    },
    {
        "school": "CLINTON V BUSH ELEMENTARY SCHOOL",
        "district": "JAMESTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361563001346",
    },
    {
        "school": "JAMESTOWN HIGH SCHOOL",
        "district": "JAMESTOWN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361563001350",
    },
    {
        "school": "THOMAS JEFFERSON MIDDLE SCHOOL",
        "district": "JAMESTOWN CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361563001351",
    },
    {
        "school": "ABRAHAM LINCOLN ELEMENTARY SCHOOL",
        "district": "JAMESTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361563001352",
    },
    {
        "school": "MILTON J FLETCHER ELEMENTARY SCHOOL",
        "district": "JAMESTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361563001353",
    },
    {
        "school": "SAMUEL G LOVE ELEMENTARY SCHOOL",
        "district": "JAMESTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361563001355",
    },
    {
        "school": "GEORGE WASHINGTON MIDDLE SCHOOL",
        "district": "JAMESTOWN CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361563001356",
    },
    {
        "school": "PERSELL MIDDLE SCHOOL",
        "district": "JAMESTOWN CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361563004390",
    },
    {
        "school": "PANAMA K-6 SCHOOL",
        "district": "PANAMA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362241003155",
    },
    {
        "school": "PANAMA HIGH SCHOOL",
        "district": "PANAMA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362241003156",
    },
    {
        "school": "PINE VALLEY CENTRAL JUNIOR-SENIOR HIGH SCHOOL",
        "district": "PINE VALLEY CENTRAL SCHOOL DISTRICT (SOUTH DAYTON)",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362307003232",
    },
    {
        "school": "PINE VALLEY ELEMENTARY SCHOOL",
        "district": "PINE VALLEY CENTRAL SCHOOL DISTRICT (SOUTH DAYTON)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362307003233",
    },
    {
        "school": "RIPLEY CENTRAL SCHOOL",
        "district": "RIPLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362466004367",
    },
    {
        "school": "SHERMAN HIGH SCHOOL",
        "district": "SHERMAN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362673003650",
    },
    {
        "school": "SILVER CREEK ELEMENTARY SCHOOL",
        "district": "SILVER CREEK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362688003665",
    },
    {
        "school": "SILVER CREEK HIGH SCHOOL",
        "district": "SILVER CREEK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362688003666",
    },
    {
        "school": "SOUTHWESTERN MIDDLE SCHOOL",
        "district": "SOUTHWESTERN CENTRAL SCHOOL DISTRICT AT JAMESTOWN",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362766003755",
    },
    {
        "school": "SOUTHWESTERN SENIOR HIGH SCHOOL",
        "district": "SOUTHWESTERN CENTRAL SCHOOL DISTRICT AT JAMESTOWN",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362766003756",
    },
    {
        "school": "WESTFIELD MIDDLE SCHOOL",
        "district": "WESTFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363099003239",
    },
    {
        "school": "WESTFIELD ELEMENTARY SCHOOL",
        "district": "WESTFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363099004163",
    },
    {
        "school": "WESTFIELD HIGH SCHOOL",
        "district": "WESTFIELD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363099004164",
    },
    {
        "school": "MARLBORO ELEMENTARY SCHOOL",
        "district": "MARLBORO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361857005841",
    },
    {
        "school": "ELLENVILLE ELEMENTARY SCHOOL",
        "district": "ELLENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361050000805",
    },
    {
        "school": "ELLENVILLE MIDDLE SCHOOL",
        "district": "ELLENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361050003217",
    },
    {
        "school": "ELLENVILLE HIGH SCHOOL",
        "district": "ELLENVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361050004338",
    },
    {
        "school": "HIGHLAND ELEMENTARY SCHOOL",
        "district": "HIGHLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361440001191",
    },
    {
        "school": "HIGHLAND HIGH SCHOOL",
        "district": "HIGHLAND CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361440001192",
    },
    {
        "school": "HIGHLAND MIDDLE SCHOOL",
        "district": "HIGHLAND CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361440001193",
    },
    {
        "school": "CHAMBERS SCHOOL",
        "district": "KINGSTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361629001429",
    },
    {
        "school": "HARRY L EDSON SCHOOL",
        "district": "KINGSTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361629001430",
    },
    {
        "school": "GEORGE WASHINGTON SCHOOL",
        "district": "KINGSTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361629001432",
    },
    {
        "school": "ERNEST C MYER SCHOOL",
        "district": "KINGSTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361629001433",
    },
    {
        "school": "J WATSON BAILEY MIDDLE SCHOOL",
        "district": "KINGSTON CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361629001434",
    },
    {
        "school": "JOHN F KENNEDY SCHOOL",
        "district": "KINGSTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361629001435",
    },
    {
        "school": "KINGSTON HIGH SCHOOL",
        "district": "KINGSTON CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361629001436",
    },
    {
        "school": "E R CROSBY ELEMENTARY SCHOOL",
        "district": "KINGSTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361629001437",
    },
    {
        "school": "M CLIFFORD MILLER MIDDLE SCHOOL",
        "district": "KINGSTON CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361629001438",
    },
    {
        "school": "ROBERT R GRAVES SCHOOL",
        "district": "KINGSTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361629001441",
    },
    {
        "school": "LENAPE ELEMENTARY SCHOOL",
        "district": "NEW PALTZ CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362046000353",
    },
    {
        "school": "DUZINE SCHOOL",
        "district": "NEW PALTZ CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362046001888",
    },
    {
        "school": "NEW PALTZ MIDDLE SCHOOL",
        "district": "NEW PALTZ CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362046001890",
    },
    {
        "school": "NEW PALTZ SENIOR HIGH SCHOOL",
        "district": "NEW PALTZ CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362046001891",
    },
    {
        "school": "ONTEORA HIGH SCHOOL",
        "district": "ONTEORA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362184003101",
    },
    {
        "school": "PHOENICIA ELEMENTARY SCHOOL",
        "district": "ONTEORA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362184003102",
    },
    {
        "school": "REGINALD BENNETT ELEMENTARY SCHOOL",
        "district": "ONTEORA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362184003103",
    },
    {
        "school": "WOODSTOCK ELEMENTARY SCHOOL",
        "district": "ONTEORA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362184003105",
    },
    {
        "school": "ONTEORA MIDDLE SCHOOL",
        "district": "ONTEORA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362184004849",
    },
    {
        "school": "KERHONKSON ELEMENTARY SCHOOL",
        "district": "RONDOUT VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362496003455",
    },
    {
        "school": "MARBLETOWN ELEMENTARY SCHOOL",
        "district": "RONDOUT VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362496003456",
    },
    {
        "school": "RONDOUT VALLEY HIGH SCHOOL",
        "district": "RONDOUT VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362496003458",
    },
    {
        "school": "SAUGERTIES JUNIOR HIGH SCHOOL",
        "district": "SAUGERTIES CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362580002741",
    },
    {
        "school": "CAHILL SCHOOL",
        "district": "SAUGERTIES CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362580003544",
    },
    {
        "school": "MORSE SCHOOL",
        "district": "SAUGERTIES CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362580003545",
    },
    {
        "school": "MOUNT MARION ELEMENTARY SCHOOL",
        "district": "SAUGERTIES CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362580003546",
    },
    {
        "school": "RICCARDI ELEMENTARY SCHOOL",
        "district": "SAUGERTIES CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362580003547",
    },
    {
        "school": "SAUGERTIES SENIOR HIGH SCHOOL",
        "district": "SAUGERTIES CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362580003549",
    },
    {
        "school": "WEST PARK SCHOOL",
        "district": "WEST PARK UNION FREE SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "363076004137",
    },
    {
        "school": "ULSTER BOCES",
        "district": "ULSTER BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368092004662",
    },
    {
        "school": "LEPTONDALE ELEMENTARY SCHOOL",
        "district": "WALLKILL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362979004000",
    },
    {
        "school": "MARLBORO CENTRAL HIGH SCHOOL",
        "district": "MARLBORO CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361857001670",
    },
    {
        "school": "MARLBORO MIDDLE SCHOOL",
        "district": "MARLBORO CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361857001673",
    },
    {
        "school": "OSTRANDER ELEMENTARY SCHOOL",
        "district": "WALLKILL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362979004001",
    },
    {
        "school": "PLATTEKILL ELEMENTARY SCHOOL",
        "district": "WALLKILL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362979004002",
    },
    {
        "school": "JOHN G BORDEN MIDDLE SCHOOL",
        "district": "WALLKILL CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362979004003",
    },
    {
        "school": "WALLKILL SENIOR HIGH SCHOOL",
        "district": "WALLKILL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362979004004",
    },
    {
        "school": "BRUSHTON GRADE SCHOOL",
        "district": "BRUSHTON-MOIRA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360582000293",
    },
    {
        "school": "BRUSHTON-MOIRA HIGH SCHOOL",
        "district": "BRUSHTON-MOIRA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360582000294",
    },
    {
        "school": "CHATEAUGAY HIGH SCHOOL",
        "district": "CHATEAUGAY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360708000498",
    },
    {
        "school": "CHATEAUGAY ELEMENTARY SCHOOL",
        "district": "CHATEAUGAY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360708000499",
    },
    {
        "school": "DAVIS ELEMENTARY SCHOOL",
        "district": "MALONE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361818001633",
    },
    {
        "school": "FLANDERS ELEMENTARY SCHOOL",
        "district": "MALONE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361818001634",
    },
    {
        "school": "FRANKLIN ACADEMY HIGH SCHOOL",
        "district": "MALONE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361818001635",
    },
    {
        "school": "MALONE MIDDLE SCHOOL",
        "district": "MALONE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361818001638",
    },
    {
        "school": "SAINT JOSEPH'S ELEMENTARY SCHOOL",
        "district": "MALONE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361818001639",
    },
    {
        "school": "SALMON RIVER ELEMENTARY SCHOOL",
        "district": "SALMON RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362550003522",
    },
    {
        "school": "SALMON RIVER HIGH SCHOOL",
        "district": "SALMON RIVER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362550003524",
    },
    {
        "school": "SAINT REGIS MOHAWK SCHOOL",
        "district": "SALMON RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362550003525",
    },
    {
        "school": "PETROVA ELEMENTARY SCHOOL",
        "district": "SARANAC LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362574003533",
    },
    {
        "school": "SARANAC LAKE MIDDLE SCHOOL",
        "district": "SARANAC LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362574003534",
    },
    {
        "school": "SARANAC LAKE SENIOR HIGH SCHOOL",
        "district": "SARANAC LAKE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362574003535",
    },
    {
        "school": "BLOOMINGDALE SCHOOL",
        "district": "SARANAC LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362574004620",
    },
    {
        "school": "SAINT REGIS FALLS CENTRAL SCHOOL",
        "district": "SAINT REGIS FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362799003793",
    },
    {
        "school": "L P QUINN ELEMENTARY SCHOOL",
        "district": "TUPPER LAKE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362916003928",
    },
    {
        "school": "TUPPER LAKE MIDDLE-HIGH SCHOOL",
        "district": "TUPPER LAKE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362916003929",
    },
    {
        "school": "FRANKLIN-ESSEX-HAMILTON BOCES",
        "district": "FRANKLIN-ESSEX-HAMILTON BOCES",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368034004633",
    },
    {
        "school": "HOSTOS-LINCOLN ACADEMY OF SCIENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008400757",
    },
    {
        "school": "HEALTH OPPORTUNITIES HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008401338",
    },
    {
        "school": "ALFRED E SMITH CAREER AND TECHNICAL EDUCATION HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360008401909",
    },
    {
        "school": "JHS 151 LOU GEHRIG",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008401983",
    },
    {
        "school": "PS 1 COURTLANDT SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402043",
    },
    {
        "school": "PS 5 PORT MORRIS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402056",
    },
    {
        "school": "PS 18 JOHN PETER ZENGER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402098",
    },
    {
        "school": "PS 25 BILINGUAL SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402122",
    },
    {
        "school": "PS/MS 29 MELROSE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402138",
    },
    {
        "school": "PS 30 WILTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402143",
    },
    {
        "school": "PS/MS 31 WILLIAM LLOYD GARRISON (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402147",
    },
    {
        "school": "PS 43 JONAS BRONCK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402191",
    },
    {
        "school": "PS 49 WILLIS AVENUE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402218",
    },
    {
        "school": "PS 65 MOTHER HALE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402269",
    },
    {
        "school": "PS 154 JONATHAN D HYATT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402556",
    },
    {
        "school": "PS 161 JUAN PONCE DE LEON SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008402578",
    },
    {
        "school": "PS 277",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008403738",
    },
    {
        "school": "PS 179",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405118",
    },
    {
        "school": "COMMUNITY SCHOOL FOR SOCIAL JUSTICE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405180",
    },
    {
        "school": "MOTT HAVEN VILLAGE PREPARATORY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405187",
    },
    {
        "school": "URBAN ASSEMBLY BRONX ACADEMY OF LETTERS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405504",
    },
    {
        "school": "CAREERS IN SPORTS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405512",
    },
    {
        "school": "PS/IS 224",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405520",
    },
    {
        "school": "LABORATORY SCHOOL OF FINANCE AND TECHNOLOGY (THE):  X223",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405521",
    },
    {
        "school": "PS 157 GROVE HILL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405533",
    },
    {
        "school": "SOUTH BRONX PREPARATORY - A COLLEGE BOARD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405650",
    },
    {
        "school": "SOUTH BRONX ACADEMY FOR APPLIED MEDIA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405785",
    },
    {
        "school": "ACADEMY OF PUBLIC RELATIONS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405786",
    },
    {
        "school": "HERBERT H LEHMAN HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008501964",
    },
    {
        "school": "JHS 131 ALBERT EINSTEIN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008501979",
    },
    {
        "school": "PS 14 SENATOR JOHN CALANDRA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502085",
    },
    {
        "school": "PS 36 UNIONPORT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502168",
    },
    {
        "school": "PS 48 JOSEPH R DRAKE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502211",
    },
    {
        "school": "PS 62 INOCENSIO CASANOVA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502264",
    },
    {
        "school": "PS 69 JOURNEY PREP SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502285",
    },
    {
        "school": "PS 71 ROSE E SCALA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502293",
    },
    {
        "school": "PS 72 DR WILLIAM DORNEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502295",
    },
    {
        "school": "PS 75 SCHOOL OF RESEARCH AND DISCOVERY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502302",
    },
    {
        "school": "PS 93 ALBERT G OLIVER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502354",
    },
    {
        "school": "PS 100 ISAAC CLASON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502380",
    },
    {
        "school": "PS 107",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502401",
    },
    {
        "school": "DR EMMETT W BASSETT SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502441",
    },
    {
        "school": "JHS 123 JAMES M KIERNAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502456",
    },
    {
        "school": "PS 130 ABRAM STEVENS HEWITT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502479",
    },
    {
        "school": "PS 138 SAMUEL RANDALL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502505",
    },
    {
        "school": "PS 140 EAGLE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502509",
    },
    {
        "school": "PS 146 EDWARD COLLINS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502530",
    },
    {
        "school": "PS 152 EVERGREEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502547",
    },
    {
        "school": "PS 182",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502632",
    },
    {
        "school": "LONGWOOD PREPARATORY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008502968",
    },
    {
        "school": "MS 101 EDWARD R BYRNE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008503740",
    },
    {
        "school": "MS 301 PAUL L DUNBAR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505121",
    },
    {
        "school": "MS 302 LUISA DESSUS CRUZ",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505122",
    },
    {
        "school": "PS 304 EARLY CHILDHOOD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505123",
    },
    {
        "school": "GOTHAM COLLABORATIVE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505186",
    },
    {
        "school": "BRONX STUDIO SCHOOL FOR WRITERS AND ARTISTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505652",
    },
    {
        "school": "WOMEN'S ACADEMY OF EXCELLENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505653",
    },
    {
        "school": "MILLENIUM ART ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505654",
    },
    {
        "school": "LONGWOOD ACADEMY FOR DISCOVERY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505655",
    },
    {
        "school": "SCHOOL FOR INQUIRY AND SOCIAL JUSTICE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505657",
    },
    {
        "school": "RENAISSANCE HIGH SCHOOL FOR MUSICAL THEATER AND THE ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505659",
    },
    {
        "school": "PS 170",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008600728",
    },
    {
        "school": "BRONX LEADERSHIP ACADEMY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008600795",
    },
    {
        "school": "PS 11 HIGHBRIDGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602073",
    },
    {
        "school": "PS 28 MOUNT HOPE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602133",
    },
    {
        "school": "PS 35 FRANZ SIEGEL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602160",
    },
    {
        "school": "PS 42 CLAREMONT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602188",
    },
    {
        "school": "PS 53 BASHEER QUISIM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602232",
    },
    {
        "school": "PS 55 BENJAMIN FRANKLIN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602238",
    },
    {
        "school": "PS 58",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602250",
    },
    {
        "school": "PS 114 LUIS LLORENS TORRES SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602276",
    },
    {
        "school": "PS 70 MAX SCHOENFELD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602288",
    },
    {
        "school": "PS 73 BRONX",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602298",
    },
    {
        "school": "PS 88 S SILVERSTEIN LITTLE SPARROW SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602338",
    },
    {
        "school": "PS 109 SEDGWICK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602410",
    },
    {
        "school": "PS 110 THEODORE SCHOENFELD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602413",
    },
    {
        "school": "PS 126 DR MARJORIE H DUNBAR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602465",
    },
    {
        "school": "PS 132 GARRETT A MORGAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602486",
    },
    {
        "school": "PS 163 ARTHUR A SCHOMBERG",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602583",
    },
    {
        "school": "IS 229 ROLAND PATTERSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602737",
    },
    {
        "school": "PS 236 LANGSTON HUGHES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602751",
    },
    {
        "school": "BRONX SCHOOL FOR LAW GOVERNMENT AND JUSTICE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008602961",
    },
    {
        "school": "PS/IS 218 RAFAEL HERNANDEZ DUAL LANGUAGE MAGNET SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008603742",
    },
    {
        "school": "IS 219 NEW VENTURE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008603747",
    },
    {
        "school": "IS 303 LEADERSHIP & COMMUNITY SERVICE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008603764",
    },
    {
        "school": "IS 313 SCHOOL OF LEADERSHIP DEVELOPMENT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008603767",
    },
    {
        "school": "IS 339",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008603780",
    },
    {
        "school": "PS 199 SHAKESPEARE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008604459",
    },
    {
        "school": "JHS 22 JORDAN L MOTT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008604461",
    },
    {
        "school": "PS 204 MORRIS HEIGHTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008604808",
    },
    {
        "school": "IS 232",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008604876",
    },
    {
        "school": "BRONX INTERNATIONAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008604879",
    },
    {
        "school": "SCHOOL FOR EXCELLENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605175",
    },
    {
        "school": "BRONX HIGH SCHOOL OF BUSINESS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605176",
    },
    {
        "school": "BRONX HIGH SCHOOL FOR MEDICAL SCIENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605177",
    },
    {
        "school": "PS/MS 4 CROTONA PARK WEST",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605191",
    },
    {
        "school": "IS 117 JOSEPH H WADE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605192",
    },
    {
        "school": "HIGH SCHOOL FOR VIOLIN AND DANCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605547",
    },
    {
        "school": "PS 63 AUTHOR'S ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605561",
    },
    {
        "school": "MOTT HALL III",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605663",
    },
    {
        "school": "BRONX WRITING ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605664",
    },
    {
        "school": "COMPREHENSIVE MODEL SCHOOL PROJECT MS 327",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605666",
    },
    {
        "school": "NEW MILLENNIUM BRONX ACADEMY OF THE ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605667",
    },
    {
        "school": "FREDERICK DOUGLASS ACADEMY III SECONDARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605668",
    },
    {
        "school": "BRONX COLLEGIATE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605669",
    },
    {
        "school": "EAGLE ACADEMY FOR YOUNG MEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605670",
    },
    {
        "school": "KAPPA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605790",
    },
    {
        "school": "EXIMIUS COLLEGE PREPARATORY ACADEMY:  A COLLEGE BOARD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605791",
    },
    {
        "school": "MOTT HALL BRONX HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605793",
    },
    {
        "school": "BRONX CENTER FOR SCIENCE AND MATHEMATICS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605794",
    },
    {
        "school": "BRONX STEM AND ARTS ACADEMY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008700127",
    },
    {
        "school": "PS 23 NEW CHILDREN'S SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008700130",
    },
    {
        "school": "PS 279 CAPT MANUEL RIVERA JR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008700183",
    },
    {
        "school": "PS 209",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008700739",
    },
    {
        "school": "PS 37 MULTIPLE INTELLIGENCE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008701304",
    },
    {
        "school": "PS 291",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008701306",
    },
    {
        "school": "PS 306",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008701307",
    },
    {
        "school": "PS 15 INSTITUTE FOR ENVIRONMENTAL LEARNING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008701748",
    },
    {
        "school": "BRONX HIGH SCHOOL OF SCIENCE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008701922",
    },
    {
        "school": "DEWITT CLINTON HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008701940",
    },
    {
        "school": "MILTON FEIN SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702060",
    },
    {
        "school": "PS 8 ISSAC VARIAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702063",
    },
    {
        "school": "PS 9 RYER AVENUE ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702067",
    },
    {
        "school": "PS 24 SPUYTEN DUYVIL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702121",
    },
    {
        "school": "PS 32 BELMONT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702150",
    },
    {
        "school": "PS 33 TIMOTHY DWIGHT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702155",
    },
    {
        "school": "PS/MS 20 PO GEORGE J WERDAN III",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702179",
    },
    {
        "school": "THOMAS C GIORDANO MIDDLE SCHOOL 45",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702202",
    },
    {
        "school": "PS 46 EDGAR ALLAN POE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702204",
    },
    {
        "school": "PS 310 MARBLE HILL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702210",
    },
    {
        "school": "PS 56 NORWOOD HEIGHTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702244",
    },
    {
        "school": "JHS 80 MOSHOLU PARKWAY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702316",
    },
    {
        "school": "PS 81 ROBERT J CHRISTEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702318",
    },
    {
        "school": "PS 86 KINGSBRIDGE HEIGHTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702332",
    },
    {
        "school": "PS 94 KINGS COLLEGE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702357",
    },
    {
        "school": "PS 95 SHEILA MENCHER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702361",
    },
    {
        "school": "JHS 118 WILLIAM W NILES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702440",
    },
    {
        "school": "RIVERDALE/KINGSBRIDGE ACADEMY (MS/HS 141)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702513",
    },
    {
        "school": "PS 205 FIORELLO LAGUARDIA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702691",
    },
    {
        "school": "PS 315 LAB SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008702939",
    },
    {
        "school": "PS/IS 54",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008703783",
    },
    {
        "school": "IS 254",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008703794",
    },
    {
        "school": "PS 340",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008703795",
    },
    {
        "school": "PS 360",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008703805",
    },
    {
        "school": "MS 390",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008703811",
    },
    {
        "school": "ANGELO PATRI MIDDLE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008703812",
    },
    {
        "school": "PS 396",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008703820",
    },
    {
        "school": "IS 206 ANN MERSEREAU",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008704310",
    },
    {
        "school": "PS 159 LUIS MUMOZ MARIN BILING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008704353",
    },
    {
        "school": "PS 246 POE CENTER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008704464",
    },
    {
        "school": "IN-TECH ACADEMY (MS/HS 368)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008704473",
    },
    {
        "school": "PS 207",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008704693",
    },
    {
        "school": "PS/MS 280 MOSHOLU PARKWAY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008704695",
    },
    {
        "school": "PS 226",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008704731",
    },
    {
        "school": "PS 3 RAUL JULIA MICRO SOCIETY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705137",
    },
    {
        "school": "PS 59 COMMUNITY SCHOOL OF TECHNOLOGY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705138",
    },
    {
        "school": "PS 85 GREAT EXPECTATIONS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705139",
    },
    {
        "school": "PS 91",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705140",
    },
    {
        "school": "HIGH SCHOOL FOR TEACHING AND THE PROFESSIONS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705181",
    },
    {
        "school": "BELMONT PREPARATORY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705182",
    },
    {
        "school": "FORDHAM HIGH SCHOOL FOR THE ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705183",
    },
    {
        "school": "FORDHAM LEADERSHIP ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705184",
    },
    {
        "school": "BRONX HIGH SCHOOL FOR LAW AND COMMUNITY SERVICE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705185",
    },
    {
        "school": "HIGH SCHOOL OF AMERICAN STUDIES AT LEHMAN COLLEGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705190",
    },
    {
        "school": "LUISA PINEIRO FUENTES SCHOOL OF SCIENCE AND DISCOVERY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705550",
    },
    {
        "school": "CELIA CRUZ BRONX HIGH SCHOOL OF MUSIC (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705556",
    },
    {
        "school": "DISCOVERY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705557",
    },
    {
        "school": "BRONX DANCE ACADEMY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705569",
    },
    {
        "school": "WEST BRONX ACADEMY FOR THE FUTURE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705674",
    },
    {
        "school": "BRONX SCHOOL OF YOUNG LEADERS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705675",
    },
    {
        "school": "BRONX ENGINEERING AND TECHNOLOGY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705676",
    },
    {
        "school": "MARIE CURIE HIGH SCHOOL-NURSING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705677",
    },
    {
        "school": "THEATRE ARTS PRODUCTION COMPANY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705796",
    },
    {
        "school": "JONAS BRONCK ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705797",
    },
    {
        "school": "NEW SCHOOL FOR LEADERSHIP AND JOURNALISM (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705798",
    },
    {
        "school": "KINGSBRIDGE INTERNATIONAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705799",
    },
    {
        "school": "PS 178 DR SELMAN WAKSMAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008800158",
    },
    {
        "school": "HARRY S TRUMAN HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008801963",
    },
    {
        "school": "IS 181 PABLO CASALS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008801989",
    },
    {
        "school": "PS 16 WAKEFIELD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802092",
    },
    {
        "school": "PS 19 JUDITH K WEISS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802100",
    },
    {
        "school": "PS 21 PHILIP H SHERIDAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802111",
    },
    {
        "school": "PS 41 GUN HILL ROAD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802185",
    },
    {
        "school": "PS 68",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802282",
    },
    {
        "school": "PS 76 BENNINGTON SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802306",
    },
    {
        "school": "PS 78 ANNE HUTCHINSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802312",
    },
    {
        "school": "PS 83 DONALD HERTZ",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802323",
    },
    {
        "school": "PS 87",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802336",
    },
    {
        "school": "PS 89",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802342",
    },
    {
        "school": "PS 96 RICHARD RODGERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802364",
    },
    {
        "school": "PS 97",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802368",
    },
    {
        "school": "PS 103 HECTOR FONTANEZ",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802389",
    },
    {
        "school": "PS 105 SENATOR ABRAHAM BERNSTEIN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802394",
    },
    {
        "school": "PS 106 PARKCHESTER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802397",
    },
    {
        "school": "PS 108 PHILIP J ABINANTI",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802404",
    },
    {
        "school": "PS 111 SETON FALLS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802417",
    },
    {
        "school": "PS 112 BRONXWOOD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802419",
    },
    {
        "school": "PS 121 THROOP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802450",
    },
    {
        "school": "JHS 127 CASTLE HILL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802469",
    },
    {
        "school": "JHS 144 MICHELANGELO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802524",
    },
    {
        "school": "PS 153 HELEN KELLER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802553",
    },
    {
        "school": "PS 160 WALT DISNEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802573",
    },
    {
        "school": "PS 175 CITY ISLAND",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802613",
    },
    {
        "school": "MS 180 DR DANIEL HALE WILLIAMS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008802628",
    },
    {
        "school": "BRONX HIGH SCHOOL FOR THE VISUAL ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805179",
    },
    {
        "school": "PELHAM PREPARATORY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805541",
    },
    {
        "school": "HIGH SCHOOL FOR CONTEMPORARY ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805543",
    },
    {
        "school": "PS/MS 194",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805558",
    },
    {
        "school": "BRONX AEROSPACE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805568",
    },
    {
        "school": "BRONX HEALTH SCIENCES HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805680",
    },
    {
        "school": "BRONX HIGH SCHOOL FOR WRITING AND COMMUNICATION ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805681",
    },
    {
        "school": "BRONX LAB SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805683",
    },
    {
        "school": "HIGH SCHOOL OF COMPUTERS AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360008805684",
    },
    {
        "school": "COLLEGIATE INSTITUTE FOR MATH AND SCIENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805685",
    },
    {
        "school": "BRONX ACADEMY OF HEALTH CAREERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805686",
    },
    {
        "school": "ASTOR COLLEGIATE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805687",
    },
    {
        "school": "NORTH BRONX SCHOOL OF EMPOWERMENT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805800",
    },
    {
        "school": "NEW WORLD HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805803",
    },
    {
        "school": "BRONXWOOD PREPARATORY ACADEMY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805804",
    },
    {
        "school": "BRONX CHARTER SCHOOL FOR BETTER LEARNING",
        "district": "BRONX CHARTER SCHOOL FOR BETTER LEARNING",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008905554",
    },
    {
        "school": "PS 214",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009000227",
    },
    {
        "school": "PS 212",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009001309",
    },
    {
        "school": "FANNIE LOU HAMER FREEDOM HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009001327",
    },
    {
        "school": "WINGS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009001332",
    },
    {
        "school": "HIGH SCHOOL OF WORLD CULTURES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009001767",
    },
    {
        "school": "PS 6 WEST FARMS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009002059",
    },
    {
        "school": "PS 44 DAVID C FARRAGUT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009002194",
    },
    {
        "school": "PS 47 JOHN RANDOLPH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009002209",
    },
    {
        "school": "PS 57 CRESCENT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009002245",
    },
    {
        "school": "PS 61 FRANCISCO OLLER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009002260",
    },
    {
        "school": "PS 67 MOHEGAN SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009002279",
    },
    {
        "school": "JHS 98 HERMAN RIDDER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009002373",
    },
    {
        "school": "MS 129 ACADEMY FOR INDEPENDENT LEARNING AND LEADERSHIP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009002477",
    },
    {
        "school": "PS 134 GEORGE F BRISTOW",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009002491",
    },
    {
        "school": "PS 150 CHARLES JAMES FOX",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009002541",
    },
    {
        "school": "PS 211",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009002706",
    },
    {
        "school": "PS 195",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009003353",
    },
    {
        "school": "PS 196",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009003369",
    },
    {
        "school": "BRONX LITTLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009003847",
    },
    {
        "school": "IS 318 MATH SCIENCE & TECHNOLOGY THROUGH ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009004878",
    },
    {
        "school": "ESMT-IS 190",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005166",
    },
    {
        "school": "SCHOOL OF PERFORMING ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005169",
    },
    {
        "school": "PS 66 SCHOOL OF HIGHER EXPECTATIONS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005509",
    },
    {
        "school": "EAST BRONX ACADEMY FOR THE FUTURE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005679",
    },
    {
        "school": "BRONX LATIN SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005689",
    },
    {
        "school": "FREDERICK DOUGLASS ACADEMY V MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005690",
    },
    {
        "school": "KNOWLEDGE AND POWER PREPARATORY ACADEMY III",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005691",
    },
    {
        "school": "ACCION ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005692",
    },
    {
        "school": "MOTT HALL V",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005805",
    },
    {
        "school": "FANNIE LOU HAMER MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005806",
    },
    {
        "school": "SCHOOL OF SCIENCE AND APPLIED LEARNING (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005807",
    },
    {
        "school": "METROPOLITAN HIGH SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005809",
    },
    {
        "school": "BRONX CHARTER SCHOOL FOR CHILDREN",
        "district": "BRONX CHARTER SCHOOL FOR CHILDREN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011005651",
    },
    {
        "school": "BRONX LIGHTHOUSE CHARTER SCHOOL",
        "district": "BRONX LIGHTHOUSE CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011105662",
    },
    {
        "school": "GRAND CONCOURSE ACADEMY CHARTER SCHOOL",
        "district": "GRAND CONCOURSE ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011205672",
    },
    {
        "school": "BRONX CHARTER SCHOOL FOR EXCELLENCE",
        "district": "BRONX CHARTER SCHOOL FOR EXCELLENCE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011305688",
    },
    {
        "school": "PS 721 STEPHEN MCSWEENEY SCHOOL",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013501923",
    },
    {
        "school": "PS 12 LEWIS AND CLARK SCHOOL",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Secondary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502079",
    },
    {
        "school": "PS 168",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502224",
    },
    {
        "school": "PS 811",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502844",
    },
    {
        "school": "PS 17",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013503373",
    },
    {
        "school": "PS 186 WALTER J DAMROSCH SCHOOL",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504468",
    },
    {
        "school": "PS 188",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504469",
    },
    {
        "school": "PS 176",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504521",
    },
    {
        "school": "JM RAPPORT SCHOOL FOR CAREER DEVELOPMENT",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504522",
    },
    {
        "school": "PS 10",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504560",
    },
    {
        "school": "HOSPITAL SCHOOLS",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Not reported",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504597",
    },
    {
        "school": "SOUTH BRONX CHARTER SCHOOL",
        "district": "SOUTH BRONX CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360014405787",
    },
    {
        "school": "SCIENCE SKILLS CENTER HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009100867",
    },
    {
        "school": "BROOKLYN INTERNATIONAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009101371",
    },
    {
        "school": "BROOKLYN TECHNICAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009101928",
    },
    {
        "school": "GEORGE WESTINGHOUSE CAREER & TECHNICAL ED HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360009101955",
    },
    {
        "school": "PS 3 BEDFORD VILLAGE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102050",
    },
    {
        "school": "PS 8 ROBERT FULTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102064",
    },
    {
        "school": "PS 9 TEUNIS G BERGEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102069",
    },
    {
        "school": "PS 11 PURVIS J BEHAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102074",
    },
    {
        "school": "PS 20 CLINTON HILL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102106",
    },
    {
        "school": "PS 44 MARCUS GARVEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102195",
    },
    {
        "school": "PS 46 EDWARD C BLUM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102205",
    },
    {
        "school": "PS 54 SAMUEL C BARNES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102237",
    },
    {
        "school": "PS 56 LEWIS H LATIMER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102243",
    },
    {
        "school": "PS 67 CHARLES A DORSEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102280",
    },
    {
        "school": "BENJAMIN BANNEKER ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102315",
    },
    {
        "school": "PS 93 WILLIAM H PRESCOTT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102356",
    },
    {
        "school": "ACORN COMMUNITY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102478",
    },
    {
        "school": "PS 133 WILLIAM A BUTLER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102490",
    },
    {
        "school": "PS 256 BENJAMIN BANNEKER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102772",
    },
    {
        "school": "DR SUSAN S MCKINNEY SECONDARY SCHOOL OF THE ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102781",
    },
    {
        "school": "PS 270 JOHANN DEKALB",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102784",
    },
    {
        "school": "PS 282 PARK SLOPE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102793",
    },
    {
        "school": "PS 287 BAILEY K ASHFORD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102796",
    },
    {
        "school": "PS 305 DR PETER RAY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102809",
    },
    {
        "school": "PS 307 DANIEL HALE WILLIAMS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009102811",
    },
    {
        "school": "MS 266 PARK PLACE COMMUNITY MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009104483",
    },
    {
        "school": "MS 113 RONALD EDMONDS LEARNING CENTER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009104523",
    },
    {
        "school": "BEDFORD ACADEMY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009105508",
    },
    {
        "school": "SATELLITE EAST MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009105695",
    },
    {
        "school": "DOCK STREET SCHOOL FOR STEAM STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009105696",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL FOR LAW AND JUSTICE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009105698",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL FOR MUSIC AND ART",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009105812",
    },
    {
        "school": "DIGITAL ARTS AND CINEMA TECHNOLOGY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009201377",
    },
    {
        "school": "PS 1 BERGEN (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202041",
    },
    {
        "school": "MAGNET SCHOOL OF MATH SCIENCE & DESIGN TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202072",
    },
    {
        "school": "PS 15 PATRICK F DALY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202088",
    },
    {
        "school": "PS 29 JOHN M HARRIGAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202139",
    },
    {
        "school": "PS 32 SAMUEL MILLS SPROLE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202151",
    },
    {
        "school": "PS 38 PACIFIC (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202173",
    },
    {
        "school": "PS 39 HENRY BRISTOW",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202175",
    },
    {
        "school": "MS 51 WILLIAM ALEXANDER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202226",
    },
    {
        "school": "PS 58 CARROLL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202251",
    },
    {
        "school": "PS 295",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202325",
    },
    {
        "school": "PS 94 HENRY LONGFELLOW (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202359",
    },
    {
        "school": "PS 107 JOHN W KIMBALL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202403",
    },
    {
        "school": "PS 124 SILAS B DUTCHER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202461",
    },
    {
        "school": "PS 130 PARKSIDE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202481",
    },
    {
        "school": "PS 131",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202482",
    },
    {
        "school": "WINDSOR TERRACE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202557",
    },
    {
        "school": "PS 169 SUNSET PARK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202602",
    },
    {
        "school": "PS 172 BEACON SCHOOL OF EXCELLENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202607",
    },
    {
        "school": "PS 230 DORIS L COHEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202740",
    },
    {
        "school": "PS 261 PHILIP LIVINGSTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202778",
    },
    {
        "school": "PS 321 WILLIAM PENN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202818",
    },
    {
        "school": "PS 24",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009202993",
    },
    {
        "school": "COBBLE HILL SCHOOL OF AMERICAN STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009203389",
    },
    {
        "school": "JHS 88 PETER ROUGET",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009204474",
    },
    {
        "school": "BROOKLYN HIGH SCHOOL OF THE ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009204497",
    },
    {
        "school": "BROOKLYN NEW SCHOOL-PS 146 (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009204811",
    },
    {
        "school": "JOHN JAY SCHOOL FOR LAW",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009204889",
    },
    {
        "school": "BOERUM HILL SCHOOL FOR INTERNATIONAL STUDIES (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009204890",
    },
    {
        "school": "SOUTH BROOKLYN COMMUNITY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009205243",
    },
    {
        "school": "BROOKLYN COLLABORATIVE STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009205497",
    },
    {
        "school": "MATH AND SCIENCE EXPLORATORY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009205498",
    },
    {
        "school": "NEW VOICES SCHOOL OF ACADEMIC AND CREATIVE ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009205501",
    },
    {
        "school": "MS 442 CARROLL GARDENS SCHOOL FOR INNOVATION",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009205502",
    },
    {
        "school": "IS 136 CHARLES O DEWEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009205513",
    },
    {
        "school": "PARK SLOPE COLLEGIATE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009205529",
    },
    {
        "school": "CYBERARTS STUDIO ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009205531",
    },
    {
        "school": "SUNSET PARK PREP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009205706",
    },
    {
        "school": "BOYS AND GIRLS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009401921",
    },
    {
        "school": "PS 5 DR RONALD MCNAIR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402054",
    },
    {
        "school": "PS 21 CRISPUS ATTUCKS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402108",
    },
    {
        "school": "PS 25 EUBIE BLAKE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402123",
    },
    {
        "school": "PS 26 JESSE OWENS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402128",
    },
    {
        "school": "MS 35 STEPHEN DECATUR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402163",
    },
    {
        "school": "PS 40 GEORGE W CARVER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402178",
    },
    {
        "school": "PS 81 THADDEUS STEVENS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402320",
    },
    {
        "school": "WHITELAW REID ACADEMY OF ARTS AND BUSINESS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402499",
    },
    {
        "school": "PS 243 WEEKSVILLE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402758",
    },
    {
        "school": "PS 262 EL HAJJ MALIK EL SHABAZZ ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402779",
    },
    {
        "school": "PS 308 CLARA CARDWELL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402812",
    },
    {
        "school": "PS 309 GEORGE E WIBECAN PREPARATORY ACADEMY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402813",
    },
    {
        "school": "PS 335 GRANVILLE T WOODS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009402823",
    },
    {
        "school": "MS 267 MATH SCIENCE & TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009404053",
    },
    {
        "school": "PS 28 WARREN PREP ACADEMY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009405519",
    },
    {
        "school": "NORMA ADAMS CLEMONS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009500799",
    },
    {
        "school": "MEDGAR EVERS COLLEGE PREPARATORY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009500882",
    },
    {
        "school": "PARKSIDE PREPARATORY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009501344",
    },
    {
        "school": "DR JACQUELINE PEEK-DAVIS SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009501347",
    },
    {
        "school": "CLARA BARTON HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360009501937",
    },
    {
        "school": "MS 61 DR GLADSTONE H ATWELL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502262",
    },
    {
        "school": "PS 91 ALBANY AVENUE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502348",
    },
    {
        "school": "PS 138",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502504",
    },
    {
        "school": "PS 161 CROWN (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502576",
    },
    {
        "school": "PS 181",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502631",
    },
    {
        "school": "PS 189 BILINGUAL CENTER (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502649",
    },
    {
        "school": "PS 191 PAUL ROBESON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502656",
    },
    {
        "school": "PS 221 TOUSSAINT L'OUVERTURE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502725",
    },
    {
        "school": "PS 241 EMMA L JOHNSTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502756",
    },
    {
        "school": "MS 246 WALT WHITMAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502760",
    },
    {
        "school": "PS 249 CATON (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502763",
    },
    {
        "school": "PS 289 GEORGE V BROWER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502798",
    },
    {
        "school": "PS 316 ELIJAH STROUD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502815",
    },
    {
        "school": "PS 397 FOSTER-LAURIE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502832",
    },
    {
        "school": "PS 398 WALTER WEAVER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009502833",
    },
    {
        "school": "PS 399 STANLEY EUGENE CLARKE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009504359",
    },
    {
        "school": "IS 340",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009504813",
    },
    {
        "school": "PS 375 JACKIE ROBINSON SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009504882",
    },
    {
        "school": "MS 394",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009504883",
    },
    {
        "school": "PS 92 ADRIAN HEGEMAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505210",
    },
    {
        "school": "HIGH SCHOOL FOR PUBLIC SERVICE-HEROES OF TOMORROW",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505510",
    },
    {
        "school": "BROOKLYN SCHOOL FOR MUSIC & THEATER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505514",
    },
    {
        "school": "SCIENCE TECHNOLOGY & RESEARCH EARLY COLLEGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505516",
    },
    {
        "school": "BROOKLYN ACADEMY OF SCIENCE AND THE ENVIRONMENT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505523",
    },
    {
        "school": "SCHOOL FOR HUMAN RIGHTS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505709",
    },
    {
        "school": "INTERNATIONAL HIGH SCHOOL AT PROSPECT HEIGHTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505712",
    },
    {
        "school": "HIGH SCHOOL FOR GLOBAL CITIZENSHIP (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505713",
    },
    {
        "school": "HIGH SCHOOL FOR YOUTH AND COMMUNITY DEVELOPMENT AT ERASMUS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505714",
    },
    {
        "school": "HIGH SCHOOL FOR SERVICE AND LEARNING AT ERASMUS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505715",
    },
    {
        "school": "EBBETS FIELD MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505818",
    },
    {
        "school": "ELIJAH STROUD MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505819",
    },
    {
        "school": "SCHOOL OF INTEGRATED LEARNING (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505820",
    },
    {
        "school": "IS 68 ISAAC BILDERSEE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602283",
    },
    {
        "school": "PS 114 RYDER ELEMENTARY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602427",
    },
    {
        "school": "PS 115 DANIEL MUCATEL SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602429",
    },
    {
        "school": "PS 135 SHELDON A BROOKNER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602496",
    },
    {
        "school": "PS 208 ELSA EBELING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602701",
    },
    {
        "school": "IS 211 JOHN WILSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602707",
    },
    {
        "school": "PS 219 KENNEDY-KING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602721",
    },
    {
        "school": "PS 233 LANGSTON HUGHES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602745",
    },
    {
        "school": "PS 235 JANICE MARIE KNIGHT SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602750",
    },
    {
        "school": "PS 244 RICHARD R GREEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602759",
    },
    {
        "school": "PS 268 EMMA LAZARUS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602782",
    },
    {
        "school": "PS 272 CURTIS ESTABROOK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602786",
    },
    {
        "school": "PS 276 LOUIS MARSHALL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602790",
    },
    {
        "school": "PS 279 HERMAN SCHREIBER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602791",
    },
    {
        "school": "IS 285 MEYER LEVIN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009602795",
    },
    {
        "school": "PS 66",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009605506",
    },
    {
        "school": "EBC HIGH SCHOOL FOR PUBLIC SERVICE-BUSHWICK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009700827",
    },
    {
        "school": "PS 376",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009701789",
    },
    {
        "school": "JHS 383 PHILIPPA SCHUYLER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702000",
    },
    {
        "school": "PS/IS 45 HORACE E GREENE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702199",
    },
    {
        "school": "PS 75 MAYDA CORTIELLA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702304",
    },
    {
        "school": "PS 86 IRVINGTON (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702334",
    },
    {
        "school": "PS 106 EDWARD EVERETT HALE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702400",
    },
    {
        "school": "PS 116 ELIZABETH L FARRELL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702434",
    },
    {
        "school": "PS 123 SUYDAM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702457",
    },
    {
        "school": "PS 145 ANDREW JACKSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702526",
    },
    {
        "school": "PS 151 LYNDON B JOHNSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702543",
    },
    {
        "school": "JHS 162 WILLOUGHBY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702582",
    },
    {
        "school": "PS 274 KOSCIUSKO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702788",
    },
    {
        "school": "JHS 291 ROLAND HAYES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702799",
    },
    {
        "school": "PS 299 THOMAS WARREN FIELD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702806",
    },
    {
        "school": "PS 377 ALEJANDRINA B DE GAUTIER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702829",
    },
    {
        "school": "PS/IS 384 FRANCES E CARTER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009702830",
    },
    {
        "school": "IS 347 SCHOOL OF HUMANITIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009704887",
    },
    {
        "school": "IS 349 MATH SCIENCE AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009704888",
    },
    {
        "school": "ALL CITY LEADERSHIP SECONDARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009705537",
    },
    {
        "school": "ACADEMY OF URBAN PLANNING AND ENGINEERING (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009705552",
    },
    {
        "school": "BROOKLYN SCHOOL FOR SOCIAL JUSTICE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009705555",
    },
    {
        "school": "BUSHWICK LEADERS HIGH SCHOOL FOR ACADEMIC EXCELLENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009705562",
    },
    {
        "school": "BUSHWICK COMMUNITY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009705725",
    },
    {
        "school": "PS/IS 208",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010105544",
    },
    {
        "school": "EXCELLENCE BOYS CHARTER SCHOOL OF BEDFORD STUYVESANT",
        "district": "EXCELLENCE BOYS CHARTER SCHOOL OF BEDFORD STUYVESANT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011405700",
    },
    {
        "school": "WILLIAMSBURG CHARTER HIGH SCHOOL",
        "district": "WILLIAMSBURG CHARTER HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011505705",
    },
    {
        "school": "BROOKLYN EXCELSIOR CHARTER SCHOOL",
        "district": "BROOKLYN EXCELSIOR CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011605708",
    },
    {
        "school": "EL PUENTE ACADEMY FOR PEACE AND JUSTICE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011900892",
    },
    {
        "school": "A-TECH HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360011901913",
    },
    {
        "school": "PS 16 LEONARD DUNKLY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902091",
    },
    {
        "school": "PS 17 HENRY D WOODWORTH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902095",
    },
    {
        "school": "PS 18 EDWARD BUSH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902096",
    },
    {
        "school": "PS 23 CARTER G WOODSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902116",
    },
    {
        "school": "PS 31 SAMUEL F DUPONT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902144",
    },
    {
        "school": "PS 34 OLIVER H PERRY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902156",
    },
    {
        "school": "JHS 50 JOHN D WELLS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902221",
    },
    {
        "school": "PS 59 WILLIAM FLOYD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902255",
    },
    {
        "school": "JUAN MOREL CAMPOS SECONDARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902291",
    },
    {
        "school": "PS 84 JOSE DE DIEGO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902326",
    },
    {
        "school": "PS 110 MONITOR (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902412",
    },
    {
        "school": "PS 120 CARLOS TAPIA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902445",
    },
    {
        "school": "JOHN ERICSSON MIDDLE SCHOOL 126",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902467",
    },
    {
        "school": "PS 132 CONSELYEA SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902487",
    },
    {
        "school": "PS 147 ISSAC REMSEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902533",
    },
    {
        "school": "PS/IS 157 BENJAMIN FRANKLIN HEATH AND SCIENCE ACADEMY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902565",
    },
    {
        "school": "PS 196 TEN EYCK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902668",
    },
    {
        "school": "PS 250 GEORGE H LINDSAY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902764",
    },
    {
        "school": "PS 257 JOHN F HYLAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902773",
    },
    {
        "school": "PS 297 ABRAHAM STOCKTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902804",
    },
    {
        "school": "IS 318 EUGENIO MARIA DE HOSTOS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011902816",
    },
    {
        "school": "PROGRESS HIGH SCHOOL FOR PROFESSIONAL CAREERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011903074",
    },
    {
        "school": "EAST WILLIAMSBURG SCHOLARS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011903078",
    },
    {
        "school": "HIGH SCHOOL FOR ENTERPRISE BUSINESS & TECHNOLOGY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011903091",
    },
    {
        "school": "PS 380 JOHN WAYNE ELEMENTARY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011904358",
    },
    {
        "school": "PS 319",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011904604",
    },
    {
        "school": "CONSELYEA PREPARATORY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011905701",
    },
    {
        "school": "MS 582",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011905702",
    },
    {
        "school": "WILLIAMSBURG HIGH SCHOOL FOR ARCHITECTURE AND DESIGN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360011905703",
    },
    {
        "school": "WILLIAMSBURG PREPARATORY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011905704",
    },
    {
        "school": "EAST NEW YORK FAMILY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012000813",
    },
    {
        "school": "TRANSIT TECH CAREER AND TECHNICAL EDUCATION HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360012001941",
    },
    {
        "school": "IS 364 GATEWAY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002006",
    },
    {
        "school": "PS 13 ROBERTO CLEMENTE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002080",
    },
    {
        "school": "PS 65",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002275",
    },
    {
        "school": "PS 108 SAL ABBRACCIAMENTO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002406",
    },
    {
        "school": "PS 149 DANNY KAYE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002538",
    },
    {
        "school": "PS 158 WARWICK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002570",
    },
    {
        "school": "PS 159 ISAAC PITKIN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002572",
    },
    {
        "school": "IS 171 ABRAHAM LINCOLN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002604",
    },
    {
        "school": "PS 190 SHEFFIELD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002651",
    },
    {
        "school": "PS 202 ERNEST S JENKYNS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002684",
    },
    {
        "school": "PS 213 NEW LOTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002710",
    },
    {
        "school": "PS 214 MICHAEL FRIEDSAM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002712",
    },
    {
        "school": "JHS 218 JAMES P SINNOTT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002720",
    },
    {
        "school": "PS 224 HALE A WOODRUFF",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002730",
    },
    {
        "school": "PS 273 WORTMAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002787",
    },
    {
        "school": "JHS 292 MARGARET S DOUGLAS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002800",
    },
    {
        "school": "PS 306 ETHAN ALLEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002810",
    },
    {
        "school": "PS 328 PHYLLIS WHEATLEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002820",
    },
    {
        "school": "PS 345 PATROLMAN ROBERT BOLDEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002824",
    },
    {
        "school": "PS 346 ABE STARK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012002855",
    },
    {
        "school": "W H MAXWELL CAREER AND TECHNICAL EDUCATION HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360012002889",
    },
    {
        "school": "PS 89 CYPRESS HILLS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012003000",
    },
    {
        "school": "PS 290 JUAN MOREL CAMPOS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012004316",
    },
    {
        "school": "PS 7 ABRAHAM LINCOLN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012004351",
    },
    {
        "school": "PS 41 FRANCIS WHITE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012102182",
    },
    {
        "school": "PS/IS 137 RACHAEL JEAN MITCHELL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012102501",
    },
    {
        "school": "PS 150 CHRISTOPHER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012102542",
    },
    {
        "school": "PS/IS 155 NICHOLAS HERKIMER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012102559",
    },
    {
        "school": "PS 156 WAVERLY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012102564",
    },
    {
        "school": "PS 165 IDA POSNER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012102590",
    },
    {
        "school": "PS 178 SAINT CLAIR MCKELWAY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012102623",
    },
    {
        "school": "PS 184 NEWPORT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012102636",
    },
    {
        "school": "GREGORY JOCKO JACKSON-SPORTS-ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012102794",
    },
    {
        "school": "PS 298 DR BETTY SHABAZZ",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012102805",
    },
    {
        "school": "PS 327 DR ROSE B ENGLISH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012102819",
    },
    {
        "school": "PS/IS 323",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012104886",
    },
    {
        "school": "IS 392",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012105237",
    },
    {
        "school": "TEACHERS PREPARATORY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012105242",
    },
    {
        "school": "PS 373 BROOKLYN TRANSITION CENTER",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013500806",
    },
    {
        "school": "PS 372 CHILDREN'S SCHOOL (THE)",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013500812",
    },
    {
        "school": "PS 811 CONNIE LEKAS SCHOOL",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013501926",
    },
    {
        "school": "PS 721 BROOKLYN OCCUPATIONAL TRAINING CENTER",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013501927",
    },
    {
        "school": "PS 368",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502020",
    },
    {
        "school": "PS 77",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502311",
    },
    {
        "school": "PS 369 COY L COX SCHOOL",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502825",
    },
    {
        "school": "PS 370",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502826",
    },
    {
        "school": "PS 371 LILLIAN L RASHKIS",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502827",
    },
    {
        "school": "PS 753 SCHOOL FOR CAREER DEVELOPMENT",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504319",
    },
    {
        "school": "PS  4",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504409",
    },
    {
        "school": "PS 36",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504476",
    },
    {
        "school": "PS 141",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504477",
    },
    {
        "school": "PS 231",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504478",
    },
    {
        "school": "PS 140",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504561",
    },
    {
        "school": "PS 53",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504605",
    },
    {
        "school": "PS 396",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504782",
    },
    {
        "school": "PS 771",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504815",
    },
    {
        "school": "WILLIAMSBURG COLLEGIATE CHARTER SCHOOL",
        "district": "WILLIAMSBURG COLLEGIATE CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360014505814",
    },
    {
        "school": "HELLENIC CLASSICAL CHARTER SCHOOL",
        "district": "HELLENIC CLASSICAL CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360014605815",
    },
    {
        "school": "ACHIEVEMENT FIRST CROWN HEIGHTS CHARTER SCHOOL",
        "district": "ACHIEVEMENT FIRST CROWN HEIGHTS CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360014705821",
    },
    {
        "school": "KIPP ALWAYS MENTALLY PREPARED CHARTER SCHOOL",
        "district": "KIPP ALWAYS MENTALLY PREPARED CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360014805822",
    },
    {
        "school": "ACHIEVEMENT FIRST EAST NEW YORK CHARTER SCHOOL",
        "district": "ACHIEVEMENT FIRST EAST NEW YORK CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360014905824",
    },
    {
        "school": "UFT CHARTER SCHOOL",
        "district": "UFT CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015005825",
    },
    {
        "school": "IS 187 CHRISTA MCAULIFFE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015101348",
    },
    {
        "school": "HIGH SCHOOL OF TELECOMMUNICATION ARTS AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015101916",
    },
    {
        "school": "FRANKLIN DELANO ROOSEVELT HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015101947",
    },
    {
        "school": "FORT HAMILTON HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015101952",
    },
    {
        "school": "NEW UTRECHT HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102036",
    },
    {
        "school": "PS 48 MAPLETON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102212",
    },
    {
        "school": "JHS 62 DITMAS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102266",
    },
    {
        "school": "PS 102 BAYVIEW (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102385",
    },
    {
        "school": "PS/IS 104 FORT HAMILTON SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102391",
    },
    {
        "school": "PS 105 BLYTHEBOURNE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102396",
    },
    {
        "school": "PS 112 LEFFERTS PARK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102421",
    },
    {
        "school": "PS 127 MCKINLEY PARK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102471",
    },
    {
        "school": "PS 160 WILLIAM T SAMPSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102575",
    },
    {
        "school": "PS 163 BATH BEACH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102585",
    },
    {
        "school": "PS 164 CAESAR RODNEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102587",
    },
    {
        "school": "RALPH A FABRIZIO SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102603",
    },
    {
        "school": "PS 176 OVINGTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102618",
    },
    {
        "school": "PS 179 KENSINGTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102625",
    },
    {
        "school": "SEEALL ACADEMY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102626",
    },
    {
        "school": "PS 185 WALTER KASSENBROCK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102638",
    },
    {
        "school": "PS 186 DR IRVING A GLADSTONE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102641",
    },
    {
        "school": "PS 192 MAGNET SCHOOL FOR MATH AND SCIENCE INQUIRY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102657",
    },
    {
        "school": "PS 200 BENSON SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102679",
    },
    {
        "school": "JHS 201 DYKER HEIGHTS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102682",
    },
    {
        "school": "PS 204 VINCE LOMBARDI",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102689",
    },
    {
        "school": "PS 205 CLARION",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102692",
    },
    {
        "school": "JHS 220 JOHN J PERSHING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102724",
    },
    {
        "school": "JHS 223 MONTAUK (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102729",
    },
    {
        "school": "JHS 227 EDWARD B SHALLOW",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102735",
    },
    {
        "school": "PS 229 DYKER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102738",
    },
    {
        "school": "PS 247",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102761",
    },
    {
        "school": "JHS 259 WILLIAM MCKINLEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015102775",
    },
    {
        "school": "PS/IS 30 MARY WHITE OVINGTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015103006",
    },
    {
        "school": "PS 69 VINCENT D GRIPPO SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015105227",
    },
    {
        "school": "ABRAHAM LINCOLN HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015201906",
    },
    {
        "school": "EDWARD R MURROW HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015201943",
    },
    {
        "school": "PS 90 EDNA COHEN SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202346",
    },
    {
        "school": "PS 95 GRAVESEND (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202363",
    },
    {
        "school": "IS 96 SETH LOW",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202367",
    },
    {
        "school": "PS 97 HIGHLAWN (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202370",
    },
    {
        "school": "PS 99 ISAAC ASIMOV",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202377",
    },
    {
        "school": "PS 100 CONEY ISLAND SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202378",
    },
    {
        "school": "PS 101 VERRAZANO (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202382",
    },
    {
        "school": "PS 121 NELSON A ROCKEFELLER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202447",
    },
    {
        "school": "PS 128 BENSONHURST",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202473",
    },
    {
        "school": "PS 153 HOMECREST",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202552",
    },
    {
        "school": "PS 177 MARLBORO (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202619",
    },
    {
        "school": "PS 188 MICHAEL E BERDY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202645",
    },
    {
        "school": "PS 199 FREDERICK WACHTEL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202676",
    },
    {
        "school": "PS 209 MARGARET MEAD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202702",
    },
    {
        "school": "PS 212 LADY DEBORAH MOODY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202708",
    },
    {
        "school": "PS 215 MORRIS H WEISS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202713",
    },
    {
        "school": "PS 216 ARTURO TOSCANINI",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202715",
    },
    {
        "school": "PS 225 EILEEN E ZAGLIN (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202731",
    },
    {
        "school": "PS 226 ALFRED DE B MASON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202734",
    },
    {
        "school": "IS 228 DAVID A BOODY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202736",
    },
    {
        "school": "PS 238 ANNE SULLIVAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202753",
    },
    {
        "school": "MARK TWAIN IS 239 FOR THE GIFTED AND TALENTED",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202754",
    },
    {
        "school": "PS 253",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202767",
    },
    {
        "school": "IS 281 JOSEPH B CAVALLARO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202792",
    },
    {
        "school": "PS 288 SHIRLEY TANYHILL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202797",
    },
    {
        "school": "IS 303 HERBERT S EISENBERG",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202807",
    },
    {
        "school": "PS 329 SURFSIDE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015202821",
    },
    {
        "school": "WILLIAM E GRADY CAREER AND TECHNICAL EDUCATION HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360015202888",
    },
    {
        "school": "IS 98 BAY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015203011",
    },
    {
        "school": "BROOKLYN STUDIO SECONDARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015203107",
    },
    {
        "school": "JOHN DEWEY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015204312",
    },
    {
        "school": "RACHEL CARSON HIGH SCHOOL FOR COASTAL STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015205826",
    },
    {
        "school": "HIGH SCHOOL OF SPORTS MANAGEMENT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015205827",
    },
    {
        "school": "BROOKLYN COLLEGE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015300829",
    },
    {
        "school": "LEON M GOLDSTEIN HIGH SCHOOL FOR THE SCIENCES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015300871",
    },
    {
        "school": "PS 109",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015301788",
    },
    {
        "school": "JHS 14 SHELL BANK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302003",
    },
    {
        "school": "JHS 78 ROY H MANN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302007",
    },
    {
        "school": "JAMES MADISON HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302009",
    },
    {
        "school": "JHS 278 MARINE PARK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302012",
    },
    {
        "school": "MIDWOOD HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302032",
    },
    {
        "school": "PS 52 SHEEPSHEAD BAY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302230",
    },
    {
        "school": "PS 119 AMERSFORT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302443",
    },
    {
        "school": "PS 139 ALEXINE A FENTY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302507",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302549",
    },
    {
        "school": "PS 193 GIL HODGES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302660",
    },
    {
        "school": "PS 194 RAOUL WALLENBERG",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302662",
    },
    {
        "school": "PS 195 MANHATTAN BEACH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302665",
    },
    {
        "school": "PS 197 KINGS HIGHWAY ACADEMY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302669",
    },
    {
        "school": "PS 198",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302673",
    },
    {
        "school": "PS 206 JOSEPH F LAMB",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302695",
    },
    {
        "school": "PS 207 ELIZABETH G LEARY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302697",
    },
    {
        "school": "PS 217 COLONEL DAVID MARCUS SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302717",
    },
    {
        "school": "PS 222 KATHERINE R SNYDER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302727",
    },
    {
        "school": "JHS 234 ARTHUR W CUNNINGHAM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302748",
    },
    {
        "school": "PS 236 MILL BASIN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302752",
    },
    {
        "school": "ANDRIES HUDDE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302755",
    },
    {
        "school": "PS 254 DAG HAMMARSKJOLD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302768",
    },
    {
        "school": "PS 255 BARBARA REING SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302769",
    },
    {
        "school": "PS 312 BERGEN BEACH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302814",
    },
    {
        "school": "PS 203 FLOYD BENNETT SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302852",
    },
    {
        "school": "PS 251 PAERDEGAT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302853",
    },
    {
        "school": "PS 277 GERRITSEN BEACH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015302854",
    },
    {
        "school": "PS 315",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015303385",
    },
    {
        "school": "PS 361 EAST FLATBUSH EARLY CHILDHOOD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015303387",
    },
    {
        "school": "PS 134",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015304067",
    },
    {
        "school": "IS 381",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015304070",
    },
    {
        "school": "PS 326",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015304885",
    },
    {
        "school": "EXPLORE CHARTER SCHOOL",
        "district": "EXPLORE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015705846",
    },
    {
        "school": "PS 256",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504817",
    },
    {
        "school": "MARSHALL SCHOOL",
        "district": "HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361413005610",
    },
    {
        "school": "PLAINEDGE MIDDLE SCHOOL",
        "district": "PLAINEDGE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362319005613",
    },
    {
        "school": "SOUTH SALEM ELEMENTARY SCHOOL",
        "district": "PORT WASHINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362358005612",
    },
    {
        "school": "ROOSEVELT MIDDLE SCHOOL",
        "district": "ROOSEVELT UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362499005611",
    },
    {
        "school": "EAST SIDE COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007600695",
    },
    {
        "school": "MARTA VALLE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007601275",
    },
    {
        "school": "PS 15 ROBERTO CLEMENTE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007602087",
    },
    {
        "school": "PS 19 ASHER LEVY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007602101",
    },
    {
        "school": "PS 20 ANNA SILVER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007602104",
    },
    {
        "school": "PS 34 FRANKLIN D ROOSEVELT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007602157",
    },
    {
        "school": "STAR ACADEMY PS 63 (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007602270",
    },
    {
        "school": "PS 110 FLORENCE NIGHTINGALE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007602411",
    },
    {
        "school": "PS 134 HENRIETTA SZOLD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007602492",
    },
    {
        "school": "PS 140 NATHAN STRAUS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007602511",
    },
    {
        "school": "PS 142 AMALIA CASTRO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007602515",
    },
    {
        "school": "PS 184 SHUANG WEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007603508",
    },
    {
        "school": "UNIVERSITY NEIGHBORHOOD HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007603680",
    },
    {
        "school": "PS 64 ROBERT SIMON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007604868",
    },
    {
        "school": "PS 188 ISLAND SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007604869",
    },
    {
        "school": "NEW EXPLORATIONS INTO SCIENCETECH AND MATH HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007604873",
    },
    {
        "school": "ORCHARD COLLEGIATE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007605614",
    },
    {
        "school": "EAST VILLAGE COMMUNITY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007605615",
    },
    {
        "school": "UNIVERSITY NEIGHBORHOOD MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007605616",
    },
    {
        "school": "CHILDREN'S WORKSHOP SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007605617",
    },
    {
        "school": "NEIGHBORHOOD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007605618",
    },
    {
        "school": "EARTH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007605619",
    },
    {
        "school": "TOMPKINS SQUARE MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007605620",
    },
    {
        "school": "BARD HIGH SCHOOL EARLY COLLEGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007605621",
    },
    {
        "school": "HIGH SCHOOL FOR ENVIRONMENTAL STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700116",
    },
    {
        "school": "LANDMARK HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700582",
    },
    {
        "school": "MANHATTAN VILLAGE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700584",
    },
    {
        "school": "VANGUARD HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700585",
    },
    {
        "school": "MANHATTAN INTERNATIONAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700586",
    },
    {
        "school": "UNITY CENTER FOR URBAN TECHNOLOGIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700595",
    },
    {
        "school": "HIGH SCHOOL FOR HEALTH PROFESSIONS & HUMAN SERVICES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700691",
    },
    {
        "school": "LEADERSHIP & PUBLIC SERVICE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700692",
    },
    {
        "school": "HIGH SCHOOL OF ECONOMICS & FINANCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700700",
    },
    {
        "school": "PS 290 MANHATTAN NEW SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007701219",
    },
    {
        "school": "TALENT UNLIMITED HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007701297",
    },
    {
        "school": "JACQUELINE KENNEDY-ONASSIS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007701299",
    },
    {
        "school": "REPERTORY COMPANY HIGH SCHOOL FOR THEATRE ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007701713",
    },
    {
        "school": "INSTITUTE FOR COLLABORATIVE EDUCATION",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007701720",
    },
    {
        "school": "PROFESSIONAL PERFORMING ARTS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007701723",
    },
    {
        "school": "ART AND DESIGN HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007701911",
    },
    {
        "school": "CHELSEA CAREER AND TECHNICAL EDUCATION HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007701934",
    },
    {
        "school": "HIGH SCHOOL OF FASHION INDUSTRIES (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007701949",
    },
    {
        "school": "MURRY BERGTRAUM HIGH SCHOOL FOR BUSINESS CAREERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702034",
    },
    {
        "school": "PS 1 ALFRED E SMITH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702042",
    },
    {
        "school": "PS 2 MEYER LONDON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702047",
    },
    {
        "school": "PS 3 CHARRETTE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702049",
    },
    {
        "school": "PS 6 LILLIE D BLAKE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702058",
    },
    {
        "school": "PS 11 WILLIAM T HARRIS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702076",
    },
    {
        "school": "PS 33 CHELSEA PREP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702152",
    },
    {
        "school": "PS 40 AUGUSTUS SAINT-GAUDENS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702177",
    },
    {
        "school": "PS 41 GREENWICH VILLAGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702184",
    },
    {
        "school": "PS 42 BENJAMIN ALTMAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702187",
    },
    {
        "school": "PS 51 ELIAS HOWE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702225",
    },
    {
        "school": "PS 59 BEEKMAN HILL INTERNATIONAL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702253",
    },
    {
        "school": "PS 111 ADOLPH S OCHS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702414",
    },
    {
        "school": "PS 116 MARY LINDLEY MURRAY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702433",
    },
    {
        "school": "PS 124 YUNG WING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702458",
    },
    {
        "school": "PS 126 JACOB AUGUST RIIS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702468",
    },
    {
        "school": "PS 130 HERNANDO DE SOTO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702480",
    },
    {
        "school": "PS 150",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702540",
    },
    {
        "school": "PS 158 BAYARD TAYLOR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702569",
    },
    {
        "school": "JHS 167 ROBERT F WAGNER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702597",
    },
    {
        "school": "PS 183 ROBERT L STEVENSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702635",
    },
    {
        "school": "PS 198 ISADOR E IDA STRAUS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702675",
    },
    {
        "school": "BARUCH COLLEGE CAMPUS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702856",
    },
    {
        "school": "NYC LAB HIGH SCHOOL FOR COLLABORATIVE STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702857",
    },
    {
        "school": "SCHOOL OF THE FUTURE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702862",
    },
    {
        "school": "NYC MUSEUM SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702871",
    },
    {
        "school": "STUYVESANT HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702877",
    },
    {
        "school": "HUMANITIES PREPARATORY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007702914",
    },
    {
        "school": "PS 89",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007703328",
    },
    {
        "school": "IS 289",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007703331",
    },
    {
        "school": "ELLA BAKER SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007703348",
    },
    {
        "school": "PS 77 LOWER LAB SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007703548",
    },
    {
        "school": "URBAN ACADEMY LABORATORY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007703646",
    },
    {
        "school": "LIFE SCIENCES SECONDARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007703705",
    },
    {
        "school": "PS 234 INDEPENDENCE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007704356",
    },
    {
        "school": "MS 131",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007704402",
    },
    {
        "school": "EAST SIDE MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007704405",
    },
    {
        "school": "PS/IS 217 ROOSEVELT ISLAND",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007704406",
    },
    {
        "school": "PS 212 MIDTOWN WEST",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007704407",
    },
    {
        "school": "MS 255 SALK SCHOOL OF SCIENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007704408",
    },
    {
        "school": "CLINTON SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007704410",
    },
    {
        "school": "JHS 104 SIMON BARUCH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007704447",
    },
    {
        "school": "AMERICAN SIGN LANGUAGE & ENGLISH SECONDARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360007704454",
    },
    {
        "school": "RICHARD R GREEN HIGH SCHOOL OF TEACHING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007704729",
    },
    {
        "school": "MANHATTAN COMPREHENSIVE NIGHT AND DAY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007704778",
    },
    {
        "school": "ELEANOR ROOSEVELT HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705084",
    },
    {
        "school": "MILLENNIUM HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705085",
    },
    {
        "school": "BALLET TECH/NYC PUBLIC SCHOOL FOR DANCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705112",
    },
    {
        "school": "NEW DESIGN HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705499",
    },
    {
        "school": "MANHATTAN BRIDGES HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705500",
    },
    {
        "school": "HARVEY MILK HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705522",
    },
    {
        "school": "HIGH SCHOOL FOR DUAL LANGUAGE AND ASIAN STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705532",
    },
    {
        "school": "NYC LAB MS FOR COLLABORATIVE STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705539",
    },
    {
        "school": "FOOD AND FINANCE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007705622",
    },
    {
        "school": "ESSEX STREET ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705623",
    },
    {
        "school": "HIGH SCHOOL OF HOSPITALITY MANAGEMENT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705624",
    },
    {
        "school": "PACE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705625",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL OF DESIGN AND CONSTRUCTION",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705626",
    },
    {
        "school": "47 AMERICAN SIGN LANGUAGE AND ENGLISH LOWER SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705767",
    },
    {
        "school": "LOWER MANHATTAN COMMUNITY MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705768",
    },
    {
        "school": "FACING HISTORY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705769",
    },
    {
        "school": "URBAN ASSEMBLY ACADEMY OF GOVERNMENT AND LAW",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705770",
    },
    {
        "school": "LOWER MANHATTAN ARTS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705771",
    },
    {
        "school": "JAMES BALDWIN SCHOOL-A SCHOOL FOR EXPEDITIONARY LRNING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705772",
    },
    {
        "school": "BEACON HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007800592",
    },
    {
        "school": "WADLEIGH PERF AND VISUAL ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007800687",
    },
    {
        "school": "PS 9 SARAH ANDERSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802068",
    },
    {
        "school": "JHS 54 BOOKER T WASHINGTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802235",
    },
    {
        "school": "PS 75 EMILY DICKINSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802303",
    },
    {
        "school": "PS 76 A PHILLIP RANDOLPH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802308",
    },
    {
        "school": "PS 84 LILLIAN WEBER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802327",
    },
    {
        "school": "PS 87 WILLIAM SHERMAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802335",
    },
    {
        "school": "PS 145 BLOOMINGDALE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802525",
    },
    {
        "school": "PS 149 SOJOURNER TRUTH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802539",
    },
    {
        "school": "PS 163 ALFRED E SMITH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802584",
    },
    {
        "school": "PS 165 ROBERT E SIMON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802591",
    },
    {
        "school": "PS 166 RICHARD ROGERS SCHOOL OF THE ARTS & SCIENCE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802593",
    },
    {
        "school": "LOCKE SCHOOL OF ARTS AND ENGINEERING (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802640",
    },
    {
        "school": "RIVERSIDE SCHOOL FOR MAKERS AND ARTISTS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802655",
    },
    {
        "school": "PS 199 JESSIE ISADOR STRAUS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007802677",
    },
    {
        "school": "STEM INSTITUTE OF MANHATTAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007803550",
    },
    {
        "school": "PS 242 YOUNG DIPLOMATS MAGNET ACADEMY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007803551",
    },
    {
        "school": "MS 243 CENTER SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007803552",
    },
    {
        "school": "MS 245 COMPUTER SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007803572",
    },
    {
        "school": "MS 247 DUAL LANGUAGE MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007803579",
    },
    {
        "school": "MS 250 WEST SIDE COLLABORATIVE MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007803603",
    },
    {
        "school": "LAFAYETTE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007803607",
    },
    {
        "school": "COMMUNITY ACTION SCHOOL-MS 258",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007803616",
    },
    {
        "school": "PS 333 MANHATTAN SCHOOL FOR CHILDREN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007803622",
    },
    {
        "school": "FIORELLO H LAGUARDIA HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007804458",
    },
    {
        "school": "HIGH SCHOOL FOR LAW ADVOCACY AND COMMUNITY JUSTICE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007805113",
    },
    {
        "school": "HIGH SCHOOL OF ARTS AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007805114",
    },
    {
        "school": "MANHATTAN/HUNTER SCIENCE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007805505",
    },
    {
        "school": "PS 180 HUGO NEWMAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007805524",
    },
    {
        "school": "FREDERICK DOUGLASS ACADEMY II SECONDARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007805627",
    },
    {
        "school": "MOTT HALL II",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007805629",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL FOR MEDIA STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007805630",
    },
    {
        "school": "ANDERSON SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007805773",
    },
    {
        "school": "MAXINE GREENE HIGH SCHOOL FOR IMAGINATIVE INQUIRY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007805774",
    },
    {
        "school": "PARK EAST HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007900593",
    },
    {
        "school": "CENTRAL PARK EAST HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007900638",
    },
    {
        "school": "PS 7 SAMUEL STERN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902061",
    },
    {
        "school": "PS 38 ROBERTO CLEMENTE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902083",
    },
    {
        "school": "JAMES WELDON JOHNSON SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902246",
    },
    {
        "school": "LEXINGTON ACADEMY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902294",
    },
    {
        "school": "BILINGUAL BICULTURAL SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902324",
    },
    {
        "school": "PS 96 JOSEPH LANZETTA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902366",
    },
    {
        "school": "PS 102 JACQUES CARTIER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902387",
    },
    {
        "school": "PS 108 ASSEMBLYMAN ANGELO DEL TORO EDUCATIONAL COMPLEX",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902407",
    },
    {
        "school": "PS 112 JOSE CELSO BARBOSA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902418",
    },
    {
        "school": "PS 146 ANN M SHORT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902529",
    },
    {
        "school": "PS 155 WILLIAM PACA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902560",
    },
    {
        "school": "PS 171 PATRICK HENRY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902605",
    },
    {
        "school": "PS 206 JOSE CELSO BARBOSA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902694",
    },
    {
        "school": "YOUNG WOMEN'S LEADERSHIP SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902919",
    },
    {
        "school": "HERITAGE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007902929",
    },
    {
        "school": "MS 224 MANHATTAN EAST SCHOOL FOR ARTS & ACADEMICS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007904412",
    },
    {
        "school": "MANHATTAN CENTER FOR SCIENCE & MATHEMATICS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007904518",
    },
    {
        "school": "PS 83 LUIS MUNOZ RIVERA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007905530",
    },
    {
        "school": "TAG YOUNG SCHOLARS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007905631",
    },
    {
        "school": "RIVER EAST ELEMENTARY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007905632",
    },
    {
        "school": "CENTRAL PARK EAST I",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007905633",
    },
    {
        "school": "ISAAC NEWTON MIDDLE SSCHOOL FOR MATH AND SCIENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007905634",
    },
    {
        "school": "CENTRAL PARK EAST II",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007905635",
    },
    {
        "school": "HARLEM VILLAGE ACADEMY WEST CHARTER SCHOOL",
        "district": "HARLEM VILLAGE ACADEMY WEST CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008005528",
    },
    {
        "school": "FREDERICK DOUGLASS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008100701",
    },
    {
        "school": "PS 30 HERNANDEZ/HUGHES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102141",
    },
    {
        "school": "PS 36 MARGARET DOUGLAS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102164",
    },
    {
        "school": "PS 154 HARRIET TUBMAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102176",
    },
    {
        "school": "PS 46 ARTHUR TAPPAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102207",
    },
    {
        "school": "PS 123 MAHALIA JACKSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102455",
    },
    {
        "school": "PS 125 RALPH BUNCHE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102462",
    },
    {
        "school": "PS 129 JOHN H FINLEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102475",
    },
    {
        "school": "PS 133 FRED R MOORE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102489",
    },
    {
        "school": "PS 161 PEDRO ALBIZU CAMPOS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102577",
    },
    {
        "school": "PS 194 COUNTEE CULLEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102663",
    },
    {
        "school": "PS 197 JOHN B RUSSWURM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102670",
    },
    {
        "school": "PS 200 JAMES MCCUNE SMITH SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008102680",
    },
    {
        "school": "URBAN ASSEMBLY ACADEMY FOR FUTURE LEADERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008104436",
    },
    {
        "school": "PS 175 HENRY H GARNET",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008104690",
    },
    {
        "school": "THURGOOD MARSHALL ACADEMY FOR LEARNING & SOCIAL CHANGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008105115",
    },
    {
        "school": "PS 92 MARY MCLEOD BETHUNE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008105117",
    },
    {
        "school": "MOTT HALL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008105639",
    },
    {
        "school": "THURGOOD MARSHALL ACADEMY LOWER SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008105780",
    },
    {
        "school": "KIPP STAR COLLEGE PREP CHARTER SCHOOL",
        "district": "KIPP STAR COLLEGE PREP CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008205526",
    },
    {
        "school": "PS 5 ELLEN LURIE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008300519",
    },
    {
        "school": "PS 18 PARK TERRACE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008300523",
    },
    {
        "school": "PS 48 PO MICHAEL J BUCZEK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008300528",
    },
    {
        "school": "IS 528 BEA FULLER RODGERS SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008300551",
    },
    {
        "school": "GREGORIO LUPERON HIGH SCHOOL FOR SCIENCE AND MATHEMATICS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008301265",
    },
    {
        "school": "PS 4 DUKE ELLINGTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008301675",
    },
    {
        "school": "PS 8 LUIS BELLIARD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008301676",
    },
    {
        "school": "PS 28 WRIGHT BROTHERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302135",
    },
    {
        "school": "PS 98 SHORAC KAPPOCK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302374",
    },
    {
        "school": "PS 115 ALEXANDER HUMBOLDT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302431",
    },
    {
        "school": "PS 128 AUDUBON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302472",
    },
    {
        "school": "PS 132 JUAN PABLO DUARTE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302485",
    },
    {
        "school": "JHS 143 ELEANOR ROOSEVELT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302519",
    },
    {
        "school": "PS 152 DYCKMAN VALLEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302546",
    },
    {
        "school": "PS 153 ADAM CLAYTON POWELL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302550",
    },
    {
        "school": "PS 173",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302609",
    },
    {
        "school": "PS/IS 187 HUDSON CLIFFS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302643",
    },
    {
        "school": "PS 189",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302648",
    },
    {
        "school": "PS 192 JACOB H SCHIFF",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302658",
    },
    {
        "school": "PS/IS 210 21ST CENTURY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008302872",
    },
    {
        "school": "COLLEGE ACADEMY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008303681",
    },
    {
        "school": "HIGH SCHOOL FOR MEDIA & COMMUNICATIONS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008303685",
    },
    {
        "school": "HIGH SCHOOL FOR LAW & PUBLIC SERVICE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008303691",
    },
    {
        "school": "HIGH SCHOOL FOR HEALTH CAREERS & SCIENCES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008303692",
    },
    {
        "school": "A PHILIP RANDOLPH CAMPUS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008304305",
    },
    {
        "school": "HAROLD O LEVY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008304451",
    },
    {
        "school": "MOTT HALL SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008304517",
    },
    {
        "school": "PROFESSOR JUAN BOSCH PUBLIC SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008304872",
    },
    {
        "school": "PAULA HEDBAVNY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305642",
    },
    {
        "school": "AMISTAD DUAL LANGUAGE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305643",
    },
    {
        "school": "MUSCOTA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305644",
    },
    {
        "school": "MS 319 MARIE TERESA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305645",
    },
    {
        "school": "MS 324 PATRIA MIRABAL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305647",
    },
    {
        "school": "COMMUNITY MATH AND SCIENCE PREP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305649",
    },
    {
        "school": "MIDDLE SCHOOL 322",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305782",
    },
    {
        "school": "CITY COLLEGE ACADEMY OF THE ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305784",
    },
    {
        "school": "MARBLE HILL HIGH SCHOOL OF INTERNATIONAL STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705188",
    },
    {
        "school": "BRONX THEATRE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705496",
    },
    {
        "school": "BRONX SCHOOL OF LAW AND FINANCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705678",
    },
    {
        "school": "HARLEM CHILDREN'S ZONE PROMISE ACADEMY CHARTER SCHOOL",
        "district": "HARLEM CHILDREN'S ZONE PROMISE ACADEMY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010805640",
    },
    {
        "school": "OPPORTUNITY CHARTER SCHOOL",
        "district": "OPPORTUNITY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010905641",
    },
    {
        "school": "PS 811 MICKEY MANTLE SCHOOL",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013501932",
    },
    {
        "school": "PS 721 MANHATTAN OCCUPATIONAL TRAINING CENTER",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502026",
    },
    {
        "school": "PS 169 ROBERT F KENNEDY",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502601",
    },
    {
        "school": "PS 226",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502733",
    },
    {
        "school": "MANHATTAN SCHOOL FOR CAREER DEVELOPMENT",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502870",
    },
    {
        "school": "PS 35",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013503340",
    },
    {
        "school": "PS 94",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504596",
    },
    {
        "school": "PS 138",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504780",
    },
    {
        "school": "PS 79 HORAN SCHOOL",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504807",
    },
    {
        "school": "GIRLS PREPARATORY CHARTER SCHOOL OF NEW YORK",
        "district": "GIRLS PREPARATORY CHARTER SCHOOL OF NEW YORK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360013605765",
    },
    {
        "school": "MANHATTAN CHARTER SCHOOL",
        "district": "MANHATTAN CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360013705766",
    },
    {
        "school": "HARLEM LINK CHARTER SCHOOL",
        "district": "HARLEM LINK CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360013805775",
    },
    {
        "school": "FUTURE LEADERS INSTITUTE CHARTER SCHOOL",
        "district": "FUTURE LEADERS INSTITUTE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360013905776",
    },
    {
        "school": "HARLEM CHILDREN'S ZONE PROMISE ACADEMY II CHARTER SCHOOL",
        "district": "HARLEM CHILDREN'S ZONE PROMISE ACADEMY II CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360014005777",
    },
    {
        "school": "HARLEM VILLAGE ACADEMY EAST CHARTER SCHOOL",
        "district": "HARLEM VILLAGE ACADEMY EAST CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360014105778",
    },
    {
        "school": "NYC AUTISM CHARTER SCHOOL EAST HARLEM",
        "district": "NYC AUTISM CHARTER SCHOOL EAST HARLEM",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360014205779",
    },
    {
        "school": "KIPP INFINITY CHARTER SCHOOL",
        "district": "KIPP INFINITY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360014305781",
    },
    {
        "school": "PS 7 LOUIS F SIMEONE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009801406",
    },
    {
        "school": "ROBERT F WAGNER JR SECONDARY SCHOOL FOR ARTS AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009801791",
    },
    {
        "school": "AVIATION CAREER AND TECHNICAL EDUCATION HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360009801915",
    },
    {
        "school": "GROVER CLEVELAND HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009801959",
    },
    {
        "school": "NEWTOWN HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802038",
    },
    {
        "school": "PS 13 CLEMENT C MOORE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802081",
    },
    {
        "school": "PS 14 FAIRVIEW",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802084",
    },
    {
        "school": "PS 19 MARINO JEANTET",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802103",
    },
    {
        "school": "PS 49 DOROTHY BONAWIT KOLE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802215",
    },
    {
        "school": "IS 61 LEONARDO DA VINCI",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802263",
    },
    {
        "school": "PS 68 CAMBRIDGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802284",
    },
    {
        "school": "PS 71 FOREST",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802292",
    },
    {
        "school": "IS 73 FRANK SANSIVIERI INTERMEDIATE SCHOOL  (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802300",
    },
    {
        "school": "PS 81 JEAN PAUL RICHTER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802319",
    },
    {
        "school": "PS/IS 87 MIDDLE VILLAGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802337",
    },
    {
        "school": "PS 88 SENECA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802340",
    },
    {
        "school": "PS 89 ELMHURST",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802343",
    },
    {
        "school": "PS 91 RICHARD ARKWRIGHT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802349",
    },
    {
        "school": "IS 93 RIDGEWOOD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802355",
    },
    {
        "school": "PS 102 BAYVIEW",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802386",
    },
    {
        "school": "PS/IS 113 ANTHONY J PRANZO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802423",
    },
    {
        "school": "PS/IS 119 GLENDALE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802442",
    },
    {
        "school": "IS 125 THOMAS J MCCANN WOODSIDE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802464",
    },
    {
        "school": "PS 128 LORRAINE TUZZO-JUNIPER VALLEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802474",
    },
    {
        "school": "PS 143 LOUIS ARMSTRONG",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802521",
    },
    {
        "school": "PS 153 MASPETH ELEMENTARY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802551",
    },
    {
        "school": "PS 199 MAURICE A FITZGERALD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802678",
    },
    {
        "school": "PS 229 EMANUEL KAPLAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009802739",
    },
    {
        "school": "QUEENS TECHNICAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360009802860",
    },
    {
        "school": "IS 5 WALTER CROWLEY INTERMEDIATE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009803117",
    },
    {
        "school": "HIGH SCHOOL FOR ARTS AND BUSINESS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009803154",
    },
    {
        "school": "PS 16 NANCY DEBENEDITTIS SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009804146",
    },
    {
        "school": "PS 12 JAMES B COLGATE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009804563",
    },
    {
        "school": "IS 77",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009804609",
    },
    {
        "school": "MIDDLE COLLEGE HIGH SCHOOL AT LAGUARDIA COMMUNITY COLLEGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009804895",
    },
    {
        "school": "INTERNATIONAL HIGH SCHOOL AT LAGUARDIA COMMUNITY COLLEGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009804896",
    },
    {
        "school": "PS 28 THOMAS EMANUEL EARLY CHILDHOOD CENTER (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009805244",
    },
    {
        "school": "PS 58 SCHOOL OF HEROES (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009805245",
    },
    {
        "school": "PS 239",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009805564",
    },
    {
        "school": "ACADEMY OF FINANCE AND ENTERPRISE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009805828",
    },
    {
        "school": "HIGH SCHOOL OF APPLIED COMMUNICATIONS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009805829",
    },
    {
        "school": "BAYSIDE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009901917",
    },
    {
        "school": "BENJAMIN N CARDOZO HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009901919",
    },
    {
        "school": "FRANCIS LEWIS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009901953",
    },
    {
        "school": "MARTIN VAN BUREN HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902030",
    },
    {
        "school": "PS 18 WINCHESTER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902099",
    },
    {
        "school": "PS 26 RUFUS KING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902129",
    },
    {
        "school": "PS 31 BAYSIDE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902145",
    },
    {
        "school": "PS 41 CROCHERON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902183",
    },
    {
        "school": "PS 46 ALLEY POND",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902203",
    },
    {
        "school": "JHS 67 LOUIS PASTEUR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902281",
    },
    {
        "school": "JHS 74 NATHANIEL HAWTHORNE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902301",
    },
    {
        "school": "PS 94 DAVID D PORTER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902358",
    },
    {
        "school": "PS 98 DOUGLASTON SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902372",
    },
    {
        "school": "JAMES J AMBROSE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902428",
    },
    {
        "school": "PS 133",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902488",
    },
    {
        "school": "MS 158 MARIE CURIE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902568",
    },
    {
        "school": "PS 159",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902571",
    },
    {
        "school": "PS 162 JOHN GOLDEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902580",
    },
    {
        "school": "IRWIN ALTMAN MIDDLE SCHOOL 172",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902608",
    },
    {
        "school": "PS 173 FRESH MEADOWS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902610",
    },
    {
        "school": "PS/IS 178 HOLLISWOOD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902622",
    },
    {
        "school": "PS 186 CASTLEWOOD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902642",
    },
    {
        "school": "PS 188 KINGSBURY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902646",
    },
    {
        "school": "PS 191 MAYFLOWER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902654",
    },
    {
        "school": "PS 203 OAKLAND GARDENS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902687",
    },
    {
        "school": "PS 205 ALEXANDER GRAHAM BELL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902693",
    },
    {
        "school": "PS 213 CARL ULLMAN SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902709",
    },
    {
        "school": "JHS 216 GEORGE J RYAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902716",
    },
    {
        "school": "PS 221 NORTH HILLS SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009902726",
    },
    {
        "school": "QUEENS HIGH SCHOOL OF TEACHING LIBERAL ARTS AND SCIENCES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009905536",
    },
    {
        "school": "PS/IS 266",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009905567",
    },
    {
        "school": "QUEENS GATEWAY TO HEALTH SCIENCES SECONDARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010001414",
    },
    {
        "school": "FOREST HILLS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010001951",
    },
    {
        "school": "HILLCREST HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010001965",
    },
    {
        "school": "PS 40 SAMUEL HUNTINGTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002181",
    },
    {
        "school": "PS 48 WILLIAM WORDSWORTH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002213",
    },
    {
        "school": "PS 50 TALFOURD LAWN ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002222",
    },
    {
        "school": "PS 54 HILLSIDE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002236",
    },
    {
        "school": "PS 55 MAURE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002241",
    },
    {
        "school": "CATHERINE & COUNT BASIE MIDDLE SCHOOL 72",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002297",
    },
    {
        "school": "PS 80 THURGOOD MARSHALL MAGNET SCHOOL OF MULTIMEDIA (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002317",
    },
    {
        "school": "PS 82 HAMMOND",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002322",
    },
    {
        "school": "PS 86",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002333",
    },
    {
        "school": "PS 99 KEW GARDENS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002376",
    },
    {
        "school": "PS 101 SCHOOL IN THE GARDENS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002384",
    },
    {
        "school": "PS 117 J KELD/BRIARWOOD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002437",
    },
    {
        "school": "PS 121",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002448",
    },
    {
        "school": "PS 139 REGO PARK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002508",
    },
    {
        "school": "PS 140 EDWARD K ELLINGTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002510",
    },
    {
        "school": "PS 144 COL JEROMUS REMSEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002523",
    },
    {
        "school": "JHS 157 STEPHEN A HALSEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002567",
    },
    {
        "school": "PS 160 WALTER FRANCIS BISHOP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002574",
    },
    {
        "school": "PS 174 WILLIAM SIDNEY MOUNT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002612",
    },
    {
        "school": "PS 175 LYNN GROSS DISCOVERY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002614",
    },
    {
        "school": "JHS 190 RUSSELL SAGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002653",
    },
    {
        "school": "PS 196 GRAND CENTRAL PARKWAY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002667",
    },
    {
        "school": "PS 206 HORACE HARDING SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002696",
    },
    {
        "school": "JHS 217 ROBERT A VAN WYCK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002718",
    },
    {
        "school": "PS 220 EDWARD MANDEL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010002723",
    },
    {
        "school": "THOMAS A EDISON CAREER AND TECHNICAL EDUCATION HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360010002881",
    },
    {
        "school": "JHS 8 RICHARD S GROSSLEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010003176",
    },
    {
        "school": "PS 182 SAMANTHA SMITH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010004611",
    },
    {
        "school": "PS 161 ARTHUR ASHE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010004734",
    },
    {
        "school": "QUEENS HIGH SCHOOL FOR THE SCIENCES AT YORK COLLEGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010005297",
    },
    {
        "school": "HS FOR LAW ENFORCEMENT AND PUBLIC SAFETY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010005534",
    },
    {
        "school": "YOUNG WOMEN'S LEADERSHIP SCHOOL-QUEENS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010005832",
    },
    {
        "school": "MATH/SCIENCE RESEARCH/TECH MAGNET",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010101408",
    },
    {
        "school": "HUMANITIES AND ARTS MAGNET HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010101413",
    },
    {
        "school": "IS 238 SUSAN B ANTHONY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010101997",
    },
    {
        "school": "PS 15 JACKIE ROBINSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102089",
    },
    {
        "school": "PS 33 EDWARD M FUNK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102153",
    },
    {
        "school": "PS 34 JOHN HARVARD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102158",
    },
    {
        "school": "PS 35 NATHANIEL WOODHULL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102162",
    },
    {
        "school": "PS 36 SAINT ALBANS SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102166",
    },
    {
        "school": "CYNTHIA JENKINS SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102169",
    },
    {
        "school": "PS 38 ROSEDALE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102172",
    },
    {
        "school": "PS 52",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102227",
    },
    {
        "school": "IS 59 SPRINGFIELD GARDENS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102254",
    },
    {
        "school": "PS 95 EASTWOOD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102362",
    },
    {
        "school": "JEAN NUZZI INTERMEDIATE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102409",
    },
    {
        "school": "PS/IS 116 WILLIAM C HUGHLEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102432",
    },
    {
        "school": "PS 118 LORRAINE HANSBERRY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102438",
    },
    {
        "school": "PS 131 ABIGAIL ADAMS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102483",
    },
    {
        "school": "PS 132 RALPH BUNCHE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102484",
    },
    {
        "school": "PS 134 HOLLIS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102493",
    },
    {
        "school": "BELLAIRE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102494",
    },
    {
        "school": "PS 136 ROY WILKINS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102497",
    },
    {
        "school": "PS/MS 138 SUNRISE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102506",
    },
    {
        "school": "PS/MS 147 RONALD MCNAIR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102532",
    },
    {
        "school": "PS 156 LAURELTON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102563",
    },
    {
        "school": "PS 176 CAMBRIA HEIGHTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102617",
    },
    {
        "school": "PS 181 BROOKFIELD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102630",
    },
    {
        "school": "IS 192 LINDEN (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102659",
    },
    {
        "school": "PS 195 WILLIAM HABERLE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102666",
    },
    {
        "school": "PS 251",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010102765",
    },
    {
        "school": "PS/IS 268",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010105545",
    },
    {
        "school": "GORDON PARKS SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010105546",
    },
    {
        "school": "EXCELSIOR PREPARATORTY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010105733",
    },
    {
        "school": "GEORGE WASHINGTON CARVER HIGH SCHOOL FOR THE SCIENCES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010105734",
    },
    {
        "school": "QUEENS PREPARATORY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010105833",
    },
    {
        "school": "PATHWAYS COLLEGE PREPARATORY SCHOOL:  A COLLEGE BOARD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010105834",
    },
    {
        "school": "NEWCOMERS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010201821",
    },
    {
        "school": "LONG ISLAND CITY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202022",
    },
    {
        "school": "PS 2 ALFRED ZIMBERG",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202045",
    },
    {
        "school": "IS 10 HORACE GREELEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202071",
    },
    {
        "school": "PS 11 KATHRYN PHELAN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202077",
    },
    {
        "school": "PS 17 HENRY DAVID THOREAU",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202093",
    },
    {
        "school": "PS 69 JACKSON HEIGHTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202287",
    },
    {
        "school": "PS 70",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202289",
    },
    {
        "school": "PS 76 WILLIAM HALLET",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202309",
    },
    {
        "school": "PS 84 STEINWAY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202328",
    },
    {
        "school": "PS 85 JUDGE CHARLES VALLONE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202330",
    },
    {
        "school": "PS 92 HARRY T STEWART SR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202352",
    },
    {
        "school": "PS 111 JACOB BLACKWELL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202416",
    },
    {
        "school": "PS 112 DUTCH KILLS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202420",
    },
    {
        "school": "PS 122 MAMIE FAY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202451",
    },
    {
        "school": "ALBERT SHANKER SCHOOL FOR VISUAL AND PERFORMING ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202466",
    },
    {
        "school": "PS 127 AEROSPACE SCIENCE MAGNET SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202470",
    },
    {
        "school": "IS 141 STEINWAY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202514",
    },
    {
        "school": "IS 145 JOSEPH PULITZER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202527",
    },
    {
        "school": "PS 148",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202534",
    },
    {
        "school": "ACADEMY FOR NEW AMERICANS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202535",
    },
    {
        "school": "PS 149 CHRISTA MCAULIFFE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202536",
    },
    {
        "school": "PS 151 MARY D CARTER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202544",
    },
    {
        "school": "PS 152 GWENDOLINE N ALLEYNE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202548",
    },
    {
        "school": "ACADEMY OF AMERICAN STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202562",
    },
    {
        "school": "PS 166 HENRY GRADSTEIN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202594",
    },
    {
        "school": "PS 171 PETER G VAN ALST",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202606",
    },
    {
        "school": "IS 204 OLIVER W HOLMES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202688",
    },
    {
        "school": "WILLIAM CULLEN BRYANT HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010202887",
    },
    {
        "school": "PS/IS 78",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010203123",
    },
    {
        "school": "IS 227 LOUIS ARMSTRONG",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010203146",
    },
    {
        "school": "PS 212",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010204785",
    },
    {
        "school": "IS 230",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010204802",
    },
    {
        "school": "IVAN LAFAYETTE EARLY CHILDHOOD SCHOOL OF THE ARTS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010204893",
    },
    {
        "school": "FRANK SINATRA SCHOOL OF THE ARTS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010204894",
    },
    {
        "school": "PS 150",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010205287",
    },
    {
        "school": "PS 222-FIRE FIGHTER CHRISTOPHER A SANTORA SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010205288",
    },
    {
        "school": "INFORMATION TECHNOLOGY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010205511",
    },
    {
        "school": "PS 234",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010205553",
    },
    {
        "school": "BACCALAUREATE SCHOOL FOR GLOBAL EDUCATION",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010205735",
    },
    {
        "school": "PENINSULA PREPARATORY ACADEMY CHARTER SCHOOL",
        "district": "PENINSULA PREPARATORY ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011805732",
    },
    {
        "school": "IS 250 ROBERT F KENNEDY COMMUNITY MIDDLE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012200249",
    },
    {
        "school": "ROBERT F KENNEDY COMMUNITY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012200954",
    },
    {
        "school": "FLUSHING HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012201950",
    },
    {
        "school": "IS 25 ADRIEN BLOCK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012201969",
    },
    {
        "school": "IS 237",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012201996",
    },
    {
        "school": "JOHN BOWNE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202014",
    },
    {
        "school": "PS 20 JOHN BOWNE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202105",
    },
    {
        "school": "PS 21 EDWARD HART",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202109",
    },
    {
        "school": "PS 22 THOMAS JEFFERSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202115",
    },
    {
        "school": "PS 24 ANDREW JACKSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202119",
    },
    {
        "school": "PS 29",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202136",
    },
    {
        "school": "PS 32 STATE STREET",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202148",
    },
    {
        "school": "PS 79 FRANCIS LEWIS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202314",
    },
    {
        "school": "PS 107 THOMAS A DOOLEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202402",
    },
    {
        "school": "PS 120",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202444",
    },
    {
        "school": "PS 129 PATRICIA LARKIN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202476",
    },
    {
        "school": "PS 154",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202555",
    },
    {
        "school": "PS 163 FLUSHING HEIGHTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202586",
    },
    {
        "school": "PS 164 QUEENS VALLEY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202589",
    },
    {
        "school": "PS 165 EDITH K BERGTRAUM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202592",
    },
    {
        "school": "PS 169 BAY TERRACE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202600",
    },
    {
        "school": "PS 184 FLUSHING MANOR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202637",
    },
    {
        "school": "JHS 185 EDWARD BLEEKER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202639",
    },
    {
        "school": "JHS 189 DANIEL CARTER BEARD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202650",
    },
    {
        "school": "PS 193 ALFRED J KENNEDY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202661",
    },
    {
        "school": "JHS 194 WILLIAM CARR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202664",
    },
    {
        "school": "PS/MS 200 MAGNET SCHOOL-GLOBAL STUDI",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202681",
    },
    {
        "school": "PS 201 DISCOVERY SCHOOL FOR INQUIRY AND RESEARCH (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202683",
    },
    {
        "school": "PS 209 CLEARVIEW GARDENS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202703",
    },
    {
        "school": "PS 214 CADWALLADER COLDEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202711",
    },
    {
        "school": "PS 219 PAUL KLAPPER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012202722",
    },
    {
        "school": "QUEENS COLLEGE SCHOOL FOR MATH SCIENCE & TECHNOLOGY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012204175",
    },
    {
        "school": "TOWNSEND HARRIS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012204485",
    },
    {
        "school": "PS 130",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012204610",
    },
    {
        "school": "PS 242 LEONARD P STAVISKY EARLY CHILDHOOD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012204892",
    },
    {
        "school": "FLUSHING INTERNATIONAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012205727",
    },
    {
        "school": "QUEENS SCHOOL OF INQUIRY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012205830",
    },
    {
        "school": "PS 51",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012301790",
    },
    {
        "school": "AUGUST MARTIN HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012301912",
    },
    {
        "school": "MS 53 BRIAN PICCOLO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012301972",
    },
    {
        "school": "JHS 226 VIRGIL I GRISSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012301995",
    },
    {
        "school": "JOHN ADAMS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302013",
    },
    {
        "school": "PS/MS 42 R VERNAM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302190",
    },
    {
        "school": "PS 45 CLARENCE WITHERSPOON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302198",
    },
    {
        "school": "PS 47 CHRIS GALAS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302208",
    },
    {
        "school": "PS 60 WOODHAVEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302259",
    },
    {
        "school": "PS 62 CHESTER PARK SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302265",
    },
    {
        "school": "PS 63 OLD SOUTH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302268",
    },
    {
        "school": "PS 64 JOSEPH P ADDABBO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302273",
    },
    {
        "school": "PS 66 JACQUELINE KENNEDY-ONASSIS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302278",
    },
    {
        "school": "PS 90 HORACE MANN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302345",
    },
    {
        "school": "PS 96",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302365",
    },
    {
        "school": "PS 97 FOREST PARK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302369",
    },
    {
        "school": "PS 100 GLEN MORRIS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302379",
    },
    {
        "school": "PS 104 BAYS WATER (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302392",
    },
    {
        "school": "PS 105 BAY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302395",
    },
    {
        "school": "LIGHTHOUSE ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302398",
    },
    {
        "school": "PS 108 CAPTAIN VINCENT G FOWLER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302405",
    },
    {
        "school": "PS/MS 114 BELLE HARBOR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302426",
    },
    {
        "school": "PS 123",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302454",
    },
    {
        "school": "PS 124 OSMOND A CHURCH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302460",
    },
    {
        "school": "PS 43",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302512",
    },
    {
        "school": "PS 65 RAYMOND YORK ELEMENTARY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302516",
    },
    {
        "school": "PS 146 HOWARD BEACH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302531",
    },
    {
        "school": "PS 155",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302558",
    },
    {
        "school": "PS 183 DR RICHARD R GREEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302634",
    },
    {
        "school": "PS 197 OCEAN SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302671",
    },
    {
        "school": "JHS 202 ROBERT H GODDARD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302685",
    },
    {
        "school": "PS 207 ROCKWOOD PARK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302699",
    },
    {
        "school": "JHS 210 ELIZABETH BLACKWELL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302704",
    },
    {
        "school": "PS 223 LYNDON B JOHNSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302728",
    },
    {
        "school": "PS 232 LINDENWOOD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302743",
    },
    {
        "school": "RICHMOND HILL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012302863",
    },
    {
        "school": "PS 56 HARRY EICHLER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012304352",
    },
    {
        "school": "MS 137 AMERICA'S SCHOOL OF HEROES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012305269",
    },
    {
        "school": "SCHOLARS' ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012305831",
    },
    {
        "school": "PS 9",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502070",
    },
    {
        "school": "ROBERT E PEARY SCHOOL",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502305",
    },
    {
        "school": "PS 255",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502770",
    },
    {
        "school": "PS Q811",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502843",
    },
    {
        "school": "PS 224",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502858",
    },
    {
        "school": "JOHN F KENNEDY JR SCHOOL",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502859",
    },
    {
        "school": "PS 177",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504354",
    },
    {
        "school": "PS 23 AT QUEENS CHILDREN CENTER",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504480",
    },
    {
        "school": "QUEENS TRANSITION CENTER",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504481",
    },
    {
        "school": "PS Q4",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504699",
    },
    {
        "school": "PS 233",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504781",
    },
    {
        "school": "PS 993",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013504818",
    },
    {
        "school": "MICHAEL J PETRIDES SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010301827",
    },
    {
        "school": "CURTIS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010301939",
    },
    {
        "school": "IS 7 ELIAS BERNSTEIN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010301966",
    },
    {
        "school": "IS 34 TOTTENVILLE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010301970",
    },
    {
        "school": "IS 61 WILLIAM A MORRIS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010301973",
    },
    {
        "school": "IS 72 ROCCO LAURIE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010301974",
    },
    {
        "school": "NEW DORP HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302035",
    },
    {
        "school": "PS 1 TOTTENVILLE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302044",
    },
    {
        "school": "IS 2 GEORGE L EGBERT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302046",
    },
    {
        "school": "PS 3 MARGARET GIOIOSA SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302051",
    },
    {
        "school": "PS 4 MAURICE WOLLIN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302052",
    },
    {
        "school": "PS 5 HUGUENOT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302055",
    },
    {
        "school": "IS 51 EDWIN MARKHAM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302057",
    },
    {
        "school": "PS 8 SHIRLEE SOLOMON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302062",
    },
    {
        "school": "PS 11 THOMAS DONGAN SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302075",
    },
    {
        "school": "PS 13 M L LINDEMEYER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302082",
    },
    {
        "school": "PS 16 JOHN J DRISCOLL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302090",
    },
    {
        "school": "PS 18 JOHN G WHITTIER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302097",
    },
    {
        "school": "PS 19 CURTIS SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302102",
    },
    {
        "school": "PS 20 PORT RICHMOND",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302107",
    },
    {
        "school": "PS 21 MARGARET EMERY-ELM PARK",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302110",
    },
    {
        "school": "PS 22 GRANITEVILLE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302113",
    },
    {
        "school": "PS 23 RICHMONDTOWN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302118",
    },
    {
        "school": "IS 24 MYRA S BARNES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302120",
    },
    {
        "school": "PS 26 CARTERET SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302127",
    },
    {
        "school": "IS 27 ANNING S PRALL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302130",
    },
    {
        "school": "PS 29 BARDWELL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302137",
    },
    {
        "school": "PS 30 WESTERLEIGH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302142",
    },
    {
        "school": "PS 31 WILLIAM T DAVIS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302146",
    },
    {
        "school": "PS 32 GIFFORD SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302149",
    },
    {
        "school": "PS 35 CLOVE VALLEY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302159",
    },
    {
        "school": "PS 36 J C DRUMGOOLE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302165",
    },
    {
        "school": "PS 38 GEORGE CROMWELL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302171",
    },
    {
        "school": "PS 39 FRANCIS J MURPHY JR",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302174",
    },
    {
        "school": "STEPHANIE A VIERNO SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302186",
    },
    {
        "school": "PS 42 ELTINGVILLE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302189",
    },
    {
        "school": "PS 44 THOMAS C BROWN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302196",
    },
    {
        "school": "PS 45 JOHN TYLER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302201",
    },
    {
        "school": "PS 46 ALBERT V MANISCALCO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302206",
    },
    {
        "school": "PS 48 WILLIAM G WILCOX",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302214",
    },
    {
        "school": "IS 49 BERTA A DREYFUS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302216",
    },
    {
        "school": "PS 50 FRANK HANKINSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302220",
    },
    {
        "school": "PS 52 JOHN C THOMPSON",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302229",
    },
    {
        "school": "BARBARA ESSELBORN SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302233",
    },
    {
        "school": "PS 54 CHARLES W LENG",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302234",
    },
    {
        "school": "PS 55 HENRY M BOEHM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302239",
    },
    {
        "school": "PS 57 HUBERT H HUMPHREY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302247",
    },
    {
        "school": "PS 60 ALICE AUSTEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302257",
    },
    {
        "school": "PS 69 DANIEL D TOMPKINS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302286",
    },
    {
        "school": "PORT RICHMOND HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302850",
    },
    {
        "school": "RALPH R MCKEE CAREER AND TECHNICAL EDUCATION HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360010302861",
    },
    {
        "school": "SUSAN E WAGNER HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302878",
    },
    {
        "school": "TOTTENVILLE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010302883",
    },
    {
        "school": "PS 56 LOUIS DESARIO SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010303394",
    },
    {
        "school": "STATEN ISLAND TECHNICAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010304186",
    },
    {
        "school": "IS 75 FRANK D PAULO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010304526",
    },
    {
        "school": "PS 6 CORPORAL ALLAN F KIVLEHAN SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010304816",
    },
    {
        "school": "SPACE SHUTTLE COLUMBIA SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010305548",
    },
    {
        "school": "CSI HIGH SCHOOL FOR INTERNATIONAL STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010305835",
    },
    {
        "school": "PS 373",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013500957",
    },
    {
        "school": "SOUTH RICHMOND HIGH SCHOOL IS/PS 25",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502124",
    },
    {
        "school": "DAVID MARQUIS SCHOOL OF THE ARTS (THE)",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502170",
    },
    {
        "school": "RICHARD H HUNGERFORD SCHOOL (THE)",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013502864",
    },
    {
        "school": "PS 723",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013500554",
    },
    {
        "school": "FIELDSTONE MIDDLE SCHOOL",
        "district": "HAVERSTRAW-STONY POINT CSD (NORTH ROCKLAND)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361401005738",
    },
    {
        "school": "CENTER MORICHES MIDDLE SCHOOL",
        "district": "CENTER MORICHES UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360684005570",
    },
    {
        "school": "EAST MORICHES ELEMENTARY SCHOOL",
        "district": "EAST MORICHES UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360987005745",
    },
    {
        "school": "WILLIAM FLOYD MIDDLE SCHOOL",
        "district": "WILLIAM FLOYD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361869005579",
    },
    {
        "school": "NATHANIEL WOODHULL ELEMENTARY SCHOOL",
        "district": "WILLIAM FLOYD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361869005743",
    },
    {
        "school": "WILLIAM PACA MIDDLE SCHOOL",
        "district": "WILLIAM FLOYD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361869005744",
    },
    {
        "school": "ROCKY POINT MIDDLE SCHOOL",
        "district": "ROCKY POINT UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362484005420",
    },
    {
        "school": "SACHEM HIGH SCHOOL EAST",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535005740",
    },
    {
        "school": "SAMOSET MIDDLE SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535005742",
    },
    {
        "school": "MILLS POND ELEMENTARY SCHOOL",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706005431",
    },
    {
        "school": "NESAQUAKE MIDDLE SCHOOL",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706005746",
    },
    {
        "school": "SMITHTOWN HIGH SCHOOL EAST",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706005839",
    },
    {
        "school": "ACCOMPSETT MIDDLE SCHOOL",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706005840",
    },
    {
        "school": "LA FRANCIS HARDIMAN ELEMENTARY SCHOOL",
        "district": "WYANDANCH UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363180005838",
    },
    {
        "school": "CHARTER SCHOOL OF EDUCATIONAL EXCELLENCE",
        "district": "CHARTER SCHOOL OF EDUCATIONAL EXCELLENCE",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015505844",
    },
    {
        "school": "SEVEN BRIDGES MIDDLE SCHOOL",
        "district": "CHAPPAQUA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360699005571",
    },
    {
        "school": "BLIND BROOK-RYE MIDDLE SCHOOL",
        "district": "BLIND BROOK-RYE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362463005483",
    },
    {
        "school": "CLARK ACADEMY",
        "district": "GREENBURGH-NORTH CASTLE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "362798005843",
    },
    {
        "school": "YONKERS MIDDLE SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192005591",
    },
    {
        "school": "ROOSEVELT CHILDREN'S ACADEMY CHARTER SCHOOL",
        "district": "ROOSEVELT CHILDREN'S ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360003004379",
    },
    {
        "school": "BALDWIN MIDDLE SCHOOL",
        "district": "BALDWIN UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360384000126",
    },
    {
        "school": "BALDWIN SENIOR HIGH SCHOOL",
        "district": "BALDWIN UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360384000128",
    },
    {
        "school": "BROOKSIDE ELEMENTARY SCHOOL",
        "district": "BALDWIN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360384000129",
    },
    {
        "school": "LENOX ELEMENTARY SCHOOL",
        "district": "BALDWIN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360384000132",
    },
    {
        "school": "MEADOW ELEMENTARY SCHOOL",
        "district": "BALDWIN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360384000133",
    },
    {
        "school": "PLAZA ELEMENTARY SCHOOL",
        "district": "BALDWIN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360384000135",
    },
    {
        "school": "STEELE ELEMENTARY SCHOOL",
        "district": "BALDWIN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360384000138",
    },
    {
        "school": "SHORE ROAD SCHOOL",
        "district": "BELLMORE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360441000190",
    },
    {
        "school": "WINTHROP AVENUE SCHOOL",
        "district": "BELLMORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360441000191",
    },
    {
        "school": "REINHARD EARLY CHILDHOOD CENTER",
        "district": "BELLMORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360441002841",
    },
    {
        "school": "BETHPAGE SENIOR HIGH SCHOOL",
        "district": "BETHPAGE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360474000217",
    },
    {
        "school": "CENTRAL BOULEVARD ELEMENTARY SCHOOL",
        "district": "BETHPAGE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360474000218",
    },
    {
        "school": "CHARLES CAMPAGNE SCHOOL",
        "district": "BETHPAGE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360474000219",
    },
    {
        "school": "JOHN F KENNEDY MIDDLE SCHOOL",
        "district": "BETHPAGE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360474000220",
    },
    {
        "school": "KRAMER LANE ELEMENTARY SCHOOL",
        "district": "BETHPAGE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360474000221",
    },
    {
        "school": "CARLE PLACE MIDDLE SENIOR HIGH SCHOOL",
        "district": "CARLE PLACE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360654000435",
    },
    {
        "school": "CHERRY LANE SCHOOL",
        "district": "CARLE PLACE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360654000436",
    },
    {
        "school": "RUSHMORE AVENUE SCHOOL",
        "district": "CARLE PLACE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360654000437",
    },
    {
        "school": "WEST SIDE SCHOOL",
        "district": "COLD SPRING HARBOR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360801000575",
    },
    {
        "school": "CLARKE MIDDLE SCHOOL",
        "district": "EAST MEADOW UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360984000106",
    },
    {
        "school": "BARNUM WOODS SCHOOL",
        "district": "EAST MEADOW UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360984000754",
    },
    {
        "school": "BOWLING GREEN SCHOOL",
        "district": "EAST MEADOW UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360984000755",
    },
    {
        "school": "EAST MEADOW HIGH SCHOOL",
        "district": "EAST MEADOW UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360984000756",
    },
    {
        "school": "MCVEY ELEMENTARY SCHOOL",
        "district": "EAST MEADOW UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360984000758",
    },
    {
        "school": "MEADOWBROOK ELEMENTARY SCHOOL",
        "district": "EAST MEADOW UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360984000759",
    },
    {
        "school": "PARKWAY SCHOOL",
        "district": "EAST MEADOW UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360984000760",
    },
    {
        "school": "W TRESPER CLARKE HIGH SCHOOL",
        "district": "EAST MEADOW UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360984000761",
    },
    {
        "school": "WOODLAND MIDDLE SCHOOL",
        "district": "EAST MEADOW UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360984000762",
    },
    {
        "school": "CENTRE AVENUE ELEMENTARY SCHOOL",
        "district": "EAST ROCKAWAY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360996000768",
    },
    {
        "school": "EAST ROCKAWAY JUNIOR-SENIOR HIGH SCHOOL",
        "district": "EAST ROCKAWAY UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360996000769",
    },
    {
        "school": "RHAME AVENUE ELEMENTARY SCHOOL",
        "district": "EAST ROCKAWAY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360996000770",
    },
    {
        "school": "NORTH SIDE SCHOOL",
        "district": "EAST WILLISTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361005000780",
    },
    {
        "school": "WHEATLEY SCHOOL",
        "district": "EAST WILLISTON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361005000781",
    },
    {
        "school": "WILLETS ROAD SCHOOL",
        "district": "EAST WILLISTON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361005000782",
    },
    {
        "school": "ALDEN TERRACE SCHOOL",
        "district": "ELMONT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361062000831",
    },
    {
        "school": "CLARA H CARLSON SCHOOL",
        "district": "ELMONT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361062000832",
    },
    {
        "school": "COVERT AVENUE SCHOOL",
        "district": "ELMONT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361062000833",
    },
    {
        "school": "DUTCH BROADWAY SCHOOL",
        "district": "ELMONT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361062000834",
    },
    {
        "school": "GOTHAM AVENUE SCHOOL",
        "district": "ELMONT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361062000835",
    },
    {
        "school": "STEWART MANOR SCHOOL",
        "district": "ELMONT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361062000836",
    },
    {
        "school": "ALBANY AVENUE ELEMENTARY SCHOOL",
        "district": "FARMINGDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361098000875",
    },
    {
        "school": "FARMINGDALE SENIOR HIGH SCHOOL",
        "district": "FARMINGDALE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361098000877",
    },
    {
        "school": "HOWITT SCHOOL",
        "district": "FARMINGDALE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361098000878",
    },
    {
        "school": "NORTHSIDE ELEMENTARY SCHOOL",
        "district": "FARMINGDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361098000880",
    },
    {
        "school": "WOODWARD PARKWAY ELEMENTARY SCHOOL",
        "district": "FARMINGDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361098000881",
    },
    {
        "school": "FLORAL PARK-BELLEROSE SCHOOL",
        "district": "FLORAL PARK-BELLEROSE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361116000885",
    },
    {
        "school": "JOHN LEWIS CHILDS SCHOOL",
        "district": "FLORAL PARK-BELLEROSE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361116000886",
    },
    {
        "school": "JOHN STREET SCHOOL",
        "district": "FRANKLIN SQUARE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361146000901",
    },
    {
        "school": "POLK STREET SCHOOL",
        "district": "FRANKLIN SQUARE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361146000902",
    },
    {
        "school": "WASHINGTON STREET SCHOOL",
        "district": "FRANKLIN SQUARE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361146000903",
    },
    {
        "school": "ARCHER STREET SCHOOL",
        "district": "FREEPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361155000909",
    },
    {
        "school": "BAYVIEW AVENUE SCHOOL",
        "district": "FREEPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361155000910",
    },
    {
        "school": "CAROLINE G ATKINSON SCHOOL",
        "district": "FREEPORT UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361155000911",
    },
    {
        "school": "FREEPORT HIGH SCHOOL",
        "district": "FREEPORT UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361155000914",
    },
    {
        "school": "JOHN W DODD MIDDLE SCHOOL",
        "district": "FREEPORT UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361155000915",
    },
    {
        "school": "LEO F GIBLYN SCHOOL",
        "district": "FREEPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361155000916",
    },
    {
        "school": "NEW VISIONS ELEMENTARY SCHOOL",
        "district": "FREEPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361155001636",
    },
    {
        "school": "COLUMBUS AVENUE SCHOOL",
        "district": "FREEPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361155004441",
    },
    {
        "school": "GARDEN CITY MIDDLE SCHOOL",
        "district": "GARDEN CITY UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361176000941",
    },
    {
        "school": "GARDEN CITY HIGH SCHOOL",
        "district": "GARDEN CITY UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361176000942",
    },
    {
        "school": "HOMESTEAD SCHOOL",
        "district": "GARDEN CITY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361176000944",
    },
    {
        "school": "LOCUST SCHOOL",
        "district": "GARDEN CITY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361176000945",
    },
    {
        "school": "STEWART SCHOOL",
        "district": "GARDEN CITY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361176000946",
    },
    {
        "school": "STRATFORD AVENUE SCHOOL",
        "district": "GARDEN CITY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361176000947",
    },
    {
        "school": "HEMLOCK SCHOOL",
        "district": "GARDEN CITY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361176001637",
    },
    {
        "school": "CONNOLLY SCHOOL",
        "district": "GLEN COVE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361218000972",
    },
    {
        "school": "DEASY SCHOOL",
        "district": "GLEN COVE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361218000973",
    },
    {
        "school": "GLEN COVE HIGH SCHOOL",
        "district": "GLEN COVE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361218000974",
    },
    {
        "school": "GRIBBIN SCHOOL",
        "district": "GLEN COVE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361218000975",
    },
    {
        "school": "LANDING SCHOOL",
        "district": "GLEN COVE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361218000976",
    },
    {
        "school": "ROBERT M FINLEY MIDDLE SCHOOL",
        "district": "GLEN COVE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361218000977",
    },
    {
        "school": "E M BAKER SCHOOL",
        "district": "GREAT NECK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361251001013",
    },
    {
        "school": "GREAT NECK NORTH MIDDLE SCHOOL",
        "district": "GREAT NECK UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361251001015",
    },
    {
        "school": "GREAT NECK NORTH HIGH SCHOOL",
        "district": "GREAT NECK UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361251001016",
    },
    {
        "school": "GREAT NECK SOUTH MIDDLE SCHOOL",
        "district": "GREAT NECK UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361251001017",
    },
    {
        "school": "GREAT NECK SOUTH HIGH SCHOOL",
        "district": "GREAT NECK UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361251001018",
    },
    {
        "school": "JOHN F KENNEDY SCHOOL",
        "district": "GREAT NECK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361251001019",
    },
    {
        "school": "LAKEVILLE ELEMENTARY SCHOOL",
        "district": "GREAT NECK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361251001021",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "GREAT NECK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361251001022",
    },
    {
        "school": "SADDLE ROCK SCHOOL",
        "district": "GREAT NECK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361251001023",
    },
    {
        "school": "VILLAGE SCHOOL",
        "district": "GREAT NECK UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "361251002027",
    },
    {
        "school": "JOSEPH MCNEIL SCHOOL",
        "district": "HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361413001150",
    },
    {
        "school": "DAVID PATERSON SCHOOL",
        "district": "HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361413001151",
    },
    {
        "school": "HEMPSTEAD HIGH SCHOOL",
        "district": "HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361413001152",
    },
    {
        "school": "ALVERTA B GRAY SCHULTZ MIDDLE SCHOOL",
        "district": "HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361413001153",
    },
    {
        "school": "JACKSON MAIN ELEMENTARY SCHOOL",
        "district": "HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361413001155",
    },
    {
        "school": "BARACK OBAMA ELEMENTARY SCHOOL",
        "district": "HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361413001156",
    },
    {
        "school": "JACKSON ANNEX SCHOOL",
        "district": "HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361413004591",
    },
    {
        "school": "FRONT STREET ELEMENTARY SCHOOL",
        "district": "HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361413004772",
    },
    {
        "school": "CENTER STREET SCHOOL",
        "district": "HERRICKS UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361428001174",
    },
    {
        "school": "DENTON AVENUE SCHOOL",
        "district": "HERRICKS UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361428001175",
    },
    {
        "school": "HERRICKS HIGH SCHOOL",
        "district": "HERRICKS UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361428001177",
    },
    {
        "school": "SEARINGTOWN SCHOOL",
        "district": "HERRICKS UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361428001178",
    },
    {
        "school": "HERRICKS MIDDLE SCHOOL",
        "district": "HERRICKS UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361428001179",
    },
    {
        "school": "BURNS AVENUE SCHOOL",
        "district": "HICKSVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361434001181",
    },
    {
        "school": "DUTCH LANE SCHOOL",
        "district": "HICKSVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361434001182",
    },
    {
        "school": "FORK LANE SCHOOL",
        "district": "HICKSVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361434001184",
    },
    {
        "school": "HICKSVILLE HIGH SCHOOL",
        "district": "HICKSVILLE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361434001185",
    },
    {
        "school": "HICKSVILLE MIDDLE SCHOOL",
        "district": "HICKSVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361434001186",
    },
    {
        "school": "LEE AVENUE SCHOOL",
        "district": "HICKSVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361434001187",
    },
    {
        "school": "OLD COUNTRY ROAD SCHOOL",
        "district": "HICKSVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361434001188",
    },
    {
        "school": "WOODLAND AVENUE SCHOOL",
        "district": "HICKSVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361434001190",
    },
    {
        "school": "EAST STREET SCHOOL",
        "district": "HICKSVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361434003309",
    },
    {
        "school": "FRANCIS X HEGARTY ELEMENTARY SCHOOL",
        "district": "ISLAND PARK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361548001316",
    },
    {
        "school": "ISLAND PARK LINCOLN ORENS MIDDLE SCHOOL",
        "district": "ISLAND PARK UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361548001317",
    },
    {
        "school": "ISLAND TREES MIDDLE SCHOOL",
        "district": "ISLAND TREES UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361551001319",
    },
    {
        "school": "ISLAND TREES HIGH SCHOOL",
        "district": "ISLAND TREES UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361551001320",
    },
    {
        "school": "J FRED SPARKE SCHOOL",
        "district": "ISLAND TREES UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361551001321",
    },
    {
        "school": "MICHAEL F STOKES SCHOOL",
        "district": "ISLAND TREES UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361551001322",
    },
    {
        "school": "CANTIAGUE ELEMENTARY SCHOOL",
        "district": "JERICHO UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361581001367",
    },
    {
        "school": "GEORGE A JACKSON SCHOOL",
        "district": "JERICHO UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361581001368",
    },
    {
        "school": "JERICHO MIDDLE SCHOOL",
        "district": "JERICHO UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361581001369",
    },
    {
        "school": "JERICHO SENIOR HIGH SCHOOL",
        "district": "JERICHO UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361581001370",
    },
    {
        "school": "ROBERT SEAMAN ELEMENTARY SCHOOL",
        "district": "JERICHO UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361581002040",
    },
    {
        "school": "LAWRENCE PRIMARY SCHOOL AT #2 SCHOOL",
        "district": "LAWRENCE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361683001500",
    },
    {
        "school": "LAWRENCE EARLY CHILDHOOD CENTER AT #4 SCHOOL",
        "district": "LAWRENCE UNION FREE SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361683001501",
    },
    {
        "school": "LAWRENCE ELEMENTARY SCHOOL AT BROADWAY CAMPUS",
        "district": "LAWRENCE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361683001502",
    },
    {
        "school": "LAWRENCE MIDDLE SCHOOL AT BROADWAY CAMPUS",
        "district": "LAWRENCE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361683001504",
    },
    {
        "school": "LAWRENCE SENIOR HIGH SCHOOL",
        "district": "LAWRENCE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361683001505",
    },
    {
        "school": "ABBEY LANE SCHOOL",
        "district": "LEVITTOWN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361716001518",
    },
    {
        "school": "DIVISION AVENUE SENIOR HIGH SCHOOL",
        "district": "LEVITTOWN UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361716001520",
    },
    {
        "school": "GARDINERS AVENUE SCHOOL",
        "district": "LEVITTOWN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361716001522",
    },
    {
        "school": "GEN DOUGLAS MACARTHUR SENIOR HIGH SCHOOL",
        "district": "LEVITTOWN UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361716001523",
    },
    {
        "school": "JONAS E SALK MIDDLE SCHOOL",
        "district": "LEVITTOWN UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361716001524",
    },
    {
        "school": "LEE ROAD SCHOOL",
        "district": "LEVITTOWN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361716001526",
    },
    {
        "school": "NORTHSIDE SCHOOL",
        "district": "LEVITTOWN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361716001529",
    },
    {
        "school": "SUMMIT LANE SCHOOL",
        "district": "LEVITTOWN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361716001531",
    },
    {
        "school": "WISDOM LANE MIDDLE SCHOOL",
        "district": "LEVITTOWN UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361716001532",
    },
    {
        "school": "EAST BROADWAY SCHOOL",
        "district": "LEVITTOWN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361716002839",
    },
    {
        "school": "BAYVILLE PRIMARY",
        "district": "LOCUST VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361770001590",
    },
    {
        "school": "ANN MACARTHUR PRIMARY",
        "district": "LOCUST VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361770001591",
    },
    {
        "school": "LOCUST VALLEY HIGH SCHOOL",
        "district": "LOCUST VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361770001592",
    },
    {
        "school": "LOCUST VALLEY MIDDLE SCHOOL",
        "district": "LOCUST VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361770001664",
    },
    {
        "school": "EAST ELEMENTARY SCHOOL",
        "district": "LONG BEACH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361773001595",
    },
    {
        "school": "LIDO ELEMENTARY SCHOOL",
        "district": "LONG BEACH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361773001596",
    },
    {
        "school": "LINDELL BOULEVARD SCHOOL",
        "district": "LONG BEACH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361773001597",
    },
    {
        "school": "LONG BEACH MIDDLE SCHOOL",
        "district": "LONG BEACH CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361773001598",
    },
    {
        "school": "LONG BEACH HIGH SCHOOL",
        "district": "LONG BEACH CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361773001599",
    },
    {
        "school": "WEST ELEMENTARY SCHOOL",
        "district": "LONG BEACH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361773001600",
    },
    {
        "school": "LYNBROOK NORTH MIDDLE SCHOOL",
        "district": "LYNBROOK UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361791001605",
    },
    {
        "school": "LYNBROOK SENIOR HIGH SCHOOL",
        "district": "LYNBROOK UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361791001606",
    },
    {
        "school": "LYNBROOK SOUTH MIDDLE SCHOOL",
        "district": "LYNBROOK UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361791001607",
    },
    {
        "school": "MARION STREET SCHOOL",
        "district": "LYNBROOK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361791001608",
    },
    {
        "school": "WAVERLY PARK SCHOOL",
        "district": "LYNBROOK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361791001609",
    },
    {
        "school": "WEST END SCHOOL",
        "district": "LYNBROOK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361791001610",
    },
    {
        "school": "KINDERGARTEN CENTER",
        "district": "LYNBROOK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361791001657",
    },
    {
        "school": "DAVISON AVENUE INTERMEDIATE SCHOOL",
        "district": "MALVERNE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361821001640",
    },
    {
        "school": "HOWARD T HERBER MIDDLE SCHOOL",
        "district": "MALVERNE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361821001641",
    },
    {
        "school": "MAURICE W DOWNING PRIMARY SCHOOL",
        "district": "MALVERNE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361821001642",
    },
    {
        "school": "MALVERNE SENIOR HIGH SCHOOL",
        "district": "MALVERNE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361821001643",
    },
    {
        "school": "MANHASSET MIDDLE SCHOOL",
        "district": "MANHASSET UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361827000112",
    },
    {
        "school": "MANHASSET SECONDARY SCHOOL",
        "district": "MANHASSET UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361827001650",
    },
    {
        "school": "MUNSEY PARK ELEMENTARY SCHOOL",
        "district": "MANHASSET UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361827001651",
    },
    {
        "school": "SHELTER ROCK ELEMENTARY SCHOOL",
        "district": "MANHASSET UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361827001652",
    },
    {
        "school": "MCKENNA ELEMENTARY SCHOOL",
        "district": "MASSAPEQUA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361863000131",
    },
    {
        "school": "BERNER MIDDLE SCHOOL",
        "district": "MASSAPEQUA UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361863001682",
    },
    {
        "school": "BIRCH LANE ELEMENTARY SCHOOL",
        "district": "MASSAPEQUA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361863001683",
    },
    {
        "school": "EAST LAKE ELEMENTARY SCHOOL",
        "district": "MASSAPEQUA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361863001684",
    },
    {
        "school": "FAIRFIELD ELEMENTARY SCHOOL",
        "district": "MASSAPEQUA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361863001685",
    },
    {
        "school": "LOCKHART ELEMENTARY SCHOOL",
        "district": "MASSAPEQUA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361863001687",
    },
    {
        "school": "MASSAPEQUA HIGH SCHOOL",
        "district": "MASSAPEQUA UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361863001688",
    },
    {
        "school": "UNQUA ELEMENTARY SCHOOL",
        "district": "MASSAPEQUA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361863001690",
    },
    {
        "school": "MHS AMES CAMPUS",
        "district": "MASSAPEQUA UNION FREE SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361863003506",
    },
    {
        "school": "SANFORD H CALHOUN HIGH SCHOOL",
        "district": "BELLMORE-MERRICK CENTRAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361902001721",
    },
    {
        "school": "GRAND AVENUE MIDDLE SCHOOL",
        "district": "BELLMORE-MERRICK CENTRAL HIGH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361902001722",
    },
    {
        "school": "JOHN F KENNEDY HIGH SCHOOL",
        "district": "BELLMORE-MERRICK CENTRAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361902001724",
    },
    {
        "school": "WELLINGTON C MEPHAM HIGH SCHOOL",
        "district": "BELLMORE-MERRICK CENTRAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361902001725",
    },
    {
        "school": "MERRICK AVENUE MIDDLE SCHOOL",
        "district": "BELLMORE-MERRICK CENTRAL HIGH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361902001726",
    },
    {
        "school": "BIRCH SCHOOL",
        "district": "MERRICK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361911001727",
    },
    {
        "school": "CHATTERTON SCHOOL",
        "district": "MERRICK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361911001728",
    },
    {
        "school": "NORMAN J LEVY LAKESIDE SCHOOL",
        "district": "MERRICK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361911001729",
    },
    {
        "school": "HAMPTON STREET SCHOOL",
        "district": "MINEOLA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361950001777",
    },
    {
        "school": "JACKSON AVENUE SCHOOL",
        "district": "MINEOLA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361950001778",
    },
    {
        "school": "MEADOW DRIVE SCHOOL",
        "district": "MINEOLA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361950001779",
    },
    {
        "school": "MINEOLA HIGH SCHOOL",
        "district": "MINEOLA UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361950001780",
    },
    {
        "school": "MINEOLA MIDDLE SCHOOL",
        "district": "MINEOLA UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361950001781",
    },
    {
        "school": "GARDEN CITY PARK SCHOOL",
        "district": "NEW HYDE PARK-GARDEN CITY PARK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362040001882",
    },
    {
        "school": "HILLSIDE GRADE SCHOOL",
        "district": "NEW HYDE PARK-GARDEN CITY PARK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362040001883",
    },
    {
        "school": "MANOR OAKS WILLIAM BOWIE SCHOOL",
        "district": "NEW HYDE PARK-GARDEN CITY PARK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362040001884",
    },
    {
        "school": "NEW HYDE PARK ROAD SCHOOL",
        "district": "NEW HYDE PARK-GARDEN CITY PARK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362040001885",
    },
    {
        "school": "JOHN G DINKELMEYER SCHOOL",
        "district": "NORTH BELLMORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362094002973",
    },
    {
        "school": "NEWBRIDGE ROAD SCHOOL",
        "district": "NORTH BELLMORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362094002974",
    },
    {
        "school": "PARK AVENUE SCHOOL",
        "district": "NORTH BELLMORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362094002975",
    },
    {
        "school": "SAW MILL ROAD SCHOOL",
        "district": "NORTH BELLMORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362094002976",
    },
    {
        "school": "MARTIN AVENUE ELEMENTARY SCHOOL",
        "district": "NORTH BELLMORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362094004866",
    },
    {
        "school": "CAMP AVENUE SCHOOL",
        "district": "NORTH MERRICK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362112002988",
    },
    {
        "school": "HAROLD D FAYETTE SCHOOL",
        "district": "NORTH MERRICK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362112002989",
    },
    {
        "school": "OLD MILL ROAD SCHOOL",
        "district": "NORTH MERRICK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362112002990",
    },
    {
        "school": "SCHOOL 6-KINDERGARTEN CENTER",
        "district": "OCEANSIDE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362157002021",
    },
    {
        "school": "SCHOOL 9E-BOARDMAN ELEM SCHOOL",
        "district": "OCEANSIDE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362157003057",
    },
    {
        "school": "SCHOOL 7-OCEANSIDE SENIOR HIGH SCHOOL",
        "district": "OCEANSIDE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362157003059",
    },
    {
        "school": "SCHOOL 2",
        "district": "OCEANSIDE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362157003060",
    },
    {
        "school": "SCHOOL 3",
        "district": "OCEANSIDE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362157003061",
    },
    {
        "school": "SCHOOL 5",
        "district": "OCEANSIDE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362157003062",
    },
    {
        "school": "SCHOOL 8",
        "district": "OCEANSIDE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362157003064",
    },
    {
        "school": "SCHOOL 4",
        "district": "OCEANSIDE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362157004527",
    },
    {
        "school": "SCHOOL 9M-OCEANSIDE MIDDLE SCHOOL",
        "district": "OCEANSIDE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362157004528",
    },
    {
        "school": "OYSTER BAY HIGH SCHOOL",
        "district": "OYSTER BAY-EAST NORWICH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362229003147",
    },
    {
        "school": "THEODORE ROOSEVELT SCHOOL",
        "district": "OYSTER BAY-EAST NORWICH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362229003148",
    },
    {
        "school": "VERNON SCHOOL",
        "district": "OYSTER BAY-EAST NORWICH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362229003149",
    },
    {
        "school": "CHARLES E SCHWARTING SCHOOL",
        "district": "PLAINEDGE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362319003244",
    },
    {
        "school": "EASTPLAIN SCHOOL",
        "district": "PLAINEDGE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362319003245",
    },
    {
        "school": "JOHN H WEST SCHOOL",
        "district": "PLAINEDGE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362319003246",
    },
    {
        "school": "PLAINEDGE SENIOR HIGH SCHOOL",
        "district": "PLAINEDGE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362319003248",
    },
    {
        "school": "STRATFORD ROAD SCHOOL",
        "district": "PLAINVIEW-OLD BETHPAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362322000508",
    },
    {
        "school": "H B MATTLIN MIDDLE SCHOOL",
        "district": "PLAINVIEW-OLD BETHPAGE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362322003250",
    },
    {
        "school": "OLD BETHPAGE SCHOOL",
        "district": "PLAINVIEW-OLD BETHPAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362322003253",
    },
    {
        "school": "JUDY JACOBS PARKWAY ELEMENTARY SCHOOL",
        "district": "PLAINVIEW-OLD BETHPAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362322003254",
    },
    {
        "school": "PLAINVIEW-OLD BETHPAGE/JFK HIGH SCHOOL",
        "district": "PLAINVIEW-OLD BETHPAGE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362322003256",
    },
    {
        "school": "PLAINVIEW-OLD BETHPAGE MIDDLE SCHOOL",
        "district": "PLAINVIEW-OLD BETHPAGE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362322003257",
    },
    {
        "school": "PASADENA ELEMENTARY SCHOOL",
        "district": "PLAINVIEW-OLD BETHPAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362322004381",
    },
    {
        "school": "CARRIE PALMER WEBER MIDDLE SCHOOL",
        "district": "PORT WASHINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362358003288",
    },
    {
        "school": "GUGGENHEIM ELEMENTARY SCHOOL",
        "district": "PORT WASHINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362358003290",
    },
    {
        "school": "JOHN J DALY ELEMENTARY SCHOOL",
        "district": "PORT WASHINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362358003291",
    },
    {
        "school": "JOHN PHILIP SOUSA ELEMENTARY SCHOOL",
        "district": "PORT WASHINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362358003292",
    },
    {
        "school": "MANORHAVEN ELEMENTARY SCHOOL",
        "district": "PORT WASHINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362358003294",
    },
    {
        "school": "PAUL D SCHREIBER SENIOR HIGH SCHOOL",
        "district": "PORT WASHINGTON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362358003295",
    },
    {
        "school": "HEWITT SCHOOL",
        "district": "ROCKVILLE CENTRE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362478003427",
    },
    {
        "school": "RIVERSIDE SCHOOL",
        "district": "ROCKVILLE CENTRE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362478003429",
    },
    {
        "school": "SOUTH SIDE MIDDLE SCHOOL",
        "district": "ROCKVILLE CENTRE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362478003430",
    },
    {
        "school": "SOUTH SIDE HIGH SCHOOL",
        "district": "ROCKVILLE CENTRE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362478003431",
    },
    {
        "school": "WATSON SCHOOL",
        "district": "ROCKVILLE CENTRE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362478003432",
    },
    {
        "school": "WILSON SCHOOL",
        "district": "ROCKVILLE CENTRE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362478003433",
    },
    {
        "school": "WILLIAM S COVERT SCHOOL",
        "district": "ROCKVILLE CENTRE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362478003434",
    },
    {
        "school": "CENTENNIAL AVENUE ELEMENTARY SCHOOL",
        "district": "ROOSEVELT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362499003460",
    },
    {
        "school": "ROOSEVELT HIGH SCHOOL",
        "district": "ROOSEVELT UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362499003463",
    },
    {
        "school": "ULYSSES BYAS ELEMENTARY SCHOOL",
        "district": "ROOSEVELT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362499003464",
    },
    {
        "school": "WASHINGTON ROSE SCHOOL",
        "district": "ROOSEVELT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362499003465",
    },
    {
        "school": "EAST HILLS ELEMENTARY SCHOOL",
        "district": "ROSLYN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362505003467",
    },
    {
        "school": "HARBOR HILL SCHOOL",
        "district": "ROSLYN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362505003469",
    },
    {
        "school": "ROSLYN HIGH SCHOOL",
        "district": "ROSLYN UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362505003470",
    },
    {
        "school": "ROSLYN HEIGHTS ELEMENTARY SCHOOL",
        "district": "ROSLYN UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362505003471",
    },
    {
        "school": "ROSLYN MIDDLE SCHOOL",
        "district": "ROSLYN UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362505003472",
    },
    {
        "school": "GLEN HEAD ELEMENTARY SCHOOL",
        "district": "NORTH SHORE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362637003611",
    },
    {
        "school": "GLENWOOD LANDING ELEMENTARY SCHOOL",
        "district": "NORTH SHORE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362637003612",
    },
    {
        "school": "NORTH SHORE MIDDLE SCHOOL",
        "district": "NORTH SHORE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362637003613",
    },
    {
        "school": "NORTH SHORE SENIOR HIGH SCHOOL",
        "district": "NORTH SHORE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362637003614",
    },
    {
        "school": "SEA CLIFF ELEMENTARY SCHOOL",
        "district": "NORTH SHORE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362637003615",
    },
    {
        "school": "SEAFORD HARBOR SCHOOL",
        "district": "SEAFORD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362640003617",
    },
    {
        "school": "SEAFORD MIDDLE SCHOOL",
        "district": "SEAFORD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362640003618",
    },
    {
        "school": "SEAFORD MANOR SCHOOL",
        "district": "SEAFORD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362640003619",
    },
    {
        "school": "SEAFORD SENIOR HIGH SCHOOL",
        "district": "SEAFORD UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362640003620",
    },
    {
        "school": "ELMONT MEMORIAL HIGH SCHOOL",
        "district": "SEWANHAKA CENTRAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362652003626",
    },
    {
        "school": "FLORAL PARK MEMORIAL HIGH SCHOOL",
        "district": "SEWANHAKA CENTRAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362652003627",
    },
    {
        "school": "H FRANK CAREY HIGH SCHOOL",
        "district": "SEWANHAKA CENTRAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362652003628",
    },
    {
        "school": "NEW HYDE PARK MEMORIAL HIGH SCHOOL",
        "district": "SEWANHAKA CENTRAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362652003629",
    },
    {
        "school": "SEWANHAKA HIGH SCHOOL",
        "district": "SEWANHAKA CENTRAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362652003630",
    },
    {
        "school": "WILLITS ELEMENTARY SCHOOL",
        "district": "SYOSSET CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362856003835",
    },
    {
        "school": "BAYLIS ELEMENTARY SCHOOL",
        "district": "SYOSSET CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362856003836",
    },
    {
        "school": "BERRY HILL ELEMENTARY SCHOOL",
        "district": "SYOSSET CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362856003837",
    },
    {
        "school": "H B THOMPSON MIDDLE SCHOOL",
        "district": "SYOSSET CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362856003838",
    },
    {
        "school": "ROBBINS LANE ELEMENTARY SCHOOL",
        "district": "SYOSSET CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362856003839",
    },
    {
        "school": "SOUTH GROVE ELEMENTARY SCHOOL",
        "district": "SYOSSET CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362856003840",
    },
    {
        "school": "SOUTH WOODS MIDDLE SCHOOL",
        "district": "SYOSSET CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362856003841",
    },
    {
        "school": "SYOSSET SENIOR HIGH SCHOOL",
        "district": "SYOSSET CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362856003843",
    },
    {
        "school": "VILLAGE ELEMENTARY SCHOOL",
        "district": "SYOSSET CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362856003844",
    },
    {
        "school": "WALT WHITMAN ELEMENTARY SCHOOL",
        "district": "SYOSSET CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362856003845",
    },
    {
        "school": "CALIFORNIA AVENUE ELEMENTARY SCHOOL",
        "district": "UNIONDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362928003938",
    },
    {
        "school": "GRAND AVENUE ELEMENTARY SCHOOL",
        "district": "UNIONDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362928003939",
    },
    {
        "school": "LAWRENCE ROAD MIDDLE SCHOOL",
        "district": "UNIONDALE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362928003940",
    },
    {
        "school": "NORTHERN PARKWAY ELEMENTARY SCHOOL",
        "district": "UNIONDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362928003941",
    },
    {
        "school": "SMITH STREET ELEMENTARY SCHOOL",
        "district": "UNIONDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362928003942",
    },
    {
        "school": "TURTLE HOOK MIDDLE SCHOOL",
        "district": "UNIONDALE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362928003943",
    },
    {
        "school": "UNIONDALE HIGH SCHOOL",
        "district": "UNIONDALE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362928003944",
    },
    {
        "school": "WALNUT STREET ELEMENTARY SCHOOL",
        "district": "UNIONDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362928003945",
    },
    {
        "school": "HOWELL ROAD SCHOOL",
        "district": "VALLEY STREAM 13 UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362943003969",
    },
    {
        "school": "JAMES A DEVER SCHOOL",
        "district": "VALLEY STREAM 13 UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362943003970",
    },
    {
        "school": "WHEELER AVENUE SCHOOL",
        "district": "VALLEY STREAM 13 UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362943003971",
    },
    {
        "school": "WILLOW ROAD SCHOOL",
        "district": "VALLEY STREAM 13 UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362943003972",
    },
    {
        "school": "BROOKLYN AVENUE SCHOOL",
        "district": "VALLEY STREAM 24 UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362946003973",
    },
    {
        "school": "ROBERT W CARBONARO SCHOOL",
        "district": "VALLEY STREAM 24 UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362946003974",
    },
    {
        "school": "WILLIAM L BUCK SCHOOL",
        "district": "VALLEY STREAM 24 UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362946003976",
    },
    {
        "school": "CLEARSTREAM AVENUE SCHOOL",
        "district": "VALLEY STREAM 30 UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362949003977",
    },
    {
        "school": "FOREST ROAD SCHOOL",
        "district": "VALLEY STREAM 30 UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362949003978",
    },
    {
        "school": "SHAW AVENUE SCHOOL",
        "district": "VALLEY STREAM 30 UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362949003979",
    },
    {
        "school": "VALLEY STREAM CENTRAL HIGH SCHOOL",
        "district": "VALLEY STREAM CENTRAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362952003980",
    },
    {
        "school": "VALLEY STREAM MEMORIAL JUNIOR HIGH SCHOOL",
        "district": "VALLEY STREAM CENTRAL HIGH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362952003981",
    },
    {
        "school": "VALLEY STREAM NORTH HIGH SCHOOL",
        "district": "VALLEY STREAM CENTRAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362952003982",
    },
    {
        "school": "VALLEY STREAM SOUTH HIGH SCHOOL",
        "district": "VALLEY STREAM CENTRAL HIGH SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362952003983",
    },
    {
        "school": "FOREST LAKE SCHOOL",
        "district": "WANTAGH UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362985004007",
    },
    {
        "school": "MANDALAY SCHOOL",
        "district": "WANTAGH UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362985004008",
    },
    {
        "school": "WANTAGH MIDDLE SCHOOL",
        "district": "WANTAGH UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362985004010",
    },
    {
        "school": "WANTAGH SENIOR HIGH SCHOOL",
        "district": "WANTAGH UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362985004011",
    },
    {
        "school": "WANTAGH SCHOOL",
        "district": "WANTAGH UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362985004012",
    },
    {
        "school": "WEST HEMPSTEAD MIDDLE SCHOOL",
        "district": "WEST HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363066000501",
    },
    {
        "school": "CORNWELL AVENUE SCHOOL",
        "district": "WEST HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363066004121",
    },
    {
        "school": "GEORGE WASHINGTON SCHOOL",
        "district": "WEST HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363066004122",
    },
    {
        "school": "WEST HEMPSTEAD HIGH SCHOOL",
        "district": "WEST HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363066004124",
    },
    {
        "school": "CHESTNUT STREET SCHOOL",
        "district": "WEST HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363066004867",
    },
    {
        "school": "DRYDEN STREET SCHOOL",
        "district": "WESTBURY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363096002842",
    },
    {
        "school": "DREXEL AVENUE SCHOOL",
        "district": "WESTBURY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363096004157",
    },
    {
        "school": "PARK AVENUE SCHOOL",
        "district": "WESTBURY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363096004159",
    },
    {
        "school": "POWELLS LANE SCHOOL",
        "district": "WESTBURY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363096004160",
    },
    {
        "school": "WESTBURY MIDDLE SCHOOL",
        "district": "WESTBURY UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363096004161",
    },
    {
        "school": "WESTBURY HIGH SCHOOL",
        "district": "WESTBURY UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363096004162",
    },
    {
        "school": "FRANKLIN EARLY CHILDHOOD CENTER",
        "district": "HEWLETT-WOODMERE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363171004226",
    },
    {
        "school": "GEORGE W HEWLETT HIGH SCHOOL",
        "district": "HEWLETT-WOODMERE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363171004227",
    },
    {
        "school": "HEWLETT ELEMENTARY SCHOOL",
        "district": "HEWLETT-WOODMERE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363171004228",
    },
    {
        "school": "OGDEN ELEMENTARY SCHOOL",
        "district": "HEWLETT-WOODMERE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363171004229",
    },
    {
        "school": "WOODMERE MIDDLE SCHOOL",
        "district": "HEWLETT-WOODMERE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363171004230",
    },
    {
        "school": "NASSAU BOCES",
        "district": "NASSAU BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368054004643",
    },
    {
        "school": "BELLPORT MIDDLE SCHOOL",
        "district": "SOUTH COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000800192",
    },
    {
        "school": "BELLPORT SENIOR HIGH SCHOOL",
        "district": "SOUTH COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000800193",
    },
    {
        "school": "BROOKHAVEN ELEMENTARY SCHOOL",
        "district": "SOUTH COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000800194",
    },
    {
        "school": "FRANK P LONG INTERMEDIATE SCHOOL",
        "district": "SOUTH COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000800195",
    },
    {
        "school": "KREAMER STREET ELEMENTARY SCHOOL",
        "district": "SOUTH COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000800196",
    },
    {
        "school": "VERNE W CRITZ ELEMENTARY SCHOOL",
        "district": "SOUTH COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000800197",
    },
    {
        "school": "MATTITUCK JUNIOR-SENIOR HIGH SCHOOL",
        "district": "MATTITUCK-CUTCHOGUE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002101704",
    },
    {
        "school": "MATTITUCK-CUTCHOGUE ELEMENTARY SCHOOL",
        "district": "MATTITUCK-CUTCHOGUE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002101705",
    },
    {
        "school": "RIVERHEAD CHARTER SCHOOL",
        "district": "RIVERHEAD CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360006004847",
    },
    {
        "school": "AMAGANSETT SCHOOL",
        "district": "AMAGANSETT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360288000059",
    },
    {
        "school": "EDMUND W MILES MIDDLE SCHOOL",
        "district": "AMITYVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360294000062",
    },
    {
        "school": "AMITYVILLE MEMORIAL HIGH SCHOOL",
        "district": "AMITYVILLE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360294000063",
    },
    {
        "school": "NORTHEAST SCHOOL",
        "district": "AMITYVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360294000064",
    },
    {
        "school": "NORTHWEST ELEMENTARY SCHOOL",
        "district": "AMITYVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360294000065",
    },
    {
        "school": "PARK AVENUE SCHOOL",
        "district": "AMITYVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360294000066",
    },
    {
        "school": "BABYLON ELEMENTARY SCHOOL",
        "district": "BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360372000120",
    },
    {
        "school": "BABYLON JUNIOR-SENIOR HIGH SCHOOL",
        "district": "BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360372000121",
    },
    {
        "school": "BABYLON MEMORIAL GRADE SCHOOL",
        "district": "BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360372000122",
    },
    {
        "school": "BAY SHORE MIDDLE SCHOOL",
        "district": "BAY SHORE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360408000165",
    },
    {
        "school": "BAY SHORE SENIOR HIGH SCHOOL",
        "district": "BAY SHORE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360408000166",
    },
    {
        "school": "BROOK AVENUE ELEMENTARY SCHOOL",
        "district": "BAY SHORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360408000167",
    },
    {
        "school": "FIFTH AVENUE SCHOOL",
        "district": "BAY SHORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360408000168",
    },
    {
        "school": "GARDINER MANOR SCHOOL",
        "district": "BAY SHORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360408000169",
    },
    {
        "school": "MARY G CLARKSON SCHOOL",
        "district": "BAY SHORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360408000170",
    },
    {
        "school": "SOUTH COUNTRY SCHOOL",
        "district": "BAY SHORE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360408000171",
    },
    {
        "school": "ACADEMY STREET ELEMENTARY SCHOOL",
        "district": "BAYPORT-BLUE POINT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360411000172",
    },
    {
        "school": "BAYPORT-BLUE POINT HIGH SCHOOL",
        "district": "BAYPORT-BLUE POINT UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360411000173",
    },
    {
        "school": "BLUE POINT ELEMENTARY SCHOOL",
        "district": "BAYPORT-BLUE POINT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360411000174",
    },
    {
        "school": "JAMES WILSON YOUNG MIDDLE SCHOOL",
        "district": "BAYPORT-BLUE POINT UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360411000175",
    },
    {
        "school": "SYLVAN AVENUE ELEMENTARY SCHOOL",
        "district": "BAYPORT-BLUE POINT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360411000176",
    },
    {
        "school": "EAST MIDDLE SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000248",
    },
    {
        "school": "HEMLOCK ELEMENTARY SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000250",
    },
    {
        "school": "LAUREL PARK ELEMENTARY SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000251",
    },
    {
        "school": "LORETTA PARK ELEMENTARY SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000252",
    },
    {
        "school": "NORTH ELEMENTARY SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000253",
    },
    {
        "school": "NORTH MIDDLE SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000254",
    },
    {
        "school": "NORTHEAST ELEMENTARY SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000255",
    },
    {
        "school": "OAK PARK ELEMENTARY SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000256",
    },
    {
        "school": "PINE PARK ELEMENTARY SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000257",
    },
    {
        "school": "SOUTH MIDDLE SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000258",
    },
    {
        "school": "SOUTHEAST ELEMENTARY SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000259",
    },
    {
        "school": "SOUTHWEST ELEMENTARY SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000260",
    },
    {
        "school": "TWIN PINES ELEMENTARY SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000261",
    },
    {
        "school": "WEST MIDDLE SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528000263",
    },
    {
        "school": "EAST ELEMENTARY SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528004432",
    },
    {
        "school": "BRENTWOOD HIGH SCHOOL",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528004433",
    },
    {
        "school": "FRESHMAN CENTER",
        "district": "BRENTWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360528004829",
    },
    {
        "school": "BRIDGEHAMPTON SCHOOL",
        "district": "BRIDGEHAMPTON UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360537000271",
    },
    {
        "school": "CLAYTON HUEY ELEMENTARY SCHOOL",
        "district": "CENTER MORICHES UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360684000469",
    },
    {
        "school": "CENTER MORICHES HIGH SCHOOL",
        "district": "CENTER MORICHES UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360684000470",
    },
    {
        "school": "ANDREW T MORROW SCHOOL",
        "district": "CENTRAL ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360687000471",
    },
    {
        "school": "CENTRAL ISLIP SENIOR HIGH SCHOOL",
        "district": "CENTRAL ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360687000473",
    },
    {
        "school": "CHARLES A MULLIGAN ELEMENTARY SCHOOL",
        "district": "CENTRAL ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360687000474",
    },
    {
        "school": "FRANCIS J O'NEILL SCHOOL",
        "district": "CENTRAL ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360687000476",
    },
    {
        "school": "MARGUERITE L MULVEY SCHOOL",
        "district": "CENTRAL ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360687000477",
    },
    {
        "school": "RALPH REED SCHOOL",
        "district": "CENTRAL ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360687000478",
    },
    {
        "school": "ANTHONY ALFANO ELEMENTARY SCHOOL",
        "district": "CENTRAL ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360687001061",
    },
    {
        "school": "CORDELLO AVENUE ELEMENTARY SCHOOL",
        "district": "CENTRAL ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360687004253",
    },
    {
        "school": "COLD SPRING HARBOR HIGH SCHOOL",
        "district": "COLD SPRING HARBOR CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360801000573",
    },
    {
        "school": "LLOYD HARBOR SCHOOL",
        "district": "COLD SPRING HARBOR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360801000574",
    },
    {
        "school": "GOOSEHILL PRIMARY CENTER",
        "district": "COLD SPRING HARBOR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360801001044",
    },
    {
        "school": "BURR INTERMEDIATE SCHOOL",
        "district": "COMMACK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360813000577",
    },
    {
        "school": "COMMACK HIGH SCHOOL",
        "district": "COMMACK UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360813000580",
    },
    {
        "school": "COMMACK MIDDLE SCHOOL",
        "district": "COMMACK UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360813000581",
    },
    {
        "school": "NORTH RIDGE SCHOOL",
        "district": "COMMACK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360813000587",
    },
    {
        "school": "ROLLING HILLS SCHOOL",
        "district": "COMMACK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360813000589",
    },
    {
        "school": "SAWMILL INTERMEDIATE SCHOOL",
        "district": "COMMACK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360813000591",
    },
    {
        "school": "WOOD PARK SCHOOL",
        "district": "COMMACK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360813000594",
    },
    {
        "school": "INDIAN HOLLOW SCHOOL",
        "district": "COMMACK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360813004382",
    },
    {
        "school": "CHEROKEE STREET ELEMENTARY SCHOOL",
        "district": "CONNETQUOT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360816000596",
    },
    {
        "school": "CONNETQUOT HIGH SCHOOL",
        "district": "CONNETQUOT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360816000597",
    },
    {
        "school": "EDITH L SLOCUM ELEMENTARY SCHOOL",
        "district": "CONNETQUOT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360816000598",
    },
    {
        "school": "EDWARD J BOSTI ELEMENTARY SCHOOL",
        "district": "CONNETQUOT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360816000599",
    },
    {
        "school": "IDLE HOUR ELEMENTARY SCHOOL",
        "district": "CONNETQUOT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360816000601",
    },
    {
        "school": "JOHN PEARL ELEMENTARY SCHOOL",
        "district": "CONNETQUOT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360816000602",
    },
    {
        "school": "OAKDALE-BOHEMIA MIDDLE SCHOOL",
        "district": "CONNETQUOT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360816000603",
    },
    {
        "school": "RONKONKOMA MIDDLE SCHOOL",
        "district": "CONNETQUOT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360816000604",
    },
    {
        "school": "SYCAMORE AVENUE ELEMENTARY SCHOOL",
        "district": "CONNETQUOT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360816000605",
    },
    {
        "school": "HELEN B DUFFIELD ELEMENTARY SCHOOL",
        "district": "CONNETQUOT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360816004383",
    },
    {
        "school": "WALTER G O'CONNELL COPIAGUE HIGH SCHOOL",
        "district": "COPIAGUE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360831000609",
    },
    {
        "school": "COPIAGUE MIDDLE SCHOOL",
        "district": "COPIAGUE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360831000610",
    },
    {
        "school": "DEAUVILLE GARDENS EAST ELEMENTARY SCHOOL",
        "district": "COPIAGUE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360831000611",
    },
    {
        "school": "GREAT NECK ROAD ELEMENTARY SCHOOL",
        "district": "COPIAGUE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360831000612",
    },
    {
        "school": "SUSAN E WILEY SCHOOL",
        "district": "COPIAGUE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360831000614",
    },
    {
        "school": "MAY MOORE PRIMARY SCHOOL",
        "district": "DEER PARK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360888004712",
    },
    {
        "school": "JOHN QUINCY ADAMS PRIMARY SCHOOL",
        "district": "DEER PARK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360888004713",
    },
    {
        "school": "DEER PARK HIGH SCHOOL",
        "district": "DEER PARK UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360888004714",
    },
    {
        "school": "JOHN F KENNEDY INTERMEDIATE SCHOOL",
        "district": "DEER PARK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360888004715",
    },
    {
        "school": "ROBERT FROST MIDDLE SCHOOL",
        "district": "DEER PARK UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360888004716",
    },
    {
        "school": "EAST HAMPTON HIGH SCHOOL",
        "district": "EAST HAMPTON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360966000736",
    },
    {
        "school": "EAST HAMPTON MIDDLE SCHOOL",
        "district": "EAST HAMPTON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360966000737",
    },
    {
        "school": "JOHN M MARSHALL ELEMENTARY SCHOOL",
        "district": "EAST HAMPTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360966000738",
    },
    {
        "school": "CONNETQUOT ELEMENTARY SCHOOL",
        "district": "EAST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360972000746",
    },
    {
        "school": "EAST ISLIP HIGH SCHOOL",
        "district": "EAST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360972000747",
    },
    {
        "school": "EAST ISLIP MIDDLE SCHOOL",
        "district": "EAST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360972000750",
    },
    {
        "school": "JOHN F KENNEDY ELEMENTARY SCHOOL",
        "district": "EAST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360972000751",
    },
    {
        "school": "RUTH C KINNEY ELEMENTARY SCHOOL",
        "district": "EAST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360972000752",
    },
    {
        "school": "TIMBER POINT ELEMENTARY SCHOOL",
        "district": "EAST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360972000753",
    },
    {
        "school": "EAST MORICHES SCHOOL",
        "district": "EAST MORICHES UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360987000763",
    },
    {
        "school": "EAST QUOGUE SCHOOL",
        "district": "EAST QUOGUE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360990000764",
    },
    {
        "school": "JAMES H BOYD ELEMENTARY SCHOOL",
        "district": "ELWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361068000840",
    },
    {
        "school": "ELWOOD MIDDLE SCHOOL",
        "district": "ELWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361068000841",
    },
    {
        "school": "HARLEY AVENUE ELEMENTARY SCHOOL",
        "district": "ELWOOD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361068000842",
    },
    {
        "school": "ELWOOD/JOHN GLENN HIGH SCHOOL",
        "district": "ELWOOD UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361068000843",
    },
    {
        "school": "SALTZMAN EAST MEMORIAL ELEMENTARY SCHOOL",
        "district": "FARMINGDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361098000876",
    },
    {
        "school": "FISHERS ISLAND SCHOOL",
        "district": "FISHERS ISLAND UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361110000884",
    },
    {
        "school": "GREENPORT ELEMENTARY SCHOOL",
        "district": "GREENPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361284001053",
    },
    {
        "school": "GREENPORT HIGH SCHOOL",
        "district": "GREENPORT UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361284001054",
    },
    {
        "school": "CANDLEWOOD MIDDLE SCHOOL",
        "district": "HALF HOLLOW HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361329001081",
    },
    {
        "school": "HALF HOLLOW HILLS HIGH SCHOOL EAST",
        "district": "HALF HOLLOW HILLS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361329001084",
    },
    {
        "school": "HALF HOLLOW HILLS HIGH SCHOOL WEST",
        "district": "HALF HOLLOW HILLS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361329001085",
    },
    {
        "school": "OTSEGO ELEMENTARY SCHOOL",
        "district": "HALF HOLLOW HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361329001088",
    },
    {
        "school": "PAUMANOK ELEMENTARY SCHOOL",
        "district": "HALF HOLLOW HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361329001089",
    },
    {
        "school": "SIGNAL HILL ELEMENTARY SCHOOL",
        "district": "HALF HOLLOW HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361329001090",
    },
    {
        "school": "VANDERBILT ELEMENTARY SCHOOL",
        "district": "HALF HOLLOW HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361329001093",
    },
    {
        "school": "WEST HOLLOW MIDDLE SCHOOL",
        "district": "HALF HOLLOW HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361329001094",
    },
    {
        "school": "SUNQUAM ELEMENTARY SCHOOL",
        "district": "HALF HOLLOW HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361329004246",
    },
    {
        "school": "HAMPTON BAYS ELEMENTARY SCHOOL",
        "district": "HAMPTON BAYS UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361353001107",
    },
    {
        "school": "HAMPTON BAYS HIGH SCHOOL",
        "district": "HAMPTON BAYS UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361353001108",
    },
    {
        "school": "HARBORFIELDS HIGH SCHOOL",
        "district": "HARBORFIELDS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361362001114",
    },
    {
        "school": "OLDFIELD MIDDLE SCHOOL",
        "district": "HARBORFIELDS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361362001116",
    },
    {
        "school": "THOMAS J LAHEY ELEMENTARY SCHOOL",
        "district": "HARBORFIELDS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361362001117",
    },
    {
        "school": "WASHINGTON DRIVE PRIMARY SCHOOL",
        "district": "HARBORFIELDS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361362001450",
    },
    {
        "school": "FOREST BROOK ELEMENTARY SCHOOL",
        "district": "HAUPPAUGE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361398001048",
    },
    {
        "school": "BRETTON WOODS ELEMENTARY SCHOOL",
        "district": "HAUPPAUGE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361398001133",
    },
    {
        "school": "HAUPPAUGE HIGH SCHOOL",
        "district": "HAUPPAUGE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361398001135",
    },
    {
        "school": "HAUPPAUGE MIDDLE SCHOOL",
        "district": "HAUPPAUGE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361398001136",
    },
    {
        "school": "PINES ELEMENTARY SCHOOL",
        "district": "HAUPPAUGE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361398001138",
    },
    {
        "school": "J TAYLOR FINLEY MIDDLE SCHOOL",
        "district": "HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361509001260",
    },
    {
        "school": "FLOWER HILL SCHOOL",
        "district": "HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361509001261",
    },
    {
        "school": "HUNTINGTON HIGH SCHOOL",
        "district": "HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361509001263",
    },
    {
        "school": "JEFFERSON SCHOOL",
        "district": "HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361509001264",
    },
    {
        "school": "SOUTHDOWN SCHOOL",
        "district": "HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361509001266",
    },
    {
        "school": "WASHINGTON SCHOOL",
        "district": "HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361509001267",
    },
    {
        "school": "WOODHULL INTERMEDIATE SCHOOL",
        "district": "HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361509004773",
    },
    {
        "school": "WING ELEMENTARY SCHOOL",
        "district": "ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361554000331",
    },
    {
        "school": "COMMACK ROAD ELEMENTARY SCHOOL",
        "district": "ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361554001323",
    },
    {
        "school": "ISLIP HIGH SCHOOL",
        "district": "ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361554001324",
    },
    {
        "school": "ISLIP MIDDLE SCHOOL",
        "district": "ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361554001325",
    },
    {
        "school": "MAUD S SHERWOOD ELEMENTARY SCHOOL",
        "district": "ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361554001326",
    },
    {
        "school": "BOYLE ROAD ELEMENTARY SCHOOL",
        "district": "BROOKHAVEN-COMSEWOGUE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361578001360",
    },
    {
        "school": "CLINTON AVENUE SCHOOL",
        "district": "BROOKHAVEN-COMSEWOGUE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361578001361",
    },
    {
        "school": "COMSEWOGUE HIGH SCHOOL",
        "district": "BROOKHAVEN-COMSEWOGUE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361578001363",
    },
    {
        "school": "JOHN F KENNEDY MIDDLE SCHOOL",
        "district": "BROOKHAVEN-COMSEWOGUE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361578001364",
    },
    {
        "school": "NORWOOD AVENUE SCHOOL",
        "district": "BROOKHAVEN-COMSEWOGUE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361578001365",
    },
    {
        "school": "TERRYVILLE ROAD SCHOOL",
        "district": "BROOKHAVEN-COMSEWOGUE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361578003417",
    },
    {
        "school": "KINGS PARK HIGH SCHOOL",
        "district": "KINGS PARK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361626001451",
    },
    {
        "school": "PARKVIEW ELEMENTARY SCHOOL",
        "district": "KINGS PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361626001456",
    },
    {
        "school": "FORT SALONGA ELEMENTARY SCHOOL",
        "district": "KINGS PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361626001464",
    },
    {
        "school": "WILLIAM T ROGERS MIDDLE SCHOOL",
        "district": "KINGS PARK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361626001483",
    },
    {
        "school": "RJ O INTERMEDIATE SCHOOL",
        "district": "KINGS PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361626004273",
    },
    {
        "school": "ALBANY AVENUE SCHOOL",
        "district": "LINDENHURST UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361738001541",
    },
    {
        "school": "ALLEGHANY AVENUE SCHOOL",
        "district": "LINDENHURST UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361738001542",
    },
    {
        "school": "DANIEL STREET SCHOOL",
        "district": "LINDENHURST UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361738001543",
    },
    {
        "school": "HARDING AVENUE SCHOOL",
        "district": "LINDENHURST UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361738001545",
    },
    {
        "school": "LINDENHURST MIDDLE SCHOOL",
        "district": "LINDENHURST UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361738001547",
    },
    {
        "school": "LINDENHURST SENIOR HIGH SCHOOL",
        "district": "LINDENHURST UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361738001548",
    },
    {
        "school": "WEST GATES AVENUE SCHOOL",
        "district": "LINDENHURST UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361738001550",
    },
    {
        "school": "WILLIAM RALL SCHOOL",
        "district": "LINDENHURST UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361738001551",
    },
    {
        "school": "LITTLE FLOWER SCHOOL",
        "district": "LITTLE FLOWER UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361740001552",
    },
    {
        "school": "WILLIAM FLOYD HIGH SCHOOL",
        "district": "WILLIAM FLOYD UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361869004672",
    },
    {
        "school": "WILLIAM FLOYD ELEMENTARY SCHOOL",
        "district": "WILLIAM FLOYD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361869004673",
    },
    {
        "school": "TANGIER SMITH ELEMENTARY SCHOOL",
        "district": "WILLIAM FLOYD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361869004674",
    },
    {
        "school": "MORICHES ELEMENTARY SCHOOL",
        "district": "WILLIAM FLOYD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361869004675",
    },
    {
        "school": "JOHN S HOBART ELEMENTARY SCHOOL",
        "district": "WILLIAM FLOYD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361869004677",
    },
    {
        "school": "CENTEREACH HIGH SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001736",
    },
    {
        "school": "DAWNWOOD MIDDLE SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001737",
    },
    {
        "school": "HAWKINS PATH SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001738",
    },
    {
        "school": "HOLBROOK ROAD SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001739",
    },
    {
        "school": "JERICHO ELEMENTARY SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001740",
    },
    {
        "school": "NEW LANE MEMORIAL ELEMENTARY SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001741",
    },
    {
        "school": "NEWFIELD HIGH SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001742",
    },
    {
        "school": "NORTH COLEMAN ROAD SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001743",
    },
    {
        "school": "OXHEAD ROAD SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001744",
    },
    {
        "school": "SELDEN MIDDLE SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001745",
    },
    {
        "school": "STAGECOACH SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001747",
    },
    {
        "school": "EUGENE AUER MEMORIAL SCHOOL",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920001749",
    },
    {
        "school": "UNITY DRIVE KINDERGARTEN-PRE K CENTER",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920004343",
    },
    {
        "school": "BICYCLE PATH KINDERGARTEN-PRE K CENTER",
        "district": "MIDDLE COUNTRY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361920004843",
    },
    {
        "school": "C E WALTERS SCHOOL",
        "district": "LONGWOOD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361923001751",
    },
    {
        "school": "CORAM ELEMENTARY SCHOOL",
        "district": "LONGWOOD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361923001752",
    },
    {
        "school": "LONGWOOD HIGH SCHOOL",
        "district": "LONGWOOD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361923001753",
    },
    {
        "school": "LONGWOOD JUNIOR HIGH SCHOOL",
        "district": "LONGWOOD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361923001754",
    },
    {
        "school": "RIDGE ELEMENTARY SCHOOL",
        "district": "LONGWOOD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361923001755",
    },
    {
        "school": "WEST MIDDLE ISLAND SCHOOL",
        "district": "LONGWOOD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361923001756",
    },
    {
        "school": "LONGWOOD MIDDLE SCHOOL",
        "district": "LONGWOOD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361923004513",
    },
    {
        "school": "MILLER PLACE HIGH SCHOOL",
        "district": "MILLER PLACE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361941001773",
    },
    {
        "school": "ANDREW MULLER PRIMARY SCHOOL",
        "district": "MILLER PLACE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361941001774",
    },
    {
        "school": "NORTH COUNTRY ROAD SCHOOL",
        "district": "MILLER PLACE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361941001775",
    },
    {
        "school": "SOUND BEACH SCHOOL",
        "district": "MILLER PLACE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361941004303",
    },
    {
        "school": "MONTAUK SCHOOL",
        "district": "MONTAUK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361971001805",
    },
    {
        "school": "MOUNT SINAI ELEMENTARY SCHOOL",
        "district": "MOUNT SINAI UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362004001829",
    },
    {
        "school": "MOUNT SINAI MIDDLE SCHOOL",
        "district": "MOUNT SINAI UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362004004304",
    },
    {
        "school": "ROBERT M GRABLE JR MOUNT SINAI HIGH SCHOOL",
        "district": "MOUNT SINAI UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362004004827",
    },
    {
        "school": "NEW SUFFOLK SCHOOL",
        "district": "NEW SUFFOLK COMMON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362052001905",
    },
    {
        "school": "BELMONT ELEMENTARY SCHOOL",
        "district": "NORTH BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362091004736",
    },
    {
        "school": "ROBERT MOSES MIDDLE SCHOOL",
        "district": "NORTH BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362091004737",
    },
    {
        "school": "PARLIAMENT PLACE SCHOOL",
        "district": "NORTH BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362091004738",
    },
    {
        "school": "WOODS ROAD ELEMENTARY SCHOOL",
        "district": "NORTH BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362091004739",
    },
    {
        "school": "NORTH BABYLON HIGH SCHOOL",
        "district": "NORTH BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362091004740",
    },
    {
        "school": "MARION G VEDDER ELEMENTARY SCHOOL",
        "district": "NORTH BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362091004741",
    },
    {
        "school": "WILLIAM E DELUCA JR ELEMENTARY SCHOOL",
        "district": "NORTH BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362091004742",
    },
    {
        "school": "BELLEROSE ELEMENTARY SCHOOL",
        "district": "NORTHPORT-EAST NORTHPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362127003026",
    },
    {
        "school": "DICKINSON AVENUE ELEMENTARY SCHOOL",
        "district": "NORTHPORT-EAST NORTHPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362127003027",
    },
    {
        "school": "EAST NORTHPORT MIDDLE SCHOOL",
        "district": "NORTHPORT-EAST NORTHPORT UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362127003028",
    },
    {
        "school": "FIFTH AVENUE ELEMENTARY SCHOOL",
        "district": "NORTHPORT-EAST NORTHPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362127003029",
    },
    {
        "school": "NORTHPORT MIDDLE SCHOOL",
        "district": "NORTHPORT-EAST NORTHPORT UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362127003032",
    },
    {
        "school": "NORTHPORT SENIOR HIGH SCHOOL",
        "district": "NORTHPORT-EAST NORTHPORT UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362127003033",
    },
    {
        "school": "NORWOOD AVENUE SCHOOL",
        "district": "NORTHPORT-EAST NORTHPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362127003034",
    },
    {
        "school": "OCEAN AVENUE SCHOOL",
        "district": "NORTHPORT-EAST NORTHPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362127003035",
    },
    {
        "school": "PULASKI ROAD SCHOOL",
        "district": "NORTHPORT-EAST NORTHPORT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362127003036",
    },
    {
        "school": "WOODHULL SCHOOL",
        "district": "FIRE ISLAND UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362154003056",
    },
    {
        "school": "OYSTERPONDS ELEMENTARY SCHOOL",
        "district": "OYSTERPONDS UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362193003114",
    },
    {
        "school": "BARTON ELEMENTARY SCHOOL",
        "district": "PATCHOGUE-MEDFORD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362247003159",
    },
    {
        "school": "BAY ELEMENTARY SCHOOL",
        "district": "PATCHOGUE-MEDFORD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362247003160",
    },
    {
        "school": "CANAAN ELEMENTARY SCHOOL",
        "district": "PATCHOGUE-MEDFORD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362247003161",
    },
    {
        "school": "EAGLE ELEMENTARY SCHOOL",
        "district": "PATCHOGUE-MEDFORD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362247003162",
    },
    {
        "school": "MEDFORD ELEMENTARY SCHOOL",
        "district": "PATCHOGUE-MEDFORD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362247003163",
    },
    {
        "school": "OREGON MIDDLE SCHOOL",
        "district": "PATCHOGUE-MEDFORD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362247003164",
    },
    {
        "school": "PATCHOGUE-MEDFORD HIGH SCHOOL",
        "district": "PATCHOGUE-MEDFORD UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362247003165",
    },
    {
        "school": "RIVER ELEMENTARY SCHOOL",
        "district": "PATCHOGUE-MEDFORD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362247003166",
    },
    {
        "school": "SAXTON MIDDLE SCHOOL",
        "district": "PATCHOGUE-MEDFORD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362247003167",
    },
    {
        "school": "SOUTH OCEAN MIDDLE SCHOOL",
        "district": "PATCHOGUE-MEDFORD UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362247003168",
    },
    {
        "school": "TREMONT ELEMENTARY SCHOOL",
        "district": "PATCHOGUE-MEDFORD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362247003169",
    },
    {
        "school": "PORT JEFFERSON MIDDLE SCHOOL",
        "district": "PORT JEFFERSON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362349001901",
    },
    {
        "school": "EARL L VANDERMEULEN HIGH SCHOOL",
        "district": "PORT JEFFERSON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362349003280",
    },
    {
        "school": "PORT JEFFERSON ELEMENTARY SCHOOL",
        "district": "PORT JEFFERSON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362349003281",
    },
    {
        "school": "QUOGUE ELEMENTARY SCHOOL",
        "district": "QUOGUE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362406003319",
    },
    {
        "school": "REMSENBURG-SPEONK ELEMENTARY SCHOOL",
        "district": "REMSENBURG-SPEONK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362442003339",
    },
    {
        "school": "AQUEBOGUE ELEMENTARY SCHOOL",
        "district": "RIVERHEAD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362469003354",
    },
    {
        "school": "PHILLIPS AVENUE SCHOOL",
        "district": "RIVERHEAD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362469003355",
    },
    {
        "school": "PULASKI STREET ELEMENTARY SCHOOL",
        "district": "RIVERHEAD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362469003356",
    },
    {
        "school": "RILEY AVENUE SCHOOL",
        "district": "RIVERHEAD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362469003357",
    },
    {
        "school": "RIVERHEAD MIDDLE SCHOOL",
        "district": "RIVERHEAD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362469003358",
    },
    {
        "school": "RIVERHEAD SENIOR HIGH SCHOOL",
        "district": "RIVERHEAD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362469003359",
    },
    {
        "school": "ROANOKE AVENUE SCHOOL",
        "district": "RIVERHEAD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362469003360",
    },
    {
        "school": "JOSEPH A EDGAR IMTERMEDIATE SCHOOL",
        "district": "ROCKY POINT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362484003435",
    },
    {
        "school": "FRANK J CARASITI ELEMENTARY SCHOOL",
        "district": "ROCKY POINT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362484003436",
    },
    {
        "school": "ROCKY POINT HIGH SCHOOL",
        "district": "ROCKY POINT UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362484003437",
    },
    {
        "school": "CAYUGA SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003498",
    },
    {
        "school": "CHIPPEWA ELEMENTARY SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003499",
    },
    {
        "school": "GRUNDY AVENUE SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003501",
    },
    {
        "school": "HIAWATHA SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003502",
    },
    {
        "school": "LYNWOOD AVENUE SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003503",
    },
    {
        "school": "MERRIMAC SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003504",
    },
    {
        "school": "NOKOMIS SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003505",
    },
    {
        "school": "SAGAMORE MIDDLE SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003507",
    },
    {
        "school": "SENECA MIDDLE SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003509",
    },
    {
        "school": "TAMARAC ELEMENTARY SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003510",
    },
    {
        "school": "WAVERLY AVENUE SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003512",
    },
    {
        "school": "WENONAH SCHOOL",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535003513",
    },
    {
        "school": "SACHEM HIGH SCHOOL NORTH",
        "district": "SACHEM CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362535004567",
    },
    {
        "school": "PIERSON MIDDLE/HIGH SCHOOL",
        "district": "SAG HARBOR UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362538003514",
    },
    {
        "school": "SAG HARBOR ELEMENTARY SCHOOL",
        "district": "SAG HARBOR UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362538003515",
    },
    {
        "school": "SAGAPONACK SCHOOL",
        "district": "SAGAPONACK COMMON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362541003516",
    },
    {
        "school": "CHERRY AVENUE ELEMENTARY SCHOOL",
        "district": "SAYVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362592003554",
    },
    {
        "school": "LINCOLN AVENUE ELEMENTARY SCHOOL",
        "district": "SAYVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362592003556",
    },
    {
        "school": "SAYVILLE HIGH SCHOOL",
        "district": "SAYVILLE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362592003557",
    },
    {
        "school": "SAYVILLE MIDDLE SCHOOL",
        "district": "SAYVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362592003558",
    },
    {
        "school": "SUNRISE DRIVE ELEMENTARY SCHOOL",
        "district": "SAYVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362592003559",
    },
    {
        "school": "SHELTER ISLAND SCHOOL",
        "district": "SHELTER ISLAND UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362664003632",
    },
    {
        "school": "MILLER AVENUE SCHOOL",
        "district": "SHOREHAM-WADING RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362684003656",
    },
    {
        "school": "SHOREHAM-WADING RIVER HIGH SCHOOL",
        "district": "SHOREHAM-WADING RIVER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362684003657",
    },
    {
        "school": "ALBERT G PRODELL MIDDLE SCHOOL",
        "district": "SHOREHAM-WADING RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362684003658",
    },
    {
        "school": "WADING RIVER SCHOOL",
        "district": "SHOREHAM-WADING RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362684003659",
    },
    {
        "school": "SMITHTOWN HIGH SCHOOL-WEST",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706000327",
    },
    {
        "school": "ACCOMPSETT ELEMENTARY SCHOOL",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706003675",
    },
    {
        "school": "DOGWOOD ELEMENTARY SCHOOL",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706003678",
    },
    {
        "school": "MOUNT PLEASANT ELEMENTARY SCHOOL",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706003682",
    },
    {
        "school": "SMITHTOWN ELEMENTARY SCHOOL",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706003686",
    },
    {
        "school": "SAINT JAMES ELEMENTARY SCHOOL",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706003689",
    },
    {
        "school": "TACKAN ELEMENTARY SCHOOL",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706003690",
    },
    {
        "school": "GREAT HOLLOW MIDDLE SCHOOL",
        "district": "SMITHTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362706004257",
    },
    {
        "school": "BIRCHWOOD INTERMEDIATE SCHOOL",
        "district": "SOUTH HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362730003722",
    },
    {
        "school": "COUNTRYWOOD PRIMARY CENTER",
        "district": "SOUTH HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362730003723",
    },
    {
        "school": "HENRY L STIMSON MIDDLE SCHOOL",
        "district": "SOUTH HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362730003724",
    },
    {
        "school": "MAPLEWOOD INTERMEDIATE SCHOOL",
        "district": "SOUTH HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362730003725",
    },
    {
        "school": "OAKWOOD PRIMARY CENTER",
        "district": "SOUTH HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362730003727",
    },
    {
        "school": "WALT WHITMAN HIGH SCHOOL",
        "district": "SOUTH HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362730003729",
    },
    {
        "school": "SOUTHAMPTON ELEMENTARY SCHOOL",
        "district": "SOUTHAMPTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362754003743",
    },
    {
        "school": "SOUTHAMPTON INTERMEDIATE SCHOOL",
        "district": "SOUTHAMPTON UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362754003744",
    },
    {
        "school": "SOUTHAMPTON HIGH SCHOOL",
        "district": "SOUTHAMPTON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362754003745",
    },
    {
        "school": "SOUTHOLD ELEMENTARY SCHOOL",
        "district": "SOUTHOLD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362762003750",
    },
    {
        "school": "SOUTHOLD JUNIOR-SENIOR HIGH SCHOOL",
        "district": "SOUTHOLD UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362762003751",
    },
    {
        "school": "SPRINGS SCHOOL",
        "district": "SPRINGS UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362790003787",
    },
    {
        "school": "ARROWHEAD ELEMENTARY SCHOOL",
        "district": "THREE VILLAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362820003802",
    },
    {
        "school": "MINNESAUKE ELEMENTARY SCHOOL",
        "district": "THREE VILLAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362820003803",
    },
    {
        "school": "NASSAKEAG ELEMENTARY SCHOOL",
        "district": "THREE VILLAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362820003804",
    },
    {
        "school": "PAUL J GELINAS JUNIOR HIGH SCHOOL",
        "district": "THREE VILLAGE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362820003806",
    },
    {
        "school": "ROBERT CUSHMAN MURPHY JUNIOR HIGH SCHOOL",
        "district": "THREE VILLAGE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362820003807",
    },
    {
        "school": "SETAUKET ELEMENTARY SCHOOL",
        "district": "THREE VILLAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362820003808",
    },
    {
        "school": "WARD MELVILLE SENIOR HIGH SCHOOL",
        "district": "THREE VILLAGE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362820003809",
    },
    {
        "school": "WILLIAM SIDNEY MOUNT ELEMENTARY SCHOOL",
        "district": "THREE VILLAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362820003810",
    },
    {
        "school": "TUCKAHOE SCHOOL",
        "district": "TUCKAHOE COMMON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362907003925",
    },
    {
        "school": "WAINSCOTT SCHOOL",
        "district": "WAINSCOTT COMMON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362976003999",
    },
    {
        "school": "FOREST AVENUE SCHOOL",
        "district": "WEST BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363054004100",
    },
    {
        "school": "JOHN F KENNEDY SCHOOL",
        "district": "WEST BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363054004101",
    },
    {
        "school": "SANTAPOGUE SCHOOL",
        "district": "WEST BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363054004102",
    },
    {
        "school": "SOUTH BAY SCHOOL",
        "district": "WEST BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363054004103",
    },
    {
        "school": "TOOKER AVENUE SCHOOL",
        "district": "WEST BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363054004104",
    },
    {
        "school": "WEST BABYLON JUNIOR HIGH SCHOOL",
        "district": "WEST BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363054004105",
    },
    {
        "school": "WEST BABYLON SENIOR HIGH SCHOOL",
        "district": "WEST BABYLON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363054004106",
    },
    {
        "school": "BAYVIEW ELEMENTARY SCHOOL",
        "district": "WEST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363069004125",
    },
    {
        "school": "BEACH STREET MIDDLE SCHOOL",
        "district": "WEST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363069004126",
    },
    {
        "school": "MANETUCK ELEMENTARY SCHOOL",
        "district": "WEST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363069004129",
    },
    {
        "school": "OQUENOCK ELEMENTARY SCHOOL",
        "district": "WEST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363069004130",
    },
    {
        "school": "PAUL J BELLEW ELEMENTARY SCHOOL",
        "district": "WEST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363069004131",
    },
    {
        "school": "UDALL ROAD MIDDLE SCHOOL",
        "district": "WEST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363069004134",
    },
    {
        "school": "WEST ISLIP SENIOR HIGH SCHOOL",
        "district": "WEST ISLIP UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363069004135",
    },
    {
        "school": "WESTHAMPTON BEACH ELEMENTARY SCHOOL",
        "district": "WESTHAMPTON BEACH UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363102004165",
    },
    {
        "school": "WESTHAMPTON BEACH SENIOR HIGH SCHOOL",
        "district": "WESTHAMPTON BEACH UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363102004166",
    },
    {
        "school": "WESTHAMPTON MIDDLE SCHOOL",
        "district": "WESTHAMPTON BEACH UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363102004167",
    },
    {
        "school": "MARTIN LUTHER KING ELEMENTARY SCHOOL",
        "district": "WYANDANCH UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363180004234",
    },
    {
        "school": "MILTON L OLIVE MIDDLE SCHOOL",
        "district": "WYANDANCH UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363180004235",
    },
    {
        "school": "WYANDANCH MEMORIAL HIGH SCHOOL",
        "district": "WYANDANCH UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363180004237",
    },
    {
        "school": "EASTERN SUFFOLK BOCES",
        "district": "EASTERN SUFFOLK BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368082004657",
    },
    {
        "school": "WESTERN SUFFOLK BOCES",
        "district": "WESTERN SUFFOLK BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368086004659",
    },
    {
        "school": "BRONX PREPARATORY CHARTER SCHOOL",
        "district": "BRONX PREPARATORY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360004204466",
    },
    {
        "school": "HARRIET TUBMAN CHARTER SCHOOL",
        "district": "HARRIET TUBMAN CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360004804457",
    },
    {
        "school": "ICAHN CHARTER SCHOOL 1",
        "district": "ICAHN CHARTER SCHOOL 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360004904470",
    },
    {
        "school": "KIPP ACADEMY CHARTER SCHOOL",
        "district": "KIPP ACADEMY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360005404452",
    },
    {
        "school": "BRONX CHARTER SCHOOL FOR THE ARTS",
        "district": "BRONX CHARTER SCHOOL FOR THE ARTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360006304875",
    },
    {
        "school": "FAMILY LIFE ACADEMY CHARTER SCHOOL",
        "district": "FAMILY LIFE ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360006604877",
    },
    {
        "school": "BROOKLYN CHARTER SCHOOL (THE)",
        "district": "BROOKLYN CHARTER SCHOOL (THE)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360004504493",
    },
    {
        "school": "COMMUNITY PARTNERSHIP CHARTER SCHOOL",
        "district": "COMMUNITY PARTNERSHIP CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360004604487",
    },
    {
        "school": "AMBER CHARTER SCHOOL EAST HARLEM",
        "district": "AMBER CHARTER SCHOOL EAST HARLEM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360003904439",
    },
    {
        "school": "HARBOR SCIENCE AND ARTS CHARTER SCHOOL",
        "district": "HARBOR SCIENCE AND ARTS CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360004704413",
    },
    {
        "school": "JOHN V LINDSAY WILDCAT ACADEMY CHARTER SCHOOL",
        "district": "JOHN V LINDSAY WILDCAT ACADEMY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360005304411",
    },
    {
        "school": "SISULU-WALKER CHARTER SCHOOL OF HARLEM",
        "district": "SISULU-WALKER CHARTER SCHOOL OF HARLEM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360006104438",
    },
    {
        "school": "HARLEM PREP CHARTER SCHOOL",
        "district": "HARLEM PREP CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360006804870",
    },
    {
        "school": "BREWSTER HIGH SCHOOL",
        "district": "BREWSTER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360531000264",
    },
    {
        "school": "HENRY H WELLS MIDDLE SCHOOL",
        "district": "BREWSTER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360531000266",
    },
    {
        "school": "JOHN F KENNEDY ELEMENTARY SCHOOL",
        "district": "BREWSTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360531000267",
    },
    {
        "school": "C V STARR INTERMEDIATE SCHOOL",
        "district": "BREWSTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360531003400",
    },
    {
        "school": "CARMEL HIGH SCHOOL",
        "district": "CARMEL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360657000438",
    },
    {
        "school": "GEORGE FISCHER MIDDLE SCHOOL",
        "district": "CARMEL CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360657000439",
    },
    {
        "school": "KENT ELEMENTARY SCHOOL",
        "district": "CARMEL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360657000440",
    },
    {
        "school": "KENT PRIMARY SCHOOL",
        "district": "CARMEL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360657000441",
    },
    {
        "school": "MATTHEW PATERSON ELEMENTARY SCHOOL",
        "district": "CARMEL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360657000442",
    },
    {
        "school": "GARRISON SCHOOL",
        "district": "GARRISON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361186000948",
    },
    {
        "school": "HALDANE ELEMENTARY SCHOOL",
        "district": "HALDANE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361323001078",
    },
    {
        "school": "HALDANE HIGH SCHOOL",
        "district": "HALDANE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361323001079",
    },
    {
        "school": "AUSTIN ROAD ELEMENTARY SCHOOL",
        "district": "MAHOPAC CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361812001620",
    },
    {
        "school": "FULMAR ROAD ELEMENTARY SCHOOL",
        "district": "MAHOPAC CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361812001621",
    },
    {
        "school": "LAKEVIEW ELEMENTARY SCHOOL",
        "district": "MAHOPAC CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361812001622",
    },
    {
        "school": "MAHOPAC HIGH SCHOOL",
        "district": "MAHOPAC CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361812001624",
    },
    {
        "school": "MAHOPAC MIDDLE SCHOOL",
        "district": "MAHOPAC CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361812001625",
    },
    {
        "school": "PUTNAM VALLEY ELEMENTARY SCHOOL",
        "district": "PUTNAM VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362400003314",
    },
    {
        "school": "PUTNAM VALLEY MIDDLE SCHOOL",
        "district": "PUTNAM VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362400003315",
    },
    {
        "school": "PUTNAM VALLEY HIGH SCHOOL",
        "district": "PUTNAM VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362400004837",
    },
    {
        "school": "MERRICK ACADEMY-QUEENS PUBLIC CHARTER SCHOOL",
        "district": "MERRICK ACADEMY-QUEENS PUBLIC CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360005504777",
    },
    {
        "school": "OUR WORLD NEIGHBORHOOD CHARTER SCHOOL",
        "district": "OUR WORLD NEIGHBORHOOD CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360005704804",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL",
        "district": "RENAISSANCE CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360005904803",
    },
    {
        "school": "GELLER HOUSE SCHOOL",
        "district": "HAWTHORNE-CEDAR KNOLLS UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361407001519",
    },
    {
        "school": "HAVERSTRAW ELEMENTARY SCHOOL",
        "district": "HAVERSTRAW-STONY POINT CSD (NORTH ROCKLAND)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361401001142",
    },
    {
        "school": "JAMES A FARLEY ELEMENTARY SCHOOL",
        "district": "HAVERSTRAW-STONY POINT CSD (NORTH ROCKLAND)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361401001143",
    },
    {
        "school": "NORTH ROCKLAND HIGH SCHOOL",
        "district": "HAVERSTRAW-STONY POINT CSD (NORTH ROCKLAND)",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361401001145",
    },
    {
        "school": "STONY POINT ELEMENTARY SCHOOL",
        "district": "HAVERSTRAW-STONY POINT CSD (NORTH ROCKLAND)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361401001146",
    },
    {
        "school": "THIELLS ELEMENTARY SCHOOL",
        "district": "HAVERSTRAW-STONY POINT CSD (NORTH ROCKLAND)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361401001147",
    },
    {
        "school": "WEST HAVERSTRAW ELEMENTARY SCHOOL",
        "district": "HAVERSTRAW-STONY POINT CSD (NORTH ROCKLAND)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361401001148",
    },
    {
        "school": "WILLOW GROVE ELEMENTARY SCHOOL",
        "district": "HAVERSTRAW-STONY POINT CSD (NORTH ROCKLAND)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361401003211",
    },
    {
        "school": "GEORGE W MILLER ELEMENTARY SCHOOL",
        "district": "NANUET UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362019001852",
    },
    {
        "school": "A MACARTHUR BARR MIDDLE SCHOOL",
        "district": "NANUET UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362019001853",
    },
    {
        "school": "NANUET SENIOR HIGH SCHOOL",
        "district": "NANUET UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362019001854",
    },
    {
        "school": "HIGHVIEW ELEMENTARY SCHOOL",
        "district": "NANUET UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362019004224",
    },
    {
        "school": "BARDONIA ELEMENTARY SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034001860",
    },
    {
        "school": "CLARKSTOWN NORTH SENIOR HIGH SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034001863",
    },
    {
        "school": "CLARKSTOWN SOUTH SENIOR HIGH SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034001865",
    },
    {
        "school": "LAKEWOOD ELEMENTARY SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034001868",
    },
    {
        "school": "LAUREL PLAINS ELEMENTARY SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034001869",
    },
    {
        "school": "LINK ELEMENTARY SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034001870",
    },
    {
        "school": "LITTLE TOR ELEMENTARY SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034001871",
    },
    {
        "school": "NEW CITY ELEMENTARY SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034001872",
    },
    {
        "school": "STRAWTOWN ELEMENTARY SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034001873",
    },
    {
        "school": "WEST NYACK ELEMENTARY SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034001875",
    },
    {
        "school": "WOODGLEN ELEMENTARY SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362034001876",
    },
    {
        "school": "BIRCHWOOD SCHOOL",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "362034004444",
    },
    {
        "school": "NYACK MIDDLE SCHOOL",
        "district": "NYACK UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362148003049",
    },
    {
        "school": "LIBERTY ELEMENTARY SCHOOL",
        "district": "NYACK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362148003050",
    },
    {
        "school": "NYACK SENIOR HIGH SCHOOL",
        "district": "NYACK UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362148003051",
    },
    {
        "school": "UPPER NYACK SCHOOL",
        "district": "NYACK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362148003052",
    },
    {
        "school": "VALLEY COTTAGE SCHOOL",
        "district": "NYACK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362148003053",
    },
    {
        "school": "EVANS PARK SCHOOL",
        "district": "PEARL RIVER UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362256003174",
    },
    {
        "school": "FRANKLIN AVENUE SCHOOL",
        "district": "PEARL RIVER UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362256003175",
    },
    {
        "school": "PEARL RIVER MIDDLE SCHOOL",
        "district": "PEARL RIVER UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362256003177",
    },
    {
        "school": "PEARL RIVER HIGH SCHOOL",
        "district": "PEARL RIVER UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362256003178",
    },
    {
        "school": "LINCOLN AVENUE SCHOOL",
        "district": "PEARL RIVER UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362256004824",
    },
    {
        "school": "SOUTH ORANGETOWN MIDDLE SCHOOL",
        "district": "SOUTH ORANGETOWN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362745003739",
    },
    {
        "school": "TAPPAN ZEE HIGH SCHOOL",
        "district": "SOUTH ORANGETOWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362745003741",
    },
    {
        "school": "WILLIAM O SCHAEFER ELEMENTARY SCHOOL",
        "district": "SOUTH ORANGETOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362745004427",
    },
    {
        "school": "COTTAGE LANE ELEMENTARY SCHOOL",
        "district": "SOUTH ORANGETOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362745004708",
    },
    {
        "school": "ELDORADO ELEMENTARY SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003768",
    },
    {
        "school": "ELMWOOD ELEMENTARY SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003769",
    },
    {
        "school": "FLEETWOOD ELEMENTARY SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003770",
    },
    {
        "school": "GRANDVIEW ELEMENTARY SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003771",
    },
    {
        "school": "HEMPSTEAD ELEMENTARY SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003772",
    },
    {
        "school": "KAKIAT ELEMENTARY SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003773",
    },
    {
        "school": "LIME KILN ELEMENTARY SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003775",
    },
    {
        "school": "MARGETTS ELEMENTARY SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003776",
    },
    {
        "school": "POMONA MIDDLE SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003778",
    },
    {
        "school": "RAMAPO HIGH SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003779",
    },
    {
        "school": "CHESTNUT RIDGE MIDDLE SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003781",
    },
    {
        "school": "SPRING VALLEY HIGH SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781003782",
    },
    {
        "school": "SUMMIT PARK ELEMENTARY SCHOOL",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781004569",
    },
    {
        "school": "CHERRY LANE ELEMENTARY SCHOOL",
        "district": "SUFFERN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362832003813",
    },
    {
        "school": "RICHARD P CONNOR ELEMENTARY SCHOOL",
        "district": "SUFFERN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362832003814",
    },
    {
        "school": "MONTEBELLO ROAD SCHOOL",
        "district": "SUFFERN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362832003815",
    },
    {
        "school": "SLOATSBURG ELEMENTARY SCHOOL",
        "district": "SUFFERN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362832003816",
    },
    {
        "school": "SUFFERN MIDDLE SCHOOL",
        "district": "SUFFERN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362832003817",
    },
    {
        "school": "SUFFERN SENIOR HIGH SCHOOL",
        "district": "SUFFERN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362832003818",
    },
    {
        "school": "VIOLA ELEMENTARY SCHOOL",
        "district": "SUFFERN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362832003819",
    },
    {
        "school": "ROCKLAND BOCES",
        "district": "ROCKLAND BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368072004652",
    },
    {
        "school": "ABBOTT SCHOOL",
        "district": "ABBOTT UNION FREE SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360230004429",
    },
    {
        "school": "ARDSLEY HIGH SCHOOL",
        "district": "ARDSLEY UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360318000080",
    },
    {
        "school": "ARDSLEY MIDDLE SCHOOL",
        "district": "ARDSLEY UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360318000081",
    },
    {
        "school": "CONCORD ROAD ELEMENTARY SCHOOL",
        "district": "ARDSLEY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360318000082",
    },
    {
        "school": "BRIARCLIFF HIGH SCHOOL",
        "district": "BRIARCLIFF MANOR UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360534000268",
    },
    {
        "school": "TODD ELEMENTARY SCHOOL",
        "district": "BRIARCLIFF MANOR UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360534000270",
    },
    {
        "school": "BRIARCLIFF MIDDLE SCHOOL",
        "district": "BRIARCLIFF MANOR UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360534002762",
    },
    {
        "school": "BRONXVILLE ELEMENTARY SCHOOL",
        "district": "BRONXVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360564000290",
    },
    {
        "school": "BRONXVILLE HIGH SCHOOL",
        "district": "BRONXVILLE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360564000291",
    },
    {
        "school": "BRONXVILLE MIDDLE SCHOOL",
        "district": "BRONXVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360564004547",
    },
    {
        "school": "BYRAM HILLS HIGH SCHOOL",
        "district": "BYRAM HILLS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360606000389",
    },
    {
        "school": "COMAN HILL SCHOOL",
        "district": "BYRAM HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360606000390",
    },
    {
        "school": "H C CRITTENDEN MIDDLE SCHOOL",
        "district": "BYRAM HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360606000391",
    },
    {
        "school": "WAMPUS SCHOOL",
        "district": "BYRAM HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360606000392",
    },
    {
        "school": "DOUGLAS G GRAFFLIN SCHOOL",
        "district": "CHAPPAQUA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360699000487",
    },
    {
        "school": "HORACE GREELEY HIGH SCHOOL",
        "district": "CHAPPAQUA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360699000488",
    },
    {
        "school": "ROARING BROOK SCHOOL",
        "district": "CHAPPAQUA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360699000489",
    },
    {
        "school": "ROBERT E BELL SCHOOL",
        "district": "CHAPPAQUA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360699000490",
    },
    {
        "school": "WESTORCHARD SCHOOL",
        "district": "CHAPPAQUA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360699000491",
    },
    {
        "school": "MOUNT PLEASANT-COTTAGE SCHOOL",
        "district": "MOUNT PLEASANT-COTTAGE UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360847000652",
    },
    {
        "school": "EDENWALD SCHOOL",
        "district": "MOUNT PLEASANT-COTTAGE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360847000653",
    },
    {
        "school": "CARRIE E TOMPKINS SCHOOL",
        "district": "CROTON-HARMON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360858000658",
    },
    {
        "school": "CROTON-HARMON HIGH SCHOOL",
        "district": "CROTON-HARMON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360858000659",
    },
    {
        "school": "PIERRE VAN CORTLANDT SCHOOL",
        "district": "CROTON-HARMON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360858000660",
    },
    {
        "school": "DOBBS FERRY HIGH SCHOOL",
        "district": "DOBBS FERRY UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360912000702",
    },
    {
        "school": "SPRINGHURST ELEMENTARY SCHOOL",
        "district": "DOBBS FERRY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360912000703",
    },
    {
        "school": "DOBBS FERRY MIDDLE SCHOOL",
        "district": "DOBBS FERRY UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360912004681",
    },
    {
        "school": "ANNE HUTCHINSON SCHOOL",
        "district": "EASTCHESTER UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361008000783",
    },
    {
        "school": "EASTCHESTER MIDDLE SCHOOL",
        "district": "EASTCHESTER UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361008000784",
    },
    {
        "school": "EASTCHESTER SENIOR HIGH SCHOOL",
        "district": "EASTCHESTER UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361008000785",
    },
    {
        "school": "GREENVALE SCHOOL",
        "district": "EASTCHESTER UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361008000786",
    },
    {
        "school": "WAVERLY EARLY CHILDHOOD CENTER",
        "district": "EASTCHESTER UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361008004767",
    },
    {
        "school": "GREENBURGH ELEVEN ELEMENTARY SCHOOL",
        "district": "GREENBURGH ELEVEN UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361014000343",
    },
    {
        "school": "GREENBURGH ELEVEN HIGH SCHOOL",
        "district": "GREENBURGH ELEVEN UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361014000387",
    },
    {
        "school": "GREENBURGH ELEVEN MIDDLE SCHOOL",
        "district": "GREENBURGH ELEVEN UNION FREE SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361014000454",
    },
    {
        "school": "SEELY PLACE SCHOOL",
        "district": "EDGEMONT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361020004508",
    },
    {
        "school": "EDGEMONT JUNIOR-SENIOR HIGH SCHOOL",
        "district": "EDGEMONT UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361020004509",
    },
    {
        "school": "GREENVILLE SCHOOL",
        "district": "EDGEMONT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361020004551",
    },
    {
        "school": "ALEXANDER HAMILTON HIGH SCHOOL",
        "district": "ELMSFORD UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361065000837",
    },
    {
        "school": "ALICE E GRADY ELEMENTARY SCHOOL",
        "district": "ELMSFORD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361065000838",
    },
    {
        "school": "CARL L DIXSON ELEMENTARY SCHOOL",
        "district": "ELMSFORD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361065000839",
    },
    {
        "school": "ZICCOLELLA ELEMENTARY SCHOOL",
        "district": "GREENBURGH-GRAHAM UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361240001008",
    },
    {
        "school": "MARTIN LUTHER KING JR HIGH SCHOOL",
        "district": "GREENBURGH-GRAHAM UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361240004295",
    },
    {
        "school": "HIGHVIEW SCHOOL",
        "district": "GREENBURGH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361272001045",
    },
    {
        "school": "LEE F JACKSON SCHOOL",
        "district": "GREENBURGH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361272001046",
    },
    {
        "school": "EARLY CHILDHOOD PROGRAM",
        "district": "GREENBURGH CENTRAL SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361272001047",
    },
    {
        "school": "RICHARD J BAILEY SCHOOL",
        "district": "GREENBURGH CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361272001049",
    },
    {
        "school": "WOODLANDS MIDDLE/HIGH SCHOOL",
        "district": "GREENBURGH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361272001050",
    },
    {
        "school": "HARRISON AVENUE ELEMENTARY SCHOOL",
        "district": "HARRISON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361374001121",
    },
    {
        "school": "HARRISON HIGH SCHOOL",
        "district": "HARRISON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361374001122",
    },
    {
        "school": "LOUIS M KLEIN MIDDLE SCHOOL",
        "district": "HARRISON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361374001123",
    },
    {
        "school": "PARSONS MEMORIAL SCHOOL",
        "district": "HARRISON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361374001124",
    },
    {
        "school": "PURCHASE SCHOOL",
        "district": "HARRISON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361374001125",
    },
    {
        "school": "SAMUEL J PRESTON SCHOOL",
        "district": "HARRISON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361374001126",
    },
    {
        "school": "FARRAGUT MIDDLE SCHOOL",
        "district": "HASTINGS-ON-HUDSON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361395001130",
    },
    {
        "school": "HASTINGS HIGH SCHOOL",
        "district": "HASTINGS-ON-HUDSON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361395001131",
    },
    {
        "school": "HILLSIDE ELEMENTARY SCHOOL",
        "district": "HASTINGS-ON-HUDSON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361395001132",
    },
    {
        "school": "ACHIEVE ALTERNATIVE HIGH SCHOOL",
        "district": "HAWTHORNE-CEDAR KNOLLS UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361407001149",
    },
    {
        "school": "CEDAR KNOLLS ACADEMY",
        "district": "HAWTHORNE-CEDAR KNOLLS UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361407001515",
    },
    {
        "school": "LINDEN HILL HIGH SCHOOL",
        "district": "HAWTHORNE-CEDAR KNOLLS UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361407001517",
    },
    {
        "school": "BLUE MOUNTAIN MIDDLE SCHOOL",
        "district": "HENDRICK HUDSON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361419001161",
    },
    {
        "school": "BUCHANAN-VERPLANCK ELEMENTARY SCHOOL",
        "district": "HENDRICK HUDSON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361419001162",
    },
    {
        "school": "FRANK G LINDSEY ELEMENTARY SCHOOL",
        "district": "HENDRICK HUDSON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361419001163",
    },
    {
        "school": "FURNACE WOODS ELEMENTARY SCHOOL",
        "district": "HENDRICK HUDSON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361419001164",
    },
    {
        "school": "HENDRICK HUDSON HIGH SCHOOL",
        "district": "HENDRICK HUDSON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361419001165",
    },
    {
        "school": "MAIN STREET SCHOOL SCHOOL (4-5)",
        "district": "IRVINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361545001312",
    },
    {
        "school": "IRVINGTON HIGH SCHOOL",
        "district": "IRVINGTON UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361545001313",
    },
    {
        "school": "IRVINGTON MIDDLE SCHOOL",
        "district": "IRVINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361545001314",
    },
    {
        "school": "DOWS LANE (K-3) SCHOOL",
        "district": "IRVINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361545004903",
    },
    {
        "school": "INCREASE MILLER ELEMENTARY SCHOOL",
        "district": "KATONAH-LEWISBORO UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361608001388",
    },
    {
        "school": "JOHN JAY MIDDLE SCHOOL",
        "district": "KATONAH-LEWISBORO UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361608001389",
    },
    {
        "school": "JOHN JAY HIGH SCHOOL",
        "district": "KATONAH-LEWISBORO UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361608001390",
    },
    {
        "school": "KATONAH ELEMENTARY SCHOOL",
        "district": "KATONAH-LEWISBORO UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361608001391",
    },
    {
        "school": "MEADOW POND ELEMENTARY SCHOOL",
        "district": "KATONAH-LEWISBORO UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361608001393",
    },
    {
        "school": "BENJAMIN FRANKLIN ELEMENTARY SCHOOL",
        "district": "LAKELAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361662001471",
    },
    {
        "school": "LAKELAND-COPPER BEECH MIDDLE SCHOOL",
        "district": "LAKELAND CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361662001472",
    },
    {
        "school": "GEORGE WASHINGTON ELEMENTARY SCHOOL",
        "district": "LAKELAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361662001473",
    },
    {
        "school": "LAKELAND HIGH SCHOOL",
        "district": "LAKELAND CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361662001475",
    },
    {
        "school": "LINCOLN TITUS ELEMENTARY SCHOOL",
        "district": "LAKELAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361662001476",
    },
    {
        "school": "THOMAS JEFFERSON ELEMENTARY SCHOOL",
        "district": "LAKELAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361662001477",
    },
    {
        "school": "VAN CORTLANDTVILLE SCHOOL",
        "district": "LAKELAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361662001478",
    },
    {
        "school": "WALTER PANAS HIGH SCHOOL",
        "district": "LAKELAND CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361662001479",
    },
    {
        "school": "CENTRAL SCHOOL",
        "district": "MAMARONECK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361824001644",
    },
    {
        "school": "CHATSWORTH AVENUE SCHOOL",
        "district": "MAMARONECK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361824001645",
    },
    {
        "school": "HOMMOCKS SCHOOL",
        "district": "MAMARONECK UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361824001646",
    },
    {
        "school": "MAMARONECK AVENUE SCHOOL",
        "district": "MAMARONECK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361824001647",
    },
    {
        "school": "MAMARONECK HIGH SCHOOL",
        "district": "MAMARONECK UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361824001648",
    },
    {
        "school": "MURRAY AVENUE SCHOOL",
        "district": "MAMARONECK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361824001649",
    },
    {
        "school": "BEDFORD HILLS ELEMENTARY SCHOOL",
        "district": "BEDFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361995001820",
    },
    {
        "school": "FOX LANE HIGH SCHOOL",
        "district": "BEDFORD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361995001822",
    },
    {
        "school": "FOX LANE MIDDLE SCHOOL",
        "district": "BEDFORD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361995001823",
    },
    {
        "school": "MOUNT KISCO ELEMENTARY SCHOOL",
        "district": "BEDFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361995001824",
    },
    {
        "school": "POUND RIDGE ELEMENTARY SCHOOL",
        "district": "BEDFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361995001825",
    },
    {
        "school": "WEST PATENT ELEMENTARY SCHOOL",
        "district": "BEDFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361995001826",
    },
    {
        "school": "BEDFORD VILLAGE ELEMENTARY SCHOOL",
        "district": "BEDFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361995004831",
    },
    {
        "school": "COLUMBUS SCHOOL AT THE FRANKO BUILDING",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001832",
    },
    {
        "school": "GRAHAM SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001833",
    },
    {
        "school": "HAMILTON SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001835",
    },
    {
        "school": "HOLMES SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001836",
    },
    {
        "school": "LINCOLN SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001837",
    },
    {
        "school": "REBECCA TURNER ELEMTNARY SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001838",
    },
    {
        "school": "MOUNT VERNON HIGH SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001839",
    },
    {
        "school": "CECIL H PARKER SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001841",
    },
    {
        "school": "PENNINGTON SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001842",
    },
    {
        "school": "EDWARD WILLIAMS SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001843",
    },
    {
        "school": "TRAPHAGEN SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001844",
    },
    {
        "school": "GRIMES SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010001845",
    },
    {
        "school": "BENJAMIN TURNER MIDDLE SCHOOL",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010004345",
    },
    {
        "school": "COLUMBUS ELEMENTARY SCHOOL",
        "district": "MOUNT PLEASANT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362016001846",
    },
    {
        "school": "HAWTHORNE ELEMENTARY SCHOOL",
        "district": "MOUNT PLEASANT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362016001847",
    },
    {
        "school": "WESTLAKE HIGH SCHOOL",
        "district": "MOUNT PLEASANT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362016001849",
    },
    {
        "school": "WESTLAKE MIDDLE SCHOOL",
        "district": "MOUNT PLEASANT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362016001850",
    },
    {
        "school": "BLYTHEDALE SCHOOL",
        "district": "MOUNT PLEASANT-BLYTHEDALE UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "362017001851",
    },
    {
        "school": "ALBERT LEONARD MIDDLE SCHOOL",
        "district": "NEW ROCHELLE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362049001892",
    },
    {
        "school": "COLUMBUS ELEMENTARY SCHOOL",
        "district": "NEW ROCHELLE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362049001893",
    },
    {
        "school": "DANIEL WEBSTER ELEMENTARY SCHOOL",
        "district": "NEW ROCHELLE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362049001894",
    },
    {
        "school": "GEORGE M DAVIS ELEMENTARY SCHOOL",
        "district": "NEW ROCHELLE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362049001895",
    },
    {
        "school": "HENRY BARNARD SCHOOL",
        "district": "NEW ROCHELLE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362049001896",
    },
    {
        "school": "ISAAC E YOUNG MIDDLE SCHOOL",
        "district": "NEW ROCHELLE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362049001897",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "NEW ROCHELLE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362049001898",
    },
    {
        "school": "NEW ROCHELLE HIGH SCHOOL",
        "district": "NEW ROCHELLE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362049001900",
    },
    {
        "school": "TRINITY ELEMENTARY SCHOOL",
        "district": "NEW ROCHELLE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362049004399",
    },
    {
        "school": "WILLIAM B WARD ELEMENTARY SCHOOL",
        "district": "NEW ROCHELLE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362049004400",
    },
    {
        "school": "NORTH SALEM MIDDLE SCHOOL/HIGH SCHOOL",
        "district": "NORTH SALEM CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362118002991",
    },
    {
        "school": "PEQUENAKONCK ELEMENTARY SCHOOL",
        "district": "NORTH SALEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362118002992",
    },
    {
        "school": "ANNE M DORNER MIDDLE SCHOOL",
        "district": "OSSINING UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362202003118",
    },
    {
        "school": "BROOKSIDE SCHOOL",
        "district": "OSSINING UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362202003119",
    },
    {
        "school": "CLAREMONT SCHOOL",
        "district": "OSSINING UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362202003120",
    },
    {
        "school": "OSSINING HIGH SCHOOL",
        "district": "OSSINING UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362202003121",
    },
    {
        "school": "PARK SCHOOL",
        "district": "OSSINING UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362202003122",
    },
    {
        "school": "ROOSEVELT SCHOOL",
        "district": "OSSINING UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362202004852",
    },
    {
        "school": "HILLCREST SCHOOL",
        "district": "PEEKSKILL CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362265003179",
    },
    {
        "school": "OAKSIDE SCHOOL",
        "district": "PEEKSKILL CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362265003180",
    },
    {
        "school": "PEEKSKILL HIGH SCHOOL",
        "district": "PEEKSKILL CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362265003181",
    },
    {
        "school": "URIAH HILL SCHOOL",
        "district": "PEEKSKILL CITY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362265003183",
    },
    {
        "school": "WOODSIDE SCHOOL",
        "district": "PEEKSKILL CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362265003184",
    },
    {
        "school": "PEEKSKILL MIDDLE SCHOOL",
        "district": "PEEKSKILL CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362265004366",
    },
    {
        "school": "COLONIAL SCHOOL",
        "district": "PELHAM UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362268003185",
    },
    {
        "school": "HUTCHINSON SCHOOL",
        "district": "PELHAM UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362268003186",
    },
    {
        "school": "PELHAM MIDDLE SCHOOL",
        "district": "PELHAM UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362268003187",
    },
    {
        "school": "PELHAM MEMORIAL HIGH SCHOOL",
        "district": "PELHAM UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362268003188",
    },
    {
        "school": "PROSPECT HILL SCHOOL",
        "district": "PELHAM UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362268003189",
    },
    {
        "school": "SIWANOY SCHOOL",
        "district": "PELHAM UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362268003190",
    },
    {
        "school": "BEDFORD ROAD SCHOOL",
        "district": "PLEASANTVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362331003264",
    },
    {
        "school": "PLEASANTVILLE HIGH SCHOOL",
        "district": "PLEASANTVILLE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362331003265",
    },
    {
        "school": "PLEASANTVILLE MIDDLE SCHOOL",
        "district": "PLEASANTVILLE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362331004745",
    },
    {
        "school": "POCANTICO HILLS CENTRAL SCHOOL",
        "district": "POCANTICO HILLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362334003267",
    },
    {
        "school": "JOHN F KENNEDY ELEMENTARY SCHOOL",
        "district": "PORT CHESTER-RYE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362346003273",
    },
    {
        "school": "KING STREET SCHOOL",
        "district": "PORT CHESTER-RYE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362346003274",
    },
    {
        "school": "PARK AVENUE SCHOOL",
        "district": "PORT CHESTER-RYE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362346003276",
    },
    {
        "school": "PORT CHESTER MIDDLE SCHOOL",
        "district": "PORT CHESTER-RYE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362346003277",
    },
    {
        "school": "PORT CHESTER SENIOR HIGH SCHOOL",
        "district": "PORT CHESTER-RYE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362346003278",
    },
    {
        "school": "THOMAS A EDISON SCHOOL",
        "district": "PORT CHESTER-RYE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362346003279",
    },
    {
        "school": "BLIND BROOK HIGH SCHOOL",
        "district": "BLIND BROOK-RYE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362463003350",
    },
    {
        "school": "BRUNO M PONTERIO RIDGE STREET SCHOOL",
        "district": "BLIND BROOK-RYE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362463003351",
    },
    {
        "school": "MIDLAND SCHOOL",
        "district": "RYE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362526003489",
    },
    {
        "school": "MILTON SCHOOL",
        "district": "RYE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362526003490",
    },
    {
        "school": "OSBORN SCHOOL",
        "district": "RYE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362526003491",
    },
    {
        "school": "RYE HIGH SCHOOL",
        "district": "RYE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362526003492",
    },
    {
        "school": "RYE MIDDLE SCHOOL",
        "district": "RYE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362526003493",
    },
    {
        "school": "DANIEL WARREN ELEMENTARY SCHOOL",
        "district": "RYE NECK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362529002771",
    },
    {
        "school": "F E BELLOWS ELEMENTARY SCHOOL",
        "district": "RYE NECK UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362529003494",
    },
    {
        "school": "RYE NECK MIDDLE SCHOOL",
        "district": "RYE NECK UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362529003495",
    },
    {
        "school": "RYE NECK SENIOR HIGH SCHOOL",
        "district": "RYE NECK UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362529003496",
    },
    {
        "school": "EDGEWOOD SCHOOL",
        "district": "SCARSDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362595003560",
    },
    {
        "school": "FOX MEADOW SCHOOL",
        "district": "SCARSDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362595003561",
    },
    {
        "school": "GREENACRES SCHOOL",
        "district": "SCARSDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362595003562",
    },
    {
        "school": "HEATHCOTE SCHOOL",
        "district": "SCARSDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362595003563",
    },
    {
        "school": "QUAKER RIDGE SCHOOL",
        "district": "SCARSDALE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362595003564",
    },
    {
        "school": "SCARSDALE MIDDLE SCHOOL",
        "district": "SCARSDALE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362595003565",
    },
    {
        "school": "SCARSDALE SENIOR HIGH SCHOOL",
        "district": "SCARSDALE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362595003566",
    },
    {
        "school": "PRIMROSE SCHOOL",
        "district": "SOMERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362718003700",
    },
    {
        "school": "SOMERS INTERMEDIATE SCHOOL",
        "district": "SOMERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362718003701",
    },
    {
        "school": "SOMERS MIDDLE SCHOOL",
        "district": "SOMERS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362718003702",
    },
    {
        "school": "SOMERS SENIOR HIGH SCHOOL",
        "district": "SOMERS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362718003703",
    },
    {
        "school": "GREENBURGH ACADEMY",
        "district": "GREENBURGH-NORTH CASTLE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "362798003792",
    },
    {
        "school": "REACH ACADEMY (THE)",
        "district": "GREENBURGH-NORTH CASTLE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "362798004904",
    },
    {
        "school": "JOHN PAULDING SCHOOL",
        "district": "UNION FREE SCHOOL DISTRICT OF THE TARRYTOWNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362865003888",
    },
    {
        "school": "SLEEPY HOLLOW HIGH SCHOOL",
        "district": "UNION FREE SCHOOL DISTRICT OF THE TARRYTOWNS",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362865003889",
    },
    {
        "school": "W L MORSE SCHOOL",
        "district": "UNION FREE SCHOOL DISTRICT OF THE TARRYTOWNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362865003891",
    },
    {
        "school": "WASHINGTON IRVING INTERM SCHOOL",
        "district": "UNION FREE SCHOOL DISTRICT OF THE TARRYTOWNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362865003892",
    },
    {
        "school": "TUCKAHOE MIDDLE SCHOOL",
        "district": "TUCKAHOE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362904002757",
    },
    {
        "school": "TUCKAHOE HIGH SCHOOL",
        "district": "TUCKAHOE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362904003923",
    },
    {
        "school": "WILLIAM E COTTLE SCHOOL",
        "district": "TUCKAHOE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362904003924",
    },
    {
        "school": "VALHALLA MIDDLE SCHOOL",
        "district": "VALHALLA UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362940001521",
    },
    {
        "school": "VIRGINIA ROAD ELEMENTARY SCHOOL",
        "district": "VALHALLA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362940004536",
    },
    {
        "school": "VALHALLA HIGH SCHOOL",
        "district": "VALHALLA UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362940004537",
    },
    {
        "school": "KENSICO SCHOOL",
        "district": "VALHALLA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362940004572",
    },
    {
        "school": "WHITE PLAINS MIDDLE SCHOOL",
        "district": "WHITE PLAINS CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363126004177",
    },
    {
        "school": "GEORGE WASHINGTON SCHOOL",
        "district": "WHITE PLAINS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363126004179",
    },
    {
        "school": "MAMARONECK AVENUE SCHOOL",
        "district": "WHITE PLAINS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363126004181",
    },
    {
        "school": "POST ROAD SCHOOL",
        "district": "WHITE PLAINS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363126004184",
    },
    {
        "school": "RIDGEWAY SCHOOL",
        "district": "WHITE PLAINS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363126004185",
    },
    {
        "school": "WHITE PLAINS SENIOR HIGH SCHOOL",
        "district": "WHITE PLAINS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363126004188",
    },
    {
        "school": "CHURCH STREET SCHOOL",
        "district": "WHITE PLAINS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363126004755",
    },
    {
        "school": "RIVERSIDE HIGH SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192000448",
    },
    {
        "school": "ROBERT C DODSON SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192000452",
    },
    {
        "school": "FAMILY SCHOOL 32",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192001077",
    },
    {
        "school": "MONTESSORI SCHOOL 31",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192001527",
    },
    {
        "school": "WILLIAM BOYCE THOMPSON SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192001920",
    },
    {
        "school": "PAIDEIA SCHOOL 24",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192002802",
    },
    {
        "school": "PAIDEIA SCHOOL 15",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192003452",
    },
    {
        "school": "ENRICO FERMI SCHOOL FOR THE PERFORMING ARTS",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004242",
    },
    {
        "school": "GORTON HIGH SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004243",
    },
    {
        "school": "LINCOLN HIGH SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004245",
    },
    {
        "school": "YONKERS MONTESSORI ACADEMY",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004247",
    },
    {
        "school": "MLK JR HIGH TECH & COMPUTER MAGNET SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004248",
    },
    {
        "school": "CROSS HILL ACADEMY",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004249",
    },
    {
        "school": "ROOSEVELT HIGH SCHOOL - EARLY COLLEGE STUDIES",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004250",
    },
    {
        "school": "SAUNDERS TRADES & TECHNICAL HIGH SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004251",
    },
    {
        "school": "SCHOOL 5",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004252",
    },
    {
        "school": "PATRICIA A DICHIARO SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004254",
    },
    {
        "school": "SCHOOL 9",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004255",
    },
    {
        "school": "SCHOOL 13",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004258",
    },
    {
        "school": "ROSMARIE ANN SIRAGUSA SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004259",
    },
    {
        "school": "SCHOOL 16",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004260",
    },
    {
        "school": "SCHOOL 17",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004261",
    },
    {
        "school": "SCHOLASTIC ACADEMY FOR ACADEMIC EXCELLENCE",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004262",
    },
    {
        "school": "EUGENIO MARIA DE HOSTOS MICROSOCIETY SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004263",
    },
    {
        "school": "SCHOOL 21",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004264",
    },
    {
        "school": "SCHOOL 22",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004265",
    },
    {
        "school": "SCHOOL 23",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004266",
    },
    {
        "school": "MUSEUM SCHOOL 25",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004267",
    },
    {
        "school": "CASIMIR PULASKI SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004268",
    },
    {
        "school": "MONTESSORI SCHOOL 27",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004269",
    },
    {
        "school": "KAHLIL GIBRAN SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004270",
    },
    {
        "school": "SCHOOL 29",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004271",
    },
    {
        "school": "SCHOOL 30",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004272",
    },
    {
        "school": "PEARLS HAWTHORNE SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004539",
    },
    {
        "school": "YONKERS HIGH SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004574",
    },
    {
        "school": "CESAR E CHAVEZ SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192004853",
    },
    {
        "school": "BROOKSIDE SCHOOL",
        "district": "YORKTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363198004280",
    },
    {
        "school": "CROMPOND SCHOOL",
        "district": "YORKTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363198004281",
    },
    {
        "school": "MILDRED E STRANG MIDDLE SCHOOL",
        "district": "YORKTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363198004282",
    },
    {
        "school": "MOHANSIC SCHOOL",
        "district": "YORKTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363198004283",
    },
    {
        "school": "YORKTOWN HIGH SCHOOL",
        "district": "YORKTOWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363198004284",
    },
    {
        "school": "PUTNAM-WESTCHESTER BOCES",
        "district": "PUTNAM-WESTCHESTER BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368068004650",
    },
    {
        "school": "WESTCHESTER BOCES",
        "district": "WESTCHESTER BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368096004664",
    },
    {
        "school": "NORWOOD-NORFOLK MIDDLE SCHOOL",
        "district": "NORWOOD-NORFOLK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362136005581",
    },
    {
        "school": "ST LAWRENCE MIDDLE SCHOOL",
        "district": "BRASHER FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362796005388",
    },
    {
        "school": "EDWARDS-KNOX ELEMENTARY SCHOOL",
        "district": "EDWARDS-KNOX CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000304542",
    },
    {
        "school": "EDWARDS-KNOX JUNIOR-SENIOR HIGH SCHOOL",
        "district": "EDWARDS-KNOX CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000304543",
    },
    {
        "school": "F S BANFORD ELEMENTARY SCHOOL",
        "district": "CANTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360647000427",
    },
    {
        "school": "H C WILLIAMS SENIOR HIGH SCHOOL",
        "district": "CANTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360647000428",
    },
    {
        "school": "J M MCKENNEY MIDDLE SCHOOL",
        "district": "CANTON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360647004763",
    },
    {
        "school": "CLIFTON-FINE ELEMENTARY SCHOOL",
        "district": "CLIFTON-FINE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360771000552",
    },
    {
        "school": "CLIFTON-FINE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "CLIFTON-FINE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360771000553",
    },
    {
        "school": "COLTON-PIERREPONT CENTRAL SCHOOL",
        "district": "COLTON-PIERREPONT CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360810000576",
    },
    {
        "school": "GOUVERNEUR ELEMENTARY SCHOOL",
        "district": "GOUVERNEUR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361236001000",
    },
    {
        "school": "GOUVERNEUR HIGH SCHOOL",
        "district": "GOUVERNEUR CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361236001002",
    },
    {
        "school": "HAMMOND CENTRAL SCHOOL",
        "district": "HAMMOND CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361344004511",
    },
    {
        "school": "HERMON-DEKALB CENTRAL SCHOOL",
        "district": "HERMON-DEKALB CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361425001173",
    },
    {
        "school": "HEUVELTON CENTRAL SCHOOL",
        "district": "HEUVELTON CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361431001180",
    },
    {
        "school": "LISBON CENTRAL SCHOOL",
        "district": "LISBON CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361743001553",
    },
    {
        "school": "MADRID-WADDINGTON JUNIOR-SENIOR HIGH SCHOOL",
        "district": "MADRID-WADDINGTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361809001618",
    },
    {
        "school": "MADRID-WADDINGTON ELEMENTARY SCHOOL",
        "district": "MADRID-WADDINGTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361809004825",
    },
    {
        "school": "JEFFERSON ELEMENTARY SCHOOL",
        "district": "MASSENA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361866001691",
    },
    {
        "school": "MADISON ELEMENTARY SCHOOL",
        "district": "MASSENA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361866001693",
    },
    {
        "school": "J WILLIAM LEARY JUNIOR HIGH SCHOOL",
        "district": "MASSENA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361866001694",
    },
    {
        "school": "MASSENA SENIOR HIGH SCHOOL",
        "district": "MASSENA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361866001695",
    },
    {
        "school": "NIGHTENGALE ELEMENTARY SCHOOL",
        "district": "MASSENA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361866001696",
    },
    {
        "school": "MORRISTOWN CENTRAL SCHOOL",
        "district": "MORRISTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361989001817",
    },
    {
        "school": "NORWOOD-NORFOLK ELEMENTARY SCHOOL",
        "district": "NORWOOD-NORFOLK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362136003043",
    },
    {
        "school": "NORWOOD-NORFOLK SCHOOL",
        "district": "NORWOOD-NORFOLK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362136003045",
    },
    {
        "school": "JOHN F KENNEDY SCHOOL",
        "district": "OGDENSBURG CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362166003069",
    },
    {
        "school": "MADILL SCHOOL",
        "district": "OGDENSBURG CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362166003071",
    },
    {
        "school": "OGDENSBURG FREE ACADEMY",
        "district": "OGDENSBURG CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362166004325",
    },
    {
        "school": "PARISHVILLE-HOPKINTON ELEMENTARY SCHOOL",
        "district": "PARISHVILLE-HOPKINTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362244003157",
    },
    {
        "school": "PARISHVILLE-HOPKINTON JUNIOR-SENIOR HIGH SCHOOL",
        "district": "PARISHVILLE-HOPKINTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362244003158",
    },
    {
        "school": "A A KINGSTON MIDDLE SCHOOL",
        "district": "POTSDAM CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362367003299",
    },
    {
        "school": "LAWRENCE AVENUE ELEMENTARY SCHOOL",
        "district": "POTSDAM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362367003300",
    },
    {
        "school": "POTSDAM SENIOR HIGH SCHOOL",
        "district": "POTSDAM CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362367003301",
    },
    {
        "school": "SAINT LAWRENCE ELEMENTARY SCHOOL",
        "district": "BRASHER FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362796003790",
    },
    {
        "school": "SAINT LAWRENCE HIGH SCHOOL",
        "district": "BRASHER FALLS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362796003791",
    },
    {
        "school": "SAINT LAWRENCE-LEWIS BOCES",
        "district": "SAINT LAWRENCE-LEWIS BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368074004653",
    },
    {
        "school": "ELLICOTTVILLE ELEMENTARY SCHOOL",
        "district": "ELLICOTTVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361053005577",
    },
    {
        "school": "ALLEGANY-LIMESTONE ELEMENTARY SCHOOL",
        "district": "ALLEGANY-LIMESTONE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001500052",
    },
    {
        "school": "ALLEGANY-LIMESTONE MIDDLE-HIGH SCHOOL",
        "district": "ALLEGANY-LIMESTONE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001500053",
    },
    {
        "school": "CATTARAUGUS-LITTLE VALLEY ELEMENTARY SCHOOL",
        "district": "CATTARAUGUS-LITTLE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002404322",
    },
    {
        "school": "CATTARAUGUS-LITTLE VALLEY HIGH SCHOOL",
        "district": "CATTARAUGUS-LITTLE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002404324",
    },
    {
        "school": "CATTARAUGUS-LITTLE VALLEY MIDDLE SCHOOL",
        "district": "CATTARAUGUS-LITTLE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002404857",
    },
    {
        "school": "RANDOLPH ACADEMY",
        "district": "RANDOLPH ACADEMY UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360744004507",
    },
    {
        "school": "ARCADE ELEMENTARY SCHOOL",
        "district": "YORKSHIRE-PIONEER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360897000683",
    },
    {
        "school": "DELEVAN ELEMENTARY SCHOOL",
        "district": "YORKSHIRE-PIONEER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360897000684",
    },
    {
        "school": "PIONEER SENIOR HIGH SCHOOL",
        "district": "YORKSHIRE-PIONEER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360897000686",
    },
    {
        "school": "ELLICOTTVILLE MIDDLE SCHOOL HIGH SCHOOL",
        "district": "ELLICOTTVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361053004318",
    },
    {
        "school": "FRANKLINVILLE ELEMENTARY SCHOOL",
        "district": "FRANKLINVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361149000904",
    },
    {
        "school": "FRANKLINVILLE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "FRANKLINVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361149000905",
    },
    {
        "school": "GOWANDA HIGH SCHOOL",
        "district": "GOWANDA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361239001007",
    },
    {
        "school": "GOWANDA MIDDLE SCHOOL",
        "district": "GOWANDA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361239004858",
    },
    {
        "school": "HINSDALE CENTRAL SCHOOL",
        "district": "HINSDALE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361449001203",
    },
    {
        "school": "EAST VIEW ELEMENTARY SCHOOL",
        "district": "OLEAN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362172003077",
    },
    {
        "school": "OLEAN INTERMEDIATE-MIDDLE SCHOOL",
        "district": "OLEAN CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362172003081",
    },
    {
        "school": "OLEAN SENIOR HIGH SCHOOL",
        "district": "OLEAN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362172003082",
    },
    {
        "school": "WASHINGTON WEST ELEMENTARY SCHOOL",
        "district": "OLEAN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362172003083",
    },
    {
        "school": "PORTVILLE ELEMENTARY SCHOOL",
        "district": "PORTVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362364003297",
    },
    {
        "school": "PORTVILLE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "PORTVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362364003298",
    },
    {
        "school": "G N CHAPMAN ELEMENTARY SCHOOL",
        "district": "RANDOLPH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362409003320",
    },
    {
        "school": "RANDOLPH SENIOR HIGH SCHOOL",
        "district": "RANDOLPH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362409003321",
    },
    {
        "school": "PROSPECT ELEMENTARY SCHOOL",
        "district": "SALAMANCA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362544003518",
    },
    {
        "school": "SALAMANCA HIGH SCHOOL",
        "district": "SALAMANCA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362544003519",
    },
    {
        "school": "SENECA INTERMEDIATE SCHOOL",
        "district": "SALAMANCA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362544003520",
    },
    {
        "school": "WEST VALLEY CENTRAL SCHOOL",
        "district": "WEST VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363090004153",
    },
    {
        "school": "CATTARAUGUS-ALLEGANY-ERIE-WYOMING BOCES",
        "district": "CATTARAUGUS-ALLEGANY-ERIE-WYOMING BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368015004626",
    },
    {
        "school": "PIONEER MIDDLE SCHOOL",
        "district": "YORKSHIRE-PIONEER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360897000685",
    },
    {
        "school": "GOWANDA ELEMENTARY SCHOOL",
        "district": "GOWANDA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361239001005",
    },
    {
        "school": "CHERRY VALLEY-SPRINGFIELD CENTRAL SCHOOL",
        "district": "CHERRY VALLEY-SPRINGFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000600525",
    },
    {
        "school": "SCHENEVUS CENTRAL SCHOOL",
        "district": "SCHENEVUS CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360306000078",
    },
    {
        "school": "GILBERTSVILLE-MOUNT UPTON JUNIOR-SENIOR HIGH SCHOOL",
        "district": "GILBERTSVILLE-MOUNT UPTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360475704757",
    },
    {
        "school": "GILBERTSVILLE-MOUNT UPTON ELEMENTARY SCHOOL",
        "district": "GILBERTSVILLE-MOUNT UPTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360475704759",
    },
    {
        "school": "COOPERSTOWN JUNIOR/SENIOR HIGH SCHOOL",
        "district": "COOPERSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360825000606",
    },
    {
        "school": "COOPERSTOWN ELEMENTARY SCHOOL",
        "district": "COOPERSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360825000607",
    },
    {
        "school": "EDMESTON CENTRAL SCHOOL",
        "district": "EDMESTON CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361026000797",
    },
    {
        "school": "LAURENS CENTRAL SCHOOL",
        "district": "LAURENS CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361680001498",
    },
    {
        "school": "MILFORD CENTRAL SCHOOL",
        "district": "MILFORD CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361935001769",
    },
    {
        "school": "MORRIS CENTRAL SCHOOL",
        "district": "MORRIS CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361986001816",
    },
    {
        "school": "GREATER PLAINS ELEMENTARY SCHOOL",
        "district": "ONEONTA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362178003093",
    },
    {
        "school": "ONEONTA MIDDLE SCHOOL",
        "district": "ONEONTA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362178003094",
    },
    {
        "school": "ONEONTA SENIOR HIGH SCHOOL",
        "district": "ONEONTA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362178003095",
    },
    {
        "school": "RIVERSIDE ELEMENTARY SCHOOL",
        "district": "ONEONTA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362178003096",
    },
    {
        "school": "VALLEYVIEW ELEMENTARY SCHOOL",
        "district": "ONEONTA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362178003097",
    },
    {
        "school": "RICHFIELD SPRINGS ELEMENTARY SCHOOL",
        "district": "RICHFIELD SPRINGS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362457003347",
    },
    {
        "school": "UNADILLA ELEMENTARY SCHOOL",
        "district": "OTEGO-UNADILLA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362924003933",
    },
    {
        "school": "UNATEGO JUNIOR-SENIOR HIGH SCHOOL",
        "district": "OTEGO-UNADILLA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362924003934",
    },
    {
        "school": "WORCESTER SCHOOL",
        "district": "WORCESTER CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363174004232",
    },
    {
        "school": "AUSABLE VALLEY MIDDLE SCHOOL",
        "district": "AUSABLE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361617004948",
    },
    {
        "school": "MORRISONVILLE ELEMENTARY SCHOOL",
        "district": "SARANAC CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000904666",
    },
    {
        "school": "SARANAC ELEMENTARY SCHOOL",
        "district": "SARANAC CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000904668",
    },
    {
        "school": "SARANAC HIGH SCHOOL",
        "district": "SARANAC CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000904669",
    },
    {
        "school": "SARANAC MIDDLE SCHOOL",
        "district": "SARANAC CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000904670",
    },
    {
        "school": "BEEKMANTOWN ELEMENTARY SCHOOL",
        "district": "BEEKMANTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360429000184",
    },
    {
        "school": "BEEKMANTOWN HIGH SCHOOL",
        "district": "BEEKMANTOWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360429000185",
    },
    {
        "school": "CUMBERLAND HEAD ELEMENTARY SCHOOL",
        "district": "BEEKMANTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360429000186",
    },
    {
        "school": "BEEKMANTOWN MIDDLE SCHOOL",
        "district": "BEEKMANTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360429003247",
    },
    {
        "school": "CHAZY CENTRAL RURAL ELEMENTARY SCHOOL",
        "district": "CHAZY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360717000506",
    },
    {
        "school": "CHAZY CENTRAL RURAL JUNIOR-SENIOR HIGH SCHOOL",
        "district": "CHAZY UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360717000507",
    },
    {
        "school": "AUSABLE VALLEY HIGH SCHOOL",
        "district": "AUSABLE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361617001396",
    },
    {
        "school": "KEESEVILLE PRIMARY SCHOOL",
        "district": "AUSABLE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361617001397",
    },
    {
        "school": "NORTHEASTERN CLINTON MIDDLE SCHOOL",
        "district": "NORTHEASTERN CLINTON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362125003018",
    },
    {
        "school": "NORTHEASTERN CLINTON SENIOR HIGH SCHOOL",
        "district": "NORTHEASTERN CLINTON CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362125003019",
    },
    {
        "school": "MOOERS ELEMENTARY SCHOOL",
        "district": "NORTHEASTERN CLINTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362125003020",
    },
    {
        "school": "ROUSES POINT ELEMENTARY SCHOOL",
        "district": "NORTHEASTERN CLINTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362125003021",
    },
    {
        "school": "NORTHERN ADIRONDACK MIDDLE/HIGH SCHOOL",
        "district": "NORTHERN ADIRONDACK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362126003024",
    },
    {
        "school": "NORTHERN ADIRONDACK ELEMENTARY SCHOOL",
        "district": "NORTHERN ADIRONDACK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362126004489",
    },
    {
        "school": "PERU ELEMENTARY SCHOOL",
        "district": "PERU CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362283003208",
    },
    {
        "school": "PERU HIGH SCHOOL",
        "district": "PERU CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362283003209",
    },
    {
        "school": "BAILEY AVENUE SCHOOL",
        "district": "PLATTSBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362328003258",
    },
    {
        "school": "ARTHUR P MOMOT ELEMENTARY SCHOOL",
        "district": "PLATTSBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362328003260",
    },
    {
        "school": "OAK STREET SCHOOL",
        "district": "PLATTSBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362328003261",
    },
    {
        "school": "STAFFORD MIDDLE SCHOOL",
        "district": "PLATTSBURGH CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362328003262",
    },
    {
        "school": "PLATTSBURGH SENIOR HIGH SCHOOL",
        "district": "PLATTSBURGH CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362328003263",
    },
    {
        "school": "CLINTON-ESSEX-WARREN-WASHINGTON BOCES",
        "district": "CLINTON-ESSEX-WARREN-WASHINGTON BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368022004628",
    },
    {
        "school": "AUSABLE FORKS ELEMENTARY SCHOOL",
        "district": "AUSABLE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361617001395",
    },
    {
        "school": "VAIL FARM ELEMENTARY SCHOOL",
        "district": "ARLINGTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360327005596",
    },
    {
        "school": "UNION VALE MIDDLE SCHOOL",
        "district": "ARLINGTON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360327005597",
    },
    {
        "school": "ORCHARD VIEW ALTERNATIVE HIGH SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "362988005598",
    },
    {
        "school": "WEBUTUCK ELEMENTARY SCHOOL",
        "district": "NORTHEAST CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363039004971",
    },
    {
        "school": "CORNWALL MIDDLE SCHOOL",
        "district": "CORNWALL CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360843005575",
    },
    {
        "school": "ARTHUR S MAY SCHOOL",
        "district": "ARLINGTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360327000086",
    },
    {
        "school": "ARLINGTON HIGH SCHOOL",
        "district": "ARLINGTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360327000088",
    },
    {
        "school": "BEEKMAN SCHOOL",
        "district": "ARLINGTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360327000089",
    },
    {
        "school": "NOXON ROAD ELEMENTARY SCHOOL",
        "district": "ARLINGTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360327000092",
    },
    {
        "school": "OVERLOOK PRIMARY SCHOOL",
        "district": "ARLINGTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360327000093",
    },
    {
        "school": "TRAVER ROAD PRIMARY SCHOOL",
        "district": "ARLINGTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360327000095",
    },
    {
        "school": "WEST ROAD/D'AQUANNIS INTERMEDIATE SCHOOL",
        "district": "ARLINGTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360327000096",
    },
    {
        "school": "LAGRANGE MIDDLE SCHOOL",
        "district": "ARLINGTON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360327003266",
    },
    {
        "school": "TITUSVILLE INTERMEDIATE",
        "district": "ARLINGTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360327003268",
    },
    {
        "school": "BEACON HIGH SCHOOL",
        "district": "BEACON CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360414000177",
    },
    {
        "school": "GLENHAM SCHOOL",
        "district": "BEACON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360414000178",
    },
    {
        "school": "J V FORRESTAL ELEMENTARY SCHOOL",
        "district": "BEACON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360414000179",
    },
    {
        "school": "ROMBOUT MIDDLE SCHOOL",
        "district": "BEACON CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360414000180",
    },
    {
        "school": "SARGENT SCHOOL",
        "district": "BEACON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360414000181",
    },
    {
        "school": "SOUTH AVENUE SCHOOL",
        "district": "BEACON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360414000182",
    },
    {
        "school": "HAGAN SCHOOL",
        "district": "SPACKENKILL UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360650000430",
    },
    {
        "school": "NASSAU SCHOOL",
        "district": "SPACKENKILL UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360650000432",
    },
    {
        "school": "ORVILLE A TODD MIDDLE SCHOOL",
        "district": "SPACKENKILL UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360650000433",
    },
    {
        "school": "SPACKENKILL HIGH SCHOOL",
        "district": "SPACKENKILL UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360650000434",
    },
    {
        "school": "DOVER ELEMENTARY SCHOOL",
        "district": "DOVER UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360921000706",
    },
    {
        "school": "DOVER HIGH SCHOOL",
        "district": "DOVER UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360921000707",
    },
    {
        "school": "WINGDALE ELEMENTARY SCHOOL",
        "district": "DOVER UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360921000708",
    },
    {
        "school": "DOVER MIDDLE SCHOOL",
        "district": "DOVER UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360921004332",
    },
    {
        "school": "FRANKLIN D ROOSEVELT SENIOR HIGH SCHOOL",
        "district": "HYDE PARK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361518001269",
    },
    {
        "school": "HAVILAND MIDDLE SCHOOL",
        "district": "HYDE PARK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361518001270",
    },
    {
        "school": "NETHERWOOD SCHOOL",
        "district": "HYDE PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361518001272",
    },
    {
        "school": "NORTH PARK ELEMENTARY SCHOOL",
        "district": "HYDE PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361518001273",
    },
    {
        "school": "RALPH R SMITH SCHOOL",
        "district": "HYDE PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361518001274",
    },
    {
        "school": "VIOLET AVENUE SCHOOL",
        "district": "HYDE PARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361518001276",
    },
    {
        "school": "ALDEN PLACE ELEMENTARY SCHOOL",
        "district": "MILLBROOK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361938001770",
    },
    {
        "school": "ELM DRIVE ELEMENTARY SCHOOL",
        "district": "MILLBROOK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361938001771",
    },
    {
        "school": "MILLBROOK MIDDLE SCHOOL",
        "district": "MILLBROOK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361938001772",
    },
    {
        "school": "PAWLING ELEMENTARY SCHOOL",
        "district": "PAWLING CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362253003172",
    },
    {
        "school": "PAWLING HIGH SCHOOL",
        "district": "PAWLING CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362253003173",
    },
    {
        "school": "PAWLING MIDDLE SCHOOL",
        "district": "PAWLING CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362253003255",
    },
    {
        "school": "SEYMOUR SMITH INTERMEDIATE LEARNING CENTER",
        "district": "PINE PLAINS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362304003230",
    },
    {
        "school": "STISSING MOUNTAIN JUNIOR/SENIOR HIGH SCHOOL",
        "district": "PINE PLAINS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362304003231",
    },
    {
        "school": "COLD SPRING EARLY LEARNING CENTER",
        "district": "PINE PLAINS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362304004530",
    },
    {
        "school": "WARRING MAGNET ACADEMY OF SCIENCE AND TECHNOLOGY",
        "district": "POUGHKEEPSIE CITY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362376003302",
    },
    {
        "school": "G W KRIEGER SCHOOL",
        "district": "POUGHKEEPSIE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362376003304",
    },
    {
        "school": "GOV GEORGE CLINTON SCHOOL",
        "district": "POUGHKEEPSIE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362376003305",
    },
    {
        "school": "MORSE YOUNG MAGNET SCHOOL",
        "district": "POUGHKEEPSIE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362376003306",
    },
    {
        "school": "POUGHKEEPSIE HIGH SCHOOL",
        "district": "POUGHKEEPSIE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362376003307",
    },
    {
        "school": "POUGHKEEPSIE MIDDLE SCHOOL",
        "district": "POUGHKEEPSIE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362376003308",
    },
    {
        "school": "COLUMBUS SCHOOL",
        "district": "POUGHKEEPSIE CITY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362376004326",
    },
    {
        "school": "SMITH EARLY LEARNING CENTER",
        "district": "POUGHKEEPSIE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362376004616",
    },
    {
        "school": "MILL ROAD-INTERMEDIATE GRADES",
        "district": "RED HOOK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362424000225",
    },
    {
        "school": "MILL ROAD-PRIMARY GRADES",
        "district": "RED HOOK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362424000247",
    },
    {
        "school": "LINDEN AVENUE MIDDLE SCHOOL",
        "district": "RED HOOK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362424003333",
    },
    {
        "school": "RED HOOK SENIOR HIGH SCHOOL",
        "district": "RED HOOK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362424003334",
    },
    {
        "school": "BULKELEY MIDDLE SCHOOL",
        "district": "RHINEBECK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362448003343",
    },
    {
        "school": "CHANCELLOR LIVINGSTON ELEMENTARY SCHOOL",
        "district": "RHINEBECK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362448003344",
    },
    {
        "school": "RHINEBECK SENIOR HIGH SCHOOL",
        "district": "RHINEBECK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362448003345",
    },
    {
        "school": "KINRY ROAD ELEMENTARY SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988001118",
    },
    {
        "school": "BRINCKERHOFF ELEMENTARY SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004013",
    },
    {
        "school": "FISHKILL ELEMENTARY SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004014",
    },
    {
        "school": "FISHKILL PLAINS ELEMENTARY SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004015",
    },
    {
        "school": "GAYHEAD SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004016",
    },
    {
        "school": "JAMES S EVANS ELEMENTARY SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004017",
    },
    {
        "school": "JOHN JAY SENIOR HIGH SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004018",
    },
    {
        "school": "MYERS CORNERS SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004020",
    },
    {
        "school": "OAK GROVE ELEMENTARY SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004021",
    },
    {
        "school": "ROY C KETCHAM SENIOR HIGH SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004022",
    },
    {
        "school": "SHEAFE ROAD ELEMENTARY SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004023",
    },
    {
        "school": "VAN WYCK JUNIOR HIGH SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004024",
    },
    {
        "school": "VASSAR ROAD ELEMENTARY SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004025",
    },
    {
        "school": "WAPPINGERS JUNIOR HIGH SCHOOL",
        "district": "WAPPINGERS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362988004026",
    },
    {
        "school": "WEBUTUCK HIGH SCHOOL",
        "district": "NORTHEAST CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363039004093",
    },
    {
        "school": "DUTCHESS BOCES",
        "district": "DUTCHESS BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368028004630",
    },
    {
        "school": "KIRYAS JOEL VILLAGE SCHOOL",
        "district": "KIRYAS JOEL VILLAGE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360475804758",
    },
    {
        "school": "CHESTER ELEMENTARY SCHOOL",
        "district": "CHESTER UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360738000526",
    },
    {
        "school": "CHESTER ACADEMY-MIDDLE/HIGH SCHOOL",
        "district": "CHESTER UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360738000527",
    },
    {
        "school": "CORNWALL ELEMENTARY SCHOOL",
        "district": "CORNWALL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360843000641",
    },
    {
        "school": "CORNWALL CENTRAL HIGH SCHOOL",
        "district": "CORNWALL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360843000642",
    },
    {
        "school": "CORNWALL-ON-HUDSON ELEMENTARY SCHOOL",
        "district": "CORNWALL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360843000643",
    },
    {
        "school": "WILLOW AVENUE ELEMENTARY SCHOOL",
        "district": "CORNWALL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360843000644",
    },
    {
        "school": "GOSHEN CENTRAL HIGH SCHOOL",
        "district": "GOSHEN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361233000995",
    },
    {
        "school": "GOSHEN INTERMEDIATE SCHOOL",
        "district": "GOSHEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361233000996",
    },
    {
        "school": "C J HOOKER MIDDLE SCHOOL",
        "district": "GOSHEN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361233000997",
    },
    {
        "school": "SCOTCHTOWN AVENUE SCHOOL",
        "district": "GOSHEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361233000998",
    },
    {
        "school": "GREENWOOD LAKE MIDDLE SCHOOL",
        "district": "GREENWOOD LAKE UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361296001060",
    },
    {
        "school": "GREENWOOD LAKE ELEMENTARY SCHOOL",
        "district": "GREENWOOD LAKE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361296004389",
    },
    {
        "school": "HIGHLAND FALLS INTERMEDIATE SCHOOL",
        "district": "HIGHLAND FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361443001195",
    },
    {
        "school": "JAMES I O'NEILL HIGH SCHOOL",
        "district": "HIGHLAND FALLS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361443001196",
    },
    {
        "school": "FORT MONTGOMERY ELEMENTARY SCHOOL",
        "district": "HIGHLAND FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361443004821",
    },
    {
        "school": "WILLIAM A CARTER SCHOOL",
        "district": "MIDDLETOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361932001763",
    },
    {
        "school": "MIDDLETOWN TWIN TOWERS MIDDLE SCHOOL",
        "district": "MIDDLETOWN CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361932001765",
    },
    {
        "school": "MIDDLETOWN HIGH SCHOOL",
        "district": "MIDDLETOWN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361932001766",
    },
    {
        "school": "MONHAGEN MIDDLE SCHOOL",
        "district": "MIDDLETOWN CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361932003198",
    },
    {
        "school": "MAPLE HILL ELEMENTARY SCHOOL",
        "district": "MIDDLETOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361932003199",
    },
    {
        "school": "MINISINK VALLEY ELEMENTARY SCHOOL",
        "district": "MINISINK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361956001783",
    },
    {
        "school": "MINISINK VALLEY HIGH SCHOOL",
        "district": "MINISINK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361956001784",
    },
    {
        "school": "MINISINK VALLEY MIDDLE SCHOOL",
        "district": "MINISINK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361956001785",
    },
    {
        "school": "OTISVILLE ELEMENTARY SCHOOL",
        "district": "MINISINK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361956004722",
    },
    {
        "school": "MINISINK VALLEY INTERMEDIATE SCHOOL",
        "district": "MINISINK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361956004822",
    },
    {
        "school": "CENTRAL VALLEY ELEMENTARY SCHOOL",
        "district": "MONROE-WOODBURY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361965001792",
    },
    {
        "school": "MONROE-WOODBURY MIDDLE SCHOOL",
        "district": "MONROE-WOODBURY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361965001794",
    },
    {
        "school": "MONROE-WOODBURY HIGH SCHOOL",
        "district": "MONROE-WOODBURY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361965001795",
    },
    {
        "school": "NORTH MAIN STREET SCHOOL",
        "district": "MONROE-WOODBURY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361965001796",
    },
    {
        "school": "PINE TREE ELEMENTARY SCHOOL",
        "district": "MONROE-WOODBURY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361965001797",
    },
    {
        "school": "SMITH CLOVE ELEMENTARY SCHOOL",
        "district": "MONROE-WOODBURY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361965004198",
    },
    {
        "school": "SAPPHIRE ELEMENTARY SCHOOL",
        "district": "MONROE-WOODBURY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361965004823",
    },
    {
        "school": "BEREA ELEMENTARY SCHOOL",
        "district": "VALLEY CENTRAL SCHOOL DISTRICT (MONTGOMERY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361968001798",
    },
    {
        "school": "EAST COLDENHAM ELEMENTARY SCHOOL",
        "district": "VALLEY CENTRAL SCHOOL DISTRICT (MONTGOMERY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361968001799",
    },
    {
        "school": "MONTGOMERY ELEMENTARY SCHOOL",
        "district": "VALLEY CENTRAL SCHOOL DISTRICT (MONTGOMERY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361968001801",
    },
    {
        "school": "VALLEY CENTRAL MIDDLE SCHOOL",
        "district": "VALLEY CENTRAL SCHOOL DISTRICT (MONTGOMERY)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361968001802",
    },
    {
        "school": "VALLEY CENTRAL HIGH SCHOOL",
        "district": "VALLEY CENTRAL SCHOOL DISTRICT (MONTGOMERY)",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361968001803",
    },
    {
        "school": "WALDEN ELEMENTARY SCHOOL",
        "district": "VALLEY CENTRAL SCHOOL DISTRICT (MONTGOMERY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361968001804",
    },
    {
        "school": "BALMVILLE SCHOOL",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070002901",
    },
    {
        "school": "FOSTERTOWN ETC MAGNET SCHOOL",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070002903",
    },
    {
        "school": "GARDNERTOWN LEADERSHIP  ACADEMY ELEMENTARY SCHOOL",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070002904",
    },
    {
        "school": "GAMS HIGH TECH MAGNET SCHOOL",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070002905",
    },
    {
        "school": "MEADOW HILL GLOBAL EXPLORATIONS MAGNET SCHOOL",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070002907",
    },
    {
        "school": "HORIZON-ON-THE-HUDSON MAGNET SCHOOL",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070002908",
    },
    {
        "school": "NEW WINDSOR SCHOOL",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070002909",
    },
    {
        "school": "NEWBURGH FREE ACADEMY",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070002910",
    },
    {
        "school": "SOUTH MIDDLE SCHOOL",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070002912",
    },
    {
        "school": "TEMPLE HILL SCHOOL",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070002913",
    },
    {
        "school": "VAILS GATE STEAM ACADEMY",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070002915",
    },
    {
        "school": "HERITAGE MIDDLE SCHOOL",
        "district": "NEWBURGH CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362070004486",
    },
    {
        "school": "CIRCLEVILLE ELEMENTARY SCHOOL",
        "district": "PINE BUSH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362301003223",
    },
    {
        "school": "CIRCLEVILLE MIDDLE SCHOOL",
        "district": "PINE BUSH CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362301003224",
    },
    {
        "school": "CRISPELL MIDDLE SCHOOL",
        "district": "PINE BUSH CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362301003225",
    },
    {
        "school": "E J RUSSELL ELEMENTARY SCHOOL",
        "district": "PINE BUSH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362301003226",
    },
    {
        "school": "PAKANASINK ELEMENTARY SCHOOL",
        "district": "PINE BUSH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362301003227",
    },
    {
        "school": "PINE BUSH ELEMENTARY SCHOOL",
        "district": "PINE BUSH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362301004820",
    },
    {
        "school": "ANNA S KUHL ELEMENTARY SCHOOL",
        "district": "PORT JERVIS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362352003283",
    },
    {
        "school": "PORT JERVIS MIDDLE SCHOOL",
        "district": "PORT JERVIS CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362352003284",
    },
    {
        "school": "N A HAMILTON BICENTENNIAL SCHOOL",
        "district": "PORT JERVIS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362352003285",
    },
    {
        "school": "PORT JERVIS SENIOR HIGH SCHOOL",
        "district": "PORT JERVIS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362352003286",
    },
    {
        "school": "S S SEWARD INSTITUTE",
        "district": "FLORIDA UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362532003497",
    },
    {
        "school": "GOLDEN HILL ELEMENTARY",
        "district": "FLORIDA UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362532004329",
    },
    {
        "school": "GEORGE F BAKER HIGH SCHOOL",
        "district": "TUXEDO UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362919003930",
    },
    {
        "school": "GEORGE GRANT MASON ELEMENTARY SCHOOL",
        "district": "TUXEDO UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362919004753",
    },
    {
        "school": "PARK AVENUE ELEMENTARY SCHOOL",
        "district": "WARWICK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362997004032",
    },
    {
        "school": "WARWICK VALLEY HIGH SCHOOL",
        "district": "WARWICK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362997004034",
    },
    {
        "school": "WARWICK VALLEY MIDDLE SCHOOL",
        "district": "WARWICK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362997004035",
    },
    {
        "school": "SANFORDVILLE ELEMENTARY SCHOOL",
        "district": "WARWICK VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362997004836",
    },
    {
        "school": "LITTLE BRITAIN ELEMENTARY SCHOOL",
        "district": "WASHINGTONVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363003004036",
    },
    {
        "school": "ROUND HILL ELEMENTARY SCHOOL",
        "district": "WASHINGTONVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363003004037",
    },
    {
        "school": "TAFT ELEMENTARY SCHOOL",
        "district": "WASHINGTONVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363003004038",
    },
    {
        "school": "WASHINGTONVILLE MIDDLE SCHOOL",
        "district": "WASHINGTONVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363003004039",
    },
    {
        "school": "WASHINGTONVILLE SENIOR HIGH SCHOOL",
        "district": "WASHINGTONVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363003004040",
    },
    {
        "school": "ORANGE-ULSTER BOCES",
        "district": "ORANGE-ULSTER BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368062004647",
    },
    {
        "school": "PINE BUSH SENIOR HIGH SCHOOL",
        "district": "PINE BUSH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362301003228",
    },
    {
        "school": "URBAN CHOICE CHARTER SCHOOL",
        "district": "URBAN CHOICE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360013405756",
    },
    {
        "school": "EAST IRONDEQUOIT MIDDLE SCHOOL",
        "district": "EAST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360969005576",
    },
    {
        "school": "CANAL VIEW ELEMENTARY SCHOOL",
        "district": "SPENCERPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362778005589",
    },
    {
        "school": "BLOOMFIELD MIDDLE SCHOOL",
        "district": "EAST BLOOMFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360492005737",
    },
    {
        "school": "VICTOR EARLY CHILDHOOD SCHOOL",
        "district": "VICTOR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362964005334",
    },
    {
        "school": "AVON PRIMARY SCHOOL",
        "district": "AVON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360366000118",
    },
    {
        "school": "AVON HIGH SCHOOL",
        "district": "AVON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360366000119",
    },
    {
        "school": "AVON MIDDLE SCHOOL",
        "district": "AVON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360366004863",
    },
    {
        "school": "CALEDONIA-MUMFORD ELEMENTARY SCHOOL",
        "district": "CALEDONIA-MUMFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360618000398",
    },
    {
        "school": "CALEDONIA-MUMFORD HIGH SCHOOL",
        "district": "CALEDONIA-MUMFORD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360618000399",
    },
    {
        "school": "CALEDONIA-MUMFORD MIDDLE SCHOOL",
        "district": "CALEDONIA-MUMFORD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360618002838",
    },
    {
        "school": "DANSVILLE PRIMARY SCHOOL",
        "district": "DANSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360879000666",
    },
    {
        "school": "DANSVILLE HIGH SCHOOL",
        "district": "DANSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360879000667",
    },
    {
        "school": "ELLIS B HYDE ELEMENTARY SCHOOL",
        "district": "DANSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360879004385",
    },
    {
        "school": "GENESEO MIDDLE SCHOOL HIGH SCHOOL",
        "district": "GENESEO CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361194000961",
    },
    {
        "school": "GENESEO ELEMENTARY SCHOOL",
        "district": "GENESEO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361194004553",
    },
    {
        "school": "LIMA ELEMENTARY SCHOOL",
        "district": "HONEOYE FALLS-LIMA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361470001224",
    },
    {
        "school": "LIVONIA ELEMENTARY SCHOOL",
        "district": "LIVONIA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361764001577",
    },
    {
        "school": "LIVONIA MIDDLE/HIGH SCHOOL",
        "district": "LIVONIA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361764001578",
    },
    {
        "school": "MOUNT MORRIS MIDDLE/SENIOR HIGH SCHOOL",
        "district": "MOUNT MORRIS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362001004344",
    },
    {
        "school": "MOUNT MORRIS ELEMENTARY SCHOOL",
        "district": "MOUNT MORRIS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362001004515",
    },
    {
        "school": "DALTON-NUNDA PRIMARY SCHOOL",
        "district": "DALTON-NUNDA CENTRAL SCHOOL DISTRICT (KESHEQUA)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362145003046",
    },
    {
        "school": "DALTON-NUNDA SECONDARY SCHOOL",
        "district": "DALTON-NUNDA CENTRAL SCHOOL DISTRICT (KESHEQUA)",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362145003047",
    },
    {
        "school": "DALTON-NUNDA INTERMEDIATE SCHOOL",
        "district": "DALTON-NUNDA CENTRAL SCHOOL DISTRICT (KESHEQUA)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362145003293",
    },
    {
        "school": "YORK CENTRAL ELEMENTARY SCHOOL",
        "district": "YORK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363195004278",
    },
    {
        "school": "YORK MIDDLE/HIGH SCHOOL",
        "district": "YORK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363195004279",
    },
    {
        "school": "EUGENIO MARIA DE HOSTOS CHARTER SCHOOL",
        "district": "EUGENIO MARIA DE HOSTOS CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002604363",
    },
    {
        "school": "GENESEE COMMUNITY CHARTER SCHOOL",
        "district": "GENESEE COMMUNITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360002904376",
    },
    {
        "school": "BRIGHTON HIGH SCHOOL",
        "district": "BRIGHTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360546000272",
    },
    {
        "school": "FRENCH ROAD ELEMENTARY SCHOOL",
        "district": "BRIGHTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360546000273",
    },
    {
        "school": "COUNCIL ROCK PRIMARY SCHOOL",
        "district": "BRIGHTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360546000274",
    },
    {
        "school": "TWELVE CORNERS MIDDLE SCHOOL",
        "district": "BRIGHTON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360546000275",
    },
    {
        "school": "BARCLAY ELEMENTARY SCHOOL",
        "district": "BROCKPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360558000284",
    },
    {
        "school": "BROCKPORT HIGH SCHOOL",
        "district": "BROCKPORT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360558000285",
    },
    {
        "school": "A D OLIVER MIDDLE SCHOOL",
        "district": "BROCKPORT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360558000286",
    },
    {
        "school": "GINTHER ELEMENTARY SCHOOL",
        "district": "BROCKPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360558000287",
    },
    {
        "school": "FRED W HILL SCHOOL",
        "district": "BROCKPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360558004579",
    },
    {
        "school": "CHESTNUT RIDGE ELEMENTARY SCHOOL",
        "district": "CHURCHVILLE-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360753000534",
    },
    {
        "school": "CHURCHVILLE-CHILI SENIOR HIGH SCHOOL",
        "district": "CHURCHVILLE-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360753000536",
    },
    {
        "school": "CHURCHVILLE ELEMENTARY SCHOOL",
        "district": "CHURCHVILLE-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360753000537",
    },
    {
        "school": "FAIRBANKS ROAD ELEMENTARY SCHOOL",
        "district": "CHURCHVILLE-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360753000538",
    },
    {
        "school": "CHURCHVILLE-CHILI MIDDLE SCHOOL",
        "district": "CHURCHVILLE-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360753002002",
    },
    {
        "school": "DURAND-EASTMAN INTERMEDIATE SCHOOL",
        "district": "EAST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360969000740",
    },
    {
        "school": "EASTRIDGE SENIOR HIGH SCHOOL",
        "district": "EAST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360969000741",
    },
    {
        "school": "LAURELTON-PARDEE INTERMEDIATE SCHOOL",
        "district": "EAST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360969000742",
    },
    {
        "school": "IVAN L GREEN PRIMARY SCHOOL",
        "district": "EAST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360969000745",
    },
    {
        "school": "HELENDALE ROAD PRIMARY SCHOOL",
        "district": "EAST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360969004717",
    },
    {
        "school": "EAST ROCHESTER ELEMENTARY SCHOOL",
        "district": "EAST ROCHESTER UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360993000765",
    },
    {
        "school": "EAST ROCHESTER JUNIOR-SENIOR HIGH SCHOOL",
        "district": "EAST ROCHESTER UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360993000767",
    },
    {
        "school": "BROOKS HILL SCHOOL",
        "district": "FAIRPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361089000858",
    },
    {
        "school": "DUDLEY SCHOOL",
        "district": "FAIRPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361089000859",
    },
    {
        "school": "FAIRPORT SENIOR HIGH SCHOOL",
        "district": "FAIRPORT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361089000860",
    },
    {
        "school": "JEFFERSON AVENUE SCHOOL",
        "district": "FAIRPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361089000861",
    },
    {
        "school": "JOHANNA PERRIN MIDDLE SCHOOL",
        "district": "FAIRPORT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361089000862",
    },
    {
        "school": "MARTHA BROWN MIDDLE SCHOOL",
        "district": "FAIRPORT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361089000863",
    },
    {
        "school": "MINERVA DELAND SCHOOL",
        "district": "FAIRPORT CENTRAL SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361089000864",
    },
    {
        "school": "NORTHSIDE SCHOOL",
        "district": "FAIRPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361089000865",
    },
    {
        "school": "FLORENCE BRASSER SCHOOL",
        "district": "GATES-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361188000949",
    },
    {
        "school": "GATES-CHILI HIGH SCHOOL",
        "district": "GATES-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361188000950",
    },
    {
        "school": "GATES-CHILI MIDDLE SCHOOL",
        "district": "GATES-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361188000951",
    },
    {
        "school": "NEIL ARMSTRONG SCHOOL",
        "district": "GATES-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361188000952",
    },
    {
        "school": "PAUL ROAD SCHOOL",
        "district": "GATES-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361188000953",
    },
    {
        "school": "WALT DISNEY SCHOOL",
        "district": "GATES-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361188000955",
    },
    {
        "school": "ARCADIA MIDDLE SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263000475",
    },
    {
        "school": "PINE BROOK ELEMENTARY SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263000486",
    },
    {
        "school": "AUTUMN LANE ELEMENTARY SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001024",
    },
    {
        "school": "BROOKSIDE ELEMENTARY SCHOOL CAMPUS",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001027",
    },
    {
        "school": "BUCKMAN HEIGHTS ELEMENTARY SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001028",
    },
    {
        "school": "CRAIG HILL ELEMENTARY SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001029",
    },
    {
        "school": "ENGLISH VILLAGE ELEMENTARY SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001030",
    },
    {
        "school": "ARCADIA HIGH SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001031",
    },
    {
        "school": "ATHENA HIGH SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001032",
    },
    {
        "school": "ATHENA MIDDLE SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001033",
    },
    {
        "school": "HOLMES ROAD ELEMENTARY SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001034",
    },
    {
        "school": "ODYSSEY ACADEMY",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001035",
    },
    {
        "school": "LAKESHORE ELEMENTARY SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001037",
    },
    {
        "school": "LONGRIDGE SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001038",
    },
    {
        "school": "OLYMPIA HIGH SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001039",
    },
    {
        "school": "PADDY HILL ELEMENTARY SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263001040",
    },
    {
        "school": "WEST RIDGE ELEMENTARY SCHOOL",
        "district": "GREECE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361263004770",
    },
    {
        "school": "QUEST ELEMENTARY SCHOOL",
        "district": "HILTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361446000091",
    },
    {
        "school": "VILLAGE ELEMENTARY SCHOOL",
        "district": "HILTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361446001197",
    },
    {
        "school": "HILTON HIGH SCHOOL",
        "district": "HILTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361446001198",
    },
    {
        "school": "MERTON WILLIAMS MIDDLE SCHOOL",
        "district": "HILTON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361446001200",
    },
    {
        "school": "NORTHWOOD ELEMENTARY SCHOOL",
        "district": "HILTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361446004592",
    },
    {
        "school": "HONEOYE FALLS-LIMA MIDDLE SCHOOL",
        "district": "HONEOYE FALLS-LIMA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361470001222",
    },
    {
        "school": "HONEOYE FALLS-LIMA SENIOR HIGH SCHOOL",
        "district": "HONEOYE FALLS-LIMA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361470001223",
    },
    {
        "school": "MANOR INTERMEDIATE SCHOOL",
        "district": "HONEOYE FALLS-LIMA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361470001225",
    },
    {
        "school": "BRIARWOOD SCHOOL",
        "district": "WEST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361539001298",
    },
    {
        "school": "COLEBROOK SCHOOL",
        "district": "WEST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361539001300",
    },
    {
        "school": "DAKE JUNIOR HIGH SCHOOL",
        "district": "WEST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361539001301",
    },
    {
        "school": "IRONDEQUOIT HIGH SCHOOL",
        "district": "WEST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361539001302",
    },
    {
        "school": "IROQUOIS MIDDLE SCHOOL",
        "district": "WEST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361539001303",
    },
    {
        "school": "LISTWOOD SCHOOL",
        "district": "WEST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361539001305",
    },
    {
        "school": "ROGERS MIDDLE SCHOOL",
        "district": "WEST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361539001308",
    },
    {
        "school": "SOUTHLAWN SCHOOL",
        "district": "WEST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361539001310",
    },
    {
        "school": "SENECA SCHOOL",
        "district": "WEST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361539004593",
    },
    {
        "school": "BROOKVIEW SCHOOL",
        "district": "WEST IRONDEQUOIT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361539004594",
    },
    {
        "school": "BAY TRAIL MIDDLE SCHOOL",
        "district": "PENFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362271003191",
    },
    {
        "school": "COBBLES ELEMENTARY SCHOOL",
        "district": "PENFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362271003192",
    },
    {
        "school": "HARRIS HILL ELEMENTARY SCHOOL",
        "district": "PENFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362271003194",
    },
    {
        "school": "INDIAN LANDING ELEMENTARY SCHOOL",
        "district": "PENFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362271003195",
    },
    {
        "school": "PENFIELD SENIOR HIGH SCHOOL",
        "district": "PENFIELD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362271003196",
    },
    {
        "school": "SCRIBNER ROAD ELEMENTARY SCHOOL",
        "district": "PENFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362271003197",
    },
    {
        "school": "ALLEN CREEK SCHOOL",
        "district": "PITTSFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362316003235",
    },
    {
        "school": "JEFFERSON ROAD SCHOOL",
        "district": "PITTSFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362316003238",
    },
    {
        "school": "PARK ROAD SCHOOL",
        "district": "PITTSFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362316003240",
    },
    {
        "school": "PITTSFORD-MENDON HIGH SCHOOL",
        "district": "PITTSFORD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362316003241",
    },
    {
        "school": "PITTSFORD SUTHERLAND HIGH SCHOOL",
        "district": "PITTSFORD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362316003242",
    },
    {
        "school": "THORNELL ROAD SCHOOL",
        "district": "PITTSFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362316003243",
    },
    {
        "school": "BARKER ROAD MIDDLE SCHOOL",
        "district": "PITTSFORD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362316004490",
    },
    {
        "school": "MENDON CENTER ELEMENTARY SCHOOL",
        "district": "PITTSFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362316004744",
    },
    {
        "school": "SCHOOL 15-CHILDREN'S SCHOOL OF ROCHESTER (THE)",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475001623",
    },
    {
        "school": "SCHOOL 20-HENRY LOMB SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475001626",
    },
    {
        "school": "SCHOOL 57-EARLY CHILDHOOD SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475001628",
    },
    {
        "school": "SCHOOL 45-MARY MCLEOD BETHUNE",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475002005",
    },
    {
        "school": "EAST UPPER HIGH SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003363",
    },
    {
        "school": "JAMES MONROE HIGH SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003371",
    },
    {
        "school": "SCHOOL 2-CLARA BARTON",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003377",
    },
    {
        "school": "SCHOOL 3-NATHANIEL ROCHESTER",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003378",
    },
    {
        "school": "SCHOOL 4-GEORGE MATHER FORBES",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003379",
    },
    {
        "school": "SCHOOL 5-JOHN WILLIAMS",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003380",
    },
    {
        "school": "SCHOOL 7-VIRGIL GRISSOM",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003382",
    },
    {
        "school": "SCHOOL 8-ROBERTO CLEMENTE",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003383",
    },
    {
        "school": "SCHOOL 9-DR MARTIN LUTHER KING JR",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003384",
    },
    {
        "school": "ANNA MURRAY-DOUGLASS ACADEMY",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003386",
    },
    {
        "school": "SCHOOL 16-JOHN WALTON SPENCER",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003390",
    },
    {
        "school": "SCHOOL 17-ENRICO FERMI",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003391",
    },
    {
        "school": "SCHOOL 19-DR CHARLES T LUNSFORD",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003392",
    },
    {
        "school": "SCHOOL 23-FRANCIS PARKER",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003396",
    },
    {
        "school": "SCHOOL 25-NATHANIEL HAWTHORNE",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003398",
    },
    {
        "school": "SCHOOL 29-ADLAI E STEVENSON",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003401",
    },
    {
        "school": "SCHOOL 33-AUDUBON",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003404",
    },
    {
        "school": "SCHOOL 34-DR LOUIS A CERULLI",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003405",
    },
    {
        "school": "SCHOOL 35-PINNACLE",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003406",
    },
    {
        "school": "SCHOOL 39-ANDREW J TOWNSON",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003410",
    },
    {
        "school": "SCHOOL 42-ABELARD REYNOLDS",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003413",
    },
    {
        "school": "SCHOOL 43-THEODORE ROOSEVELT",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003414",
    },
    {
        "school": "SCHOOL 44-LINCOLN PARK",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003415",
    },
    {
        "school": "SCHOOL 46-CHARLES CARROLL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003416",
    },
    {
        "school": "SCHOOL 50-HELEN BARRETT MONTGOMERY",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003418",
    },
    {
        "school": "SCHOOL 52-FRANK FOWLER DOW",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003419",
    },
    {
        "school": "SCHOOL WITHOUT WALLS",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003420",
    },
    {
        "school": "JOSEPH C WILSON MAGNET HIGH SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003422",
    },
    {
        "school": "SCHOOL 58-WORLD OF INQUIRY SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475003424",
    },
    {
        "school": "SCHOOL 53 MONTESSORI ACADEMY",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475004361",
    },
    {
        "school": "SCHOOL 22-LINCOLN SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475004423",
    },
    {
        "school": "SCHOOL 28-HENRY HUDSON",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475004424",
    },
    {
        "school": "SCHOOL OF THE ARTS",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475004787",
    },
    {
        "school": "SCHOOL 54-FLOWER CITY COMMUNITY SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475004805",
    },
    {
        "school": "HENRY V BURGER JUNIOR HIGH SCHOOL",
        "district": "RUSH-HENRIETTA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362517000492",
    },
    {
        "school": "DAVID B CRANE ELEMENTARY SCHOOL",
        "district": "RUSH-HENRIETTA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362517003480",
    },
    {
        "school": "ETHEL K FYLE ELEMENTARY SCHOOL",
        "district": "RUSH-HENRIETTA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362517003482",
    },
    {
        "school": "FLOYD S WINSLOW ELEMENTARY SCHOOL",
        "district": "RUSH-HENRIETTA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362517003483",
    },
    {
        "school": "RUSH-HENRIETTA SENIOR HIGH SCHOOL",
        "district": "RUSH-HENRIETTA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362517003485",
    },
    {
        "school": "MONICA B LEARY ELEMENTARY SCHOOL",
        "district": "RUSH-HENRIETTA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362517003486",
    },
    {
        "school": "CHARLES H ROTH JUNIOR HIGH SCHOOL",
        "district": "RUSH-HENRIETTA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362517004534",
    },
    {
        "school": "EMMA E SHERMAN ELEMENTARY SCHOOL",
        "district": "RUSH-HENRIETTA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362517004566",
    },
    {
        "school": "A M COSGROVE MIDDLE SCHOOL",
        "district": "SPENCERPORT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362778003761",
    },
    {
        "school": "SPENCERPORT HIGH SCHOOL",
        "district": "SPENCERPORT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362778003762",
    },
    {
        "school": "LEO BERNABI SCHOOL",
        "district": "SPENCERPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362778003763",
    },
    {
        "school": "TERRY TAYLOR ELEMENTARY SCHOOL",
        "district": "SPENCERPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362778003765",
    },
    {
        "school": "WILLIAM C MUNN SCHOOL",
        "district": "SPENCERPORT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362778003766",
    },
    {
        "school": "SPRY MIDDLE SCHOOL",
        "district": "WEBSTER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363036001207",
    },
    {
        "school": "WILLINK MIDDLE SCHOOL",
        "district": "WEBSTER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363036004081",
    },
    {
        "school": "KLEM ROAD NORTH ELEMENTARY SCHOOL",
        "district": "WEBSTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363036004083",
    },
    {
        "school": "KLEM ROAD SOUTH ELEMENTARY SCHOOL",
        "district": "WEBSTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363036004084",
    },
    {
        "school": "PLANK ROAD SOUTH ELEMENTARY SCHOOL",
        "district": "WEBSTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363036004086",
    },
    {
        "school": "WEBSTER-SCHROEDER HIGH SCHOOL",
        "district": "WEBSTER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363036004087",
    },
    {
        "school": "STATE ROAD ELEMENTARY SCHOOL",
        "district": "WEBSTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363036004089",
    },
    {
        "school": "DEWITT ROAD ELEMENTARY SCHOOL",
        "district": "WEBSTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363036004428",
    },
    {
        "school": "PLANK ROAD NORTH ELEMENTARY SCHOOL",
        "district": "WEBSTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363036004709",
    },
    {
        "school": "SCHLEGEL ROAD ELEMENTARY SCHOOL",
        "district": "WEBSTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363036004792",
    },
    {
        "school": "THOMAS HIGH SCHOOL",
        "district": "WEBSTER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363036004865",
    },
    {
        "school": "T J CONNOR ELEMENTARY SCHOOL",
        "district": "WHEATLAND-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363117004171",
    },
    {
        "school": "WHEATLAND-CHILI HIGH SCHOOL",
        "district": "WHEATLAND-CHILI CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363117004172",
    },
    {
        "school": "MONROE 1 BOCES",
        "district": "MONROE 1 BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368050004641",
    },
    {
        "school": "MONROE 2-ORLEANS BOCES",
        "district": "MONROE 2-ORLEANS BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368052004642",
    },
    {
        "school": "BLOOMFIELD ELEMENTARY SCHOOL",
        "district": "EAST BLOOMFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360492000236",
    },
    {
        "school": "BLOOMFIELD HIGH SCHOOL",
        "district": "EAST BLOOMFIELD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360492000237",
    },
    {
        "school": "CANANDAIGUA ACADEMY",
        "district": "CANANDAIGUA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360633000414",
    },
    {
        "school": "CANANDAIGUA PRIMARY-ELEMENTARY SCHOOL",
        "district": "CANANDAIGUA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360633000415",
    },
    {
        "school": "CANANDAIGUA MIDDLE SCHOOL",
        "district": "CANANDAIGUA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360633000416",
    },
    {
        "school": "GENEVA MIDDLE SCHOOL",
        "district": "GENEVA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361197000963",
    },
    {
        "school": "GENEVA HIGH SCHOOL",
        "district": "GENEVA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361197000964",
    },
    {
        "school": "NORTH STREET ELEMENTARY SCHOOL",
        "district": "GENEVA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361197000965",
    },
    {
        "school": "WEST STREET ELEMENTARY SCHOOL",
        "district": "GENEVA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361197000966",
    },
    {
        "school": "GORHAM ELEMENTARY SCHOOL",
        "district": "GORHAM-MIDDLESEX CENTRAL SCHOOL DISTRICT (MARCUS WHITMAN)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361230000992",
    },
    {
        "school": "MARCUS WHITMAN HIGH SCHOOL",
        "district": "GORHAM-MIDDLESEX CENTRAL SCHOOL DISTRICT (MARCUS WHITMAN)",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361230000993",
    },
    {
        "school": "MARCUS WHITMAN MIDDLE SCHOOL",
        "district": "GORHAM-MIDDLESEX CENTRAL SCHOOL DISTRICT (MARCUS WHITMAN)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361230001418",
    },
    {
        "school": "HONEOYE ELEMENTARY SCHOOL",
        "district": "HONEOYE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361467001220",
    },
    {
        "school": "HONEOYE MIDDLE/HIGH SCHOOL",
        "district": "HONEOYE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361467001221",
    },
    {
        "school": "NAPLES ELEMENTARY SCHOOL",
        "district": "NAPLES CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362022001855",
    },
    {
        "school": "NAPLES HIGH SCHOOL",
        "district": "NAPLES CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362022001856",
    },
    {
        "school": "MIDLAKES INTERMEDIATE SCHOOL",
        "district": "PHELPS-CLIFTON SPRINGS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362289003213",
    },
    {
        "school": "MIDLAKES HIGH SCHOOL",
        "district": "PHELPS-CLIFTON SPRINGS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362289003214",
    },
    {
        "school": "MIDLAKES PRIMARY SCHOOL",
        "district": "PHELPS-CLIFTON SPRINGS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362289003215",
    },
    {
        "school": "MIDLAKES MIDDLE SCHOOL",
        "district": "PHELPS-CLIFTON SPRINGS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362289003216",
    },
    {
        "school": "RED JACKET ELEMENTARY SCHOOL",
        "district": "MANCHESTER-SHORTSVILLE CENTRAL SCHOOL DISTRICT (RED JACKET)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362427003335",
    },
    {
        "school": "RED JACKET HIGH SCHOOL",
        "district": "MANCHESTER-SHORTSVILLE CENTRAL SCHOOL DISTRICT (RED JACKET)",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362427003336",
    },
    {
        "school": "RED JACKET MIDDLE SCHOOL",
        "district": "MANCHESTER-SHORTSVILLE CENTRAL SCHOOL DISTRICT (RED JACKET)",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362427003397",
    },
    {
        "school": "VICTOR INTERMEDIATE SCHOOL",
        "district": "VICTOR CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362964003993",
    },
    {
        "school": "VICTOR JUNIOR HIGH SCHOOL",
        "district": "VICTOR CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362964003994",
    },
    {
        "school": "VICTOR PRIMARY SCHOOL",
        "district": "VICTOR CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362964003995",
    },
    {
        "school": "VICTOR SENIOR HIGH SCHOOL",
        "district": "VICTOR CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362964003996",
    },
    {
        "school": "CHARLES D'AMICO HIGH SCHOOL",
        "district": "ALBION CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360252000033",
    },
    {
        "school": "CARL I BERGERSON MIDDLE SCHOOL",
        "district": "ALBION CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360252000034",
    },
    {
        "school": "RONALD L SODOMA ELEMENTARY SCHOOL",
        "district": "ALBION CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360252000035",
    },
    {
        "school": "HOLLEY JUNIOR SENIOR HIGH SCHOOL",
        "district": "HOLLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361461001213",
    },
    {
        "school": "HOLLEY ELEMENTARY SCHOOL",
        "district": "HOLLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361461004207",
    },
    {
        "school": "KENDALL ELEMENTARY SCHOOL",
        "district": "KENDALL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361620001398",
    },
    {
        "school": "KENDALL JUNIOR-SENIOR HIGH SCHOOL",
        "district": "KENDALL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361620001399",
    },
    {
        "school": "L A WEBBER MIDDLE-HIGH SCHOOL",
        "district": "LYNDONVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361797001612",
    },
    {
        "school": "LYNDONVILLE ELEMENTARY SCHOOL",
        "district": "LYNDONVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361797001613",
    },
    {
        "school": "CLIFFORD WISE INTERMEDIATE/MIDDLE SCHOOL",
        "district": "MEDINA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361896001715",
    },
    {
        "school": "MEDINA HIGH SCHOOL",
        "district": "MEDINA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361896001716",
    },
    {
        "school": "OAK ORCHARD SCHOOL",
        "district": "MEDINA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361896001717",
    },
    {
        "school": "ORLEANS-NIAGARA BOCES",
        "district": "ORLEANS-NIAGARA BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368064004648",
    },
    {
        "school": "CLYDE-SAVANNAH ELEMENTARY SCHOOL",
        "district": "CLYDE-SAVANNAH CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360786000558",
    },
    {
        "school": "CLYDE-SAVANNAH HIGH SCHOOL",
        "district": "CLYDE-SAVANNAH CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360786000559",
    },
    {
        "school": "RUBEN A CIRILLO HIGH SCHOOL",
        "district": "GANANDA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361174000940",
    },
    {
        "school": "GANANDA MIDDLE SCHOOL",
        "district": "GANANDA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361174003447",
    },
    {
        "school": "RICHARD MANN ELEMENTARY SCHOOL",
        "district": "GANANDA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361174004685",
    },
    {
        "school": "NORTH ROSE-WOLCOTT ELEMENTARY SCHOOL",
        "district": "NORTH ROSE-WOLCOTT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361698001512",
    },
    {
        "school": "NORTH ROSE-WOLCOTT HIGH SCHOOL",
        "district": "NORTH ROSE-WOLCOTT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361698001513",
    },
    {
        "school": "NORTH ROSE-WOLCOTT MIDDLE SCHOOL",
        "district": "NORTH ROSE-WOLCOTT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361698001514",
    },
    {
        "school": "LYONS ELEMENTARY SCHOOL",
        "district": "LYONS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361803001614",
    },
    {
        "school": "LYONS SENIOR HIGH SCHOOL",
        "district": "LYONS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361803001615",
    },
    {
        "school": "LYONS MIDDLE SCHOOL",
        "district": "LYONS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361803004288",
    },
    {
        "school": "MARION ELEMENTARY SCHOOL",
        "district": "MARION CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361854001668",
    },
    {
        "school": "MARION JUNIOR-SENIOR HIGH SCHOOL",
        "district": "MARION CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361854001669",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "NEWARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362064002893",
    },
    {
        "school": "NEWARK MIDDLE SCHOOL",
        "district": "NEWARK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362064002894",
    },
    {
        "school": "NEWARK SENIOR HIGH SCHOOL",
        "district": "NEWARK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362064002895",
    },
    {
        "school": "NORMAN R KELLEY INTERMEDIATE SCHOOL",
        "district": "NEWARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362064002896",
    },
    {
        "school": "PERKINS ELEMENTARY SCHOOL",
        "district": "NEWARK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362064002897",
    },
    {
        "school": "PALMYRA-MACEDON INTERMEDIATE SCHOOL",
        "district": "PALMYRA-MACEDON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362238003150",
    },
    {
        "school": "PALMYRA-MACEDON PRIMARY SCHOOL",
        "district": "PALMYRA-MACEDON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362238003151",
    },
    {
        "school": "PALMYRA-MACEDON MIDDLE SCHOOL",
        "district": "PALMYRA-MACEDON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362238003152",
    },
    {
        "school": "PALMYRA-MACEDON SENIOR HIGH SCHOOL",
        "district": "PALMYRA-MACEDON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362238003153",
    },
    {
        "school": "MARGARET W CUYLER ELEMENTARY SCHOOL",
        "district": "RED CREEK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362421003329",
    },
    {
        "school": "RED CREEK HIGH SCHOOL",
        "district": "RED CREEK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362421003330",
    },
    {
        "school": "RED CREEK MIDDLE SCHOOL",
        "district": "RED CREEK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362421004851",
    },
    {
        "school": "SODUS JR/SR HIGH SCHOOL",
        "district": "SODUS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362712003694",
    },
    {
        "school": "SODUS ELEMENTARY SCHOOL",
        "district": "SODUS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362712003695",
    },
    {
        "school": "SODUS INTERMEDIATE SCHOOL",
        "district": "SODUS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362712004902",
    },
    {
        "school": "WAYNE CENTRAL ELEMENTARY SCHOOL",
        "district": "WAYNE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363033004074",
    },
    {
        "school": "WAYNE CENTRAL PRIMARY SCHOOL",
        "district": "WAYNE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363033004075",
    },
    {
        "school": "WAYNE CENTRAL MIDDLE SCHOOL",
        "district": "WAYNE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363033004076",
    },
    {
        "school": "WAYNE SENIOR HIGH SCHOOL",
        "district": "WAYNE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363033004078",
    },
    {
        "school": "WILLIAMSON MIDDLE SCHOOL",
        "district": "WILLIAMSON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363144004204",
    },
    {
        "school": "WILLIAMSON ELEMENTARY SCHOOL",
        "district": "WILLIAMSON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363144004205",
    },
    {
        "school": "WILLIAMSON SENIOR HIGH SCHOOL",
        "district": "WILLIAMSON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363144004206",
    },
    {
        "school": "ONTARIO-SENECA-YATES-CAYUGA-WAYNE BOCES",
        "district": "ONTARIO-SENECA-YATES-CAYUGA-WAYNE BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368060004646",
    },
    {
        "school": "MIDDLESEX VALLEY ELEMENTARY SCHOOL",
        "district": "GORHAM-MIDDLESEX CENTRAL SCHOOL DISTRICT (MARCUS WHITMAN)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361230000994",
    },
    {
        "school": "WATERLOO HIGH SCHOOL",
        "district": "WATERLOO CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001401425",
    },
    {
        "school": "LA FAYETTE SCHOOL",
        "district": "WATERLOO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001401428",
    },
    {
        "school": "WATERLOO MIDDLE SCHOOL",
        "district": "WATERLOO CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001401431",
    },
    {
        "school": "SKOI-YASE SCHOOL",
        "district": "WATERLOO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001401442",
    },
    {
        "school": "SOUTH SENECA ELEMENTARY SCHOOL",
        "district": "SOUTH SENECA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362214003133",
    },
    {
        "school": "SOUTH SENECA MIDDLE/HIGH SCHOOL",
        "district": "SOUTH SENECA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362214003134",
    },
    {
        "school": "ROMULUS CENTRAL SCHOOL",
        "district": "ROMULUS CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362493004369",
    },
    {
        "school": "ELIZABETH CADY STANTON ELEMENTARY SCHOOL",
        "district": "SENECA FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362643003621",
    },
    {
        "school": "MYNDERSE ACADEMY",
        "district": "SENECA FALLS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362643003624",
    },
    {
        "school": "FRANK M KNIGHT ELEMENTARY SCHOOL",
        "district": "SENECA FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362643004425",
    },
    {
        "school": "SENECA FALLS MIDDLE SCHOOL",
        "district": "SENECA FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362643004706",
    },
    {
        "school": "SYRACUSE ACADEMY OF SCIENCE CHARTER SCHOOL",
        "district": "SYRACUSE ACADEMY OF SCIENCE CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010405549",
    },
    {
        "school": "SOLVAY MIDDLE SCHOOL",
        "district": "SOLVAY UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362715005736",
    },
    {
        "school": "NORTH BROAD STREET SCHOOL",
        "district": "ONEIDA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001301160",
    },
    {
        "school": "SENECA STREET SCHOOL",
        "district": "ONEIDA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001301167",
    },
    {
        "school": "W F PRIOR ELEMENTARY SCHOOL",
        "district": "ONEIDA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001301171",
    },
    {
        "school": "OTTO L SHORTELL MIDDLE SCHOOL",
        "district": "ONEIDA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001301176",
    },
    {
        "school": "ONEIDA SENIOR HIGH SCHOOL",
        "district": "ONEIDA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001301199",
    },
    {
        "school": "BROOKFIELD CENTRAL SCHOOL",
        "district": "BROOKFIELD CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360567000292",
    },
    {
        "school": "CANASTOTA HIGH SCHOOL",
        "district": "CANASTOTA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360639000419",
    },
    {
        "school": "PETERBORO STREET ELEMENTARY SCHOOL",
        "district": "CANASTOTA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360639000420",
    },
    {
        "school": "ROBERTS STREET MIDDLE SCHOOL",
        "district": "CANASTOTA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360639000421",
    },
    {
        "school": "SOUTH SIDE ELEMENTARY SCHOOL",
        "district": "CANASTOTA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360639000422",
    },
    {
        "school": "BURTON STREET ELEMENTARY SCHOOL",
        "district": "CAZENOVIA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360678000465",
    },
    {
        "school": "CAZENOVIA HIGH SCHOOL",
        "district": "CAZENOVIA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360678000466",
    },
    {
        "school": "CAZENOVIA MIDDLE SCHOOL",
        "district": "CAZENOVIA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360678000467",
    },
    {
        "school": "BOLIVAR ROAD ELEMENTARY SCHOOL",
        "district": "CHITTENANGO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360747000529",
    },
    {
        "school": "BRIDGEPORT ELEMENTARY SCHOOL",
        "district": "CHITTENANGO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360747000530",
    },
    {
        "school": "CHITTENANGO HIGH SCHOOL",
        "district": "CHITTENANGO CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360747000531",
    },
    {
        "school": "CHITTENANGO MIDDLE SCHOOL",
        "district": "CHITTENANGO CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360747000532",
    },
    {
        "school": "DERUYTER HIGH SCHOOL",
        "district": "DERUYTER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360885000670",
    },
    {
        "school": "DERUYTER ELEMENTARY SCHOOL",
        "district": "DERUYTER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360885004585",
    },
    {
        "school": "HAMILTON JUNIOR-SENIOR HIGH SCHOOL",
        "district": "HAMILTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361338001102",
    },
    {
        "school": "HAMILTON ELEMENTARY SCHOOL",
        "district": "HAMILTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361338004771",
    },
    {
        "school": "MADISON CENTRAL SCHOOL",
        "district": "MADISON CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361808001616",
    },
    {
        "school": "EDWARD R ANDREWS ELEMENTARY SCHOOL",
        "district": "MORRISVILLE-EATON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361992001818",
    },
    {
        "school": "MORRISVILLE MIDDLE SCHOOL HIGH SCHOOL",
        "district": "MORRISVILLE-EATON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361992001819",
    },
    {
        "school": "STOCKBRIDGE VALLEY CENTRAL SCHOOL",
        "district": "STOCKBRIDGE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362814003801",
    },
    {
        "school": "DURHAMVILLE SCHOOL",
        "district": "ONEIDA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001301154",
    },
    {
        "school": "SOUTHSIDE ACADEMY CHARTER SCHOOL",
        "district": "SOUTHSIDE ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007004898",
    },
    {
        "school": "CATHERINE M MCNAMARA ELEMENTARY SCHOOL",
        "district": "BALDWINSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360387000139",
    },
    {
        "school": "CHARLES W BAKER HIGH SCHOOL",
        "district": "BALDWINSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360387000140",
    },
    {
        "school": "DONALD S RAY SCHOOL",
        "district": "BALDWINSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360387000141",
    },
    {
        "school": "HARRY E ELDEN ELEMENTARY SCHOOL",
        "district": "BALDWINSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360387000143",
    },
    {
        "school": "L PEARL PALMER ELEMENTARY SCHOOL",
        "district": "BALDWINSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360387000144",
    },
    {
        "school": "MAE E REYNOLDS SCHOOL",
        "district": "BALDWINSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360387000145",
    },
    {
        "school": "THEODORE R DURGEE JUNIOR HIGH SCHOOL",
        "district": "BALDWINSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360387000146",
    },
    {
        "school": "VAN BUREN ELEMENTARY SCHOOL",
        "district": "BALDWINSVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360387000147",
    },
    {
        "school": "BREWERTON ELEMENTARY SCHOOL",
        "district": "CENTRAL SQUARE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360690000479",
    },
    {
        "school": "CHERRY ROAD ELEMENTARY SCHOOL",
        "district": "WESTHILL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360732000521",
    },
    {
        "school": "ONONDAGA HILL MIDDLE SCHOOL",
        "district": "WESTHILL CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360732000522",
    },
    {
        "school": "WESTHILL HIGH SCHOOL",
        "district": "WESTHILL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360732000524",
    },
    {
        "school": "WALBERTA PARK PRIMARY SCHOOL",
        "district": "WESTHILL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360732004582",
    },
    {
        "school": "JAMESVILLE ELEMENTARY SCHOOL",
        "district": "JAMESVILLE-DEWITT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360909000696",
    },
    {
        "school": "JAMESVILLE-DEWITT HIGH SCHOOL",
        "district": "JAMESVILLE-DEWITT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360909000697",
    },
    {
        "school": "JAMESVILLE-DEWITT MIDDLE SCHOOL",
        "district": "JAMESVILLE-DEWITT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360909000698",
    },
    {
        "school": "MOSES DEWITT ELEMENTARY SCHOOL",
        "district": "JAMESVILLE-DEWITT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360909000699",
    },
    {
        "school": "TECUMSEH ELEMENTARY SCHOOL",
        "district": "JAMESVILLE-DEWITT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360909004766",
    },
    {
        "school": "EAST SYRACUSE MINOA CENTRAL HIGH SCHOOL",
        "district": "EAST SYRACUSE MINOA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360999000772",
    },
    {
        "school": "FREMONT ELEMENTARY SCHOOL",
        "district": "EAST SYRACUSE MINOA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360999000773",
    },
    {
        "school": "EAST SYRACUSE ELEMENTARY SCHOOL",
        "district": "EAST SYRACUSE MINOA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360999000774",
    },
    {
        "school": "MINOA ELEMENTARY SCHOOL",
        "district": "EAST SYRACUSE MINOA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360999000775",
    },
    {
        "school": "PINE GROVE MIDDLE SCHOOL",
        "district": "EAST SYRACUSE MINOA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360999000778",
    },
    {
        "school": "WOODLAND ELEMENTARY SCHOOL",
        "district": "EAST SYRACUSE MINOA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360999000779",
    },
    {
        "school": "PARK HILL SCHOOL",
        "district": "EAST SYRACUSE MINOA CENTRAL SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360999004718",
    },
    {
        "school": "FABIUS-POMPEY ELEMENTARY SCHOOL",
        "district": "FABIUS-POMPEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361086000856",
    },
    {
        "school": "FABIUS-POMPEY MIDDLE SCHOOL HIGH SCHOOL",
        "district": "FABIUS-POMPEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361086004440",
    },
    {
        "school": "ELBRIDGE ELEMENTARY SCHOOL",
        "district": "JORDAN-ELBRIDGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361599001385",
    },
    {
        "school": "JORDAN-ELBRIDGE HIGH SCHOOL",
        "district": "JORDAN-ELBRIDGE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361599001386",
    },
    {
        "school": "JORDAN-ELBRIDGE MIDDLE SCHOOL",
        "district": "JORDAN-ELBRIDGE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361599002581",
    },
    {
        "school": "C GRANT GRIMSHAW SCHOOL",
        "district": "LAFAYETTE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361641001447",
    },
    {
        "school": "LA FAYETTE JUNIOR-SENIOR HIGH SCHOOL",
        "district": "LAFAYETTE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361641001448",
    },
    {
        "school": "ONONDAGA NATION SCHOOL",
        "district": "LAFAYETTE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361641001449",
    },
    {
        "school": "CHESTNUT HILL ELEMENTARY SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001559",
    },
    {
        "school": "CHESTNUT HILL MIDDLE SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001560",
    },
    {
        "school": "DONLIN DRIVE ELEMENTARY SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001562",
    },
    {
        "school": "ELMCREST ELEMENTARY SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001563",
    },
    {
        "school": "LIVERPOOL ELEMENTARY SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001564",
    },
    {
        "school": "LIVERPOOL HIGH SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001565",
    },
    {
        "school": "LIVERPOOL MIDDLE SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001566",
    },
    {
        "school": "LONG BRANCH ELEMENTARY SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001567",
    },
    {
        "school": "MORGAN ROAD ELEMENTARY SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001569",
    },
    {
        "school": "NATE PERRY ELEMENTARY SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001570",
    },
    {
        "school": "SOULE ROAD ELEMENTARY SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001571",
    },
    {
        "school": "SOULE ROAD MIDDLE SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752001572",
    },
    {
        "school": "WILLOW FIELD ELEMENTARY SCHOOL",
        "district": "LIVERPOOL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361752004720",
    },
    {
        "school": "LYNCOURT SCHOOL",
        "district": "LYNCOURT UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361794001611",
    },
    {
        "school": "EAGLE HILL MIDDLE SCHOOL",
        "district": "FAYETTEVILLE-MANLIUS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361833001653",
    },
    {
        "school": "ENDERS ROAD ELEMENTARY SCHOOL",
        "district": "FAYETTEVILLE-MANLIUS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361833001654",
    },
    {
        "school": "FAYETTEVILLE ELEMENTARY SCHOOL",
        "district": "FAYETTEVILLE-MANLIUS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361833001655",
    },
    {
        "school": "FAYETTEVILLE-MANLIUS SENIOR HIGH SCHOOL",
        "district": "FAYETTEVILLE-MANLIUS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361833001656",
    },
    {
        "school": "WELLWOOD MIDDLE SCHOOL",
        "district": "FAYETTEVILLE-MANLIUS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361833001658",
    },
    {
        "school": "MOTT ROAD ELEMENTARY SCHOOL",
        "district": "FAYETTEVILLE-MANLIUS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361833004595",
    },
    {
        "school": "C S DRIVER MIDDLE SCHOOL",
        "district": "MARCELLUS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361848001662",
    },
    {
        "school": "K C HEFFERNAN ELEMENTARY SCHOOL",
        "district": "MARCELLUS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361848001663",
    },
    {
        "school": "MARCELLUS HIGH SCHOOL",
        "district": "MARCELLUS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361848001665",
    },
    {
        "school": "ALLEN ROAD ELEMENTARY SCHOOL",
        "district": "NORTH SYRACUSE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362121002994",
    },
    {
        "school": "KARL W SAILE BEAR ROAD ELEMENTARY SCHOOL",
        "district": "NORTH SYRACUSE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362121002995",
    },
    {
        "school": "CICERO ELEMENTARY SCHOOL",
        "district": "NORTH SYRACUSE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362121002996",
    },
    {
        "school": "CICERO-NORTH SYRACUSE HIGH SCHOOL",
        "district": "NORTH SYRACUSE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362121002997",
    },
    {
        "school": "GILLETTE ROAD MIDDLE SCHOOL",
        "district": "NORTH SYRACUSE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362121002998",
    },
    {
        "school": "LAKESHORE ROAD ELEMENTARY SCHOOL",
        "district": "NORTH SYRACUSE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362121002999",
    },
    {
        "school": "NORTH SYRACUSE JUNIOR HIGH SCHOOL",
        "district": "NORTH SYRACUSE CENTRAL SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362121003001",
    },
    {
        "school": "ROXBORO ROAD ELEMENTARY SCHOOL",
        "district": "NORTH SYRACUSE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362121003003",
    },
    {
        "school": "ROXBORO ROAD MIDDLE SCHOOL",
        "district": "NORTH SYRACUSE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362121003004",
    },
    {
        "school": "SMITH ROAD ELEMENTARY SCHOOL",
        "district": "NORTH SYRACUSE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362121003005",
    },
    {
        "school": "MAIN STREET ELEMENTARY SCHOOL",
        "district": "NORTH SYRACUSE CENTRAL SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362121004565",
    },
    {
        "school": "ONONDAGA SENIOR HIGH SCHOOL",
        "district": "ONONDAGA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362181003098",
    },
    {
        "school": "ROCKWELL ELEMENTARY SCHOOL",
        "district": "ONONDAGA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362181003099",
    },
    {
        "school": "WHEELER ELEMENTARY SCHOOL",
        "district": "ONONDAGA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362181003100",
    },
    {
        "school": "SKANEATELES MIDDLE SCHOOL",
        "district": "SKANEATELES CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362694003667",
    },
    {
        "school": "SKANEATELES SENIOR HIGH SCHOOL",
        "district": "SKANEATELES CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362694003668",
    },
    {
        "school": "STATE STREET INTERMEDIATE SCHOOL",
        "district": "SKANEATELES CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362694003669",
    },
    {
        "school": "WATERMAN ELEMENTARY SCHOOL",
        "district": "SKANEATELES CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362694003670",
    },
    {
        "school": "SOLVAY ELEMENTARY SCHOOL",
        "district": "SOLVAY UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362715003698",
    },
    {
        "school": "SOLVAY HIGH SCHOOL",
        "district": "SOLVAY UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362715003699",
    },
    {
        "school": "BELLEVUE ELEMENTARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003846",
    },
    {
        "school": "CLARY MIDDLE SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003849",
    },
    {
        "school": "CORCORAN HIGH SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003850",
    },
    {
        "school": "DR WEEKS ELEMENTARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003853",
    },
    {
        "school": "EDWARD SMITH K-8 SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003856",
    },
    {
        "school": "FRANKLIN ELEMENTARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003859",
    },
    {
        "school": "FRAZER K-8 SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003860",
    },
    {
        "school": "GRANT MIDDLE SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003862",
    },
    {
        "school": "HURLBUT W SMITH K-8 SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003863",
    },
    {
        "school": "HENNINGER HIGH SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003864",
    },
    {
        "school": "HUNTINGTON K-8 SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003865",
    },
    {
        "school": "LEMOYNE ELEMENTARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003867",
    },
    {
        "school": "LINCOLN MIDDLE SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003868",
    },
    {
        "school": "MCKINLEY-BRIGHTON ELEMENTARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003869",
    },
    {
        "school": "MEACHEM ELEMENTARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003870",
    },
    {
        "school": "NOTTINGHAM HIGH SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003871",
    },
    {
        "school": "PORTER ELEMENTARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003873",
    },
    {
        "school": "ROBERTS K-8 SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003875",
    },
    {
        "school": "SALEM HYDE ELEMENTARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003877",
    },
    {
        "school": "SEYMOUR DUAL LANGUAGE ACADEMY",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003879",
    },
    {
        "school": "VAN DUYN ELEMENTARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003881",
    },
    {
        "school": "WEBSTER ELEMENTARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859003883",
    },
    {
        "school": "TULLY ELEMENTARY SCHOOL",
        "district": "TULLY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362913003926",
    },
    {
        "school": "TULLY JUNIOR-SENIOR HIGH SCHOOL",
        "district": "TULLY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362913003927",
    },
    {
        "school": "CAMILLUS MIDDLE SCHOOL",
        "district": "WEST GENESEE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363063004111",
    },
    {
        "school": "EAST HILL ELEMENTARY SCHOOL",
        "district": "WEST GENESEE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363063004112",
    },
    {
        "school": "ONONDAGA ROAD ELEMENTARY SCHOOL",
        "district": "WEST GENESEE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363063004114",
    },
    {
        "school": "SPLIT ROCK ELEMENTARY SCHOOL",
        "district": "WEST GENESEE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363063004115",
    },
    {
        "school": "STONEHEDGE ELEMENTARY SCHOOL",
        "district": "WEST GENESEE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363063004116",
    },
    {
        "school": "WEST GENESEE MIDDLE SCHOOL",
        "district": "WEST GENESEE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363063004118",
    },
    {
        "school": "WEST GENESEE SENIOR HIGH SCHOOL",
        "district": "WEST GENESEE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363063004119",
    },
    {
        "school": "ONONDAGA-CORTLAND-MADISON BOCES",
        "district": "ONONDAGA-CORTLAND-MADISON BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368058004645",
    },
    {
        "school": "ALTMAR-PARISH-WILLIAMSTOWN JR/SR HIGH SCHOOL",
        "district": "ALTMAR-PARISH-WILLIAMSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360282000055",
    },
    {
        "school": "AURA A COLE ELEMENTARY SCHOOL",
        "district": "CENTRAL SQUARE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360690000482",
    },
    {
        "school": "HASTINGS MALLORY ELEMENTARY SCHOOL",
        "district": "CENTRAL SQUARE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360690000483",
    },
    {
        "school": "MILLARD HAWK ELEMENTARY SCHOOL",
        "district": "CENTRAL SQUARE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360690000484",
    },
    {
        "school": "PAUL V MOORE HIGH SCHOOL",
        "district": "CENTRAL SQUARE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360690000485",
    },
    {
        "school": "CENTRAL SQUARE MIDDLE SCHOOL",
        "district": "CENTRAL SQUARE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360690000999",
    },
    {
        "school": "FAIRGRIEVE SCHOOL",
        "district": "FULTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361170000929",
    },
    {
        "school": "FULTON JUNIOR HIGH SCHOOL",
        "district": "FULTON CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361170000930",
    },
    {
        "school": "G RAY BODLEY HIGH SCHOOL",
        "district": "FULTON CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361170000931",
    },
    {
        "school": "J E LANIGAN SCHOOL",
        "district": "FULTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361170000932",
    },
    {
        "school": "GRANBY ELEMENTARY SCHOOL",
        "district": "FULTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361170000934",
    },
    {
        "school": "VOLNEY ELEMENTARY SCHOOL",
        "district": "FULTON CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361170000936",
    },
    {
        "school": "KENNEY MIDDLE SCHOOL",
        "district": "HANNIBAL CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361359001111",
    },
    {
        "school": "FAIRLEY SCHOOL",
        "district": "HANNIBAL CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361359001112",
    },
    {
        "school": "HANNIBAL HIGH SCHOOL",
        "district": "HANNIBAL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361359001113",
    },
    {
        "school": "MEXICO MIDDLE SCHOOL",
        "district": "MEXICO CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361917001730",
    },
    {
        "school": "MEXICO ELEMENTARY SCHOOL",
        "district": "MEXICO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361917001731",
    },
    {
        "school": "MEXICO HIGH SCHOOL",
        "district": "MEXICO CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361917001732",
    },
    {
        "school": "NEW HAVEN ELEMENTARY SCHOOL",
        "district": "MEXICO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361917001733",
    },
    {
        "school": "PALERMO ELEMENTARY SCHOOL",
        "district": "MEXICO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361917001734",
    },
    {
        "school": "CHARLES E RILEY ELEMENTARY SCHOOL",
        "district": "OSWEGO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362205003124",
    },
    {
        "school": "FITZHUGH PARK ELEMENTARY SCHOOL",
        "district": "OSWEGO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362205003125",
    },
    {
        "school": "KINGSFORD PARK ELEMENTARY SCHOOL",
        "district": "OSWEGO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362205003126",
    },
    {
        "school": "LEIGHTON ELEMENTARY SCHOOL",
        "district": "OSWEGO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362205003127",
    },
    {
        "school": "MINETTO ELEMENTARY SCHOOL",
        "district": "OSWEGO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362205003128",
    },
    {
        "school": "OSWEGO MIDDLE SCHOOL",
        "district": "OSWEGO CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362205003129",
    },
    {
        "school": "OSWEGO HIGH SCHOOL",
        "district": "OSWEGO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362205003130",
    },
    {
        "school": "MICHAEL A MAROUN ELEMENTARY SCHOOL",
        "district": "PHOENIX CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362292003218",
    },
    {
        "school": "JOHN C BIRDLEBOUGH HIGH SCHOOL",
        "district": "PHOENIX CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362292003219",
    },
    {
        "school": "EMERSON J DILLON MIDDLE SCHOOL",
        "district": "PHOENIX CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362292003221",
    },
    {
        "school": "PULASKI ELEMENTARY SCHOOL",
        "district": "PULASKI CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362388003311",
    },
    {
        "school": "PULASKI HIGH SCHOOL",
        "district": "PULASKI CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362388003312",
    },
    {
        "school": "SANDY CREEK ELEMENTARY SCHOOL",
        "district": "SANDY CREEK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362565003526",
    },
    {
        "school": "SANDY CREEK HIGH SCHOOL",
        "district": "SANDY CREEK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362565003527",
    },
    {
        "school": "SANDY CREEK MIDDLE SCHOOL",
        "district": "SANDY CREEK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362565004900",
    },
    {
        "school": "OSWEGO BOCES",
        "district": "OSWEGO BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368066004649",
    },
    {
        "school": "FRANKFORT-SCHUYLER MIDDLE SCHOOL",
        "district": "FRANKFORT-SCHUYLER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361140005755",
    },
    {
        "school": "NEW YORK STATE SCHOOL FOR THE DEAF",
        "district": "NEW YORK STATE SCHOOL FOR THE DEAF",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360015405313",
    },
    {
        "school": "GEORGE R STALEY ELEMENTARY SCHOOL",
        "district": "ROME CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362490005837",
    },
    {
        "school": "MADISON-ONEIDA BOCES",
        "district": "MADISON-ONEIDA BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368048004640",
    },
    {
        "school": "JAMES A GREEN HIGH SCHOOL",
        "district": "DOLGEVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000104498",
    },
    {
        "school": "DOLGEVILLE ELEMENTARY SCHOOL",
        "district": "DOLGEVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000104540",
    },
    {
        "school": "FRANKFORT-SCHUYLER CENTRAL HIGH SCHOOL",
        "district": "FRANKFORT-SCHUYLER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361140000896",
    },
    {
        "school": "FRANKFORT-SCHUYLER ELEMENTARY SCHOOL",
        "district": "FRANKFORT-SCHUYLER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361140000898",
    },
    {
        "school": "HERKIMER HIGH SCHOOL",
        "district": "HERKIMER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361422001168",
    },
    {
        "school": "HERKIMER ELEMENTARY SCHOOL",
        "district": "HERKIMER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361422004798",
    },
    {
        "school": "BENTON HALL ACADEMY",
        "district": "LITTLE FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361746001554",
    },
    {
        "school": "LITTLE FALLS HIGH SCHOOL",
        "district": "LITTLE FALLS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361746001555",
    },
    {
        "school": "LITTLE FALLS MIDDLE SCHOOL",
        "district": "LITTLE FALLS CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361746001594",
    },
    {
        "school": "OWEN D YOUNG CENTRAL SCHOOL",
        "district": "VAN HORNESVILLE-OWEN D YOUNG CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362220003142",
    },
    {
        "school": "POLAND JUNIOR-SENIOR HIGH SCHOOL",
        "district": "POLAND CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362337003269",
    },
    {
        "school": "POLAND ELEMENTARY SCHOOL",
        "district": "POLAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362337004799",
    },
    {
        "school": "TOWN OF WEBB SCHOOL",
        "district": "TOWN OF WEBB UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362880003908",
    },
    {
        "school": "WEST CANADA VALLEY ELEMENTARY SCHOOL",
        "district": "WEST CANADA VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363060004108",
    },
    {
        "school": "WEST CANADA VALLEY JUNIOR-SENIOR HIGH SCHOOL",
        "district": "WEST CANADA VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363060004109",
    },
    {
        "school": "MOUNT MARKHAM ELEMENTARY SCHOOL",
        "district": "MOUNT MARKHAM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363093004154",
    },
    {
        "school": "MOUNT MARKHAM MIDDLE SCHOOL",
        "district": "MOUNT MARKHAM CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363093004155",
    },
    {
        "school": "MOUNT MARKHAM SENIOR HIGH SCHOOL",
        "district": "MOUNT MARKHAM CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363093004156",
    },
    {
        "school": "HERKIMER-FULTON-HAMILTON-OTSEGO BOCES",
        "district": "HERKIMER-FULTON-HAMILTON-OTSEGO BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368042004637",
    },
    {
        "school": "WEST LEYDEN ELEMENTARY SCHOOL",
        "district": "ADIRONDACK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360504000244",
    },
    {
        "school": "SAUQUOIT VALLEY HIGH SCHOOL",
        "district": "SAUQUOIT VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000204500",
    },
    {
        "school": "SAUQUOIT VALLEY ELEMENTARY SCHOOL",
        "district": "SAUQUOIT VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000204541",
    },
    {
        "school": "SAUQUOIT VALLEY MIDDLE SCHOOL",
        "district": "SAUQUOIT VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000204761",
    },
    {
        "school": "ADIRONDACK HIGH SCHOOL",
        "district": "ADIRONDACK CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360504000241",
    },
    {
        "school": "BOONVILLE ELEMENTARY SCHOOL",
        "district": "ADIRONDACK CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360504000242",
    },
    {
        "school": "ADIRONDACK MIDDLE SCHOOL",
        "district": "ADIRONDACK CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360504004187",
    },
    {
        "school": "CAMDEN ELEMENTARY SCHOOL",
        "district": "CAMDEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360624000403",
    },
    {
        "school": "CAMDEN MIDDLE SCHOOL",
        "district": "CAMDEN CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360624000404",
    },
    {
        "school": "CAMDEN SENIOR HIGH SCHOOL",
        "district": "CAMDEN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360624000405",
    },
    {
        "school": "MCCONNELLSVILLE ELEMENTARY SCHOOL",
        "district": "CAMDEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360624000406",
    },
    {
        "school": "CLINTON ELEMENTARY SCHOOL",
        "district": "CLINTON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360777000555",
    },
    {
        "school": "CLINTON MIDDLE SCHOOL",
        "district": "CLINTON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360777000556",
    },
    {
        "school": "CLINTON SENIOR HIGH SCHOOL",
        "district": "CLINTON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360777000557",
    },
    {
        "school": "GENERAL WILLIAM FLOYD ELEMENTARY SCHOOL",
        "district": "HOLLAND PATENT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361458001208",
    },
    {
        "school": "HOLLAND PATENT CENTRAL HIGH SCHOOL",
        "district": "HOLLAND PATENT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361458001209",
    },
    {
        "school": "HOLLAND PATENT ELEMENTARY SCHOOL",
        "district": "HOLLAND PATENT CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361458001210",
    },
    {
        "school": "HOLLAND PATENT MIDDLE SCHOOL",
        "district": "HOLLAND PATENT CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361458001211",
    },
    {
        "school": "HUGHES ELEMENTARY SCHOOL",
        "district": "NEW HARTFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362037001877",
    },
    {
        "school": "MYLES ELEMENTARY SCHOOL",
        "district": "NEW HARTFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362037001878",
    },
    {
        "school": "NEW HARTFORD SENIOR HIGH SCHOOL",
        "district": "NEW HARTFORD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362037001879",
    },
    {
        "school": "ROBERT L BRADLEY ELEMENTARY SCHOOL",
        "district": "NEW HARTFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362037001880",
    },
    {
        "school": "PERRY JUNIOR HIGH SCHOOL",
        "district": "NEW HARTFORD CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362037001881",
    },
    {
        "school": "NEW YORK MILLS ELEMENTARY SCHOOL",
        "district": "NEW YORK MILLS UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362061001416",
    },
    {
        "school": "NEW YORK MILLS JUNIOR-SENIOR HIGH SCHOOL",
        "district": "NEW YORK MILLS UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362061002891",
    },
    {
        "school": "N A WALBRAN ELEMENTARY SCHOOL",
        "district": "ORISKANY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362196003115",
    },
    {
        "school": "ORISKANY JUNIOR-SENIOR HIGH SCHOOL",
        "district": "ORISKANY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362196003116",
    },
    {
        "school": "REMSEN ELEMENTARY SCHOOL",
        "district": "REMSEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362436003337",
    },
    {
        "school": "REMSEN JUNIOR-SENIOR HIGH SCHOOL",
        "district": "REMSEN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362436003338",
    },
    {
        "school": "BELLAMY ELEMENTARY SCHOOL",
        "district": "ROME CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362490002579",
    },
    {
        "school": "GANSEVOORT ELEMENTARY SCHOOL",
        "district": "ROME CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362490003442",
    },
    {
        "school": "LOUIS V DENTI ELEMENTARY SCHOOL",
        "district": "ROME CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362490003445",
    },
    {
        "school": "LYNDON H STROUGH MIDDLE SCHOOL",
        "district": "ROME CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362490003446",
    },
    {
        "school": "RIDGE MILLS ELEMENTARY SCHOOL",
        "district": "ROME CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362490003448",
    },
    {
        "school": "ROME FREE ACADEMY",
        "district": "ROME CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362490003449",
    },
    {
        "school": "STOKES ELEMENTARY SCHOOL",
        "district": "ROME CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362490003450",
    },
    {
        "school": "JOHN E JOY ELEMENTARY SCHOOL",
        "district": "ROME CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362490003451",
    },
    {
        "school": "E A MCALLISTER ELEMENTARY SCHOOL",
        "district": "SHERRILL CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362676003651",
    },
    {
        "school": "J D GEORGE ELEMENTARY SCHOOL",
        "district": "SHERRILL CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362676003652",
    },
    {
        "school": "VERNON-VERONA-SHERRILL SENIOR HIGH SCHOOL",
        "district": "SHERRILL CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362676003653",
    },
    {
        "school": "W A WETTEL ELEMENTARY SCHOOL",
        "district": "SHERRILL CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362676003654",
    },
    {
        "school": "VERNON-VERONA-SHERRILL MIDDLE SCHOOL",
        "district": "SHERRILL CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362676004371",
    },
    {
        "school": "CHRISTOPHER COLUMBUS ELEMENTARY SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937000231",
    },
    {
        "school": "WATSON WILLIAMS ELEMENTARY SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937000262",
    },
    {
        "school": "ALBANY ELEMENTARY SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937003946",
    },
    {
        "school": "GENERAL HERKIMER ELEMENTARY SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937003948",
    },
    {
        "school": "HUGH R JONES ELEMENTARY SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937003950",
    },
    {
        "school": "JOHN F HUGHES ELEMENTARY SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937003951",
    },
    {
        "school": "JOHN F KENNEDY MIDDLE SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937003952",
    },
    {
        "school": "KERNAN ELEMENTARY SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937003954",
    },
    {
        "school": "MARTIN LUTHER KING JR ELEMENTARY SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937003957",
    },
    {
        "school": "THOMAS JEFFERSON ELEMENTARY SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937003961",
    },
    {
        "school": "SENATOR JAMES H DONOVAN MIDDLE SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937003962",
    },
    {
        "school": "THOMAS R PROCTOR HIGH SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937003963",
    },
    {
        "school": "WATERVILLE JR/SR HIGH SCHOOL",
        "district": "WATERVILLE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363016004538",
    },
    {
        "school": "MEMORIAL PARK ELEMENTARY SCHOOL",
        "district": "WATERVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363016004573",
    },
    {
        "school": "WESTMORELAND UPPER ELEMENTARY SCHOOL",
        "district": "WESTMORELAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363105001417",
    },
    {
        "school": "DEFOREST A HILL PRIMARY SCHOOL",
        "district": "WESTMORELAND CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363105004168",
    },
    {
        "school": "DONALD H CRANE JUNIOR/SENIOR HIGH SCHOOL",
        "district": "WESTMORELAND CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363105004169",
    },
    {
        "school": "DEERFIELD ELEMENTARY SCHOOL",
        "district": "WHITESBORO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363132004191",
    },
    {
        "school": "HARTS HILL SCHOOL",
        "district": "WHITESBORO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363132004192",
    },
    {
        "school": "MARCY ELEMENTARY SCHOOL",
        "district": "WHITESBORO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363132004193",
    },
    {
        "school": "PARKWAY MIDDLE SCHOOL",
        "district": "WHITESBORO CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363132004194",
    },
    {
        "school": "WESTMORELAND ROAD ELEMENTARY SCHOOL",
        "district": "WHITESBORO CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363132004195",
    },
    {
        "school": "WHITESBORO MIDDLE SCHOOL",
        "district": "WHITESBORO CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363132004196",
    },
    {
        "school": "WHITESBORO HIGH SCHOOL",
        "district": "WHITESBORO CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363132004197",
    },
    {
        "school": "ONEIDA-HERKIMER-MADISON BOCES",
        "district": "ONEIDA-HERKIMER-MADISON BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368056004644",
    },
    {
        "school": "CLARKE MIDDLE SCHOOL",
        "district": "SOUTH JEFFERSON CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360234005605",
    },
    {
        "school": "INDIAN RIVER INTERMEDIATE SCHOOL",
        "district": "INDIAN RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361530005044",
    },
    {
        "school": "MANNSVILLE MANOR ELEMENTARY SCHOOL",
        "district": "SOUTH JEFFERSON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360234000004",
    },
    {
        "school": "MAYNARD P WILSON ELEMENTARY SCHOOL",
        "district": "SOUTH JEFFERSON CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360234000005",
    },
    {
        "school": "SOUTH JEFFERSON HIGH SCHOOL",
        "district": "SOUTH JEFFERSON CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360234000006",
    },
    {
        "school": "ALEXANDRIA CENTRAL ELEMENTARY SCHOOL",
        "district": "ALEXANDRIA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360267000044",
    },
    {
        "school": "ALEXANDRIA CENTRAL HIGH SCHOOL",
        "district": "ALEXANDRIA CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360267004333",
    },
    {
        "school": "BELLEVILLE HENDERSON CENTRAL SCHOOL",
        "district": "BELLEVILLE-HENDERSON CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360437004801",
    },
    {
        "school": "BLACK RIVER SCHOOL",
        "district": "CARTHAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360663000443",
    },
    {
        "school": "CARTHAGE ELEMENTARY SCHOOL",
        "district": "CARTHAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360663000444",
    },
    {
        "school": "CARTHAGE MIDDLE SCHOOL",
        "district": "CARTHAGE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360663000445",
    },
    {
        "school": "CARTHAGE SENIOR HIGH SCHOOL",
        "district": "CARTHAGE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360663000446",
    },
    {
        "school": "WEST CARTHAGE ELEMENTARY SCHOOL",
        "district": "CARTHAGE CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360663000449",
    },
    {
        "school": "CAPE VINCENT ELEMENTARY SCHOOL",
        "district": "THOUSAND ISLANDS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360765000546",
    },
    {
        "school": "GUARDINO ELEMENTARY SCHOOL",
        "district": "THOUSAND ISLANDS CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360765000547",
    },
    {
        "school": "THOUSAND ISLANDS HIGH SCHOOL",
        "district": "THOUSAND ISLANDS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360765000548",
    },
    {
        "school": "THOUSAND ISLANDS MIDDLE SCHOOL",
        "district": "THOUSAND ISLANDS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360765004711",
    },
    {
        "school": "BROWNVILLE SCHOOL",
        "district": "GENERAL BROWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361191000958",
    },
    {
        "school": "DEXTER ELEMENTARY SCHOOL",
        "district": "GENERAL BROWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361191000959",
    },
    {
        "school": "GENERAL BROWN JUNIOR-SENIOR HIGH SCHOOL",
        "district": "GENERAL BROWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361191000960",
    },
    {
        "school": "SACKETS HARBOR CENTRAL SCHOOL",
        "district": "SACKETS HARBOR CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361488001245",
    },
    {
        "school": "ANTWERP PRIMARY SCHOOL",
        "district": "INDIAN RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361530001286",
    },
    {
        "school": "EVANS MILLS PRIMARY SCHOOL",
        "district": "INDIAN RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361530001287",
    },
    {
        "school": "INDIAN RIVER HIGH SCHOOL",
        "district": "INDIAN RIVER CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361530001288",
    },
    {
        "school": "PHILADELPHIA PRIMARY SCHOOL",
        "district": "INDIAN RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361530001289",
    },
    {
        "school": "THERESA PRIMARY SCHOOL",
        "district": "INDIAN RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361530001290",
    },
    {
        "school": "INDIAN RIVER MIDDLE SCHOOL",
        "district": "INDIAN RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361530004774",
    },
    {
        "school": "CALCIUM PRIMARY SCHOOL",
        "district": "INDIAN RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361530004800",
    },
    {
        "school": "LA FARGEVILLE CENTRAL SCHOOL",
        "district": "LA FARGEVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361638001446",
    },
    {
        "school": "LYME CENTRAL SCHOOL",
        "district": "LYME CENTRAL SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361788001604",
    },
    {
        "school": "CASE MIDDLE SCHOOL",
        "district": "WATERTOWN CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363012004047",
    },
    {
        "school": "HAROLD T WILEY SCHOOL",
        "district": "WATERTOWN CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363012004048",
    },
    {
        "school": "KNICKERBOCKER SCHOOL",
        "district": "WATERTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363012004051",
    },
    {
        "school": "OHIO STREET SCHOOL",
        "district": "WATERTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363012004054",
    },
    {
        "school": "SHERMAN SCHOOL",
        "district": "WATERTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363012004055",
    },
    {
        "school": "WATERTOWN SENIOR HIGH SCHOOL",
        "district": "WATERTOWN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363012004057",
    },
    {
        "school": "NORTH ELEMENTARY SCHOOL",
        "district": "WATERTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363012004622",
    },
    {
        "school": "JEFFERSON-LEWIS-HAMILTON-HERKIMER-ONEIDA BOCES",
        "district": "JEFFERSON-LEWIS-HAMILTON-HERKIMER-ONEIDA BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "368044004638",
    },
    {
        "school": "Lima Senior High School",
        "district": "Lima City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442205325",
    },
    {
        "school": "East Bridge Academy of Excellence",
        "district": "East Bridge Academy of Excellence",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390056405056",
    },
    {
        "school": "Rosa Parks Elementary School",
        "district": "Middletown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444005331",
    },
    {
        "school": "Wings Academy 1",
        "district": "Wings Academy 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390039904959",
    },
    {
        "school": "Harvard Avenue Performance Academy",
        "district": "Harvard Avenue Performance Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390064105328",
    },
    {
        "school": "John Adams High School",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805320",
    },
    {
        "school": "The School of One",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805339",
    },
    {
        "school": "Barack Obama School",
        "district": "Maple Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443005352",
    },
    {
        "school": "Abraham Lincoln School",
        "district": "Maple Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443005353",
    },
    {
        "school": "J.F. Kennedy School",
        "district": "Maple Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443005355",
    },
    {
        "school": "Olentangy Meadows Elementary School",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605348",
    },
    {
        "school": "Educational Academy for Boys & Girls",
        "district": "Educational Academy for Boys & Girls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390043404993",
    },
    {
        "school": "Midnimo Cross Cultural Community School",
        "district": "Midnimo Cross Cultural Community School",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390043504994",
    },
    {
        "school": "Westside Academy",
        "district": "Westside Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390047405033",
    },
    {
        "school": "Early College Academy",
        "district": "Early College Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390063805183",
    },
    {
        "school": "North Woods Career Prep High School",
        "district": "North Woods Career Prep High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390064305312",
    },
    {
        "school": "South Scioto Academy",
        "district": "South Scioto Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390064405338",
    },
    {
        "school": "Parsons Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438005313",
    },
    {
        "school": "Roll Hill School",
        "district": "Cincinnati Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505098",
    },
    {
        "school": "North Elementary School",
        "district": "Licking Heights Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480005322",
    },
    {
        "school": "Lorain High School",
        "district": "Lorain City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442605326",
    },
    {
        "school": "Toledo Early College High School",
        "district": "Toledo City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449005317",
    },
    {
        "school": "Dayton Business Technology High School",
        "district": "Dayton Business Technology High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390064205309",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438402915",
    },
    {
        "school": "Cleveland Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438405350",
    },
    {
        "school": "Cardington Intermediate School",
        "district": "Cardington-Lincoln Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487905139",
    },
    {
        "school": "Middlebranch Elementary School",
        "district": "Plain Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499305342",
    },
    {
        "school": "Schnee Learning Center",
        "district": "Schnee Learning Center",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390038504528",
    },
    {
        "school": "Stambaugh Charter Academy",
        "district": "Stambaugh Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390046705026",
    },
    {
        "school": "Glacier Ridge Elementary",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470205318",
    },
    {
        "school": "Five Points",
        "district": "Springboro Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504205311",
    },
    {
        "school": "Dennis",
        "district": "Springboro Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504205321",
    },
    {
        "school": "Manchester High School",
        "district": "Manchester Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390053705248",
    },
    {
        "school": "Manchester Elementary School",
        "district": "Manchester Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390053705249",
    },
    {
        "school": "Liberty Center Middle School",
        "district": "Liberty Center Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475804618",
    },
    {
        "school": "Patrick Henry Middle School",
        "district": "Patrick Henry Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475904619",
    },
    {
        "school": "Whiteoak Junior High School",
        "district": "Bright Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476104938",
    },
    {
        "school": "Fairfield Local Middle School",
        "district": "Fairfield Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476204620",
    },
    {
        "school": "Chieftain Elementary School",
        "district": "Logan-Hocking Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442405282",
    },
    {
        "school": "Hocking Hills Elementary School",
        "district": "Logan-Hocking Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442405283",
    },
    {
        "school": "Central Elementary School",
        "district": "Logan-Hocking Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442405285",
    },
    {
        "school": "Jackson Southview Elementary School",
        "district": "Jackson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441504535",
    },
    {
        "school": "Jackson Westview Elementary School",
        "district": "Jackson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441505279",
    },
    {
        "school": "Oak Hill Middle/High School",
        "district": "Oak Hill Union Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477604623",
    },
    {
        "school": "Oak Hill Elementary",
        "district": "Oak Hill Union Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477604624",
    },
    {
        "school": "Meigs Primary School",
        "district": "Meigs Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485204638",
    },
    {
        "school": "Meigs Intermediate School",
        "district": "Meigs Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485204639",
    },
    {
        "school": "Southern Elementary School",
        "district": "Southern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485304640",
    },
    {
        "school": "Morgan Junior High School",
        "district": "Morgan Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487704643",
    },
    {
        "school": "East Elementary School",
        "district": "Morgan Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487704644",
    },
    {
        "school": "West Elementary School",
        "district": "Morgan Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487704645",
    },
    {
        "school": "South Elementary School",
        "district": "Morgan Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487704646",
    },
    {
        "school": "Antwerp Local Middle School",
        "district": "Antwerp Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489904649",
    },
    {
        "school": "Eastern Primary Elementary School",
        "district": "Eastern Local School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491204651",
    },
    {
        "school": "Eastern Intermediate Elementary School",
        "district": "Eastern Local School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491204652",
    },
    {
        "school": "Eastern Middle School",
        "district": "Eastern Local School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491204653",
    },
    {
        "school": "North Adams High School",
        "district": "Adams County Ohio Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390619004105",
    },
    {
        "school": "Peebles Elementary School",
        "district": "Adams County Ohio Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390619004107",
    },
    {
        "school": "Peebles High School",
        "district": "Adams County Ohio Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390619004108",
    },
    {
        "school": "North Adams Elementary School",
        "district": "Adams County Ohio Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390619004109",
    },
    {
        "school": "West Union Elementary School",
        "district": "Adams County Ohio Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390619004113",
    },
    {
        "school": "West Union High School",
        "district": "Adams County Ohio Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390619004114",
    },
    {
        "school": "Ohio Valley Career & Technical Center",
        "district": "Adams County Ohio Valley Local",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390619004234",
    },
    {
        "school": "Ada Elementary School",
        "district": "Ada Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451802112",
    },
    {
        "school": "Ada High School",
        "district": "Ada Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451802113",
    },
    {
        "school": "Hardin Northern Elementary School",
        "district": "Hardin Northern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474902903",
    },
    {
        "school": "Hardin Northern High School",
        "district": "Hardin Northern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474902904",
    },
    {
        "school": "Ridgemont Elementary School",
        "district": "Ridgemont Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475002905",
    },
    {
        "school": "Ridgemont High School",
        "district": "Ridgemont Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475002906",
    },
    {
        "school": "Upper Scioto Valley Middle School",
        "district": "Upper Scioto Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475202911",
    },
    {
        "school": "Upper Scioto Valley Elementary School",
        "district": "Upper Scioto Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475202912",
    },
    {
        "school": "Upper Scioto Valley High School",
        "district": "Upper Scioto Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475202913",
    },
    {
        "school": "Kenton Elementary School",
        "district": "Kenton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002501090",
    },
    {
        "school": "Kenton High School",
        "district": "Kenton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002501091",
    },
    {
        "school": "Kenton Middle School",
        "district": "Kenton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002501092",
    },
    {
        "school": "Harrison Central Jr./Sr. High School",
        "district": "Harrison Hills City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452402133",
    },
    {
        "school": "Napoleon Elementary School",
        "district": "Napoleon Area City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444301361",
    },
    {
        "school": "Napoleon Junior/Senior High School",
        "district": "Napoleon Area City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444301364",
    },
    {
        "school": "Holgate Elementary School",
        "district": "Holgate Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475702918",
    },
    {
        "school": "Holgate High School",
        "district": "Holgate Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475702919",
    },
    {
        "school": "Liberty Center Elementary School",
        "district": "Liberty Center Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475802920",
    },
    {
        "school": "Liberty Center High School",
        "district": "Liberty Center Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475802921",
    },
    {
        "school": "Patrick Henry Elementary School",
        "district": "Patrick Henry Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475902924",
    },
    {
        "school": "Patrick Henry High School",
        "district": "Patrick Henry Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475902925",
    },
    {
        "school": "Four County Career Center",
        "district": "Four County Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390509604060",
    },
    {
        "school": "Hillsboro High School",
        "district": "Hillsboro City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441201059",
    },
    {
        "school": "Hillsboro Intermediate School",
        "district": "Hillsboro City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441201061",
    },
    {
        "school": "Hillsboro Primary School",
        "district": "Hillsboro City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441201062",
    },
    {
        "school": "Hillsboro Middle School",
        "district": "Hillsboro City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441202576",
    },
    {
        "school": "Hillsboro Early Childhood Center",
        "district": "Hillsboro City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441204303",
    },
    {
        "school": "Greenfield Elementary School",
        "district": "Greenfield Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454002202",
    },
    {
        "school": "McClain High School",
        "district": "Greenfield Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454002203",
    },
    {
        "school": "Rainsboro Elementary School",
        "district": "Greenfield Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454002205",
    },
    {
        "school": "Greenfield Middle School",
        "district": "Greenfield Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454004341",
    },
    {
        "school": "Whiteoak High School",
        "district": "Bright Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476102928",
    },
    {
        "school": "Bright Elementary School",
        "district": "Bright Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476103639",
    },
    {
        "school": "Fairfield Local High School",
        "district": "Fairfield Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476202929",
    },
    {
        "school": "Fairfield Local Elementary School",
        "district": "Fairfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476202930",
    },
    {
        "school": "Lynchburg-Clay High School",
        "district": "Lynchburg-Clay Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476302933",
    },
    {
        "school": "Lynchburg-Clay Elementary School",
        "district": "Lynchburg-Clay Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476303584",
    },
    {
        "school": "Lynchburg-Clay Middle School",
        "district": "Lynchburg-Clay Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476303595",
    },
    {
        "school": "Logan-Hocking Middle School",
        "district": "Logan-Hocking Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442400167",
    },
    {
        "school": "Green Elementary School",
        "district": "Logan-Hocking Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442401172",
    },
    {
        "school": "Logan High School",
        "district": "Logan-Hocking Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442401174",
    },
    {
        "school": "Union Furnace Elementary School",
        "district": "Logan-Hocking Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442401178",
    },
    {
        "school": "Berlin Elementary School",
        "district": "East Holmes Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476802934",
    },
    {
        "school": "Chestnut Ridge Elementary School",
        "district": "East Holmes Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476802936",
    },
    {
        "school": "Flat Ridge Elementary School",
        "district": "East Holmes Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476802937",
    },
    {
        "school": "Hiland High School",
        "district": "East Holmes Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476802938",
    },
    {
        "school": "Mt Hope Elementary School",
        "district": "East Holmes Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476802940",
    },
    {
        "school": "Walnut Creek Elementary School",
        "district": "East Holmes Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476802941",
    },
    {
        "school": "Winesburg Elementary School",
        "district": "East Holmes Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476802942",
    },
    {
        "school": "Wise Elementary School",
        "district": "East Holmes Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476802943",
    },
    {
        "school": "Killbuck Elementary School",
        "district": "West Holmes Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476902945",
    },
    {
        "school": "Lakeville Elementary School",
        "district": "West Holmes Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476902946",
    },
    {
        "school": "Millersburg Elementary School",
        "district": "West Holmes Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476902947",
    },
    {
        "school": "Nashville Elementary School",
        "district": "West Holmes Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476902948",
    },
    {
        "school": "West Holmes High School",
        "district": "West Holmes Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476902949",
    },
    {
        "school": "West Holmes Middle School",
        "district": "West Holmes Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390476902950",
    },
    {
        "school": "Jackson High School",
        "district": "Jackson City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441501075",
    },
    {
        "school": "Jackson Middle School",
        "district": "Jackson City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441501077",
    },
    {
        "school": "Bundy Elementary School",
        "district": "Wellston City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450201939",
    },
    {
        "school": "Wellston Middle School",
        "district": "Wellston City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450201940",
    },
    {
        "school": "Wellston Intermediate School",
        "district": "Wellston City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450201941",
    },
    {
        "school": "Wellston High School",
        "district": "Wellston City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450201942",
    },
    {
        "school": "Eastern Elementary School",
        "district": "Eastern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485101428",
    },
    {
        "school": "Eastern High School",
        "district": "Eastern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485103279",
    },
    {
        "school": "Meigs High School",
        "district": "Meigs Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485203284",
    },
    {
        "school": "Meigs Middle School",
        "district": "Meigs Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485203285",
    },
    {
        "school": "Southern High School",
        "district": "Southern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485303295",
    },
    {
        "school": "Morgan High School",
        "district": "Morgan Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487703401",
    },
    {
        "school": "Caldwell High School",
        "district": "Caldwell Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452502145",
    },
    {
        "school": "Caldwell Elementary School",
        "district": "Caldwell Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452502146",
    },
    {
        "school": "Shenandoah High School",
        "district": "Noble Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489003448",
    },
    {
        "school": "Shenandoah Elementary School",
        "district": "Noble Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489004248",
    },
    {
        "school": "Oakwood Elementary School",
        "district": "Paulding Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455702283",
    },
    {
        "school": "Paulding High School",
        "district": "Paulding Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455702284",
    },
    {
        "school": "Paulding Elementary School",
        "district": "Paulding Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455702285",
    },
    {
        "school": "Paulding Middle School",
        "district": "Paulding Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455702286",
    },
    {
        "school": "Antwerp Local Elementary School",
        "district": "Antwerp Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489903467",
    },
    {
        "school": "Antwerp Local High School",
        "district": "Antwerp Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489903468",
    },
    {
        "school": "Grover Hill Elementary School",
        "district": "Wayne Trace Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490303469",
    },
    {
        "school": "Payne Elementary School",
        "district": "Wayne Trace Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490303470",
    },
    {
        "school": "Wayne Trace High School",
        "district": "Wayne Trace Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490303471",
    },
    {
        "school": "Junction City Elementary School",
        "district": "New Lexington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444701393",
    },
    {
        "school": "New Lexington Elementary School",
        "district": "New Lexington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444701394",
    },
    {
        "school": "New Lexington Middle School",
        "district": "New Lexington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444701395",
    },
    {
        "school": "New Lexington High School",
        "district": "New Lexington School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444701396",
    },
    {
        "school": "Crooksville Elementary School",
        "district": "Crooksville Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453500313",
    },
    {
        "school": "Crooksville High School",
        "district": "Crooksville Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453502186",
    },
    {
        "school": "Crooksville Middle School",
        "district": "Crooksville Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453504221",
    },
    {
        "school": "Sheridan Middle School",
        "district": "Northern Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490500338",
    },
    {
        "school": "Somerset Elementary School",
        "district": "Northern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490501058",
    },
    {
        "school": "Glenford Elementary School",
        "district": "Northern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490503472",
    },
    {
        "school": "Sheridan High School",
        "district": "Northern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490503473",
    },
    {
        "school": "Thornville Elementary School",
        "district": "Northern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490503476",
    },
    {
        "school": "Millcreek Elementary School",
        "district": "Southern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490600306",
    },
    {
        "school": "Miller High School",
        "district": "Southern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490603478",
    },
    {
        "school": "Eastern High School",
        "district": "Eastern Local School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491203499",
    },
    {
        "school": "Jasper Elementary School",
        "district": "Scioto Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491303501",
    },
    {
        "school": "Piketon Jr/Sr High School",
        "district": "Scioto Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491303503",
    },
    {
        "school": "Waverly Primary School",
        "district": "Waverly City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491403504",
    },
    {
        "school": "Waverly Junior High School",
        "district": "Waverly City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491403505",
    },
    {
        "school": "Waverly High School",
        "district": "Waverly City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491403506",
    },
    {
        "school": "Waverly Intermediate School",
        "district": "Waverly City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491403507",
    },
    {
        "school": "Western Elementary School",
        "district": "Western Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491503510",
    },
    {
        "school": "Western High School",
        "district": "Western Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491503511",
    },
    {
        "school": "Vern Riffe Career Technology C",
        "district": "Pike County Area",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390513704082",
    },
    {
        "school": "Columbus Grove Elementary School",
        "district": "Columbus Grove Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493103558",
    },
    {
        "school": "Columbus Grove High School",
        "district": "Columbus Grove Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493103559",
    },
    {
        "school": "Columbus Grove Middle School",
        "district": "Columbus Grove Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493103560",
    },
    {
        "school": "Continental Local Elementary School",
        "district": "Continental Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493203561",
    },
    {
        "school": "Continental Local High School",
        "district": "Continental Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493203562",
    },
    {
        "school": "Fort Jennings Elementary School",
        "district": "Jennings Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493303563",
    },
    {
        "school": "Fort Jennings High School",
        "district": "Jennings Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493303564",
    },
    {
        "school": "Kalida Elementary School",
        "district": "Kalida Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493403565",
    },
    {
        "school": "Kalida High School",
        "district": "Kalida Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493403566",
    },
    {
        "school": "Leipsic Elementary School",
        "district": "Leipsic Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493503567",
    },
    {
        "school": "Leipsic High School",
        "district": "Leipsic Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493503568",
    },
    {
        "school": "Miller City Elementary School",
        "district": "Miller City-New Cleveland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493603569",
    },
    {
        "school": "Miller City High School",
        "district": "Miller City-New Cleveland Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493603570",
    },
    {
        "school": "Miller City Middle School",
        "district": "Miller City-New Cleveland Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493603571",
    },
    {
        "school": "Ottawa-Glandorf Complex Elementary School",
        "district": "Ottawa-Glandorf Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493701065",
    },
    {
        "school": "Glandorf Elementary School",
        "district": "Ottawa-Glandorf Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493703572",
    },
    {
        "school": "Ottawa Elementary School",
        "district": "Ottawa-Glandorf Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493703573",
    },
    {
        "school": "Ottawa-Glandorf High School",
        "district": "Ottawa-Glandorf Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493703574",
    },
    {
        "school": "Ottoville Elementary School",
        "district": "Ottoville Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493803575",
    },
    {
        "school": "Ottoville High School",
        "district": "Ottoville Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493803576",
    },
    {
        "school": "Pandora-Gilboa Middle School",
        "district": "Pandora-Gilboa Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493903577",
    },
    {
        "school": "Pandora-Gilboa Elementary School",
        "district": "Pandora-Gilboa Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493903578",
    },
    {
        "school": "Pandora-Gilboa High School",
        "district": "Pandora-Gilboa Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390493903579",
    },
    {
        "school": "Buckskin Elementary School",
        "district": "Greenfield Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454002201",
    },
    {
        "school": "West Elementary",
        "district": "Vinton County Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503903929",
    },
    {
        "school": "South Elementary",
        "district": "Vinton County Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503903931",
    },
    {
        "school": "Central Elementary",
        "district": "Vinton County Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503903932",
    },
    {
        "school": "Vinton County High School",
        "district": "Vinton County Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503903933",
    },
    {
        "school": "Vinton County Middle School",
        "district": "Vinton County Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503904405",
    },
    {
        "school": "Bryan Elementary",
        "district": "Bryan City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436700211",
    },
    {
        "school": "Bryan Middle School/High School",
        "district": "Bryan City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436700212",
    },
    {
        "school": "Montpelier Elementary School",
        "district": "Montpelier Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455202261",
    },
    {
        "school": "Montpelier High School",
        "district": "Montpelier Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455202262",
    },
    {
        "school": "Edgerton Elementary School",
        "district": "Edgerton Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506104006",
    },
    {
        "school": "Edgerton High School",
        "district": "Edgerton Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506104007",
    },
    {
        "school": "Edon High School",
        "district": "Edon Northwest Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506204009",
    },
    {
        "school": "Edon Elementary School",
        "district": "Edon Northwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506204010",
    },
    {
        "school": "Hilltop High School",
        "district": "Millcreek-West Unity Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506304012",
    },
    {
        "school": "Hilltop Elementary School",
        "district": "Millcreek-West Unity Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506304013",
    },
    {
        "school": "North Central Junior/High School",
        "district": "North Central Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506404016",
    },
    {
        "school": "North Central Elementary School",
        "district": "North Central Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506404017",
    },
    {
        "school": "Stryker Elementary School",
        "district": "Stryker Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506504018",
    },
    {
        "school": "Stryker High School",
        "district": "Stryker Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506504019",
    },
    {
        "school": "Carey High School",
        "district": "Carey Exempted Village Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452602149",
    },
    {
        "school": "Carey Elementary School",
        "district": "Carey Exempted Village Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452602150",
    },
    {
        "school": "Mohawk High School",
        "district": "Mohawk Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390507404049",
    },
    {
        "school": "Mohawk Elementary School",
        "district": "Mohawk Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390507404050",
    },
    {
        "school": "Union Elementary School",
        "district": "Upper Sandusky Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002402308",
    },
    {
        "school": "South Elementary School",
        "district": "Upper Sandusky Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002402310",
    },
    {
        "school": "Upper Sandusky Middle School",
        "district": "Upper Sandusky Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002402311",
    },
    {
        "school": "Upper Sandusky High School",
        "district": "Upper Sandusky Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002402313",
    },
    {
        "school": "East Elementary School",
        "district": "Upper Sandusky Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002404389",
    },
    {
        "school": "Powhatan Elementary School",
        "district": "Switzerland of Ohio Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486503334",
    },
    {
        "school": "Beallsville Elementary School",
        "district": "Switzerland of Ohio Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486503324",
    },
    {
        "school": "Beallsville High School",
        "district": "Switzerland of Ohio Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486503325",
    },
    {
        "school": "River Elementary School",
        "district": "Switzerland of Ohio Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486503330",
    },
    {
        "school": "River High School",
        "district": "Switzerland of Ohio Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486503335",
    },
    {
        "school": "Skyvue Elementary School",
        "district": "Switzerland of Ohio Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486503337",
    },
    {
        "school": "Swiss Hills Career Center",
        "district": "Switzerland of Ohio Local",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390486503338",
    },
    {
        "school": "Woodsfield Elementary School",
        "district": "Switzerland of Ohio Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486503339",
    },
    {
        "school": "Monroe Central High School",
        "district": "Switzerland of Ohio Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486503340",
    },
    {
        "school": "Ravenna Preschool",
        "district": "Ravenna City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446805113",
    },
    {
        "school": "Leighton Elementary School",
        "district": "Aurora City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491704654",
    },
    {
        "school": "Crestwood Primary School",
        "district": "Crestwood Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491805300",
    },
    {
        "school": "Crestwood Intermediate School",
        "district": "Crestwood Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491805301",
    },
    {
        "school": "Henry Defer Intermediate Elementary School",
        "district": "Streetsboro City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492304656",
    },
    {
        "school": "Randall Park High School",
        "district": "Randall Park High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390027904819",
    },
    {
        "school": "Summit Academy Transition High School-Cincinnati",
        "district": "Summit Academy Transition High School-Cincinnati",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390033704874",
    },
    {
        "school": "Summit Academy Transition High School-Columbus",
        "district": "Summit Academy Transition High School-Columbus",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390034204879",
    },
    {
        "school": "Summit Academy Transition High School Dayton",
        "district": "Summit Academy Transition High School Dayton",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390034804885",
    },
    {
        "school": "Summit Academy Secondary - Akron",
        "district": "Summit Academy Secondary - Akron",
        "level": "High",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390049405204",
    },
    {
        "school": "Cascade Career Prep High School",
        "district": "Cascade Career Prep High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390059305084",
    },
    {
        "school": "Akron Alternative Academy",
        "district": "Akron City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434805266",
    },
    {
        "school": "Green Primary School",
        "district": "Green Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500105315",
    },
    {
        "school": "Davey Elementary School",
        "district": "Kent City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441601081",
    },
    {
        "school": "Holden Elementary School",
        "district": "Kent City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441601084",
    },
    {
        "school": "Longcoy Elementary School",
        "district": "Kent City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441601085",
    },
    {
        "school": "Theodore Roosevelt High School",
        "district": "Kent City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441601086",
    },
    {
        "school": "Walls Elementary School",
        "district": "Kent City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441601087",
    },
    {
        "school": "Stanton Middle School",
        "district": "Kent City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441602601",
    },
    {
        "school": "Brown Middle School",
        "district": "Ravenna City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446801560",
    },
    {
        "school": "Carlin Elementary School",
        "district": "Ravenna City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446801561",
    },
    {
        "school": "Ravenna High School",
        "district": "Ravenna City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446801563",
    },
    {
        "school": "West Main Elementary School",
        "district": "Ravenna City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446801565",
    },
    {
        "school": "West Park Elementary School",
        "district": "Ravenna City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446801566",
    },
    {
        "school": "Willyard Elementary School",
        "district": "Ravenna City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446801567",
    },
    {
        "school": "Katherine Thomas Elementary School",
        "district": "Windham Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456602325",
    },
    {
        "school": "Windham High School",
        "district": "Windham Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456602326",
    },
    {
        "school": "Windham Junior High School",
        "district": "Windham Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456602327",
    },
    {
        "school": "Aurora High School",
        "district": "Aurora City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491703512",
    },
    {
        "school": "Harmon Middle School",
        "district": "Aurora City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491703513",
    },
    {
        "school": "Craddock Elementary School",
        "district": "Aurora City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491703516",
    },
    {
        "school": "Crestwood High School",
        "district": "Crestwood Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491803517",
    },
    {
        "school": "Crestwood Middle School",
        "district": "Crestwood Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491803519",
    },
    {
        "school": "Brimfield Elementary School",
        "district": "Field Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491903524",
    },
    {
        "school": "Field High School",
        "district": "Field Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491903525",
    },
    {
        "school": "Field Middle School",
        "district": "Field Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491903526",
    },
    {
        "school": "Suffield Elementary School",
        "district": "Field Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491903527",
    },
    {
        "school": "James A Garfield Elementary School",
        "district": "James A Garfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492003528",
    },
    {
        "school": "James A Garfield High School",
        "district": "James A Garfield Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492003529",
    },
    {
        "school": "James A Garfield Middle School",
        "district": "James A Garfield Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492003530",
    },
    {
        "school": "Rootstown Elementary School",
        "district": "Rootstown Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492103531",
    },
    {
        "school": "Rootstown/Ward Davis Bldg High School",
        "district": "Rootstown Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492103532",
    },
    {
        "school": "Rootstown/Mabel Schnee Bldg Middle School",
        "district": "Rootstown Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492103533",
    },
    {
        "school": "Southeast Intermediate Elementary School",
        "district": "Southeast Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492202755",
    },
    {
        "school": "Southeast High School",
        "district": "Southeast Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492203534",
    },
    {
        "school": "Southeast Primary Elementary School",
        "district": "Southeast Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492203535",
    },
    {
        "school": "Southeast Junior High School",
        "district": "Southeast Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492203536",
    },
    {
        "school": "Streetsboro Elementary School",
        "district": "Streetsboro City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492303537",
    },
    {
        "school": "Streetsboro High School",
        "district": "Streetsboro City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492303538",
    },
    {
        "school": "Streetsboro Middle School",
        "district": "Streetsboro City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492303539",
    },
    {
        "school": "Waterloo High School",
        "district": "Waterloo Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492403542",
    },
    {
        "school": "Waterloo Middle School",
        "district": "Waterloo Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492403543",
    },
    {
        "school": "Waterloo Elementary School",
        "district": "Waterloo Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492403544",
    },
    {
        "school": "Maplewood Career Center",
        "district": "Maplewood Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390513904083",
    },
    {
        "school": "Middlebury Academy",
        "district": "Middlebury Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390002701572",
    },
    {
        "school": "Edge Academy The",
        "district": "Edge Academy The",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390003302834",
    },
    {
        "school": "Summit Academy Akron Elementary School",
        "district": "Summit Academy Akron Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390003802844",
    },
    {
        "school": "Towpath Trail High School",
        "district": "Towpath Trail High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390005303054",
    },
    {
        "school": "Summit Academy Akron Middle School",
        "district": "Summit Academy Akron Middle School",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390009804167",
    },
    {
        "school": "Judith A Resnik Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800014",
    },
    {
        "school": "Findley Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800015",
    },
    {
        "school": "Firestone High School",
        "district": "Akron City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800016",
    },
    {
        "school": "Firestone Park Elementary School",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800017",
    },
    {
        "school": "Forest Hill Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800018",
    },
    {
        "school": "Barber Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800019",
    },
    {
        "school": "Kenmore/Garfield High School",
        "district": "Akron City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800020",
    },
    {
        "school": "Glover Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800021",
    },
    {
        "school": "Harris/Jackson Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800025",
    },
    {
        "school": "Hatton CLC",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800026",
    },
    {
        "school": "Sam Salem Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800028",
    },
    {
        "school": "Hill Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800029",
    },
    {
        "school": "Hyre Community Learning Center",
        "district": "Akron City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800031",
    },
    {
        "school": "Innes Community Learning Center",
        "district": "Akron City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800032",
    },
    {
        "school": "Jennings Community Learning Center",
        "district": "Akron City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800034",
    },
    {
        "school": "King Elementary School",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800037",
    },
    {
        "school": "Betty Jane Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800038",
    },
    {
        "school": "Leggett Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800040",
    },
    {
        "school": "Litchfield Middle School",
        "district": "Akron City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800042",
    },
    {
        "school": "Mason Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800044",
    },
    {
        "school": "McEbright Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800045",
    },
    {
        "school": "North High School",
        "district": "Akron City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800046",
    },
    {
        "school": "Pfeiffer Elementary School",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800048",
    },
    {
        "school": "Portage Path Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800049",
    },
    {
        "school": "Buchtel Community Learning Center",
        "district": "Akron City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800051",
    },
    {
        "school": "Rimer Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800052",
    },
    {
        "school": "Ritzman Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800053",
    },
    {
        "school": "Robinson Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800054",
    },
    {
        "school": "Schumacher Community Learning Cent",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800055",
    },
    {
        "school": "Seiberling CLC",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800056",
    },
    {
        "school": "Case Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800058",
    },
    {
        "school": "Voris Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800061",
    },
    {
        "school": "Windemere CLC",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800063",
    },
    {
        "school": "Crouse Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800105",
    },
    {
        "school": "East Community Learning Center",
        "district": "Akron City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800106",
    },
    {
        "school": "Ellet High School",
        "district": "Akron City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434800113",
    },
    {
        "school": "Miller-South Visual Performing Arts",
        "district": "Akron City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434804409",
    },
    {
        "school": "Barberton High School",
        "district": "Barberton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435300104",
    },
    {
        "school": "Barberton Elementary School West",
        "district": "Barberton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435300108",
    },
    {
        "school": "Barberton Middle School",
        "district": "Barberton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435300109",
    },
    {
        "school": "Barberton Elementary School East",
        "district": "Barberton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435304146",
    },
    {
        "school": "Bolich Middle School",
        "district": "Cuyahoga Falls City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438300761",
    },
    {
        "school": "Cuyahoga Falls High School",
        "district": "Cuyahoga Falls City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438300762",
    },
    {
        "school": "Elizabeth Price Elementary School",
        "district": "Cuyahoga Falls City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438300763",
    },
    {
        "school": "Gordon Dewitt Elementary School",
        "district": "Cuyahoga Falls City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438300764",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Cuyahoga Falls City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438300766",
    },
    {
        "school": "Preston Elementary School",
        "district": "Cuyahoga Falls City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438300768",
    },
    {
        "school": "Richardson Elementary School",
        "district": "Cuyahoga Falls City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438300769",
    },
    {
        "school": "Roberts Middle School",
        "district": "Cuyahoga Falls City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438300770",
    },
    {
        "school": "Silver Lake Elementary School",
        "district": "Cuyahoga Falls City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438300773",
    },
    {
        "school": "Norton Elementary School",
        "district": "Norton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445501447",
    },
    {
        "school": "Norton High School",
        "district": "Norton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445501448",
    },
    {
        "school": "Norton Middle School",
        "district": "Norton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445501449",
    },
    {
        "school": "Norton Primary Elementary School",
        "district": "Norton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445501450",
    },
    {
        "school": "Echo Hills Elementary School",
        "district": "Stow-Munroe Falls City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448301712",
    },
    {
        "school": "Fishcreek Elementary School",
        "district": "Stow-Munroe Falls City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448301713",
    },
    {
        "school": "Highland Elementary School",
        "district": "Stow-Munroe Falls City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448301714",
    },
    {
        "school": "Indian Trail Elementary School",
        "district": "Stow-Munroe Falls City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448301715",
    },
    {
        "school": "Kimpton Middle School",
        "district": "Stow-Munroe Falls City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448301716",
    },
    {
        "school": "Stow-Munroe Falls High School",
        "district": "Stow-Munroe Falls City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448301717",
    },
    {
        "school": "Riverview Elementary School",
        "district": "Stow-Munroe Falls City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448301718",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Stow-Munroe Falls City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448301719",
    },
    {
        "school": "Lakeview Elementary School",
        "district": "Stow-Munroe Falls City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448304336",
    },
    {
        "school": "Dunbar Elementary School",
        "district": "Tallmadge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448801755",
    },
    {
        "school": "Munroe Elementary School",
        "district": "Tallmadge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448801756",
    },
    {
        "school": "Tallmadge High School",
        "district": "Tallmadge City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448801758",
    },
    {
        "school": "Tallmadge Middle School",
        "district": "Tallmadge City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448801759",
    },
    {
        "school": "Woodridge Elementary School",
        "district": "Woodridge Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499700704",
    },
    {
        "school": "Woodridge Middle School",
        "district": "Woodridge Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499703778",
    },
    {
        "school": "Woodridge High School",
        "district": "Woodridge Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499703780",
    },
    {
        "school": "Arrowhead Primary Elementary School",
        "district": "Copley-Fairlawn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499803781",
    },
    {
        "school": "Copley High School",
        "district": "Copley-Fairlawn City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499803782",
    },
    {
        "school": "Copley-Fairlawn Middle School",
        "district": "Copley-Fairlawn City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499803783",
    },
    {
        "school": "Fort Island Primary Elementary School",
        "district": "Copley-Fairlawn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499803784",
    },
    {
        "school": "Herberich Primary Elementary School",
        "district": "Copley-Fairlawn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499803785",
    },
    {
        "school": "Coventry High School",
        "district": "Coventry Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499903788",
    },
    {
        "school": "Coventry Middle School",
        "district": "Coventry Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499903789",
    },
    {
        "school": "Coventry Elementary School",
        "district": "Coventry Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499903791",
    },
    {
        "school": "Manchester Middle School",
        "district": "Manchester Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500003792",
    },
    {
        "school": "Manchester High School",
        "district": "Manchester Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500003793",
    },
    {
        "school": "Nolley Elementary School",
        "district": "Manchester Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500003795",
    },
    {
        "school": "Green Intermediate Elementary School",
        "district": "Green Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500100710",
    },
    {
        "school": "Green High School",
        "district": "Green Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500103797",
    },
    {
        "school": "Green Middle School",
        "district": "Green Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500103798",
    },
    {
        "school": "Greenwood Early Learning Center",
        "district": "Green Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500103800",
    },
    {
        "school": "East Woods Elementary School",
        "district": "Hudson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500200199",
    },
    {
        "school": "Evamere Elementary School",
        "district": "Hudson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500203801",
    },
    {
        "school": "Ellsworth Hill Elementary School",
        "district": "Hudson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500203802",
    },
    {
        "school": "Hudson Middle School",
        "district": "Hudson City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500203803",
    },
    {
        "school": "Hudson High School",
        "district": "Hudson City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500203804",
    },
    {
        "school": "McDowell Elementary School",
        "district": "Hudson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500203805",
    },
    {
        "school": "Mogadore Junior High School",
        "district": "Mogadore Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500303514",
    },
    {
        "school": "Mogadore High School",
        "district": "Mogadore Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500303806",
    },
    {
        "school": "O H Somers Elementary School",
        "district": "Mogadore Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500303807",
    },
    {
        "school": "Northfield Elementary School",
        "district": "Nordonia Hills City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500401098",
    },
    {
        "school": "Ledgeview Elementary School",
        "district": "Nordonia Hills City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500403808",
    },
    {
        "school": "Lee Eaton Elementary School",
        "district": "Nordonia Hills City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500403809",
    },
    {
        "school": "Nordonia Middle School",
        "district": "Nordonia Hills City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500403811",
    },
    {
        "school": "Nordonia High School",
        "district": "Nordonia Hills City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500403812",
    },
    {
        "school": "Rushwood Elementary School",
        "district": "Nordonia Hills City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500403814",
    },
    {
        "school": "Bath Elementary School",
        "district": "Revere Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500503815",
    },
    {
        "school": "Revere Middle School",
        "district": "Revere Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500503816",
    },
    {
        "school": "Richfield Elementary School",
        "district": "Revere Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500503817",
    },
    {
        "school": "Revere High School",
        "district": "Revere Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500503818",
    },
    {
        "school": "Spring Hill Elementary",
        "district": "Springfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500603823",
    },
    {
        "school": "Schrop Intermediate School",
        "district": "Springfield Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500603825",
    },
    {
        "school": "Springfield Junior/Senior High School",
        "district": "Springfield Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500603827",
    },
    {
        "school": "Young Elementary School",
        "district": "Springfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500603828",
    },
    {
        "school": "Twinsburg High School",
        "district": "Twinsburg City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500702802",
    },
    {
        "school": "R B Chamberlin Middle School",
        "district": "Twinsburg City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500703829",
    },
    {
        "school": "Geo G Dodge Elementary School",
        "district": "Twinsburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500703830",
    },
    {
        "school": "Samuel Bissell Elementary School",
        "district": "Twinsburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500703831",
    },
    {
        "school": "Wilcox Elementary School",
        "district": "Twinsburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500703833",
    },
    {
        "school": "Portage Lakes Career Center",
        "district": "Portage Lakes",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390634904123",
    },
    {
        "school": "Mapleton Elementary School",
        "district": "Mapleton Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458305294",
    },
    {
        "school": "Ashland High School",
        "district": "Ashland City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435000075",
    },
    {
        "school": "Ashland Middle School",
        "district": "Ashland City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435000076",
    },
    {
        "school": "Edison Elementary School",
        "district": "Ashland City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435000077",
    },
    {
        "school": "Taft Intermediate School",
        "district": "Ashland City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435000080",
    },
    {
        "school": "Reagan Elementary School",
        "district": "Ashland City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435000081",
    },
    {
        "school": "Budd Elementary School",
        "district": "Loudonville-Perrysville Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454602224",
    },
    {
        "school": "Loudonville High School",
        "district": "Loudonville-Perrysville Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454602225",
    },
    {
        "school": "McMullen Elementary School",
        "district": "Loudonville-Perrysville Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454602226",
    },
    {
        "school": "Hillsdale Elementary School",
        "district": "Hillsdale Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458202351",
    },
    {
        "school": "Hillsdale High School",
        "district": "Hillsdale Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458202352",
    },
    {
        "school": "Hillsdale Middle School",
        "district": "Hillsdale Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458202353",
    },
    {
        "school": "Mapleton High School",
        "district": "Mapleton Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458302354",
    },
    {
        "school": "Ashland-W Holmes Career Center",
        "district": "Ashland County-West Holmes",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390620404117",
    },
    {
        "school": "Crestview High School",
        "district": "Crestview Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494203583",
    },
    {
        "school": "Crestview Elementary School",
        "district": "Crestview Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494203585",
    },
    {
        "school": "Crestview Middle School",
        "district": "Crestview Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494203586",
    },
    {
        "school": "Black River High School",
        "district": "Black River Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484603258",
    },
    {
        "school": "Black River Education Center Middle School",
        "district": "Black River Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484603260",
    },
    {
        "school": "Black River Education Center Elementary School",
        "district": "Black River Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484603261",
    },
    {
        "school": "Gateway Elementary School",
        "district": "Conneaut Area City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438105273",
    },
    {
        "school": "Lakeshore Primary Elementary School",
        "district": "Conneaut Area City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438105274",
    },
    {
        "school": "Grand Valley Elementary School",
        "district": "Grand Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458605126",
    },
    {
        "school": "Lakeside High School",
        "district": "Ashtabula Area City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435100084",
    },
    {
        "school": "Lakeside Junior High School",
        "district": "Ashtabula Area City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435100087",
    },
    {
        "school": "Ontario Primary School",
        "district": "Ashtabula Area City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435100088",
    },
    {
        "school": "Erie Intermediate School",
        "district": "Ashtabula Area City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435100090",
    },
    {
        "school": "Michigan Primary School",
        "district": "Ashtabula Area City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435100091",
    },
    {
        "school": "Huron Primary School",
        "district": "Ashtabula Area City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435100093",
    },
    {
        "school": "Conneaut High School",
        "district": "Conneaut Area City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438100747",
    },
    {
        "school": "Conneaut Middle School",
        "district": "Conneaut Area City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438100750",
    },
    {
        "school": "Austinburg Elementary School",
        "district": "Geneva Area City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440501000",
    },
    {
        "school": "Cork Elementary School",
        "district": "Geneva Area City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440501001",
    },
    {
        "school": "Geneva High School",
        "district": "Geneva Area City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440501003",
    },
    {
        "school": "Geneva Middle School",
        "district": "Geneva Area City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440504215",
    },
    {
        "school": "Edgewood High School",
        "district": "Buckeye Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458502358",
    },
    {
        "school": "Kingsville Elementary School",
        "district": "Buckeye Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458502359",
    },
    {
        "school": "Ridgeview Elementary School",
        "district": "Buckeye Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458502363",
    },
    {
        "school": "Wallace H Braden Middle School",
        "district": "Buckeye Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458502364",
    },
    {
        "school": "Grand Valley Middle School",
        "district": "Grand Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458602366",
    },
    {
        "school": "Grand Valley High School",
        "district": "Grand Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458602367",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Jefferson Area Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458702371",
    },
    {
        "school": "Jefferson Area Sr High School",
        "district": "Jefferson Area Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458702372",
    },
    {
        "school": "Rock Creek Elementary School",
        "district": "Jefferson Area Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458702373",
    },
    {
        "school": "Pymatuning Valley High School",
        "district": "Pymatuning Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458802374",
    },
    {
        "school": "Pymatuning Valley Middle School",
        "district": "Pymatuning Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458802375",
    },
    {
        "school": "Pymatuning Valley Primary Elementary School",
        "district": "Pymatuning Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458802376",
    },
    {
        "school": "Ashtabula County Technical and Career Campus",
        "district": "Ashtabula County Technical and Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390508104053",
    },
    {
        "school": "Athens High School",
        "district": "Athens City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435200097",
    },
    {
        "school": "Athens Middle School",
        "district": "Athens City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435200098",
    },
    {
        "school": "East Elementary School",
        "district": "Athens City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435200100",
    },
    {
        "school": "Morrison Elementary School",
        "district": "Athens City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435200101",
    },
    {
        "school": "The Plains Elementary School",
        "district": "Athens City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435200102",
    },
    {
        "school": "Nelsonville-York High School",
        "district": "Nelsonville-York City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444401368",
    },
    {
        "school": "Nelsonville-York Junior High School",
        "district": "Nelsonville-York City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444401369",
    },
    {
        "school": "Nelsonville-York Elementary School",
        "district": "Nelsonville-York City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444401371",
    },
    {
        "school": "Alexander Elementary School",
        "district": "Alexander Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459002377",
    },
    {
        "school": "Alexander Jr. / Sr. High School",
        "district": "Alexander Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459002378",
    },
    {
        "school": "Amesville Elementary School",
        "district": "Federal Hocking Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459102381",
    },
    {
        "school": "Coolville Elementary School",
        "district": "Federal Hocking Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459102382",
    },
    {
        "school": "Federal Hocking High School",
        "district": "Federal Hocking Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459102383",
    },
    {
        "school": "Federal Hocking Middle School",
        "district": "Federal Hocking Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459104244",
    },
    {
        "school": "Trimble High School",
        "district": "Trimble Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459202384",
    },
    {
        "school": "Trimble Elementary School",
        "district": "Trimble Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459202385",
    },
    {
        "school": "Trimble Junior High",
        "district": "Trimble Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459202386",
    },
    {
        "school": "Tri-County Career Center",
        "district": "Tri-County Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390516004090",
    },
    {
        "school": "Bellefontaine High School",
        "district": "Bellefontaine City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435800144",
    },
    {
        "school": "Bellefontaine Middle School",
        "district": "Bellefontaine City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435800145",
    },
    {
        "school": "Bellefontaine Elementary School",
        "district": "Bellefontaine City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435800148",
    },
    {
        "school": "Bellefontaine Intermediate School",
        "district": "Bellefontaine City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435800149",
    },
    {
        "school": "West Liberty-Salem Elementary School",
        "district": "West Liberty-Salem Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462102471",
    },
    {
        "school": "West Liberty-Salem Middle/High School",
        "district": "West Liberty-Salem Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462102472",
    },
    {
        "school": "Benjamin Logan Elementary School",
        "district": "Benjamin Logan Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480703099",
    },
    {
        "school": "Benjamin Logan High School",
        "district": "Benjamin Logan Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480703102",
    },
    {
        "school": "Benjamin Logan Middle School",
        "district": "Benjamin Logan Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480703103",
    },
    {
        "school": "Indian Lake High School",
        "district": "Indian Lake Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480803105",
    },
    {
        "school": "Indian Lake Elementary School",
        "district": "Indian Lake Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480803106",
    },
    {
        "school": "Indian Lake Middle School",
        "district": "Indian Lake Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480803107",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Riverside Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480903108",
    },
    {
        "school": "Riverside High School",
        "district": "Riverside Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480903109",
    },
    {
        "school": "Ohio Hi-Point",
        "district": "Ohio Hi-Point Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390513304079",
    },
    {
        "school": "Buckeye Central Elementary School",
        "district": "Buckeye Central Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465004591",
    },
    {
        "school": "Bucyrus Secondary School",
        "district": "Bucyrus City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436800216",
    },
    {
        "school": "Primary Elementary School",
        "district": "Galion City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440200981",
    },
    {
        "school": "Galion High School",
        "district": "Galion City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440200983",
    },
    {
        "school": "Galion Middle School",
        "district": "Galion City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440200984",
    },
    {
        "school": "Intermediate Elementary School",
        "district": "Galion City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440200986",
    },
    {
        "school": "Buckeye Central High School",
        "district": "Buckeye Central Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465002574",
    },
    {
        "school": "Col Crawford High School",
        "district": "Colonel Crawford Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465102577",
    },
    {
        "school": "William Crawford Intermediate Schools",
        "district": "Colonel Crawford Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465102578",
    },
    {
        "school": "Hannah Crawford Elementary School grades 3 -5",
        "district": "Colonel Crawford Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465102580",
    },
    {
        "school": "Hannah Crawford Elementary School PreK-Grade 2",
        "district": "Colonel Crawford Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465102581",
    },
    {
        "school": "Wynford Elementary School",
        "district": "Wynford Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465202582",
    },
    {
        "school": "Wynford High School",
        "district": "Wynford Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465202586",
    },
    {
        "school": "Crestline High School",
        "district": "Crestline Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000802181",
    },
    {
        "school": "Crestline Elementary School",
        "district": "Crestline Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000802184",
    },
    {
        "school": "Crestline Preschool",
        "district": "Crestline Exempted Village",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000804482",
    },
    {
        "school": "Cambridge Primary School",
        "district": "Cambridge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436904198",
    },
    {
        "school": "Cambridge Intermediate School",
        "district": "Cambridge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436904199",
    },
    {
        "school": "Cambridge Middle School",
        "district": "Cambridge City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436900224",
    },
    {
        "school": "Cambridge High School",
        "district": "Cambridge City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436900225",
    },
    {
        "school": "Brook Intermediate School",
        "district": "Rolling Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473002831",
    },
    {
        "school": "Byesville Elementary School",
        "district": "Rolling Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473002832",
    },
    {
        "school": "Meadowbrook High School",
        "district": "Rolling Hills Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473002835",
    },
    {
        "school": "Meadowbrook Middle School",
        "district": "Rolling Hills Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473004166",
    },
    {
        "school": "Secrest Elementary School",
        "district": "Rolling Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473004311",
    },
    {
        "school": "Buckeye Trail High School",
        "district": "East Guernsey Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390696804139",
    },
    {
        "school": "Buckeye Trail Middle School",
        "district": "East Guernsey Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390696804143",
    },
    {
        "school": "Buckeye Trail Elementary",
        "district": "East Guernsey Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390696804255",
    },
    {
        "school": "Malvern Middle School",
        "district": "Brown Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461705296",
    },
    {
        "school": "Stark High School",
        "district": "Stark High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390017504699",
    },
    {
        "school": "Canton Harbor High School",
        "district": "Canton Harbor High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390028504617",
    },
    {
        "school": "Summit Academy Secondary - Canton",
        "district": "Summit Academy Secondary - Canton",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390049505205",
    },
    {
        "school": "Alliance Middle School",
        "district": "Alliance City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434904189",
    },
    {
        "school": "Alliance Intermediate School @ Northside",
        "district": "Alliance City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434904190",
    },
    {
        "school": "Rockhill Elementary School",
        "district": "Alliance City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434904191",
    },
    {
        "school": "Choices Alternative School",
        "district": "Canton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437104202",
    },
    {
        "school": "Strausser Elementary School",
        "district": "Jackson Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498504662",
    },
    {
        "school": "Carrollton High School-Carrollton Middle School",
        "district": "Carrollton Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452702154",
    },
    {
        "school": "Carrollton Elementary School",
        "district": "Carrollton Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452702155",
    },
    {
        "school": "Malvern Elementary School",
        "district": "Brown Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461702461",
    },
    {
        "school": "Malvern High School",
        "district": "Brown Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461702462",
    },
    {
        "school": "Conotton Valley High School",
        "district": "Conotton Valley Union Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475402916",
    },
    {
        "school": "Conotton Valley Elementary",
        "district": "Conotton Valley Union Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475402914",
    },
    {
        "school": "Summit Academy Community School for Alternative Learn-Canton",
        "district": "Summit Academy Community School for Alternative Learn-Canton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390007103346",
    },
    {
        "school": "Alliance High School",
        "district": "Alliance City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434900064",
    },
    {
        "school": "Parkway Elementary School",
        "district": "Alliance City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434900069",
    },
    {
        "school": "Alliance Early Learning School at South Lincoln",
        "district": "Alliance City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434900071",
    },
    {
        "school": "Allen Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100236",
    },
    {
        "school": "Belden Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100238",
    },
    {
        "school": "Belle Stone Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100239",
    },
    {
        "school": "Cedar Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100240",
    },
    {
        "school": "Clarendon Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100241",
    },
    {
        "school": "Canton Early College Academy at Crenshaw",
        "district": "Canton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100242",
    },
    {
        "school": "Dueber Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100243",
    },
    {
        "school": "Gibbs Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100245",
    },
    {
        "school": "Harter Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100246",
    },
    {
        "school": "Hartford Middle School",
        "district": "Canton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100247",
    },
    {
        "school": "Lehman Middle School",
        "district": "Canton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100249",
    },
    {
        "school": "Mason Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100251",
    },
    {
        "school": "McGregor Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100252",
    },
    {
        "school": "McKinley High School",
        "district": "Canton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100253",
    },
    {
        "school": "Barbara F Schreiber Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100259",
    },
    {
        "school": "Worley Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100260",
    },
    {
        "school": "Youtz Elementary School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437100261",
    },
    {
        "school": "Portage Collab Montessori Middle School",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437103213",
    },
    {
        "school": "Massillon Junior High School",
        "district": "Massillon City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443501276",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Massillon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443501279",
    },
    {
        "school": "Gorrell Elementary School",
        "district": "Massillon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443501280",
    },
    {
        "school": "Washington High School",
        "district": "Massillon City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443501286",
    },
    {
        "school": "Whittier Elementary School",
        "district": "Massillon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443501287",
    },
    {
        "school": "Clearmount Elementary School",
        "district": "North Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445001415",
    },
    {
        "school": "Greentown Intermediate  School",
        "district": "North Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445001416",
    },
    {
        "school": "Hoover High School",
        "district": "North Canton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445001417",
    },
    {
        "school": "North Canton Middle School",
        "district": "North Canton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445001418",
    },
    {
        "school": "Northwood Elementary School",
        "district": "North Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445001419",
    },
    {
        "school": "Orchard Hill Intermediate School",
        "district": "North Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445001420",
    },
    {
        "school": "Mary L Evans Early Childhood Center",
        "district": "North Canton City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445004361",
    },
    {
        "school": "Canton South High School",
        "district": "Canton Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498303700",
    },
    {
        "school": "Faircrest Memorial Middle School",
        "district": "Canton Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498303701",
    },
    {
        "school": "Walker Elementary School",
        "district": "Canton Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498303707",
    },
    {
        "school": "Fairless Middle School",
        "district": "Fairless Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498400701",
    },
    {
        "school": "Fairless High School",
        "district": "Fairless Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498403709",
    },
    {
        "school": "Amherst Elementary School",
        "district": "Jackson Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498503714",
    },
    {
        "school": "Jackson High School",
        "district": "Jackson Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498503715",
    },
    {
        "school": "Jackson Memorial Middle School",
        "district": "Jackson Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498503716",
    },
    {
        "school": "Lake Cable Elementary School",
        "district": "Jackson Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498503717",
    },
    {
        "school": "Sauder Elementary School",
        "district": "Jackson Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498503718",
    },
    {
        "school": "Lake Middle / High School",
        "district": "Lake Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498603720",
    },
    {
        "school": "Lake Primary School",
        "district": "Lake Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498603723",
    },
    {
        "school": "Lake Elementary School",
        "district": "Lake Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498604170",
    },
    {
        "school": "Louisville Elementary School",
        "district": "Louisville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498703725",
    },
    {
        "school": "Louisville High School",
        "district": "Louisville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498703726",
    },
    {
        "school": "Louisville Middle School",
        "district": "Louisville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498703727",
    },
    {
        "school": "North Nimishillen Elementary School",
        "district": "Louisville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498703728",
    },
    {
        "school": "Lexington Elementary School",
        "district": "Marlington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498803730",
    },
    {
        "school": "Marlington High School",
        "district": "Marlington Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498803732",
    },
    {
        "school": "Marlington Middle School",
        "district": "Marlington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498803733",
    },
    {
        "school": "Washington Elementary School",
        "district": "Marlington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498803734",
    },
    {
        "school": "Minerva Middle School",
        "district": "Minerva Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498903735",
    },
    {
        "school": "Minerva Elementary School",
        "district": "Minerva Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498903736",
    },
    {
        "school": "Minerva High School",
        "district": "Minerva Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498903737",
    },
    {
        "school": "W. S. Stinson Elementary School",
        "district": "Northwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499003740",
    },
    {
        "school": "Northwest Primary School",
        "district": "Northwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499003741",
    },
    {
        "school": "Northwest High School",
        "district": "Northwest Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499003742",
    },
    {
        "school": "Northwest Middle School",
        "district": "Northwest Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499003743",
    },
    {
        "school": "East Canton Middle School",
        "district": "Osnaburg Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499100341",
    },
    {
        "school": "East Canton Elementary School",
        "district": "Osnaburg Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499103745",
    },
    {
        "school": "East Canton High School",
        "district": "Osnaburg Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499103746",
    },
    {
        "school": "Edison Middle School",
        "district": "Perry Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499203747",
    },
    {
        "school": "Genoa Elementary School",
        "district": "Perry Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499203748",
    },
    {
        "school": "Lohr Elementary School",
        "district": "Perry Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499203749",
    },
    {
        "school": "Perry High School",
        "district": "Perry Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499203750",
    },
    {
        "school": "Pfeiffer Intermediate School",
        "district": "Perry Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499203751",
    },
    {
        "school": "T C Knapp Elementary School",
        "district": "Perry Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499203754",
    },
    {
        "school": "Watson Elementary School",
        "district": "Perry Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499203755",
    },
    {
        "school": "Whipple Heights Elementary School",
        "district": "Perry Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499203756",
    },
    {
        "school": "Avondale Elementary School",
        "district": "Plain Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499303757",
    },
    {
        "school": "Charles L Warstler Elementary School",
        "district": "Plain Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499303758",
    },
    {
        "school": "Frazer Elementary School",
        "district": "Plain Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499303760",
    },
    {
        "school": "GlenOak High School",
        "district": "Plain Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499303761",
    },
    {
        "school": "Oakwood Middle School",
        "district": "Plain Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499303763",
    },
    {
        "school": "Ransom H Barr Elementary School",
        "district": "Plain Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499303766",
    },
    {
        "school": "Glenwood Intermediate School",
        "district": "Plain Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499303767",
    },
    {
        "school": "Robert A. Taft Elementary School",
        "district": "Plain Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499304329",
    },
    {
        "school": "Tuslaw Middle School",
        "district": "Tuslaw Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499503772",
    },
    {
        "school": "Tuslaw High School",
        "district": "Tuslaw Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499503776",
    },
    {
        "school": "Tuslaw Elementary School",
        "district": "Tuslaw Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499503777",
    },
    {
        "school": "R G Drage Career Technical Ctr",
        "district": "Stark County Area",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390620204116",
    },
    {
        "school": "Education Complex",
        "district": "Celina City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003005095",
    },
    {
        "school": "Coldwater Middle School",
        "district": "Coldwater Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453101377",
    },
    {
        "school": "Coldwater High School",
        "district": "Coldwater Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453102171",
    },
    {
        "school": "Coldwater Elementary School",
        "district": "Coldwater Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453104398",
    },
    {
        "school": "Parkway Elementary School",
        "district": "Parkway Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485700250",
    },
    {
        "school": "Parkway High School",
        "district": "Parkway Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485703303",
    },
    {
        "school": "St Henry High School",
        "district": "St Henry Consolidated Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485803305",
    },
    {
        "school": "St Henry Elementary School",
        "district": "St Henry Consolidated Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485803306",
    },
    {
        "school": "St Henry Middle School",
        "district": "St Henry Consolidated Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485803307",
    },
    {
        "school": "Fort Recovery Middle School",
        "district": "Fort Recovery Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485903308",
    },
    {
        "school": "Fort Recovery High School",
        "district": "Fort Recovery Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485903309",
    },
    {
        "school": "Fort Recovery Elementary School",
        "district": "Fort Recovery Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485903312",
    },
    {
        "school": "Celina Middle School",
        "district": "Celina City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003000262",
    },
    {
        "school": "Celina High School",
        "district": "Celina City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003000263",
    },
    {
        "school": "Celina Primary School",
        "district": "Celina City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003000264",
    },
    {
        "school": "Celina Elementary School",
        "district": "Celina City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003000266",
    },
    {
        "school": "Celina Intermediate Elementary School",
        "district": "Celina City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003001318",
    },
    {
        "school": "Marion Local Elementary School",
        "district": "Marion Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003103297",
    },
    {
        "school": "Marion Local High School",
        "district": "Marion Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003103298",
    },
    {
        "school": "Parkway Middle School",
        "district": "Parkway Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390485703302",
    },
    {
        "school": "Unioto Elementary",
        "district": "Union-Scioto Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495305302",
    },
    {
        "school": "Chillicothe High School",
        "district": "Chillicothe City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437400281",
    },
    {
        "school": "Chillicothe Primary School",
        "district": "Chillicothe City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437400285",
    },
    {
        "school": "Chillicothe Middle School",
        "district": "Chillicothe City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437400286",
    },
    {
        "school": "Chillicothe Intermediate School",
        "district": "Chillicothe City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437400287",
    },
    {
        "school": "Adena Middle School",
        "district": "Adena Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494901451",
    },
    {
        "school": "Adena High School",
        "district": "Adena Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494903611",
    },
    {
        "school": "Adena Elementary School",
        "district": "Adena Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494903613",
    },
    {
        "school": "Huntington Middle School",
        "district": "Huntington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495002791",
    },
    {
        "school": "Huntington Elementary School",
        "district": "Huntington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495003614",
    },
    {
        "school": "Huntington High School",
        "district": "Huntington Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495003615",
    },
    {
        "school": "Paint Valley Middle School",
        "district": "Paint Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495103616",
    },
    {
        "school": "Paint Valley High School",
        "district": "Paint Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495103617",
    },
    {
        "school": "Paint Valley Elementary",
        "district": "Paint Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495103618",
    },
    {
        "school": "Southeastern Middle School",
        "district": "Southeastern Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495203620",
    },
    {
        "school": "Southeastern Elementary School",
        "district": "Southeastern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495203621",
    },
    {
        "school": "Southeastern High School",
        "district": "Southeastern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495203623",
    },
    {
        "school": "Unioto Middle School",
        "district": "Union-Scioto Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495301094",
    },
    {
        "school": "Unioto High School",
        "district": "Union-Scioto Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495303624",
    },
    {
        "school": "Zane Trace Elementary School",
        "district": "Zane Trace Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495403627",
    },
    {
        "school": "Zane Trace High School",
        "district": "Zane Trace Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495403628",
    },
    {
        "school": "Zane Trace Middle School",
        "district": "Zane Trace Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495403629",
    },
    {
        "school": "Pickaway-Ross Career & Technology Center",
        "district": "Pickaway-Ross County JVSD",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390514304085",
    },
    {
        "school": "Endeavor Elementary School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461105343",
    },
    {
        "school": "Ripley Union Lewis Huntington Middle School",
        "district": "Ripley-Union-Lewis-Huntington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460705295",
    },
    {
        "school": "Middletown Preparatory & Fitness Academy",
        "district": "Middletown Preparatory & Fitness Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390019404718",
    },
    {
        "school": "Summit Academy Secondary School - Middletown",
        "district": "Summit Academy Secondary School - Middletown",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390036104898",
    },
    {
        "school": "VanGorden Elementary School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461104583",
    },
    {
        "school": "Lakota Plains Junior School",
        "district": "Lakota Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461104584",
    },
    {
        "school": "Wyandot Early Childhood School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461105186",
    },
    {
        "school": "Butler Tech School of the Arts",
        "district": "Butler Technology & Career Development Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390508804942",
    },
    {
        "school": "Butler Tech Natural Science Center",
        "district": "Butler Technology & Career Development Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390508804943",
    },
    {
        "school": "Mulberry Elementary School",
        "district": "Milford Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455004576",
    },
    {
        "school": "McCormick Elementary School",
        "district": "Milford Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455004577",
    },
    {
        "school": "Meadowview Elementary School",
        "district": "Milford Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455004578",
    },
    {
        "school": "Pattison Elementary School",
        "district": "Milford Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455004579",
    },
    {
        "school": "Milford Preschool and Extended Day",
        "district": "Milford Exempted Village",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455005125",
    },
    {
        "school": "Hill Intermediate Elementary School",
        "district": "Bethel-Tate Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463104589",
    },
    {
        "school": "Bick Primary Elementary School",
        "district": "Bethel-Tate Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463104590",
    },
    {
        "school": "Alliance Academy of Cincinnati",
        "district": "Alliance Academy of Cincinnati",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390013004180",
    },
    {
        "school": "Ohio Connections Academy Inc",
        "district": "Ohio Connections Academy Inc",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390025005193",
    },
    {
        "school": "Orion Academy",
        "district": "Orion Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390030804845",
    },
    {
        "school": "The Dream Academy Community School",
        "district": "The Dream Academy Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390031404851",
    },
    {
        "school": "Horizon Science Academy-Cincinnati",
        "district": "Horizon Science Academy-Cincinnati",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390044105000",
    },
    {
        "school": "Summit Academy Community School - Cincinnati",
        "district": "Summit Academy Community School - Cincinnati",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390050105211",
    },
    {
        "school": "Toledo Preparatory and Fitness Academy",
        "district": "Toledo Preparatory and Fitness Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390057305065",
    },
    {
        "school": "Mt. Healthy Preparatory and Fitness Academy",
        "district": "Mt. Healthy Preparatory and Fitness Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390057505067",
    },
    {
        "school": "Virtual High School",
        "district": "Cincinnati Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437504213",
    },
    {
        "school": "Western Hills University High School",
        "district": "Cincinnati Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437504219",
    },
    {
        "school": "Academy for Multilingual Immersion Studies",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437504258",
    },
    {
        "school": "Riverview East Academy",
        "district": "Cincinnati Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437504274",
    },
    {
        "school": "Withrow University High School",
        "district": "Cincinnati Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437504284",
    },
    {
        "school": "Woodward Career Technical High School",
        "district": "Cincinnati Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437504416",
    },
    {
        "school": "Aiken New Tech High School",
        "district": "Cincinnati Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437504417",
    },
    {
        "school": "Greater Ohio Virtual School",
        "district": "Greater Ohio Virtual School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390048805198",
    },
    {
        "school": "Bowman Primary School",
        "district": "Lebanon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442104927",
    },
    {
        "school": "Lebanon Junior High",
        "district": "Lebanon City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442104928",
    },
    {
        "school": "Georgetown Jr/Sr High School",
        "district": "Georgetown Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453702192",
    },
    {
        "school": "Georgetown Elementary School",
        "district": "Georgetown Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453702194",
    },
    {
        "school": "Russellville Elementary School",
        "district": "Eastern Local School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460300796",
    },
    {
        "school": "Eastern MS",
        "district": "Eastern Local School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460300797",
    },
    {
        "school": "Eastern High School",
        "district": "Eastern Local School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460302411",
    },
    {
        "school": "Sardinia Elementary School",
        "district": "Eastern Local School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460302413",
    },
    {
        "school": "Fayetteville-Perry Elementary School",
        "district": "Fayetteville-Perry Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460402414",
    },
    {
        "school": "Fayetteville-Perry High School",
        "district": "Fayetteville-Perry Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460402415",
    },
    {
        "school": "Fayetteville-Perry Middle School",
        "district": "Fayetteville-Perry Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460404163",
    },
    {
        "school": "Mt  Orab Middle School",
        "district": "Western Brown Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460600427",
    },
    {
        "school": "Hamersville Elementary School",
        "district": "Western Brown Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460602416",
    },
    {
        "school": "Mt Orab Primary Elementary School",
        "district": "Western Brown Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460602417",
    },
    {
        "school": "Western Brown High School",
        "district": "Western Brown Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460602418",
    },
    {
        "school": "Ripley Union Lewis Huntington Elementary School",
        "district": "Ripley-Union-Lewis-Huntington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460700516",
    },
    {
        "school": "Ripley-Union-Lewis-Huntington High School",
        "district": "Ripley-Union-Lewis-Huntington Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460702421",
    },
    {
        "school": "Southern Hills Career Technical Center",
        "district": "Southern Hills",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390507904052",
    },
    {
        "school": "Loveland Early Childhood Center",
        "district": "Loveland City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442701206",
    },
    {
        "school": "Madeira Middle School",
        "district": "Madeira City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442801213",
    },
    {
        "school": "Milford Sr High School",
        "district": "Milford Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455002252",
    },
    {
        "school": "Milford Junior High School",
        "district": "Milford Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455002253",
    },
    {
        "school": "Charles L Seipelt Elementary School",
        "district": "Milford Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455002256",
    },
    {
        "school": "Boyd E Smith Elementary School",
        "district": "Milford Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455004161",
    },
    {
        "school": "Locust Corner Elementary School",
        "district": "New Richmond Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455500792",
    },
    {
        "school": "Monroe Elementary School",
        "district": "New Richmond Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455502273",
    },
    {
        "school": "New Richmond High School",
        "district": "New Richmond Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455502276",
    },
    {
        "school": "New Richmond Middle School",
        "district": "New Richmond Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455502277",
    },
    {
        "school": "Batavia Middle School",
        "district": "Batavia Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463000818",
    },
    {
        "school": "Batavia Elementary School",
        "district": "Batavia Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463002503",
    },
    {
        "school": "Batavia High School",
        "district": "Batavia Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463002504",
    },
    {
        "school": "Bethel Tate High School",
        "district": "Bethel-Tate Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463102505",
    },
    {
        "school": "Bethel-Tate Middle School",
        "district": "Bethel-Tate Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463102507",
    },
    {
        "school": "Clermont Northeastern High School",
        "district": "Clermont Northeastern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463202508",
    },
    {
        "school": "Clermont Northeastern Middle School",
        "district": "Clermont Northeastern Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463202510",
    },
    {
        "school": "Clermont Northeastern Elementary School",
        "district": "Clermont Northeastern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463202512",
    },
    {
        "school": "Felicity-Franklin Local Middle School",
        "district": "Felicity-Franklin Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463300821",
    },
    {
        "school": "Felicity-Franklin Local  Elementary School",
        "district": "Felicity-Franklin Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463302513",
    },
    {
        "school": "Felicity-Franklin Local  High School",
        "district": "Felicity-Franklin Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463302514",
    },
    {
        "school": "Marr/Cook Elementary School",
        "district": "Goshen Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463402515",
    },
    {
        "school": "Goshen High School",
        "district": "Goshen Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463402516",
    },
    {
        "school": "Spaulding Elementary School",
        "district": "Goshen Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463402517",
    },
    {
        "school": "Goshen Middle School",
        "district": "Goshen Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463402519",
    },
    {
        "school": "Amelia Elementary School",
        "district": "West Clermont Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463502520",
    },
    {
        "school": "West Clermont Middle School",
        "district": "West Clermont Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463502522",
    },
    {
        "school": "Summerside Elementary",
        "district": "West Clermont Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463502523",
    },
    {
        "school": "Clough Pike Elementary School",
        "district": "West Clermont Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463502524",
    },
    {
        "school": "West Clermont High School",
        "district": "West Clermont Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463502525",
    },
    {
        "school": "Merwin Elementary School",
        "district": "West Clermont Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463502527",
    },
    {
        "school": "Willowville Elementary School",
        "district": "West Clermont Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463502530",
    },
    {
        "school": "Withamsville-Tobasco Elementary School",
        "district": "West Clermont Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463502531",
    },
    {
        "school": "Holly Hill Elementary School",
        "district": "West Clermont Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463504224",
    },
    {
        "school": "Williamsburg Elementary School",
        "district": "Williamsburg Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463602532",
    },
    {
        "school": "Williamsburg High School",
        "district": "Williamsburg Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463602533",
    },
    {
        "school": "Live Oaks Cdc",
        "district": "Great Oaks Career Campuses",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390510604277",
    },
    {
        "school": "U S Grant",
        "district": "U S Grant",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390628004122",
    },
    {
        "school": "Laurel Oaks Cdc",
        "district": "Great Oaks Career Campuses",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390510604276",
    },
    {
        "school": "Cincinnati College Preparatory Academy",
        "district": "Cincinnati College Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390003102807",
    },
    {
        "school": "Riverside Academy",
        "district": "Riverside Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390004302979",
    },
    {
        "school": "T.C.P. World Academy",
        "district": "T.C.P. World Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390007203360",
    },
    {
        "school": "Lighthouse Community Sch Inc",
        "district": "Lighthouse Community Sch Inc",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390007703387",
    },
    {
        "school": "Queen City Career Prep High School",
        "district": "Queen City Career Prep High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390008603447",
    },
    {
        "school": "Dohn Community",
        "district": "Dohn Community",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390010604067",
    },
    {
        "school": "Phoenix Community Learning Ctr",
        "district": "Phoenix Community Learning Ctr",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390011303911",
    },
    {
        "school": "Hamilton Cnty Math & Science",
        "district": "Hamilton Cnty Math & Science",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390012103912",
    },
    {
        "school": "Bond Hill Academy",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500293",
    },
    {
        "school": "Dater Montessori School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500300",
    },
    {
        "school": "Chase School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500303",
    },
    {
        "school": "Cheviot School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500304",
    },
    {
        "school": "College Hill Fundamental Academy",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500311",
    },
    {
        "school": "Covedale School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500314",
    },
    {
        "school": "School For Creative and Performing Arts",
        "district": "Cincinnati Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500316",
    },
    {
        "school": "Gilbert A. Dater High School",
        "district": "Cincinnati Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500319",
    },
    {
        "school": "Frederick Douglass School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500320",
    },
    {
        "school": "Fairview-Clifton German Language School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500325",
    },
    {
        "school": "Hartwell School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500330",
    },
    {
        "school": "George Hays-Jennie Porter School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500332",
    },
    {
        "school": "Evanston Academy",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500335",
    },
    {
        "school": "Kilgour School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500339",
    },
    {
        "school": "John P. Parker School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500344",
    },
    {
        "school": "Midway School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500349",
    },
    {
        "school": "Ethel M. Taylor Academy",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500350",
    },
    {
        "school": "Mt. Airy School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500351",
    },
    {
        "school": "Mt. Washington School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500352",
    },
    {
        "school": "North Avondale Montessori School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500353",
    },
    {
        "school": "Oyler School",
        "district": "Cincinnati Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500357",
    },
    {
        "school": "Pleasant Hill Academy",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500361",
    },
    {
        "school": "Pleasant Ridge Montessori School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500362",
    },
    {
        "school": "Roberts Academy:  A Paideia Learning Community",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500366",
    },
    {
        "school": "Rockdale Academy",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500367",
    },
    {
        "school": "Roselawn Condon School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500370",
    },
    {
        "school": "Rothenberg Preparatory Academy",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500371",
    },
    {
        "school": "Sands Montessori School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500372",
    },
    {
        "school": "Sayler Park School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500374",
    },
    {
        "school": "Shroder Paideia High School",
        "district": "Cincinnati Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500377",
    },
    {
        "school": "Silverton Paideia Academy",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500378",
    },
    {
        "school": "South Avondale School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500379",
    },
    {
        "school": "William H Taft Elementary School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500381",
    },
    {
        "school": "Robert A. Taft Information Technology High School",
        "district": "Cincinnati Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500382",
    },
    {
        "school": "Walnut Hills High School",
        "district": "Cincinnati Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500384",
    },
    {
        "school": "Westwood School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500389",
    },
    {
        "school": "Winton Hills Academy",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500392",
    },
    {
        "school": "Parker Woods Montessori School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500393",
    },
    {
        "school": "Woodford Paideia Academy",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437500395",
    },
    {
        "school": "Carson School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437503703",
    },
    {
        "school": "Academy Of World Languages School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437504280",
    },
    {
        "school": "Clark Montessori High School",
        "district": "Cincinnati Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437504331",
    },
    {
        "school": "Amity Elementary School",
        "district": "Deer Park Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438500833",
    },
    {
        "school": "Deer Park  Jr/Sr High School",
        "district": "Deer Park Community City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438500834",
    },
    {
        "school": "Winton Woods Intermediate School",
        "district": "Winton Woods City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440800588",
    },
    {
        "school": "Winton Woods Primary North",
        "district": "Winton Woods City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440801015",
    },
    {
        "school": "Winton Woods High School",
        "district": "Winton Woods City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440801018",
    },
    {
        "school": "Winton Woods Middle School",
        "district": "Winton Woods City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440801021",
    },
    {
        "school": "Winton Woods Primary South",
        "district": "Winton Woods City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440801024",
    },
    {
        "school": "Winton Woods Elementary School",
        "district": "Winton Woods City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440801025",
    },
    {
        "school": "Lockland Elementary School",
        "district": "Lockland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442301166",
    },
    {
        "school": "Lockland High School",
        "district": "Lockland Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442301167",
    },
    {
        "school": "Loveland Elementary School",
        "district": "Loveland City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442700327",
    },
    {
        "school": "Loveland High School",
        "district": "Loveland City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442701207",
    },
    {
        "school": "Loveland Primary School",
        "district": "Loveland City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442701209",
    },
    {
        "school": "Loveland Middle School",
        "district": "Loveland City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442701210",
    },
    {
        "school": "Loveland Intermediate School",
        "district": "Loveland City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442703688",
    },
    {
        "school": "Madeira Elementary School",
        "district": "Madeira City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442801211",
    },
    {
        "school": "Madeira High School",
        "district": "Madeira City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442801212",
    },
    {
        "school": "Mariemont Junior High School",
        "district": "Mariemont City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443100606",
    },
    {
        "school": "Mariemont High School",
        "district": "Mariemont City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443101240",
    },
    {
        "school": "Mariemont Elementary School",
        "district": "Mariemont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443101241",
    },
    {
        "school": "Terrace Park Elementary School",
        "district": "Mariemont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443101242",
    },
    {
        "school": "Mt. Healthy South Elementary School",
        "district": "Mt Healthy City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444101345",
    },
    {
        "school": "Mt Healthy High School",
        "district": "Mt Healthy City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444101346",
    },
    {
        "school": "Mt. Healthy North Elementary School",
        "district": "Mt Healthy City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444101347",
    },
    {
        "school": "Mt Healthy Junior High School",
        "district": "Mt Healthy City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444101350",
    },
    {
        "school": "North College Hill Elementary School",
        "district": "North College Hill City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445101423",
    },
    {
        "school": "North College Hill High School",
        "district": "North College Hill City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445101425",
    },
    {
        "school": "Sharpsburg Primary",
        "district": "Norwood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445701459",
    },
    {
        "school": "Norwood High School",
        "district": "Norwood City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445701461",
    },
    {
        "school": "Norwood Middle School",
        "district": "Norwood City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445701462",
    },
    {
        "school": "Norwood View Elementary School",
        "district": "Norwood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445701463",
    },
    {
        "school": "Sharpsburg Elementary School",
        "district": "Norwood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445701464",
    },
    {
        "school": "Williams Avenue Elementary School",
        "district": "Norwood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445701465",
    },
    {
        "school": "Evendale Elementary School",
        "district": "Princeton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446701549",
    },
    {
        "school": "Glendale Elementary School",
        "district": "Princeton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446701550",
    },
    {
        "school": "Heritage Hill Elementary School",
        "district": "Princeton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446701551",
    },
    {
        "school": "Lincoln Heights Elementary School",
        "district": "Princeton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446701552",
    },
    {
        "school": "Princeton Community Middle School",
        "district": "Princeton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446701553",
    },
    {
        "school": "Princeton High School",
        "district": "Princeton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446701554",
    },
    {
        "school": "Sharonville Elementary School",
        "district": "Princeton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446701556",
    },
    {
        "school": "Springdale Elementary School",
        "district": "Princeton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446701557",
    },
    {
        "school": "Stewart Elementary School",
        "district": "Princeton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446701558",
    },
    {
        "school": "Woodlawn Elementary School",
        "district": "Princeton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446701559",
    },
    {
        "school": "Reading Primary Elementary School",
        "district": "Reading Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446901568",
    },
    {
        "school": "Reading Intermediate Elementary School",
        "district": "Reading Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446901570",
    },
    {
        "school": "Reading  Community High School",
        "district": "Reading Community City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446901571",
    },
    {
        "school": "Elmwood Place Elementary School",
        "district": "St Bernard-Elmwood Place City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447101579",
    },
    {
        "school": "St Bernard Elementary School",
        "district": "St Bernard-Elmwood Place City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447101580",
    },
    {
        "school": "St Bernard-Elmwood Place High School",
        "district": "St Bernard-Elmwood Place City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447101581",
    },
    {
        "school": "Blue Ash Elementary",
        "district": "Sycamore Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448601737",
    },
    {
        "school": "Edwin H Greene Intermediate Middle School",
        "district": "Sycamore Community City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448601738",
    },
    {
        "school": "Maple Dale Elementary School",
        "district": "Sycamore Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448601739",
    },
    {
        "school": "Montgomery Elementary School",
        "district": "Sycamore Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448601740",
    },
    {
        "school": "Sycamore High School",
        "district": "Sycamore Community City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448601741",
    },
    {
        "school": "Sycamore Junior High School",
        "district": "Sycamore Community City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448601742",
    },
    {
        "school": "Symmes Elementary School",
        "district": "Sycamore Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448604371",
    },
    {
        "school": "Elm Avenue Elementary School",
        "district": "Wyoming City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451402043",
    },
    {
        "school": "Hilltop Elementary School",
        "district": "Wyoming City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451402044",
    },
    {
        "school": "Vermont Avenue Elementary School",
        "district": "Wyoming City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451402046",
    },
    {
        "school": "Wyoming High School",
        "district": "Wyoming City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451402047",
    },
    {
        "school": "Wyoming Middle School",
        "district": "Wyoming City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451402048",
    },
    {
        "school": "Indian Hill Elementary School",
        "district": "Indian Hill Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454302212",
    },
    {
        "school": "Indian Hill High School",
        "district": "Indian Hill Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454302213",
    },
    {
        "school": "Indian Hill Middle School",
        "district": "Indian Hill Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454302214",
    },
    {
        "school": "Indian Hill Primary Elementary School",
        "district": "Indian Hill Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454304366",
    },
    {
        "school": "Finneytown Secondary Campus",
        "district": "Finneytown Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473302840",
    },
    {
        "school": "Brent Elementary School",
        "district": "Finneytown Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473304499",
    },
    {
        "school": "Nagel Middle School",
        "district": "Forest Hills Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473402704",
    },
    {
        "school": "Anderson High School",
        "district": "Forest Hills Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473402843",
    },
    {
        "school": "Ayer Elementary School",
        "district": "Forest Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473402845",
    },
    {
        "school": "Maddux Elementary School",
        "district": "Forest Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473402846",
    },
    {
        "school": "Mercer Elementary School",
        "district": "Forest Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473402847",
    },
    {
        "school": "Sherwood Elementary School",
        "district": "Forest Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473402848",
    },
    {
        "school": "Summit Elementary School",
        "district": "Forest Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473402849",
    },
    {
        "school": "Turpin High School",
        "district": "Forest Hills Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473402850",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Forest Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473402852",
    },
    {
        "school": "Colerain Elementary School",
        "district": "Northwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473602854",
    },
    {
        "school": "Colerain High School",
        "district": "Northwest Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473602855",
    },
    {
        "school": "Colerain Middle School",
        "district": "Northwest Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473602856",
    },
    {
        "school": "Monfort Heights Elementary School",
        "district": "Northwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473602858",
    },
    {
        "school": "Northwest High School",
        "district": "Northwest Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473602859",
    },
    {
        "school": "Pleasant Run Elementary School",
        "district": "Northwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473602860",
    },
    {
        "school": "Pleasant Run Middle School",
        "district": "Northwest Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473602861",
    },
    {
        "school": "Taylor Elementary School",
        "district": "Northwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473602863",
    },
    {
        "school": "Struble Elementary School",
        "district": "Northwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473602864",
    },
    {
        "school": "White Oak Middle School",
        "district": "Northwest Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473602866",
    },
    {
        "school": "Rapid Run Middle School",
        "district": "Oak Hills Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473702722",
    },
    {
        "school": "Bridgetown Middle School",
        "district": "Oak Hills Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473702867",
    },
    {
        "school": "C O Harrison Elementary School",
        "district": "Oak Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473702868",
    },
    {
        "school": "Charles W Springmyer Elementary School",
        "district": "Oak Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473702869",
    },
    {
        "school": "Delhi Middle School",
        "district": "Oak Hills Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473702870",
    },
    {
        "school": "Delshire Elementary School",
        "district": "Oak Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473702871",
    },
    {
        "school": "John Foster Dulles Elementary School",
        "district": "Oak Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473702872",
    },
    {
        "school": "Oak Hills High School",
        "district": "Oak Hills Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473702873",
    },
    {
        "school": "Oakdale Elementary School",
        "district": "Oak Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473702874",
    },
    {
        "school": "Crosby Elementary School",
        "district": "Southwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473802875",
    },
    {
        "school": "Harrison Elementary School",
        "district": "Southwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473802877",
    },
    {
        "school": "Harrison Middle School",
        "district": "Southwest Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473802878",
    },
    {
        "school": "Miamitown Elementary School",
        "district": "Southwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473802880",
    },
    {
        "school": "William Henry Harrison High School",
        "district": "Southwest Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473802881",
    },
    {
        "school": "Whitewater Valley Elementary School",
        "district": "Southwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473804397",
    },
    {
        "school": "Taylor High School",
        "district": "Three Rivers Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473902884",
    },
    {
        "school": "Three Rivers Elementary",
        "district": "Three Rivers Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473902886",
    },
    {
        "school": "Diamond Oaks Cdc",
        "district": "Great Oaks Career Campuses",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390510604065",
    },
    {
        "school": "Scarlet Oaks Cdc",
        "district": "Great Oaks Career Campuses",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390510604068",
    },
    {
        "school": "Anthony Wayne Elementary School",
        "district": "Franklin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440000962",
    },
    {
        "school": "Franklin High School",
        "district": "Franklin City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440000963",
    },
    {
        "school": "Franklin Junior High School",
        "district": "Franklin City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440000964",
    },
    {
        "school": "George H Gerke Elementary School",
        "district": "Franklin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440000965",
    },
    {
        "school": "Hunter Elementary School",
        "district": "Franklin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440000967",
    },
    {
        "school": "Pennyroyal Elementary School",
        "district": "Franklin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440000969",
    },
    {
        "school": "William C Schenck Elementary School",
        "district": "Franklin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440000970",
    },
    {
        "school": "Berry Intermediate School",
        "district": "Lebanon City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442101144",
    },
    {
        "school": "Lebanon High School",
        "district": "Lebanon City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442101146",
    },
    {
        "school": "Donovan  Elementary School",
        "district": "Lebanon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442104304",
    },
    {
        "school": "Carlisle High School",
        "district": "Carlisle Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504103935",
    },
    {
        "school": "Bobby F. Grigsby Intermediate School",
        "district": "Carlisle Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504103936",
    },
    {
        "school": "Chamberlain Middle School",
        "district": "Carlisle Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504103937",
    },
    {
        "school": "Alden R Brown Elementary School",
        "district": "Carlisle Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504103938",
    },
    {
        "school": "Springboro Intermediate School",
        "district": "Springboro Community City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504203518",
    },
    {
        "school": "Clearcreek Elementary School",
        "district": "Springboro Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504203939",
    },
    {
        "school": "Springboro High School",
        "district": "Springboro Community City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504203941",
    },
    {
        "school": "Springboro Junior High School",
        "district": "Springboro Community City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504204172",
    },
    {
        "school": "Columbia Intermediate School",
        "district": "Kings Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504300921",
    },
    {
        "school": "J F Burns Elementary School",
        "district": "Kings Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504303942",
    },
    {
        "school": "Kings Junior High School",
        "district": "Kings Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504303943",
    },
    {
        "school": "Kings Mills Elementary School",
        "district": "Kings Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504303944",
    },
    {
        "school": "South Lebanon Elementary School",
        "district": "Kings Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504303945",
    },
    {
        "school": "Kings High School",
        "district": "Kings Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504304356",
    },
    {
        "school": "Little Miami Intermediate Middle School",
        "district": "Little Miami Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504403548",
    },
    {
        "school": "Hamilton-Maineville Elementary School",
        "district": "Little Miami Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504403946",
    },
    {
        "school": "Little Miami High School",
        "district": "Little Miami Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504403948",
    },
    {
        "school": "Little Miami Junior High School",
        "district": "Little Miami Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504404302",
    },
    {
        "school": "Mason Early Childhood Center Elementary School",
        "district": "Mason City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504501106",
    },
    {
        "school": "Mason Intermediate Elementary School",
        "district": "Mason City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504501468",
    },
    {
        "school": "Mason Middle School",
        "district": "Mason City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504503952",
    },
    {
        "school": "William Mason High School",
        "district": "Mason City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504503954",
    },
    {
        "school": "Waynesville Elementary School",
        "district": "Wayne Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504603955",
    },
    {
        "school": "Waynesville High School",
        "district": "Wayne Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504603956",
    },
    {
        "school": "Waynesville Middle School",
        "district": "Wayne Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504604379",
    },
    {
        "school": "Warren County Career Center",
        "district": "Warren County Vocational School",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390514704087",
    },
    {
        "school": "Monroe High School",
        "district": "Monroe Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390009403602",
    },
    {
        "school": "Monroe Elementary School",
        "district": "Monroe Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390009403635",
    },
    {
        "school": "Summit Acdy Comm Schl for Alternative Learners of Middletown",
        "district": "Summit Acdy Comm Schl for Alternative Learners of Middletown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390009603913",
    },
    {
        "school": "Marshall High School",
        "district": "Marshall High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390010103860",
    },
    {
        "school": "Brookwood Elementary School",
        "district": "Hamilton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441001036",
    },
    {
        "school": "Highland Elementary School",
        "district": "Hamilton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441001037",
    },
    {
        "school": "Garfield Middle School",
        "district": "Hamilton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441001038",
    },
    {
        "school": "Riverview Elementary School",
        "district": "Hamilton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441001041",
    },
    {
        "school": "Hamilton High School",
        "district": "Hamilton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441001050",
    },
    {
        "school": "Crawford Woods Elementary School",
        "district": "Hamilton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441001052",
    },
    {
        "school": "Wilson Middle School",
        "district": "Hamilton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441001054",
    },
    {
        "school": "Amanda Elementary School",
        "district": "Middletown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444001317",
    },
    {
        "school": "Creekview Elementary School",
        "district": "Middletown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444001320",
    },
    {
        "school": "Middletown Middle School",
        "district": "Middletown City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444001322",
    },
    {
        "school": "Mayfield Elementary School",
        "district": "Middletown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444001327",
    },
    {
        "school": "Middletown High School",
        "district": "Middletown City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444001329",
    },
    {
        "school": "Miller Ridge Elementary School",
        "district": "Middletown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444001334",
    },
    {
        "school": "Highview 6th Grade Center",
        "district": "Middletown City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444001338",
    },
    {
        "school": "Wildwood Elementary School",
        "district": "Middletown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444001339",
    },
    {
        "school": "Central Academy Nongraded Elementary School",
        "district": "Middletown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444004385",
    },
    {
        "school": "Edgewood Middle School",
        "district": "Edgewood City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460900294",
    },
    {
        "school": "Seven Mile Elementary School",
        "district": "Edgewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460900439",
    },
    {
        "school": "Babeck Early Childhood School",
        "district": "Edgewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460902422",
    },
    {
        "school": "Edgewood Elementary School",
        "district": "Edgewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460902423",
    },
    {
        "school": "Edgewood High School",
        "district": "Edgewood City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460902424",
    },
    {
        "school": "Fairfield East Elementary School",
        "district": "Fairfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461000802",
    },
    {
        "school": "Crossroads Middle School",
        "district": "Fairfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461001410",
    },
    {
        "school": "Fairfield Central Elementary School",
        "district": "Fairfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461002428",
    },
    {
        "school": "Fairfield High School",
        "district": "Fairfield City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461002429",
    },
    {
        "school": "Fairfield Freshman High School",
        "district": "Fairfield City",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461002430",
    },
    {
        "school": "Creekside Middle School",
        "district": "Fairfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461002431",
    },
    {
        "school": "Fairfield North Elementary School",
        "district": "Fairfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461002432",
    },
    {
        "school": "Fairfield South Elementary School",
        "district": "Fairfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461002433",
    },
    {
        "school": "Fairfield West Elementary School",
        "district": "Fairfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461002434",
    },
    {
        "school": "Heritage Early Childhood School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461100179",
    },
    {
        "school": "Cherokee Elementary School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461100441",
    },
    {
        "school": "Independence Elementary School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461100450",
    },
    {
        "school": "Creekside Early Childhood School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461100804",
    },
    {
        "school": "Lakota Ridge Junior School",
        "district": "Lakota Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461100806",
    },
    {
        "school": "Lakota East High School",
        "district": "Lakota Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461100810",
    },
    {
        "school": "Adena Elementary School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461102435",
    },
    {
        "school": "Hopewell Early Childhood School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461102436",
    },
    {
        "school": "Hopewell Junior School",
        "district": "Lakota Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461102437",
    },
    {
        "school": "Lakota West High School",
        "district": "Lakota Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461102438",
    },
    {
        "school": "Liberty Junior School",
        "district": "Lakota Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461102439",
    },
    {
        "school": "Liberty Early Childhood School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461102440",
    },
    {
        "school": "Union Elementary School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461102441",
    },
    {
        "school": "Freedom Elementary School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461104343",
    },
    {
        "school": "Shawnee Early Childhood School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461104403",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461104404",
    },
    {
        "school": "Madison Junior High",
        "district": "Madison Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461202442",
    },
    {
        "school": "Madison High School",
        "district": "Madison Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461202443",
    },
    {
        "school": "Madison Elementary School",
        "district": "Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461202444",
    },
    {
        "school": "New Miami Elementary School",
        "district": "New Miami Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461302446",
    },
    {
        "school": "New Miami  High School",
        "district": "New Miami Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461302447",
    },
    {
        "school": "Elda Elementary School",
        "district": "Ross Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461402449",
    },
    {
        "school": "Morgan Elementary School",
        "district": "Ross Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461402450",
    },
    {
        "school": "Ross High School",
        "district": "Ross Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461402451",
    },
    {
        "school": "Ross Middle School",
        "district": "Ross Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461402452",
    },
    {
        "school": "Kramer Elementary School",
        "district": "Talawanda City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461502454",
    },
    {
        "school": "Maude Marshall Elementary School",
        "district": "Talawanda City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461502456",
    },
    {
        "school": "Bogan Elementary",
        "district": "Talawanda City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461502459",
    },
    {
        "school": "Talawanda High School",
        "district": "Talawanda City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461502460",
    },
    {
        "school": "Talawanda Middle School",
        "district": "Talawanda City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461504370",
    },
    {
        "school": "D Russel Lee Career-Technology Center",
        "district": "Butler Technology & Career Development Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390508804056",
    },
    {
        "school": "Hope Academy Northcoast",
        "district": "Hope Academy Northcoast",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390018104705",
    },
    {
        "school": "Constellation Schools: Puritas Community Elementary",
        "district": "Constellation Schools: Puritas Community Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390021104735",
    },
    {
        "school": "Constellation Schools: Stockyard Community Elementary",
        "district": "Constellation Schools: Stockyard Community Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390021204736",
    },
    {
        "school": "Lake Erie International High School",
        "district": "Lake Erie International High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390027704817",
    },
    {
        "school": "Cleveland Academy for Scholarship Technology and Leadership",
        "district": "Cleveland Academy for Scholarship Technology and Leadership",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390028604731",
    },
    {
        "school": "Constellation Schools: Puritas Community Middle",
        "district": "Constellation Schools: Puritas Community Middle",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390029104828",
    },
    {
        "school": "Pinnacle Academy",
        "district": "Pinnacle Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390029904836",
    },
    {
        "school": "Apex Academy",
        "district": "Apex Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390030904846",
    },
    {
        "school": "Hope Academy Northwest Campus",
        "district": "Hope Academy Northwest Campus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390031304850",
    },
    {
        "school": "Capital City Career Prep High School",
        "district": "Capital City Career Prep High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390038104918",
    },
    {
        "school": "Horizon Science Academy-Denison Middle School",
        "district": "Horizon Science Academy-Denison Middle School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390045405013",
    },
    {
        "school": "Horizon Science Academy-Cleveland Middle School",
        "district": "Horizon Science Academy-Cleveland Middle School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390047005029",
    },
    {
        "school": "Summit Academy Community School-Parma",
        "district": "Summit Academy Community School-Parma",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390049705207",
    },
    {
        "school": "Constellation Schools: Westpark Community Middle",
        "district": "Constellation Schools: Westpark Community Middle",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390050305213",
    },
    {
        "school": "Constellation Schools: Madison Community Elementary",
        "district": "Constellation Schools: Madison Community Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390050605216",
    },
    {
        "school": "Constellation Schools: Lorain Community Middle",
        "district": "Constellation Schools: Lorain Community Middle",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390050705217",
    },
    {
        "school": "Constellation Schools: Old Brooklyn Community Middle",
        "district": "Constellation Schools: Old Brooklyn Community Middle",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390050805218",
    },
    {
        "school": "Promise Academy",
        "district": "Promise Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390056205054",
    },
    {
        "school": "Cleveland Arts and Social Sciences Academy",
        "district": "Cleveland Arts and Social Sciences Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390058405076",
    },
    {
        "school": "Noble Academy-Cleveland",
        "district": "Noble Academy-Cleveland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390064605345",
    },
    {
        "school": "Bluestone Elementary School",
        "district": "Euclid City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439505277",
    },
    {
        "school": "Chestnut Intermediate Elementary School",
        "district": "North Olmsted City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445204542",
    },
    {
        "school": "First Step Preschool and Daycare",
        "district": "Parma City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446305112",
    },
    {
        "school": "Moreland Hills Elementary School",
        "district": "Orange City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001604592",
    },
    {
        "school": "Summit Academy Community School - Painesville",
        "district": "Summit Academy Community School - Painesville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390035604893",
    },
    {
        "school": "Black River Career Prep High School",
        "district": "Black River Career Prep High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390017604700",
    },
    {
        "school": "Summit Academy School - Lorain",
        "district": "Summit Academy School - Lorain",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390033804875",
    },
    {
        "school": "Summit Academy - Toledo",
        "district": "Summit Academy - Toledo",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390049605206",
    },
    {
        "school": "Menlo Park Academy",
        "district": "Menlo Park Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390050505215",
    },
    {
        "school": "Lorain Preparatory Academy",
        "district": "Lorain Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390058705079",
    },
    {
        "school": "Monroe Preparatory Academy",
        "district": "Monroe Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390059405085",
    },
    {
        "school": "Elyria Early Childhood Center",
        "district": "Elyria City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439405104",
    },
    {
        "school": "Frank Jacinto Elementary",
        "district": "Lorain City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442605106",
    },
    {
        "school": "General Johnnie Wilson Middle School",
        "district": "Lorain City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442605107",
    },
    {
        "school": "Longfellow Middle School",
        "district": "Lorain City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442605108",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Lorain City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442605109",
    },
    {
        "school": "Palm Elementary School",
        "district": "Lorain City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442605286",
    },
    {
        "school": "Avon Heritage Elementary School",
        "district": "Avon Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481105137",
    },
    {
        "school": "Visintainer Middle School",
        "district": "Brunswick City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436604196",
    },
    {
        "school": "H G Blake Elementary School",
        "district": "Medina City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443804541",
    },
    {
        "school": "Granger Elementary School",
        "district": "Highland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484905299",
    },
    {
        "school": "Constellation Schools: Old Brooklyn Community Elementary",
        "district": "Constellation Schools: Old Brooklyn Community Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390001901514",
    },
    {
        "school": "Green Inspiration Academy",
        "district": "Green Inspiration Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390002501543",
    },
    {
        "school": "Citizens Academy",
        "district": "Citizens Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390003202833",
    },
    {
        "school": "Horizon Science Acad Cleveland",
        "district": "Horizon Science Acad Cleveland",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390004002939",
    },
    {
        "school": "Invictus High School",
        "district": "Invictus High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390005203027",
    },
    {
        "school": "Intergenerational School The",
        "district": "Intergenerational School The",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390006503248",
    },
    {
        "school": "Constellation Schools: Parma Community",
        "district": "Constellation Schools: Parma Community",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390006803315",
    },
    {
        "school": "Constellation Schools: Westpark Community Elementary",
        "district": "Constellation Schools: Westpark Community Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390010504154",
    },
    {
        "school": "Washington Park Community School",
        "district": "Washington Park Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390010704153",
    },
    {
        "school": "West Preparatory Academy",
        "district": "West Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390011903854",
    },
    {
        "school": "Bay High School",
        "district": "Bay Village City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435400115",
    },
    {
        "school": "Bay Middle School",
        "district": "Bay Village City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435400116",
    },
    {
        "school": "Normandy Elementary School",
        "district": "Bay Village City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435400119",
    },
    {
        "school": "Westerly Elementary School",
        "district": "Bay Village City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435400120",
    },
    {
        "school": "Beachwood High School",
        "district": "Beachwood City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435500121",
    },
    {
        "school": "Beachwood Middle School",
        "district": "Beachwood City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435500122",
    },
    {
        "school": "Bryden Elementary School",
        "district": "Beachwood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435500123",
    },
    {
        "school": "Fairmount Early Childhood Center",
        "district": "Beachwood City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435500124",
    },
    {
        "school": "Hilltop Elementary School",
        "district": "Beachwood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435500125",
    },
    {
        "school": "Brook Park Memorial Elementary School",
        "district": "Berea City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436000163",
    },
    {
        "school": "Brookview Elementary School",
        "district": "Berea City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436000164",
    },
    {
        "school": "Berea-Midpark Middle School",
        "district": "Berea City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436000169",
    },
    {
        "school": "Big Creek Elementary School",
        "district": "Berea City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436000174",
    },
    {
        "school": "Berea-Midpark High School",
        "district": "Berea City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436000175",
    },
    {
        "school": "Grindstone Elementary School",
        "district": "Berea City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436004414",
    },
    {
        "school": "Brecksville-Broadview Heights High School",
        "district": "Brecksville-Broadview Heights City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436400194",
    },
    {
        "school": "Brecksville-Broadview Heights Middle School",
        "district": "Brecksville-Broadview Heights City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436400195",
    },
    {
        "school": "Chippewa Elementary School",
        "district": "Brecksville-Broadview Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436400196",
    },
    {
        "school": "Highland Drive Elementary School",
        "district": "Brecksville-Broadview Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436400197",
    },
    {
        "school": "Hilton Elementary School",
        "district": "Brecksville-Broadview Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436400198",
    },
    {
        "school": "Brooklyn High School",
        "district": "Brooklyn City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436500200",
    },
    {
        "school": "Brooklyn Intermediate School",
        "district": "Brooklyn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436500538",
    },
    {
        "school": "Adlai Stevenson School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800413",
    },
    {
        "school": "Almira",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800417",
    },
    {
        "school": "Andrew J Rickoff",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800418",
    },
    {
        "school": "Anton Grdina",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800420",
    },
    {
        "school": "Artemus Ward",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800421",
    },
    {
        "school": "Benjamin Franklin",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800424",
    },
    {
        "school": "Bolton",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800425",
    },
    {
        "school": "Buhrer",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800430",
    },
    {
        "school": "Case",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800433",
    },
    {
        "school": "Alfred Benesch",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800434",
    },
    {
        "school": "Charles A Mooney School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800435",
    },
    {
        "school": "Charles Dickens School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800436",
    },
    {
        "school": "Whitney M Young",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800440",
    },
    {
        "school": "Clara E Westropp School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800442",
    },
    {
        "school": "Clark School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800443",
    },
    {
        "school": "Collinwood High School",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800444",
    },
    {
        "school": "Daniel E Morgan School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800447",
    },
    {
        "school": "Denison",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800448",
    },
    {
        "school": "Dike School of Arts",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800449",
    },
    {
        "school": "Memorial School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800451",
    },
    {
        "school": "East Clark",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800453",
    },
    {
        "school": "East Technical High School",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800456",
    },
    {
        "school": "Albert Bushnell Hart",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800462",
    },
    {
        "school": "George Washington Carver",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800464",
    },
    {
        "school": "Glenville High School",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800468",
    },
    {
        "school": "Halle",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800469",
    },
    {
        "school": "Harvey Rice Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800474",
    },
    {
        "school": "Iowa-Maple Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800479",
    },
    {
        "school": "James Ford Rhodes High School",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800480",
    },
    {
        "school": "Jane Addams Business Careers High School",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800481",
    },
    {
        "school": "Cleveland Early College High",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800485",
    },
    {
        "school": "Kenneth W Clement",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800491",
    },
    {
        "school": "Luis Munoz Marin School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800495",
    },
    {
        "school": "Louis Agassiz School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800499",
    },
    {
        "school": "Franklin D. Roosevelt",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800500",
    },
    {
        "school": "Marion C Seltzer Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800504",
    },
    {
        "school": "Marion-Sterling Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800505",
    },
    {
        "school": "Mary B Martin School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800507",
    },
    {
        "school": "Mary M Bethune",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800508",
    },
    {
        "school": "Max S Hayes High School",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800509",
    },
    {
        "school": "Miles School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800513",
    },
    {
        "school": "Miles Park School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800514",
    },
    {
        "school": "Michael R. White",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800515",
    },
    {
        "school": "Mound Elementary School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800518",
    },
    {
        "school": "Nathan Hale School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800522",
    },
    {
        "school": "Newton D Baker School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800524",
    },
    {
        "school": "Oliver Hazard Perry Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800525",
    },
    {
        "school": "Orchard School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800526",
    },
    {
        "school": "Patrick Henry School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800527",
    },
    {
        "school": "Paul L Dunbar Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800528",
    },
    {
        "school": "Riverside School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800531",
    },
    {
        "school": "Robert H Jamison School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800533",
    },
    {
        "school": "Robinson G Jones Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800534",
    },
    {
        "school": "Scranton School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800536",
    },
    {
        "school": "Sunbeam",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800540",
    },
    {
        "school": "Tremont Montessori School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800542",
    },
    {
        "school": "Valley View Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800544",
    },
    {
        "school": "Wade Park",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800546",
    },
    {
        "school": "Walton School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800547",
    },
    {
        "school": "Waverly Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800550",
    },
    {
        "school": "Joseph M Gallagher School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800551",
    },
    {
        "school": "Whitney M Young School",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800554",
    },
    {
        "school": "Wilbur Wright School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800555",
    },
    {
        "school": "William C Bryant Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800557",
    },
    {
        "school": "Willow School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800561",
    },
    {
        "school": "Hannah Gibbons-Nottingham Elementary School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800729",
    },
    {
        "school": "Louisa May Alcott Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437800730",
    },
    {
        "school": "Garrett Morgan Schl Of Science School",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437804151",
    },
    {
        "school": "Cleveland School Of The Arts High School",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437804208",
    },
    {
        "school": "Gearity Professional Development School",
        "district": "Cleveland Heights-University Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437900565",
    },
    {
        "school": "Boulevard Elementary School",
        "district": "Cleveland Heights-University Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437900566",
    },
    {
        "school": "Canterbury Elementary School",
        "district": "Cleveland Heights-University Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437900567",
    },
    {
        "school": "Fairfax Elementary School",
        "district": "Cleveland Heights-University Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437900569",
    },
    {
        "school": "Cleveland Heights High School",
        "district": "Cleveland Heights-University Heights City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437900571",
    },
    {
        "school": "Monticello Middle School",
        "district": "Cleveland Heights-University Heights City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437900573",
    },
    {
        "school": "Noble Elementary School",
        "district": "Cleveland Heights-University Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437900574",
    },
    {
        "school": "Oxford Elementary School",
        "district": "Cleveland Heights-University Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437900576",
    },
    {
        "school": "Roxboro Elementary School",
        "district": "Cleveland Heights-University Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437900577",
    },
    {
        "school": "Roxboro Middle School",
        "district": "Cleveland Heights-University Heights City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437900578",
    },
    {
        "school": "Caledonia Elementary School",
        "district": "East Cleveland City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439000861",
    },
    {
        "school": "Chambers Elementary School",
        "district": "East Cleveland City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439000862",
    },
    {
        "school": "Mayfair Elementary School",
        "district": "East Cleveland City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439000865",
    },
    {
        "school": "Shaw High School",
        "district": "East Cleveland City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439000866",
    },
    {
        "school": "Superior Elementary School",
        "district": "East Cleveland City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439000867",
    },
    {
        "school": "Heritage Middle School",
        "district": "East Cleveland City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439000868",
    },
    {
        "school": "Euclid High School",
        "district": "Euclid City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439500909",
    },
    {
        "school": "Euclid Central Middle School",
        "district": "Euclid City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439500910",
    },
    {
        "school": "Chardon Hills Elementary School",
        "district": "Euclid City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439500914",
    },
    {
        "school": "Arbor Elementary School",
        "district": "Euclid City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439500915",
    },
    {
        "school": "Shoreview Elementary School",
        "district": "Euclid City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439500920",
    },
    {
        "school": "Fairview High School",
        "district": "Fairview Park City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439700934",
    },
    {
        "school": "Gilles-Sweet Elementary School",
        "district": "Fairview Park City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439700937",
    },
    {
        "school": "Lewis F Mayer Middle School",
        "district": "Fairview Park City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439704214",
    },
    {
        "school": "Parkview Early Education Center",
        "district": "Fairview Park City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439704372",
    },
    {
        "school": "Maple Leaf Elementary School",
        "district": "Garfield Heights City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440400580",
    },
    {
        "school": "Elmwood Elementary School",
        "district": "Garfield Heights City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440400993",
    },
    {
        "school": "Garfield Heights High School",
        "district": "Garfield Heights City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440400994",
    },
    {
        "school": "Garfield Heights Middle School",
        "district": "Garfield Heights City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440400995",
    },
    {
        "school": "William Foster Elementary School",
        "district": "Garfield Heights City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440400999",
    },
    {
        "school": "Grant Elementary School",
        "district": "Lakewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441901118",
    },
    {
        "school": "Lakewood High School",
        "district": "Lakewood City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441901123",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Lakewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441901124",
    },
    {
        "school": "Horace Mann Elementary School",
        "district": "Lakewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441901126",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Lakewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441901127",
    },
    {
        "school": "Emerson Elementary School",
        "district": "Lakewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441901128",
    },
    {
        "school": "Milkovich Middle School",
        "district": "Maple Heights City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443001232",
    },
    {
        "school": "Maple Heights High School",
        "district": "Maple Heights City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443001233",
    },
    {
        "school": "Gates Mills Elementary School",
        "district": "Mayfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443701295",
    },
    {
        "school": "Lander Elementary",
        "district": "Mayfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443701296",
    },
    {
        "school": "Mayfield High School",
        "district": "Mayfield City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443701297",
    },
    {
        "school": "Mayfield Center Elementary School",
        "district": "Mayfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443701298",
    },
    {
        "school": "Millridge Elementary School",
        "district": "Mayfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443701300",
    },
    {
        "school": "Mayfield Preschool",
        "district": "Mayfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443701301",
    },
    {
        "school": "Mayfield Middle School",
        "district": "Mayfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443704451",
    },
    {
        "school": "Forest Elementary School",
        "district": "North Olmsted City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445201430",
    },
    {
        "school": "Maple Intermediate Elementary School",
        "district": "North Olmsted City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445201431",
    },
    {
        "school": "North Olmsted High School",
        "district": "North Olmsted City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445201432",
    },
    {
        "school": "North Olmsted Middle School",
        "district": "North Olmsted City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445201433",
    },
    {
        "school": "Pine  School",
        "district": "North Olmsted City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445201434",
    },
    {
        "school": "Spruce Elementary School",
        "district": "North Olmsted City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445201435",
    },
    {
        "school": "Birch Elementary School",
        "district": "North Olmsted City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445204399",
    },
    {
        "school": "Albion Elementary School",
        "district": "North Royalton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445401442",
    },
    {
        "school": "North Royalton High School",
        "district": "North Royalton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445401443",
    },
    {
        "school": "Royal View Elementary School",
        "district": "North Royalton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445401444",
    },
    {
        "school": "Valley Vista Elementary School",
        "district": "North Royalton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445401445",
    },
    {
        "school": "North Royalton Middle School",
        "district": "North Royalton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445404363",
    },
    {
        "school": "Pleasant Valley Elementary School",
        "district": "Parma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446300136",
    },
    {
        "school": "Dentzler Elementary School",
        "district": "Parma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301495",
    },
    {
        "school": "Green Valley Elementary School",
        "district": "Parma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301499",
    },
    {
        "school": "Greenbriar Middle School",
        "district": "Parma City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301500",
    },
    {
        "school": "Hillside Middle School",
        "district": "Parma City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301502",
    },
    {
        "school": "John Muir Elementary School",
        "district": "Parma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301504",
    },
    {
        "school": "Normandy High School",
        "district": "Parma City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301505",
    },
    {
        "school": "Parma High School",
        "district": "Parma City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301506",
    },
    {
        "school": "Parma Park Elementary School",
        "district": "Parma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301507",
    },
    {
        "school": "Renwood Elementary School",
        "district": "Parma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301511",
    },
    {
        "school": "Ridge-Brook Elementary School",
        "district": "Parma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301512",
    },
    {
        "school": "Thoreau Park Elementary School",
        "district": "Parma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301518",
    },
    {
        "school": "Valley Forge High School",
        "district": "Parma City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446301519",
    },
    {
        "school": "Shiloh Middle School",
        "district": "Parma City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446304458",
    },
    {
        "school": "Goldwood Primary Elementary School",
        "district": "Rocky River City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447001574",
    },
    {
        "school": "Kensington Intermediate Elementary School",
        "district": "Rocky River City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447001575",
    },
    {
        "school": "Rocky River Middle School",
        "district": "Rocky River City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447001576",
    },
    {
        "school": "Rocky River High School",
        "district": "Rocky River City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447001577",
    },
    {
        "school": "Boulevard Elementary School",
        "district": "Shaker Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447501607",
    },
    {
        "school": "Shaker Hts Middle School",
        "district": "Shaker Heights City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447501608",
    },
    {
        "school": "Fernway Elementary School",
        "district": "Shaker Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447501609",
    },
    {
        "school": "Lomond Elementary School",
        "district": "Shaker Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447501610",
    },
    {
        "school": "Mercer Elementary School",
        "district": "Shaker Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447501613",
    },
    {
        "school": "Onaway Elementary School",
        "district": "Shaker Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447501615",
    },
    {
        "school": "Shaker Hts High School",
        "district": "Shaker Heights City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447501616",
    },
    {
        "school": "Woodbury Elementary School",
        "district": "Shaker Heights City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447504323",
    },
    {
        "school": "Adrian Elementary School",
        "district": "South Euclid-Lyndhurst City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447901642",
    },
    {
        "school": "Brush High School",
        "district": "South Euclid-Lyndhurst City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447901645",
    },
    {
        "school": "Memorial Junior High School",
        "district": "South Euclid-Lyndhurst City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447901648",
    },
    {
        "school": "Rowland Elementary School",
        "district": "South Euclid-Lyndhurst City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447901650",
    },
    {
        "school": "Sunview Elementary School",
        "district": "South Euclid-Lyndhurst City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447901652",
    },
    {
        "school": "Greenview Upper Elementary School",
        "district": "South Euclid-Lyndhurst City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447904386",
    },
    {
        "school": "Kinsner Elementary School",
        "district": "Strongsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448401333",
    },
    {
        "school": "Strongsville Middle School",
        "district": "Strongsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448401722",
    },
    {
        "school": "Whitney Elementary School",
        "district": "Strongsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448401724",
    },
    {
        "school": "Surrarrer Elementary School",
        "district": "Strongsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448401725",
    },
    {
        "school": "Muraski Elementary School",
        "district": "Strongsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448401726",
    },
    {
        "school": "Chapman Elementary School",
        "district": "Strongsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448401727",
    },
    {
        "school": "Strongsville High School",
        "district": "Strongsville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448401730",
    },
    {
        "school": "Warrensville Heights High School",
        "district": "Warrensville Heights City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450001930",
    },
    {
        "school": "Warrensville Heights Middle School",
        "district": "Warrensville Heights City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450001931",
    },
    {
        "school": "Westlake Elementary School",
        "district": "Westlake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450601971",
    },
    {
        "school": "Lee Burneson Middle School",
        "district": "Westlake City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450601975",
    },
    {
        "school": "Dover Intermediate School",
        "district": "Westlake City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450601976",
    },
    {
        "school": "Westlake High School",
        "district": "Westlake City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450601977",
    },
    {
        "school": "Chagrin Falls High School",
        "district": "Chagrin Falls Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452802159",
    },
    {
        "school": "Chagrin Falls Middle School",
        "district": "Chagrin Falls Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452802160",
    },
    {
        "school": "Chagrin Falls Intermediate Elementary School",
        "district": "Chagrin Falls Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452802656",
    },
    {
        "school": "Cuyahoga Hts Middle School",
        "district": "Cuyahoga Heights Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465500454",
    },
    {
        "school": "Cuyahoga Hts Elementary School",
        "district": "Cuyahoga Heights Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465502587",
    },
    {
        "school": "Cuyahoga Hts High School",
        "district": "Cuyahoga Heights Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465502588",
    },
    {
        "school": "Independence High School",
        "district": "Independence Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465602589",
    },
    {
        "school": "Independence Middle School",
        "district": "Independence Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465602590",
    },
    {
        "school": "Independence Primary School",
        "district": "Independence Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465602591",
    },
    {
        "school": "Olmsted Falls Intermediate Building",
        "district": "Olmsted Falls City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465702593",
    },
    {
        "school": "Falls-Lenox Primary Elementary School",
        "district": "Olmsted Falls City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465702594",
    },
    {
        "school": "Olmsted Falls High School",
        "district": "Olmsted Falls City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465702595",
    },
    {
        "school": "Olmsted Falls Middle School",
        "district": "Olmsted Falls City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465702596",
    },
    {
        "school": "Richmond Heights Elementary School",
        "district": "Richmond Heights Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465902602",
    },
    {
        "school": "Richmond Heights High School",
        "district": "Richmond Heights Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465902603",
    },
    {
        "school": "Solon Middle School",
        "district": "Solon City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466000173",
    },
    {
        "school": "Parkside Elementary School",
        "district": "Solon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466000177",
    },
    {
        "school": "Solon Preschool",
        "district": "Solon City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466002605",
    },
    {
        "school": "Dorothy E Lewis Elementary School",
        "district": "Solon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466002606",
    },
    {
        "school": "Orchard Middle School",
        "district": "Solon City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466002607",
    },
    {
        "school": "Grace L Roxbury Elementary School",
        "district": "Solon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466002608",
    },
    {
        "school": "Solon High School",
        "district": "Solon City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466002609",
    },
    {
        "school": "Cuyahoga Valley Career Center",
        "district": "Cuyahoga Valley Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390509204058",
    },
    {
        "school": "Polaris Career Center",
        "district": "Polaris",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390509404059",
    },
    {
        "school": "Ballard Brady Middle School",
        "district": "Orange City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001602597",
    },
    {
        "school": "Orange High School",
        "district": "Orange City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001602600",
    },
    {
        "school": "Bedford High School",
        "district": "Bedford City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001700127",
    },
    {
        "school": "Carylwood Intermediate School",
        "district": "Bedford City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001700128",
    },
    {
        "school": "Central Primary School",
        "district": "Bedford City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001700129",
    },
    {
        "school": "Glendale Primary School",
        "district": "Bedford City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001700132",
    },
    {
        "school": "Heskett Middle School",
        "district": "Bedford City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001700133",
    },
    {
        "school": "Columbus Intermediate School",
        "district": "Bedford City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001700323",
    },
    {
        "school": "Gurney Elementary School",
        "district": "Chagrin Falls Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452804340",
    },
    {
        "school": "Berkshire High School",
        "district": "Berkshire Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471602780",
    },
    {
        "school": "Burton Elementary School",
        "district": "Berkshire Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471602781",
    },
    {
        "school": "A J Jordak Elementary School",
        "district": "Cardinal Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471702692",
    },
    {
        "school": "Cardinal Middle School",
        "district": "Cardinal Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471702785",
    },
    {
        "school": "Cardinal High School",
        "district": "Cardinal Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471702786",
    },
    {
        "school": "Chardon High School",
        "district": "Chardon Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471802789",
    },
    {
        "school": "Chardon Middle School",
        "district": "Chardon Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471802790",
    },
    {
        "school": "Munson Elementary School",
        "district": "Chardon Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471802793",
    },
    {
        "school": "Park Elementary School",
        "district": "Chardon Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471802794",
    },
    {
        "school": "Kenston High School",
        "district": "Kenston Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471902796",
    },
    {
        "school": "Kenston Middle School",
        "district": "Kenston Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471902798",
    },
    {
        "school": "Kenston Intermediate School",
        "district": "Kenston Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471902799",
    },
    {
        "school": "Timmons Elementary School",
        "district": "Kenston Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471904313",
    },
    {
        "school": "Newbury Elementary School",
        "district": "Newbury Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472102803",
    },
    {
        "school": "Newbury High School",
        "district": "Newbury Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472102804",
    },
    {
        "school": "Robert C Lindsey Elementary School",
        "district": "West Geauga Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472202806",
    },
    {
        "school": "West Geauga High School",
        "district": "West Geauga Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472202808",
    },
    {
        "school": "West Geauga Middle School",
        "district": "West Geauga Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472202809",
    },
    {
        "school": "Westwood Elementary School",
        "district": "West Geauga Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472202810",
    },
    {
        "school": "Wickliffe Elementary School",
        "district": "Wickliffe City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450801984",
    },
    {
        "school": "Wickliffe High School",
        "district": "Wickliffe City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450801986",
    },
    {
        "school": "Wickliffe Middle School",
        "district": "Wickliffe City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450801987",
    },
    {
        "school": "Eastlake Middle School",
        "district": "Willoughby-Eastlake City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451001996",
    },
    {
        "school": "Edison Elementary School",
        "district": "Willoughby-Eastlake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451001997",
    },
    {
        "school": "Grant Elementary School",
        "district": "Willoughby-Eastlake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451001999",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Willoughby-Eastlake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451002000",
    },
    {
        "school": "Longfellow Elementary School",
        "district": "Willoughby-Eastlake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451002003",
    },
    {
        "school": "North High School",
        "district": "Willoughby-Eastlake City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451002005",
    },
    {
        "school": "Royalview Elementary School",
        "district": "Willoughby-Eastlake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451002007",
    },
    {
        "school": "South High School",
        "district": "Willoughby-Eastlake City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451002009",
    },
    {
        "school": "Willoughby Middle School",
        "district": "Willoughby-Eastlake City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451002012",
    },
    {
        "school": "Northern Career Institute",
        "district": "Willoughby-Eastlake City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390451002013",
    },
    {
        "school": "Willowick Middle School",
        "district": "Willoughby-Eastlake City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451002014",
    },
    {
        "school": "Fairport Harding High School",
        "district": "Fairport Harbor Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453602190",
    },
    {
        "school": "Mckinley Elementary School",
        "district": "Fairport Harbor Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453602191",
    },
    {
        "school": "Bellflower Elementary School",
        "district": "Mentor Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454902235",
    },
    {
        "school": "Ridge Elementary School",
        "district": "Mentor Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454902236",
    },
    {
        "school": "Fairfax Elementary School",
        "district": "Mentor Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454902238",
    },
    {
        "school": "Hopkins Elementary School",
        "district": "Mentor Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454902241",
    },
    {
        "school": "Lake Elementary School",
        "district": "Mentor Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454902242",
    },
    {
        "school": "Memorial Middle School",
        "district": "Mentor Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454902243",
    },
    {
        "school": "Mentor High School",
        "district": "Mentor Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454902244",
    },
    {
        "school": "Shore Middle School",
        "district": "Mentor Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454902245",
    },
    {
        "school": "Orchard Hollow Elementary School",
        "district": "Mentor Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454902246",
    },
    {
        "school": "Sterling Morton Elementary School",
        "district": "Mentor Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454902250",
    },
    {
        "school": "Kirtland Elementary School",
        "district": "Kirtland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478703016",
    },
    {
        "school": "Kirtland High School",
        "district": "Kirtland Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478703017",
    },
    {
        "school": "Kirtland Middle School",
        "district": "Kirtland Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478703018",
    },
    {
        "school": "Madison High School",
        "district": "Madison Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478803020",
    },
    {
        "school": "North Elementary School",
        "district": "Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478803022",
    },
    {
        "school": "South  Elementary School",
        "district": "Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478803023",
    },
    {
        "school": "Madison Middle School",
        "district": "Madison Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478803024",
    },
    {
        "school": "Perry Elementary School",
        "district": "Perry Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479003035",
    },
    {
        "school": "Perry High School",
        "district": "Perry Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479003037",
    },
    {
        "school": "Perry Middle School",
        "district": "Perry Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479003038",
    },
    {
        "school": "Auburn Vocational",
        "district": "Auburn",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390511604071",
    },
    {
        "school": "Henry F Lamuth Middle School",
        "district": "Riverside Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001403025",
    },
    {
        "school": "Buckeye Elementary School",
        "district": "Riverside Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001403026",
    },
    {
        "school": "Riverview Elementary School",
        "district": "Riverside Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001403029",
    },
    {
        "school": "Parkside Elementary School",
        "district": "Riverside Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001403030",
    },
    {
        "school": "Melridge Elementary School",
        "district": "Riverside Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001403032",
    },
    {
        "school": "Riverside Jr/Sr High School",
        "district": "Riverside Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001403033",
    },
    {
        "school": "Chestnut Elementary School",
        "district": "Painesville City Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001501487",
    },
    {
        "school": "Harvey High School",
        "district": "Painesville City Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001501488",
    },
    {
        "school": "Elm Street Elementary School",
        "district": "Painesville City Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001501489",
    },
    {
        "school": "Maple Elementary School",
        "district": "Painesville City Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001501490",
    },
    {
        "school": "Heritage  Middle School",
        "district": "Painesville City Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001501491",
    },
    {
        "school": "Constellation Schools: Lorain Community Elementary",
        "district": "Constellation Schools: Lorain Community Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390010204160",
    },
    {
        "school": "Constellation Schools: Elyria Community",
        "district": "Constellation Schools: Elyria Community",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390010304054",
    },
    {
        "school": "Summit Academy Community School Alternative Learners-Lorain",
        "district": "Summit Academy Community School Alternative Learners-Lorain",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390010904106",
    },
    {
        "school": "Crestwood Elementary School",
        "district": "Elyria City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439400888",
    },
    {
        "school": "Eastern Heights Middle School",
        "district": "Elyria City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439400889",
    },
    {
        "school": "Ely Elementary School",
        "district": "Elyria City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439400892",
    },
    {
        "school": "Elyria High School",
        "district": "Elyria City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439400893",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Elyria City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439400896",
    },
    {
        "school": "Mckinley Elementary School",
        "district": "Elyria City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439400901",
    },
    {
        "school": "Northwood Middle School",
        "district": "Elyria City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439400902",
    },
    {
        "school": "Oakwood Elementary School",
        "district": "Elyria City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439400903",
    },
    {
        "school": "Prospect Elementary School",
        "district": "Elyria City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439400904",
    },
    {
        "school": "Westwood Middle School",
        "district": "Elyria City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439400907",
    },
    {
        "school": "Windsor Elementary School",
        "district": "Elyria City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439400908",
    },
    {
        "school": "Hawthorne Elementary School",
        "district": "Lorain City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442601191",
    },
    {
        "school": "Admiral King Elementary School",
        "district": "Lorain City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442601193",
    },
    {
        "school": "Larkmoor Elementary School",
        "district": "Lorain City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442601194",
    },
    {
        "school": "Stevan Dohanos Elementary School",
        "district": "Lorain City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442601198",
    },
    {
        "school": "Washington Elementary School",
        "district": "Lorain City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442601203",
    },
    {
        "school": "North Ridgeville Early Childhood Learning Community",
        "district": "North Ridgeville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445300312",
    },
    {
        "school": "Liberty Elementary School",
        "district": "North Ridgeville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445301438",
    },
    {
        "school": "North Ridgeville High School",
        "district": "North Ridgeville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445301439",
    },
    {
        "school": "North Ridgeville Academic Center",
        "district": "North Ridgeville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445301440",
    },
    {
        "school": "Eastwood Elementary School",
        "district": "Oberlin City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445901470",
    },
    {
        "school": "Oberlin High School",
        "district": "Oberlin City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445901471",
    },
    {
        "school": "Langston Middle School",
        "district": "Oberlin City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445901472",
    },
    {
        "school": "Prospect Elementary School",
        "district": "Oberlin City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445901473",
    },
    {
        "school": "Brookside High School",
        "district": "Sheffield-Sheffield Lake City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447601619",
    },
    {
        "school": "Knollwood Elementary School",
        "district": "Sheffield-Sheffield Lake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447601621",
    },
    {
        "school": "Brookside Middle School",
        "district": "Sheffield-Sheffield Lake City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447601622",
    },
    {
        "school": "Forestlawn Elementary",
        "district": "Sheffield-Sheffield Lake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447601623",
    },
    {
        "school": "Brookside Intermediate School",
        "district": "Sheffield-Sheffield Lake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447601624",
    },
    {
        "school": "Marion L Steele High School",
        "district": "Amherst Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451902116",
    },
    {
        "school": "Powers Elementary School",
        "district": "Amherst Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451902117",
    },
    {
        "school": "Walter G. Nord Middle School",
        "district": "Amherst Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451902118",
    },
    {
        "school": "Amherst Junior High School",
        "district": "Amherst Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451902119",
    },
    {
        "school": "Mccormick Middle School",
        "district": "Wellington Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456502321",
    },
    {
        "school": "Wellington High School",
        "district": "Wellington Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456502322",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Wellington Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456502323",
    },
    {
        "school": "Avon Middle School",
        "district": "Avon Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481101426",
    },
    {
        "school": "Avon High School",
        "district": "Avon Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481103110",
    },
    {
        "school": "Avon East Elementary School",
        "district": "Avon Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481103111",
    },
    {
        "school": "Avon Early Learning Center",
        "district": "Avon Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481103112",
    },
    {
        "school": "Troy Intermediate Elementary School",
        "district": "Avon Lake City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481200966",
    },
    {
        "school": "Avon Lake High School",
        "district": "Avon Lake City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481203113",
    },
    {
        "school": "Eastview Elementary School",
        "district": "Avon Lake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481203114",
    },
    {
        "school": "Erieview Elementary School",
        "district": "Avon Lake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481203115",
    },
    {
        "school": "Learwood Middle School",
        "district": "Avon Lake City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481203116",
    },
    {
        "school": "Redwood Elementary School",
        "district": "Avon Lake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481203117",
    },
    {
        "school": "Westview Elementary School",
        "district": "Avon Lake City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481203119",
    },
    {
        "school": "Clearview High School",
        "district": "Clearview Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481303120",
    },
    {
        "school": "Durling Middle School",
        "district": "Clearview Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481303121",
    },
    {
        "school": "Vincent Elementary School",
        "district": "Clearview Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481303122",
    },
    {
        "school": "Columbia High School",
        "district": "Columbia Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481403123",
    },
    {
        "school": "Columbia Middle School",
        "district": "Columbia Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481403124",
    },
    {
        "school": "Copopa Elementary School",
        "district": "Columbia Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481403125",
    },
    {
        "school": "Firelands Elementary School",
        "district": "Firelands Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481503128",
    },
    {
        "school": "Firelands High School",
        "district": "Firelands Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481503129",
    },
    {
        "school": "South Amherst Middle School",
        "district": "Firelands Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481503143",
    },
    {
        "school": "Keystone High School",
        "district": "Keystone Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481603132",
    },
    {
        "school": "Keystone Middle School",
        "district": "Keystone Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481603133",
    },
    {
        "school": "Keystone Elementary School",
        "district": "Keystone Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481603134",
    },
    {
        "school": "Midview North Elementary School",
        "district": "Midview Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481703137",
    },
    {
        "school": "Midview West Elementary School",
        "district": "Midview Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481703138",
    },
    {
        "school": "Midview High School",
        "district": "Midview Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481703140",
    },
    {
        "school": "Midview Middle School",
        "district": "Midview Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481703141",
    },
    {
        "school": "William R Burton",
        "district": "Lorain County JVS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390512204074",
    },
    {
        "school": "Applewood Elementary School",
        "district": "Brunswick City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436600203",
    },
    {
        "school": "Brunswick High School",
        "district": "Brunswick City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436600204",
    },
    {
        "school": "Brunswick Memorial Elementary School",
        "district": "Brunswick City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436600205",
    },
    {
        "school": "Edwards Middle School",
        "district": "Brunswick City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436600206",
    },
    {
        "school": "C R Towslee Elementary School",
        "district": "Brunswick City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436600207",
    },
    {
        "school": "Crestview Elementary School",
        "district": "Brunswick City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436600208",
    },
    {
        "school": "Hickory Ridge Elementary School",
        "district": "Brunswick City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436600209",
    },
    {
        "school": "Walter Kidder Elementary School",
        "district": "Brunswick City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436600210",
    },
    {
        "school": "Huntington Elementary School",
        "district": "Brunswick City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436604205",
    },
    {
        "school": "Willetts Middle School",
        "district": "Brunswick City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436604330",
    },
    {
        "school": "A. I. Root Middle School",
        "district": "Medina City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443800365",
    },
    {
        "school": "Ella Canavan Elementary School",
        "district": "Medina City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443801303",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Medina City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443801304",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Medina City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443801305",
    },
    {
        "school": "Medina High School",
        "district": "Medina City SD",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443801306",
    },
    {
        "school": "Claggett Middle School",
        "district": "Medina City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443801307",
    },
    {
        "school": "Sidney Fenn Elementary School",
        "district": "Medina City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443801308",
    },
    {
        "school": "Buckeye High School",
        "district": "Buckeye Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484703262",
    },
    {
        "school": "Buckeye Junior High School",
        "district": "Buckeye Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484703263",
    },
    {
        "school": "Buckeye Intermediate School",
        "district": "Buckeye Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484703265",
    },
    {
        "school": "Buckeye  Primary School",
        "district": "Buckeye Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484703266",
    },
    {
        "school": "Cloverleaf High School",
        "district": "Cloverleaf Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484803268",
    },
    {
        "school": "Cloverleaf Middle School",
        "district": "Cloverleaf Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484803269",
    },
    {
        "school": "Cloverleaf Elementary School",
        "district": "Cloverleaf Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484803272",
    },
    {
        "school": "Highland High School",
        "district": "Highland Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484903274",
    },
    {
        "school": "Highland Middle School",
        "district": "Highland Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484903275",
    },
    {
        "school": "Hinckley Elementary School",
        "district": "Highland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484903276",
    },
    {
        "school": "Sharon Elementary School",
        "district": "Highland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484903277",
    },
    {
        "school": "Medina County Career Center",
        "district": "Medina County Joint Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390621004119",
    },
    {
        "school": "Wadsworth Middle School",
        "district": "Wadsworth City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002901891",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Wadsworth City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002901892",
    },
    {
        "school": "Isham Memorial Elementary School",
        "district": "Wadsworth City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002901893",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Wadsworth City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002901894",
    },
    {
        "school": "Overlook Elementary School",
        "district": "Wadsworth City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002901895",
    },
    {
        "school": "Valley View Elementary School",
        "district": "Wadsworth City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002901896",
    },
    {
        "school": "Wadsworth High School",
        "district": "Wadsworth City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002901897",
    },
    {
        "school": "Central Intermediate School",
        "district": "Wadsworth City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002903600",
    },
    {
        "school": "Luther E Ball (Chjcf)",
        "district": "Buckeye United School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390023704674",
    },
    {
        "school": "John C Dempsey Middle School",
        "district": "Delaware City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438704530",
    },
    {
        "school": "Tyler Run Elementary School",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467604597",
    },
    {
        "school": "Olentangy Liberty Middle School",
        "district": "Olentangy Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467604598",
    },
    {
        "school": "Olentangy Liberty High School",
        "district": "Olentangy Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467604599",
    },
    {
        "school": "Olentangy Orange Middle School",
        "district": "Olentangy Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467604600",
    },
    {
        "school": "Indian Springs Elementary",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467604601",
    },
    {
        "school": "Walnut Creek Elementary",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467604602",
    },
    {
        "school": "Glen Oak Elementary School",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605129",
    },
    {
        "school": "Eli Pinney Elementary School",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470204613",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Pickerington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468904603",
    },
    {
        "school": "Pickerington Lakeview Junior High",
        "district": "Pickerington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468904604",
    },
    {
        "school": "Pickerington High School North",
        "district": "Pickerington Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468904605",
    },
    {
        "school": "Ohio School For The Deaf",
        "district": "Ohio School For The Deaf",
        "level": "High",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390000104681",
    },
    {
        "school": "Ohio School For The Deaf",
        "district": "Ohio School For The Deaf",
        "level": "Elementary",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390000104682",
    },
    {
        "school": "Ohio School For The Deaf",
        "district": "Ohio School For The Deaf",
        "level": "Middle",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390000104683",
    },
    {
        "school": "State School For The Blind",
        "district": "Ohio School For The Blind",
        "level": "High",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390000204684",
    },
    {
        "school": "State School For The Blind",
        "district": "Ohio School For The Blind",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390000204685",
    },
    {
        "school": "Focus Learning Academy of Southwest Columbus",
        "district": "Focus Learning Academy of Southwest Columbus",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390017704701",
    },
    {
        "school": "Focus Learning Academy of Southeastern Columbus",
        "district": "Focus Learning Academy of Southeastern Columbus",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390017804702",
    },
    {
        "school": "Focus Learning Academy of Northern Columbus",
        "district": "Focus Learning Academy of Northern Columbus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390017904703",
    },
    {
        "school": "International Acad Of Columbus",
        "district": "International Acad Of Columbus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390019004714",
    },
    {
        "school": "Great Western Academy",
        "district": "Great Western Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390019204716",
    },
    {
        "school": "Arts & College Preparatory Academy",
        "district": "Arts & College Preparatory Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390022304747",
    },
    {
        "school": "Columbus Humanities Arts and Technology Academy",
        "district": "Columbus Humanities Arts and Technology Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390030404841",
    },
    {
        "school": "A+ Arts Academy",
        "district": "A+ Arts Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390030504842",
    },
    {
        "school": "Columbus Arts & Technology Academy",
        "district": "Columbus Arts & Technology Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390030604843",
    },
    {
        "school": "Columbus Preparatory Academy",
        "district": "Columbus Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390030704844",
    },
    {
        "school": "Summit Academy Middle School - Columbus",
        "district": "Summit Academy Middle School - Columbus",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390033904876",
    },
    {
        "school": "Oakstone Community School",
        "district": "Oakstone Community School",
        "level": "Other",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390038304920",
    },
    {
        "school": "Zenith Academy",
        "district": "Zenith Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390039604956",
    },
    {
        "school": "Summit Academy Community School-Columbus",
        "district": "Summit Academy Community School-Columbus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390049205202",
    },
    {
        "school": "Whitehall Preparatory and Fitness Academy",
        "district": "Whitehall Preparatory and Fitness Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390055005262",
    },
    {
        "school": "Northland Preparatory and Fitness Academy",
        "district": "Northland Preparatory and Fitness Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390055205264",
    },
    {
        "school": "Columbus Preparatory and Fitness Academy",
        "district": "Columbus Preparatory and Fitness Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390057405066",
    },
    {
        "school": "Charles School at Ohio Dominican University",
        "district": "Charles School at Ohio Dominican University",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390058605078",
    },
    {
        "school": "Groveport Community School",
        "district": "Groveport Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390064005351",
    },
    {
        "school": "Noble Academy-Columbus",
        "district": "Noble Academy-Columbus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390064505319",
    },
    {
        "school": "Woodcrest Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004520",
    },
    {
        "school": "Columbus Africentric Early College High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004524",
    },
    {
        "school": "Eastgate Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438005270",
    },
    {
        "school": "Jackson Middle School",
        "district": "South-Western City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448004552",
    },
    {
        "school": "Central Crossing High School",
        "district": "South-Western City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448004553",
    },
    {
        "school": "South-Western Career Academy",
        "district": "South-Western City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390448004554",
    },
    {
        "school": "Hayes Intermediate School",
        "district": "South-Western City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448004555",
    },
    {
        "school": "South-Western Preschool Center",
        "district": "South-Western City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448005114",
    },
    {
        "school": "The Bostic Head Start Center",
        "district": "South-Western City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448005115",
    },
    {
        "school": "Fouse Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450404564",
    },
    {
        "school": "Alcott Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450404565",
    },
    {
        "school": "Westerville Central High School",
        "district": "Westerville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450404566",
    },
    {
        "school": "Winchester Trail Elementary",
        "district": "Canal Winchester Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469404606",
    },
    {
        "school": "Hamilton Intermediate School",
        "district": "Hamilton Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469504607",
    },
    {
        "school": "New Albany Early Learning Center",
        "district": "New Albany-Plain Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469904608",
    },
    {
        "school": "Waggoner Road Middle School",
        "district": "Reynoldsburg City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470005132",
    },
    {
        "school": "Alton Darby Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470104609",
    },
    {
        "school": "Hilliard Tharp Sixth Grade Elementary School",
        "district": "Hilliard City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470104610",
    },
    {
        "school": "Hoffman Trails Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470104611",
    },
    {
        "school": "Hilliard Memorial Middle School",
        "district": "Hilliard City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470104612",
    },
    {
        "school": "Par Excellence Academy",
        "district": "Par Excellence Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390056705059",
    },
    {
        "school": "Granville Intermediate School",
        "district": "Granville Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453904573",
    },
    {
        "school": "Slate Ridge Elementary School",
        "district": "Reynoldsburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470005131",
    },
    {
        "school": "Canaan Middle School",
        "district": "Jonathan Alder Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482605138",
    },
    {
        "school": "Tomorrow Center",
        "district": "Tomorrow Center",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390014504757",
    },
    {
        "school": "Goal Digital Academy",
        "district": "Goal Digital Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390015104763",
    },
    {
        "school": "Ralph C Starkey (Cjcf)",
        "district": "Buckeye United School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390023704676",
    },
    {
        "school": "Westfall Elementary School",
        "district": "Westfall Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491004650",
    },
    {
        "school": "Indian River (Irjcf)",
        "district": "Buckeye United School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390023704675",
    },
    {
        "school": "Creekview Intermediate Elementary School",
        "district": "Marysville Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454704574",
    },
    {
        "school": "Navin Elementary School",
        "district": "Marysville Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454704575",
    },
    {
        "school": "Northwood Elementary",
        "district": "Marysville Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454705124",
    },
    {
        "school": "Dublin Jerome High School",
        "district": "Dublin City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470204614",
    },
    {
        "school": "North Union Elementary School",
        "district": "North Union Local School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503305303",
    },
    {
        "school": "Mt Gilead High School",
        "district": "Mount Gilead Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455302266",
    },
    {
        "school": "Mt Gilead Middle School",
        "district": "Mount Gilead Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455302267",
    },
    {
        "school": "Park Avenue Elementary School",
        "district": "Mount Gilead Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455302268",
    },
    {
        "school": "Cardington-Lincoln Middle School",
        "district": "Cardington-Lincoln Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487901051",
    },
    {
        "school": "Cardington-Lincoln High School",
        "district": "Cardington-Lincoln Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487903405",
    },
    {
        "school": "Cardington-Lincoln Elementary School",
        "district": "Cardington-Lincoln Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487903406",
    },
    {
        "school": "Highland High School",
        "district": "Highland Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488003408",
    },
    {
        "school": "Highland Middle School",
        "district": "Highland Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488003409",
    },
    {
        "school": "Highland  Elementary School",
        "district": "Highland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488004232",
    },
    {
        "school": "Northmor Elementary School",
        "district": "Northmor Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488103412",
    },
    {
        "school": "Northmor High School",
        "district": "Northmor Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488103414",
    },
    {
        "school": "Mill Valley Elementary School",
        "district": "Marysville Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454700784",
    },
    {
        "school": "Edgewood Elementary School",
        "district": "Marysville Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454702229",
    },
    {
        "school": "Marysville High School",
        "district": "Marysville Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454702230",
    },
    {
        "school": "Bunsold Middle School",
        "district": "Marysville Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454702231",
    },
    {
        "school": "Raymond Elementary School",
        "district": "Marysville Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454702232",
    },
    {
        "school": "Fairbanks High School",
        "district": "Fairbanks Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503203909",
    },
    {
        "school": "Fairbanks Elementary School",
        "district": "Fairbanks Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503203910",
    },
    {
        "school": "Fairbanks Middle School",
        "district": "Fairbanks Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503204253",
    },
    {
        "school": "North Union Middle School",
        "district": "North Union Local School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503303917",
    },
    {
        "school": "North Union High School",
        "district": "North Union Local School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503303918",
    },
    {
        "school": "Robert F Schultz Elementary School",
        "district": "Delaware City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438700724",
    },
    {
        "school": "David Smith Elementary School",
        "district": "Delaware City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438700844",
    },
    {
        "school": "Ervin Carlisle Elementary School",
        "district": "Delaware City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438700845",
    },
    {
        "school": "James Conger Elementary School",
        "district": "Delaware City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438700847",
    },
    {
        "school": "Laura Woodward Elementary School",
        "district": "Delaware City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438700848",
    },
    {
        "school": "Rutherford B Hayes High School",
        "district": "Delaware City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438700850",
    },
    {
        "school": "Westerville-North High School",
        "district": "Westerville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401961",
    },
    {
        "school": "Big Walnut High School",
        "district": "Big Walnut Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467402638",
    },
    {
        "school": "Big Walnut Middle School",
        "district": "Big Walnut Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467402639",
    },
    {
        "school": "Big Walnut Elementary School",
        "district": "Big Walnut Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467402640",
    },
    {
        "school": "Hylen Souders Elementary School",
        "district": "Big Walnut Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467402642",
    },
    {
        "school": "Buckeye Valley Local Middle School",
        "district": "Buckeye Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467500827",
    },
    {
        "school": "Buckeye Valley East Elementary School",
        "district": "Buckeye Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467502643",
    },
    {
        "school": "Buckeye Valley Local High School",
        "district": "Buckeye Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467502645",
    },
    {
        "school": "Buckeye Valley West Elementary School",
        "district": "Buckeye Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467502646",
    },
    {
        "school": "Wyandot Run Elementary School",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467600298",
    },
    {
        "school": "Alum Creek Elementary School",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467600646",
    },
    {
        "school": "Scioto Ridge Elementary School",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467601414",
    },
    {
        "school": "Arrowhead Elementary School",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467601421",
    },
    {
        "school": "Olentangy High School",
        "district": "Olentangy Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467602648",
    },
    {
        "school": "Olentangy Shanahan Middle School",
        "district": "Olentangy Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467602650",
    },
    {
        "school": "Oak Creek Elementary School",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467603636",
    },
    {
        "school": "Willard Grizzell Middle School",
        "district": "Dublin City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470200475",
    },
    {
        "school": "Deer Run Elementary School",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470204165",
    },
    {
        "school": "Delaware Area Career Center South Campus",
        "district": "Delaware Area Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390509801492",
    },
    {
        "school": "Gorsuch West Elementary School",
        "district": "Lancaster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442001129",
    },
    {
        "school": "Mt. Pleasant Elementary School",
        "district": "Lancaster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442001130",
    },
    {
        "school": "General Sherman Junior High School",
        "district": "Lancaster City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442001131",
    },
    {
        "school": "Lancaster High School",
        "district": "Lancaster City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442001132",
    },
    {
        "school": "Medill Elementary School",
        "district": "Lancaster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442001133",
    },
    {
        "school": "Early Childhood Center 1",
        "district": "Lancaster City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442001136",
    },
    {
        "school": "Tallmadge Elementary School",
        "district": "Lancaster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442001138",
    },
    {
        "school": "Tarhe Trails Elementary School",
        "district": "Lancaster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442001139",
    },
    {
        "school": "Thomas Ewing Junior High School",
        "district": "Lancaster City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442001140",
    },
    {
        "school": "Amanda-Clearcreek Middle School",
        "district": "Amanda-Clearcreek Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468400919",
    },
    {
        "school": "Amanda-Clearcreek Elementary School",
        "district": "Amanda-Clearcreek Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468402671",
    },
    {
        "school": "Amanda-Clearcreek High School",
        "district": "Amanda-Clearcreek Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468402672",
    },
    {
        "school": "Amanda-Clearcreek Primary School",
        "district": "Amanda-Clearcreek Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468402673",
    },
    {
        "school": "Berne Union Elementary School",
        "district": "Berne Union Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468502674",
    },
    {
        "school": "Berne Union High School",
        "district": "Berne Union Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468502675",
    },
    {
        "school": "Bloom Carroll Intermediate School",
        "district": "Bloom-Carroll Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468602676",
    },
    {
        "school": "Bloom-Carroll Middle School",
        "district": "Bloom-Carroll Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468602677",
    },
    {
        "school": "Bloom-Carroll High School",
        "district": "Bloom-Carroll Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468602678",
    },
    {
        "school": "Bloom Carroll Primary School",
        "district": "Bloom-Carroll Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468602679",
    },
    {
        "school": "Bremen Elementary School",
        "district": "Fairfield Union Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468702681",
    },
    {
        "school": "Fairfield Union High School",
        "district": "Fairfield Union Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468702682",
    },
    {
        "school": "Fairfield Union Rushville Middle School",
        "district": "Fairfield Union Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468702683",
    },
    {
        "school": "Pleasantville Elementary School",
        "district": "Fairfield Union Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468702684",
    },
    {
        "school": "Liberty Union Elementary School",
        "district": "Liberty Union-Thurston Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468802686",
    },
    {
        "school": "Liberty Union High School",
        "district": "Liberty Union-Thurston Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468802687",
    },
    {
        "school": "Liberty Union Middle School",
        "district": "Liberty Union-Thurston Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468802688",
    },
    {
        "school": "Pickerington Ridgeview Junior High School",
        "district": "Pickerington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468900171",
    },
    {
        "school": "Tussing Elementary School",
        "district": "Pickerington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468900659",
    },
    {
        "school": "Pickerington Elementary School",
        "district": "Pickerington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468902689",
    },
    {
        "school": "Pickerington High School Central",
        "district": "Pickerington Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468902690",
    },
    {
        "school": "Violet Elementary School",
        "district": "Pickerington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468902693",
    },
    {
        "school": "Harmon Middle School",
        "district": "Pickerington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468903553",
    },
    {
        "school": "Diley Middle School",
        "district": "Pickerington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468903554",
    },
    {
        "school": "Fairfield Elementary School",
        "district": "Pickerington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468904229",
    },
    {
        "school": "Millersport Elementary School",
        "district": "Walnut Township Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469002694",
    },
    {
        "school": "Millersport Jr/Sr High School",
        "district": "Walnut Township Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469002695",
    },
    {
        "school": "Fairfield Career Center",
        "district": "Eastland-Fairfield Career & Technical Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390510004285",
    },
    {
        "school": "Millennium Community School",
        "district": "Millennium Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390003602838",
    },
    {
        "school": "Horizon Science Academy Columbus",
        "district": "Horizon Science Academy Columbus",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390004202978",
    },
    {
        "school": "Graham School The",
        "district": "Graham School The",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390008003428",
    },
    {
        "school": "Cornerstone Academy Community School",
        "district": "Cornerstone Academy Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390008103441",
    },
    {
        "school": "YB Columbus Community School",
        "district": "YB Columbus Community School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390010404157",
    },
    {
        "school": "Bexley High School",
        "district": "Bexley City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436200180",
    },
    {
        "school": "Bexley Middle School",
        "district": "Bexley City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436200181",
    },
    {
        "school": "Cassingham Elementary School",
        "district": "Bexley City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436200182",
    },
    {
        "school": "Maryland Elementary School",
        "district": "Bexley City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436200183",
    },
    {
        "school": "Montrose Elementary School",
        "district": "Bexley City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436200184",
    },
    {
        "school": "Fort Hayes Career Center",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390438000356",
    },
    {
        "school": "Columbus Spanish Immersion K-6 School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000559",
    },
    {
        "school": "Valleyview Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000575",
    },
    {
        "school": "Alpine Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000582",
    },
    {
        "school": "Avalon Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000584",
    },
    {
        "school": "Avondale Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000585",
    },
    {
        "school": "Beatty Park Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390438000587",
    },
    {
        "school": "Beechcroft High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000590",
    },
    {
        "school": "Berwick Alternative K-8 School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000592",
    },
    {
        "school": "Binns Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000593",
    },
    {
        "school": "Briggs High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000595",
    },
    {
        "school": "Broadleigh Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000596",
    },
    {
        "school": "Buckeye Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000598",
    },
    {
        "school": "Burroughs Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000599",
    },
    {
        "school": "Cassady Alternative Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000601",
    },
    {
        "school": "Cedarwood Alternative Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000602",
    },
    {
        "school": "Centennial High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000603",
    },
    {
        "school": "Champion Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000605",
    },
    {
        "school": "Watkins Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000607",
    },
    {
        "school": "Clinton Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000609",
    },
    {
        "school": "Colerain Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000611",
    },
    {
        "school": "Como Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000612",
    },
    {
        "school": "Cranbrook Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000614",
    },
    {
        "school": "Starling PK-8",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000617",
    },
    {
        "school": "Devonshire Alternative Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000619",
    },
    {
        "school": "Dominion Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000620",
    },
    {
        "school": "Duxberry Park Alternative Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000622",
    },
    {
        "school": "East High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000624",
    },
    {
        "school": "East Columbus Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000625",
    },
    {
        "school": "East Linden Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000626",
    },
    {
        "school": "Easthaven Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000628",
    },
    {
        "school": "Arts Impact Middle School (Aims)",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000632",
    },
    {
        "school": "Fairmoor Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000634",
    },
    {
        "school": "Fairwood Alternative Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000635",
    },
    {
        "school": "Hubbard Mastery School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000636",
    },
    {
        "school": "Georgian Heights Alt Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000643",
    },
    {
        "school": "Hamilton STEM Academy (K-6)",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000647",
    },
    {
        "school": "Highland Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000649",
    },
    {
        "school": "Hilltonia Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000650",
    },
    {
        "school": "Huy/A.G. Bell Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000653",
    },
    {
        "school": "Independence High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000654",
    },
    {
        "school": "Indian Springs Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000655",
    },
    {
        "school": "Indianola Informal K-8 School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000656",
    },
    {
        "school": "Innis Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000658",
    },
    {
        "school": "Johnson Park Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000660",
    },
    {
        "school": "Leawood Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000665",
    },
    {
        "school": "Lincoln Park Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000668",
    },
    {
        "school": "Linden STEM Academy (K-6)",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000670",
    },
    {
        "school": "Linden-Mckinley STEM Academy",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000672",
    },
    {
        "school": "Livingston Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000674",
    },
    {
        "school": "Maize Road Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000676",
    },
    {
        "school": "Marion-Franklin High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000677",
    },
    {
        "school": "Columbus Alternative High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000680",
    },
    {
        "school": "Medina Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000682",
    },
    {
        "school": "Mifflin High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000683",
    },
    {
        "school": "Mifflin Alternative Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000684",
    },
    {
        "school": "Columbus Africentric Early College ES",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000685",
    },
    {
        "school": "Moler Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000686",
    },
    {
        "school": "North Linden Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000689",
    },
    {
        "school": "Northland High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000691",
    },
    {
        "school": "Northtowne Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000693",
    },
    {
        "school": "Oakland Park Alternative Elementary",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000694",
    },
    {
        "school": "Ohio Avenue Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000696",
    },
    {
        "school": "Olde Orchard Alt Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000697",
    },
    {
        "school": "Parkmoor Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000698",
    },
    {
        "school": "Ridgeview Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000703",
    },
    {
        "school": "Salem Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000705",
    },
    {
        "school": "Scottwood Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000707",
    },
    {
        "school": "Shady Lane Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000709",
    },
    {
        "school": "Sherwood Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000711",
    },
    {
        "school": "Siebert Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000712",
    },
    {
        "school": "South High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000714",
    },
    {
        "school": "South Mifflin STEM Academy (K-6)",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000715",
    },
    {
        "school": "Southwood Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000717",
    },
    {
        "school": "Stewart Alternative Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000719",
    },
    {
        "school": "Sullivant Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000721",
    },
    {
        "school": "Trevitt Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000723",
    },
    {
        "school": "Walnut Ridge High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000728",
    },
    {
        "school": "Wedgewood Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000731",
    },
    {
        "school": "Weinland Park Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000732",
    },
    {
        "school": "West High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000733",
    },
    {
        "school": "West Broad Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000734",
    },
    {
        "school": "West Mound Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000735",
    },
    {
        "school": "Westgate Alternative Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000736",
    },
    {
        "school": "Westmoor Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000737",
    },
    {
        "school": "Whetstone High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000738",
    },
    {
        "school": "Windsor STEM Academy (K-6)",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000740",
    },
    {
        "school": "Winterset Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000741",
    },
    {
        "school": "Woodward Park Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000743",
    },
    {
        "school": "Yorktown Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438000744",
    },
    {
        "school": "Eastmoor Academy",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438002560",
    },
    {
        "school": "Fort Hayes Arts and Academic HS",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004236",
    },
    {
        "school": "Columbus Downtown High School",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390438004238",
    },
    {
        "school": "Eakin Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004315",
    },
    {
        "school": "Forest Park Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004316",
    },
    {
        "school": "Ecole Kenwood French Immersion",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004318",
    },
    {
        "school": "Oakmont  Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004319",
    },
    {
        "school": "Gables Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004320",
    },
    {
        "school": "Columbus Scioto 6-12",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390438004430",
    },
    {
        "school": "Lindbergh Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004431",
    },
    {
        "school": "Special Education Center",
        "district": "Columbus City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004432",
    },
    {
        "school": "Valley Forge Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004433",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438004434",
    },
    {
        "school": "Grandview Heights High School",
        "district": "Grandview Heights Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440701011",
    },
    {
        "school": "Larson Middle School",
        "district": "Grandview Heights Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440701012",
    },
    {
        "school": "Stevenson Elementary",
        "district": "Grandview Heights Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440701013",
    },
    {
        "school": "Edison Intermediate",
        "district": "Grandview Heights Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440701014",
    },
    {
        "school": "Buckeye Woods Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448000631",
    },
    {
        "school": "Darby Woods Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448000637",
    },
    {
        "school": "Alton Hall Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001654",
    },
    {
        "school": "Brookpark Middle School",
        "district": "South-Western City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001655",
    },
    {
        "school": "Darbydale Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001656",
    },
    {
        "school": "Finland Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001658",
    },
    {
        "school": "Finland Middle School",
        "district": "South-Western City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001659",
    },
    {
        "school": "Franklin Heights High School",
        "district": "South-Western City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001660",
    },
    {
        "school": "Grove City High School",
        "district": "South-Western City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001662",
    },
    {
        "school": "Highland Park Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001664",
    },
    {
        "school": "Monterey Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001666",
    },
    {
        "school": "Norton Middle School",
        "district": "South-Western City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001668",
    },
    {
        "school": "Pleasant View Middle School",
        "district": "South-Western City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001670",
    },
    {
        "school": "Prairie Lincoln Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001671",
    },
    {
        "school": "Prairie Norton Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001672",
    },
    {
        "school": "Richard Avenue Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001673",
    },
    {
        "school": "JC Sommer Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001674",
    },
    {
        "school": "James A Harmon Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001675",
    },
    {
        "school": "Stiles Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001676",
    },
    {
        "school": "West Franklin Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001678",
    },
    {
        "school": "Westland High School",
        "district": "South-Western City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448001679",
    },
    {
        "school": "Franklin Woods Intermediate School",
        "district": "South-Western City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448003794",
    },
    {
        "school": "Holt Crossing Intermediate School",
        "district": "South-Western City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448003796",
    },
    {
        "school": "Galloway Ridge Intermediate School",
        "district": "South-Western City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448003810",
    },
    {
        "school": "Park Street Intermediate School",
        "district": "South-Western City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448003813",
    },
    {
        "school": "Barrington Road Elementary School",
        "district": "Upper Arlington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449301859",
    },
    {
        "school": "Greensview Elementary School",
        "district": "Upper Arlington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449301862",
    },
    {
        "school": "Hastings Middle School",
        "district": "Upper Arlington City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449301863",
    },
    {
        "school": "Jones Middle School",
        "district": "Upper Arlington City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449301864",
    },
    {
        "school": "Tremont Elementary School",
        "district": "Upper Arlington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449301865",
    },
    {
        "school": "Upper Arlington High School",
        "district": "Upper Arlington City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449301866",
    },
    {
        "school": "Windermere Elementary School",
        "district": "Upper Arlington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449301868",
    },
    {
        "school": "Hanby Building Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450400130",
    },
    {
        "school": "Genoa Middle School",
        "district": "Westerville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401362",
    },
    {
        "school": "Annehurst Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401948",
    },
    {
        "school": "Blendon Middle School",
        "district": "Westerville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401949",
    },
    {
        "school": "Cherrington Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401951",
    },
    {
        "school": "Emerson Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401952",
    },
    {
        "school": "Hawthorne Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401954",
    },
    {
        "school": "Huber Ridge Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401955",
    },
    {
        "school": "Mark Twain Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401957",
    },
    {
        "school": "Pointview Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401958",
    },
    {
        "school": "Robert Frost Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401959",
    },
    {
        "school": "Walnut Springs Middle School",
        "district": "Westerville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401960",
    },
    {
        "school": "Westerville-South High School",
        "district": "Westerville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401962",
    },
    {
        "school": "Whittier Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450401963",
    },
    {
        "school": "McVay Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450404367",
    },
    {
        "school": "Wilder Elementary School",
        "district": "Westerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450404368",
    },
    {
        "school": "Heritage Middle School",
        "district": "Westerville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450404369",
    },
    {
        "school": "Beechwood Elementary School",
        "district": "Whitehall City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450701978",
    },
    {
        "school": "Etna Road Elementary School",
        "district": "Whitehall City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450701979",
    },
    {
        "school": "Kae Avenue Elementary School",
        "district": "Whitehall City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450701980",
    },
    {
        "school": "Rosemore Middle School",
        "district": "Whitehall City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450701982",
    },
    {
        "school": "Whitehall Yearling High School",
        "district": "Whitehall City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450701983",
    },
    {
        "school": "Kilbourne Middle School",
        "district": "Worthington City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451300309",
    },
    {
        "school": "Brookside Elementary School",
        "district": "Worthington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451302034",
    },
    {
        "school": "Colonial Hills Elementary School",
        "district": "Worthington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451302035",
    },
    {
        "school": "Evening Street Elementary School",
        "district": "Worthington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451302036",
    },
    {
        "school": "Wilson Hill Elementary School",
        "district": "Worthington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451302038",
    },
    {
        "school": "Thomas Worthington High School",
        "district": "Worthington City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451302039",
    },
    {
        "school": "Worthington Estates Elementary School",
        "district": "Worthington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451302040",
    },
    {
        "school": "Worthington Hills Elementary School",
        "district": "Worthington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451302041",
    },
    {
        "school": "Worthingway Middle School",
        "district": "Worthington City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451302042",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Worthington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451304156",
    },
    {
        "school": "Sutter Park Elementary School",
        "district": "Worthington City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451304306",
    },
    {
        "school": "Mccord Middle School",
        "district": "Worthington City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451304307",
    },
    {
        "school": "Granby Elementary School",
        "district": "Worthington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451304338",
    },
    {
        "school": "Worthington Park Elementary School",
        "district": "Worthington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451304339",
    },
    {
        "school": "Slate Hill Elementary School",
        "district": "Worthington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451304478",
    },
    {
        "school": "Worthington Kilbourne High School",
        "district": "Worthington City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451304479",
    },
    {
        "school": "Bluffsview Elementary School",
        "district": "Worthington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451304480",
    },
    {
        "school": "Canal Winchester Middle School",
        "district": "Canal Winchester Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469400307",
    },
    {
        "school": "Indian Trail Elementary School",
        "district": "Canal Winchester Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469402680",
    },
    {
        "school": "Canal Winchester High School",
        "district": "Canal Winchester Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469402709",
    },
    {
        "school": "Hamilton Township High School",
        "district": "Hamilton Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469502710",
    },
    {
        "school": "Hamilton Elementary School",
        "district": "Hamilton Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469502711",
    },
    {
        "school": "Hamilton Middle School",
        "district": "Hamilton Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469502712",
    },
    {
        "school": "Gahanna South Middle School",
        "district": "Gahanna-Jefferson City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469600258",
    },
    {
        "school": "Blacklick Elementary School",
        "district": "Gahanna-Jefferson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469600465",
    },
    {
        "school": "Chapelfield Elementary School",
        "district": "Gahanna-Jefferson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469602714",
    },
    {
        "school": "Gahanna East Middle School",
        "district": "Gahanna-Jefferson City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469602715",
    },
    {
        "school": "Gahanna West Middle School",
        "district": "Gahanna-Jefferson City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469602716",
    },
    {
        "school": "Goshen Lane Elementary School",
        "district": "Gahanna-Jefferson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469602717",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Gahanna-Jefferson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469602718",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Gahanna-Jefferson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469602719",
    },
    {
        "school": "Lincoln High School",
        "district": "Gahanna-Jefferson City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469602720",
    },
    {
        "school": "Royal Manor Elementary School",
        "district": "Gahanna-Jefferson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469602721",
    },
    {
        "school": "High Point Elementary School",
        "district": "Gahanna-Jefferson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469604348",
    },
    {
        "school": "Dunloe Elementary School",
        "district": "Groveport Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469702724",
    },
    {
        "school": "Glendening Elementary School",
        "district": "Groveport Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469702725",
    },
    {
        "school": "Groveport Elementary School",
        "district": "Groveport Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469702726",
    },
    {
        "school": "Groveport Madison Middle School South",
        "district": "Groveport Madison Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469702727",
    },
    {
        "school": "Groveport Madison High School",
        "district": "Groveport Madison Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469702728",
    },
    {
        "school": "Groveport Madison Middle School Central",
        "district": "Groveport Madison Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469702729",
    },
    {
        "school": "Madison Elementary School",
        "district": "Groveport Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469702730",
    },
    {
        "school": "Groveport Madison Middle School North",
        "district": "Groveport Madison Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469702731",
    },
    {
        "school": "Sedalia Elementary",
        "district": "Groveport Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469702732",
    },
    {
        "school": "Asbury Elementary School",
        "district": "Groveport Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469704299",
    },
    {
        "school": "New Albany Primary School",
        "district": "New Albany-Plain Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469902733",
    },
    {
        "school": "New Albany High School",
        "district": "New Albany-Plain Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469902734",
    },
    {
        "school": "New Albany Middle School",
        "district": "New Albany-Plain Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469902735",
    },
    {
        "school": "French Run Elementary School",
        "district": "Reynoldsburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470002736",
    },
    {
        "school": "Herbert Mills Elementary School",
        "district": "Reynoldsburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470002738",
    },
    {
        "school": "Baldwin Road Junior High School",
        "district": "Reynoldsburg City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470002740",
    },
    {
        "school": "Hannah J Ashton Middle School",
        "district": "Reynoldsburg City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470002741",
    },
    {
        "school": "Rose Hill Elementary School",
        "district": "Reynoldsburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470002742",
    },
    {
        "school": "Norwich Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470100299",
    },
    {
        "school": "Hilliard Crossing Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470100305",
    },
    {
        "school": "Hilliard Weaver Middle School",
        "district": "Hilliard City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470100473",
    },
    {
        "school": "Hilliard Horizon Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470100662",
    },
    {
        "school": "Hilliard Darby High School",
        "district": "Hilliard City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470100663",
    },
    {
        "school": "Darby Creek Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470101424",
    },
    {
        "school": "Avery Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470102743",
    },
    {
        "school": "Beacon Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470102744",
    },
    {
        "school": "Britton Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470102745",
    },
    {
        "school": "Brown Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470102746",
    },
    {
        "school": "Scioto Darby Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470102747",
    },
    {
        "school": "Hilliard Davidson High School",
        "district": "Hilliard City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470102748",
    },
    {
        "school": "Hilliard Heritage Middle School",
        "district": "Hilliard City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470102749",
    },
    {
        "school": "J W Reason Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470102750",
    },
    {
        "school": "Ridgewood Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470102751",
    },
    {
        "school": "Hilliard Station Sixth Grade Elementary School",
        "district": "Hilliard City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470104495",
    },
    {
        "school": "Dublin Scioto High School",
        "district": "Dublin City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470200666",
    },
    {
        "school": "Mary Emma Bailey Elementary School",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470200667",
    },
    {
        "school": "Henry Karrer Middle School",
        "district": "Dublin City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470202685",
    },
    {
        "school": "Dublin Coffman High School",
        "district": "Dublin City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470202752",
    },
    {
        "school": "John Sells Middle School",
        "district": "Dublin City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470202753",
    },
    {
        "school": "Indian Run Elementary School",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470202754",
    },
    {
        "school": "Olde Sawmill Elementary School",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470204230",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470204271",
    },
    {
        "school": "Scottish Corners Elementary School",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470204326",
    },
    {
        "school": "Ann Simpson Davis Middle School",
        "district": "Dublin City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470204349",
    },
    {
        "school": "Griffith Thomas Elementary School",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470204350",
    },
    {
        "school": "Wyandot Elementary School",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470204351",
    },
    {
        "school": "Albert Chapman Elementary School",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470204364",
    },
    {
        "school": "Daniel Wright Elementary School",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470204365",
    },
    {
        "school": "Eastland Career Center",
        "district": "Eastland-Fairfield Career & Technical Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390510004062",
    },
    {
        "school": "Laurelville Elementary School",
        "district": "Logan Elm Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490803483",
    },
    {
        "school": "Heath Middle School",
        "district": "Heath City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441101055",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Heath City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441101056",
    },
    {
        "school": "Heath High School",
        "district": "Heath City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441101057",
    },
    {
        "school": "Cherry Valley Elementary School",
        "district": "Newark City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444501373",
    },
    {
        "school": "John Clem Elementary School",
        "district": "Newark City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444501374",
    },
    {
        "school": "Ben Franklin Elementary School",
        "district": "Newark City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444501376",
    },
    {
        "school": "McGuffey Elementary School",
        "district": "Newark City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444501384",
    },
    {
        "school": "Newark High School",
        "district": "Newark City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444501385",
    },
    {
        "school": "Wilson Middle School",
        "district": "Newark City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444501389",
    },
    {
        "school": "Granville Elementary School",
        "district": "Granville Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453902197",
    },
    {
        "school": "Granville High School",
        "district": "Granville Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453902198",
    },
    {
        "school": "Granville Middle School",
        "district": "Granville Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453902199",
    },
    {
        "school": "Taylor Road Elementary School",
        "district": "Reynoldsburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470000467",
    },
    {
        "school": "Johnstown High School",
        "district": "Johnstown-Monroe Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479803063",
    },
    {
        "school": "Johnstown Elementary School",
        "district": "Johnstown-Monroe Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479803065",
    },
    {
        "school": "Johnstown Middle School",
        "district": "Johnstown-Monroe Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479803066",
    },
    {
        "school": "Hebron Elementary School",
        "district": "Lakewood Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479903068",
    },
    {
        "school": "Lakewood High School",
        "district": "Lakewood Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479903070",
    },
    {
        "school": "Lakewood Middle School",
        "district": "Lakewood Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479903071",
    },
    {
        "school": "Jackson Intermediate",
        "district": "Lakewood Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479903072",
    },
    {
        "school": "West Elementary School",
        "district": "Licking Heights Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480003073",
    },
    {
        "school": "Licking Heights High School",
        "district": "Licking Heights Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480003074",
    },
    {
        "school": "Central Middle School",
        "district": "Licking Heights Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480003075",
    },
    {
        "school": "South Elementary",
        "district": "Licking Heights Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480003076",
    },
    {
        "school": "Licking Valley Middle School",
        "district": "Licking Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480103077",
    },
    {
        "school": "Licking Valley High School",
        "district": "Licking Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480103078",
    },
    {
        "school": "Licking Valley Elementary School",
        "district": "Licking Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480103079",
    },
    {
        "school": "Newton Elementary School",
        "district": "North Fork Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480203085",
    },
    {
        "school": "Utica Elementary School",
        "district": "North Fork Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480203086",
    },
    {
        "school": "Utica High School",
        "district": "North Fork Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480203087",
    },
    {
        "school": "Utica Middle School",
        "district": "North Fork Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480203088",
    },
    {
        "school": "Northridge High School",
        "district": "Northridge Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480303093",
    },
    {
        "school": "Northridge Middle School",
        "district": "Northridge Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480304504",
    },
    {
        "school": "Etna Elementary School",
        "district": "Southwest Licking Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480403094",
    },
    {
        "school": "Kirkersville Elementary School",
        "district": "Southwest Licking Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480403095",
    },
    {
        "school": "Pataskala Elementary School",
        "district": "Southwest Licking Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480403096",
    },
    {
        "school": "Watkins Memorial High School",
        "district": "Southwest Licking Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480403097",
    },
    {
        "school": "Watkins Middle School",
        "district": "Southwest Licking Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480403098",
    },
    {
        "school": "Career and Technology Educational Centers",
        "district": "Career and Technology Educational Centers",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390512004073",
    },
    {
        "school": "London High School",
        "district": "London City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442501182",
    },
    {
        "school": "London MIddle School",
        "district": "London City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442501183",
    },
    {
        "school": "London Elementary School",
        "district": "London City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442504216",
    },
    {
        "school": "West Jefferson  Middle School",
        "district": "Jefferson Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482503173",
    },
    {
        "school": "Norwood Elementary School",
        "district": "Jefferson Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482503174",
    },
    {
        "school": "West Jefferson High School",
        "district": "Jefferson Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482503176",
    },
    {
        "school": "Jonathan Alder Junior High",
        "district": "Jonathan Alder Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482603177",
    },
    {
        "school": "Jonathan Alder High School",
        "district": "Jonathan Alder Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482603178",
    },
    {
        "school": "Monroe Elementary School",
        "district": "Jonathan Alder Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482603179",
    },
    {
        "school": "Plain City Elementary School",
        "district": "Jonathan Alder Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482603180",
    },
    {
        "school": "Madison-Plains High School",
        "district": "Madison-Plains Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482703183",
    },
    {
        "school": "Madison-Plains Junior High",
        "district": "Madison-Plains Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482703186",
    },
    {
        "school": "Tolles Career & Technical Center",
        "district": "Tolles Career & Technical Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390635104124",
    },
    {
        "school": "Circleville High School",
        "district": "Circleville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437600398",
    },
    {
        "school": "Circleville Middle School",
        "district": "Circleville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437600399",
    },
    {
        "school": "Circleville Elementary School",
        "district": "Circleville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437600403",
    },
    {
        "school": "George Mcdowell-Exchange Middle School",
        "district": "Logan Elm Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490803482",
    },
    {
        "school": "Logan Elm High School",
        "district": "Logan Elm Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490803484",
    },
    {
        "school": "Pickaway Elementary School",
        "district": "Logan Elm Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490803485",
    },
    {
        "school": "Salt Creek Intermediate School",
        "district": "Logan Elm Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490803486",
    },
    {
        "school": "Washington Elementary School",
        "district": "Logan Elm Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490803487",
    },
    {
        "school": "Ashville Elementary School",
        "district": "Teays Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490903488",
    },
    {
        "school": "Scioto Elementary School",
        "district": "Teays Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490903489",
    },
    {
        "school": "Teays Valley High School",
        "district": "Teays Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490903490",
    },
    {
        "school": "Teays Valley East Middle School",
        "district": "Teays Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490903491",
    },
    {
        "school": "Walnut Elementary School",
        "district": "Teays Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490903492",
    },
    {
        "school": "Westfall High School",
        "district": "Westfall Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491003496",
    },
    {
        "school": "Westfall Middle School",
        "district": "Westfall Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491003497",
    },
    {
        "school": "Coshocton Opportunity School",
        "district": "Coshocton Opportunity School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390033104868",
    },
    {
        "school": "Coshocton High School",
        "district": "Coshocton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438200754",
    },
    {
        "school": "Coshocton Elementary",
        "district": "Coshocton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438204152",
    },
    {
        "school": "Ridgewood High School",
        "district": "Ridgewood Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464702565",
    },
    {
        "school": "Ridgewood Middle School",
        "district": "Ridgewood Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464703515",
    },
    {
        "school": "Conesville Elementary School",
        "district": "River View Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464802567",
    },
    {
        "school": "Keene Elementary School",
        "district": "River View Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464802568",
    },
    {
        "school": "River View High School",
        "district": "River View Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464802570",
    },
    {
        "school": "Warsaw Elementary School",
        "district": "River View Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464802573",
    },
    {
        "school": "River View Middle School",
        "district": "River View Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464804164",
    },
    {
        "school": "Coshocton County Career Center",
        "district": "Coshocton County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390652204126",
    },
    {
        "school": "Fairborn Digital Academy",
        "district": "Fairborn Digital Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390015504767",
    },
    {
        "school": "Greeneview Elementary School",
        "district": "Greeneview Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472604616",
    },
    {
        "school": "Forest Elementary School",
        "district": "Troy City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449204561",
    },
    {
        "school": "Pathway School of Discovery",
        "district": "Pathway School of Discovery",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390012904179",
    },
    {
        "school": "Mound Street Academies",
        "district": "Mound Street Academies",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390018504709",
    },
    {
        "school": "Trotwood Preparatory & Fitness Academy",
        "district": "Trotwood Preparatory & Fitness Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390019304717",
    },
    {
        "school": "North Dayton School Of Science & Discovery",
        "district": "North Dayton School Of Science & Discovery",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390021604740",
    },
    {
        "school": "Miami Valley Academies",
        "district": "Miami Valley Academies",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390024104688",
    },
    {
        "school": "Emerson Academy",
        "district": "Emerson Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390031504852",
    },
    {
        "school": "Horizon Science Academy-Dayton",
        "district": "Horizon Science Academy-Dayton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390044405003",
    },
    {
        "school": "Gem City Career Prep High School",
        "district": "Gem City Career Prep High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390044805007",
    },
    {
        "school": "Summit Academy Community School - Dayton",
        "district": "Summit Academy Community School - Dayton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390049305203",
    },
    {
        "school": "Charity Adams Earley Girls Academy",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438405101",
    },
    {
        "school": "Miami Valley Ctc Alternative",
        "district": "Miami Valley Career Tech",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390512804668",
    },
    {
        "school": "William Bruce Elementary School",
        "district": "Eaton Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439300882",
    },
    {
        "school": "Eaton Middle School",
        "district": "Eaton Community City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439300883",
    },
    {
        "school": "Eaton High School",
        "district": "Eaton Community City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439300884",
    },
    {
        "school": "Hollingsworth East Elementary School",
        "district": "Eaton Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439300885",
    },
    {
        "school": "Twin Valley South Middle School",
        "district": "Twin Valley Community Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490003172",
    },
    {
        "school": "Twin Valley South Elementary School",
        "district": "Twin Valley Community Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490003212",
    },
    {
        "school": "Twin Valley South High School",
        "district": "Twin Valley Community Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490003555",
    },
    {
        "school": "Tri-County North Elementary School",
        "district": "Tri-County North Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492604249",
    },
    {
        "school": "Tri-County North High School",
        "district": "Tri-County North Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492604250",
    },
    {
        "school": "Tri-County North Middle School",
        "district": "Tri-County North Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492604251",
    },
    {
        "school": "National Trail Elementary School",
        "district": "National Trail Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492703545",
    },
    {
        "school": "National Trail Middle School",
        "district": "National Trail Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492703546",
    },
    {
        "school": "National Trail High School",
        "district": "National Trail Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492703547",
    },
    {
        "school": "Camden Primary School",
        "district": "Preble Shawnee Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492803549",
    },
    {
        "school": "Preble Shawnee High School/Junior High School",
        "district": "Preble Shawnee Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492803550",
    },
    {
        "school": "West Elkton Intermediate School",
        "district": "Preble Shawnee Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390492803551",
    },
    {
        "school": "College Corner Union Elementary School",
        "district": "College Corner Local",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390649604125",
    },
    {
        "school": "Summit Academy Community School Alternative Learners -Xenia",
        "district": "Summit Academy Community School Alternative Learners -Xenia",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390009704036",
    },
    {
        "school": "Baker Middle School",
        "district": "Fairborn City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439600924",
    },
    {
        "school": "Fairborn High School",
        "district": "Fairborn City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439600927",
    },
    {
        "school": "Fairborn Primary School",
        "district": "Fairborn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439600928",
    },
    {
        "school": "Fairborn Intermediate School",
        "district": "Fairborn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439600930",
    },
    {
        "school": "Xenia Preschool",
        "district": "Xenia Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451502050",
    },
    {
        "school": "Cox Elementary School",
        "district": "Xenia Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451502051",
    },
    {
        "school": "McKinley Elementary School",
        "district": "Xenia Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451502052",
    },
    {
        "school": "Shawnee Elementary School",
        "district": "Xenia Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451502053",
    },
    {
        "school": "Arrowood Elementary",
        "district": "Xenia Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451502054",
    },
    {
        "school": "Tecumseh Elementary School",
        "district": "Xenia Community City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451502057",
    },
    {
        "school": "Warner Middle School",
        "district": "Xenia Community City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451502058",
    },
    {
        "school": "Xenia High School",
        "district": "Xenia Community City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451502059",
    },
    {
        "school": "Beavercreek High School",
        "district": "Beavercreek City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472402811",
    },
    {
        "school": "Fairbrook Elementary School",
        "district": "Beavercreek City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472402812",
    },
    {
        "school": "Jacob Coy Middle School",
        "district": "Beavercreek City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472402813",
    },
    {
        "school": "Herman K Ankeney Middle School",
        "district": "Beavercreek City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472402814",
    },
    {
        "school": "Main Elementary School",
        "district": "Beavercreek City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472402815",
    },
    {
        "school": "Parkwood Elementary School",
        "district": "Beavercreek City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472402816",
    },
    {
        "school": "Shaw Elementary School",
        "district": "Beavercreek City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472402817",
    },
    {
        "school": "Valley Elementary School",
        "district": "Beavercreek City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472402818",
    },
    {
        "school": "Cedarville Elementary School",
        "district": "Cedar Cliff Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472502820",
    },
    {
        "school": "Cedarville High School",
        "district": "Cedar Cliff Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472502821",
    },
    {
        "school": "Greeneview High School",
        "district": "Greeneview Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472602822",
    },
    {
        "school": "Greeneview Middle School",
        "district": "Greeneview Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472602823",
    },
    {
        "school": "Bell Creek Intermediate School",
        "district": "Bellbrook-Sugarcreek Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472700688",
    },
    {
        "school": "Bellbrook Middle School",
        "district": "Bellbrook-Sugarcreek Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472702826",
    },
    {
        "school": "Bellbrook High School",
        "district": "Bellbrook-Sugarcreek Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472702827",
    },
    {
        "school": "Stephen Bell Elementary School",
        "district": "Bellbrook-Sugarcreek Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472702828",
    },
    {
        "school": "Greene County Career Center",
        "district": "Greene County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390510404064",
    },
    {
        "school": "Washington Primary Elementary School",
        "district": "Piqua City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446401523",
    },
    {
        "school": "Piqua High School",
        "district": "Piqua City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446401526",
    },
    {
        "school": "Springcreek Primary Elementary School",
        "district": "Piqua City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446401528",
    },
    {
        "school": "Piqua Central Intermediate School",
        "district": "Piqua City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446401531",
    },
    {
        "school": "Piqua Junior High School",
        "district": "Piqua City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446402644",
    },
    {
        "school": "Concord Elementary School",
        "district": "Troy City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449201850",
    },
    {
        "school": "Cookson Elementary School",
        "district": "Troy City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449201851",
    },
    {
        "school": "Heywood Elementary School",
        "district": "Troy City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449201853",
    },
    {
        "school": "Hook Elementary School",
        "district": "Troy City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449201854",
    },
    {
        "school": "Kyle Elementary School",
        "district": "Troy City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449201855",
    },
    {
        "school": "Troy High School",
        "district": "Troy City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449201856",
    },
    {
        "school": "Troy Junior High School",
        "district": "Troy City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449201857",
    },
    {
        "school": "Van Cleve Elementary School",
        "district": "Troy City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449201858",
    },
    {
        "school": "Bradford High School",
        "district": "Bradford Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452202126",
    },
    {
        "school": "Bradford Elementary School",
        "district": "Bradford Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452202127",
    },
    {
        "school": "Covington Elementary School",
        "district": "Covington Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453302178",
    },
    {
        "school": "Covington High School",
        "district": "Covington Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453302179",
    },
    {
        "school": "Covington Junior High School",
        "district": "Covington Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453302180",
    },
    {
        "school": "Milton-Union Middle School",
        "district": "Milton-Union Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455102258",
    },
    {
        "school": "Milton-Union High School",
        "district": "Milton-Union Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455102259",
    },
    {
        "school": "Milton-Union Elementary School",
        "district": "Milton-Union Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455102260",
    },
    {
        "school": "Broadway Elementary School",
        "district": "Tipp City Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456102300",
    },
    {
        "school": "Tippecanoe Middle School",
        "district": "Tipp City Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456102301",
    },
    {
        "school": "Nevin Coppock Elementary School",
        "district": "Tipp City Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456102302",
    },
    {
        "school": "Tippecanoe High School",
        "district": "Tipp City Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456102303",
    },
    {
        "school": "L. T. Ball Intermediate School",
        "district": "Tipp City Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456102304",
    },
    {
        "school": "Bethel Elementary School",
        "district": "Bethel Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486103313",
    },
    {
        "school": "Bethel High School",
        "district": "Bethel Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486103314",
    },
    {
        "school": "Bethel Middle School",
        "district": "Bethel Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486104327",
    },
    {
        "school": "Miami East Elementary",
        "district": "Miami East Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486203317",
    },
    {
        "school": "Miami East Junior High School",
        "district": "Miami East Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486203319",
    },
    {
        "school": "Miami East High School",
        "district": "Miami East Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486203320",
    },
    {
        "school": "Newton Elementary School",
        "district": "Newton Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486303322",
    },
    {
        "school": "Newton High School",
        "district": "Newton Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486303323",
    },
    {
        "school": "Upper Valley Career Center",
        "district": "Upper Valley Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390621204120",
    },
    {
        "school": "City Day Community School",
        "district": "City Day Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390002901578",
    },
    {
        "school": "Richard Allen Academy",
        "district": "Richard Allen Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390004702997",
    },
    {
        "school": "Richard Allen Preparatory",
        "district": "Richard Allen Preparatory",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390007303361",
    },
    {
        "school": "Dayton Leadership Academies-Dayton View Campus",
        "district": "Dayton Leadership Academies-Dayton View Campus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390008303762",
    },
    {
        "school": "Centerville High School",
        "district": "Centerville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437300267",
    },
    {
        "school": "Dr John Hole Elementary School",
        "district": "Centerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437300268",
    },
    {
        "school": "Driscoll Elementary School",
        "district": "Centerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437300269",
    },
    {
        "school": "Hadley E Watts Middle School",
        "district": "Centerville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437300270",
    },
    {
        "school": "Magsig Middle School",
        "district": "Centerville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437300272",
    },
    {
        "school": "Normandy Elementary School",
        "district": "Centerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437300273",
    },
    {
        "school": "Stingley Elementary School",
        "district": "Centerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437300274",
    },
    {
        "school": "Tower Heights Middle School",
        "district": "Centerville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437300275",
    },
    {
        "school": "W O Cline Elementary School",
        "district": "Centerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437300277",
    },
    {
        "school": "Weller Elementary School",
        "district": "Centerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437300278",
    },
    {
        "school": "Centerville Primary Village North",
        "district": "Centerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437304422",
    },
    {
        "school": "Belle Haven Elementary School",
        "district": "Dayton City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400776",
    },
    {
        "school": "Belmont High School",
        "district": "Dayton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400778",
    },
    {
        "school": "Louise Troy Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400780",
    },
    {
        "school": "Thurgood Marshall High School",
        "district": "Dayton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400782",
    },
    {
        "school": "Dunbar Early College High School",
        "district": "Dayton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400785",
    },
    {
        "school": "Eastmont Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400786",
    },
    {
        "school": "Edison Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400787",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400789",
    },
    {
        "school": "River's Edge Montessori Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400791",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400800",
    },
    {
        "school": "Valerie Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400812",
    },
    {
        "school": "Meadowdale High School",
        "district": "Dayton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400813",
    },
    {
        "school": "Wright Brothers Middle School",
        "district": "Dayton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400815",
    },
    {
        "school": "David H. Ponitz Career Technology  Center",
        "district": "Dayton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400823",
    },
    {
        "school": "Stivers School For The Arts",
        "district": "Dayton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400824",
    },
    {
        "school": "Edwin Joel Brown Middle School",
        "district": "Dayton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400826",
    },
    {
        "school": "Kiser Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400828",
    },
    {
        "school": "Wogaman Middle School",
        "district": "Dayton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438400832",
    },
    {
        "school": "Dayton Digital Academy",
        "district": "Dayton City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438404294",
    },
    {
        "school": "Horace Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438404297",
    },
    {
        "school": "Kemp Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438404300",
    },
    {
        "school": "Beavertown Elementary School",
        "district": "Kettering City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441801097",
    },
    {
        "school": "Greenmont Elementary School",
        "district": "Kettering City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441801100",
    },
    {
        "school": "Indian Riffle Elementary School",
        "district": "Kettering City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441801101",
    },
    {
        "school": "J F Kennedy Elementary School",
        "district": "Kettering City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441801102",
    },
    {
        "school": "Kettering Middle School",
        "district": "Kettering City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441801103",
    },
    {
        "school": "Kettering Fairmont High School",
        "district": "Kettering City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441801104",
    },
    {
        "school": "Oakview Elementary School",
        "district": "Kettering City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441801107",
    },
    {
        "school": "Orchard Park Elementary School",
        "district": "Kettering City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441801108",
    },
    {
        "school": "Prass Elementary School",
        "district": "Kettering City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441801109",
    },
    {
        "school": "Southdale Elementary School",
        "district": "Kettering City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441801113",
    },
    {
        "school": "Van Buren Middle School",
        "district": "Kettering City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441801114",
    },
    {
        "school": "Bauer Elementary School",
        "district": "Miamisburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443901309",
    },
    {
        "school": "Bear Elementary School",
        "district": "Miamisburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443901310",
    },
    {
        "school": "Kinder Elementary School",
        "district": "Miamisburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443901311",
    },
    {
        "school": "Mark Twain Elementary School",
        "district": "Miamisburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443901312",
    },
    {
        "school": "Miamisburg High School",
        "district": "Miamisburg City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443901313",
    },
    {
        "school": "Mound Elementary School",
        "district": "Miamisburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443901315",
    },
    {
        "school": "Miamisburg Middle School",
        "district": "Miamisburg City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443901316",
    },
    {
        "school": "Medlar View Elementary School",
        "district": "Miamisburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443902622",
    },
    {
        "school": "Harman Elementary School",
        "district": "Oakwood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445801466",
    },
    {
        "school": "Oakwood High School",
        "district": "Oakwood City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445801467",
    },
    {
        "school": "Smith Elementary School",
        "district": "Oakwood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445801469",
    },
    {
        "school": "Julian & Marjorie Lange School Elementary School",
        "district": "Oakwood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445803541",
    },
    {
        "school": "Oakwood Junior High School",
        "district": "Oakwood City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445804264",
    },
    {
        "school": "Butler High School",
        "district": "Vandalia-Butler City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449501875",
    },
    {
        "school": "Demmitt Elementary School",
        "district": "Vandalia-Butler City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449501876",
    },
    {
        "school": "Helke Elementary School",
        "district": "Vandalia-Butler City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449501877",
    },
    {
        "school": "Morton Middle School",
        "district": "Vandalia-Butler City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449501879",
    },
    {
        "school": "C F Holliday Elementary School",
        "district": "West Carrollton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450501964",
    },
    {
        "school": "Harry Russell Elementary School",
        "district": "West Carrollton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450501966",
    },
    {
        "school": "Harold Schnell Elementary School",
        "district": "West Carrollton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450501967",
    },
    {
        "school": "Shade Elementary School",
        "district": "West Carrollton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450501968",
    },
    {
        "school": "West Carrollton High School",
        "district": "West Carrollton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450501969",
    },
    {
        "school": "West Carrollton Middle School",
        "district": "West Carrollton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450501970",
    },
    {
        "school": "Brookville High School",
        "district": "Brookville Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486703341",
    },
    {
        "school": "Brookville Intermediate School",
        "district": "Brookville Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486703342",
    },
    {
        "school": "Brookville Elementary School",
        "district": "Brookville Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486703343",
    },
    {
        "school": "Blairwood Elementary School",
        "district": "Jefferson Township Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486803344",
    },
    {
        "school": "Jefferson High School",
        "district": "Jefferson Township Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486803345",
    },
    {
        "school": "Trotwood-Madison High School",
        "district": "Trotwood-Madison City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486903353",
    },
    {
        "school": "Beverly Gardens Elementary School",
        "district": "Mad River Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487003356",
    },
    {
        "school": "Brantwood Elementary School",
        "district": "Mad River Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487003357",
    },
    {
        "school": "Virginia Stevenson Elementary School",
        "district": "Mad River Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487003358",
    },
    {
        "school": "Spinning Hills Middle School (5-6)",
        "district": "Mad River Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487003359",
    },
    {
        "school": "Saville Elementary School",
        "district": "Mad River Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487003362",
    },
    {
        "school": "Mad River Middle School",
        "district": "Mad River Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487003363",
    },
    {
        "school": "Stebbins High School",
        "district": "Mad River Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487003364",
    },
    {
        "school": "Dixie High School",
        "district": "New Lebanon Local School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487103365",
    },
    {
        "school": "Dixie Elementary School",
        "district": "New Lebanon Local School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487103366",
    },
    {
        "school": "Dixie Middle School",
        "district": "New Lebanon Local School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487103367",
    },
    {
        "school": "Englewood Elementary School",
        "district": "Northmont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487203370",
    },
    {
        "school": "Englewood Hills Elementary School",
        "district": "Northmont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487203371",
    },
    {
        "school": "Northmont High School",
        "district": "Northmont City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487203372",
    },
    {
        "school": "Northmont Middle School",
        "district": "Northmont City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487203373",
    },
    {
        "school": "Northmoor Elementary School",
        "district": "Northmont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487203374",
    },
    {
        "school": "Northwood Elementary School",
        "district": "Northmont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487203375",
    },
    {
        "school": "Union Elementary School",
        "district": "Northmont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487203377",
    },
    {
        "school": "NORTHRIDGE MIDDLE SCHOOL",
        "district": "Northridge Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487303378",
    },
    {
        "school": "Northridge Elementary School",
        "district": "Northridge Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487303379",
    },
    {
        "school": "Northridge High School",
        "district": "Northridge Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487303380",
    },
    {
        "school": "Valley View Intermediate School",
        "district": "Valley View Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487403383",
    },
    {
        "school": "Valley View Primary School",
        "district": "Valley View Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487403384",
    },
    {
        "school": "Valley View Junior High School",
        "district": "Valley View Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487403385",
    },
    {
        "school": "Valley View High School",
        "district": "Valley View Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487403386",
    },
    {
        "school": "Wright Brothers Elementary School",
        "district": "Huber Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487503388",
    },
    {
        "school": "Monticello Elementary School",
        "district": "Huber Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487503389",
    },
    {
        "school": "Rushmore Elementary School",
        "district": "Huber Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487503390",
    },
    {
        "school": "Charles Huber Elementary School",
        "district": "Huber Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487503393",
    },
    {
        "school": "Valley Forge Elementary School",
        "district": "Huber Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487503394",
    },
    {
        "school": "Wayne High School",
        "district": "Huber Heights City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487503395",
    },
    {
        "school": "Weisenborn Junior High",
        "district": "Huber Heights City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487503396",
    },
    {
        "school": "Miami Valley Ctc",
        "district": "Miami Valley Career Tech",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390512804076",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Central Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467104594",
    },
    {
        "school": "Tinora Elementary School",
        "district": "Northeastern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467204595",
    },
    {
        "school": "Defiance Middle School",
        "district": "Defiance City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438600840",
    },
    {
        "school": "Defiance High School",
        "district": "Defiance City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438600841",
    },
    {
        "school": "Hicksville Elementary School",
        "district": "Hicksville Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454102206",
    },
    {
        "school": "Hicksville High School",
        "district": "Hicksville Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454102207",
    },
    {
        "school": "Ayersville Elementary School",
        "district": "Ayersville Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467002625",
    },
    {
        "school": "Ayersville High School",
        "district": "Ayersville Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467002626",
    },
    {
        "school": "Fairview High School",
        "district": "Central Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467102628",
    },
    {
        "school": "Fairview Middle School",
        "district": "Central Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467102629",
    },
    {
        "school": "Noble Elementary School",
        "district": "Northeastern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467202633",
    },
    {
        "school": "Tinora High School",
        "district": "Northeastern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467202636",
    },
    {
        "school": "Tinora Junior High School",
        "district": "Northeastern Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467202637",
    },
    {
        "school": "Buckeye On-Line School for Success",
        "district": "Buckeye On-Line School for Success",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390053005240",
    },
    {
        "school": "East Liverpool High School",
        "district": "East Liverpool City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439100870",
    },
    {
        "school": "East Liverpool Junior High",
        "district": "East Liverpool City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439100872",
    },
    {
        "school": "Lacroft Elementary School",
        "district": "East Liverpool City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439100873",
    },
    {
        "school": "North Elementary School",
        "district": "East Liverpool City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439100874",
    },
    {
        "school": "Westgate Middle School",
        "district": "East Liverpool City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439100875",
    },
    {
        "school": "East Palestine Elementary School",
        "district": "East Palestine City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439200876",
    },
    {
        "school": "East Palestine High School",
        "district": "East Palestine City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439200878",
    },
    {
        "school": "East Palestine Middle School",
        "district": "East Palestine City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439200879",
    },
    {
        "school": "Daw Elementary School",
        "district": "Wellsville Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450301943",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Wellsville Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450301945",
    },
    {
        "school": "Wellsville Jr. Sr. High",
        "district": "Wellsville Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450301947",
    },
    {
        "school": "Columbiana High School",
        "district": "Columbiana Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453202175",
    },
    {
        "school": "Joshua Dixon Elementary School",
        "district": "Columbiana Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453202176",
    },
    {
        "school": "South Side Middle School",
        "district": "Columbiana Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453202177",
    },
    {
        "school": "David Anderson Jr/Sr High School",
        "district": "Lisbon Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454502221",
    },
    {
        "school": "McKinley Elementary School",
        "district": "Lisbon Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454502223",
    },
    {
        "school": "Beaver Local Middle School",
        "district": "Beaver Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464202546",
    },
    {
        "school": "Beaver Local High School",
        "district": "Beaver Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464202547",
    },
    {
        "school": "Beaver Local Elementary School",
        "district": "Beaver Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464202548",
    },
    {
        "school": "Crestview High School",
        "district": "Crestview Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464302552",
    },
    {
        "school": "Crestview Elementary School",
        "district": "Crestview Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464302553",
    },
    {
        "school": "Crestview Middle School",
        "district": "Crestview Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464302554",
    },
    {
        "school": "Southern Local Elementary School",
        "district": "Southern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464402558",
    },
    {
        "school": "Southern Local Jr/Sr High School",
        "district": "Southern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464402559",
    },
    {
        "school": "United Elementary School",
        "district": "United Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464502561",
    },
    {
        "school": "United High School",
        "district": "United Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464502562",
    },
    {
        "school": "Columbiana County",
        "district": "Columbiana County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390509004057",
    },
    {
        "school": "Buckeye Elementary School",
        "district": "Salem City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000601589",
    },
    {
        "school": "Reilly Elementary School",
        "district": "Salem City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000601591",
    },
    {
        "school": "Salem Junior High School",
        "district": "Salem City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000601592",
    },
    {
        "school": "Salem High School",
        "district": "Salem City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000601593",
    },
    {
        "school": "Southeast Elementary School",
        "district": "Salem City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000601594",
    },
    {
        "school": "Leetonia Junior Senior High School",
        "district": "Leetonia Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000702217",
    },
    {
        "school": "Leetonia Elementary School",
        "district": "Leetonia Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000702218",
    },
    {
        "school": "Findlay Digital Academy",
        "district": "Findlay Digital Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390052805238",
    },
    {
        "school": "Arcadia Middle School",
        "district": "Arcadia Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000205134",
    },
    {
        "school": "Arlington Local Elementary School",
        "district": "Arlington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474202889",
    },
    {
        "school": "Arlington Local High School",
        "district": "Arlington Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474202890",
    },
    {
        "school": "Cory-Rawson High School",
        "district": "Cory-Rawson Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474302891",
    },
    {
        "school": "Cory-Rawson Elementary School",
        "district": "Cory-Rawson Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474302893",
    },
    {
        "school": "Liberty-Benton Middle School",
        "district": "Liberty-Benton Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474400936",
    },
    {
        "school": "Liberty-Benton Elementary School",
        "district": "Liberty-Benton Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474402894",
    },
    {
        "school": "Liberty-Benton High School",
        "district": "Liberty-Benton Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474402895",
    },
    {
        "school": "Vanlue Elementary School",
        "district": "Vanlue Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474702901",
    },
    {
        "school": "Vanlue High School",
        "district": "Vanlue Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474702902",
    },
    {
        "school": "Riverdale Elementary School",
        "district": "Riverdale Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475102907",
    },
    {
        "school": "Riverdale Elementary School",
        "district": "Riverdale Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475102908",
    },
    {
        "school": "Riverdale High School",
        "district": "Riverdale Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475102909",
    },
    {
        "school": "Riverdale Middle School",
        "district": "Riverdale Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390475102910",
    },
    {
        "school": "Bigelow Hill Elementary School",
        "district": "Findlay City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000000940",
    },
    {
        "school": "Glenwood Middle School",
        "district": "Findlay City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000000941",
    },
    {
        "school": "Chamberlin Hill Elementary School",
        "district": "Findlay City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000000942",
    },
    {
        "school": "Donnell Middle School",
        "district": "Findlay City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000000943",
    },
    {
        "school": "Findlay High School",
        "district": "Findlay City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000000944",
    },
    {
        "school": "Jacobs Elementary School",
        "district": "Findlay City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000000946",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Findlay City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000000947",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Findlay City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000000948",
    },
    {
        "school": "Northview Elementary School",
        "district": "Findlay City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000000950",
    },
    {
        "school": "Whittier Elementary School",
        "district": "Findlay City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000000953",
    },
    {
        "school": "Wilson Vance Elementary School",
        "district": "Findlay City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000000954",
    },
    {
        "school": "Van Buren Elementary School",
        "district": "Van Buren Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000102899",
    },
    {
        "school": "Van Buren High School",
        "district": "Van Buren Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000102900",
    },
    {
        "school": "Van Buren Middle School",
        "district": "Van Buren Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000103509",
    },
    {
        "school": "Arcadia Elementary School",
        "district": "Arcadia Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000202887",
    },
    {
        "school": "Arcadia High School",
        "district": "Arcadia Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000202888",
    },
    {
        "school": "McComb Local Elementary School",
        "district": "McComb Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474502897",
    },
    {
        "school": "McComb Local Jr/Sr High School",
        "district": "McComb Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390474502896",
    },
    {
        "school": "Woodmore High School",
        "district": "Woodmore Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495703637",
    },
    {
        "school": "Atkinson Elementary School",
        "district": "Fremont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440100971",
    },
    {
        "school": "Croghan Elementary School",
        "district": "Fremont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440100972",
    },
    {
        "school": "Fremont Middle School",
        "district": "Fremont City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440100973",
    },
    {
        "school": "Fremont Ross High School",
        "district": "Fremont City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440100974",
    },
    {
        "school": "Hayes Elementary School",
        "district": "Fremont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440100975",
    },
    {
        "school": "Lutz Elementary School",
        "district": "Fremont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440100976",
    },
    {
        "school": "Otis Elementary School",
        "district": "Fremont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440100977",
    },
    {
        "school": "Stamm Elementary School",
        "district": "Fremont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440100979",
    },
    {
        "school": "Washington Elementary School",
        "district": "Fremont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440100980",
    },
    {
        "school": "Gibsonburg Middle School",
        "district": "Gibsonburg Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453800777",
    },
    {
        "school": "James J Hilfiker Elementary School",
        "district": "Gibsonburg Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453802195",
    },
    {
        "school": "Gibsonburg High School",
        "district": "Gibsonburg Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390453802196",
    },
    {
        "school": "Woodmore Elementary School",
        "district": "Woodmore Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495703638",
    },
    {
        "school": "Technology Center",
        "district": "Vanguard-Sentinel Career & Technology Centers",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390514501496",
    },
    {
        "school": "Vanguard Tech Center",
        "district": "Vanguard-Sentinel Career & Technology Centers",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390514504086",
    },
    {
        "school": "McPherson Middle School",
        "district": "Clyde-Green Springs Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002002166",
    },
    {
        "school": "Clyde High School",
        "district": "Clyde-Green Springs Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002002167",
    },
    {
        "school": "Green Springs Elementary School",
        "district": "Clyde-Green Springs Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002002168",
    },
    {
        "school": "Clyde Elementary School",
        "district": "Clyde-Green Springs Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002002169",
    },
    {
        "school": "Sentinel Career & Technology Center",
        "district": "Vanguard-Sentinel Career & Technology Centers",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390514504278",
    },
    {
        "school": "Greenville Elementary School",
        "district": "Greenville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440901026",
    },
    {
        "school": "Greenville Senior High School",
        "district": "Greenville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440901028",
    },
    {
        "school": "Greenville Middle School",
        "district": "Greenville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440901029",
    },
    {
        "school": "Versailles Elementary School",
        "district": "Versailles Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456302315",
    },
    {
        "school": "Versailles High School",
        "district": "Versailles Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456302316",
    },
    {
        "school": "Versailles Middle School",
        "district": "Versailles Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456302317",
    },
    {
        "school": "Ansonia Elementary School",
        "district": "Ansonia Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466202610",
    },
    {
        "school": "Ansonia High School",
        "district": "Ansonia Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466202611",
    },
    {
        "school": "Ansonia Middle School",
        "district": "Ansonia Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466202612",
    },
    {
        "school": "Arcanum Elementary School",
        "district": "Arcanum-Butler Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466302613",
    },
    {
        "school": "Arcanum High School",
        "district": "Arcanum-Butler Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466302614",
    },
    {
        "school": "Butler Middle School",
        "district": "Arcanum-Butler Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466302615",
    },
    {
        "school": "Franklin Monroe Elementary School",
        "district": "Franklin Monroe Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466402616",
    },
    {
        "school": "Franklin Monroe High School",
        "district": "Franklin Monroe Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466402617",
    },
    {
        "school": "Mississinawa Valley Elementary School",
        "district": "Mississinawa Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466702618",
    },
    {
        "school": "Mississinawa Valley JR/SR High School",
        "district": "Mississinawa Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466702619",
    },
    {
        "school": "Tri-Village High School",
        "district": "Tri-Village Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466802621",
    },
    {
        "school": "Tri-Village Elementary School",
        "district": "Tri-Village Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466802623",
    },
    {
        "school": "Fairland West Elementary School",
        "district": "Fairland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479304628",
    },
    {
        "school": "Rock Hill Elementary School",
        "district": "Rock Hill Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479404629",
    },
    {
        "school": "Rock Hill Middle School",
        "district": "Rock Hill Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479404630",
    },
    {
        "school": "Rock Hill Sr High School",
        "district": "Rock Hill Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479404631",
    },
    {
        "school": "Ironton Middle School",
        "district": "Ironton City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441400359",
    },
    {
        "school": "Ironton High School",
        "district": "Ironton City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441401069",
    },
    {
        "school": "Ironton Elementary School",
        "district": "Ironton City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441401072",
    },
    {
        "school": "Chesapeake High School",
        "district": "Chesapeake Union Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452902163",
    },
    {
        "school": "Chesapeake Middle School",
        "district": "Chesapeake Union Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452902164",
    },
    {
        "school": "Chesapeake Elementary School",
        "district": "Chesapeake Union Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452902165",
    },
    {
        "school": "Dawson-Bryant High School",
        "district": "Dawson-Bryant Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479203040",
    },
    {
        "school": "Dawson-Bryant Middle School",
        "district": "Dawson-Bryant Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479203041",
    },
    {
        "school": "Dawson-Bryant Elementary School",
        "district": "Dawson-Bryant Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479203042",
    },
    {
        "school": "Fairland High School",
        "district": "Fairland Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479303044",
    },
    {
        "school": "Fairland East Elementary School",
        "district": "Fairland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479303045",
    },
    {
        "school": "Fairland Middle School",
        "district": "Fairland Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479303046",
    },
    {
        "school": "Burlington Elementary School",
        "district": "South Point Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479503053",
    },
    {
        "school": "South Point High School",
        "district": "South Point Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479503055",
    },
    {
        "school": "South Point Elementary School",
        "district": "South Point Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479503056",
    },
    {
        "school": "South Point Middle School",
        "district": "South Point Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479503057",
    },
    {
        "school": "Symmes Valley Elementary School",
        "district": "Symmes Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479603058",
    },
    {
        "school": "Symmes Valley High School",
        "district": "Symmes Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390479603059",
    },
    {
        "school": "Lawrence County",
        "district": "Lawrence County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390511804072",
    },
    {
        "school": "West Central Learning Academy II",
        "district": "West Central Learning Academy II",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390027604816",
    },
    {
        "school": "Heir Force Community School",
        "district": "Heir Force Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390034104878",
    },
    {
        "school": "Auglaize County Educational Academy",
        "district": "Auglaize County Educational Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390049005200",
    },
    {
        "school": "Unity Elementary School",
        "district": "Lima City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442204536",
    },
    {
        "school": "Freedom Elementary School",
        "district": "Lima City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442204537",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Lima City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442204538",
    },
    {
        "school": "Independence Elementary School",
        "district": "Lima City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442205280",
    },
    {
        "school": "Liberty Arts Magnet K-8",
        "district": "Lima City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442205281",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Delphos City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438800851",
    },
    {
        "school": "Jefferson High School",
        "district": "Delphos City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438800852",
    },
    {
        "school": "Lima North Middle School",
        "district": "Lima City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442201158",
    },
    {
        "school": "Lima South Science-Technology Magnet K-8",
        "district": "Lima City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442201160",
    },
    {
        "school": "Lima West Middle School",
        "district": "Lima City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442201162",
    },
    {
        "school": "Bluffton Middle School",
        "district": "Bluffton Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452101366",
    },
    {
        "school": "Bluffton Elementary School",
        "district": "Bluffton Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452102124",
    },
    {
        "school": "Bluffton High School",
        "district": "Bluffton Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452102125",
    },
    {
        "school": "Allen East High School",
        "district": "Allen East Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457502331",
    },
    {
        "school": "Allen East Elementary School",
        "district": "Allen East Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457502332",
    },
    {
        "school": "Bath Elementary School",
        "district": "Bath Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457602334",
    },
    {
        "school": "Bath High School",
        "district": "Bath Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457602335",
    },
    {
        "school": "Bath Middle School",
        "district": "Bath Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457602336",
    },
    {
        "school": "Elida High School",
        "district": "Elida Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457702339",
    },
    {
        "school": "Elida Elementary",
        "district": "Elida Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457702340",
    },
    {
        "school": "Elida Middle School",
        "district": "Elida Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457704223",
    },
    {
        "school": "Perry Elementary School",
        "district": "Perry Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457802341",
    },
    {
        "school": "Perry High School",
        "district": "Perry Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457802342",
    },
    {
        "school": "Elmwood Elementary School",
        "district": "Shawnee Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457902343",
    },
    {
        "school": "Maplewood Elementary School",
        "district": "Shawnee Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457902344",
    },
    {
        "school": "Shawnee High School",
        "district": "Shawnee Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457902345",
    },
    {
        "school": "Shawnee Middle School",
        "district": "Shawnee Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457902346",
    },
    {
        "school": "Spencerville Elementary School",
        "district": "Spencerville Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458002348",
    },
    {
        "school": "Spencerville High School",
        "district": "Spencerville Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458002349",
    },
    {
        "school": "Spencerville Middle School",
        "district": "Spencerville Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458002350",
    },
    {
        "school": "Apollo Career Center",
        "district": "Apollo",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390507704051",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Delphos City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438800853",
    },
    {
        "school": "Interactive Media & Construction (IMAC)",
        "district": "Interactive Media & Construction (IMAC)",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390047805037",
    },
    {
        "school": "Jesse Beer - Madison Early Childhood Learning Center",
        "district": "Madison Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494505140",
    },
    {
        "school": "Malabar Intermediate School",
        "district": "Mansfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442901215",
    },
    {
        "school": "Mansfield Middle School",
        "district": "Mansfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442901219",
    },
    {
        "school": "Mansfield Senior High School",
        "district": "Mansfield City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442901220",
    },
    {
        "school": "Prospect Elementary School",
        "district": "Mansfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442901222",
    },
    {
        "school": "Sherman Elementary School",
        "district": "Mansfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442901225",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Mansfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442901230",
    },
    {
        "school": "Clear Fork Middle School",
        "district": "Clear Fork Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494102764",
    },
    {
        "school": "Bellville Elementary School",
        "district": "Clear Fork Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494103580",
    },
    {
        "school": "Butler Elementary School",
        "district": "Clear Fork Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494103581",
    },
    {
        "school": "Clear Fork High School",
        "district": "Clear Fork Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494103582",
    },
    {
        "school": "Central Elementary School",
        "district": "Lexington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494303587",
    },
    {
        "school": "Eastern Elementary School",
        "district": "Lexington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494303588",
    },
    {
        "school": "Lexington High School",
        "district": "Lexington Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494303589",
    },
    {
        "school": "Lexington Junior High School",
        "district": "Lexington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494303590",
    },
    {
        "school": "Western Elementary School",
        "district": "Lexington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494303591",
    },
    {
        "school": "Lucas Elementary School",
        "district": "Lucas Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494403592",
    },
    {
        "school": "Lucas High School",
        "district": "Lucas Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494403593",
    },
    {
        "school": "Lucas Heritage Middle School",
        "district": "Lucas Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494404169",
    },
    {
        "school": "Eastview Elementary School",
        "district": "Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494503594",
    },
    {
        "school": "Madison Middle School",
        "district": "Madison Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494503597",
    },
    {
        "school": "Madison High School",
        "district": "Madison Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494503598",
    },
    {
        "school": "Madison South Elementary School",
        "district": "Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494503599",
    },
    {
        "school": "Mifflin Elementary School",
        "district": "Madison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494503601",
    },
    {
        "school": "Plymouth High School",
        "district": "Plymouth-Shiloh Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494603605",
    },
    {
        "school": "Shiloh Middle School",
        "district": "Plymouth-Shiloh Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494603606",
    },
    {
        "school": "Shiloh Elementary School",
        "district": "Plymouth-Shiloh Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494604353",
    },
    {
        "school": "Ontario High School",
        "district": "Ontario Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494703608",
    },
    {
        "school": "Ontario Middle School",
        "district": "Ontario Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494703609",
    },
    {
        "school": "Stingel Elementary School",
        "district": "Ontario Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494703677",
    },
    {
        "school": "Pioneer Career & Technology",
        "district": "Pioneer Career & Technology",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390514104084",
    },
    {
        "school": "Auburn Elementary School",
        "district": "Shelby City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000901625",
    },
    {
        "school": "Dowds Elementary School",
        "district": "Shelby City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000901627",
    },
    {
        "school": "Shelby Middle School",
        "district": "Shelby City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000901628",
    },
    {
        "school": "Shelby High School",
        "district": "Shelby City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000901629",
    },
    {
        "school": "William H. Taft Elementary School",
        "district": "Marion City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443304539",
    },
    {
        "school": "James A. Garfield Elementary School",
        "district": "Marion City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443304540",
    },
    {
        "school": "Ulysses S. Grant Middle School",
        "district": "Marion City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443305287",
    },
    {
        "school": "William McKinley Elementary School",
        "district": "Marion City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443305288",
    },
    {
        "school": "TRECA Digital Academy",
        "district": "TRECA Digital Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390011804148",
    },
    {
        "school": "George Washington Elementary School",
        "district": "Marion City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443301257",
    },
    {
        "school": "Harding High School",
        "district": "Marion City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443301259",
    },
    {
        "school": "Benjamin Harrison Elementary School",
        "district": "Marion City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443301261",
    },
    {
        "school": "Rutherford B. Hayes Elementary School",
        "district": "Marion City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443301267",
    },
    {
        "school": "Elgin High School",
        "district": "Elgin Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484103240",
    },
    {
        "school": "Elgin Middle School",
        "district": "Elgin Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484103241",
    },
    {
        "school": "Elgin Elementary School",
        "district": "Elgin Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484103242",
    },
    {
        "school": "Pleasant Elementary School",
        "district": "Pleasant Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484203244",
    },
    {
        "school": "Pleasant Middle School",
        "district": "Pleasant Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484203245",
    },
    {
        "school": "Pleasant High School",
        "district": "Pleasant Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484203246",
    },
    {
        "school": "Ridgedale Jr/Sr High School",
        "district": "Ridgedale Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484303250",
    },
    {
        "school": "Ridgedale Elementary School",
        "district": "Ridgedale Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484303251",
    },
    {
        "school": "Liberty Elementary School",
        "district": "River Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484403252",
    },
    {
        "school": "River Valley High School",
        "district": "River Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484403255",
    },
    {
        "school": "River Valley Middle School",
        "district": "River Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484403256",
    },
    {
        "school": "Heritage Elementary School",
        "district": "River Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390484403257",
    },
    {
        "school": "Tri-Rivers Career Center",
        "district": "Tri-Rivers",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390652604127",
    },
    {
        "school": "Centerburg Middle School",
        "district": "Centerburg Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478204626",
    },
    {
        "school": "Danville Middle School",
        "district": "Danville Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478304627",
    },
    {
        "school": "Centerburg Elementary School",
        "district": "Centerburg Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478203005",
    },
    {
        "school": "Centerburg High School",
        "district": "Centerburg Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478203006",
    },
    {
        "school": "Danville Elementary School",
        "district": "Danville Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478303007",
    },
    {
        "school": "Danville High School",
        "district": "Danville Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478303008",
    },
    {
        "school": "Fredericktown Elementary School",
        "district": "Fredericktown Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478503012",
    },
    {
        "school": "Fredericktown High School",
        "district": "Fredericktown Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478503013",
    },
    {
        "school": "Fredericktown Middle School",
        "district": "Fredericktown Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478503014",
    },
    {
        "school": "Knox County Career Center",
        "district": "Knox County JVSD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390511404070",
    },
    {
        "school": "Columbia Elementary School",
        "district": "Mount Vernon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001201351",
    },
    {
        "school": "Dan Emmett Elementary School",
        "district": "Mount Vernon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001201352",
    },
    {
        "school": "East Elementary School",
        "district": "Mount Vernon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001201353",
    },
    {
        "school": "Wiggin Street Elementary School",
        "district": "Mount Vernon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001201355",
    },
    {
        "school": "Mount Vernon High School",
        "district": "Mount Vernon City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001201356",
    },
    {
        "school": "Mount Vernon Middle School",
        "district": "Mount Vernon City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001201357",
    },
    {
        "school": "Pleasant Street Elementary School",
        "district": "Mount Vernon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001201358",
    },
    {
        "school": "Twin Oak Elementary School",
        "district": "Mount Vernon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001201359",
    },
    {
        "school": "East Knox Junior/Senior High School",
        "district": "East Knox Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001303010",
    },
    {
        "school": "Quaker Digital Academy",
        "district": "Quaker Digital Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390025205195",
    },
    {
        "school": "Claymont Middle School",
        "district": "Claymont City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437700404",
    },
    {
        "school": "Claymont High School",
        "district": "Claymont City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437700405",
    },
    {
        "school": "Claymont Elementary School",
        "district": "Claymont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437700406",
    },
    {
        "school": "Claymont Intermediate School",
        "district": "Claymont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437700407",
    },
    {
        "school": "Claymont Primary School",
        "district": "Claymont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437700410",
    },
    {
        "school": "Dover High School",
        "district": "Dover City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438900855",
    },
    {
        "school": "Dover Avenue Elementary School",
        "district": "Dover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438900856",
    },
    {
        "school": "Dover Middle School",
        "district": "Dover City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438900857",
    },
    {
        "school": "East Elementary School",
        "district": "Dover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438900858",
    },
    {
        "school": "South Elementary School",
        "district": "Dover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438900860",
    },
    {
        "school": "Central Elementary School",
        "district": "New Philadelphia City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444801397",
    },
    {
        "school": "East Elementary School",
        "district": "New Philadelphia City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444801398",
    },
    {
        "school": "New Philadelphia High School",
        "district": "New Philadelphia City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444801400",
    },
    {
        "school": "South Elementary School",
        "district": "New Philadelphia City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444801401",
    },
    {
        "school": "Joseph Welty Middle School",
        "district": "New Philadelphia City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444801403",
    },
    {
        "school": "West Elementary School",
        "district": "New Philadelphia City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444801404",
    },
    {
        "school": "York Elementary School",
        "district": "New Philadelphia City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444801405",
    },
    {
        "school": "East Elementary School",
        "district": "Newcomerstown Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455402269",
    },
    {
        "school": "Newcomerstown High School",
        "district": "Newcomerstown Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455402270",
    },
    {
        "school": "Newcomerstown Middle School",
        "district": "Newcomerstown Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455402271",
    },
    {
        "school": "West Elementary School",
        "district": "Newcomerstown Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455402272",
    },
    {
        "school": "Dundee Elementary School",
        "district": "Garaway Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502703892",
    },
    {
        "school": "Garaway High School",
        "district": "Garaway Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502703893",
    },
    {
        "school": "Baltic Elementary School",
        "district": "Garaway Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502703894",
    },
    {
        "school": "Miller Avenue Elementary School",
        "district": "Garaway Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502703895",
    },
    {
        "school": "Ragersville Elementary School",
        "district": "Garaway Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502703896",
    },
    {
        "school": "Indian Valley High School",
        "district": "Indian Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502803899",
    },
    {
        "school": "Midvale Elementary School",
        "district": "Indian Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502803900",
    },
    {
        "school": "Port Washington Elementary School",
        "district": "Indian Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502803901",
    },
    {
        "school": "Tuscarawas Middle School",
        "district": "Indian Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502803902",
    },
    {
        "school": "Strasburg-Franklin Elementary School",
        "district": "Strasburg-Franklin Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502903903",
    },
    {
        "school": "Strasburg-Franklin High School",
        "district": "Strasburg-Franklin Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502903904",
    },
    {
        "school": "Tuscarawas Valley Intermediate",
        "district": "Tuscarawas Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503003905",
    },
    {
        "school": "Tuscarawas Valley Primary",
        "district": "Tuscarawas Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503003906",
    },
    {
        "school": "Tuscarawas Valley High School",
        "district": "Tuscarawas Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503003908",
    },
    {
        "school": "Buckeye Career Center",
        "district": "Buckeye",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390516504092",
    },
    {
        "school": "Sandy Valley High School",
        "district": "Sandy Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499403770",
    },
    {
        "school": "Main Street School",
        "district": "Norwalk City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445605290",
    },
    {
        "school": "New London Middle School",
        "district": "New London Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477204621",
    },
    {
        "school": "Western Reserve Elementary School",
        "district": "Western Reserve Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477404622",
    },
    {
        "school": "Bellevue Middle School",
        "district": "Bellevue City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435900151",
    },
    {
        "school": "League Elementary School",
        "district": "Norwalk City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445601454",
    },
    {
        "school": "Maplehurst Elementary School",
        "district": "Norwalk City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445601455",
    },
    {
        "school": "Norwalk Middle School",
        "district": "Norwalk City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445601456",
    },
    {
        "school": "Norwalk High School",
        "district": "Norwalk City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445601457",
    },
    {
        "school": "Pleasant Elementary School",
        "district": "Norwalk City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445601458",
    },
    {
        "school": "Willard Elementary School",
        "district": "Willard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450901989",
    },
    {
        "school": "Willard Middle School",
        "district": "Willard City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450901992",
    },
    {
        "school": "Willard High School",
        "district": "Willard City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450901994",
    },
    {
        "school": "Monroeville Elementary School",
        "district": "Monroeville Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477102951",
    },
    {
        "school": "Monroeville High School",
        "district": "Monroeville Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477102952",
    },
    {
        "school": "New London Elementary School",
        "district": "New London Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477202954",
    },
    {
        "school": "New London High School",
        "district": "New London Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477202955",
    },
    {
        "school": "South Central High School",
        "district": "South Central Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477302956",
    },
    {
        "school": "South Central Elementary School",
        "district": "South Central Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477302958",
    },
    {
        "school": "Western Reserve High School",
        "district": "Western Reserve Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477402961",
    },
    {
        "school": "Western Reserve Middle School",
        "district": "Western Reserve Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477402962",
    },
    {
        "school": "Bellevue High School",
        "district": "Bellevue City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435900150",
    },
    {
        "school": "Bellevue Elementary School",
        "district": "Bellevue City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435900157",
    },
    {
        "school": "Belpre Elementary School",
        "district": "Belpre City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436104194",
    },
    {
        "school": "Belpre High School",
        "district": "Belpre City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436100159",
    },
    {
        "school": "Beverly-Center Elementary School",
        "district": "Fort Frye Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504803958",
    },
    {
        "school": "Fort Frye High School",
        "district": "Fort Frye Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504803960",
    },
    {
        "school": "Lowell Elementary School",
        "district": "Fort Frye Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504803961",
    },
    {
        "school": "Salem-Liberty Elementary School",
        "district": "Fort Frye Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504803962",
    },
    {
        "school": "Frontier High/Middle School",
        "district": "Frontier Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504903963",
    },
    {
        "school": "Matamoras Elementary School",
        "district": "Frontier Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504903965",
    },
    {
        "school": "Newport Elementary School",
        "district": "Frontier Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504903966",
    },
    {
        "school": "Waterford Elementary School",
        "district": "Wolf Creek Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505103973",
    },
    {
        "school": "Waterford High School",
        "district": "Wolf Creek Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505103974",
    },
    {
        "school": "Washington County CC use 051706",
        "district": "Washington County Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390516904094",
    },
    {
        "school": "Warren Middle School",
        "district": "Warren Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001803967",
    },
    {
        "school": "Little Hocking Elementary School",
        "district": "Warren Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001803970",
    },
    {
        "school": "Warren Elementary School",
        "district": "Warren Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001803971",
    },
    {
        "school": "Warren High School",
        "district": "Warren Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001803972",
    },
    {
        "school": "Harmar Elementary School",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001901244",
    },
    {
        "school": "Marietta Middle School",
        "district": "Marietta City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001901245",
    },
    {
        "school": "Marietta High School",
        "district": "Marietta City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001901246",
    },
    {
        "school": "Phillips Elementary School",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001901249",
    },
    {
        "school": "Putnam Elementary School",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001901250",
    },
    {
        "school": "Washington Elementary School",
        "district": "Marietta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001901252",
    },
    {
        "school": "Gallia Academy High School",
        "district": "Gallipolis City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440300989",
    },
    {
        "school": "Green Elementary School",
        "district": "Gallipolis City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440300990",
    },
    {
        "school": "Rio Grande Elementary School",
        "district": "Gallipolis City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440300991",
    },
    {
        "school": "Washington Elementary School",
        "district": "Gallipolis City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440300992",
    },
    {
        "school": "Buckeye Hills Career Center",
        "district": "Gallia-Jackson-Vinton",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390620604118",
    },
    {
        "school": "South Gallia High School",
        "district": "Gallia County Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390656800725",
    },
    {
        "school": "Addaville Elementary School",
        "district": "Gallia County Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390656804128",
    },
    {
        "school": "River Valley Middle School",
        "district": "Gallia County Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390656804129",
    },
    {
        "school": "Southwestern Elementary School",
        "district": "Gallia County Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390656804130",
    },
    {
        "school": "Hannan Trace Elementary School",
        "district": "Gallia County Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390656804133",
    },
    {
        "school": "River Valley High School",
        "district": "Gallia County Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390656804135",
    },
    {
        "school": "Vinton Elementary School",
        "district": "Gallia County Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390656804138",
    },
    {
        "school": "Wheelersburg Middle School",
        "district": "Wheelersburg Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496604660",
    },
    {
        "school": "Sciotoville",
        "district": "Sciotoville",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390012303957",
    },
    {
        "school": "Glenwood High School",
        "district": "New Boston Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444601390",
    },
    {
        "school": "Oak Intermediate Elementary School",
        "district": "New Boston Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444601391",
    },
    {
        "school": "Stanton Primary Elementary School",
        "district": "New Boston Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444601392",
    },
    {
        "school": "South Webster Jr/Sr High School",
        "district": "Bloom-Vernon Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495903640",
    },
    {
        "school": "Bloom-Vernon Elementary School",
        "district": "Bloom-Vernon Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495903643",
    },
    {
        "school": "Green Primary Elementary School",
        "district": "Green Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496100699",
    },
    {
        "school": "Green Elementary School",
        "district": "Green Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496103647",
    },
    {
        "school": "Green High School",
        "district": "Green Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496103648",
    },
    {
        "school": "Minford High School",
        "district": "Minford Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496203649",
    },
    {
        "school": "Minford Middle School",
        "district": "Minford Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496203650",
    },
    {
        "school": "Minford Primary Elementary School",
        "district": "Minford Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496203651",
    },
    {
        "school": "Northwest Middle School",
        "district": "Northwest Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496300490",
    },
    {
        "school": "Northwest Elementary School",
        "district": "Northwest Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496300493",
    },
    {
        "school": "Northwest High School",
        "district": "Northwest Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496303654",
    },
    {
        "school": "Valley Elementary School",
        "district": "Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496403658",
    },
    {
        "school": "Valley High School",
        "district": "Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496403659",
    },
    {
        "school": "Valley Middle School",
        "district": "Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496403660",
    },
    {
        "school": "Portsmouth West Elementary School",
        "district": "Washington-Nile Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496501452",
    },
    {
        "school": "Portsmouth West Middle School",
        "district": "Washington-Nile Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496501453",
    },
    {
        "school": "Portsmouth West High School",
        "district": "Washington-Nile Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496503665",
    },
    {
        "school": "Wheelersburg Elementary School",
        "district": "Wheelersburg Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496603666",
    },
    {
        "school": "Wheelersburg High School",
        "district": "Wheelersburg Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496603667",
    },
    {
        "school": "Scioto County Career Technical Center",
        "district": "Scioto County Career Technical Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390514904088",
    },
    {
        "school": "Clay High School",
        "district": "Clay Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002603644",
    },
    {
        "school": "Clay Elementary School",
        "district": "Clay Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002603645",
    },
    {
        "school": "Clay Middle School",
        "district": "Clay Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002603646",
    },
    {
        "school": "East Portsmouth Elementary",
        "district": "Portsmouth City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002701539",
    },
    {
        "school": "Portsmouth Junior High School/Portsmouth High School",
        "district": "Portsmouth City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002701544",
    },
    {
        "school": "Portsmouth Elementary",
        "district": "Portsmouth City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002703706",
    },
    {
        "school": "Huron High School",
        "district": "Huron City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441301063",
    },
    {
        "school": "McCormick Junior High",
        "district": "Huron City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441301064",
    },
    {
        "school": "Woodlands Intermediate School",
        "district": "Huron City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441301066",
    },
    {
        "school": "Sandusky Middle School",
        "district": "Sandusky City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447401595",
    },
    {
        "school": "Hancock Elementary School",
        "district": "Sandusky City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447401598",
    },
    {
        "school": "Mills Elementary School",
        "district": "Sandusky City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447401601",
    },
    {
        "school": "Ontario School",
        "district": "Sandusky City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447401603",
    },
    {
        "school": "Osborne Elementary School",
        "district": "Sandusky City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447401604",
    },
    {
        "school": "Sandusky High School",
        "district": "Sandusky City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447401605",
    },
    {
        "school": "Venice Heights Elementary School",
        "district": "Sandusky City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447401606",
    },
    {
        "school": "Edison Middle School (formerly Berlin-Milan Middle School)",
        "district": "Edison Local (formerly Berlin-Milan)",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467802652",
    },
    {
        "school": "Edison High School",
        "district": "Edison Local (formerly Berlin-Milan)",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467802653",
    },
    {
        "school": "Edison Elementary School (formerly Milan Elem)",
        "district": "Edison Local (formerly Berlin-Milan)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467802654",
    },
    {
        "school": "Kelleys Island High School",
        "district": "Kelleys Island Local",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467904270",
    },
    {
        "school": "Margaretta High School",
        "district": "Margaretta Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468002658",
    },
    {
        "school": "Furry Elementary School",
        "district": "Perkins Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468102661",
    },
    {
        "school": "Meadowlawn Elementary School",
        "district": "Perkins Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468102662",
    },
    {
        "school": "Perkins High School",
        "district": "Perkins Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468102663",
    },
    {
        "school": "Briar Middle School",
        "district": "Perkins Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468102664",
    },
    {
        "school": "Vermilion Elementary School",
        "district": "Vermilion Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468202667",
    },
    {
        "school": "Vermilion High School",
        "district": "Vermilion Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468202669",
    },
    {
        "school": "Sailorway Middle School",
        "district": "Vermilion Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468204347",
    },
    {
        "school": "Ehove Career Center",
        "district": "EHOVE Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390510204063",
    },
    {
        "school": "Margaretta Elementary School",
        "district": "Margaretta Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468002660",
    },
    {
        "school": "Anna Middle School",
        "district": "Anna Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000404661",
    },
    {
        "school": "Botkins Elementary School",
        "district": "Botkins Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497603686",
    },
    {
        "school": "Botkins High School",
        "district": "Botkins Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497603687",
    },
    {
        "school": "Fairlawn Elementary School",
        "district": "Fairlawn Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497703690",
    },
    {
        "school": "Fairlawn High School",
        "district": "Fairlawn Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497703691",
    },
    {
        "school": "Fort Loramie Elementary School",
        "district": "Fort Loramie Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497803692",
    },
    {
        "school": "Fort Loramie Junior-Senior High School",
        "district": "Fort Loramie Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497803693",
    },
    {
        "school": "Hardin Houston Elementary School",
        "district": "Hardin-Houston Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497903694",
    },
    {
        "school": "Houston High School",
        "district": "Hardin-Houston Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497903695",
    },
    {
        "school": "Russia Elementary School",
        "district": "Russia Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498103698",
    },
    {
        "school": "Russia High School",
        "district": "Russia Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498103699",
    },
    {
        "school": "Sidney Middle School",
        "district": "Sidney City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000301631",
    },
    {
        "school": "Emerson Primary School",
        "district": "Sidney City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000301633",
    },
    {
        "school": "Longfellow Primary School",
        "district": "Sidney City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000301634",
    },
    {
        "school": "Northwood Intermediate School",
        "district": "Sidney City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000301636",
    },
    {
        "school": "Sidney High School",
        "district": "Sidney City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000301640",
    },
    {
        "school": "Whittier Early Childhood Center",
        "district": "Sidney City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000301641",
    },
    {
        "school": "Anna Elementary School",
        "district": "Anna Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000403682",
    },
    {
        "school": "Anna High School",
        "district": "Anna Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000403683",
    },
    {
        "school": "Jackson Center Elementary School",
        "district": "Jackson Center Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000503696",
    },
    {
        "school": "Jackson Center High School",
        "district": "Jackson Center Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000503697",
    },
    {
        "school": "Springfield Preparatory and Fitness Academy",
        "district": "Springfield Preparatory and Fitness Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390055105263",
    },
    {
        "school": "South Vienna Middle School",
        "district": "Northeastern Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462504586",
    },
    {
        "school": "Northridge Middle School",
        "district": "Northeastern Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462504587",
    },
    {
        "school": "Cliff Park High School",
        "district": "Cliff Park High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390010003820",
    },
    {
        "school": "SPRINGFIELD SCHOOL OF INNOVATION",
        "district": "Springfield City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448100117",
    },
    {
        "school": "Fulton Elementary School",
        "district": "Springfield City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101684",
    },
    {
        "school": "Hayward Middle School",
        "district": "Springfield City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101686",
    },
    {
        "school": "Kenton Elementary School",
        "district": "Springfield City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101689",
    },
    {
        "school": "Kenwood Elementary",
        "district": "Springfield City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101690",
    },
    {
        "school": "Lagonda Elementary School",
        "district": "Springfield City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101691",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Springfield City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101692",
    },
    {
        "school": "Mann Elementary School",
        "district": "Springfield City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101693",
    },
    {
        "school": "Perrin Woods Elementary School",
        "district": "Springfield City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101696",
    },
    {
        "school": "Roosevelt Middle School",
        "district": "Springfield City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101697",
    },
    {
        "school": "Schaefer Middle School",
        "district": "Springfield City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101698",
    },
    {
        "school": "Snowhill Elementary School",
        "district": "Springfield City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101699",
    },
    {
        "school": "Snyder Park Elementary School",
        "district": "Springfield City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101700",
    },
    {
        "school": "Springfield High School",
        "district": "Springfield City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101701",
    },
    {
        "school": "Warder Park-Wayne Elementary School",
        "district": "Springfield City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448101703",
    },
    {
        "school": "Yellow Springs/McKinney High School",
        "district": "Yellow Springs Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456702330",
    },
    {
        "school": "Indian Valley Intermediate School",
        "district": "Greenon Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462302474",
    },
    {
        "school": "Greenon High School",
        "district": "Greenon Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462302475",
    },
    {
        "school": "Enon Primary School",
        "district": "Greenon Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462302476",
    },
    {
        "school": "Greenon Jr. High School",
        "district": "Greenon Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462302477",
    },
    {
        "school": "Donnelsville Elementary School",
        "district": "Tecumseh Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462402478",
    },
    {
        "school": "Tecumseh  Middle School",
        "district": "Tecumseh Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462402483",
    },
    {
        "school": "Park Layne Elementary School",
        "district": "Tecumseh Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462402484",
    },
    {
        "school": "Tecumseh High School",
        "district": "Tecumseh Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462402485",
    },
    {
        "school": "New Carlisle Elementary School",
        "district": "Tecumseh Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462402486",
    },
    {
        "school": "Kenton Ridge High School",
        "district": "Northeastern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462502488",
    },
    {
        "school": "Northeastern High School",
        "district": "Northeastern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462502490",
    },
    {
        "school": "Northridge Elementary School",
        "district": "Northeastern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462502491",
    },
    {
        "school": "Rolling Hills Elementary School",
        "district": "Northeastern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462502492",
    },
    {
        "school": "South Vienna Elementary School",
        "district": "Northeastern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462502493",
    },
    {
        "school": "Northwestern Elementary School",
        "district": "Northwestern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462602494",
    },
    {
        "school": "Northwestern Junior/Senior High School",
        "district": "Northwestern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462602495",
    },
    {
        "school": "Miami View Elementary School",
        "district": "Southeastern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462702497",
    },
    {
        "school": "Southeastern  Sr. High School",
        "district": "Southeastern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462702498",
    },
    {
        "school": "Southeastern Jr. High School",
        "district": "Southeastern Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462703556",
    },
    {
        "school": "Possum Elementary School",
        "district": "Clark-Shawnee Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462802499",
    },
    {
        "school": "Reid Elementary School",
        "district": "Clark-Shawnee Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462802500",
    },
    {
        "school": "Rockway Elementary School",
        "district": "Clark-Shawnee Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462802501",
    },
    {
        "school": "Shawnee High School",
        "district": "Clark-Shawnee Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462802502",
    },
    {
        "school": "Springfield-Clark County",
        "district": "Springfield-Clark County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390515304089",
    },
    {
        "school": "Mills Lawn Elementary School",
        "district": "Yellow Springs Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456702329",
    },
    {
        "school": "Bridges Community Academy",
        "district": "Bridges Community Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390050205212",
    },
    {
        "school": "Columbian High School",
        "district": "Tiffin City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448901762",
    },
    {
        "school": "Krout 2-3 Elementary",
        "district": "Tiffin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448901764",
    },
    {
        "school": "Noble 4-5 Elementary",
        "district": "Tiffin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448901766",
    },
    {
        "school": "Washington K-1 Elementary School",
        "district": "Tiffin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448901767",
    },
    {
        "school": "Tiffin Middle School",
        "district": "Tiffin City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448901768",
    },
    {
        "school": "Seneca East Elementary",
        "district": "Seneca East Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496803668",
    },
    {
        "school": "Seneca East High School",
        "district": "Seneca East Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496803670",
    },
    {
        "school": "Seneca East Middle School",
        "district": "Seneca East Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390496803671",
    },
    {
        "school": "Hopewell-Loudon Local Elementary School",
        "district": "Hopewell-Loudon Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497003675",
    },
    {
        "school": "Hopewell-Loudon Local High School",
        "district": "Hopewell-Loudon Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497003676",
    },
    {
        "school": "New Riegel Elementary School",
        "district": "New Riegel Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497103678",
    },
    {
        "school": "New Riegel High School",
        "district": "New Riegel Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390497103679",
    },
    {
        "school": "Old Fort Elementary School Bettsville Campus",
        "district": "Old Fort Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002103680",
    },
    {
        "school": "Old Fort High School",
        "district": "Old Fort Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002103681",
    },
    {
        "school": "Fostoria Elementary School",
        "district": "Fostoria City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439900961",
    },
    {
        "school": "Fostoria Junior/Senior High School",
        "district": "Fostoria City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439900957",
    },
    {
        "school": "Glass City Academy",
        "district": "Glass City Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390012704177",
    },
    {
        "school": "Wildwood Environmental Academy",
        "district": "Wildwood Environmental Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390013805188",
    },
    {
        "school": "Ohio Virtual Academy",
        "district": "Ohio Virtual Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390018004704",
    },
    {
        "school": "Alternative Education Academy",
        "district": "Alternative Education Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390020304727",
    },
    {
        "school": "Skyway Career Prep High School",
        "district": "Skyway Career Prep High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390023104787",
    },
    {
        "school": "Winterfield Venture Academy",
        "district": "Winterfield Venture Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390030204839",
    },
    {
        "school": "Horizon Science Academy-Springfield",
        "district": "Horizon Science Academy-Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390045105010",
    },
    {
        "school": "Bennett Venture Academy",
        "district": "Bennett Venture Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390045705016",
    },
    {
        "school": "Horizon Science Academy Toledo",
        "district": "Horizon Science Academy Toledo",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390051005220",
    },
    {
        "school": "Eagle Learning Center",
        "district": "Eagle Learning Center",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390064705347",
    },
    {
        "school": "Old West End Academy Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449004559",
    },
    {
        "school": "Toledo Technology Academy High School",
        "district": "Toledo City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449004560",
    },
    {
        "school": "Ella P. Stewart Academy for Girls",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449005292",
    },
    {
        "school": "Maritime Academy of Toledo The",
        "district": "Maritime Academy of Toledo The",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390042804987",
    },
    {
        "school": "Bowling Green Preschool",
        "district": "Bowling Green City School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436305093",
    },
    {
        "school": "Elmwood Elementary School",
        "district": "Elmwood Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506805304",
    },
    {
        "school": "Bataan Memorial Primary School",
        "district": "Port Clinton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446501532",
    },
    {
        "school": "Bataan Memorial Intermediate School",
        "district": "Port Clinton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446501534",
    },
    {
        "school": "Port Clinton Middle School",
        "district": "Port Clinton City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446501535",
    },
    {
        "school": "Port Clinton High School",
        "district": "Port Clinton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446501536",
    },
    {
        "school": "Oak Harbor High School",
        "district": "Benton Carroll Salem Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489203452",
    },
    {
        "school": "Oak Harbor Middle School",
        "district": "Benton Carroll Salem Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489203453",
    },
    {
        "school": "R C Waters Elementary School",
        "district": "Benton Carroll Salem Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489203454",
    },
    {
        "school": "Danbury Elementary School",
        "district": "Danbury Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489303456",
    },
    {
        "school": "Danbury High School",
        "district": "Danbury Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489303457",
    },
    {
        "school": "Genoa Elementary",
        "district": "Genoa Area Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489403458",
    },
    {
        "school": "Genoa Area High School",
        "district": "Genoa Area Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489403461",
    },
    {
        "school": "Genoa Area Middle School",
        "district": "Genoa Area Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489403462",
    },
    {
        "school": "Put-In-Bay Elementary School",
        "district": "Put-In-Bay Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489703465",
    },
    {
        "school": "Put-In-Bay High School",
        "district": "Put-In-Bay Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489703466",
    },
    {
        "school": "Westfield/Robinson Achievement",
        "district": "Toledo City",
        "level": "Other",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390449004471",
    },
    {
        "school": "Wauseon Middle School",
        "district": "Wauseon Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456402318",
    },
    {
        "school": "Wauseon Elementary School",
        "district": "Wauseon Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456402319",
    },
    {
        "school": "Wauseon High School",
        "district": "Wauseon Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456402320",
    },
    {
        "school": "Wauseon Primary School",
        "district": "Wauseon Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456402659",
    },
    {
        "school": "Archbold Elementary School",
        "district": "Archbold-Area Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470402756",
    },
    {
        "school": "Archbold High School",
        "district": "Archbold-Area Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470402757",
    },
    {
        "school": "Archbold Middle School",
        "district": "Archbold-Area Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470402759",
    },
    {
        "school": "Evergreen High School",
        "district": "Evergreen Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470502760",
    },
    {
        "school": "Evergreen Middle School",
        "district": "Evergreen Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470502761",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Evergreen Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470502763",
    },
    {
        "school": "Fayette Elementary School",
        "district": "Fayette Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470602766",
    },
    {
        "school": "Fayette Jr/Sr High School",
        "district": "Fayette Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470602767",
    },
    {
        "school": "Pettisville Elementary School",
        "district": "Pettisville Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470702768",
    },
    {
        "school": "Pettisville High School",
        "district": "Pettisville Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470702769",
    },
    {
        "school": "Delta Elementary School",
        "district": "Pike-Delta-York Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470802770",
    },
    {
        "school": "Pike-Delta-York Middle School",
        "district": "Pike-Delta-York Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470802771",
    },
    {
        "school": "Pike-Delta-York High School",
        "district": "Pike-Delta-York Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470802773",
    },
    {
        "school": "Swanton Middle School",
        "district": "Swanton Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470902775",
    },
    {
        "school": "Swanton Elementary School",
        "district": "Swanton Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470902777",
    },
    {
        "school": "Swanton High School",
        "district": "Swanton Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470902778",
    },
    {
        "school": "Autism Model School",
        "district": "Autism Model School",
        "level": "Other",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390002201520",
    },
    {
        "school": "Toledo School For The Arts",
        "district": "Toledo School For The Arts",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390005603084",
    },
    {
        "school": "The Autism Academy Of Learning",
        "district": "The Autism Academy Of Learning",
        "level": "Other",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390011704155",
    },
    {
        "school": "Fairfield Elementary School",
        "district": "Maumee City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443601289",
    },
    {
        "school": "Fort Miami Elementary School",
        "district": "Maumee City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443601290",
    },
    {
        "school": "Gateway Middle School",
        "district": "Maumee City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443601291",
    },
    {
        "school": "Maumee High School",
        "district": "Maumee City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443601292",
    },
    {
        "school": "Wayne Trail Elementary School",
        "district": "Maumee City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443601294",
    },
    {
        "school": "Clay High School",
        "district": "Oregon City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446001475",
    },
    {
        "school": "Coy Elementary School",
        "district": "Oregon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446001476",
    },
    {
        "school": "Fassett Junior High  School",
        "district": "Oregon City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446001478",
    },
    {
        "school": "Jerusalem Elementary School",
        "district": "Oregon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446001479",
    },
    {
        "school": "Starr Elementary School",
        "district": "Oregon City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446001480",
    },
    {
        "school": "Sylvania Timberstone Junior High School",
        "district": "Sylvania Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448700758",
    },
    {
        "school": "Central Trail Elementary School",
        "district": "Sylvania Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448701743",
    },
    {
        "school": "Highland Elementary School",
        "district": "Sylvania Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448701744",
    },
    {
        "school": "Hill View Elementary School",
        "district": "Sylvania Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448701745",
    },
    {
        "school": "Maplewood Elementary School",
        "district": "Sylvania Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448701746",
    },
    {
        "school": "Stranahan Elementary School",
        "district": "Sylvania Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448701747",
    },
    {
        "school": "Sylvan Elementary School",
        "district": "Sylvania Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448701748",
    },
    {
        "school": "Sylvania Arbor Hills Junior High School",
        "district": "Sylvania Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448701749",
    },
    {
        "school": "Sylvania Mccord Junior High School",
        "district": "Sylvania Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448701750",
    },
    {
        "school": "Sylvania Northview High School",
        "district": "Sylvania Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448701751",
    },
    {
        "school": "Sylvania Southview High School",
        "district": "Sylvania Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448701752",
    },
    {
        "school": "Whiteford Elementary School",
        "district": "Sylvania Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448701753",
    },
    {
        "school": "Grove Patterson Academy Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449000426",
    },
    {
        "school": "Arlington Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001769",
    },
    {
        "school": "Beverly Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001771",
    },
    {
        "school": "Birmingham Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001772",
    },
    {
        "school": "Bowsher High School",
        "district": "Toledo City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001773",
    },
    {
        "school": "Burroughs Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001774",
    },
    {
        "school": "Chase STEM Academy",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001776",
    },
    {
        "school": "Rosa Parks Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001777",
    },
    {
        "school": "Byrnedale Elementary School",
        "district": "Toledo City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001779",
    },
    {
        "school": "DeVeaux Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001780",
    },
    {
        "school": "East Broadway Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001783",
    },
    {
        "school": "Edgewater Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001784",
    },
    {
        "school": "Elmhurst Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001785",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001789",
    },
    {
        "school": "Glendale-Feilbach Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001791",
    },
    {
        "school": "Leverette Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001795",
    },
    {
        "school": "Harvard Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001796",
    },
    {
        "school": "Hawkins Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001797",
    },
    {
        "school": "Jones Leadership Academy",
        "district": "Toledo City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001800",
    },
    {
        "school": "Keyser Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001801",
    },
    {
        "school": "Larchmont Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001805",
    },
    {
        "school": "Longfellow Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001808",
    },
    {
        "school": "Marshall STEMM Academy",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001810",
    },
    {
        "school": "McKinley STEMM Academy",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001813",
    },
    {
        "school": "McTigue Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001814",
    },
    {
        "school": "Navarre Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001816",
    },
    {
        "school": "Oakdale Elementary School",
        "district": "Toledo City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001818",
    },
    {
        "school": "Old Orchard Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001819",
    },
    {
        "school": "Ottawa River Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001821",
    },
    {
        "school": "Pickett Elementary School",
        "district": "Toledo City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001823",
    },
    {
        "school": "Raymer Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001825",
    },
    {
        "school": "Reynolds Elementary School",
        "district": "Toledo City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001826",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001827",
    },
    {
        "school": "Robinson Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001828",
    },
    {
        "school": "Rogers High School",
        "district": "Toledo City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001829",
    },
    {
        "school": "Sherman Elementary School",
        "district": "Toledo City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001832",
    },
    {
        "school": "Start High School",
        "district": "Toledo City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001835",
    },
    {
        "school": "Waite High School",
        "district": "Toledo City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001838",
    },
    {
        "school": "Walbridge Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001839",
    },
    {
        "school": "Whittier Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001843",
    },
    {
        "school": "Woodward High School",
        "district": "Toledo City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449001844",
    },
    {
        "school": "Anthony Wayne Junior High School",
        "district": "Anthony Wayne Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482000849",
    },
    {
        "school": "Anthony Wayne High School",
        "district": "Anthony Wayne Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482003144",
    },
    {
        "school": "Fallen Timbers Middle School",
        "district": "Anthony Wayne Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482003145",
    },
    {
        "school": "Monclova Elementary School",
        "district": "Anthony Wayne Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482003146",
    },
    {
        "school": "Waterville Primary School",
        "district": "Anthony Wayne Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482003147",
    },
    {
        "school": "Whitehouse Primary School",
        "district": "Anthony Wayne Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482003148",
    },
    {
        "school": "Ottawa Hills Elementary School",
        "district": "Ottawa Hills Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482103149",
    },
    {
        "school": "Ottawa Hills High School",
        "district": "Ottawa Hills Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482103150",
    },
    {
        "school": "Holloway Elementary School",
        "district": "Springfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482200478",
    },
    {
        "school": "Crissey Elementary School",
        "district": "Springfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482203151",
    },
    {
        "school": "Dorr Street Elementary School",
        "district": "Springfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482203152",
    },
    {
        "school": "Holland Elementary School",
        "district": "Springfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482203153",
    },
    {
        "school": "Springfield High School",
        "district": "Springfield Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482203154",
    },
    {
        "school": "Springfield Middle School",
        "district": "Springfield Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482203155",
    },
    {
        "school": "Greenwood Elementary School",
        "district": "Washington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482303156",
    },
    {
        "school": "Hiawatha Elementary School",
        "district": "Washington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482303157",
    },
    {
        "school": "Jackman Elementary School",
        "district": "Washington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482303160",
    },
    {
        "school": "Jefferson Junior High School",
        "district": "Washington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482303161",
    },
    {
        "school": "Mcgregor Elementary School",
        "district": "Washington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482303163",
    },
    {
        "school": "Meadowvale Elementary School",
        "district": "Washington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482303164",
    },
    {
        "school": "Monac Elementary School",
        "district": "Washington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482303165",
    },
    {
        "school": "Shoreland Elementary School",
        "district": "Washington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482303166",
    },
    {
        "school": "Wernert Elementary School",
        "district": "Washington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482303169",
    },
    {
        "school": "Whitmer High School",
        "district": "Washington Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482303171",
    },
    {
        "school": "Washington Junior High School",
        "district": "Washington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482304231",
    },
    {
        "school": "Lakota High School",
        "district": "Lakota Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495603634",
    },
    {
        "school": "Lakota Middle School",
        "district": "Lakota Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495603632",
    },
    {
        "school": "Bowling Green High School",
        "district": "Bowling Green City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436300185",
    },
    {
        "school": "Bowling Green Middle School",
        "district": "Bowling Green City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436300186",
    },
    {
        "school": "Conneaut Elementary School",
        "district": "Bowling Green City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436300187",
    },
    {
        "school": "Crim Elementary School",
        "district": "Bowling Green City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436300188",
    },
    {
        "school": "Kenwood Elementary School",
        "district": "Bowling Green City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436300189",
    },
    {
        "school": "Frank Elementary School",
        "district": "Perrysburg Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455802287",
    },
    {
        "school": "Perrysburg High School",
        "district": "Perrysburg Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455802288",
    },
    {
        "school": "Perrysburg Junior High School",
        "district": "Perrysburg Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455802289",
    },
    {
        "school": "Toth Elementary School",
        "district": "Perrysburg Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455802290",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Perrysburg Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455804162",
    },
    {
        "school": "Fort Meigs Elementary School",
        "district": "Perrysburg Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455804401",
    },
    {
        "school": "Rossford Elementary School",
        "district": "Rossford Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456002295",
    },
    {
        "school": "Rossford High School",
        "district": "Rossford Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456002299",
    },
    {
        "school": "Rossford Junior High School",
        "district": "Rossford Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390456004309",
    },
    {
        "school": "Lakota Elementary School",
        "district": "Lakota Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495603633",
    },
    {
        "school": "Eastwood Middle School",
        "district": "Eastwood Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506700345",
    },
    {
        "school": "Eastwood I High School",
        "district": "Eastwood Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506704020",
    },
    {
        "school": "Eastwood Elementary School",
        "district": "Eastwood Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506704022",
    },
    {
        "school": "Elmwood Middle School",
        "district": "Elmwood Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506804026",
    },
    {
        "school": "Elmwood High School",
        "district": "Elmwood Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506804027",
    },
    {
        "school": "Lake Elementary School",
        "district": "Lake Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506904030",
    },
    {
        "school": "Lake Middle School",
        "district": "Lake Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506904031",
    },
    {
        "school": "Lake High School",
        "district": "Lake Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390506904032",
    },
    {
        "school": "E A Powell Elementary School",
        "district": "North Baltimore Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390507004035",
    },
    {
        "school": "North Baltimore High School",
        "district": "North Baltimore Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390507004037",
    },
    {
        "school": "North Baltimore Middle School",
        "district": "North Baltimore Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390507004173",
    },
    {
        "school": "Northwood High School",
        "district": "Northwood Local Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390507104039",
    },
    {
        "school": "Northwood Elementary School",
        "district": "Northwood Local Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390507104040",
    },
    {
        "school": "Otsego Elementary School",
        "district": "Otsego Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390507204042",
    },
    {
        "school": "Otsego Junior High",
        "district": "Otsego Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390507204043",
    },
    {
        "school": "Otsego High School",
        "district": "Otsego Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390507204045",
    },
    {
        "school": "Penta Career Center - on campus",
        "district": "Penta Career Center - District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390513504080",
    },
    {
        "school": "Penta Satellite",
        "district": "Penta Career Center - District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390513504081",
    },
    {
        "school": "Triad Middle School",
        "district": "Triad Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462004585",
    },
    {
        "school": "Urbana Elementary School",
        "district": "Urbana City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449401869",
    },
    {
        "school": "Urbana Junior High School",
        "district": "Urbana City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449401873",
    },
    {
        "school": "Urbana High School",
        "district": "Urbana City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449401874",
    },
    {
        "school": "Dohron Wilson Elementary School",
        "district": "Mechanicsburg Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454802233",
    },
    {
        "school": "Mechanicsburg High School",
        "district": "Mechanicsburg Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454802234",
    },
    {
        "school": "Graham High School",
        "district": "Graham Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461902463",
    },
    {
        "school": "Graham Middle School",
        "district": "Graham Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461902464",
    },
    {
        "school": "Graham Elementary School",
        "district": "Graham Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461902466",
    },
    {
        "school": "Triad Elementary School",
        "district": "Triad Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462002468",
    },
    {
        "school": "Triad High School",
        "district": "Triad Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462002469",
    },
    {
        "school": "Crestview High School",
        "district": "Crestview Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503503919",
    },
    {
        "school": "Crestview Elementary School",
        "district": "Crestview Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503503920",
    },
    {
        "school": "Vantage Career Center",
        "district": "Vantage Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390516704093",
    },
    {
        "school": "Lincolnview Jr/Sr High School",
        "district": "Lincolnview Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002203922",
    },
    {
        "school": "Lincolnview Elementary School",
        "district": "Lincolnview Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002203926",
    },
    {
        "school": "Van Wert Elementary School",
        "district": "Van Wert City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002301884",
    },
    {
        "school": "Van Wert Middle School",
        "district": "Van Wert City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002301885",
    },
    {
        "school": "Van Wert High School",
        "district": "Van Wert City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002301888",
    },
    {
        "school": "Minster Elementary School",
        "district": "Minster Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459404582",
    },
    {
        "school": "St. Marys East Primary School",
        "district": "St Marys City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447201583",
    },
    {
        "school": "St. Marys Middle School",
        "district": "St Marys City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447201584",
    },
    {
        "school": "St Marys Memorial High School",
        "district": "St Marys City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447201585",
    },
    {
        "school": "St Marys West Intermediate School",
        "district": "St Marys City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447201588",
    },
    {
        "school": "Wapakoneta Middle School",
        "district": "Wapakoneta City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449801898",
    },
    {
        "school": "Cridersville Elementary School",
        "district": "Wapakoneta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449801901",
    },
    {
        "school": "Wapakoneta High School",
        "district": "Wapakoneta City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449801904",
    },
    {
        "school": "Minster Jr/Sr High School",
        "district": "Minster Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459402388",
    },
    {
        "school": "New Bremen Elementary School",
        "district": "New Bremen Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459502389",
    },
    {
        "school": "New Bremen High School",
        "district": "New Bremen Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459502390",
    },
    {
        "school": "New Knoxville Elementary School",
        "district": "New Knoxville Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459602391",
    },
    {
        "school": "New Knoxville High School",
        "district": "New Knoxville Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459602392",
    },
    {
        "school": "Waynesfield-Goshen Local High School",
        "district": "Waynesfield-Goshen Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459702393",
    },
    {
        "school": "Waynesfield-Goshen Local Elementary School",
        "district": "Waynesfield-Goshen Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459702394",
    },
    {
        "school": "Washington High School",
        "district": "Washington Court House City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001101937",
    },
    {
        "school": "Washington Middle School",
        "district": "Washington Court House City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001101938",
    },
    {
        "school": "Miami Trace Middle School",
        "district": "Miami Trace Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001002696",
    },
    {
        "school": "Miami Trace High School",
        "district": "Miami Trace Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001002702",
    },
    {
        "school": "Pugliese Elementary West",
        "district": "Steubenville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448201704",
    },
    {
        "school": "Harding Middle School",
        "district": "Steubenville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448201707",
    },
    {
        "school": "East Garfield Elementary School",
        "district": "Steubenville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448201710",
    },
    {
        "school": "Steubenville High School",
        "district": "Steubenville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448201711",
    },
    {
        "school": "Wells Academy",
        "district": "Steubenville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448204283",
    },
    {
        "school": "Toronto Jr. / Sr. High School",
        "district": "Toronto City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449101849",
    },
    {
        "school": "J T Karaffa Elementary School",
        "district": "Toronto City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449104220",
    },
    {
        "school": "Buckeye West Elementary School",
        "district": "Buckeye Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477802969",
    },
    {
        "school": "Buckeye North Elementary School",
        "district": "Buckeye Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477802970",
    },
    {
        "school": "Buckeye Local Junior High",
        "district": "Buckeye Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477802972",
    },
    {
        "school": "Buckeye South Elementary School",
        "district": "Buckeye Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477802981",
    },
    {
        "school": "Buckeye Local High School",
        "district": "Buckeye Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477804400",
    },
    {
        "school": "Edison High School",
        "district": "Edison Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477902988",
    },
    {
        "school": "John E Gregg Elementary School",
        "district": "Edison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477902989",
    },
    {
        "school": "Edison Jr. High School",
        "district": "Edison Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477902993",
    },
    {
        "school": "Stanton Elementary School",
        "district": "Edison Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477902994",
    },
    {
        "school": "Hills Elementary School",
        "district": "Indian Creek Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478002999",
    },
    {
        "school": "Indian Creek Middle School Grades 7 & 8",
        "district": "Indian Creek Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478003000",
    },
    {
        "school": "Wintersville Elementary School",
        "district": "Indian Creek Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478003003",
    },
    {
        "school": "Indian Creek High School",
        "district": "Indian Creek Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478003004",
    },
    {
        "school": "Jefferson County",
        "district": "Jefferson County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390511204069",
    },
    {
        "school": "Bellaire Elementary School",
        "district": "Bellaire Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435704192",
    },
    {
        "school": "Bellaire Middle School",
        "district": "Bellaire Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435704193",
    },
    {
        "school": "Bellaire High School",
        "district": "Bellaire Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435700135",
    },
    {
        "school": "Martins Ferry Middle School",
        "district": "Martins Ferry City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443401270",
    },
    {
        "school": "Martins Ferry High School",
        "district": "Martins Ferry City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443401272",
    },
    {
        "school": "Barnesville Elementary School",
        "district": "Barnesville Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452002120",
    },
    {
        "school": "Barnesville High School",
        "district": "Barnesville Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452002121",
    },
    {
        "school": "The Bridgeport School District - High School",
        "district": "Bridgeport Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452302128",
    },
    {
        "school": "The Bridgeport School DIstrict - Middle School",
        "district": "Bridgeport Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452302129",
    },
    {
        "school": "The Bridgeport School District - Elementary",
        "district": "Bridgeport Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452302131",
    },
    {
        "school": "St Clairsville Middle School",
        "district": "St Clairsville-Richland City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459902397",
    },
    {
        "school": "St Clairsville High School",
        "district": "St Clairsville-Richland City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459902398",
    },
    {
        "school": "St Clairsville Elementary School",
        "district": "St Clairsville-Richland City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390459902399",
    },
    {
        "school": "Jefferson Ave Elementary School",
        "district": "Shadyside Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460002400",
    },
    {
        "school": "Leona Ave Middle School",
        "district": "Shadyside Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460002401",
    },
    {
        "school": "Shadyside High School",
        "district": "Shadyside Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460002402",
    },
    {
        "school": "Union Local Middle School",
        "district": "Union Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460101380",
    },
    {
        "school": "Union Local Elementary School",
        "district": "Union Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460101399",
    },
    {
        "school": "Union Local High School",
        "district": "Union Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390460102408",
    },
    {
        "school": "Belmont Career Center",
        "district": "Belmont-Harrison",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390508504275",
    },
    {
        "school": "Harrison Career Center",
        "district": "Belmont-Harrison",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390508504055",
    },
    {
        "school": "Blanchester Intermediate School",
        "district": "Blanchester Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463805127",
    },
    {
        "school": "Denver Place Elementary School",
        "district": "Wilmington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451102015",
    },
    {
        "school": "Roy E Holmes Elementary School",
        "district": "Wilmington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451102017",
    },
    {
        "school": "Rodger O. Borror Middle School",
        "district": "Wilmington City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451102018",
    },
    {
        "school": "Wilmington High School",
        "district": "Wilmington City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451102022",
    },
    {
        "school": "East End Elementary School",
        "district": "Wilmington City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451104288",
    },
    {
        "school": "Blanchester Middle School",
        "district": "Blanchester Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463802534",
    },
    {
        "school": "Blanchester High School",
        "district": "Blanchester Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463802535",
    },
    {
        "school": "Putman Elementary School",
        "district": "Blanchester Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463802538",
    },
    {
        "school": "Clinton-Massie High School",
        "district": "Clinton-Massie Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463902540",
    },
    {
        "school": "Clinton-Massie Elementary School",
        "district": "Clinton-Massie Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463904225",
    },
    {
        "school": "Clinton-Massie Middle School",
        "district": "Clinton-Massie Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463904373",
    },
    {
        "school": "East Clinton Junior High School",
        "district": "East Clinton Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464000822",
    },
    {
        "school": "East Clinton High School",
        "district": "East Clinton Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464002543",
    },
    {
        "school": "New Vienna Elementary School",
        "district": "East Clinton Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464002544",
    },
    {
        "school": "Sabina Elementary School",
        "district": "East Clinton Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464002545",
    },
    {
        "school": "Rittman Academy",
        "district": "Rittman Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390036604903",
    },
    {
        "school": "Northwestern Elementary School",
        "district": "Northwestern Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003304665",
    },
    {
        "school": "Holmesville Elementary School",
        "district": "Southeast Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505803997",
    },
    {
        "school": "Green Middle School",
        "district": "Green Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505503983",
    },
    {
        "school": "Orrville Elementary School",
        "district": "Orrville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446101483",
    },
    {
        "school": "Orrville High School",
        "district": "Orrville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446101485",
    },
    {
        "school": "Orrville Middle School",
        "district": "Orrville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446101486",
    },
    {
        "school": "Chippewa Jr./Sr. High School",
        "district": "Chippewa Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505303976",
    },
    {
        "school": "Chippewa Intermediate School",
        "district": "Chippewa Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505303977",
    },
    {
        "school": "Hazel Harvey Elementary School",
        "district": "Chippewa Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505303978",
    },
    {
        "school": "Dalton Elementary School",
        "district": "Dalton Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505403979",
    },
    {
        "school": "Dalton High School",
        "district": "Dalton Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505403980",
    },
    {
        "school": "Dalton Middle School",
        "district": "Dalton Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505403981",
    },
    {
        "school": "Green  Elementary School",
        "district": "Green Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505503984",
    },
    {
        "school": "Smithville High School",
        "district": "Green Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505503986",
    },
    {
        "school": "Norwayne Middle School",
        "district": "Norwayne Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505603988",
    },
    {
        "school": "Norwayne High School",
        "district": "Norwayne Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505603989",
    },
    {
        "school": "Norwayne Elementary School",
        "district": "Norwayne Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505603990",
    },
    {
        "school": "Apple Creek Elementary School",
        "district": "Southeast Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505803995",
    },
    {
        "school": "Fredericksburg Elementary School",
        "district": "Southeast Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505803996",
    },
    {
        "school": "John R Lea Middle School",
        "district": "Southeast Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505803998",
    },
    {
        "school": "Mount Eaton Elementary School",
        "district": "Southeast Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505803999",
    },
    {
        "school": "Waynedale High School",
        "district": "Southeast Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505804000",
    },
    {
        "school": "Shreve Elementary School",
        "district": "Triway Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505904002",
    },
    {
        "school": "Triway High School",
        "district": "Triway Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505904003",
    },
    {
        "school": "Triway Junior High School",
        "district": "Triway Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505904004",
    },
    {
        "school": "Wooster Twp Elementary School",
        "district": "Triway Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390505904005",
    },
    {
        "school": "Wayne County Schools Career Center",
        "district": "Wayne County JVSD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390517104095",
    },
    {
        "school": "Rittman High School",
        "district": "Rittman Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002802292",
    },
    {
        "school": "Rittman Middle School",
        "district": "Rittman Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002802293",
    },
    {
        "school": "Rittman Elementary School",
        "district": "Rittman Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002802294",
    },
    {
        "school": "Cornerstone Elementary School",
        "district": "Wooster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003200641",
    },
    {
        "school": "Edgewood Middle School",
        "district": "Wooster City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003202025",
    },
    {
        "school": "Kean Elementary School",
        "district": "Wooster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003202029",
    },
    {
        "school": "Melrose Elementary School",
        "district": "Wooster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003202030",
    },
    {
        "school": "Parkview Elementary School",
        "district": "Wooster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003202031",
    },
    {
        "school": "Wooster High School",
        "district": "Wooster City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003202033",
    },
    {
        "school": "Northwestern Middle School",
        "district": "Northwestern Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003303992",
    },
    {
        "school": "Northwestern High School",
        "district": "Northwestern Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003303993",
    },
    {
        "school": "Mahoning Unlimited Classroom",
        "district": "Mahoning Unlimited Classroom",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390014604758",
    },
    {
        "school": "Summit Academy-Youngstown",
        "district": "Summit Academy-Youngstown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390035004887",
    },
    {
        "school": "Summit Academy Secondary - Youngstown",
        "district": "Summit Academy Secondary - Youngstown",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390049805208",
    },
    {
        "school": "Youngstown Academy of Excellence",
        "district": "Youngstown Academy of Excellence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390058005072",
    },
    {
        "school": "Struthers Elementary School",
        "district": "Struthers City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448504556",
    },
    {
        "school": "Youngstown Rayen Early College High School",
        "district": "Youngstown City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451604934",
    },
    {
        "school": "Jackson-Milton Middle School",
        "district": "Jackson-Milton Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483204637",
    },
    {
        "school": "Summit Academy Alternative LearnersWarren Middle & Secondary",
        "district": "Summit Academy Alternative LearnersWarren Middle & Secondary",
        "level": "High",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390034404881",
    },
    {
        "school": "Summit Academy Community School-Warren",
        "district": "Summit Academy Community School-Warren",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390050005210",
    },
    {
        "school": "Girard Junior High School",
        "district": "Girard City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440604533",
    },
    {
        "school": "Knox Elementary School",
        "district": "West Branch Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483803233",
    },
    {
        "school": "Youngstown Community School",
        "district": "Youngstown Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390001701509",
    },
    {
        "school": "Memorial High School",
        "district": "Campbell City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437000233",
    },
    {
        "school": "Campbell Elementary School",
        "district": "Campbell City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437000234",
    },
    {
        "school": "Struthers Middle School",
        "district": "Struthers City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448501732",
    },
    {
        "school": "Struthers High School",
        "district": "Struthers City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448501736",
    },
    {
        "school": "Paul C Bunn Elementary School",
        "district": "Youngstown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451602062",
    },
    {
        "school": "Chaney High",
        "district": "Youngstown City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451602063",
    },
    {
        "school": "Harding Elementary School",
        "district": "Youngstown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451602069",
    },
    {
        "school": "M L King Elementary School",
        "district": "Youngstown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451602080",
    },
    {
        "school": "East High School",
        "district": "Youngstown City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451602082",
    },
    {
        "school": "Taft Elementary School",
        "district": "Youngstown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451602088",
    },
    {
        "school": "William Holmes McGuffey Elementary School",
        "district": "Youngstown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451602091",
    },
    {
        "school": "Williamson Elementary School",
        "district": "Youngstown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451602094",
    },
    {
        "school": "Choffin Career Cntr",
        "district": "Youngstown City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390451604268",
    },
    {
        "school": "Austintown Middle School",
        "district": "Austintown Local Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482903187",
    },
    {
        "school": "Fitch High School",
        "district": "Austintown Local Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482903189",
    },
    {
        "school": "Austintown Intermediate School",
        "district": "Austintown Local Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482903190",
    },
    {
        "school": "Austintown Elementary School",
        "district": "Austintown Local Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482903193",
    },
    {
        "school": "Boardman High School",
        "district": "Boardman Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483003195",
    },
    {
        "school": "Boardman Center Intermediate School",
        "district": "Boardman Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483003196",
    },
    {
        "school": "Boardman Glenwood Junior High",
        "district": "Boardman Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483003197",
    },
    {
        "school": "Robinwood Lane Elementary School",
        "district": "Boardman Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483003199",
    },
    {
        "school": "Stadium Drive Elementary School",
        "district": "Boardman Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483003200",
    },
    {
        "school": "West Boulevard Elementary School",
        "district": "Boardman Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483003201",
    },
    {
        "school": "C H Campbell Elementary School",
        "district": "Canfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483103202",
    },
    {
        "school": "Canfield High School",
        "district": "Canfield Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483103203",
    },
    {
        "school": "Canfield Village Middle School",
        "district": "Canfield Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483103205",
    },
    {
        "school": "Hilltop Elementary School",
        "district": "Canfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483103206",
    },
    {
        "school": "Jackson-Milton High School",
        "district": "Jackson-Milton Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483203208",
    },
    {
        "school": "Jackson-Milton Elementary School",
        "district": "Jackson-Milton Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483203209",
    },
    {
        "school": "Lowellville Elementary School",
        "district": "Lowellville Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483302723",
    },
    {
        "school": "Lowellville High School",
        "district": "Lowellville Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483303211",
    },
    {
        "school": "Poland Middle School",
        "district": "Poland Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483403216",
    },
    {
        "school": "Mckinley Elementary School",
        "district": "Poland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483403217",
    },
    {
        "school": "Poland Seminary High School",
        "district": "Poland Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483403218",
    },
    {
        "school": "Poland Union Elementary School",
        "district": "Poland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483403219",
    },
    {
        "school": "B L Miller Elementary School",
        "district": "Sebring Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483503220",
    },
    {
        "school": "Mckinley High School",
        "district": "Sebring Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483503222",
    },
    {
        "school": "South Range Elementary School",
        "district": "South Range Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483601030",
    },
    {
        "school": "South Range High School",
        "district": "South Range Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483603223",
    },
    {
        "school": "South Range Middle School",
        "district": "South Range Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483604247",
    },
    {
        "school": "Springfield Elementary School",
        "district": "Springfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483703227",
    },
    {
        "school": "Springfield High School",
        "district": "Springfield Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483703229",
    },
    {
        "school": "Springfield Intermediate Middle School",
        "district": "Springfield Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483703230",
    },
    {
        "school": "Damascus Elementary",
        "district": "West Branch Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483803231",
    },
    {
        "school": "West Branch Middle School",
        "district": "West Branch Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483803235",
    },
    {
        "school": "West Branch High School",
        "district": "West Branch Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483803236",
    },
    {
        "school": "Western Reserve Middle School",
        "district": "Western Reserve Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483903237",
    },
    {
        "school": "Western Reserve Elementary School",
        "district": "Western Reserve Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483903238",
    },
    {
        "school": "Western Reserve High School",
        "district": "Western Reserve Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390483903239",
    },
    {
        "school": "Mahoning Career & Technical",
        "district": "Mahoning Co Career & Tech Ctr",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390512404075",
    },
    {
        "school": "River Gate High School",
        "district": "River Gate High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390008403786",
    },
    {
        "school": "Girard Sr High School",
        "district": "Girard City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440601005",
    },
    {
        "school": "Prospect Elementary School",
        "district": "Girard City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440601007",
    },
    {
        "school": "Girard Intermediate Middle School",
        "district": "Girard City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440601009",
    },
    {
        "school": "Niles Middle School",
        "district": "Niles City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444901407",
    },
    {
        "school": "Niles Primary School",
        "district": "Niles City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444901411",
    },
    {
        "school": "McKinley High School",
        "district": "Niles City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444901412",
    },
    {
        "school": "Niles Intermediate School",
        "district": "Niles City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444901413",
    },
    {
        "school": "Warren G Harding High School",
        "district": "Warren City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449901922",
    },
    {
        "school": "Hubbard High School",
        "district": "Hubbard Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454202209",
    },
    {
        "school": "Hubbard Middle School",
        "district": "Hubbard Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454202210",
    },
    {
        "school": "Hubbard  Elementary School",
        "district": "Hubbard Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454202211",
    },
    {
        "school": "Newton Falls Elementary School",
        "district": "Newton Falls Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455602279",
    },
    {
        "school": "Newton Falls Middle School",
        "district": "Newton Falls Exempted Village",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455602280",
    },
    {
        "school": "Newton Falls High School",
        "district": "Newton Falls Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455602281",
    },
    {
        "school": "Newton Falls Junior High School",
        "district": "Newton Falls Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455602282",
    },
    {
        "school": "Bloomfield High School",
        "district": "Bloomfield-Mespo Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500903835",
    },
    {
        "school": "Mesopotamia Elementary School",
        "district": "Bloomfield-Mespo Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390500903836",
    },
    {
        "school": "Bristol Elementary School",
        "district": "Bristol Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501103837",
    },
    {
        "school": "Bristol High School",
        "district": "Bristol Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501103838",
    },
    {
        "school": "Brookfield High School",
        "district": "Brookfield Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501203840",
    },
    {
        "school": "Brookfield Middle School",
        "district": "Brookfield Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501203841",
    },
    {
        "school": "Champion High School",
        "district": "Champion Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501303844",
    },
    {
        "school": "Champion Middle School",
        "district": "Champion Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501303845",
    },
    {
        "school": "Champion Central Elementary School",
        "district": "Champion Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501303846",
    },
    {
        "school": "Baker Elementary School",
        "district": "Mathews Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501503850",
    },
    {
        "school": "Currie Elementary School",
        "district": "Mathews Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501503851",
    },
    {
        "school": "Mathews High School",
        "district": "Mathews Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501503852",
    },
    {
        "school": "Mathews Junior High School",
        "district": "Mathews Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501503853",
    },
    {
        "school": "Howland High School",
        "district": "Howland Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501603855",
    },
    {
        "school": "Howland Middle School",
        "district": "Howland Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501603856",
    },
    {
        "school": "Howland Glen Elementary School",
        "district": "Howland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501603857",
    },
    {
        "school": "Howland Springs Elementary School",
        "district": "Howland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501603858",
    },
    {
        "school": "Mines Elementary School",
        "district": "Howland Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501603859",
    },
    {
        "school": "North Rd Elementary School",
        "district": "Howland Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501603861",
    },
    {
        "school": "Badger High School",
        "district": "Joseph Badger Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501703862",
    },
    {
        "school": "Badger Elementary School",
        "district": "Joseph Badger Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501703863",
    },
    {
        "school": "Badger Middle School",
        "district": "Joseph Badger Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501703865",
    },
    {
        "school": "Lakeview Elementary School",
        "district": "Lakeview Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501803866",
    },
    {
        "school": "Lakeview High School",
        "district": "Lakeview Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501803868",
    },
    {
        "school": "Lakeview Middle School",
        "district": "Lakeview Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501803869",
    },
    {
        "school": "E J Blott Elementary School",
        "district": "Liberty Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501903870",
    },
    {
        "school": "Liberty High School",
        "district": "Liberty Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501903871",
    },
    {
        "school": "William S Guy Middle School",
        "district": "Liberty Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501903872",
    },
    {
        "school": "Lordstown Elementary School",
        "district": "Lordstown Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502003874",
    },
    {
        "school": "Lordstown High School",
        "district": "Lordstown Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502003875",
    },
    {
        "school": "Maplewood High School",
        "district": "Maplewood Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502103877",
    },
    {
        "school": "Maplewood Elementary School",
        "district": "Maplewood Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502103879",
    },
    {
        "school": "McDonald High School",
        "district": "McDonald Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502203880",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "McDonald Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502203881",
    },
    {
        "school": "Chalker High School",
        "district": "Southington Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502303882",
    },
    {
        "school": "Southington Elementary School",
        "district": "Southington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502303883",
    },
    {
        "school": "Southington Middle School",
        "district": "Southington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502304355",
    },
    {
        "school": "Bascom Elementary School",
        "district": "LaBrae Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502403884",
    },
    {
        "school": "LaBrae High School",
        "district": "LaBrae Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502403885",
    },
    {
        "school": "LaBrae Middle School",
        "district": "LaBrae Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502403887",
    },
    {
        "school": "LaBrae Intermediate School",
        "district": "LaBrae Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502403888",
    },
    {
        "school": "Mineral Ridge High School",
        "district": "Weathersfield Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502503889",
    },
    {
        "school": "Seaborn Elementary School",
        "district": "Weathersfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390502503891",
    },
    {
        "school": "Trumbull Career & Tech  Center",
        "district": "Trumbull Career & Tech Ctr",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390516304091",
    },
    {
        "school": "Brookfield Elementary School",
        "district": "Brookfield Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390501203842",
    },
    {
        "school": "Foxfire High School",
        "district": "Foxfire High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390023304789",
    },
    {
        "school": "National Road",
        "district": "Zanesville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451705123",
    },
    {
        "school": "Larry Miller Intermediate Elementary School",
        "district": "East Muskingum Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488304647",
    },
    {
        "school": "Maysville Elementary School",
        "district": "Maysville Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488504648",
    },
    {
        "school": "Pike Elementary School",
        "district": "East Muskingum Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488303419",
    },
    {
        "school": "Buffalo Campus",
        "district": "Mid-East Career and Technology Centers",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390513004077",
    },
    {
        "school": "Zanesville PreSchool",
        "district": "Zanesville City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451700771",
    },
    {
        "school": "John McIntire Elementary School",
        "district": "Zanesville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451702104",
    },
    {
        "school": "Zanesville Middle School",
        "district": "Zanesville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451702107",
    },
    {
        "school": "Zane Grey Elementary School",
        "district": "Zanesville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451702110",
    },
    {
        "school": "Zanesville High School",
        "district": "Zanesville City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451702111",
    },
    {
        "school": "East Muskingum Middle School",
        "district": "East Muskingum Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488303415",
    },
    {
        "school": "John Glenn High School",
        "district": "East Muskingum Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488303416",
    },
    {
        "school": "New Concord Elementary School",
        "district": "East Muskingum Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488303417",
    },
    {
        "school": "Perry Elementary School",
        "district": "East Muskingum Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488303418",
    },
    {
        "school": "Duncan Falls Elementary School",
        "district": "Franklin Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488403422",
    },
    {
        "school": "Philo Junior High School",
        "district": "Franklin Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488403423",
    },
    {
        "school": "Philo High School",
        "district": "Franklin Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488403425",
    },
    {
        "school": "Maysville High School",
        "district": "Maysville Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488503429",
    },
    {
        "school": "Maysville Middle School",
        "district": "Maysville Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488503430",
    },
    {
        "school": "Adamsville Elementary School",
        "district": "Tri-Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488703434",
    },
    {
        "school": "Frazeysburg Elementary School",
        "district": "Tri-Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488703435",
    },
    {
        "school": "Dresden Elementary School",
        "district": "Tri-Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488703436",
    },
    {
        "school": "Nashport Elementary School",
        "district": "Tri-Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488703437",
    },
    {
        "school": "Tri-Valley High School",
        "district": "Tri-Valley Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488703438",
    },
    {
        "school": "Tri-Valley Middle School",
        "district": "Tri-Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488704376",
    },
    {
        "school": "West Muskingum Elementary School",
        "district": "West Muskingum Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488803439",
    },
    {
        "school": "West Muskingum High School",
        "district": "West Muskingum Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488803443",
    },
    {
        "school": "West Muskingum Middle School",
        "district": "West Muskingum Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488803444",
    },
    {
        "school": "Zanesville Campus",
        "district": "Mid-East Career and Technology Centers",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390513004078",
    },
    {
        "school": "Roseville Elementary  School",
        "district": "Franklin Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488403426",
    },
    {
        "school": "STONE RIDGE ES",
        "district": "PIEDMONT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402397002391",
    },
    {
        "school": "TAHLEQUAH MS",
        "district": "TAHLEQUAH",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402938002401",
    },
    {
        "school": "CENTRAL MS",
        "district": "LAWTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725002393",
    },
    {
        "school": "TOMLINSON MS",
        "district": "LAWTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725002404",
    },
    {
        "school": "JEFFERSON HEIGHTS ES",
        "district": "SAPULPA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402691002406",
    },
    {
        "school": "CENTRAL ES",
        "district": "GUTHRIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401356002410",
    },
    {
        "school": "DIBBLE MS",
        "district": "DIBBLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400987002409",
    },
    {
        "school": "CHOUTEAU-MAZIE EC CTR",
        "district": "CHOUTEAU-MAZIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400767002398",
    },
    {
        "school": "ROSE UNION ES",
        "district": "DEER CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400957002384",
    },
    {
        "school": "WEST FIELD ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059002402",
    },
    {
        "school": "JOHN MARSHALL MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002394",
    },
    {
        "school": "JOHN MARSHALL HS",
        "district": "OKLAHOMA CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002407",
    },
    {
        "school": "ROSA PARKS ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060002400",
    },
    {
        "school": "HYDRO-EAKLY MS",
        "district": "HYDRO-EAKLY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400003202357",
    },
    {
        "school": "BOSWELL MS",
        "district": "BOSWELL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400504002369",
    },
    {
        "school": "KETCHUM MS",
        "district": "KETCHUM",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401638002359",
    },
    {
        "school": "PAULS VALLEY JHS",
        "district": "PAULS VALLEY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402355002372",
    },
    {
        "school": "LAKESIDE SCHOOL",
        "district": "LAKESIDE SCHOOL",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "OK",
        "nces_id": "400006302343",
    },
    {
        "school": "WAURIKA MS",
        "district": "WAURIKA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403198002366",
    },
    {
        "school": "EUFAULA ES",
        "district": "EUFAULA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401116002345",
    },
    {
        "school": "EUFAULA MS",
        "district": "EUFAULA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401116002346",
    },
    {
        "school": "OKLAHOMA SCHOOL FOR THE DEAF",
        "district": "OKLAHOMA SCHOOL FOR THE DEAF",
        "level": "Elementary",
        "type": "Special education school",
        "state": "OK",
        "nces_id": "400007502347",
    },
    {
        "school": "OKLAHOMA SCHOOL FOR THE DEAF",
        "district": "OKLAHOMA SCHOOL FOR THE DEAF",
        "level": "High",
        "type": "Special education school",
        "state": "OK",
        "nces_id": "400007502348",
    },
    {
        "school": "KONAWA MS",
        "district": "KONAWA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401671002360",
    },
    {
        "school": "CAVE SPRINGS ES",
        "district": "CAVE SPRINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400693000274",
    },
    {
        "school": "CAVE SPRINGS HS",
        "district": "CAVE SPRINGS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400693000275",
    },
    {
        "school": "DAHLONEGAH PUBLIC SCHOOL",
        "district": "DAHLONEGAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400936000401",
    },
    {
        "school": "PEAVINE PUBLIC SCHOOL",
        "district": "PEAVINE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401056000470",
    },
    {
        "school": "MARYETTA PUBLIC SCHOOL",
        "district": "MARYETTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401920000908",
    },
    {
        "school": "GREASY PUBLIC SCHOOL",
        "district": "GREASY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402187001091",
    },
    {
        "school": "ROCKY MOUNTAIN PUBLIC SCHOOL",
        "district": "ROCKY MOUNTAIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402625001381",
    },
    {
        "school": "STILWELL ES",
        "district": "STILWELL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402871001511",
    },
    {
        "school": "STILWELL HS",
        "district": "STILWELL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402871001512",
    },
    {
        "school": "STILWELL MS",
        "district": "STILWELL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402871001513",
    },
    {
        "school": "WATTS ES",
        "district": "WATTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403186001761",
    },
    {
        "school": "WATTS HS",
        "district": "WATTS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403186001762",
    },
    {
        "school": "WESTVILLE ES",
        "district": "WESTVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403240001794",
    },
    {
        "school": "WESTVILLE JHS",
        "district": "WESTVILLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403240001795",
    },
    {
        "school": "WESTVILLE HS",
        "district": "WESTVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403240029611",
    },
    {
        "school": "ZION PUBLIC SCHOOL",
        "district": "ZION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403360001853",
    },
    {
        "school": "TIMBERLAKE ES",
        "district": "TIMBERLAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400001301028",
    },
    {
        "school": "TIMBERLAKE HS",
        "district": "TIMBERLAKE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400001301101",
    },
    {
        "school": "ALINE-CLEO HS",
        "district": "ALINE-CLEO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400272000023",
    },
    {
        "school": "BURLINGTON ES",
        "district": "BURLINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400591000220",
    },
    {
        "school": "BURLINGTON HS",
        "district": "BURLINGTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400591000221",
    },
    {
        "school": "CHEROKEE ES",
        "district": "CHEROKEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400741000296",
    },
    {
        "school": "CHEROKEE HS",
        "district": "CHEROKEE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400741000297",
    },
    {
        "school": "ATOKA HS",
        "district": "ATOKA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400336000084",
    },
    {
        "school": "ATOKA ES",
        "district": "ATOKA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400336002110",
    },
    {
        "school": "CANEY ES",
        "district": "CANEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400642000250",
    },
    {
        "school": "CANEY HS",
        "district": "CANEY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400642029614",
    },
    {
        "school": "HARMONY PUBLIC SCHOOL",
        "district": "HARMONY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401383000653",
    },
    {
        "school": "LANE PUBLIC SCHOOL",
        "district": "LANE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401704000790",
    },
    {
        "school": "STRINGTOWN ES",
        "district": "STRINGTOWN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402901001521",
    },
    {
        "school": "STRINGTOWN HS",
        "district": "STRINGTOWN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402901001522",
    },
    {
        "school": "TUSHKA ES",
        "district": "TUSHKA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403036001690",
    },
    {
        "school": "TUSHKA HS",
        "district": "TUSHKA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403036029613",
    },
    {
        "school": "BALKO ES",
        "district": "BALKO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400351000089",
    },
    {
        "school": "BALKO HS",
        "district": "BALKO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400351000090",
    },
    {
        "school": "BEAVER ES",
        "district": "BEAVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400375000115",
    },
    {
        "school": "BEAVER HS",
        "district": "BEAVER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400375000116",
    },
    {
        "school": "FORGAN ES",
        "district": "FORGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401188000553",
    },
    {
        "school": "FORGAN HS",
        "district": "FORGAN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401188000554",
    },
    {
        "school": "TURPIN ES",
        "district": "TURPIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403033001688",
    },
    {
        "school": "TURPIN HS",
        "district": "TURPIN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403033001689",
    },
    {
        "school": "THOMAS ES",
        "district": "THOMAS-FAY-CUSTER UNIFIED DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400001501630",
    },
    {
        "school": "THOMAS-FAY-CUSTER UNIFIED JHS",
        "district": "THOMAS-FAY-CUSTER UNIFIED DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400001501641",
    },
    {
        "school": "THOMAS-FAY-CUSTER UNIFIED HS",
        "district": "THOMAS-FAY-CUSTER UNIFIED DIST",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400001501659",
    },
    {
        "school": "ELK CITY HS",
        "district": "ELK CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401074000495",
    },
    {
        "school": "ELK CITY MS",
        "district": "ELK CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401074000496",
    },
    {
        "school": "ELK CITY IES",
        "district": "ELK CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401074000498",
    },
    {
        "school": "ERICK ES",
        "district": "ERICK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401104000525",
    },
    {
        "school": "ERICK HS",
        "district": "ERICK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401104029615",
    },
    {
        "school": "MERRITT ES",
        "district": "MERRITT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401980000940",
    },
    {
        "school": "MERRITT HS",
        "district": "MERRITT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401980000941",
    },
    {
        "school": "SAYRE ES",
        "district": "SAYRE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402706001431",
    },
    {
        "school": "SAYRE HS",
        "district": "SAYRE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402706001432",
    },
    {
        "school": "SAYRE MS",
        "district": "SAYRE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402706002268",
    },
    {
        "school": "CANTON ES",
        "district": "CANTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400648000253",
    },
    {
        "school": "CANTON HS",
        "district": "CANTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400648000254",
    },
    {
        "school": "GEARY ES",
        "district": "GEARY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401257000587",
    },
    {
        "school": "GEARY MS",
        "district": "GEARY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401257000588",
    },
    {
        "school": "GEARY HS",
        "district": "GEARY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401257029617",
    },
    {
        "school": "OKEENE JR-SR HS (JR)",
        "district": "OKEENE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402265000054",
    },
    {
        "school": "OKEENE ES",
        "district": "OKEENE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402265001108",
    },
    {
        "school": "OKEENE JR-SR HS (SR)",
        "district": "OKEENE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402265029616",
    },
    {
        "school": "WATONGA ES",
        "district": "WATONGA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403177001757",
    },
    {
        "school": "WATONGA HS",
        "district": "WATONGA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403177001758",
    },
    {
        "school": "WATONGA MS",
        "district": "WATONGA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403177001759",
    },
    {
        "school": "HYDRO-EAKLY ES",
        "district": "HYDRO-EAKLY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400003202283",
    },
    {
        "school": "HYDRO-EAKLY HS",
        "district": "HYDRO-EAKLY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400003202286",
    },
    {
        "school": "ANADARKO HS",
        "district": "ANADARKO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400300000050",
    },
    {
        "school": "ANADARKO EAST ES",
        "district": "ANADARKO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400300000051",
    },
    {
        "school": "SUNSET ES",
        "district": "ANADARKO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400300000053",
    },
    {
        "school": "MISSION ES",
        "district": "ANADARKO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400300000055",
    },
    {
        "school": "ANADARKO MS",
        "district": "ANADARKO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400300002101",
    },
    {
        "school": "APACHE ES",
        "district": "BOONE-APACHE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400501005010",
    },
    {
        "school": "APACHE MS",
        "district": "BOONE-APACHE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400501005012",
    },
    {
        "school": "APACHE HS",
        "district": "BOONE-APACHE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400501005013",
    },
    {
        "school": "CARNEGIE ES",
        "district": "CARNEGIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400663000258",
    },
    {
        "school": "CARNEGIE HS",
        "district": "CARNEGIE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400663000259",
    },
    {
        "school": "CEMENT ES",
        "district": "CEMENT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400696000276",
    },
    {
        "school": "CEMENT HS",
        "district": "CEMENT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400696029625",
    },
    {
        "school": "CYRIL ES",
        "district": "CYRIL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400930000397",
    },
    {
        "school": "CYRIL HS",
        "district": "CYRIL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400930029624",
    },
    {
        "school": "GRACEMONT ES",
        "district": "GRACEMONT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401308000606",
    },
    {
        "school": "GRACEMONT HS",
        "district": "GRACEMONT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401308000607",
    },
    {
        "school": "HINTON MS",
        "district": "HINTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401461000096",
    },
    {
        "school": "HINTON ES",
        "district": "HINTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401461000684",
    },
    {
        "school": "HINTON HS",
        "district": "HINTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401461000685",
    },
    {
        "school": "LOOKEBA-SICKLES ES",
        "district": "LOOKEBA SICKLES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401839000876",
    },
    {
        "school": "LOOKEBA-SICKLES HS",
        "district": "LOOKEBA SICKLES",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401839000877",
    },
    {
        "school": "FORT COBB-BROXTON MS",
        "district": "FORT COBB-BROXTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403360201597",
    },
    {
        "school": "FORT COBB-BROXTON LOWER ES",
        "district": "FORT COBB-BROXTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403360229842",
    },
    {
        "school": "FORT COBB-BROXTON HS",
        "district": "FORT COBB-BROXTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403360229844",
    },
    {
        "school": "BINGER-ONEY ES",
        "district": "BINGER-ONEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403360329845",
    },
    {
        "school": "BINGER-ONEY HS",
        "district": "BINGER-ONEY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403360329846",
    },
    {
        "school": "BOSWELL ES",
        "district": "BOSWELL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400504000177",
    },
    {
        "school": "BOSWELL HS",
        "district": "BOSWELL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400504029640",
    },
    {
        "school": "FORT TOWSON ES",
        "district": "FORT TOWSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401230000577",
    },
    {
        "school": "FORT TOWSON HS",
        "district": "FORT TOWSON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401230000578",
    },
    {
        "school": "HUGO HS",
        "district": "HUGO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401521000713",
    },
    {
        "school": "SOPER ES",
        "district": "SOPER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402796001484",
    },
    {
        "school": "SOPER HS",
        "district": "SOPER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402796001485",
    },
    {
        "school": "BOISE CITY ES",
        "district": "BOISE CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400486000166",
    },
    {
        "school": "BOISE CITY HS",
        "district": "BOISE CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400486000167",
    },
    {
        "school": "FELT HS",
        "district": "FELT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401158000546",
    },
    {
        "school": "FELT ES",
        "district": "FELT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401158000547",
    },
    {
        "school": "KEYES ES",
        "district": "KEYES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401641000763",
    },
    {
        "school": "KEYES HS",
        "district": "KEYES",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401641000764",
    },
    {
        "school": "EMERSON ES",
        "district": "COALGATE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400813000341",
    },
    {
        "school": "WALLACE BYRD MS",
        "district": "COALGATE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400813001958",
    },
    {
        "school": "COALGATE HS",
        "district": "COALGATE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400813002063",
    },
    {
        "school": "COTTONWOOD PUBLIC SCHOOL",
        "district": "COTTONWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400873000369",
    },
    {
        "school": "TUPELO ES",
        "district": "TUPELO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403027001683",
    },
    {
        "school": "TUPELO HS",
        "district": "TUPELO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403027001684",
    },
    {
        "school": "BIG PASTURE ES",
        "district": "BIG PASTURE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400435000138",
    },
    {
        "school": "BIG PASTURE HS",
        "district": "BIG PASTURE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400435000139",
    },
    {
        "school": "TEMPLE ES",
        "district": "TEMPLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402964001557",
    },
    {
        "school": "TEMPLE HS",
        "district": "TEMPLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402964029651",
    },
    {
        "school": "WALTERS ES",
        "district": "WALTERS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403147001742",
    },
    {
        "school": "WALTERS HS",
        "district": "WALTERS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403147001743",
    },
    {
        "school": "WALTERS MS",
        "district": "WALTERS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403147029649",
    },
    {
        "school": "BLUEJACKET ES",
        "district": "BLUEJACKET",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400483000164",
    },
    {
        "school": "BLUEJACKET HS",
        "district": "BLUEJACKET",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400483000165",
    },
    {
        "school": "BLUEJACKET MS",
        "district": "BLUEJACKET",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400483002082",
    },
    {
        "school": "KETCHUM ES",
        "district": "KETCHUM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401638000760",
    },
    {
        "school": "KETCHUM HS",
        "district": "KETCHUM",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401638000761",
    },
    {
        "school": "VINITA HS",
        "district": "VINITA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403129001729",
    },
    {
        "school": "EWING HALSELL MS",
        "district": "VINITA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403129001732",
    },
    {
        "school": "VINITA ES",
        "district": "VINITA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403129001733",
    },
    {
        "school": "WELCH ES",
        "district": "WELCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403219001781",
    },
    {
        "school": "WELCH MS",
        "district": "WELCH",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403219001782",
    },
    {
        "school": "WELCH HS",
        "district": "WELCH",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403219029652",
    },
    {
        "school": "WHITE OAK PUBLIC SCHOOL",
        "district": "WHITE OAK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403261001802",
    },
    {
        "school": "ARAPAHO-BUTLER ES",
        "district": "ARAPAHO-BUTLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400312000063",
    },
    {
        "school": "ARAPAHO-BUTLER HS",
        "district": "ARAPAHO-BUTLER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400312029657",
    },
    {
        "school": "NANCE ES",
        "district": "CLINTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400807000336",
    },
    {
        "school": "SOUTHWEST ES",
        "district": "CLINTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400807000337",
    },
    {
        "school": "WASHINGTON ES",
        "district": "CLINTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400807000338",
    },
    {
        "school": "CLINTON MS",
        "district": "CLINTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400807000339",
    },
    {
        "school": "WEATHERFORD EAST ES",
        "district": "WEATHERFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403207001774",
    },
    {
        "school": "WEATHERFORD HS",
        "district": "WEATHERFORD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403207001776",
    },
    {
        "school": "WEATHERFORD WEST ES",
        "district": "WEATHERFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403207029659",
    },
    {
        "school": "BURCHAM ES",
        "district": "WEATHERFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403207029660",
    },
    {
        "school": "WEATHERFORD MS",
        "district": "WEATHERFORD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403207029848",
    },
    {
        "school": "COLCORD ES",
        "district": "COLCORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400825000345",
    },
    {
        "school": "COLCORD HS",
        "district": "COLCORD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400825029663",
    },
    {
        "school": "GROVE UPPER ES",
        "district": "GROVE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401353000625",
    },
    {
        "school": "GROVE HS",
        "district": "GROVE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401353000626",
    },
    {
        "school": "GROVE MS",
        "district": "GROVE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401353000627",
    },
    {
        "school": "GROVE LOWER ES",
        "district": "GROVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401353001661",
    },
    {
        "school": "JAY ES",
        "district": "JAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401569000735",
    },
    {
        "school": "JAY HS",
        "district": "JAY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401569000736",
    },
    {
        "school": "JAY MS",
        "district": "JAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401569000737",
    },
    {
        "school": "KANSAS ES",
        "district": "KANSAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401599000750",
    },
    {
        "school": "KANSAS MS",
        "district": "KANSAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401599002269",
    },
    {
        "school": "KANSAS HS",
        "district": "KANSAS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401599029662",
    },
    {
        "school": "KENWOOD PUBLIC SCHOOL",
        "district": "KENWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401632000756",
    },
    {
        "school": "LEACH PUBLIC SCHOOL",
        "district": "LEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401731000843",
    },
    {
        "school": "MOSELEY PUBLIC SCHOOL",
        "district": "MOSELEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402043001012",
    },
    {
        "school": "OAKS-MISSION ES",
        "district": "OAKS-MISSION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402241001099",
    },
    {
        "school": "OAKS-MISSION HS",
        "district": "OAKS-MISSION",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402241001100",
    },
    {
        "school": "SEILING ES",
        "district": "SEILING",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402724001437",
    },
    {
        "school": "SEILING JR-SR HS (JR)",
        "district": "SEILING",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402724001438",
    },
    {
        "school": "SEILING JR-SR HS (SR)",
        "district": "SEILING",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402724029665",
    },
    {
        "school": "TALOGA ES",
        "district": "TALOGA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402943001549",
    },
    {
        "school": "TALOGA HS",
        "district": "TALOGA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402943001550",
    },
    {
        "school": "VICI ES",
        "district": "VICI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403117001727",
    },
    {
        "school": "VICI HS",
        "district": "VICI",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403117029664",
    },
    {
        "school": "ARNETT ES",
        "district": "ARNETT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400324000077",
    },
    {
        "school": "ARNETT HS",
        "district": "ARNETT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400324000078",
    },
    {
        "school": "FARGO ES",
        "district": "FARGO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401143000542",
    },
    {
        "school": "FARGO HS",
        "district": "FARGO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401143000543",
    },
    {
        "school": "SHATTUCK ES",
        "district": "SHATTUCK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402754001452",
    },
    {
        "school": "SHATTUCK HS",
        "district": "SHATTUCK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402754001453",
    },
    {
        "school": "ELMORE CITY-PERNELL ES",
        "district": "ELMORE CITY-PERNELL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401086000502",
    },
    {
        "school": "SENIOR HS",
        "district": "ELMORE CITY-PERNELL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401086029670",
    },
    {
        "school": "LINDSAY ES",
        "district": "LINDSAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401785000862",
    },
    {
        "school": "LINDSAY HS",
        "district": "LINDSAY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401785000863",
    },
    {
        "school": "LINDSAY MS",
        "district": "LINDSAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401785017850",
    },
    {
        "school": "MAYSVILLE ES",
        "district": "MAYSVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401938000913",
    },
    {
        "school": "MAYSVILLE HS",
        "district": "MAYSVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401938029669",
    },
    {
        "school": "PAOLI ES",
        "district": "PAOLI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402343001244",
    },
    {
        "school": "PAOLI HS",
        "district": "PAOLI",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402343001245",
    },
    {
        "school": "JACKSON ES",
        "district": "PAULS VALLEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402355001247",
    },
    {
        "school": "LEE ES",
        "district": "PAULS VALLEY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402355001248",
    },
    {
        "school": "PAULS VALLEY HS",
        "district": "PAULS VALLEY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402355001870",
    },
    {
        "school": "JEFFERSON EARLY LRNING CTR",
        "district": "PAULS VALLEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402355002123",
    },
    {
        "school": "STRATFORD ES",
        "district": "STRATFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402898001519",
    },
    {
        "school": "STRATFORD HS",
        "district": "STRATFORD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402898029668",
    },
    {
        "school": "WHITEBEAD PUBLIC SCHOOL",
        "district": "WHITEBEAD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403267001805",
    },
    {
        "school": "CENTRAL ES",
        "district": "WYNNEWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403330001833",
    },
    {
        "school": "WYNNEWOOD HS",
        "district": "WYNNEWOOD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403330001834",
    },
    {
        "school": "WYNNEWOOD MS",
        "district": "WYNNEWOOD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403330001835",
    },
    {
        "school": "DEER CREEK-LAMONT ES",
        "district": "DEER CREEK-LAMONT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401702000788",
    },
    {
        "school": "DEER CREEK-LAMONT HS",
        "district": "DEER CREEK-LAMONT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401702000789",
    },
    {
        "school": "MEDFORD ES",
        "district": "MEDFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401962000934",
    },
    {
        "school": "MEDFORD HS",
        "district": "MEDFORD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401962000935",
    },
    {
        "school": "POND CREEK-HUNTER ES",
        "district": "POND CREEK-HUNTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402472001302",
    },
    {
        "school": "POND CREEK-HUNTER HS",
        "district": "POND CREEK-HUNTER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402472001303",
    },
    {
        "school": "GRANITE ES",
        "district": "GRANITE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401329000616",
    },
    {
        "school": "GRANITE HS",
        "district": "GRANITE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401329029682",
    },
    {
        "school": "EDISON ES",
        "district": "MANGUM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401878000889",
    },
    {
        "school": "MANGUM HS",
        "district": "MANGUM",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401878000890",
    },
    {
        "school": "MANGUM MS",
        "district": "MANGUM",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401878002321",
    },
    {
        "school": "HOLLIS ES",
        "district": "HOLLIS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401485000699",
    },
    {
        "school": "HOLLIS HS",
        "district": "HOLLIS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401485000700",
    },
    {
        "school": "HOLLIS MS",
        "district": "HOLLIS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401485000701",
    },
    {
        "school": "BUFFALO ES",
        "district": "BUFFALO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400576000215",
    },
    {
        "school": "BUFFALO HS",
        "district": "BUFFALO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400576029684",
    },
    {
        "school": "LAVERNE ES",
        "district": "LAVERNE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401722000795",
    },
    {
        "school": "LAVERNE HS",
        "district": "LAVERNE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401722000796",
    },
    {
        "school": "KEOTA ES",
        "district": "KEOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401635000757",
    },
    {
        "school": "KEOTA HS",
        "district": "KEOTA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401635000758",
    },
    {
        "school": "KINTA HS",
        "district": "KINTA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401662000306",
    },
    {
        "school": "KINTA ES",
        "district": "KINTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401662000775",
    },
    {
        "school": "MCCURTAIN ES",
        "district": "MCCURTAIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401941000915",
    },
    {
        "school": "MCCURTAIN HS",
        "district": "MCCURTAIN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401941000916",
    },
    {
        "school": "STIGLER ES",
        "district": "STIGLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402865001502",
    },
    {
        "school": "STIGLER HS",
        "district": "STIGLER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402865001503",
    },
    {
        "school": "STIGLER MS",
        "district": "STIGLER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402865001504",
    },
    {
        "school": "WHITEFIELD PUBLIC SCHOOL",
        "district": "WHITEFIELD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403270001806",
    },
    {
        "school": "CALVIN ES",
        "district": "CALVIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400627000243",
    },
    {
        "school": "CALVIN HS",
        "district": "CALVIN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400627000244",
    },
    {
        "school": "HOLDENVILLE HS",
        "district": "HOLDENVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401479000694",
    },
    {
        "school": "ETHEL REED ES",
        "district": "HOLDENVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401479000696",
    },
    {
        "school": "MOSS ES",
        "district": "MOSS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402046001013",
    },
    {
        "school": "MOSS HS",
        "district": "MOSS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402046001014",
    },
    {
        "school": "STUART ES",
        "district": "STUART",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402910001530",
    },
    {
        "school": "STUART HS",
        "district": "STUART",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402910001531",
    },
    {
        "school": "WETUMKA ES",
        "district": "WETUMKA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403243001796",
    },
    {
        "school": "WETUMKA HS",
        "district": "WETUMKA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403243001797",
    },
    {
        "school": "RINGLING ES",
        "district": "RINGLING",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402586001372",
    },
    {
        "school": "RINGLING HS",
        "district": "RINGLING",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402586001373",
    },
    {
        "school": "RINGLING JHS",
        "district": "RINGLING",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402586001374",
    },
    {
        "school": "RYAN ES",
        "district": "RYAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402661001393",
    },
    {
        "school": "RYAN HS",
        "district": "RYAN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402661001394",
    },
    {
        "school": "TERRAL PUBLIC SCHOOL",
        "district": "TERRAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402976002008",
    },
    {
        "school": "WAURIKA ES",
        "district": "WAURIKA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403198001766",
    },
    {
        "school": "WAURIKA HS",
        "district": "WAURIKA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403198001767",
    },
    {
        "school": "COLEMAN ES",
        "district": "COLEMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400831000347",
    },
    {
        "school": "COLEMAN HS",
        "district": "COLEMAN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400831000348",
    },
    {
        "school": "MANNSVILLE PUBLIC SCHOOL",
        "district": "MANNSVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401887000896",
    },
    {
        "school": "MILBURN ES",
        "district": "MILBURN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401998000976",
    },
    {
        "school": "MILBURN HS",
        "district": "MILBURN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401998000977",
    },
    {
        "school": "MILL CREEK ES",
        "district": "MILL CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402004000979",
    },
    {
        "school": "MILL CREEK HS",
        "district": "MILL CREEK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402004000980",
    },
    {
        "school": "RAVIA PUBLIC SCHOOL",
        "district": "RAVIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402553001364",
    },
    {
        "school": "TISHOMINGO ES",
        "district": "TISHOMINGO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403006001572",
    },
    {
        "school": "TISHOMINGO HS",
        "district": "TISHOMINGO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403006001573",
    },
    {
        "school": "TISHOMINGO MS",
        "district": "TISHOMINGO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403006001574",
    },
    {
        "school": "WAPANUCKA ES",
        "district": "WAPANUCKA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403159001748",
    },
    {
        "school": "WAPANUCKA HS",
        "district": "WAPANUCKA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403159001749",
    },
    {
        "school": "CASHION ES",
        "district": "CASHION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400681000267",
    },
    {
        "school": "CASHION HS",
        "district": "CASHION",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400681000268",
    },
    {
        "school": "DOVER ES",
        "district": "DOVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401005000436",
    },
    {
        "school": "DOVER HS",
        "district": "DOVER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401005000437",
    },
    {
        "school": "HENNESSEY LOWER ES",
        "district": "HENNESSEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401434000676",
    },
    {
        "school": "HENNESSEY HS",
        "district": "HENNESSEY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401434000678",
    },
    {
        "school": "HENNESSEY UPPER ES",
        "district": "HENNESSEY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401434001917",
    },
    {
        "school": "KINGFISHER HS",
        "district": "KINGFISHER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401656000771",
    },
    {
        "school": "KINGFISHER MS",
        "district": "KINGFISHER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401656001879",
    },
    {
        "school": "GILMOUR ES",
        "district": "KINGFISHER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401656001996",
    },
    {
        "school": "OKARCHE ES",
        "district": "OKARCHE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402259001104",
    },
    {
        "school": "OKARCHE HS",
        "district": "OKARCHE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402259001105",
    },
    {
        "school": "OKARCHE JHS",
        "district": "OKARCHE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402259029687",
    },
    {
        "school": "LOMEGA ES",
        "district": "LOMEGA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402295001223",
    },
    {
        "school": "LOMEGA HS",
        "district": "LOMEGA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402295001224",
    },
    {
        "school": "HOBART HS",
        "district": "HOBART",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401470000691",
    },
    {
        "school": "HOBART MS",
        "district": "HOBART",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401470000692",
    },
    {
        "school": "HOBART ES",
        "district": "HOBART",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401470002237",
    },
    {
        "school": "LONE WOLF ES",
        "district": "LONE WOLF",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401827000873",
    },
    {
        "school": "LONE WOLF HS",
        "district": "LONE WOLF",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401827000874",
    },
    {
        "school": "SNYDER ES",
        "district": "SNYDER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402793001481",
    },
    {
        "school": "SNYDER HS",
        "district": "SNYDER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402793001482",
    },
    {
        "school": "JOHN D MOELLER ES",
        "district": "SNYDER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402793002085",
    },
    {
        "school": "MOUNTAIN VIEW-GOTEBO ES",
        "district": "MOUNTAIN VIEW-GOTEBO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402988602106",
    },
    {
        "school": "MOUNTAIN VIEW-GOTEBO HS",
        "district": "MOUNTAIN VIEW-GOTEBO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402988629691",
    },
    {
        "school": "BUFFALO VALLEY ES",
        "district": "BUFFALO VALLEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400582000217",
    },
    {
        "school": "BUFFALO VALLEY HS",
        "district": "BUFFALO VALLEY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400582029692",
    },
    {
        "school": "PANOLA ES",
        "district": "PANOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402340001242",
    },
    {
        "school": "PANOLA HS",
        "district": "PANOLA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402340001243",
    },
    {
        "school": "RED OAK ES",
        "district": "RED OAK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402559001365",
    },
    {
        "school": "RED OAK HS",
        "district": "RED OAK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402559001366",
    },
    {
        "school": "WILBURTON ES",
        "district": "WILBURTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403279001810",
    },
    {
        "school": "WILBURTON HS",
        "district": "WILBURTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403279001811",
    },
    {
        "school": "BATTIEST ES",
        "district": "BATTIEST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400366000112",
    },
    {
        "school": "BATTIEST HS",
        "district": "BATTIEST",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400366029703",
    },
    {
        "school": "BENNETT ES",
        "district": "BROKEN BOW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400552000208",
    },
    {
        "school": "BROKEN BOW HS",
        "district": "BROKEN BOW",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400552000209",
    },
    {
        "school": "RECTOR JOHNSON MS",
        "district": "BROKEN BOW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400552000211",
    },
    {
        "school": "DIERKS ES",
        "district": "BROKEN BOW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400552029704",
    },
    {
        "school": "DENISON PUBLIC SCHOOL",
        "district": "DENISON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400972000417",
    },
    {
        "school": "EAGLETOWN ES",
        "district": "EAGLETOWN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401044000464",
    },
    {
        "school": "EAGLETOWN HS",
        "district": "EAGLETOWN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401044000465",
    },
    {
        "school": "FOREST GROVE PUBLIC SCHOOL",
        "district": "FOREST GROVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401185000552",
    },
    {
        "school": "GLOVER PUBLIC SCHOOL",
        "district": "GLOVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401275000595",
    },
    {
        "school": "HAWORTH ES",
        "district": "HAWORTH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401408000662",
    },
    {
        "school": "HAWORTH HS",
        "district": "HAWORTH",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401408000663",
    },
    {
        "school": "HAWORTH MS",
        "district": "HAWORTH",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401408000664",
    },
    {
        "school": "HOLLY CREEK PUBLIC SCHOOL",
        "district": "HOLLY CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401489000702",
    },
    {
        "school": "IDABEL PRIMARY SOUTH ES",
        "district": "IDABEL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401537000566",
    },
    {
        "school": "CENTRAL ES",
        "district": "IDABEL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401537000721",
    },
    {
        "school": "IDABEL HS",
        "district": "IDABEL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401537000723",
    },
    {
        "school": "IDABEL MS",
        "district": "IDABEL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401537000724",
    },
    {
        "school": "LUKFATA PUBLIC SCHOOL",
        "district": "LUKFATA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401857000881",
    },
    {
        "school": "SMITHVILLE ES",
        "district": "SMITHVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402784001478",
    },
    {
        "school": "SMITHVILLE HS",
        "district": "SMITHVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402784001479",
    },
    {
        "school": "SMITHVILLE MS",
        "district": "SMITHVILLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402784001855",
    },
    {
        "school": "VALLIANT ES",
        "district": "VALLIANT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403087001710",
    },
    {
        "school": "VALLIANT MS",
        "district": "VALLIANT",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403087001712",
    },
    {
        "school": "VALLIANT HS",
        "district": "VALLIANT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403087029700",
    },
    {
        "school": "WRIGHT CITY ES",
        "district": "WRIGHT CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403321001829",
    },
    {
        "school": "WRIGHT CITY JHS",
        "district": "WRIGHT CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403321029701",
    },
    {
        "school": "WRIGHT CITY HS",
        "district": "WRIGHT CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403321029702",
    },
    {
        "school": "MARSHALL ES",
        "district": "CHECOTAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400735000289",
    },
    {
        "school": "CHECOTAH HS",
        "district": "CHECOTAH",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400735000290",
    },
    {
        "school": "CHECOTAH INTERMEDIATE ES",
        "district": "CHECOTAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400735000571",
    },
    {
        "school": "CHECOTAH MS",
        "district": "CHECOTAH",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400735001859",
    },
    {
        "school": "EUFAULA HS",
        "district": "EUFAULA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401116000529",
    },
    {
        "school": "HANNA ES",
        "district": "HANNA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401368000649",
    },
    {
        "school": "HANNA HS",
        "district": "HANNA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401368000650",
    },
    {
        "school": "MIDWAY ES",
        "district": "MIDWAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401467000687",
    },
    {
        "school": "MIDWAY HS",
        "district": "MIDWAY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401467000688",
    },
    {
        "school": "RYAL PUBLIC SCHOOL",
        "district": "RYAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402658001392",
    },
    {
        "school": "STIDHAM PUBLIC SCHOOL",
        "district": "STIDHAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402862001501",
    },
    {
        "school": "ALINE-CLEO ES",
        "district": "ALINE-CLEO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400272000022",
    },
    {
        "school": "CHAMBERLAIN MS",
        "district": "FAIRVIEW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401128000537",
    },
    {
        "school": "CORNELSEN ES",
        "district": "FAIRVIEW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401128000538",
    },
    {
        "school": "FAIRVIEW HS",
        "district": "FAIRVIEW",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401128000539",
    },
    {
        "school": "RINGWOOD ES",
        "district": "RINGWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402592001375",
    },
    {
        "school": "RINGWOOD HS",
        "district": "RINGWOOD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402592001376",
    },
    {
        "school": "KINGSTON ES",
        "district": "KINGSTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401659000773",
    },
    {
        "school": "KINGSTON HS",
        "district": "KINGSTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401659000774",
    },
    {
        "school": "KINGSTON MS",
        "district": "KINGSTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401659001948",
    },
    {
        "school": "MADILL ES",
        "district": "MADILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401870000886",
    },
    {
        "school": "MADILL HS",
        "district": "MADILL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401870000887",
    },
    {
        "school": "MADILL MS",
        "district": "MADILL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401870000888",
    },
    {
        "school": "ADAIR HS",
        "district": "ADAIR",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400246000009",
    },
    {
        "school": "ADAIR MS",
        "district": "ADAIR",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400246000010",
    },
    {
        "school": "BERNITA HUGHES ES",
        "district": "ADAIR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400246000011",
    },
    {
        "school": "CHOUTEAU ES",
        "district": "CHOUTEAU-MAZIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400767000316",
    },
    {
        "school": "CHOUTEAU-MAZIE HS",
        "district": "CHOUTEAU-MAZIE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400767000317",
    },
    {
        "school": "CHOUTEAU-MAZIE MS",
        "district": "CHOUTEAU-MAZIE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400767000318",
    },
    {
        "school": "MAZIE ES",
        "district": "CHOUTEAU-MAZIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400767000319",
    },
    {
        "school": "LOCUST GROVE EARLY LRNING CTR",
        "district": "LOCUST GROVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401800000866",
    },
    {
        "school": "LOCUST GROVE HS",
        "district": "LOCUST GROVE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401800000867",
    },
    {
        "school": "LOCUST GROVE MS",
        "district": "LOCUST GROVE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401800000868",
    },
    {
        "school": "LOCUST GROVE UPPER ES",
        "district": "LOCUST GROVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401800002323",
    },
    {
        "school": "OSAGE PUBLIC SCHOOL",
        "district": "OSAGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402319001231",
    },
    {
        "school": "JEFFERSON ES",
        "district": "PRYOR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402520001320",
    },
    {
        "school": "LINCOLN ES",
        "district": "PRYOR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402520001321",
    },
    {
        "school": "PRYOR HS",
        "district": "PRYOR",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402520001322",
    },
    {
        "school": "PRYOR JHS",
        "district": "PRYOR",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402520001323",
    },
    {
        "school": "ROOSEVELT ES",
        "district": "PRYOR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402520001324",
    },
    {
        "school": "SALINA ES",
        "district": "SALINA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402673001397",
    },
    {
        "school": "SALINA MS",
        "district": "SALINA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402673002005",
    },
    {
        "school": "SALINA HS",
        "district": "SALINA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402673002075",
    },
    {
        "school": "WICKLIFFE PUBLIC SCHOOL",
        "district": "WICKLIFFE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403276001809",
    },
    {
        "school": "DAVIS ES",
        "district": "DAVIS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400951000409",
    },
    {
        "school": "DAVIS HS",
        "district": "DAVIS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400951000410",
    },
    {
        "school": "DAVIS MS",
        "district": "DAVIS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400951000411",
    },
    {
        "school": "SULPHUR INTERMEDIATE ES",
        "district": "SULPHUR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402916001166",
    },
    {
        "school": "SULPHUR ES",
        "district": "SULPHUR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402916001533",
    },
    {
        "school": "SULPHUR HS",
        "district": "SULPHUR",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402916001534",
    },
    {
        "school": "FRONTIER ES",
        "district": "FRONTIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400002025620",
    },
    {
        "school": "FRONTIER HS",
        "district": "FRONTIER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400002029709",
    },
    {
        "school": "BILLINGS ES",
        "district": "BILLINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400436000140",
    },
    {
        "school": "BILLINGS HS",
        "district": "BILLINGS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400436000141",
    },
    {
        "school": "MORRISON ES",
        "district": "MORRISON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402034001010",
    },
    {
        "school": "MORRISON HS",
        "district": "MORRISON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402034001011",
    },
    {
        "school": "PERRY ES",
        "district": "PERRY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402385001265",
    },
    {
        "school": "PERRY HS",
        "district": "PERRY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402385001266",
    },
    {
        "school": "OKLAHOMA UNION ES",
        "district": "OKLAHOMA UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400002100848",
    },
    {
        "school": "OKLAHOMA UNION MS",
        "district": "OKLAHOMA UNION",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400002102290",
    },
    {
        "school": "OKLAHOMA UNION HS",
        "district": "OKLAHOMA UNION",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400002129712",
    },
    {
        "school": "NOWATA ES",
        "district": "NOWATA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402193001093",
    },
    {
        "school": "NOWATA HS",
        "district": "NOWATA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402193001094",
    },
    {
        "school": "NOWATA MS",
        "district": "NOWATA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402193001095",
    },
    {
        "school": "SOUTH COFFEYVILLE ES",
        "district": "SOUTH COFFEYVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402664001395",
    },
    {
        "school": "SOUTH COFFEYVILLE HS",
        "district": "SOUTH COFFEYVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402664001860",
    },
    {
        "school": "BEARDEN PUBLIC SCHOOL",
        "district": "BEARDEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400369000114",
    },
    {
        "school": "OAKES ES",
        "district": "OKEMAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400685001110",
    },
    {
        "school": "OKEMAH HS",
        "district": "OKEMAH",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400685001111",
    },
    {
        "school": "OKEMAH MS",
        "district": "OKEMAH",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400685001901",
    },
    {
        "school": "MASON ES",
        "district": "MASON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401926000909",
    },
    {
        "school": "MASON HS",
        "district": "MASON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401926000910",
    },
    {
        "school": "PADEN ES",
        "district": "PADEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402334001237",
    },
    {
        "school": "PADEN HS",
        "district": "PADEN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402334001238",
    },
    {
        "school": "WELEETKA JHS",
        "district": "WELEETKA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403222001180",
    },
    {
        "school": "WELEETKA HS",
        "district": "WELEETKA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403222001784",
    },
    {
        "school": "SPENCE MEMORIAL ES",
        "district": "WELEETKA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403222029714",
    },
    {
        "school": "ALBION PUBLIC SCHOOL",
        "district": "ALBION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400258000017",
    },
    {
        "school": "ANTLERS HS",
        "district": "ANTLERS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400306000057",
    },
    {
        "school": "BRANTLY ES",
        "district": "ANTLERS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400306000058",
    },
    {
        "school": "OBUCH MS",
        "district": "ANTLERS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400306000762",
    },
    {
        "school": "CRAIN ES",
        "district": "CLAYTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400780000327",
    },
    {
        "school": "CLAYTON HS",
        "district": "CLAYTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400780000328",
    },
    {
        "school": "MOYERS ES",
        "district": "MOYERS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402064002091",
    },
    {
        "school": "MOYERS HS",
        "district": "MOYERS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402064002092",
    },
    {
        "school": "NASHOBA PUBLIC SCHOOL",
        "district": "NASHOBA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402112001051",
    },
    {
        "school": "RATTAN ES",
        "district": "RATTAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402550001361",
    },
    {
        "school": "RATTAN HS",
        "district": "RATTAN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402550001362",
    },
    {
        "school": "RATTAN JHS",
        "district": "RATTAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402550001363",
    },
    {
        "school": "TUSKAHOMA PUBLIC SCHOOL",
        "district": "TUSKAHOMA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403039001692",
    },
    {
        "school": "CHEYENNE ES",
        "district": "CHEYENNE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400750000299",
    },
    {
        "school": "CHEYENNE HS",
        "district": "CHEYENNE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400750000300",
    },
    {
        "school": "HAMMON ES",
        "district": "HAMMON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401365000646",
    },
    {
        "school": "HAMMON HS",
        "district": "HAMMON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401365000647",
    },
    {
        "school": "LEEDEY ES",
        "district": "LEEDEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401737000844",
    },
    {
        "school": "LEEDEY HS",
        "district": "LEEDEY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401737000845",
    },
    {
        "school": "REYDON ES",
        "district": "REYDON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402580001370",
    },
    {
        "school": "REYDON HS",
        "district": "REYDON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402580001371",
    },
    {
        "school": "SWEETWATER ES",
        "district": "SWEETWATER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402931001538",
    },
    {
        "school": "SWEETWATER HS",
        "district": "SWEETWATER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402931001539",
    },
    {
        "school": "BOWLEGS ES",
        "district": "BOWLEGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400513000179",
    },
    {
        "school": "BOWLEGS HS",
        "district": "BOWLEGS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400513000180",
    },
    {
        "school": "BUTNER ES",
        "district": "BUTNER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400600000227",
    },
    {
        "school": "BUTNER HS",
        "district": "BUTNER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400600000228",
    },
    {
        "school": "JUSTICE PUBLIC SCHOOL",
        "district": "JUSTICE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401590000748",
    },
    {
        "school": "KONAWA ES",
        "district": "KONAWA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401671000779",
    },
    {
        "school": "KONAWA HS",
        "district": "KONAWA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401671000780",
    },
    {
        "school": "NEW LIMA ES",
        "district": "NEW LIMA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402136001054",
    },
    {
        "school": "NEW LIMA HS",
        "district": "NEW LIMA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402136001055",
    },
    {
        "school": "SASAKWA ES",
        "district": "SASAKWA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402694001426",
    },
    {
        "school": "SASAKWA HS",
        "district": "SASAKWA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402694001427",
    },
    {
        "school": "WILSON ES",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402730001439",
    },
    {
        "school": "NORTHWOOD ES",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402730001440",
    },
    {
        "school": "SEMINOLE MS",
        "district": "SEMINOLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402730001441",
    },
    {
        "school": "SEMINOLE HS",
        "district": "SEMINOLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402730029757",
    },
    {
        "school": "STROTHER ES",
        "district": "STROTHER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402904001523",
    },
    {
        "school": "STROTHER HS",
        "district": "STROTHER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402904001524",
    },
    {
        "school": "VARNUM ES",
        "district": "VARNUM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403099001717",
    },
    {
        "school": "VARNUM HS",
        "district": "VARNUM",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403099029758",
    },
    {
        "school": "WEWOKA ES",
        "district": "WEWOKA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403246001800",
    },
    {
        "school": "WEWOKA HS",
        "district": "WEWOKA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403246001801",
    },
    {
        "school": "FREDERICK ES",
        "district": "FREDERICK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401215000567",
    },
    {
        "school": "FREDERICK HS",
        "district": "FREDERICK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401215000569",
    },
    {
        "school": "FREDERICK MS",
        "district": "FREDERICK",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401215000570",
    },
    {
        "school": "GRANDFIELD ES",
        "district": "GRANDFIELD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401320000612",
    },
    {
        "school": "GRANDFIELD HS",
        "district": "GRANDFIELD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401320029765",
    },
    {
        "school": "TIPTON ES",
        "district": "TIPTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403003001570",
    },
    {
        "school": "TIPTON HS",
        "district": "TIPTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403003029764",
    },
    {
        "school": "WILL ROGERS ES",
        "district": "BURNS FLAT-DILL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400001401566",
    },
    {
        "school": "BURNS FLAT-DILL CITY HS",
        "district": "BURNS FLAT-DILL CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400001401582",
    },
    {
        "school": "CANUTE ES",
        "district": "CANUTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400651000255",
    },
    {
        "school": "CANUTE HS",
        "district": "CANUTE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400651000256",
    },
    {
        "school": "CORDELL HS",
        "district": "CORDELL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400864000364",
    },
    {
        "school": "CORDELL JHS",
        "district": "CORDELL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400864000365",
    },
    {
        "school": "CORDELL ES",
        "district": "CORDELL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400864000366",
    },
    {
        "school": "MCMURRAY ES",
        "district": "SENTINEL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402733001443",
    },
    {
        "school": "BLANCHE THOMAS HS",
        "district": "SENTINEL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402733001444",
    },
    {
        "school": "ALVA MS",
        "district": "ALVA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400288000041",
    },
    {
        "school": "ALVA HS",
        "district": "ALVA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400288000042",
    },
    {
        "school": "LINCOLN ES",
        "district": "ALVA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400288000043",
    },
    {
        "school": "LONGFELLOW ES",
        "district": "ALVA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400288000044",
    },
    {
        "school": "WASHINGTON ES",
        "district": "ALVA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400288000045",
    },
    {
        "school": "FREEDOM ES",
        "district": "FREEDOM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401218000573",
    },
    {
        "school": "FREEDOM HS",
        "district": "FREEDOM",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401218000574",
    },
    {
        "school": "WAYNOKA ES",
        "district": "WAYNOKA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403204001771",
    },
    {
        "school": "WAYNOKA HS",
        "district": "WAYNOKA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403204029830",
    },
    {
        "school": "MCLISH MS",
        "district": "STONEWALL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402880002389",
    },
    {
        "school": "ADA HS",
        "district": "ADA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400243000003",
    },
    {
        "school": "ADA EC CTR",
        "district": "ADA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400243000005",
    },
    {
        "school": "HAYES ES",
        "district": "ADA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400243000006",
    },
    {
        "school": "WASHINGTON ES",
        "district": "ADA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400243000007",
    },
    {
        "school": "WILLARD ES",
        "district": "ADA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400243000008",
    },
    {
        "school": "ADA JHS",
        "district": "ADA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400243000725",
    },
    {
        "school": "ALLEN ES",
        "district": "ALLEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400276000024",
    },
    {
        "school": "ALLEN HS",
        "district": "ALLEN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400276000025",
    },
    {
        "school": "BYNG ES",
        "district": "BYNG",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400606000230",
    },
    {
        "school": "HOMER ES",
        "district": "BYNG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400606029749",
    },
    {
        "school": "FRANCIS ES",
        "district": "BYNG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400606029750",
    },
    {
        "school": "BYNG JHS",
        "district": "BYNG",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400606029751",
    },
    {
        "school": "BYNG HS",
        "district": "BYNG",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400606029752",
    },
    {
        "school": "LATTA ES",
        "district": "LATTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401719000792",
    },
    {
        "school": "LATTA HS",
        "district": "LATTA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401719000793",
    },
    {
        "school": "LATTA MS",
        "district": "LATTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401719000794",
    },
    {
        "school": "ROFF ES",
        "district": "ROFF",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402628001382",
    },
    {
        "school": "ROFF HS",
        "district": "ROFF",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402628001383",
    },
    {
        "school": "STONEWALL ES",
        "district": "STONEWALL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402880001514",
    },
    {
        "school": "STONEWALL HS",
        "district": "STONEWALL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402880001515",
    },
    {
        "school": "VANOSS ES",
        "district": "VANOSS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403096001714",
    },
    {
        "school": "VANOSS HS",
        "district": "VANOSS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403096029748",
    },
    {
        "school": "ALTUS INTERMEDIATE SCHOOL",
        "district": "ALTUS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400285002365",
    },
    {
        "school": "ALTUS HS",
        "district": "ALTUS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400285000030",
    },
    {
        "school": "RIVERS ES",
        "district": "ALTUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400285000033",
    },
    {
        "school": "ALTUS PRIMARY SCHOOL",
        "district": "ALTUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400285000035",
    },
    {
        "school": "ALTUS JHS",
        "district": "ALTUS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400285000036",
    },
    {
        "school": "ALTUS ES",
        "district": "ALTUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400285000037",
    },
    {
        "school": "ALTUS EARLY CHILDHOOD CENTER",
        "district": "ALTUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400285000039",
    },
    {
        "school": "BLAIR ES",
        "district": "BLAIR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400465000157",
    },
    {
        "school": "BLAIR HS",
        "district": "BLAIR",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400465000158",
    },
    {
        "school": "DUKE ES",
        "district": "DUKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401026000444",
    },
    {
        "school": "DUKE HS",
        "district": "DUKE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401026000445",
    },
    {
        "school": "NAVAJO ES",
        "district": "NAVAJO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402118001052",
    },
    {
        "school": "NAVAJO HS",
        "district": "NAVAJO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402118001053",
    },
    {
        "school": "NAVAJO JHS",
        "district": "NAVAJO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402118001889",
    },
    {
        "school": "CHARLES EVANS ES",
        "district": "ARDMORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400318000069",
    },
    {
        "school": "JEFFERSON ES",
        "district": "ARDMORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400318029631",
    },
    {
        "school": "LINCOLN ES",
        "district": "ARDMORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400318029632",
    },
    {
        "school": "WILL ROGERS ES",
        "district": "ARDMORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400318029635",
    },
    {
        "school": "ARDMORE MS",
        "district": "ARDMORE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400318029636",
    },
    {
        "school": "ARDMORE HS",
        "district": "ARDMORE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400318029637",
    },
    {
        "school": "DICKSON ES",
        "district": "DICKSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400991000429",
    },
    {
        "school": "DICKSON HS",
        "district": "DICKSON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400991000430",
    },
    {
        "school": "DICKSON UPPER ES",
        "district": "DICKSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400991000432",
    },
    {
        "school": "FOX ES",
        "district": "FOX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401206000562",
    },
    {
        "school": "FOX HS",
        "district": "FOX",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401206000563",
    },
    {
        "school": "HEALDTON HS",
        "district": "HEALDTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401413000666",
    },
    {
        "school": "HEALDTON ES",
        "district": "HEALDTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401413000667",
    },
    {
        "school": "HEALDTON MS",
        "district": "HEALDTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401413001863",
    },
    {
        "school": "LONE GROVE MS",
        "district": "LONE GROVE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401809000869",
    },
    {
        "school": "LONE GROVE INTERMEDIATE SCHOOL",
        "district": "LONE GROVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401809000870",
    },
    {
        "school": "LONE GROVE HS",
        "district": "LONE GROVE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401809000871",
    },
    {
        "school": "LONE GROVE PRIMARY ES",
        "district": "LONE GROVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401809001120",
    },
    {
        "school": "PLAINVIEW PRIMARY ES",
        "district": "PLAINVIEW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402424001277",
    },
    {
        "school": "PLAINVIEW HS",
        "district": "PLAINVIEW",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402424001278",
    },
    {
        "school": "PLAINVIEW MS",
        "district": "PLAINVIEW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402424001279",
    },
    {
        "school": "PLAINVIEW INTERMEDIATE ES",
        "district": "PLAINVIEW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402424002104",
    },
    {
        "school": "SPRINGER ES",
        "district": "SPRINGER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402835001495",
    },
    {
        "school": "SPRINGER HS",
        "district": "SPRINGER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402835001496",
    },
    {
        "school": "WILSON ES",
        "district": "WILSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403294001815",
    },
    {
        "school": "WILSON HS",
        "district": "WILSON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403294001816",
    },
    {
        "school": "ZANEIS PUBLIC SCHOOL",
        "district": "ZANEIS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403354001852",
    },
    {
        "school": "GREENVILLE PUBLIC SCHOOL",
        "district": "GREENVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401338000622",
    },
    {
        "school": "MARIETTA ES",
        "district": "MARIETTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401899000899",
    },
    {
        "school": "MARIETTA HS",
        "district": "MARIETTA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401899000900",
    },
    {
        "school": "MARIETTA MS",
        "district": "MARIETTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401899000901",
    },
    {
        "school": "THACKERVILLE ES",
        "district": "THACKERVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402985001564",
    },
    {
        "school": "THACKERVILLE HS",
        "district": "THACKERVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402985001565",
    },
    {
        "school": "TURNER ES",
        "district": "TURNER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403030001686",
    },
    {
        "school": "TURNER HS",
        "district": "TURNER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403030001687",
    },
    {
        "school": "RICHARD KANE ES",
        "district": "BARTLESVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400363001962",
    },
    {
        "school": "HOOVER ES",
        "district": "BARTLESVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400363029818",
    },
    {
        "school": "JANE PHILLIPS ES",
        "district": "BARTLESVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400363029819",
    },
    {
        "school": "RANCH HEIGHTS ES",
        "district": "BARTLESVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400363029821",
    },
    {
        "school": "WAYSIDE ES",
        "district": "BARTLESVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400363029822",
    },
    {
        "school": "WOODROW WILSON ES",
        "district": "BARTLESVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400363029823",
    },
    {
        "school": "CENTRAL MS",
        "district": "BARTLESVILLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400363029824",
    },
    {
        "school": "MADISON MS",
        "district": "BARTLESVILLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400363029825",
    },
    {
        "school": "BARTLESVILLE HS",
        "district": "BARTLESVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400363029826",
    },
    {
        "school": "COPAN ES",
        "district": "COPAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400861000362",
    },
    {
        "school": "COPAN HS",
        "district": "COPAN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400861002199",
    },
    {
        "school": "DEWEY HS",
        "district": "DEWEY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400981000423",
    },
    {
        "school": "DEWEY ES",
        "district": "DEWEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400981000425",
    },
    {
        "school": "DEWEY MS",
        "district": "DEWEY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400981001910",
    },
    {
        "school": "CANEY VALLEY HS",
        "district": "CANEY VALLEY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402547001357",
    },
    {
        "school": "CANEY VALLEY MS",
        "district": "CANEY VALLEY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402547001358",
    },
    {
        "school": "CANEY VALLEY ES",
        "district": "CANEY VALLEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402547001359",
    },
    {
        "school": "OSAGE HILLS PUBLIC SCHOOL",
        "district": "OSAGE HILLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402322001232",
    },
    {
        "school": "BRAY-DOYLE ES",
        "district": "BRAY-DOYLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400534000189",
    },
    {
        "school": "BRAY-DOYLE HS",
        "district": "BRAY-DOYLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400534000190",
    },
    {
        "school": "CENTRAL HIGH ES",
        "district": "CENTRAL HIGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400717000281",
    },
    {
        "school": "CENTRAL HIGH HS",
        "district": "CENTRAL HIGH",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400717000282",
    },
    {
        "school": "COMANCHE ES",
        "district": "COMANCHE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400846000353",
    },
    {
        "school": "COMANCHE HS",
        "district": "COMANCHE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400846000354",
    },
    {
        "school": "COMANCHE MS",
        "district": "COMANCHE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400846002279",
    },
    {
        "school": "DUNCAN HS",
        "district": "DUNCAN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401029000446",
    },
    {
        "school": "EMERSON ES",
        "district": "DUNCAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401029000448",
    },
    {
        "school": "HORACE MANN ES",
        "district": "DUNCAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401029000449",
    },
    {
        "school": "MARK TWAIN ES",
        "district": "DUNCAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401029000451",
    },
    {
        "school": "PLATO ES",
        "district": "DUNCAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401029000452",
    },
    {
        "school": "WILL ROGERS PRE-K CTR",
        "district": "DUNCAN",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401029000454",
    },
    {
        "school": "WOODROW WILSON ES",
        "district": "DUNCAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401029000455",
    },
    {
        "school": "DUNCAN MS",
        "district": "DUNCAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401029000921",
    },
    {
        "school": "EMPIRE ES",
        "district": "EMPIRE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401089000504",
    },
    {
        "school": "EMPIRE HS",
        "district": "EMPIRE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401089029761",
    },
    {
        "school": "GRANDVIEW PUBLIC SCHOOL",
        "district": "GRANDVIEW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401326000615",
    },
    {
        "school": "MARLOW ES",
        "district": "MARLOW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401908000904",
    },
    {
        "school": "MARLOW HS",
        "district": "MARLOW",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401908000905",
    },
    {
        "school": "MARLOW MS",
        "district": "MARLOW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401908000906",
    },
    {
        "school": "VELMA-ALMA MS",
        "district": "VELMA-ALMA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403102001455",
    },
    {
        "school": "VELMA-ALMA ES",
        "district": "VELMA-ALMA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403102001719",
    },
    {
        "school": "VELMA-ALMA HS",
        "district": "VELMA-ALMA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403102029760",
    },
    {
        "school": "ACHILLE ES",
        "district": "ACHILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400237000001",
    },
    {
        "school": "ACHILLE HS",
        "district": "ACHILLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400237000002",
    },
    {
        "school": "BENNINGTON ES",
        "district": "BENNINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400393000123",
    },
    {
        "school": "BENNINGTON HS",
        "district": "BENNINGTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400393000124",
    },
    {
        "school": "CADDO ES",
        "district": "CADDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400615000237",
    },
    {
        "school": "CADDO HS",
        "district": "CADDO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400615029619",
    },
    {
        "school": "CALERA ES",
        "district": "CALERA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400618000239",
    },
    {
        "school": "CALERA HS",
        "district": "CALERA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400618000240",
    },
    {
        "school": "WARD ES EAST",
        "district": "COLBERT",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400822000342",
    },
    {
        "school": "COLBERT MS",
        "district": "COLBERT",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400822000343",
    },
    {
        "school": "WARD ES WEST",
        "district": "COLBERT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400822000344",
    },
    {
        "school": "COLBERT HS",
        "district": "COLBERT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400822029618",
    },
    {
        "school": "DURANT HS",
        "district": "DURANT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401035000456",
    },
    {
        "school": "DURANT MS",
        "district": "DURANT",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401035000457",
    },
    {
        "school": "NORTHWEST HEIGHTS ES",
        "district": "DURANT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401035000459",
    },
    {
        "school": "ROBERT E LEE EARLY CHILDHOOD",
        "district": "DURANT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401035000460",
    },
    {
        "school": "WASHINGTON IRVING ES",
        "district": "DURANT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401035000461",
    },
    {
        "school": "DURANT INTERMEDIATE ES",
        "district": "DURANT",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401035002112",
    },
    {
        "school": "SILO HS",
        "district": "SILO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402764001470",
    },
    {
        "school": "SILO MS",
        "district": "SILO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402764001471",
    },
    {
        "school": "SILO ES",
        "district": "SILO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402764001472",
    },
    {
        "school": "ROCK CREEK ES",
        "district": "ROCK CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403360129840",
    },
    {
        "school": "ROCK CREEK HS",
        "district": "ROCK CREEK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403360129841",
    },
    {
        "school": "CIMARRON ES",
        "district": "CIMARRON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400771000508",
    },
    {
        "school": "CIMARRON HS",
        "district": "CIMARRON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400771000540",
    },
    {
        "school": "COVINGTON-DOUGLAS ES",
        "district": "COVINGTON-DOUGLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400879000370",
    },
    {
        "school": "COVINGTON-DOUGLAS HS",
        "district": "COVINGTON-DOUGLAS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400879000371",
    },
    {
        "school": "DRUMMOND ES",
        "district": "DRUMMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401017000438",
    },
    {
        "school": "DRUMMOND HS",
        "district": "DRUMMOND",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401017000439",
    },
    {
        "school": "ADAMS ES",
        "district": "ENID",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000506",
    },
    {
        "school": "COOLIDGE ES",
        "district": "ENID",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000509",
    },
    {
        "school": "DEWITT WALLER MS",
        "district": "ENID",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000510",
    },
    {
        "school": "EISENHOWER ES",
        "district": "ENID",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000511",
    },
    {
        "school": "ENID HS",
        "district": "ENID",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000513",
    },
    {
        "school": "GARFIELD ES",
        "district": "ENID",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000514",
    },
    {
        "school": "GLENWOOD ES",
        "district": "ENID",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000515",
    },
    {
        "school": "HAYES ES",
        "district": "ENID",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000517",
    },
    {
        "school": "HOOVER ES",
        "district": "ENID",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000518",
    },
    {
        "school": "MCKINLEY ES",
        "district": "ENID",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000521",
    },
    {
        "school": "MONROE ES",
        "district": "ENID",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000522",
    },
    {
        "school": "TAFT ES",
        "district": "ENID",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092000523",
    },
    {
        "school": "GARBER ES",
        "district": "GARBER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401242000583",
    },
    {
        "school": "GARBER HS",
        "district": "GARBER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401242029666",
    },
    {
        "school": "KREMLIN-HILLSDALE ES",
        "district": "KREMLIN-HILLSDALE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401674000784",
    },
    {
        "school": "KREMLIN-HILLSDALE HS",
        "district": "KREMLIN-HILLSDALE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401674000785",
    },
    {
        "school": "CHISHOLM HS",
        "district": "CHISHOLM",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402178001088",
    },
    {
        "school": "CHISHOLM ES",
        "district": "CHISHOLM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402178001089",
    },
    {
        "school": "CHISHOLM MS",
        "district": "CHISHOLM",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402178002105",
    },
    {
        "school": "PIONEER-PLEASANT VALE HS",
        "district": "PIONEER-PLEASANT VALE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402451001284",
    },
    {
        "school": "PIONEER-PLEASANT VALE ES",
        "district": "PIONEER-PLEASANT VALE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402451001285",
    },
    {
        "school": "PIONEER-PLEASANT VALE JHS",
        "district": "PIONEER-PLEASANT VALE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402451029667",
    },
    {
        "school": "WAUKOMIS ES",
        "district": "WAUKOMIS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403195001763",
    },
    {
        "school": "WAUKOMIS HS",
        "district": "WAUKOMIS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403195001764",
    },
    {
        "school": "SINGLETON ES",
        "district": "ARKOMA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400321000075",
    },
    {
        "school": "ARKOMA HS",
        "district": "ARKOMA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400321029694",
    },
    {
        "school": "BOKOSHE ES",
        "district": "BOKOSHE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400495000170",
    },
    {
        "school": "BOKOSHE HS",
        "district": "BOKOSHE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400495029693",
    },
    {
        "school": "CAMERON ES",
        "district": "CAMERON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400633000246",
    },
    {
        "school": "CAMERON HS",
        "district": "CAMERON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400633000247",
    },
    {
        "school": "FANSHAWE PUBLIC SCHOOL",
        "district": "FANSHAWE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401140000541",
    },
    {
        "school": "HEAVENER HS",
        "district": "HEAVENER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401416000668",
    },
    {
        "school": "HEAVENER ES",
        "district": "HEAVENER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401416000670",
    },
    {
        "school": "HODGEN PUBLIC SCHOOL",
        "district": "HODGEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401473000693",
    },
    {
        "school": "HOWE ES",
        "district": "HOWE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401512000708",
    },
    {
        "school": "HOWE HS",
        "district": "HOWE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401512000709",
    },
    {
        "school": "LEFLORE ES",
        "district": "LE FLORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401728000840",
    },
    {
        "school": "LEFLORE HS",
        "district": "LE FLORE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401728000841",
    },
    {
        "school": "MONROE PUBLIC SCHOOL",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402019000987",
    },
    {
        "school": "PANAMA HS",
        "district": "PANAMA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402337001241",
    },
    {
        "school": "PANAMA MS",
        "district": "PANAMA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402337001987",
    },
    {
        "school": "POCOLA ES",
        "district": "POCOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402463001287",
    },
    {
        "school": "POCOLA HS",
        "district": "POCOLA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402463001288",
    },
    {
        "school": "POCOLA MS",
        "district": "POCOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402463001289",
    },
    {
        "school": "POTEAU PRIMARY ES",
        "district": "POTEAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402487001308",
    },
    {
        "school": "PANSY KIDD MS",
        "district": "POTEAU",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402487001309",
    },
    {
        "school": "POTEAU HS",
        "district": "POTEAU",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402487001310",
    },
    {
        "school": "POTEAU UPPER ES",
        "district": "POTEAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402487001682",
    },
    {
        "school": "SHADY POINT PUBLIC SCHOOL",
        "district": "SHADY POINT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402745001450",
    },
    {
        "school": "SPIRO ES",
        "district": "SPIRO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402820001492",
    },
    {
        "school": "SPIRO HS",
        "district": "SPIRO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402820001493",
    },
    {
        "school": "SPIRO MS",
        "district": "SPIRO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402820001494",
    },
    {
        "school": "TALIHINA ES",
        "district": "TALIHINA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402940001546",
    },
    {
        "school": "TALIHINA HS",
        "district": "TALIHINA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402940001547",
    },
    {
        "school": "TALIHINA JHS",
        "district": "TALIHINA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402940001548",
    },
    {
        "school": "WHITESBORO ES",
        "district": "WHITESBORO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403273001807",
    },
    {
        "school": "WHITESBORO HS",
        "district": "WHITESBORO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403273001808",
    },
    {
        "school": "WISTER ES",
        "district": "WISTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403297001817",
    },
    {
        "school": "WISTER HS",
        "district": "WISTER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403297001818",
    },
    {
        "school": "BELFONTE PUBLIC SCHOOL",
        "district": "BELFONTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400384000121",
    },
    {
        "school": "BRUSHY PUBLIC SCHOOL",
        "district": "BRUSHY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400558000214",
    },
    {
        "school": "CENTRAL ES",
        "district": "CENTRAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400714000279",
    },
    {
        "school": "CENTRAL HS",
        "district": "CENTRAL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400714000280",
    },
    {
        "school": "GANS ES",
        "district": "GANS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401239000581",
    },
    {
        "school": "GANS HS",
        "district": "GANS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401239000582",
    },
    {
        "school": "GORE ES",
        "district": "GORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401290001982",
    },
    {
        "school": "GORE HS",
        "district": "GORE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401290002202",
    },
    {
        "school": "GORE UPPER ES",
        "district": "GORE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401290002294",
    },
    {
        "school": "LIBERTY PUBLIC SCHOOL",
        "district": "LIBERTY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401770000857",
    },
    {
        "school": "MARBLE CITY PUBLIC SCHOOL",
        "district": "MARBLE CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401896000898",
    },
    {
        "school": "MOFFETT PUBLIC SCHOOL",
        "district": "MOFFETT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402016000986",
    },
    {
        "school": "MULDROW ES",
        "district": "MULDROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402088001026",
    },
    {
        "school": "MULDROW HS",
        "district": "MULDROW",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402088001027",
    },
    {
        "school": "MULDROW MS",
        "district": "MULDROW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402088001967",
    },
    {
        "school": "ROLAND ES",
        "district": "ROLAND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402631001384",
    },
    {
        "school": "ROLAND HS",
        "district": "ROLAND",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402631001385",
    },
    {
        "school": "ROLAND JHS",
        "district": "ROLAND",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402631001386",
    },
    {
        "school": "EASTSIDE ES",
        "district": "SALLISAW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402679001399",
    },
    {
        "school": "LIBERTY ES",
        "district": "SALLISAW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402679001400",
    },
    {
        "school": "SALLISAW HS",
        "district": "SALLISAW",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402679001401",
    },
    {
        "school": "SALLISAW MS",
        "district": "SALLISAW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402679001403",
    },
    {
        "school": "VIAN ES",
        "district": "VIAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403114001724",
    },
    {
        "school": "VIAN HS",
        "district": "VIAN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403114001725",
    },
    {
        "school": "VIAN MS",
        "district": "VIAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403114001726",
    },
    {
        "school": "GOODWELL ES",
        "district": "GOODWELL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401287000597",
    },
    {
        "school": "GOODWELL HS",
        "district": "GOODWELL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401287000598",
    },
    {
        "school": "ACADEMY ES",
        "district": "GUYMON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401359000635",
    },
    {
        "school": "CARRIER ES",
        "district": "GUYMON",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401359000636",
    },
    {
        "school": "CENTRAL JHS",
        "district": "GUYMON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401359000637",
    },
    {
        "school": "GUYMON HS",
        "district": "GUYMON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401359000639",
    },
    {
        "school": "HOMER LONG ES",
        "district": "GUYMON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401359000640",
    },
    {
        "school": "NORTHEAST ES",
        "district": "GUYMON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401359000641",
    },
    {
        "school": "NORTH PARK ES",
        "district": "GUYMON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401359002108",
    },
    {
        "school": "HARDESTY ES",
        "district": "HARDESTY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401374000651",
    },
    {
        "school": "HARDESTY HS",
        "district": "HARDESTY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401374000652",
    },
    {
        "school": "HOOKER ES",
        "district": "HOOKER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401509000706",
    },
    {
        "school": "HOOKER HS",
        "district": "HOOKER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401509029763",
    },
    {
        "school": "OPTIMA PUBLIC SCHOOL",
        "district": "OPTIMA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402307001230",
    },
    {
        "school": "STRAIGHT PUBLIC SCHOOL",
        "district": "STRAIGHT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402892001518",
    },
    {
        "school": "TEXHOMA ES",
        "district": "TEXHOMA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402982001562",
    },
    {
        "school": "TEXHOMA HS",
        "district": "TEXHOMA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402982001563",
    },
    {
        "school": "TYRONE ES",
        "district": "TYRONE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403048001698",
    },
    {
        "school": "TYRONE HS",
        "district": "TYRONE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403048001699",
    },
    {
        "school": "YARBROUGH ES",
        "district": "YARBROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403339001840",
    },
    {
        "school": "YARBROUGH HS",
        "district": "YARBROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403339029762",
    },
    {
        "school": "MACARTHUR MS",
        "district": "LAWTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725002364",
    },
    {
        "school": "BISHOP PUBLIC SCHOOL",
        "district": "BISHOP",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400447000146",
    },
    {
        "school": "CACHE INTERMEDIATE ES",
        "district": "CACHE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400612000107",
    },
    {
        "school": "CACHE PRIMARY ES",
        "district": "CACHE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400612000235",
    },
    {
        "school": "CACHE MS",
        "district": "CACHE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400612029646",
    },
    {
        "school": "CACHE HS",
        "district": "CACHE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400612029647",
    },
    {
        "school": "CHATTANOOGA ES",
        "district": "CHATTANOOGA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400732000286",
    },
    {
        "school": "CHATTANOOGA HS",
        "district": "CHATTANOOGA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400732000287",
    },
    {
        "school": "ELGIN ES",
        "district": "ELGIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401071000493",
    },
    {
        "school": "ELGIN HS",
        "district": "ELGIN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401071000494",
    },
    {
        "school": "ELGIN MS",
        "district": "ELGIN",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401071001980",
    },
    {
        "school": "FLETCHER ES",
        "district": "FLETCHER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401170000549",
    },
    {
        "school": "FLETCHER JHS",
        "district": "FLETCHER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401170000550",
    },
    {
        "school": "FLETCHER HS",
        "district": "FLETCHER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401170029648",
    },
    {
        "school": "FLOWER MOUND PUBLIC SCHOOL",
        "district": "FLOWER MOUND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401176000551",
    },
    {
        "school": "GERONIMO ES",
        "district": "GERONIMO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401263000589",
    },
    {
        "school": "GERONIMO HS",
        "district": "GERONIMO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401263000590",
    },
    {
        "school": "INDIAHOMA ES",
        "district": "INDIAHOMA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401542000729",
    },
    {
        "school": "INDIAHOMA HS",
        "district": "INDIAHOMA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401542000730",
    },
    {
        "school": "ADAMS ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000798",
    },
    {
        "school": "ALMOR WEST ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000799",
    },
    {
        "school": "CARRIAGE HILLS ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000801",
    },
    {
        "school": "CLEVELAND ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000803",
    },
    {
        "school": "CROSBY PARK ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000805",
    },
    {
        "school": "EDISON ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000807",
    },
    {
        "school": "EISENHOWER ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000808",
    },
    {
        "school": "EISENHOWER HS",
        "district": "LAWTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000809",
    },
    {
        "school": "RIDGECREST ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000814",
    },
    {
        "school": "LAWTON HS",
        "district": "LAWTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000819",
    },
    {
        "school": "LINCOLN ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000821",
    },
    {
        "school": "MACARTHUR HS",
        "district": "LAWTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000822",
    },
    {
        "school": "PIONEER PARK ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000826",
    },
    {
        "school": "SULLIVAN VILLAGE ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000829",
    },
    {
        "school": "WASHINGTON ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000833",
    },
    {
        "school": "LEARNING TREE ACADEMY",
        "district": "LAWTON",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000835",
    },
    {
        "school": "WHITTIER ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000836",
    },
    {
        "school": "WOODLAND HILLS ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725000839",
    },
    {
        "school": "HUGH BISH ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725001865",
    },
    {
        "school": "PAT HENRY ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725001975",
    },
    {
        "school": "STERLING ES",
        "district": "STERLING",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402859001498",
    },
    {
        "school": "STERLING HS",
        "district": "STERLING",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402859001499",
    },
    {
        "school": "JEFFERSON EC CTR",
        "district": "MCALESTER",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401944002381",
    },
    {
        "school": "PARKER INTERMEDIATE CTR",
        "district": "MCALESTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401944002388",
    },
    {
        "school": "CANADIAN ES",
        "district": "CANADIAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400639000248",
    },
    {
        "school": "CANADIAN HS",
        "district": "CANADIAN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400639000249",
    },
    {
        "school": "CROWDER ES",
        "district": "CROWDER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400909000384",
    },
    {
        "school": "CROWDER HS",
        "district": "CROWDER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400909000385",
    },
    {
        "school": "FRINK-CHAMBERS PUBLIC SCHOOL",
        "district": "FRINK-CHAMBERS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401224000576",
    },
    {
        "school": "HAILEYVILLE ES",
        "district": "HAILEYVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401362000644",
    },
    {
        "school": "HAILEYVILLE HS",
        "district": "HAILEYVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401362000645",
    },
    {
        "school": "HARTSHORNE ES",
        "district": "HARTSHORNE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401392000657",
    },
    {
        "school": "HARTSHORNE HS",
        "district": "HARTSHORNE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401392000658",
    },
    {
        "school": "HARTSHORNE MS",
        "district": "HARTSHORNE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401392000675",
    },
    {
        "school": "HAYWOOD PUBLIC SCHOOL",
        "district": "HAYWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401410000665",
    },
    {
        "school": "INDIANOLA ES",
        "district": "INDIANOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401545000731",
    },
    {
        "school": "INDIANOLA HS",
        "district": "INDIANOLA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401545029746",
    },
    {
        "school": "KIOWA ES",
        "district": "KIOWA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401665000777",
    },
    {
        "school": "KIOWA HS",
        "district": "KIOWA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401665029744",
    },
    {
        "school": "KREBS PUBLIC SCHOOL",
        "district": "KREBS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401672000782",
    },
    {
        "school": "EDMOND DOYLE ES",
        "district": "MCALESTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401944000917",
    },
    {
        "school": "EMERSON ES",
        "district": "MCALESTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401944000918",
    },
    {
        "school": "MCALESTER HS",
        "district": "MCALESTER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401944000922",
    },
    {
        "school": "PUTERBAUGH MS",
        "district": "MCALESTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401944000924",
    },
    {
        "school": "WILLIAM GAY EC CTR",
        "district": "MCALESTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401944000925",
    },
    {
        "school": "WILL ROGERS ES",
        "district": "MCALESTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401944000927",
    },
    {
        "school": "PITTSBURG ES",
        "district": "PITTSBURG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402418001275",
    },
    {
        "school": "PITTSBURG HS",
        "district": "PITTSBURG",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402418001276",
    },
    {
        "school": "QUINTON ES",
        "district": "QUINTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402541001353",
    },
    {
        "school": "QUINTON HS",
        "district": "QUINTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402541029745",
    },
    {
        "school": "SAVANNA ES",
        "district": "SAVANNA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402700001428",
    },
    {
        "school": "SAVANNA HS",
        "district": "SAVANNA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402700001429",
    },
    {
        "school": "TANNEHILL PUBLIC SCHOOL",
        "district": "TANNEHILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402952001551",
    },
    {
        "school": "WYANDOTTE MS",
        "district": "WYANDOTTE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403324002361",
    },
    {
        "school": "AFTON ES",
        "district": "AFTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400252000013",
    },
    {
        "school": "AFTON HS",
        "district": "AFTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400252000014",
    },
    {
        "school": "CLEORA PUBLIC SCHOOL",
        "district": "CLEORA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400801000330",
    },
    {
        "school": "ALEXANDER ES",
        "district": "COMMERCE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400849000358",
    },
    {
        "school": "COMMERCE HS",
        "district": "COMMERCE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400849000359",
    },
    {
        "school": "COMMERCE MS",
        "district": "COMMERCE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400849000360",
    },
    {
        "school": "FAIRLAND ES",
        "district": "FAIRLAND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401125000534",
    },
    {
        "school": "FAIRLAND HS",
        "district": "FAIRLAND",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401125000535",
    },
    {
        "school": "WILL ROGERS MS",
        "district": "MIAMI",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401986000674",
    },
    {
        "school": "MIAMI HS",
        "district": "MIAMI",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401986000942",
    },
    {
        "school": "NICHOLS UPPER ES",
        "district": "MIAMI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401986000943",
    },
    {
        "school": "ROCKDALE ES",
        "district": "MIAMI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401986000944",
    },
    {
        "school": "ROOSEVELT ES",
        "district": "MIAMI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401986000945",
    },
    {
        "school": "WASHINGTON ES",
        "district": "MIAMI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401986000946",
    },
    {
        "school": "WILSON ES",
        "district": "MIAMI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401986000948",
    },
    {
        "school": "QUAPAW ES",
        "district": "QUAPAW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402532001350",
    },
    {
        "school": "QUAPAW HS",
        "district": "QUAPAW",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402532001351",
    },
    {
        "school": "QUAPAW MS",
        "district": "QUAPAW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402532001352",
    },
    {
        "school": "TURKEY FORD PUBLIC SCHOOL",
        "district": "TURKEY FORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403029001685",
    },
    {
        "school": "WYANDOTTE ES",
        "district": "WYANDOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403324001831",
    },
    {
        "school": "WYANDOTTE HS",
        "district": "WYANDOTTE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403324029731",
    },
    {
        "school": "OKLAHOMA SCHL FOR THE BLIND ES",
        "district": "OKLAHOMA SCHOOL FOR THE BLIND",
        "level": "Elementary",
        "type": "Special education school",
        "state": "OK",
        "nces_id": "400007602349",
    },
    {
        "school": "OKLAHOMA SCHL FOR THE BLIND HS",
        "district": "OKLAHOMA SCHOOL FOR THE BLIND",
        "level": "High",
        "type": "Special education school",
        "state": "OK",
        "nces_id": "400007602350",
    },
    {
        "school": "BRAGGS ES",
        "district": "BRAGGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400528000185",
    },
    {
        "school": "BRAGGS HS",
        "district": "BRAGGS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400528000186",
    },
    {
        "school": "FORT GIBSON INTERMEDIATE ES",
        "district": "FORT GIBSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401197000557",
    },
    {
        "school": "FORT GIBSON HS",
        "district": "FORT GIBSON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401197000558",
    },
    {
        "school": "FORT GIBSON MS",
        "district": "FORT GIBSON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401197000559",
    },
    {
        "school": "FORT GIBSON EARLY LRNING CTR",
        "district": "FORT GIBSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401197001995",
    },
    {
        "school": "HASKELL MS",
        "district": "HASKELL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401395000572",
    },
    {
        "school": "MARY WHITE ES",
        "district": "HASKELL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401395000660",
    },
    {
        "school": "HASKELL HS",
        "district": "HASKELL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401395029705",
    },
    {
        "school": "HILLDALE LOWER ES",
        "district": "HILLDALE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401452000682",
    },
    {
        "school": "HILLDALE MS",
        "district": "HILLDALE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401452000683",
    },
    {
        "school": "HILLDALE HS",
        "district": "HILLDALE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401452001898",
    },
    {
        "school": "7TH AND 8TH GRADE ACADEMY",
        "district": "MUSKOGEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402097000599",
    },
    {
        "school": "MUSKOGEE HS",
        "district": "MUSKOGEE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402097001032",
    },
    {
        "school": "CHEROKEE ES",
        "district": "MUSKOGEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402097001033",
    },
    {
        "school": "IRVING ES",
        "district": "MUSKOGEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402097001038",
    },
    {
        "school": "PERSHING ES",
        "district": "MUSKOGEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402097001039",
    },
    {
        "school": "TONY GOETZ ES",
        "district": "MUSKOGEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402097001042",
    },
    {
        "school": "WHITTIER ES",
        "district": "MUSKOGEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402097001044",
    },
    {
        "school": "SADLER ARTS ACADEMY",
        "district": "MUSKOGEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402097001968",
    },
    {
        "school": "CREEK ES",
        "district": "MUSKOGEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402097001999",
    },
    {
        "school": "MUSKOGEE EC CTR",
        "district": "MUSKOGEE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402097002302",
    },
    {
        "school": "OKTAHA ES",
        "district": "OKTAHA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402283001215",
    },
    {
        "school": "OKTAHA HS",
        "district": "OKTAHA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402283001216",
    },
    {
        "school": "PORUM ES",
        "district": "PORUM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402484001306",
    },
    {
        "school": "PORUM HS",
        "district": "PORUM",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402484001307",
    },
    {
        "school": "WAINWRIGHT PUBLIC SCHOOL",
        "district": "WAINWRIGHT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403138001738",
    },
    {
        "school": "WARNER ES",
        "district": "WARNER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403165001750",
    },
    {
        "school": "WARNER HS",
        "district": "WARNER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403165029708",
    },
    {
        "school": "WEBBERS FALLS ES",
        "district": "WEBBERS FALLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403213001779",
    },
    {
        "school": "WEBBERS FALLS HS",
        "district": "WEBBERS FALLS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403213029707",
    },
    {
        "school": "MUSTANG EDUCATION CTR",
        "district": "MUSTANG",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100002358",
    },
    {
        "school": "WAYLAND BONDS ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025002363",
    },
    {
        "school": "SOUTHMOORE HS",
        "district": "MOORE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025002395",
    },
    {
        "school": "CURTIS INGE MS",
        "district": "NOBLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402163002370",
    },
    {
        "school": "CHICKASHA MS",
        "district": "CHICKASHA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400756002342",
    },
    {
        "school": "LINCOLN ES",
        "district": "CHICKASHA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400756002373",
    },
    {
        "school": "BILL WALLACE EC CTR",
        "district": "CHICKASHA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400756002374",
    },
    {
        "school": "CHANDLER JHS",
        "district": "CHANDLER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400729002375",
    },
    {
        "school": "BLANCHARD INTERMEDIATE ES",
        "district": "BLANCHARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400468002368",
    },
    {
        "school": "PURCELL INTERMEDIATE SCHOOL",
        "district": "PURCELL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402523002344",
    },
    {
        "school": "CENTENNIAL ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059002396",
    },
    {
        "school": "ALEX ES",
        "district": "ALEX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400267000019",
    },
    {
        "school": "ALEX HS",
        "district": "ALEX",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400267029673",
    },
    {
        "school": "AMBER-POCASSET ES",
        "district": "AMBER-POCASSET",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400291000046",
    },
    {
        "school": "AMBER-POCASSET JHS",
        "district": "AMBER-POCASSET",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400291000047",
    },
    {
        "school": "AMBER-POCASSET HS",
        "district": "AMBER-POCASSET",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400291029680",
    },
    {
        "school": "BRIDGE CREEK MS",
        "district": "BRIDGE CREEK",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400540001674",
    },
    {
        "school": "BRIDGE CREEK HS",
        "district": "BRIDGE CREEK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400540029677",
    },
    {
        "school": "CHICKASHA HS",
        "district": "CHICKASHA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400756000301",
    },
    {
        "school": "GRAND AVENUE ES",
        "district": "CHICKASHA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400756000305",
    },
    {
        "school": "FRIEND PUBLIC SCHOOL",
        "district": "FRIEND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401221000575",
    },
    {
        "school": "MIDDLEBERG PUBLIC SCHOOL",
        "district": "MIDDLEBERG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401989000949",
    },
    {
        "school": "MINCO ES",
        "district": "MINCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402010000983",
    },
    {
        "school": "MINCO MS",
        "district": "MINCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402010001668",
    },
    {
        "school": "MINCO HS",
        "district": "MINCO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402010029671",
    },
    {
        "school": "NINNEKAH ES",
        "district": "NINNEKAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402160001061",
    },
    {
        "school": "NINNEKAH MS",
        "district": "NINNEKAH",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402160001673",
    },
    {
        "school": "SENIOR HS",
        "district": "NINNEKAH",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402160029672",
    },
    {
        "school": "PIONEER PUBLIC SCHOOL",
        "district": "PIONEER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402415001274",
    },
    {
        "school": "RUSH SPRINGS ES",
        "district": "RUSH SPRINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402655001389",
    },
    {
        "school": "RUSH SPRINGS HS",
        "district": "RUSH SPRINGS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402655001390",
    },
    {
        "school": "RUSH SPRINGS MS",
        "district": "RUSH SPRINGS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402655001391",
    },
    {
        "school": "TUTTLE ES",
        "district": "TUTTLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403042001693",
    },
    {
        "school": "TUTTLE HS",
        "district": "TUTTLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403042001695",
    },
    {
        "school": "TUTTLE MS",
        "district": "TUTTLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403042001696",
    },
    {
        "school": "TUTTLE INTERMEDIATE ES",
        "district": "TUTTLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403042029678",
    },
    {
        "school": "VERDEN ES",
        "district": "VERDEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403108001721",
    },
    {
        "school": "VERDEN HS",
        "district": "VERDEN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403108029679",
    },
    {
        "school": "AGRA ES",
        "district": "AGRA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400255000015",
    },
    {
        "school": "AGRA HS",
        "district": "AGRA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400255000016",
    },
    {
        "school": "CARNEY ES",
        "district": "CARNEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400669000261",
    },
    {
        "school": "CARNEY HS",
        "district": "CARNEY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400669000262",
    },
    {
        "school": "CHANDLER HS",
        "district": "CHANDLER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400729000283",
    },
    {
        "school": "PARK ROAD ES",
        "district": "CHANDLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400729001709",
    },
    {
        "school": "EAST SIDE ES",
        "district": "CHANDLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400729029695",
    },
    {
        "school": "DAVENPORT ES",
        "district": "DAVENPORT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400945000405",
    },
    {
        "school": "DAVENPORT HS",
        "district": "DAVENPORT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400945000406",
    },
    {
        "school": "MEEKER ES",
        "district": "MEEKER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401968000937",
    },
    {
        "school": "MEEKER HS",
        "district": "MEEKER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401968000938",
    },
    {
        "school": "MEEKER MS",
        "district": "MEEKER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401968000939",
    },
    {
        "school": "PRAGUE ES",
        "district": "PRAGUE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402493001311",
    },
    {
        "school": "PRAGUE MS",
        "district": "PRAGUE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402493001312",
    },
    {
        "school": "PRAGUE HS",
        "district": "PRAGUE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402493001313",
    },
    {
        "school": "STROUD HS",
        "district": "STROUD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402907001528",
    },
    {
        "school": "STROUD MS",
        "district": "STROUD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402907001529",
    },
    {
        "school": "PARKVIEW ES",
        "district": "STROUD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402907001773",
    },
    {
        "school": "WELLSTON ES",
        "district": "WELLSTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403228001786",
    },
    {
        "school": "WELLSTON HS",
        "district": "WELLSTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403228001787",
    },
    {
        "school": "WELLSTON MS",
        "district": "WELLSTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403228029696",
    },
    {
        "school": "WHITE ROCK PUBLIC SCHOOL",
        "district": "WHITE ROCK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403264001804",
    },
    {
        "school": "BANNER PUBLIC SCHOOL",
        "district": "BANNER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400354000091",
    },
    {
        "school": "CALUMET ES",
        "district": "CALUMET",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400624000241",
    },
    {
        "school": "CALUMET HS",
        "district": "CALUMET",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400624029629",
    },
    {
        "school": "DARLINGTON PUBLIC SCHOOL",
        "district": "DARLINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400942000404",
    },
    {
        "school": "EL RENO HS",
        "district": "EL RENO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401065000484",
    },
    {
        "school": "ETTA DALE JHS",
        "district": "EL RENO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401065000485",
    },
    {
        "school": "HILLCREST ES",
        "district": "EL RENO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401065000486",
    },
    {
        "school": "LINCOLN LEARNING CTR",
        "district": "EL RENO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401065000488",
    },
    {
        "school": "ROSE WITCHER ES",
        "district": "EL RENO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401065000489",
    },
    {
        "school": "LESLIE F ROBLYER LEARNING CTR",
        "district": "EL RENO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401065002103",
    },
    {
        "school": "MAPLE PUBLIC SCHOOL",
        "district": "MAPLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401890000897",
    },
    {
        "school": "MUSTANG ES",
        "district": "MUSTANG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100001045",
    },
    {
        "school": "MUSTANG HS",
        "district": "MUSTANG",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100001046",
    },
    {
        "school": "MUSTANG MS",
        "district": "MUSTANG",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100001047",
    },
    {
        "school": "MUSTANG VALLEY ES",
        "district": "MUSTANG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100001048",
    },
    {
        "school": "MUSTANG CREEK ES",
        "district": "MUSTANG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100001605",
    },
    {
        "school": "MUSTANG LAKEHOMA ES",
        "district": "MUSTANG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100001869",
    },
    {
        "school": "MUSTANG NORTH MS",
        "district": "MUSTANG",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100001969",
    },
    {
        "school": "MUSTANG TRAILS ES",
        "district": "MUSTANG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100029628",
    },
    {
        "school": "PIEDMONT ES",
        "district": "PIEDMONT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402397001271",
    },
    {
        "school": "PIEDMONT HS",
        "district": "PIEDMONT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402397001272",
    },
    {
        "school": "PIEDMONT MS",
        "district": "PIEDMONT",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402397001273",
    },
    {
        "school": "RIVERSIDE PUBLIC SCHOOL",
        "district": "RIVERSIDE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402601001379",
    },
    {
        "school": "UNION CITY ES",
        "district": "UNION CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403063001706",
    },
    {
        "school": "UNION CITY HS",
        "district": "UNION CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403063001707",
    },
    {
        "school": "CENTRAL ES",
        "district": "YUKON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403348001844",
    },
    {
        "school": "MYERS ES",
        "district": "YUKON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403348001845",
    },
    {
        "school": "RANCHWOOD ES",
        "district": "YUKON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403348001846",
    },
    {
        "school": "SHEDECK ES",
        "district": "YUKON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403348001847",
    },
    {
        "school": "SURREY HILLS ES",
        "district": "YUKON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403348001848",
    },
    {
        "school": "YUKON HS",
        "district": "YUKON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403348001849",
    },
    {
        "school": "INDEPENDENCE ES",
        "district": "YUKON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403348001851",
    },
    {
        "school": "PARKLAND ES",
        "district": "YUKON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403348001886",
    },
    {
        "school": "LAKEVIEW ES",
        "district": "YUKON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403348002102",
    },
    {
        "school": "SKYVIEW ES",
        "district": "YUKON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403348029627",
    },
    {
        "school": "LEXINGTON ES",
        "district": "LEXINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401758000853",
    },
    {
        "school": "LEXINGTON HS",
        "district": "LEXINGTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401758000854",
    },
    {
        "school": "LITTLE AXE MS",
        "district": "LITTLE AXE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401788000103",
    },
    {
        "school": "LITTLE AXE ES",
        "district": "LITTLE AXE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401788000864",
    },
    {
        "school": "LITTLE AXE HS",
        "district": "LITTLE AXE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401788002206",
    },
    {
        "school": "SCHWARTZ ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995001408",
    },
    {
        "school": "CENTRAL ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025000988",
    },
    {
        "school": "HIGHLAND EAST JHS",
        "district": "MOORE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025000993",
    },
    {
        "school": "HOUCHIN ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025000995",
    },
    {
        "school": "KELLEY ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025000996",
    },
    {
        "school": "KINGSGATE ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025000997",
    },
    {
        "school": "MOORE HS",
        "district": "MOORE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025000998",
    },
    {
        "school": "NORTHMOOR ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025000999",
    },
    {
        "school": "PLAZA TOWERS ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001000",
    },
    {
        "school": "SKY RANCH ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001001",
    },
    {
        "school": "SOUTHGATE-RIPPETOE ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001002",
    },
    {
        "school": "WEST JHS",
        "district": "MOORE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001004",
    },
    {
        "school": "EARLYWINE ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001122",
    },
    {
        "school": "BROADMOORE ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001123",
    },
    {
        "school": "CENTRAL JHS",
        "district": "MOORE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001606",
    },
    {
        "school": "SANTA FE ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001867",
    },
    {
        "school": "WINDING CREEK ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001868",
    },
    {
        "school": "APPLE CREEK ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001899",
    },
    {
        "school": "RED OAK ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001900",
    },
    {
        "school": "EASTLAKE ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001945",
    },
    {
        "school": "BRYANT ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001955",
    },
    {
        "school": "BRIARWOOD ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025001966",
    },
    {
        "school": "WESTMOORE HS",
        "district": "MOORE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025002070",
    },
    {
        "school": "BRINK JHS",
        "district": "MOORE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025002214",
    },
    {
        "school": "HIGHLAND WEST JHS",
        "district": "MOORE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025002215",
    },
    {
        "school": "FISHER ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025029642",
    },
    {
        "school": "SOONER ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025029847",
    },
    {
        "school": "KATHERINE I DAILY ES",
        "district": "NOBLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402163001063",
    },
    {
        "school": "NOBLE HS",
        "district": "NOBLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402163001064",
    },
    {
        "school": "PIONEER INTERMEDIATE ES",
        "district": "NOBLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402163001066",
    },
    {
        "school": "JOHN K HUBBARD ES",
        "district": "NOBLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402163001923",
    },
    {
        "school": "ADAMS ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001068",
    },
    {
        "school": "CLEVELAND ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001071",
    },
    {
        "school": "EISENHOWER ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001072",
    },
    {
        "school": "IRVING MS",
        "district": "NORMAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001073",
    },
    {
        "school": "JACKSON ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001074",
    },
    {
        "school": "JEFFERSON ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001075",
    },
    {
        "school": "KENNEDY ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001076",
    },
    {
        "school": "LINCOLN ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001077",
    },
    {
        "school": "LONGFELLOW MS",
        "district": "NORMAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001078",
    },
    {
        "school": "MADISON ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001079",
    },
    {
        "school": "MCKINLEY ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001080",
    },
    {
        "school": "MONROE ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001081",
    },
    {
        "school": "NORMAN HS",
        "district": "NORMAN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001082",
    },
    {
        "school": "WHITTIER MS",
        "district": "NORMAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001085",
    },
    {
        "school": "WILSON ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001086",
    },
    {
        "school": "ROOSEVELT ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172001127",
    },
    {
        "school": "LAKEVIEW ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172002000",
    },
    {
        "school": "ALCOTT MS",
        "district": "NORMAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172002117",
    },
    {
        "school": "NORMAN NORTH HS",
        "district": "NORMAN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172002118",
    },
    {
        "school": "TRUMAN ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172029643",
    },
    {
        "school": "WASHINGTON ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172029644",
    },
    {
        "school": "ROBIN HILL PUBLIC SCHOOL",
        "district": "ROBIN HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402610001380",
    },
    {
        "school": "COYLE ES",
        "district": "COYLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400894000375",
    },
    {
        "school": "COYLE HS",
        "district": "COYLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400894000376",
    },
    {
        "school": "CRESCENT ES",
        "district": "CRESCENT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400900000378",
    },
    {
        "school": "CRESCENT MS",
        "district": "CRESCENT",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400900000379",
    },
    {
        "school": "CRESCENT HS",
        "district": "CRESCENT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400900029697",
    },
    {
        "school": "COTTERAL ES",
        "district": "GUTHRIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401356000630",
    },
    {
        "school": "GUTHRIE UPPER ES",
        "district": "GUTHRIE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401356000631",
    },
    {
        "school": "FOGARTY ES",
        "district": "GUTHRIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401356000632",
    },
    {
        "school": "GUTHRIE HS",
        "district": "GUTHRIE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401356000633",
    },
    {
        "school": "GUTHRIE JHS",
        "district": "GUTHRIE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401356000634",
    },
    {
        "school": "MULHALL-ORLANDO ES",
        "district": "MULHALL-ORLANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402091001029",
    },
    {
        "school": "MULHALL-ORLANDO HS",
        "district": "MULHALL-ORLANDO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402091001030",
    },
    {
        "school": "BLANCHARD ES",
        "district": "BLANCHARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400468000159",
    },
    {
        "school": "BLANCHARD HS",
        "district": "BLANCHARD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400468000160",
    },
    {
        "school": "BLANCHARD MS",
        "district": "BLANCHARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400468002240",
    },
    {
        "school": "DIBBLE ES",
        "district": "DIBBLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400987000426",
    },
    {
        "school": "DIBBLE HS",
        "district": "DIBBLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400987029698",
    },
    {
        "school": "NEWCASTLE ES",
        "district": "NEWCASTLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402151001056",
    },
    {
        "school": "NEWCASTLE HS",
        "district": "NEWCASTLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402151001057",
    },
    {
        "school": "NEWCASTLE MS",
        "district": "NEWCASTLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402151001058",
    },
    {
        "school": "PURCELL ES",
        "district": "PURCELL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402523001327",
    },
    {
        "school": "PURCELL HS",
        "district": "PURCELL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402523001328",
    },
    {
        "school": "PURCELL JHS",
        "district": "PURCELL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402523002239",
    },
    {
        "school": "WASHINGTON ES",
        "district": "WASHINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403171001754",
    },
    {
        "school": "WASHINGTON HS",
        "district": "WASHINGTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403171001755",
    },
    {
        "school": "WASHINGTON MS",
        "district": "WASHINGTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403171002087",
    },
    {
        "school": "WAYNE ES",
        "district": "WAYNE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403201001769",
    },
    {
        "school": "WAYNE HS",
        "district": "WAYNE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403201001770",
    },
    {
        "school": "WAYNE MS",
        "district": "WAYNE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403201029699",
    },
    {
        "school": "BETHANY HS",
        "district": "BETHANY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400411000130",
    },
    {
        "school": "EARL HARRIS ES",
        "district": "BETHANY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400411000131",
    },
    {
        "school": "CHILDREN'S CTR",
        "district": "BETHANY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400411029722",
    },
    {
        "school": "BETHANY MS",
        "district": "BETHANY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400411029723",
    },
    {
        "school": "CHOCTAW ES",
        "district": "CHOCTAW-NICOMA PARK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400762000309",
    },
    {
        "school": "CHOCTAW HS",
        "district": "CHOCTAW-NICOMA PARK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400762000310",
    },
    {
        "school": "INDIAN MERIDIAN ES",
        "district": "CHOCTAW-NICOMA PARK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400762000312",
    },
    {
        "school": "NICOMA PARK INTERMEDIATE ES",
        "district": "CHOCTAW-NICOMA PARK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400762000313",
    },
    {
        "school": "NICOMA PARK ES",
        "district": "CHOCTAW-NICOMA PARK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400762000314",
    },
    {
        "school": "JAMES GRIFFITH INTERMEDIATE ES",
        "district": "CHOCTAW-NICOMA PARK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400762001893",
    },
    {
        "school": "L. W. WESTFALL ES",
        "district": "CHOCTAW-NICOMA PARK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400762001957",
    },
    {
        "school": "CENTRAL OAK ES",
        "district": "CROOKED OAK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400906000380",
    },
    {
        "school": "CROOKED OAK HS",
        "district": "CROOKED OAK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400906000381",
    },
    {
        "school": "CROOKED OAK MS",
        "district": "CROOKED OAK",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400906000382",
    },
    {
        "school": "CRUTCHO PUBLIC SCHOOL",
        "district": "CRUTCHO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400915000386",
    },
    {
        "school": "DEER CREEK ES",
        "district": "DEER CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400957000412",
    },
    {
        "school": "DEER CREEK HS",
        "district": "DEER CREEK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400957000413",
    },
    {
        "school": "DEER CREEK MS",
        "district": "DEER CREEK",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400957000414",
    },
    {
        "school": "PRAIRIE VALE ES",
        "district": "DEER CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400957002243",
    },
    {
        "school": "CHISHOLM ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059000471",
    },
    {
        "school": "CLEGERN ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059000472",
    },
    {
        "school": "MEMORIAL HS",
        "district": "EDMOND",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059000474",
    },
    {
        "school": "CIMARRON MS",
        "district": "EDMOND",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059000475",
    },
    {
        "school": "IDA FREEMAN ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059000477",
    },
    {
        "school": "NORTHERN HILLS ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059000478",
    },
    {
        "school": "ORVIS RISNER ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059000479",
    },
    {
        "school": "SEQUOYAH MS",
        "district": "EDMOND",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059000481",
    },
    {
        "school": "SUNSET ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059000482",
    },
    {
        "school": "WILL ROGERS ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059000483",
    },
    {
        "school": "RUSSELL DOUGHERTY ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059000638",
    },
    {
        "school": "CENTRAL MS",
        "district": "EDMOND",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059001326",
    },
    {
        "school": "SANTA FE HS",
        "district": "EDMOND",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059001360",
    },
    {
        "school": "ANGIE DEBO ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059001864",
    },
    {
        "school": "JOHN ROSS ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059001946",
    },
    {
        "school": "CHARLES HASKELL ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059001965",
    },
    {
        "school": "NORTH HS",
        "district": "EDMOND",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059001979",
    },
    {
        "school": "CHEYENNE MS",
        "district": "EDMOND",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059002303",
    },
    {
        "school": "SUMMIT MS",
        "district": "EDMOND",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059029716",
    },
    {
        "school": "RUSSELL BABB ES",
        "district": "HARRAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401389000654",
    },
    {
        "school": "HARRAH HS",
        "district": "HARRAH",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401389000655",
    },
    {
        "school": "HARRAH MS",
        "district": "HARRAH",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401389000656",
    },
    {
        "school": "VIRGINIA SMITH ES",
        "district": "HARRAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401389001862",
    },
    {
        "school": "CLARA REYNOLDS ES",
        "district": "HARRAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401389001916",
    },
    {
        "school": "JONES HS",
        "district": "JONES",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401584000744",
    },
    {
        "school": "JONES MS",
        "district": "JONES",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401584000745",
    },
    {
        "school": "JONES ES",
        "district": "JONES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401584000746",
    },
    {
        "school": "LUTHER ES",
        "district": "LUTHER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401863000882",
    },
    {
        "school": "LUTHER HS",
        "district": "LUTHER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401863000883",
    },
    {
        "school": "LUTHER MS",
        "district": "LUTHER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401863001949",
    },
    {
        "school": "BARNES ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000950",
    },
    {
        "school": "CLEVELAND BAILEY ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000951",
    },
    {
        "school": "CARL ALBERT HS",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000952",
    },
    {
        "school": "COUNTRY ESTATES ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000954",
    },
    {
        "school": "DEL CITY ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000956",
    },
    {
        "school": "DEL CITY HS",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000957",
    },
    {
        "school": "EPPERLY HEIGHTS ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000959",
    },
    {
        "school": "HIGHLAND PARK ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000960",
    },
    {
        "school": "MIDWEST CITY HS",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000963",
    },
    {
        "school": "PARKVIEW ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000965",
    },
    {
        "school": "PLEASANT HILL EC CTR",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000966",
    },
    {
        "school": "RIDGECREST ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000967",
    },
    {
        "school": "SOLDIER CREEK ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000968",
    },
    {
        "school": "STEED ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000970",
    },
    {
        "school": "TOWNSEND ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995000972",
    },
    {
        "school": "TINKER ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995001922",
    },
    {
        "school": "MILLWOOD ES",
        "district": "MILLWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402008000981",
    },
    {
        "school": "MILLWOOD HS",
        "district": "MILLWOOD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402008002068",
    },
    {
        "school": "FAIRVIEW ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025000992",
    },
    {
        "school": "OAKDALE PUBLIC SCHOOL",
        "district": "OAKDALE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402235001098",
    },
    {
        "school": "ADAMS ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001112",
    },
    {
        "school": "ARTHUR ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001114",
    },
    {
        "school": "BODINE ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001115",
    },
    {
        "school": "BRITTON ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001116",
    },
    {
        "school": "BUCHANAN ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001117",
    },
    {
        "school": "CAPITOL HILL HS",
        "district": "OKLAHOMA CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001119",
    },
    {
        "school": "COOLIDGE ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001125",
    },
    {
        "school": "DOUGLASS HS",
        "district": "OKLAHOMA CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001130",
    },
    {
        "school": "EUGENE FIELD ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001135",
    },
    {
        "school": "FILLMORE ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001136",
    },
    {
        "school": "U. S. GRANT HS",
        "district": "OKLAHOMA CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001139",
    },
    {
        "school": "HAWTHORNE ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001143",
    },
    {
        "school": "HAYES ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001144",
    },
    {
        "school": "HERONVILLE ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001145",
    },
    {
        "school": "HILLCREST ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001146",
    },
    {
        "school": "JEFFERSON MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001150",
    },
    {
        "school": "KAISER ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001152",
    },
    {
        "school": "ADELAIDE LEE ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001154",
    },
    {
        "school": "MARK TWAIN ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001159",
    },
    {
        "school": "M.L. KING JR. ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001161",
    },
    {
        "school": "MONROE ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001163",
    },
    {
        "school": "NORTHWEST CLASSEN HS",
        "district": "OKLAHOMA CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001168",
    },
    {
        "school": "PRAIRIE QUEEN ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001175",
    },
    {
        "school": "QUAIL CREEK ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001177",
    },
    {
        "school": "RIDGEVIEW ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001179",
    },
    {
        "school": "ROCKWOOD ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001181",
    },
    {
        "school": "ROOSEVELT MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001183",
    },
    {
        "school": "SHIDLER ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001186",
    },
    {
        "school": "SPENCER ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001189",
    },
    {
        "school": "ESPERANZA ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001190",
    },
    {
        "school": "STAR SPENCER HS",
        "district": "OKLAHOMA CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001192",
    },
    {
        "school": "SOUTHERN HILLS ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001193",
    },
    {
        "school": "TAFT MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001196",
    },
    {
        "school": "WEBSTER MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001202",
    },
    {
        "school": "WILLOW BROOK ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001207",
    },
    {
        "school": "WILSON ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001208",
    },
    {
        "school": "CLEVELAND ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001866",
    },
    {
        "school": "NICHOLS HILLS ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001872",
    },
    {
        "school": "CLASSEN MS OF ADVANCED STUDIES",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001877",
    },
    {
        "school": "CLASSEN HS OF ADVANCED STUDIES",
        "district": "OKLAHOMA CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001885",
    },
    {
        "school": "SOUTHEAST HS",
        "district": "OKLAHOMA CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001895",
    },
    {
        "school": "EMERSON ALTERNATIVE ED. (HS)",
        "district": "OKLAHOMA CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277001928",
    },
    {
        "school": "THELMA R. PARKS ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002245",
    },
    {
        "school": "BELLE ISLE MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002275",
    },
    {
        "school": "VAN BUREN ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002304",
    },
    {
        "school": "EMERSON ALTERNATIVE ED. (ES)",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002325",
    },
    {
        "school": "EMERSON ALTERNATIVE ED. (MS)",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002326",
    },
    {
        "school": "JAMES L. CAPPS MS",
        "district": "PUTNAM CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001184",
    },
    {
        "school": "COOPER MS",
        "district": "PUTNAM CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001195",
    },
    {
        "school": "HEFNER MS",
        "district": "PUTNAM CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001240",
    },
    {
        "school": "MAYFIELD MS",
        "district": "PUTNAM CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001250",
    },
    {
        "school": "WESTERN OAKS MS",
        "district": "PUTNAM CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001301",
    },
    {
        "school": "APOLLO ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001330",
    },
    {
        "school": "CENTRAL ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001331",
    },
    {
        "school": "ARBOR GROVE ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001332",
    },
    {
        "school": "CORONADO HEIGHTS ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001334",
    },
    {
        "school": "HARVEST HILLS ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001335",
    },
    {
        "school": "HILLDALE ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001337",
    },
    {
        "school": "KIRKLAND EARLY CHILDHOOD CTR",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001338",
    },
    {
        "school": "LAKE PARK ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001339",
    },
    {
        "school": "OVERHOLSER ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001341",
    },
    {
        "school": "PUTNAM CITY HS",
        "district": "PUTNAM CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001342",
    },
    {
        "school": "PUTNAM CITY WEST HS",
        "district": "PUTNAM CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001343",
    },
    {
        "school": "ROLLINGWOOD ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001344",
    },
    {
        "school": "TULAKES ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001345",
    },
    {
        "school": "WILEY POST ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001346",
    },
    {
        "school": "WINDSOR HILLS ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001347",
    },
    {
        "school": "WESTERN OAKS ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001348",
    },
    {
        "school": "PUTNAM CITY NORTH HS",
        "district": "PUTNAM CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001871",
    },
    {
        "school": "DENNIS ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001890",
    },
    {
        "school": "NORTHRIDGE ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001903",
    },
    {
        "school": "WILL ROGERS ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529001951",
    },
    {
        "school": "RALPH DOWNS ES",
        "district": "PUTNAM CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402529029715",
    },
    {
        "school": "COUNCIL GROVE ES",
        "district": "WESTERN HEIGHTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403237001789",
    },
    {
        "school": "WESTERN HEIGHTS MS",
        "district": "WESTERN HEIGHTS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403237002244",
    },
    {
        "school": "JOHN GLENN ES",
        "district": "WESTERN HEIGHTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403237029717",
    },
    {
        "school": "GREENVALE ES",
        "district": "WESTERN HEIGHTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403237029718",
    },
    {
        "school": "WINDS WEST ES",
        "district": "WESTERN HEIGHTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403237029719",
    },
    {
        "school": "WESTERN HEIGHTS HS",
        "district": "WESTERN HEIGHTS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403237029721",
    },
    {
        "school": "ROOSEVELT ES",
        "district": "PONCA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402469002367",
    },
    {
        "school": "BLACKWELL HS",
        "district": "BLACKWELL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400463000151",
    },
    {
        "school": "BLACKWELL MS",
        "district": "BLACKWELL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400463000152",
    },
    {
        "school": "KILDARE PUBLIC SCHOOL",
        "district": "KILDARE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401653000769",
    },
    {
        "school": "NEWKIRK ES",
        "district": "NEWKIRK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402154001059",
    },
    {
        "school": "NEWKIRK MS",
        "district": "NEWKIRK",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402154001986",
    },
    {
        "school": "NEWKIRK HS",
        "district": "NEWKIRK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402154002071",
    },
    {
        "school": "PECKHAM PUBLIC SCHOOL",
        "district": "PECKHAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402370001257",
    },
    {
        "school": "E. M. TROUT ES",
        "district": "PONCA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402469001290",
    },
    {
        "school": "LIBERTY ES",
        "district": "PONCA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402469001294",
    },
    {
        "school": "LINCOLN ES",
        "district": "PONCA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402469001295",
    },
    {
        "school": "PONCA CITY HS",
        "district": "PONCA CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402469001296",
    },
    {
        "school": "WOODLANDS ES",
        "district": "PONCA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402469001300",
    },
    {
        "school": "UNION ES",
        "district": "PONCA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402469002004",
    },
    {
        "school": "PONCA CITY WEST MS",
        "district": "PONCA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402469002124",
    },
    {
        "school": "PONCA CITY EAST MS",
        "district": "PONCA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402469002288",
    },
    {
        "school": "TONKAWA ES",
        "district": "TONKAWA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403012001576",
    },
    {
        "school": "TONKAWA MS",
        "district": "TONKAWA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403012002236",
    },
    {
        "school": "TONKAWA HS",
        "district": "TONKAWA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403012029686",
    },
    {
        "school": "MCCORD PUBLIC SCHOOL",
        "district": "MCCORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401950000928",
    },
    {
        "school": "ASHER ES",
        "district": "ASHER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400330000082",
    },
    {
        "school": "ASHER HS",
        "district": "ASHER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400330000083",
    },
    {
        "school": "BETHEL ES",
        "district": "BETHEL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400423000132",
    },
    {
        "school": "BETHEL HS",
        "district": "BETHEL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400423000133",
    },
    {
        "school": "BETHEL MS",
        "district": "BETHEL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400423001417",
    },
    {
        "school": "DALE ES",
        "district": "DALE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400939000402",
    },
    {
        "school": "DALE HS",
        "district": "DALE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400939001994",
    },
    {
        "school": "EARLSBORO HS",
        "district": "EARLSBORO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401050000468",
    },
    {
        "school": "EARLSBORO ES",
        "district": "EARLSBORO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401050000469",
    },
    {
        "school": "GROVE PUBLIC SCHOOL",
        "district": "GROVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401350000624",
    },
    {
        "school": "MACOMB ES",
        "district": "MACOMB",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401866000884",
    },
    {
        "school": "MACOMB HS",
        "district": "MACOMB",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401866000885",
    },
    {
        "school": "MAUD ES",
        "district": "MAUD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401929000911",
    },
    {
        "school": "MAUD HS",
        "district": "MAUD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401929000912",
    },
    {
        "school": "MCLOUD ES",
        "district": "MCLOUD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401956000931",
    },
    {
        "school": "MCLOUD HS",
        "district": "MCLOUD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401956000932",
    },
    {
        "school": "MCLOUD JHS",
        "district": "MCLOUD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401956000933",
    },
    {
        "school": "PLEASANT GROVE PUBLIC SCHOOL",
        "district": "PLEASANT GROVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402433001281",
    },
    {
        "school": "SHAWNEE MS",
        "district": "SHAWNEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402757000728",
    },
    {
        "school": "SHAWNEE EC CTR",
        "district": "SHAWNEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402757001457",
    },
    {
        "school": "HORACE MANN ES",
        "district": "SHAWNEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402757001458",
    },
    {
        "school": "JEFFERSON ES",
        "district": "SHAWNEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402757001459",
    },
    {
        "school": "SEQUOYAH ES",
        "district": "SHAWNEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402757001462",
    },
    {
        "school": "SHAWNEE HS",
        "district": "SHAWNEE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402757001463",
    },
    {
        "school": "WILL ROGERS ES",
        "district": "SHAWNEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402757001466",
    },
    {
        "school": "SOUTH ROCK CREEK PUBLIC SCHOOL",
        "district": "SOUTH ROCK CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402799001486",
    },
    {
        "school": "BARNARD ES",
        "district": "TECUMSEH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402961001552",
    },
    {
        "school": "TECUMSEH EARLY CHILDHOOD CTR",
        "district": "TECUMSEH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402961001554",
    },
    {
        "school": "TECUMSEH HS",
        "district": "TECUMSEH",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402961001555",
    },
    {
        "school": "TECUMSEH MS",
        "district": "TECUMSEH",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402961001556",
    },
    {
        "school": "CROSS TIMBERS ES",
        "district": "TECUMSEH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402961029610",
    },
    {
        "school": "WANETTE ES",
        "district": "WANETTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403150001744",
    },
    {
        "school": "WANETTE HS",
        "district": "WANETTE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403150001745",
    },
    {
        "school": "PERKINS-TRYON INTERMEDIATE ES",
        "district": "PERKINS-TRYON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402380002378",
    },
    {
        "school": "PERKINS-TRYON MS",
        "district": "PERKINS-TRYON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402380002379",
    },
    {
        "school": "CUSHING HS",
        "district": "CUSHING",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400924000387",
    },
    {
        "school": "CUSHING MS",
        "district": "CUSHING",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400924000388",
    },
    {
        "school": "CUSHING PRE-KINDERGARTEN SCHL",
        "district": "CUSHING",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400924002291",
    },
    {
        "school": "GLENCOE ES",
        "district": "GLENCOE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401269000591",
    },
    {
        "school": "GLENCOE HS",
        "district": "GLENCOE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401269000592",
    },
    {
        "school": "OAK GROVE PUBLIC SCHOOL",
        "district": "OAK GROVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402216001097",
    },
    {
        "school": "PERKINS-TRYON ES",
        "district": "PERKINS-TRYON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402380001259",
    },
    {
        "school": "PERKINS-TRYON HS",
        "district": "PERKINS-TRYON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402380001260",
    },
    {
        "school": "RIPLEY ES",
        "district": "RIPLEY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402595001377",
    },
    {
        "school": "RIPLEY HS",
        "district": "RIPLEY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402595001378",
    },
    {
        "school": "HIGHLAND PARK ES",
        "district": "STILLWATER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402868029734",
    },
    {
        "school": "SANGRE RIDGE ES",
        "district": "STILLWATER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402868029735",
    },
    {
        "school": "SKYLINE ES",
        "district": "STILLWATER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402868029736",
    },
    {
        "school": "WESTWOOD ES",
        "district": "STILLWATER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402868029737",
    },
    {
        "school": "WILL ROGERS ES",
        "district": "STILLWATER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402868029738",
    },
    {
        "school": "RICHMOND ES",
        "district": "STILLWATER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402868029739",
    },
    {
        "school": "STILLWATER MS",
        "district": "STILLWATER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402868029740",
    },
    {
        "school": "STILLWATER JHS",
        "district": "STILLWATER",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402868029741",
    },
    {
        "school": "STILLWATER HS",
        "district": "STILLWATER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402868029742",
    },
    {
        "school": "YALE ES",
        "district": "YALE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403336001838",
    },
    {
        "school": "YALE MS",
        "district": "YALE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403336001839",
    },
    {
        "school": "YALE HS",
        "district": "YALE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403336029743",
    },
    {
        "school": "KEYS ES",
        "district": "KEYS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400003302299",
    },
    {
        "school": "KEYS HS",
        "district": "KEYS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400003302300",
    },
    {
        "school": "BRIGGS PUBLIC SCHOOL",
        "district": "BRIGGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400543000192",
    },
    {
        "school": "GRAND VIEW PUBLIC SCHOOL",
        "district": "GRAND VIEW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401323000614",
    },
    {
        "school": "HULBERT MS",
        "district": "HULBERT",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401524000101",
    },
    {
        "school": "HULBERT ES",
        "district": "HULBERT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401524000717",
    },
    {
        "school": "HULBERT JR-SR HS (SR)",
        "district": "HULBERT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401524029639",
    },
    {
        "school": "LOWREY PUBLIC SCHOOL",
        "district": "LOWREY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401848000880",
    },
    {
        "school": "NORWOOD PUBLIC SCHOOL",
        "district": "NORWOOD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402190001092",
    },
    {
        "school": "PEGGS PUBLIC SCHOOL",
        "district": "PEGGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402373001258",
    },
    {
        "school": "SHADY GROVE PUBLIC SCHOOL",
        "district": "SHADY GROVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402742001448",
    },
    {
        "school": "CHEROKEE ES",
        "district": "TAHLEQUAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402938001541",
    },
    {
        "school": "GREENWOOD ES",
        "district": "TAHLEQUAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402938001542",
    },
    {
        "school": "SEQUOYAH ES",
        "district": "TAHLEQUAH",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402938001543",
    },
    {
        "school": "TAHLEQUAH HS",
        "district": "TAHLEQUAH",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402938001544",
    },
    {
        "school": "TENKILLER PUBLIC SCHOOL",
        "district": "TENKILLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402967001559",
    },
    {
        "school": "WOODALL PUBLIC SCHOOL",
        "district": "WOODALL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403309001819",
    },
    {
        "school": "KELLYVILLE UPPER ES",
        "district": "KELLYVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401617002340",
    },
    {
        "school": "RONGEY MS",
        "district": "KIEFER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401650002371",
    },
    {
        "school": "FREEDOM ES",
        "district": "SAPULPA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402691002341",
    },
    {
        "school": "OOLOGAH-TALALA UPPER ES",
        "district": "OOLOGAH-TALALA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402304002351",
    },
    {
        "school": "CLYDE BOYD MS",
        "district": "SAND SPRINGS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402688002382",
    },
    {
        "school": "CENTRAL 9TH GRADE CTR",
        "district": "SAND SPRINGS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402688002383",
    },
    {
        "school": "HENRY ZARROW INTERNATIONAL SCH",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002352",
    },
    {
        "school": "LIBERTY ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002362",
    },
    {
        "school": "BEGGS ES",
        "district": "BEGGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400381000118",
    },
    {
        "school": "BEGGS HS",
        "district": "BEGGS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400381000119",
    },
    {
        "school": "BEGGS MS",
        "district": "BEGGS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400381000120",
    },
    {
        "school": "DEWAR ES",
        "district": "DEWAR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400978000420",
    },
    {
        "school": "DEWAR HS",
        "district": "DEWAR",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400978029725",
    },
    {
        "school": "HENRYETTA ES",
        "district": "HENRYETTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401437000679",
    },
    {
        "school": "HENRYETTA HS",
        "district": "HENRYETTA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401437000680",
    },
    {
        "school": "HENRYETTA MS",
        "district": "HENRYETTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401437001896",
    },
    {
        "school": "MORRIS ES",
        "district": "MORRIS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402031001007",
    },
    {
        "school": "MORRIS HS",
        "district": "MORRIS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402031001008",
    },
    {
        "school": "MORRIS MS",
        "district": "MORRIS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402031001009",
    },
    {
        "school": "DUNBAR INTERMEDIATE ES",
        "district": "OKMULGEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402280001211",
    },
    {
        "school": "OKMULGEE HS",
        "district": "OKMULGEE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402280001212",
    },
    {
        "school": "OKMULGEE PRIMARY ES",
        "district": "OKMULGEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402280001214",
    },
    {
        "school": "PRESTON ES",
        "district": "PRESTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402505001314",
    },
    {
        "school": "PRESTON HS",
        "district": "PRESTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402505001315",
    },
    {
        "school": "SCHULTER ES",
        "district": "SCHULTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402709001434",
    },
    {
        "school": "SCHULTER HS",
        "district": "SCHULTER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402709001435",
    },
    {
        "school": "TWIN HILLS PUBLIC SCHOOL",
        "district": "TWIN HILLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403045001697",
    },
    {
        "school": "WILSON ES",
        "district": "WILSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403288001813",
    },
    {
        "school": "WILSON HS",
        "district": "WILSON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403288001814",
    },
    {
        "school": "CLEVELAND PRIMARY ES",
        "district": "CLEVELAND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400804000331",
    },
    {
        "school": "CLEVELAND HS",
        "district": "CLEVELAND",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400804000332",
    },
    {
        "school": "CLEVELAND MS",
        "district": "CLEVELAND",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400804000333",
    },
    {
        "school": "CLEVELAND INTERMEDIATE ES",
        "district": "CLEVELAND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400804000335",
    },
    {
        "school": "JENNINGS PUBLIC SCHOOL",
        "district": "JENNINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401575000741",
    },
    {
        "school": "PAWNEE ES",
        "district": "PAWNEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402361001254",
    },
    {
        "school": "PAWNEE HS",
        "district": "PAWNEE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402361001255",
    },
    {
        "school": "PAWNEE MS",
        "district": "PAWNEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402361002090",
    },
    {
        "school": "ALLEN-BOWDEN PUBLIC SCHOOL",
        "district": "ALLEN-BOWDEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400279000027",
    },
    {
        "school": "BRISTOW HS",
        "district": "BRISTOW",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400546000193",
    },
    {
        "school": "EDISON ES",
        "district": "BRISTOW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400546000195",
    },
    {
        "school": "COLLINS ES",
        "district": "BRISTOW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400546000196",
    },
    {
        "school": "BRISTOW MS",
        "district": "BRISTOW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400546002083",
    },
    {
        "school": "DEPEW ES",
        "district": "DEPEW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400975000418",
    },
    {
        "school": "DEPEW HS",
        "district": "DEPEW",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400975000419",
    },
    {
        "school": "BRADLEY ES",
        "district": "DRUMRIGHT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401020000440",
    },
    {
        "school": "DRUMRIGHT HS",
        "district": "DRUMRIGHT",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401020000441",
    },
    {
        "school": "GYPSY PUBLIC SCHOOL",
        "district": "GYPSY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401360000643",
    },
    {
        "school": "KELLYVILLE MS",
        "district": "KELLYVILLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401617000154",
    },
    {
        "school": "KELLYVILLE ES",
        "district": "KELLYVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401617000753",
    },
    {
        "school": "KELLYVILLE HS",
        "district": "KELLYVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401617000754",
    },
    {
        "school": "KIEFER ES",
        "district": "KIEFER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401650000767",
    },
    {
        "school": "KIEFER HS",
        "district": "KIEFER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401650000768",
    },
    {
        "school": "LONE STAR PUBLIC SCHOOL",
        "district": "LONE STAR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401824000872",
    },
    {
        "school": "MANNFORD LOWER ES",
        "district": "MANNFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401884000893",
    },
    {
        "school": "MANNFORD HS",
        "district": "MANNFORD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401884000894",
    },
    {
        "school": "MANNFORD MS",
        "district": "MANNFORD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401884000895",
    },
    {
        "school": "MANNFORD UPPER ES",
        "district": "MANNFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401884002301",
    },
    {
        "school": "MOUNDS ES",
        "district": "MOUNDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402055001018",
    },
    {
        "school": "MOUNDS HS",
        "district": "MOUNDS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402055001019",
    },
    {
        "school": "J. F. KENNEDY ES",
        "district": "OILTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402256001102",
    },
    {
        "school": "OILTON HS",
        "district": "OILTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402256001103",
    },
    {
        "school": "OLIVE ES",
        "district": "OLIVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402286001217",
    },
    {
        "school": "OLIVE HS",
        "district": "OLIVE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402286029655",
    },
    {
        "school": "PRETTY WATER PUBLIC SCHOOL",
        "district": "PRETTY WATER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402508001316",
    },
    {
        "school": "LIBERTY ES",
        "district": "SAPULPA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402691001419",
    },
    {
        "school": "SAPULPA HS",
        "district": "SAPULPA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402691001422",
    },
    {
        "school": "SAPULPA MS",
        "district": "SAPULPA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402691001882",
    },
    {
        "school": "SAPULPA JHS",
        "district": "SAPULPA",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402691002223",
    },
    {
        "school": "ANDERSON PUBLIC SCHOOL",
        "district": "ANDERSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400301000056",
    },
    {
        "school": "AVANT PUBLIC SCHOOL",
        "district": "AVANT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400345000088",
    },
    {
        "school": "BARNSDALL ES",
        "district": "BARNSDALL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400357000092",
    },
    {
        "school": "BARNSDALL JHS",
        "district": "BARNSDALL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400357000093",
    },
    {
        "school": "BOWRING PUBLIC SCHOOL",
        "district": "BOWRING",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400516000181",
    },
    {
        "school": "HOMINY HS",
        "district": "HOMINY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401497000703",
    },
    {
        "school": "HOMINY MS",
        "district": "HOMINY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401497000704",
    },
    {
        "school": "HORACE MANN ES",
        "district": "HOMINY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401497000705",
    },
    {
        "school": "INDIAN CAMP ES",
        "district": "PAWHUSKA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402358000145",
    },
    {
        "school": "PAWHUSKA ES",
        "district": "PAWHUSKA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402358001251",
    },
    {
        "school": "PAWHUSKA HS",
        "district": "PAWHUSKA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402358001252",
    },
    {
        "school": "PRUE ES",
        "district": "PRUE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402517001318",
    },
    {
        "school": "PRUE HS",
        "district": "PRUE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402517001319",
    },
    {
        "school": "WARD ES",
        "district": "SHIDLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402763001468",
    },
    {
        "school": "SHIDLER HS",
        "district": "SHIDLER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402763029726",
    },
    {
        "school": "MARRS ES",
        "district": "SKIATOOK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402775001474",
    },
    {
        "school": "SKIATOOK HS",
        "district": "SKIATOOK",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402775001475",
    },
    {
        "school": "NEWMAN MS",
        "district": "SKIATOOK",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402775001476",
    },
    {
        "school": "WOODLAND ES",
        "district": "WOODLAND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403004829728",
    },
    {
        "school": "WOODLAND UPPER ES",
        "district": "WOODLAND",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403004829729",
    },
    {
        "school": "WOODLAND HS",
        "district": "WOODLAND",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403004829730",
    },
    {
        "school": "CENTRAL HS",
        "district": "TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001596",
    },
    {
        "school": "ACADEMY CENTRAL ES",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029854",
    },
    {
        "school": "WYNONA ES",
        "district": "WYNONA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403333001836",
    },
    {
        "school": "WYNONA HS",
        "district": "WYNONA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403333001837",
    },
    {
        "school": "CATOOSA HS",
        "district": "CATOOSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400687000270",
    },
    {
        "school": "WELLS MS",
        "district": "CATOOSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400687000811",
    },
    {
        "school": "HELEN PAUL LEARNING CTR",
        "district": "CATOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400687002309",
    },
    {
        "school": "CHEROKEE ES",
        "district": "CATOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400687029754",
    },
    {
        "school": "CHELSEA HS",
        "district": "CHELSEA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400738000293",
    },
    {
        "school": "ART GOAD ES",
        "district": "CHELSEA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400738001913",
    },
    {
        "school": "CHELSEA MS",
        "district": "CHELSEA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400738002310",
    },
    {
        "school": "CLAREMONT ES",
        "district": "CLAREMORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400774000321",
    },
    {
        "school": "CLAREMORE HS",
        "district": "CLAREMORE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400774000322",
    },
    {
        "school": "ROOSA ES",
        "district": "CLAREMORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400774000324",
    },
    {
        "school": "WESTSIDE ES",
        "district": "CLAREMORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400774000325",
    },
    {
        "school": "WILL ROGERS JHS",
        "district": "CLAREMORE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400774002197",
    },
    {
        "school": "FOYIL ES",
        "district": "FOYIL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401209000564",
    },
    {
        "school": "FOYIL HS",
        "district": "FOYIL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401209000565",
    },
    {
        "school": "FOYIL JHS",
        "district": "FOYIL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401209000847",
    },
    {
        "school": "INOLA ES",
        "district": "INOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401548000733",
    },
    {
        "school": "INOLA MS",
        "district": "INOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401548000734",
    },
    {
        "school": "INOLA HS",
        "district": "INOLA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401548029755",
    },
    {
        "school": "JUSTUS-TIAWAH PUBLIC SCHOOL",
        "district": "JUSTUS-TIAWAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401593000749",
    },
    {
        "school": "OOLOGAH-TALALA LOWER ES",
        "district": "OOLOGAH-TALALA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402304001227",
    },
    {
        "school": "OOLOGAH-TALALA HS",
        "district": "OOLOGAH-TALALA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402304001228",
    },
    {
        "school": "OOLOGAH-TALALA MS",
        "district": "OOLOGAH-TALALA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402304001229",
    },
    {
        "school": "PAMELA HODSON ES",
        "district": "OWASSO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328029812",
    },
    {
        "school": "SEQUOYAH ES",
        "district": "SEQUOYAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402739001445",
    },
    {
        "school": "SEQUOYAH HS",
        "district": "SEQUOYAH",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402739001446",
    },
    {
        "school": "VERDIGRIS ES",
        "district": "VERDIGRIS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403111001723",
    },
    {
        "school": "VERDIGRIS JHS",
        "district": "VERDIGRIS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403111002277",
    },
    {
        "school": "VERDIGRIS HS",
        "district": "VERDIGRIS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403111002278",
    },
    {
        "school": "BARNSDALL HS",
        "district": "BARNSDALL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400357029727",
    },
    {
        "school": "BERRYHILL ES SOUTH",
        "district": "BERRYHILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400402000126",
    },
    {
        "school": "BERRYHILL HS",
        "district": "BERRYHILL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400402000127",
    },
    {
        "school": "BERRYHILL MS",
        "district": "BERRYHILL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400402000128",
    },
    {
        "school": "CENTRAL ES",
        "district": "BIXBY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400450000147",
    },
    {
        "school": "BIXBY HS",
        "district": "BIXBY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400450000148",
    },
    {
        "school": "BIXBY MS",
        "district": "BIXBY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400450002097",
    },
    {
        "school": "BIXBY NORTH ES",
        "district": "BIXBY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400450002334",
    },
    {
        "school": "ARROWHEAD ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549000197",
    },
    {
        "school": "CENTENNIAL MS",
        "district": "BROKEN ARROW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549000200",
    },
    {
        "school": "RHOADES ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549000203",
    },
    {
        "school": "SEQUOYAH MS",
        "district": "BROKEN ARROW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549000205",
    },
    {
        "school": "VANDEVER ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549000207",
    },
    {
        "school": "COUNTRY LANE PRIMARY ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549001460",
    },
    {
        "school": "LYNN WOOD ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549001876",
    },
    {
        "school": "OLIVER MS",
        "district": "BROKEN ARROW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002095",
    },
    {
        "school": "LEISURE PARK ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549029804",
    },
    {
        "school": "SPRING CREEK ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549029806",
    },
    {
        "school": "CHILDERS MS",
        "district": "BROKEN ARROW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549029807",
    },
    {
        "school": "WOLF CREEK ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549029849",
    },
    {
        "school": "COLLINSVILLE HS",
        "district": "COLLINSVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400837000349",
    },
    {
        "school": "COLLINSVILLE MS",
        "district": "COLLINSVILLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400837000350",
    },
    {
        "school": "GLENPOOL ES",
        "district": "GLENPOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401272000593",
    },
    {
        "school": "GLENPOOL HS",
        "district": "GLENPOOL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401272000594",
    },
    {
        "school": "GLENPOOL MS",
        "district": "GLENPOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401272001981",
    },
    {
        "school": "JENKS HS",
        "district": "JENKS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401572000739",
    },
    {
        "school": "JENKS MS",
        "district": "JENKS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401572000740",
    },
    {
        "school": "JENKS EAST ES",
        "district": "JENKS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401572001878",
    },
    {
        "school": "JENKS WEST ES",
        "district": "JENKS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401572001919",
    },
    {
        "school": "JENKS WEST INTERMEDIATE ES",
        "district": "JENKS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401572002251",
    },
    {
        "school": "JENKS EAST INTERMEDIATE ES",
        "district": "JENKS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401572002314",
    },
    {
        "school": "SOUTHEAST ES",
        "district": "JENKS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401572029850",
    },
    {
        "school": "KEYSTONE PUBLIC SCHOOL",
        "district": "KEYSTONE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401647000766",
    },
    {
        "school": "LIBERTY ES",
        "district": "LIBERTY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401776000858",
    },
    {
        "school": "LIBERTY HS",
        "district": "LIBERTY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401776000859",
    },
    {
        "school": "ATOR ES",
        "district": "OWASSO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328001233",
    },
    {
        "school": "BARNES ES",
        "district": "OWASSO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328001234",
    },
    {
        "school": "OWASSO HS",
        "district": "OWASSO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328001235",
    },
    {
        "school": "OWASSO 7TH GRADE CTR",
        "district": "OWASSO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328001236",
    },
    {
        "school": "MILLS ES",
        "district": "OWASSO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328001881",
    },
    {
        "school": "LARKIN BAILEY ES",
        "district": "OWASSO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328001907",
    },
    {
        "school": "HAYWARD SMITH ES",
        "district": "OWASSO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328002003",
    },
    {
        "school": "OWASSO 6TH GRADE CTR",
        "district": "OWASSO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328002253",
    },
    {
        "school": "NORTHEAST ES",
        "district": "OWASSO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328002336",
    },
    {
        "school": "OWASSO 8TH GRADE CTR",
        "district": "OWASSO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328029813",
    },
    {
        "school": "NORTHWOODS FINE ARTS ACADEMY",
        "district": "SAND SPRINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402688001404",
    },
    {
        "school": "CHARLES PAGE HS",
        "district": "SAND SPRINGS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402688001405",
    },
    {
        "school": "GARFIELD ES",
        "district": "SAND SPRINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402688001407",
    },
    {
        "school": "LIMESTONE ES",
        "district": "SAND SPRINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402688001412",
    },
    {
        "school": "PRATT ES",
        "district": "SAND SPRINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402688001413",
    },
    {
        "school": "SAND SPRINGS EC CTR",
        "district": "SAND SPRINGS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402688001904",
    },
    {
        "school": "ANGUS VALLEY ES",
        "district": "SAND SPRINGS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402688001932",
    },
    {
        "school": "SKIATOOK INTERMEDIATE ES",
        "district": "SKIATOOK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402775002297",
    },
    {
        "school": "SPERRY HS",
        "district": "SPERRY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402817001490",
    },
    {
        "school": "SPERRY MS",
        "district": "SPERRY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402817001491",
    },
    {
        "school": "SPERRY ES",
        "district": "SPERRY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402817002316",
    },
    {
        "school": "EISENHOWER INTERNATIONAL ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024000989",
    },
    {
        "school": "MAYO DEMONSTRATION ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001017",
    },
    {
        "school": "ANDERSON ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001581",
    },
    {
        "school": "BOOKER T. WASHINGTON HS",
        "district": "TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001583",
    },
    {
        "school": "BELL ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001586",
    },
    {
        "school": "MEMORIAL JHS",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001591",
    },
    {
        "school": "CARVER MS",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001594",
    },
    {
        "school": "WAYMAN TISDALE FINE ARTS ACAD",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001599",
    },
    {
        "school": "DANIEL WEBSTER MS",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001601",
    },
    {
        "school": "EAST CENTRAL HS",
        "district": "TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001607",
    },
    {
        "school": "THOMAS EDISON PREPARATORY HS",
        "district": "TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001608",
    },
    {
        "school": "EDISON PREPARATORY MS",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001609",
    },
    {
        "school": "EUGENE FIELD ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001613",
    },
    {
        "school": "EAST CENTRAL JHS",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001614",
    },
    {
        "school": "HAMILTON ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001622",
    },
    {
        "school": "LEWIS AND CLARK ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001636",
    },
    {
        "school": "MARK TWAIN ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001644",
    },
    {
        "school": "MCLAIN HS FOR SCIENCE AND TECH",
        "district": "TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001649",
    },
    {
        "school": "MEMORIAL HS",
        "district": "TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001650",
    },
    {
        "school": "NATHAN HALE HS",
        "district": "TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001653",
    },
    {
        "school": "ROBERTSON ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001666",
    },
    {
        "school": "SPRINGDALE ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001672",
    },
    {
        "school": "DANIEL WEBSTER HS",
        "district": "TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001675",
    },
    {
        "school": "WHITMAN ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001676",
    },
    {
        "school": "HALE JHS",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001677",
    },
    {
        "school": "WILL ROGERS COLLEGE HS",
        "district": "TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024001679",
    },
    {
        "school": "KENDALL-WHITTIER ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002249",
    },
    {
        "school": "JOHN HOPE FRANKLIN ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002280",
    },
    {
        "school": "THOREAU DEMONSTRATION ACADEMY",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002281",
    },
    {
        "school": "OWEN ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002332",
    },
    {
        "school": "TULSA MET JHS",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029767",
    },
    {
        "school": "BURROUGHS ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029768",
    },
    {
        "school": "CARNEGIE ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029769",
    },
    {
        "school": "CELIA CLINTON ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029770",
    },
    {
        "school": "DOLORES HUERTA ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029771",
    },
    {
        "school": "COOPER ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029772",
    },
    {
        "school": "ELIOT ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029774",
    },
    {
        "school": "EMERSON ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029775",
    },
    {
        "school": "GRIMES ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029776",
    },
    {
        "school": "HAWTHORNE ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029777",
    },
    {
        "school": "PATRICK HENRY ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029778",
    },
    {
        "school": "HOOVER ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029779",
    },
    {
        "school": "UNITY LEARNING ACADEMY",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029780",
    },
    {
        "school": "KERR ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029782",
    },
    {
        "school": "KEY ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029783",
    },
    {
        "school": "LANIER ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029784",
    },
    {
        "school": "COUNCIL OAK ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029785",
    },
    {
        "school": "LINDBERGH ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029786",
    },
    {
        "school": "MACARTHUR ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029787",
    },
    {
        "school": "MARSHALL ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029788",
    },
    {
        "school": "MCCLURE ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029789",
    },
    {
        "school": "MCKINLEY ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029790",
    },
    {
        "school": "MITCHELL ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029791",
    },
    {
        "school": "PEARY ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029792",
    },
    {
        "school": "SALK ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029794",
    },
    {
        "school": "SEQUOYAH ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029796",
    },
    {
        "school": "SKELLY ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029797",
    },
    {
        "school": "WRIGHT ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029798",
    },
    {
        "school": "DISNEY ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029799",
    },
    {
        "school": "GRISSOM ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024029800",
    },
    {
        "school": "UNION 6TH-7TH GRADE CTR",
        "district": "UNION",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060001461",
    },
    {
        "school": "UNION 8TH GRADE CTR",
        "district": "UNION",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060001525",
    },
    {
        "school": "UNION HS FRESHMAN ACADEMY",
        "district": "UNION",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060001526",
    },
    {
        "school": "BOEVERS ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060001700",
    },
    {
        "school": "GROVE ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060001702",
    },
    {
        "school": "CLARK ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060001703",
    },
    {
        "school": "UNION HS",
        "district": "UNION",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060001704",
    },
    {
        "school": "PETERS ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060001883",
    },
    {
        "school": "DARNABY ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060001911",
    },
    {
        "school": "CEDAR RIDGE ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060002099",
    },
    {
        "school": "MARSHALL T. MOORE ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060002317",
    },
    {
        "school": "ANDERSEN ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060029809",
    },
    {
        "school": "MCAULIFFE ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060029810",
    },
    {
        "school": "JARMAN ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060029851",
    },
    {
        "school": "HIGHLAND PARK ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549029802",
    },
    {
        "school": "CENTRAL ES",
        "district": "COWETA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400885000372",
    },
    {
        "school": "COWETA HS",
        "district": "COWETA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400885000373",
    },
    {
        "school": "DONALD P SLOAT JHS",
        "district": "COWETA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400885000374",
    },
    {
        "school": "NORTHWEST ES",
        "district": "COWETA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400885001915",
    },
    {
        "school": "SOUTHSIDE ES",
        "district": "COWETA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400885002337",
    },
    {
        "school": "MISSION INTERMEDIATE GRD CTR",
        "district": "COWETA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400885029814",
    },
    {
        "school": "OKAY ES",
        "district": "OKAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402262001106",
    },
    {
        "school": "OKAY HS",
        "district": "OKAY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402262001107",
    },
    {
        "school": "PORTER CONSOLIDATED ES",
        "district": "PORTER CONSOLIDATED",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403019701304",
    },
    {
        "school": "PORTER CONSOLIDATED HS",
        "district": "PORTER CONSOLIDATED",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403019701305",
    },
    {
        "school": "WAGONER MS",
        "district": "WAGONER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403135001536",
    },
    {
        "school": "ELLINGTON ES",
        "district": "WAGONER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403135001735",
    },
    {
        "school": "WILLIAM R. TEAGUE ES",
        "district": "WAGONER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403135001736",
    },
    {
        "school": "WAGONER HS",
        "district": "WAGONER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403135001737",
    },
    {
        "school": "CENTRAL INTERMEDIATE ES",
        "district": "WAGONER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403135001909",
    },
    {
        "school": "FORT SUPPLY ES",
        "district": "FORT SUPPLY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401200000560",
    },
    {
        "school": "FORT SUPPLY HS",
        "district": "FORT SUPPLY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401200000561",
    },
    {
        "school": "MOORELAND ES",
        "district": "MOORELAND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402028001005",
    },
    {
        "school": "MOORELAND HS",
        "district": "MOORELAND",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402028029839",
    },
    {
        "school": "SHARON-MUTUAL ES",
        "district": "SHARON-MUTUAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402103001049",
    },
    {
        "school": "SHARON-MUTUAL HS",
        "district": "SHARON-MUTUAL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402103001050",
    },
    {
        "school": "CEDAR HEIGHTS ES",
        "district": "WOODWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403318001820",
    },
    {
        "school": "HORACE MANN ES",
        "district": "WOODWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403318029832",
    },
    {
        "school": "WOODWARD EC CTR",
        "district": "WOODWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403318029834",
    },
    {
        "school": "HIGHLAND PARK ES",
        "district": "WOODWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403318029835",
    },
    {
        "school": "WOODWARD HS",
        "district": "WOODWARD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403318029838",
    },
    {
        "school": "WOODWARD MS SOUTH CAMPUS",
        "district": "WOODWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403318029852",
    },
    {
        "school": "Baker Prairie Middle School",
        "district": "Canby SD 86",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410264001651",
    },
    {
        "school": "Philander Lee Elementary School",
        "district": "Canby SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410264001659",
    },
    {
        "school": "Cascade Heights Public Charter School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001658",
    },
    {
        "school": "Milwaukie Academy of the Arts",
        "district": "North Clackamas SD 12",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001686",
    },
    {
        "school": "Springwater Environmental Sciences School",
        "district": "Oregon City SD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933001642",
    },
    {
        "school": "Oregon City Service Learning Academy",
        "district": "Oregon City SD 62",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933001666",
    },
    {
        "school": "North Columbia Academy",
        "district": "Rainier SD 13",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410326501670",
    },
    {
        "school": "Vernonia Middle School",
        "district": "Vernonia SD 47J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411293001673",
    },
    {
        "school": "Pioneer Secondary Alternative High School",
        "district": "Crook County SD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410372001682",
    },
    {
        "school": "Tom McCall Elementary School",
        "district": "Redmond SD 2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035001645",
    },
    {
        "school": "Phoenix School",
        "district": "Douglas County SD 4",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071001685",
    },
    {
        "school": "John Muir Outdoor School",
        "district": "Ashland SD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410156001654",
    },
    {
        "school": "URCEO-Upper Rogue Center for Educational Opportunities",
        "district": "Eagle Point SD 9",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410450001681",
    },
    {
        "school": "Sage Community School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702001688",
    },
    {
        "school": "Childs Way Charter School",
        "district": "South Lane SD 45J3",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411158001677",
    },
    {
        "school": "Academy of Arts and Academics",
        "district": "Springfield SD 19",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167001641",
    },
    {
        "school": "Sweet Home Charter School",
        "district": "Sweet Home SD 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411197001643",
    },
    {
        "school": "Valley Inquiry Charter School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001683",
    },
    {
        "school": "Ron Russell Middle School",
        "district": "David Douglas SD 40",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001676",
    },
    {
        "school": "Portland Village School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001649",
    },
    {
        "school": "Alliance High School",
        "district": "Portland SD 1J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "411004001652",
    },
    {
        "school": "Portland Arthur Academy Charter School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001667",
    },
    {
        "school": "Eola Hills Charter School",
        "district": "Amity SD 4J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410123001653",
    },
    {
        "school": "Neah-Kah-Nie Middle School",
        "district": "Neah-Kah-Nie SD 56",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410865001656",
    },
    {
        "school": "Hawthorne Alternative High School",
        "district": "Pendleton SD 16",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410951001689",
    },
    {
        "school": "International School of Beaverton",
        "district": "Beaverton SD 48J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001647",
    },
    {
        "school": "Sherwood Charter School",
        "district": "Sherwood SD 88J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411129001684",
    },
    {
        "school": "Alberta Rider Elementary School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001668",
    },
    {
        "school": "Joan Austin Elementary School",
        "district": "Newberg SD 29J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410872001674",
    },
    {
        "school": "Burns Alternative School",
        "district": "Harney County SD 3",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410249001520",
    },
    {
        "school": "Buff Elementary School",
        "district": "Jefferson County SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410674001569",
    },
    {
        "school": "Eddyville Charter School",
        "district": "Lincoln County SD",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750001582",
    },
    {
        "school": "Siletz Valley Schools",
        "district": "Lincoln County SD",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750001590",
    },
    {
        "school": "Baker Middle School",
        "district": "Baker SD 5J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410171000001",
    },
    {
        "school": "Brooklyn Primary School",
        "district": "Baker SD 5J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410171000002",
    },
    {
        "school": "South Baker Intermediate School",
        "district": "Baker SD 5J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410171000007",
    },
    {
        "school": "Baker High School",
        "district": "Baker SD 5J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410171000009",
    },
    {
        "school": "Haines Elementary School",
        "district": "Baker SD 5J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410171000030",
    },
    {
        "school": "Keating Elementary School",
        "district": "Baker SD 5J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410171000034",
    },
    {
        "school": "Burnt River School",
        "district": "Burnt River SD 30J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410174000013",
    },
    {
        "school": "Huntington School",
        "district": "Huntington SD 16J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410660000011",
    },
    {
        "school": "Pine Eagle Charter School",
        "district": "Pine Eagle SD 61",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410972000016",
    },
    {
        "school": "Arlington Community Charter School",
        "district": "Arlington SD 3",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410147000343",
    },
    {
        "school": "Condon Elementary School",
        "district": "Condon SD 25J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410333000345",
    },
    {
        "school": "Condon High School",
        "district": "Condon SD 25J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410333000346",
    },
    {
        "school": "Dayville School",
        "district": "Dayville SD 16J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410402000358",
    },
    {
        "school": "Humbolt Elementary School",
        "district": "John Day SD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410678000347",
    },
    {
        "school": "Seneca Elementary School",
        "district": "John Day SD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410678000349",
    },
    {
        "school": "Grant Union Junior/Senior High School",
        "district": "John Day SD 3",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410678000350",
    },
    {
        "school": "Long Creek School",
        "district": "Long Creek SD 17",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410753000360",
    },
    {
        "school": "Monument School",
        "district": "Monument SD 8",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410846000356",
    },
    {
        "school": "Prairie City School",
        "district": "Prairie City SD 4",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411011000352",
    },
    {
        "school": "Henry L Slater Elementary School",
        "district": "Harney County SD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410249000361",
    },
    {
        "school": "Hines Middle School",
        "district": "Harney County SD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410249000363",
    },
    {
        "school": "Burns High School",
        "district": "Harney County SD 3",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410249000379",
    },
    {
        "school": "Crane Elementary School",
        "district": "Harney County SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410360000365",
    },
    {
        "school": "Crane Union High School",
        "district": "Harney County Union High SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410363000378",
    },
    {
        "school": "Diamond Elementary School",
        "district": "Diamond SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410417000367",
    },
    {
        "school": "Double O Elementary School",
        "district": "Double O SD 28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410429000372",
    },
    {
        "school": "Drewsey Elementary School",
        "district": "Drewsey SD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410438000369",
    },
    {
        "school": "Fields Elementary School",
        "district": "South Harney SD 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410502001383",
    },
    {
        "school": "Frenchglen Elementary School",
        "district": "Frenchglen SD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410531000370",
    },
    {
        "school": "Pine Creek Elementary School",
        "district": "Pine Creek SD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410969000366",
    },
    {
        "school": "Suntex Elementary School",
        "district": "Suntex SD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411191000368",
    },
    {
        "school": "Ashwood Elementary School",
        "district": "Ashwood SD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410159000448",
    },
    {
        "school": "Black Butte Elementary School",
        "district": "Black Butte SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410219000449",
    },
    {
        "school": "Culver Middle School",
        "district": "Culver SD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410384000119",
    },
    {
        "school": "Culver Elementary School",
        "district": "Culver SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410384000446",
    },
    {
        "school": "Culver High School",
        "district": "Culver SD 4",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410384000447",
    },
    {
        "school": "Madras Elementary School",
        "district": "Jefferson County SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410674000451",
    },
    {
        "school": "Metolius Elementary School",
        "district": "Jefferson County SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410674000452",
    },
    {
        "school": "Warm Springs K-8 Academy",
        "district": "Jefferson County SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410674000454",
    },
    {
        "school": "Madras High School",
        "district": "Jefferson County SD 509J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410674000456",
    },
    {
        "school": "Jefferson County Middle School",
        "district": "Jefferson County SD 509J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410674000656",
    },
    {
        "school": "Big Muddy Elementary",
        "district": "Jefferson County SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410674001446",
    },
    {
        "school": "Adel Elementary School",
        "district": "Adel SD 21",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410099000524",
    },
    {
        "school": "Union Elementary School",
        "district": "Lake County SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410728000514",
    },
    {
        "school": "Fremont/Hay Elementary School",
        "district": "Lake County SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410728000517",
    },
    {
        "school": "Lakeview Senior High School",
        "district": "Lake County SD 7",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410728000519",
    },
    {
        "school": "Daly Middle School",
        "district": "Lake County SD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410728000689",
    },
    {
        "school": "Paisley School",
        "district": "Paisley SD 11",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410943000521",
    },
    {
        "school": "Plush Elementary School",
        "district": "Plush SD 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410996000523",
    },
    {
        "school": "North Lake School",
        "district": "North Lake SD 14",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411140001381",
    },
    {
        "school": "Toledo Elementary School",
        "district": "Lincoln County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000646",
    },
    {
        "school": "Oceanlake Elementary School",
        "district": "Lincoln County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000651",
    },
    {
        "school": "Yaquina View Elementary",
        "district": "Lincoln County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000653",
    },
    {
        "school": "Taft Elementary School",
        "district": "Lincoln County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000655",
    },
    {
        "school": "Crestview Heights School",
        "district": "Lincoln County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000657",
    },
    {
        "school": "Waldport Middle School",
        "district": "Lincoln County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000658",
    },
    {
        "school": "Sam Case Elementary",
        "district": "Lincoln County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000660",
    },
    {
        "school": "Newport Middle School",
        "district": "Lincoln County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000661",
    },
    {
        "school": "Newport High School",
        "district": "Lincoln County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000663",
    },
    {
        "school": "Taft High School",
        "district": "Lincoln County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000665",
    },
    {
        "school": "Toledo Senior High School",
        "district": "Lincoln County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000666",
    },
    {
        "school": "Waldport High School",
        "district": "Lincoln County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000667",
    },
    {
        "school": "Taft Middle School",
        "district": "Lincoln County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750000984",
    },
    {
        "school": "Toledo Jr. High",
        "district": "Lincoln County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750001334",
    },
    {
        "school": "Lincoln City Career Technical High School",
        "district": "Lincoln County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410750001493",
    },
    {
        "school": "Sherman County School",
        "district": "Sherman County SD",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411125001068",
    },
    {
        "school": "Garibaldi Elementary School",
        "district": "Neah-Kah-Nie SD 56",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410865001078",
    },
    {
        "school": "Nehalem Elementary School",
        "district": "Neah-Kah-Nie SD 56",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410865001080",
    },
    {
        "school": "Neah-Kah-Nie High School",
        "district": "Neah-Kah-Nie SD 56",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410865001081",
    },
    {
        "school": "Nestucca Valley Elementary",
        "district": "Nestucca Valley SD 101J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410870001077",
    },
    {
        "school": "Nestucca High School",
        "district": "Nestucca Valley SD 101J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410870001082",
    },
    {
        "school": "East Elementary School",
        "district": "Tillamook SD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411232001070",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Tillamook SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411232001071",
    },
    {
        "school": "South Prairie Elementary School",
        "district": "Tillamook SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411232001072",
    },
    {
        "school": "Tillamook Junior High School",
        "district": "Tillamook SD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411232001074",
    },
    {
        "school": "Tillamook High School",
        "district": "Tillamook SD 9",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411232001075",
    },
    {
        "school": "Enterprise Elementary School",
        "district": "Enterprise SD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410508001148",
    },
    {
        "school": "Enterprise High School",
        "district": "Enterprise SD 21",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410508001149",
    },
    {
        "school": "Imnaha Elementary School",
        "district": "Joseph SD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410687001142",
    },
    {
        "school": "Joseph Charter School",
        "district": "Joseph SD 6",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410687001145",
    },
    {
        "school": "Troy Elementary School",
        "district": "Troy SD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411236001150",
    },
    {
        "school": "Wallowa High School",
        "district": "Wallowa SD 12",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411299001147",
    },
    {
        "school": "Wallowa Elementary School",
        "district": "Wallowa SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411299001371",
    },
    {
        "school": "Fossil Charter School",
        "district": "Fossil SD 21J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410525001375",
    },
    {
        "school": "Mitchell School",
        "district": "Mitchell SD 55",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410828001259",
    },
    {
        "school": "Spray School",
        "district": "Spray SD 1",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411164001255",
    },
    {
        "school": "Albany Options School",
        "district": "Greater Albany Public SD 8J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410112001577",
    },
    {
        "school": "Oak Grove Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000017",
    },
    {
        "school": "North Albany Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000029",
    },
    {
        "school": "North Albany Middle School",
        "district": "Greater Albany Public SD 8J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000734",
    },
    {
        "school": "Harrisburg Elementary School",
        "district": "Harrisburg SD 7J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001900698",
    },
    {
        "school": "Harrisburg High School",
        "district": "Harrisburg SD 7J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001900731",
    },
    {
        "school": "Central Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000669",
    },
    {
        "school": "Lafayette Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000670",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000671",
    },
    {
        "school": "Oak Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000672",
    },
    {
        "school": "Sunrise Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000673",
    },
    {
        "school": "South Shore Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000674",
    },
    {
        "school": "Takena Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000675",
    },
    {
        "school": "Waverly Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000676",
    },
    {
        "school": "Periwinkle Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000680",
    },
    {
        "school": "Tangent Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000692",
    },
    {
        "school": "Clover Ridge Elementary School",
        "district": "Greater Albany Public SD 8J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000725",
    },
    {
        "school": "Calapooia Middle School",
        "district": "Greater Albany Public SD 8J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000732",
    },
    {
        "school": "Memorial Middle School",
        "district": "Greater Albany Public SD 8J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000733",
    },
    {
        "school": "West Albany High School",
        "district": "Greater Albany Public SD 8J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000735",
    },
    {
        "school": "South Albany High School",
        "district": "Greater Albany Public SD 8J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112000736",
    },
    {
        "school": "Central Linn Elementary School",
        "district": "Central Linn SD 552",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410291000475",
    },
    {
        "school": "Central Linn High School",
        "district": "Central Linn SD 552",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410291000729",
    },
    {
        "school": "Cascades School",
        "district": "Lebanon Community SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410738000682",
    },
    {
        "school": "Green Acres School",
        "district": "Lebanon Community SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410738000684",
    },
    {
        "school": "Hamilton Creek School",
        "district": "Lebanon Community SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410738000696",
    },
    {
        "school": "Lacomb School",
        "district": "Lebanon Community SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410738000710",
    },
    {
        "school": "Seven Oak Middle School",
        "district": "Lebanon Community SD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410738000714",
    },
    {
        "school": "Lebanon High School",
        "district": "Lebanon Community SD 9",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410738000730",
    },
    {
        "school": "Riverview School",
        "district": "Lebanon Community SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410738004184",
    },
    {
        "school": "Pioneer School",
        "district": "Lebanon Community SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410738004185",
    },
    {
        "school": "Sand Ridge Charter School",
        "district": "Lebanon Community SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410738004186",
    },
    {
        "school": "Centennial Elementary School",
        "district": "Scio SD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411104000716",
    },
    {
        "school": "Scio Middle School",
        "district": "Scio SD 95",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411104000717",
    },
    {
        "school": "Scio High School",
        "district": "Scio SD 95",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411104000718",
    },
    {
        "school": "Lourdes School",
        "district": "Scio SD 95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411104001494",
    },
    {
        "school": "Foster Elementary School",
        "district": "Sweet Home SD 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411197000701",
    },
    {
        "school": "Hawthorne Elementary School",
        "district": "Sweet Home SD 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411197000702",
    },
    {
        "school": "Holley Elementary School",
        "district": "Sweet Home SD 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411197000703",
    },
    {
        "school": "Oak Heights Elementary School",
        "district": "Sweet Home SD 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411197000706",
    },
    {
        "school": "Sweet Home Junior High School",
        "district": "Sweet Home SD 55",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411197000707",
    },
    {
        "school": "Sweet Home High School",
        "district": "Sweet Home SD 55",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411197000708",
    },
    {
        "school": "Santiam Elementary School",
        "district": "Santiam Canyon SD 129J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410810000722",
    },
    {
        "school": "Santiam Junior/Senior High School",
        "district": "Santiam Canyon SD 129J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410810000724",
    },
    {
        "school": "Hilda Lahti Elementary School",
        "district": "Knappa SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004000176",
    },
    {
        "school": "Knappa High School",
        "district": "Knappa SD 4",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004000179",
    },
    {
        "school": "Astor Elementary School",
        "district": "Astoria SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410162000152",
    },
    {
        "school": "Astoria Middle School",
        "district": "Astoria SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410162000153",
    },
    {
        "school": "Astoria Senior High School",
        "district": "Astoria SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410162000155",
    },
    {
        "school": "Lewis & Clark Elementary School",
        "district": "Astoria SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410162000156",
    },
    {
        "school": "Jewell School",
        "district": "Jewell SD 8",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410675000158",
    },
    {
        "school": "Broadway Middle School",
        "district": "Seaside SD 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411110000159",
    },
    {
        "school": "Seaside Heights Elementary School",
        "district": "Seaside SD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411110000161",
    },
    {
        "school": "Gearhart Elementary School",
        "district": "Seaside SD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411110000162",
    },
    {
        "school": "Seaside High School",
        "district": "Seaside SD 10",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411110000163",
    },
    {
        "school": "Warrenton Grade School",
        "district": "Warrenton-Hammond SD 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411308000166",
    },
    {
        "school": "Warrenton High School",
        "district": "Warrenton-Hammond SD 30",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411308000167",
    },
    {
        "school": "Highland School at Kenwood Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001438",
    },
    {
        "school": "High Lakes Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001487",
    },
    {
        "school": "Sky View Middle School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001488",
    },
    {
        "school": "Pine Ridge Elementary",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001576",
    },
    {
        "school": "Ensworth Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001603",
    },
    {
        "school": "Elk Meadow Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000245",
    },
    {
        "school": "Bear Creek Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000258",
    },
    {
        "school": "Cascade Middle School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000259",
    },
    {
        "school": "LaPine Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000262",
    },
    {
        "school": "High Desert Middle School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000263",
    },
    {
        "school": "LaPine Middle School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000264",
    },
    {
        "school": "Juniper Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000265",
    },
    {
        "school": "R E Jewell Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000266",
    },
    {
        "school": "Pilot Butte Middle School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000268",
    },
    {
        "school": "Bend Senior High School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000270",
    },
    {
        "school": "Mountain View Senior High School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000271",
    },
    {
        "school": "LaPine Senior High School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000272",
    },
    {
        "school": "Lava Ridge Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000546",
    },
    {
        "school": "Amity Creek Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198000607",
    },
    {
        "school": "Marshall High School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410198000688",
    },
    {
        "school": "Buckingham Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001290",
    },
    {
        "school": "Three Rivers Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001350",
    },
    {
        "school": "Realms Middle School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001436",
    },
    {
        "school": "Summit High School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001451",
    },
    {
        "school": "Westside Village Magnet School at Kingston Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001454",
    },
    {
        "school": "John Tuck Elementary School",
        "district": "Redmond SD 2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035000277",
    },
    {
        "school": "M A Lynch Elementary School",
        "district": "Redmond SD 2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035000278",
    },
    {
        "school": "Terrebonne Community School",
        "district": "Redmond SD 2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035000279",
    },
    {
        "school": "Tumalo Community School",
        "district": "Redmond SD 2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035000280",
    },
    {
        "school": "Obsidian Middle School",
        "district": "Redmond SD 2J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035000281",
    },
    {
        "school": "Redmond High School",
        "district": "Redmond SD 2J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035000282",
    },
    {
        "school": "Elton Gregory Middle School",
        "district": "Redmond SD 2J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035000647",
    },
    {
        "school": "Vern Patrick Elementary School",
        "district": "Redmond SD 2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035000942",
    },
    {
        "school": "Sage Elementary School",
        "district": "Redmond SD 2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035001347",
    },
    {
        "school": "Sisters High School",
        "district": "Sisters SD 6",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411149000073",
    },
    {
        "school": "Sisters Elementary School",
        "district": "Sisters SD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411149000283",
    },
    {
        "school": "Sisters Middle School",
        "district": "Sisters SD 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411149000943",
    },
    {
        "school": "Azalea Middle School",
        "district": "Brookings-Harbor SD 17C",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410231000253",
    },
    {
        "school": "Kalmiopsis Elementary School",
        "district": "Brookings-Harbor SD 17C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410231000254",
    },
    {
        "school": "Brookings-Harbor High School",
        "district": "Brookings-Harbor SD 17C",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410231000255",
    },
    {
        "school": "Riley Creek Elementary School",
        "district": "Central Curry SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410576000249",
    },
    {
        "school": "Gold Beach High School",
        "district": "Central Curry SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410576000257",
    },
    {
        "school": "Driftwood Elementary School",
        "district": "Port Orford-Langlois SD 2CJ",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411002000246",
    },
    {
        "school": "Pacific High School",
        "district": "Port Orford-Langlois SD 2CJ",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411002000247",
    },
    {
        "school": "Chenowith Elementary School",
        "district": "North Wasco County SD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004801151",
    },
    {
        "school": "Mosier Community School",
        "district": "North Wasco County SD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004801153",
    },
    {
        "school": "Colonel Wright Elementary School",
        "district": "North Wasco County SD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004801155",
    },
    {
        "school": "Dry Hollow Elementary School",
        "district": "North Wasco County SD 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004801156",
    },
    {
        "school": "The Dalles Middle School",
        "district": "North Wasco County SD 21",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004801158",
    },
    {
        "school": "The Dalles High School",
        "district": "North Wasco County SD 21",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004801159",
    },
    {
        "school": "Maupin Elementary School",
        "district": "South Wasco County SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002101166",
    },
    {
        "school": "South Wasco County High School",
        "district": "South Wasco County SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002101167",
    },
    {
        "school": "Dufur School",
        "district": "Dufur SD 29",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410441001162",
    },
    {
        "school": "Coquille Valley Elementary",
        "district": "Coquille SD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410339001589",
    },
    {
        "school": "Resource Link Charter School",
        "district": "Coos Bay SD 9",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410366001602",
    },
    {
        "school": "Myrtle Crest School",
        "district": "Myrtle Point SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410064000233",
    },
    {
        "school": "Myrtle Point High School",
        "district": "Myrtle Point SD 41",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410064000234",
    },
    {
        "school": "Harbor Lights Middle School",
        "district": "Bandon SD 54",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410180000235",
    },
    {
        "school": "Ocean Crest Elementary School",
        "district": "Bandon SD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410180000236",
    },
    {
        "school": "Bandon Senior High School",
        "district": "Bandon SD 54",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410180000237",
    },
    {
        "school": "Lincoln School of Early Learning",
        "district": "Coquille SD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410339000200",
    },
    {
        "school": "Coquille Junior Senior High",
        "district": "Coquille SD 8",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410339000202",
    },
    {
        "school": "Blossom Gulch Elementary School",
        "district": "Coos Bay SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410366000204",
    },
    {
        "school": "Madison Elementary School",
        "district": "Coos Bay SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410366000211",
    },
    {
        "school": "Millicoma School",
        "district": "Coos Bay SD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410366000214",
    },
    {
        "school": "Sunset School",
        "district": "Coos Bay SD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410366000215",
    },
    {
        "school": "Marshfield Senior High School",
        "district": "Coos Bay SD 9",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410366000216",
    },
    {
        "school": "Destinations Academy",
        "district": "Coos Bay SD 9",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410366001486",
    },
    {
        "school": "Hillcrest Elementary School",
        "district": "North Bend SD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410882000219",
    },
    {
        "school": "North Bay Elementary School",
        "district": "North Bend SD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410882000221",
    },
    {
        "school": "North Bend Middle School",
        "district": "North Bend SD 13",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410882000224",
    },
    {
        "school": "North Bend Senior High School",
        "district": "North Bend SD 13",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410882000225",
    },
    {
        "school": "Powers Elementary School",
        "district": "Powers SD 31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411008000226",
    },
    {
        "school": "Powers High School",
        "district": "Powers SD 31",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411008000227",
    },
    {
        "school": "Alsea Charter School",
        "district": "Alsea SD 7J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410120000019",
    },
    {
        "school": "Adams Elementary School",
        "district": "Corvallis SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000032",
    },
    {
        "school": "Cheldelin Middle School",
        "district": "Corvallis SD 509J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000033",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Corvallis SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000037",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Corvallis SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000040",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Corvallis SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000042",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Corvallis SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000043",
    },
    {
        "school": "Mt View Elementary School",
        "district": "Corvallis SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000044",
    },
    {
        "school": "Linus Pauling Middle School",
        "district": "Corvallis SD 509J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000045",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Corvallis SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000046",
    },
    {
        "school": "Corvallis High School",
        "district": "Corvallis SD 509J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000047",
    },
    {
        "school": "Crescent Valley High School",
        "district": "Corvallis SD 509J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000048",
    },
    {
        "school": "Franklin School",
        "district": "Corvallis SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348000570",
    },
    {
        "school": "Monroe Grade School",
        "district": "Monroe SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410843000027",
    },
    {
        "school": "Monroe High School",
        "district": "Monroe SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410843000050",
    },
    {
        "school": "Blodgett Elementary School",
        "district": "Philomath SD 17J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410960000020",
    },
    {
        "school": "Kings Valley Charter School",
        "district": "Philomath SD 17J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410960000021",
    },
    {
        "school": "Philomath Elementary School",
        "district": "Philomath SD 17J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410960000022",
    },
    {
        "school": "Philomath Middle School",
        "district": "Philomath SD 17J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410960000023",
    },
    {
        "school": "Philomath High School",
        "district": "Philomath SD 17J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410960000024",
    },
    {
        "school": "Clemens Primary School",
        "district": "Philomath SD 17J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410960001481",
    },
    {
        "school": "Network Charter School",
        "district": "Eugene SD 4J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001593",
    },
    {
        "school": "Cesar Chavez Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001604",
    },
    {
        "school": "Holt Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001609",
    },
    {
        "school": "West Lane Technology Learning Center",
        "district": "Fern Ridge SD 28J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410495001595",
    },
    {
        "school": "Clear Lake Elementary School",
        "district": "Bethel SD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410204000616",
    },
    {
        "school": "Danebo Elementary School",
        "district": "Bethel SD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410204000617",
    },
    {
        "school": "Fairfield Elementary School",
        "district": "Bethel SD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410204000618",
    },
    {
        "school": "Irving Elementary School",
        "district": "Bethel SD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410204000619",
    },
    {
        "school": "Malabon Elementary School",
        "district": "Bethel SD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410204000620",
    },
    {
        "school": "Cascade Middle School",
        "district": "Bethel SD 52",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410204000621",
    },
    {
        "school": "Shasta Middle School",
        "district": "Bethel SD 52",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410204000622",
    },
    {
        "school": "Willamette High School",
        "district": "Bethel SD 52",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410204000623",
    },
    {
        "school": "Meadow View School",
        "district": "Bethel SD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410204001391",
    },
    {
        "school": "Kalapuya High School",
        "district": "Bethel SD 52",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410204004178",
    },
    {
        "school": "Prairie Mountain School",
        "district": "Bethel SD 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410204004179",
    },
    {
        "school": "Triangle Lake Charter School",
        "district": "Blachly SD 90",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410216000641",
    },
    {
        "school": "Creslane Elementary School",
        "district": "Creswell SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410369000604",
    },
    {
        "school": "Creswell Middle School",
        "district": "Creswell SD 40",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410369000605",
    },
    {
        "school": "Creswell High School",
        "district": "Creswell SD 40",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410369000606",
    },
    {
        "school": "Applegate Elementary School",
        "district": "Crow-Applegate-Lorane SD 66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410378000624",
    },
    {
        "school": "Crow Middle/High School",
        "district": "Crow-Applegate-Lorane SD 66",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410378000627",
    },
    {
        "school": "Adams Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000530",
    },
    {
        "school": "Awbrey Park Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000531",
    },
    {
        "school": "Coburg Community Charter School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000533",
    },
    {
        "school": "Edgewood Community Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000537",
    },
    {
        "school": "Edison Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000538",
    },
    {
        "school": "Gilham Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000542",
    },
    {
        "school": "Howard Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000544",
    },
    {
        "school": "McCornack Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000548",
    },
    {
        "school": "River Road/El Camino del Rio Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000550",
    },
    {
        "school": "Spring Creek Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000553",
    },
    {
        "school": "Twin Oaks Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000555",
    },
    {
        "school": "Willagillespie Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000559",
    },
    {
        "school": "Cal Young Middle School",
        "district": "Eugene SD 4J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000561",
    },
    {
        "school": "Kelly Middle School",
        "district": "Eugene SD 4J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000562",
    },
    {
        "school": "Kennedy Middle School",
        "district": "Eugene SD 4J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000564",
    },
    {
        "school": "Madison Middle School",
        "district": "Eugene SD 4J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000565",
    },
    {
        "school": "Monroe Middle School",
        "district": "Eugene SD 4J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000566",
    },
    {
        "school": "Eugene Education Options",
        "district": "Eugene SD 4J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410474000567",
    },
    {
        "school": "Roosevelt Middle School",
        "district": "Eugene SD 4J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000568",
    },
    {
        "school": "Spencer Butte Middle School",
        "district": "Eugene SD 4J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000569",
    },
    {
        "school": "North Eugene High School",
        "district": "Eugene SD 4J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000571",
    },
    {
        "school": "Sheldon High School",
        "district": "Eugene SD 4J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000572",
    },
    {
        "school": "South Eugene High School",
        "district": "Eugene SD 4J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000573",
    },
    {
        "school": "Churchill High School",
        "district": "Eugene SD 4J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474000575",
    },
    {
        "school": "Family School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410474000690",
    },
    {
        "school": "Charlemagne French Immersion Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001344",
    },
    {
        "school": "Buena Vista Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001345",
    },
    {
        "school": "Yujin Gakuen Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001348",
    },
    {
        "school": "Corridor Elementary School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410474001359",
    },
    {
        "school": "Ridgeline Montessori",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001491",
    },
    {
        "school": "Village School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001492",
    },
    {
        "school": "Elmira Elementary School",
        "district": "Fern Ridge SD 28J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410495000597",
    },
    {
        "school": "Veneta Elementary School",
        "district": "Fern Ridge SD 28J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410495000599",
    },
    {
        "school": "Fern Ridge Middle School",
        "district": "Fern Ridge SD 28J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410495000600",
    },
    {
        "school": "Elmira High School",
        "district": "Fern Ridge SD 28J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410495000601",
    },
    {
        "school": "Siuslaw Middle School",
        "district": "Siuslaw SD 97J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410510000643",
    },
    {
        "school": "Siuslaw Elementary School",
        "district": "Siuslaw SD 97J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410510000644",
    },
    {
        "school": "Siuslaw High School",
        "district": "Siuslaw SD 97J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410510000645",
    },
    {
        "school": "Territorial Elementary School",
        "district": "Junction City SD 69",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410693000203",
    },
    {
        "school": "Laurel Elementary School",
        "district": "Junction City SD 69",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410693000630",
    },
    {
        "school": "Oaklea Middle School",
        "district": "Junction City SD 69",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410693000631",
    },
    {
        "school": "Junction City High School",
        "district": "Junction City SD 69",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410693000632",
    },
    {
        "school": "Lundy Elementary School",
        "district": "Lowell SD 71",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410759000633",
    },
    {
        "school": "Lowell Junior/Senior High School",
        "district": "Lowell SD 71",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410759000634",
    },
    {
        "school": "Mapleton Elementary School",
        "district": "Mapleton SD 32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410771000602",
    },
    {
        "school": "Mapleton Jr/Sr High School",
        "district": "Mapleton SD 32",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410771000603",
    },
    {
        "school": "Marcola Elementary School",
        "district": "Marcola SD 79J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410774000638",
    },
    {
        "school": "Mohawk High School",
        "district": "Marcola SD 79J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410774000639",
    },
    {
        "school": "McKenzie River Community School",
        "district": "McKenzie SD 68",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410798000629",
    },
    {
        "school": "Oakridge Elementary School",
        "district": "Oakridge SD 76",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410915000635",
    },
    {
        "school": "Oakridge Junior High School",
        "district": "Oakridge SD 76",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410915000636",
    },
    {
        "school": "Oakridge High School",
        "district": "Oakridge SD 76",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410915000637",
    },
    {
        "school": "Pleasant Hill Elementary School",
        "district": "Pleasant Hill SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410987000527",
    },
    {
        "school": "Pleasant Hill High School",
        "district": "Pleasant Hill SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410987000529",
    },
    {
        "school": "Bohemia Elementary School",
        "district": "South Lane SD 45J3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411158000608",
    },
    {
        "school": "Dorena School",
        "district": "South Lane SD 45J3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411158000609",
    },
    {
        "school": "Harrison Elementary School",
        "district": "South Lane SD 45J3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411158000611",
    },
    {
        "school": "London School",
        "district": "South Lane SD 45J3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411158000613",
    },
    {
        "school": "Lincoln Middle School",
        "district": "South Lane SD 45J3",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411158000614",
    },
    {
        "school": "Cottage Grove High School",
        "district": "South Lane SD 45J3",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411158000615",
    },
    {
        "school": "Al Kennedy High School",
        "district": "South Lane SD 45J3",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "411158001390",
    },
    {
        "school": "Centennial Elementary School",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000578",
    },
    {
        "school": "Douglas Gardens Elementary School",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000579",
    },
    {
        "school": "Elizabeth Page Elementary School",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000580",
    },
    {
        "school": "Guy Lee Elementary School",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000582",
    },
    {
        "school": "Maple Elementary School",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000583",
    },
    {
        "school": "Mt Vernon Elementary School",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000586",
    },
    {
        "school": "Thurston Elementary School",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000587",
    },
    {
        "school": "Walterville Elementary School",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000588",
    },
    {
        "school": "Yolanda Elementary School",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000589",
    },
    {
        "school": "Briggs Middle School",
        "district": "Springfield SD 19",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000590",
    },
    {
        "school": "Hamlin Middle School",
        "district": "Springfield SD 19",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000591",
    },
    {
        "school": "Thurston Middle School",
        "district": "Springfield SD 19",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000593",
    },
    {
        "school": "Springfield High School",
        "district": "Springfield SD 19",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000594",
    },
    {
        "school": "Thurston High School",
        "district": "Springfield SD 19",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000595",
    },
    {
        "school": "Riverbend Elementary School",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000973",
    },
    {
        "school": "Agnes Stewart Middle School",
        "district": "Springfield SD 19",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000977",
    },
    {
        "school": "Gateways High School",
        "district": "Springfield SD 19",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167000978",
    },
    {
        "school": "Ridgeview Elementary School",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167001330",
    },
    {
        "school": "Allen Dale Elementary School",
        "district": "Grants Pass SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410591000457",
    },
    {
        "school": "Highland Elementary School",
        "district": "Grants Pass SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410591000458",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Grants Pass SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410591000459",
    },
    {
        "school": "North Middle School",
        "district": "Grants Pass SD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410591000460",
    },
    {
        "school": "Redwood Elementary School",
        "district": "Grants Pass SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410591000461",
    },
    {
        "school": "Riverside Elementary School",
        "district": "Grants Pass SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410591000462",
    },
    {
        "school": "South Middle School",
        "district": "Grants Pass SD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410591000463",
    },
    {
        "school": "Grants Pass High School",
        "district": "Grants Pass SD 7",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410591000464",
    },
    {
        "school": "Parkside Elementary",
        "district": "Grants Pass SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410591000970",
    },
    {
        "school": "Applegate Elementary School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000422",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000465",
    },
    {
        "school": "Fleming Middle School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000466",
    },
    {
        "school": "Fruitdale Elementary School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000467",
    },
    {
        "school": "Ft Vannoy Elementary School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000468",
    },
    {
        "school": "Lincoln Savage Middle School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000470",
    },
    {
        "school": "Lorna Byrne Middle School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000471",
    },
    {
        "school": "Madrona Elementary School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000472",
    },
    {
        "school": "Manzanita Elementary School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000473",
    },
    {
        "school": "Williams Elementary School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000477",
    },
    {
        "school": "Hidden Valley High School",
        "district": "Three Rivers/Josephine County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000479",
    },
    {
        "school": "Illinois Valley High School",
        "district": "Three Rivers/Josephine County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000480",
    },
    {
        "school": "North Valley High School",
        "district": "Three Rivers/Josephine County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690000481",
    },
    {
        "school": "May Street Elementary School",
        "district": "Hood River County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410651000382",
    },
    {
        "school": "Mid Valley Elementary School",
        "district": "Hood River County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410651000383",
    },
    {
        "school": "Parkdale Elementary School",
        "district": "Hood River County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410651000384",
    },
    {
        "school": "Westside Elementary School",
        "district": "Hood River County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410651000386",
    },
    {
        "school": "Hood River Middle School",
        "district": "Hood River County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410651000387",
    },
    {
        "school": "WyEast Middle School",
        "district": "Hood River County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410651000388",
    },
    {
        "school": "Cascade Locks School",
        "district": "Hood River County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410651000389",
    },
    {
        "school": "Hood River Valley High School",
        "district": "Hood River County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410651000390",
    },
    {
        "school": "Bonanza Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702001464",
    },
    {
        "school": "Gilchrist Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702001465",
    },
    {
        "school": "Bonanza Junior/Senior High School",
        "district": "Klamath County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702001466",
    },
    {
        "school": "Gilchrist Junior/Senior High School",
        "district": "Klamath County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702001467",
    },
    {
        "school": "EagleRidge High School",
        "district": "Klamath Falls City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410708001687",
    },
    {
        "school": "Chiloquin Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000492",
    },
    {
        "school": "Ferguson Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000495",
    },
    {
        "school": "Gearhart Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000496",
    },
    {
        "school": "Henley Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000498",
    },
    {
        "school": "Keno Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000499",
    },
    {
        "school": "Malin Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000500",
    },
    {
        "school": "Merrill Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000501",
    },
    {
        "school": "Peterson Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000502",
    },
    {
        "school": "Shasta Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000503",
    },
    {
        "school": "Stearns Elementary School",
        "district": "Klamath County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000504",
    },
    {
        "school": "Brixner Junior High School",
        "district": "Klamath County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000505",
    },
    {
        "school": "Henley Middle School",
        "district": "Klamath County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000506",
    },
    {
        "school": "Chiloquin High School",
        "district": "Klamath County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000508",
    },
    {
        "school": "Henley High School",
        "district": "Klamath County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000510",
    },
    {
        "school": "Lost River High School",
        "district": "Klamath County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000511",
    },
    {
        "school": "Joseph Conger Elementary School",
        "district": "Klamath Falls City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410708000483",
    },
    {
        "school": "Mills Elementary School",
        "district": "Klamath Falls City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410708000485",
    },
    {
        "school": "Pelican Elementary School",
        "district": "Klamath Falls City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410708000486",
    },
    {
        "school": "Ponderosa Middle School",
        "district": "Klamath Falls City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410708000487",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Klamath Falls City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410708000489",
    },
    {
        "school": "Klamath Union High School",
        "district": "Klamath Falls City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410708000512",
    },
    {
        "school": "Cove Charter School",
        "district": "Cove SD 15",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410354001139",
    },
    {
        "school": "Stella Mayfield Elementary School",
        "district": "Elgin SD 23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410459001140",
    },
    {
        "school": "Elgin High School",
        "district": "Elgin SD 23",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410459001141",
    },
    {
        "school": "Imbler Charter School",
        "district": "Imbler SD 11",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410663001137",
    },
    {
        "school": "Central Elementary School",
        "district": "La Grande SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410720001125",
    },
    {
        "school": "Greenwood Elementary School",
        "district": "La Grande SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410720001126",
    },
    {
        "school": "La Grande Middle School",
        "district": "La Grande SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410720001127",
    },
    {
        "school": "Island City Elementary School",
        "district": "La Grande SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410720001128",
    },
    {
        "school": "La Grande High School",
        "district": "La Grande SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410720001131",
    },
    {
        "school": "North Powder Charter School",
        "district": "North Powder SD 8J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410894001135",
    },
    {
        "school": "Union Elementary School",
        "district": "Union SD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411269001132",
    },
    {
        "school": "Union High School",
        "district": "Union SD 5",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411269001133",
    },
    {
        "school": "Eagle Rock Elementary School",
        "district": "Eagle Point SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410450001586",
    },
    {
        "school": "White Mountain Middle School",
        "district": "Eagle Point SD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410450001587",
    },
    {
        "school": "Bellview Elementary School",
        "district": "Ashland SD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410156000395",
    },
    {
        "school": "Helman Elementary School",
        "district": "Ashland SD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410156000397",
    },
    {
        "school": "Walker Elementary School",
        "district": "Ashland SD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410156000399",
    },
    {
        "school": "Ashland Middle School",
        "district": "Ashland SD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410156000400",
    },
    {
        "school": "Ashland High School",
        "district": "Ashland SD 5",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410156000401",
    },
    {
        "school": "Butte Falls Charter School",
        "district": "Butte Falls SD 91",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410258000426",
    },
    {
        "school": "Central Point Elementary School",
        "district": "Central Point SD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410294000402",
    },
    {
        "school": "Jewett Elementary School",
        "district": "Central Point SD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410294000403",
    },
    {
        "school": "Patrick Elementary School",
        "district": "Central Point SD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410294000404",
    },
    {
        "school": "Richardson Elementary School",
        "district": "Central Point SD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410294000405",
    },
    {
        "school": "Sams Valley Elementary School",
        "district": "Central Point SD 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410294000406",
    },
    {
        "school": "Hanby Middle School",
        "district": "Central Point SD 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410294000407",
    },
    {
        "school": "Scenic Middle School",
        "district": "Central Point SD 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410294000408",
    },
    {
        "school": "Hillside Elementary",
        "district": "Eagle Point SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410450000410",
    },
    {
        "school": "Shady Cove School",
        "district": "Eagle Point SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410450000413",
    },
    {
        "school": "Table Rock Elementary",
        "district": "Eagle Point SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410450000414",
    },
    {
        "school": "Eagle Point Middle School",
        "district": "Eagle Point SD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410450000416",
    },
    {
        "school": "Eagle Point High School",
        "district": "Eagle Point SD 9",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410450000417",
    },
    {
        "school": "Lake Creek Learning Center",
        "district": "Eagle Point SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410450001416",
    },
    {
        "school": "Griffin Creek Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000428",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000429",
    },
    {
        "school": "Howard Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000430",
    },
    {
        "school": "Jackson Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000431",
    },
    {
        "school": "Jacksonville Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000432",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000433",
    },
    {
        "school": "Lone Pine Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000434",
    },
    {
        "school": "Oak Grove Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000435",
    },
    {
        "school": "Kennedy Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000436",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000437",
    },
    {
        "school": "Ruch Outdoor Community School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000438",
    },
    {
        "school": "Washington Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000439",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000441",
    },
    {
        "school": "Hedrick Middle School",
        "district": "Medford SD 549C",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000442",
    },
    {
        "school": "McLoughlin Middle School",
        "district": "Medford SD 549C",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000443",
    },
    {
        "school": "South Medford High School",
        "district": "Medford SD 549C",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000444",
    },
    {
        "school": "North Medford High School",
        "district": "Medford SD 549C",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000445",
    },
    {
        "school": "Abraham Lincoln Elementary",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804000963",
    },
    {
        "school": "Central Medford High School",
        "district": "Medford SD 549C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410804004187",
    },
    {
        "school": "Phoenix Elementary School",
        "district": "Phoenix-Talent SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410963000391",
    },
    {
        "school": "Talent Elementary School",
        "district": "Phoenix-Talent SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410963000392",
    },
    {
        "school": "Talent Middle School",
        "district": "Phoenix-Talent SD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410963000393",
    },
    {
        "school": "Phoenix High School",
        "district": "Phoenix-Talent SD 4",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410963000394",
    },
    {
        "school": "Orchard Hill Elementary School",
        "district": "Phoenix-Talent SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410963001335",
    },
    {
        "school": "Armadillo Technical Institute",
        "district": "Phoenix-Talent SD 4",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410963001489",
    },
    {
        "school": "Pinehurst Elementary School",
        "district": "Pinehurst SD 94",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410975000427",
    },
    {
        "school": "Prospect Charter School",
        "district": "Prospect SD 59",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411020000111",
    },
    {
        "school": "Rogue River Elementary School",
        "district": "Rogue River SD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411068000419",
    },
    {
        "school": "Rogue River Junior/Senior High",
        "district": "Rogue River SD 35",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411068000421",
    },
    {
        "school": "Vale Elementary School",
        "district": "Vale SD 84",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001400748",
    },
    {
        "school": "Willowcreek Elementary School",
        "district": "Vale SD 84",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001400754",
    },
    {
        "school": "Vale High School",
        "district": "Vale SD 84",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001400761",
    },
    {
        "school": "Vale Middle School",
        "district": "Vale SD 84",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001401026",
    },
    {
        "school": "Adrian Elementary School",
        "district": "Adrian SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410102000755",
    },
    {
        "school": "Adrian High School",
        "district": "Adrian SD 61",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410102000756",
    },
    {
        "school": "Annex Charter School",
        "district": "Annex SD 29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410135000753",
    },
    {
        "school": "W W Jones Elementary School",
        "district": "Arock SD 81",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410150000759",
    },
    {
        "school": "Harper Charter School",
        "district": "Harper SD 66",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410612000758",
    },
    {
        "school": "Jordan Valley Elementary School",
        "district": "Jordan Valley SD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410682000697",
    },
    {
        "school": "Jordan Valley High School",
        "district": "Jordan Valley SD 3",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410682000760",
    },
    {
        "school": "Rockville Elementary School",
        "district": "Jordan Valley SD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410682001423",
    },
    {
        "school": "Juntura Elementary School",
        "district": "Juntura SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410696000747",
    },
    {
        "school": "Nyssa Elementary School",
        "district": "Nyssa SD 26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410900000750",
    },
    {
        "school": "Nyssa Middle School",
        "district": "Nyssa SD 26",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410900000751",
    },
    {
        "school": "Nyssa High School",
        "district": "Nyssa SD 26",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410900000752",
    },
    {
        "school": "Alameda Elementary School",
        "district": "Ontario SD 8C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410927000739",
    },
    {
        "school": "Cairo Elementary School",
        "district": "Ontario SD 8C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410927000740",
    },
    {
        "school": "Aiken Elementary School",
        "district": "Ontario SD 8C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410927000741",
    },
    {
        "school": "May Roberts Elementary School",
        "district": "Ontario SD 8C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410927000743",
    },
    {
        "school": "Pioneer Elementary School",
        "district": "Ontario SD 8C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410927000744",
    },
    {
        "school": "Ontario Middle School",
        "district": "Ontario SD 8C",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410927000745",
    },
    {
        "school": "Ontario High School",
        "district": "Ontario SD 8C",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410927000746",
    },
    {
        "school": "Ione Community Charter School",
        "district": "Ione SD R2",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004700862",
    },
    {
        "school": "Windy River Elementary School",
        "district": "Morrow SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410852001597",
    },
    {
        "school": "Irrigon Elementary School",
        "district": "Morrow SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410852001598",
    },
    {
        "school": "Nixyaawii Community School",
        "district": "Pendleton SD 16",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410951001534",
    },
    {
        "school": "A C Houghton Elementary School",
        "district": "Morrow SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410852000858",
    },
    {
        "school": "Heppner Elementary School",
        "district": "Morrow SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410852000859",
    },
    {
        "school": "Heppner Junior/Senior High School",
        "district": "Morrow SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410852000861",
    },
    {
        "school": "Riverside Junior/Senior High School",
        "district": "Morrow SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410852000863",
    },
    {
        "school": "Sam Boardman Elementary School",
        "district": "Morrow SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410852001311",
    },
    {
        "school": "Irrigon Junior/Senior High School",
        "district": "Morrow SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410852001312",
    },
    {
        "school": "Athena Elementary School",
        "district": "Athena-Weston SD 29RJ",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410166001112",
    },
    {
        "school": "Weston Middle School",
        "district": "Athena-Weston SD 29RJ",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410166001114",
    },
    {
        "school": "Weston-McEwen High School",
        "district": "Athena-Weston SD 29RJ",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410166001115",
    },
    {
        "school": "Echo School",
        "district": "Echo SD 5",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410453001089",
    },
    {
        "school": "Helix School",
        "district": "Helix SD 1",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410627001084",
    },
    {
        "school": "Sandstone Middle School",
        "district": "Hermiston SD 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410630000677",
    },
    {
        "school": "Rocky Heights Elementary School",
        "district": "Hermiston SD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410630001093",
    },
    {
        "school": "Sunset Elementary School",
        "district": "Hermiston SD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410630001094",
    },
    {
        "school": "West Park Elementary School",
        "district": "Hermiston SD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410630001095",
    },
    {
        "school": "Armand Larive Middle School",
        "district": "Hermiston SD 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410630001096",
    },
    {
        "school": "Hermiston High School",
        "district": "Hermiston SD 8",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410630001097",
    },
    {
        "school": "Highland Hills Elementary School",
        "district": "Hermiston SD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410630001293",
    },
    {
        "school": "Desert View Elementary School",
        "district": "Hermiston SD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410630001439",
    },
    {
        "school": "Central Middle School",
        "district": "Milton-Freewater Unified SD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410816001116",
    },
    {
        "school": "McLoughlin High School",
        "district": "Milton-Freewater Unified SD 7",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410816001123",
    },
    {
        "school": "McKay Creek Elementary School",
        "district": "Pendleton SD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410951001105",
    },
    {
        "school": "Sherwood Heights Elementary School",
        "district": "Pendleton SD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410951001106",
    },
    {
        "school": "Washington Elementary School",
        "district": "Pendleton SD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410951001107",
    },
    {
        "school": "Pendleton High School",
        "district": "Pendleton SD 16",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410951001111",
    },
    {
        "school": "Sunridge Middle School",
        "district": "Pendleton SD 16",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410951001327",
    },
    {
        "school": "Pilot Rock Elementary School",
        "district": "Pilot Rock SD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410966001085",
    },
    {
        "school": "Pilot Rock High School",
        "district": "Pilot Rock SD 2",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410966001086",
    },
    {
        "school": "Stanfield Elementary School",
        "district": "Stanfield SD 61",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411179001119",
    },
    {
        "school": "Stanfield Secondary School",
        "district": "Stanfield SD 61",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411179001120",
    },
    {
        "school": "Ukiah School",
        "district": "Ukiah SD 80R",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411254001122",
    },
    {
        "school": "Clara Brownell Middle School",
        "district": "Umatilla SD 6R",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411260001090",
    },
    {
        "school": "McNary Heights Elementary School",
        "district": "Umatilla SD 6R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411260001091",
    },
    {
        "school": "Umatilla High School",
        "district": "Umatilla SD 6R",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411260001092",
    },
    {
        "school": "Clackamas Web Academy",
        "district": "North Clackamas SD 12",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001543",
    },
    {
        "school": "Clackamas Middle College",
        "district": "North Clackamas SD 12",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001544",
    },
    {
        "school": "New Urban High School",
        "district": "North Clackamas SD 12",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001583",
    },
    {
        "school": "El Puente",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001584",
    },
    {
        "school": "Boones Ferry Primary School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317001575",
    },
    {
        "school": "South Columbia Family School",
        "district": "Scappoose SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411098001542",
    },
    {
        "school": "Plymouth High School",
        "district": "St Helens SD 502",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "411172001599",
    },
    {
        "school": "Butler Creek Elementary School",
        "district": "Centennial SD 28J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410280001574",
    },
    {
        "school": "Center for Advanced Learning",
        "district": "Gresham-Barlow SD 10J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600001571",
    },
    {
        "school": "Emerson School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001581",
    },
    {
        "school": "Reynolds Learning Academy",
        "district": "Reynolds SD 7",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "411052001471",
    },
    {
        "school": "Reynolds Arthur Academy",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001540",
    },
    {
        "school": "Salish Ponds Elementary School",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001579",
    },
    {
        "school": "The Creeks",
        "district": "Multnomah ESD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "418018001510",
    },
    {
        "school": "City View Charter School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301535",
    },
    {
        "school": "Liberty High School",
        "district": "Hillsboro SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301585",
    },
    {
        "school": "Fern Hill Elementary School",
        "district": "Forest Grove SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410516001578",
    },
    {
        "school": "Multi-sensory Instruction Teaching Children Hands-On (MITCH)",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224004176",
    },
    {
        "school": "Carus School",
        "district": "Canby SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410264000100",
    },
    {
        "school": "William Knight Elementary School",
        "district": "Canby SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410264000130",
    },
    {
        "school": "Howard Eccles Elementary School",
        "district": "Canby SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410264000132",
    },
    {
        "school": "Ninety-One School",
        "district": "Canby SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410264000135",
    },
    {
        "school": "Canby High School",
        "district": "Canby SD 86",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410264000148",
    },
    {
        "school": "Cecile Trost Elementary School",
        "district": "Canby SD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410264000165",
    },
    {
        "school": "Colton Elementary School",
        "district": "Colton SD 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410327000109",
    },
    {
        "school": "Colton High School",
        "district": "Colton SD 53",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410327000110",
    },
    {
        "school": "Colton Middle School",
        "district": "Colton SD 53",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410327001343",
    },
    {
        "school": "Clackamas River Elementary School",
        "district": "Estacada SD 108",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410470000139",
    },
    {
        "school": "River Mill Elementary School",
        "district": "Estacada SD 108",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410470000140",
    },
    {
        "school": "Estacada Middle School",
        "district": "Estacada SD 108",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410470000142",
    },
    {
        "school": "Estacada High School",
        "district": "Estacada SD 108",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410470000143",
    },
    {
        "school": "John Wetten Elementary School",
        "district": "Gladstone SD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410561000144",
    },
    {
        "school": "Walter L Kraxberger Middle School",
        "district": "Gladstone SD 115",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410561000145",
    },
    {
        "school": "Gladstone High School",
        "district": "Gladstone SD 115",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410561000146",
    },
    {
        "school": "Deep Creek - Damascus K-8 School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000098",
    },
    {
        "school": "Forest Hills Elementary School",
        "district": "Lake Oswego SD 7J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410723000060",
    },
    {
        "school": "Lake Grove Elementary School",
        "district": "Lake Oswego SD 7J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410723000061",
    },
    {
        "school": "River Grove Elementary School",
        "district": "Lake Oswego SD 7J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410723000064",
    },
    {
        "school": "Lake Oswego Middle School",
        "district": "Lake Oswego SD 7J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410723000066",
    },
    {
        "school": "Lakeridge Middle School",
        "district": "Lake Oswego SD 7J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410723000067",
    },
    {
        "school": "Lake Oswego Senior High School",
        "district": "Lake Oswego SD 7J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410723000068",
    },
    {
        "school": "Lakeridge High School",
        "district": "Lake Oswego SD 7J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410723000069",
    },
    {
        "school": "Westridge Elementary School",
        "district": "Lake Oswego SD 7J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410723001307",
    },
    {
        "school": "Hallinan Elementary School",
        "district": "Lake Oswego SD 7J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410723001308",
    },
    {
        "school": "Oak Creek Elementary School",
        "district": "Lake Oswego SD 7J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410723001378",
    },
    {
        "school": "Clarkes Elementary School",
        "district": "Molalla River SD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410831000101",
    },
    {
        "school": "Molalla River Middle School",
        "district": "Molalla River SD 35",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410831000102",
    },
    {
        "school": "Mulino Elementary School",
        "district": "Molalla River SD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410831000129",
    },
    {
        "school": "Rural Dell Elementary School",
        "district": "Molalla River SD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410831000136",
    },
    {
        "school": "Molalla High School",
        "district": "Molalla River SD 35",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410831000151",
    },
    {
        "school": "Molalla Elementary School",
        "district": "Molalla River SD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410831001325",
    },
    {
        "school": "Oregon Trail Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000008",
    },
    {
        "school": "Ardenwald Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000070",
    },
    {
        "school": "Bilquist Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000072",
    },
    {
        "school": "Happy Valley Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000076",
    },
    {
        "school": "Linwood Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000079",
    },
    {
        "school": "Whitcomb Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000080",
    },
    {
        "school": "Milwaukie Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000081",
    },
    {
        "school": "Riverside Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000084",
    },
    {
        "school": "Lewelling Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000085",
    },
    {
        "school": "Sunnyside Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000086",
    },
    {
        "school": "View Acres Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000087",
    },
    {
        "school": "Rowe Middle School",
        "district": "North Clackamas SD 12",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000092",
    },
    {
        "school": "Clackamas High School",
        "district": "North Clackamas SD 12",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000093",
    },
    {
        "school": "Milwaukie High School",
        "district": "North Clackamas SD 12",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000094",
    },
    {
        "school": "Putnam High School",
        "district": "North Clackamas SD 12",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883000095",
    },
    {
        "school": "Sojourner School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001317",
    },
    {
        "school": "Mount Scott Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001354",
    },
    {
        "school": "Rock Creek Middle School",
        "district": "North Clackamas SD 12",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001379",
    },
    {
        "school": "Spring Mountain Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001483",
    },
    {
        "school": "Oak Grove Elementary",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001484",
    },
    {
        "school": "Alder Creek Middle School",
        "district": "North Clackamas SD 12",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883004189",
    },
    {
        "school": "Beavercreek Elementary School",
        "district": "Oregon City SD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933000112",
    },
    {
        "school": "Candy Lane Elementary School",
        "district": "Oregon City SD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933000113",
    },
    {
        "school": "Holcomb Elementary School",
        "district": "Oregon City SD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933000114",
    },
    {
        "school": "Gaffney Lane Elementary School",
        "district": "Oregon City SD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933000116",
    },
    {
        "school": "Jennings Lodge Elementary School",
        "district": "Oregon City SD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933000117",
    },
    {
        "school": "John McLoughlin Elementary School",
        "district": "Oregon City SD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933000122",
    },
    {
        "school": "Gardiner Middle School",
        "district": "Oregon City SD 62",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933000123",
    },
    {
        "school": "Ogden Middle School",
        "district": "Oregon City SD 62",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933000124",
    },
    {
        "school": "Oregon City Senior High School",
        "district": "Oregon City SD 62",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933000126",
    },
    {
        "school": "Redland Elementary School",
        "district": "Oregon City SD 62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933000147",
    },
    {
        "school": "Welches Elementary School",
        "district": "Oregon Trail SD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411089000096",
    },
    {
        "school": "Naas Elementary School",
        "district": "Oregon Trail SD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411089000103",
    },
    {
        "school": "Boring Middle School",
        "district": "Oregon Trail SD 46",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411089000104",
    },
    {
        "school": "Sandy Grade School",
        "district": "Oregon Trail SD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411089000106",
    },
    {
        "school": "Firwood Elementary School",
        "district": "Oregon Trail SD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411089000107",
    },
    {
        "school": "Cedar Ridge Middle School",
        "district": "Oregon Trail SD 46",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411089000108",
    },
    {
        "school": "Sandy High School",
        "district": "Oregon Trail SD 46",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411089000149",
    },
    {
        "school": "Kelso Elementary School",
        "district": "Oregon Trail SD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411089001297",
    },
    {
        "school": "Welches Middle School",
        "district": "Oregon Trail SD 46",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411089001453",
    },
    {
        "school": "Bridgeport Elementary School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001331",
    },
    {
        "school": "Cedaroak Park Primary School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317000053",
    },
    {
        "school": "Stafford Primary School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317000054",
    },
    {
        "school": "Sunset Primary School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317000055",
    },
    {
        "school": "Athey Creek Middle School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317000056",
    },
    {
        "school": "West Linn High School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317000058",
    },
    {
        "school": "Wilsonville High School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317000574",
    },
    {
        "school": "Inza R Wood Middle School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317001318",
    },
    {
        "school": "Boeckman Creek Primary School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317001356",
    },
    {
        "school": "Willamette Primary School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317001377",
    },
    {
        "school": "Rosemont Ridge Middle School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317001414",
    },
    {
        "school": "Three Rivers Charter School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317001437",
    },
    {
        "school": "Bolton Primary School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317001447",
    },
    {
        "school": "Clatskanie Elementary School",
        "district": "Clatskanie SD 6J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410326000173",
    },
    {
        "school": "Clatskanie Middle/High School",
        "district": "Clatskanie SD 6J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410326000178",
    },
    {
        "school": "Hudson Park Elementary School",
        "district": "Rainier SD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410326500181",
    },
    {
        "school": "Rainier Jr/Sr High School",
        "district": "Rainier SD 13",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410326500184",
    },
    {
        "school": "Grant Watts Elementary School",
        "district": "Scappoose SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411098000168",
    },
    {
        "school": "Otto Petersen Elementary School",
        "district": "Scappoose SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411098000169",
    },
    {
        "school": "Warren Elementary School",
        "district": "Scappoose SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411098000170",
    },
    {
        "school": "Scappoose Middle School",
        "district": "Scappoose SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411098000171",
    },
    {
        "school": "Scappoose High School",
        "district": "Scappoose SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411098000172",
    },
    {
        "school": "Columbia City School",
        "district": "St Helens SD 502",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411172000189",
    },
    {
        "school": "McBride Elementary School",
        "district": "St Helens SD 502",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411172000193",
    },
    {
        "school": "St Helens Middle School",
        "district": "St Helens SD 502",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411172000195",
    },
    {
        "school": "St Helens High School",
        "district": "St Helens SD 502",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411172000196",
    },
    {
        "school": "Lewis & Clark Elementary School",
        "district": "St Helens SD 502",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411172004195",
    },
    {
        "school": "Mist Elementary School",
        "district": "Vernonia SD 47J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411293000186",
    },
    {
        "school": "Vernonia Elementary School",
        "district": "Vernonia SD 47J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411293000187",
    },
    {
        "school": "Vernonia High School",
        "district": "Vernonia SD 47J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411293000188",
    },
    {
        "school": "Meadows Elementary",
        "district": "Centennial SD 28J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410280001012",
    },
    {
        "school": "Centennial Middle School",
        "district": "Centennial SD 28J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410280001013",
    },
    {
        "school": "Oliver Elementary School",
        "district": "Centennial SD 28J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410280001015",
    },
    {
        "school": "Parklane Elementary School",
        "district": "Centennial SD 28J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410280001016",
    },
    {
        "school": "Patrick Lynch Elementary",
        "district": "Centennial SD 28J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410280001017",
    },
    {
        "school": "Powell Butte Elementary School",
        "district": "Centennial SD 28J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410280001018",
    },
    {
        "school": "Pleasant Valley Elementary School",
        "district": "Centennial SD 28J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410280001019",
    },
    {
        "school": "Centennial High School",
        "district": "Centennial SD 28J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410280001020",
    },
    {
        "school": "Centennial Park School",
        "district": "Centennial SD 28J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410280001221",
    },
    {
        "school": "Cherry Park Elementary School",
        "district": "David Douglas SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001025",
    },
    {
        "school": "Floyd Light Middle School",
        "district": "David Douglas SD 40",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001027",
    },
    {
        "school": "Alice Ott Middle School",
        "district": "David Douglas SD 40",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001028",
    },
    {
        "school": "Gilbert Heights Elementary School",
        "district": "David Douglas SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001029",
    },
    {
        "school": "Gilbert Park Elementary School",
        "district": "David Douglas SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001030",
    },
    {
        "school": "Lincoln Park Elementary School",
        "district": "David Douglas SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001031",
    },
    {
        "school": "Menlo Park Elementary School",
        "district": "David Douglas SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001032",
    },
    {
        "school": "Mill Park Elementary School",
        "district": "David Douglas SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001033",
    },
    {
        "school": "Ventura Park Elementary School",
        "district": "David Douglas SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001035",
    },
    {
        "school": "West Powellhurst Elementary School",
        "district": "David Douglas SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001036",
    },
    {
        "school": "David Douglas High School",
        "district": "David Douglas SD 40",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394001037",
    },
    {
        "school": "Earl Boyles Elementary",
        "district": "David Douglas SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394004180",
    },
    {
        "school": "Arthur Academy",
        "district": "David Douglas SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410394004181",
    },
    {
        "school": "Clear Creek Middle School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000525",
    },
    {
        "school": "Kelly Creek Elementary School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000534",
    },
    {
        "school": "Dexter McCarty Middle School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000988",
    },
    {
        "school": "East Gresham Elementary School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000989",
    },
    {
        "school": "Gordon Russell Middle School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000990",
    },
    {
        "school": "Highland Elementary School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000991",
    },
    {
        "school": "North Gresham Elementary School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000992",
    },
    {
        "school": "Powell Valley Elementary School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000993",
    },
    {
        "school": "West Gresham Elementary School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000994",
    },
    {
        "school": "East Orient Elementary School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000995",
    },
    {
        "school": "West Orient Middle School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600000996",
    },
    {
        "school": "Gresham High School",
        "district": "Gresham-Barlow SD 10J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600001040",
    },
    {
        "school": "Sam Barlow High School",
        "district": "Gresham-Barlow SD 10J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600001041",
    },
    {
        "school": "Hollydale Elementary School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600001303",
    },
    {
        "school": "Hall Elementary School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600001304",
    },
    {
        "school": "Hogan Cedars Elementary School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600004182",
    },
    {
        "school": "Springwater Trail High School",
        "district": "Gresham-Barlow SD 10J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600004183",
    },
    {
        "school": "Prescott Elementary School",
        "district": "Parkrose SD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410948000979",
    },
    {
        "school": "Russell Elementary",
        "district": "Parkrose SD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410948000980",
    },
    {
        "school": "Sacramento Elementary School",
        "district": "Parkrose SD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410948000981",
    },
    {
        "school": "Shaver Elementary School",
        "district": "Parkrose SD 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410948000982",
    },
    {
        "school": "Parkrose Middle School",
        "district": "Parkrose SD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410948000986",
    },
    {
        "school": "Parkrose High School",
        "district": "Parkrose SD 3",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410948000987",
    },
    {
        "school": "Rieke Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000371",
    },
    {
        "school": "Abernethy Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000865",
    },
    {
        "school": "Ainsworth Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000866",
    },
    {
        "school": "Alameda Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000867",
    },
    {
        "school": "Arleta Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000869",
    },
    {
        "school": "Astor Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000870",
    },
    {
        "school": "Atkinson Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000871",
    },
    {
        "school": "Rosa Parks Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000872",
    },
    {
        "school": "Beach Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000873",
    },
    {
        "school": "Beaumont Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000874",
    },
    {
        "school": "Boise-Eliot Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000876",
    },
    {
        "school": "Bridger Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000877",
    },
    {
        "school": "Bridlemile Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000878",
    },
    {
        "school": "Buckman Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000880",
    },
    {
        "school": "Capitol Hill Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000881",
    },
    {
        "school": "Chapman Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000882",
    },
    {
        "school": "Chief Joseph Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000883",
    },
    {
        "school": "Cesar Chavez K-8 School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000884",
    },
    {
        "school": "Harrison Park School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000885",
    },
    {
        "school": "Creston Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000886",
    },
    {
        "school": "Duniway Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000887",
    },
    {
        "school": "Faubion Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000890",
    },
    {
        "school": "George Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000893",
    },
    {
        "school": "Glencoe Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000894",
    },
    {
        "school": "Gray Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000896",
    },
    {
        "school": "Grout Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000898",
    },
    {
        "school": "Hayhurst Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000899",
    },
    {
        "school": "Beverly Cleary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000901",
    },
    {
        "school": "Hosford Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000902",
    },
    {
        "school": "Irvington Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000905",
    },
    {
        "school": "James John Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000906",
    },
    {
        "school": "Kelly Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000909",
    },
    {
        "school": "Dr. Martin Luther King Jr. School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000911",
    },
    {
        "school": "Lane Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000912",
    },
    {
        "school": "Laurelhurst Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000913",
    },
    {
        "school": "Lee Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000914",
    },
    {
        "school": "Lent Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000915",
    },
    {
        "school": "Lewis Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000916",
    },
    {
        "school": "Llewellyn Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000917",
    },
    {
        "school": "Maplewood Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000918",
    },
    {
        "school": "Markham Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000919",
    },
    {
        "school": "Marysville Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000920",
    },
    {
        "school": "Mt Tabor Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000922",
    },
    {
        "school": "Ockley Green Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000925",
    },
    {
        "school": "Peninsula Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000926",
    },
    {
        "school": "Richmond Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000930",
    },
    {
        "school": "Rigler Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000931",
    },
    {
        "school": "Roseway Heights School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000932",
    },
    {
        "school": "Sabin Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000933",
    },
    {
        "school": "Scott Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000935",
    },
    {
        "school": "Sellwood Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000936",
    },
    {
        "school": "Sitton Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000937",
    },
    {
        "school": "Skyline Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000938",
    },
    {
        "school": "Stephenson Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000940",
    },
    {
        "school": "Sunnyside Environmental School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000941",
    },
    {
        "school": "Vernon Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000944",
    },
    {
        "school": "Vestal Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000945",
    },
    {
        "school": "Whitman Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000949",
    },
    {
        "school": "Woodlawn Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000952",
    },
    {
        "school": "Woodmere Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000953",
    },
    {
        "school": "Woodstock Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000954",
    },
    {
        "school": "Benson Polytechnic High School",
        "district": "Portland SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000956",
    },
    {
        "school": "Cleveland High School",
        "district": "Portland SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000958",
    },
    {
        "school": "Franklin High School",
        "district": "Portland SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000960",
    },
    {
        "school": "Grant High School",
        "district": "Portland SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000962",
    },
    {
        "school": "Jefferson High School",
        "district": "Portland SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000964",
    },
    {
        "school": "Lincoln High School",
        "district": "Portland SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000966",
    },
    {
        "school": "Metropolitan Learning Center",
        "district": "Portland SD 1J",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "411004000967",
    },
    {
        "school": "Madison High School",
        "district": "Portland SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000968",
    },
    {
        "school": "Wilson High School",
        "district": "Portland SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000975",
    },
    {
        "school": "da Vinci Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001079",
    },
    {
        "school": "Winterhaven School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001102",
    },
    {
        "school": "Harriet Tubman Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001315",
    },
    {
        "school": "Jackson Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001365",
    },
    {
        "school": "Forest Park Elementary School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001395",
    },
    {
        "school": "Opal School of the Portland Children's Museum",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001435",
    },
    {
        "school": "Alder Elementary School",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052000997",
    },
    {
        "school": "Fairview Elementary School",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052000998",
    },
    {
        "school": "Glenfair Elementary School",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052000999",
    },
    {
        "school": "Hartley Elementary School",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001000",
    },
    {
        "school": "Margaret Scott Elementary School",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001001",
    },
    {
        "school": "Davis Elementary School",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001003",
    },
    {
        "school": "Sweetbriar Elementary School",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001004",
    },
    {
        "school": "Troutdale Elementary School",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001005",
    },
    {
        "school": "Wilkes Elementary School",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001006",
    },
    {
        "school": "Hauton B Lee Middle School",
        "district": "Reynolds SD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001007",
    },
    {
        "school": "Reynolds High School",
        "district": "Reynolds SD 7",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001009",
    },
    {
        "school": "Reynolds Middle School",
        "district": "Reynolds SD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001010",
    },
    {
        "school": "Woodland Elementary",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001209",
    },
    {
        "school": "Walt Morey Middle School",
        "district": "Reynolds SD 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001397",
    },
    {
        "school": "Multnomah Learning Academy",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001434",
    },
    {
        "school": "Riverdale High School",
        "district": "Riverdale SD 51J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411056000892",
    },
    {
        "school": "Riverdale Grade School",
        "district": "Riverdale SD 51J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411056001039",
    },
    {
        "school": "Sauvie Island School",
        "district": "Scappoose SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411098001011",
    },
    {
        "school": "Helensview High School",
        "district": "Multnomah ESD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "418018000230",
    },
    {
        "school": "Willamina Middle School",
        "district": "Willamina SD 30J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411335001338",
    },
    {
        "school": "Tobias Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002300209",
    },
    {
        "school": "West Union Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301168",
    },
    {
        "school": "Brookwood Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301169",
    },
    {
        "school": "Eastwood Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301171",
    },
    {
        "school": "W Verne McKinney Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301172",
    },
    {
        "school": "Mooberry Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301173",
    },
    {
        "school": "W L Henry Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301175",
    },
    {
        "school": "Butternut Creek Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301199",
    },
    {
        "school": "Reedville Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301200",
    },
    {
        "school": "Ladd Acres Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301201",
    },
    {
        "school": "Witch Hazel Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301202",
    },
    {
        "school": "Groner K-8",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301203",
    },
    {
        "school": "Farmington View Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301242",
    },
    {
        "school": "North Plains Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301243",
    },
    {
        "school": "Century High School",
        "district": "Hillsboro SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301248",
    },
    {
        "school": "R A Brown Middle School",
        "district": "Hillsboro SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301250",
    },
    {
        "school": "J W Poynter Middle School",
        "district": "Hillsboro SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301251",
    },
    {
        "school": "Hillsboro High School",
        "district": "Hillsboro SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301252",
    },
    {
        "school": "South Meadows Middle School",
        "district": "Hillsboro SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301253",
    },
    {
        "school": "Indian Hills Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301295",
    },
    {
        "school": "Lenox Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301300",
    },
    {
        "school": "Minter Bridge Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301305",
    },
    {
        "school": "Glencoe High School",
        "district": "Hillsboro SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301306",
    },
    {
        "school": "Evergreen Jr High School",
        "district": "Hillsboro SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301322",
    },
    {
        "school": "Jackson Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301373",
    },
    {
        "school": "Orenco Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301499",
    },
    {
        "school": "Paul L Patterson Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301500",
    },
    {
        "school": "Imlay Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002304174",
    },
    {
        "school": "Banks Elementary School",
        "district": "Banks SD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410183001176",
    },
    {
        "school": "Banks Middle School",
        "district": "Banks SD 13",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410183001179",
    },
    {
        "school": "Banks High School",
        "district": "Banks SD 13",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410183001180",
    },
    {
        "school": "Nancy Ryles Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192000210",
    },
    {
        "school": "Arts and Communication Magnet Academy",
        "district": "Beaverton SD 48J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192000213",
    },
    {
        "school": "Community School",
        "district": "Beaverton SD 48J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410192000220",
    },
    {
        "school": "School of Science & Technology",
        "district": "Beaverton SD 48J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192000536",
    },
    {
        "school": "Conestoga Middle School",
        "district": "Beaverton SD 48J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192000552",
    },
    {
        "school": "Westview High School",
        "district": "Beaverton SD 48J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192000554",
    },
    {
        "school": "Aloha-Huber Park School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001204",
    },
    {
        "school": "Barnes Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001205",
    },
    {
        "school": "Beaver Acres Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001206",
    },
    {
        "school": "Bethany Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001207",
    },
    {
        "school": "Cedar Mill Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001210",
    },
    {
        "school": "Chehalem Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001211",
    },
    {
        "school": "Cooper Mountain Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001212",
    },
    {
        "school": "Fir Grove Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001213",
    },
    {
        "school": "Hazeldale Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001215",
    },
    {
        "school": "Hiteon Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001216",
    },
    {
        "school": "Kinnaman Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001217",
    },
    {
        "school": "McKay Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001219",
    },
    {
        "school": "McKinley Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001220",
    },
    {
        "school": "Montclair Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001222",
    },
    {
        "school": "Oak Hills Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001223",
    },
    {
        "school": "Raleigh Hills Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001224",
    },
    {
        "school": "Raleigh Park Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001225",
    },
    {
        "school": "Ridgewood Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001226",
    },
    {
        "school": "Rock Creek Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001227",
    },
    {
        "school": "Terra Linda Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001229",
    },
    {
        "school": "Vose Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001230",
    },
    {
        "school": "West Tualatin View Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001231",
    },
    {
        "school": "William Walker Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001232",
    },
    {
        "school": "Cedar Park Middle School",
        "district": "Beaverton SD 48J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001233",
    },
    {
        "school": "Five Oaks Middle School",
        "district": "Beaverton SD 48J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001234",
    },
    {
        "school": "Meadow Park Middle School",
        "district": "Beaverton SD 48J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001235",
    },
    {
        "school": "Mountain View Middle School",
        "district": "Beaverton SD 48J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001236",
    },
    {
        "school": "Highland Park Middle School",
        "district": "Beaverton SD 48J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001237",
    },
    {
        "school": "Whitford Middle School",
        "district": "Beaverton SD 48J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001238",
    },
    {
        "school": "Aloha High School",
        "district": "Beaverton SD 48J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001239",
    },
    {
        "school": "Beaverton High School",
        "district": "Beaverton SD 48J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001240",
    },
    {
        "school": "Sunset High School",
        "district": "Beaverton SD 48J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001241",
    },
    {
        "school": "Findley Elementary",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001262",
    },
    {
        "school": "Greenway Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001289",
    },
    {
        "school": "Errol Hassell Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001301",
    },
    {
        "school": "Elmonica Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001321",
    },
    {
        "school": "Scholls Heights Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001430",
    },
    {
        "school": "Stoller Middle School",
        "district": "Beaverton SD 48J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001431",
    },
    {
        "school": "Southridge High School",
        "district": "Beaverton SD 48J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001432",
    },
    {
        "school": "Jacob Wismer Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001445",
    },
    {
        "school": "Cornelius Elementary School",
        "district": "Forest Grove SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410516001182",
    },
    {
        "school": "Dilley Elementary School",
        "district": "Forest Grove SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410516001183",
    },
    {
        "school": "Echo Shaw Elementary School",
        "district": "Forest Grove SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410516001184",
    },
    {
        "school": "Harvey Clarke Elementary School",
        "district": "Forest Grove SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410516001186",
    },
    {
        "school": "Joseph Gale Elementary School",
        "district": "Forest Grove SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410516001187",
    },
    {
        "school": "Neil Armstrong Middle School",
        "district": "Forest Grove SD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410516001188",
    },
    {
        "school": "Forest Grove High School",
        "district": "Forest Grove SD 15",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410516001189",
    },
    {
        "school": "Tom McCall Upper Elementary",
        "district": "Forest Grove SD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410516001339",
    },
    {
        "school": "Gaston Elementary School",
        "district": "Gaston SD 511J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410543001247",
    },
    {
        "school": "Gaston Jr/Sr High School",
        "district": "Gaston SD 511J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410543001249",
    },
    {
        "school": "West Sylvan Middle School",
        "district": "Portland SD 1J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004000947",
    },
    {
        "school": "Archer Glen Elementary School",
        "district": "Sherwood SD 88J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411129000679",
    },
    {
        "school": "J Clyde Hopkins Elementary School",
        "district": "Sherwood SD 88J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411129001244",
    },
    {
        "school": "Sherwood Middle School",
        "district": "Sherwood SD 88J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411129001245",
    },
    {
        "school": "Sherwood High School",
        "district": "Sherwood SD 88J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411129001246",
    },
    {
        "school": "Middleton Elementary School",
        "district": "Sherwood SD 88J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411129001501",
    },
    {
        "school": "Hazelbrook Middle School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224000381",
    },
    {
        "school": "Tualatin High School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224000440",
    },
    {
        "school": "Charles F Tigard Elementary School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001190",
    },
    {
        "school": "Durham Elementary School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001191",
    },
    {
        "school": "James Templeton Elementary School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001192",
    },
    {
        "school": "Metzger Elementary School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001193",
    },
    {
        "school": "Tualatin Elementary School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001195",
    },
    {
        "school": "Thomas R Fowler Middle School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001196",
    },
    {
        "school": "Twality Middle School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001197",
    },
    {
        "school": "Tigard High School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001198",
    },
    {
        "school": "Deer Creek Elementary School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001261",
    },
    {
        "school": "Edward Byrom Elementary School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001298",
    },
    {
        "school": "Mary Woodward Elementary School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411224001299",
    },
    {
        "school": "Yamhill Carlton Elementary School",
        "district": "Yamhill Carlton SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001601266",
    },
    {
        "school": "Yamhill Carlton High School",
        "district": "Yamhill Carlton SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001601288",
    },
    {
        "school": "Amity Elementary School",
        "district": "Amity SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410123001260",
    },
    {
        "school": "Amity High School",
        "district": "Amity SD 4J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410123001263",
    },
    {
        "school": "Amity Middle School",
        "district": "Amity SD 4J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410123001320",
    },
    {
        "school": "Dayton Jr High School",
        "district": "Dayton SD 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410399000228",
    },
    {
        "school": "Dayton Grade School",
        "district": "Dayton SD 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410399001264",
    },
    {
        "school": "Dayton High School",
        "district": "Dayton SD 8",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410399001265",
    },
    {
        "school": "Duniway Middle School",
        "district": "McMinnville SD 40",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410801000540",
    },
    {
        "school": "Columbus Elementary School",
        "district": "McMinnville SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410801001279",
    },
    {
        "school": "Memorial Elementary School",
        "district": "McMinnville SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410801001281",
    },
    {
        "school": "Newby Elementary School",
        "district": "McMinnville SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410801001282",
    },
    {
        "school": "Patton Middle School",
        "district": "McMinnville SD 40",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410801001283",
    },
    {
        "school": "McMinnville High School",
        "district": "McMinnville SD 40",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410801001284",
    },
    {
        "school": "Wascher Elementary School",
        "district": "McMinnville SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410801001310",
    },
    {
        "school": "Grandhaven Elementary School",
        "district": "McMinnville SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410801001433",
    },
    {
        "school": "Dundee Elementary School",
        "district": "Newberg SD 29J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410872001269",
    },
    {
        "school": "Edwards Elementary School",
        "district": "Newberg SD 29J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410872001270",
    },
    {
        "school": "Ewing Young Elementary School",
        "district": "Newberg SD 29J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410872001271",
    },
    {
        "school": "Mabel Rush Elementary School",
        "district": "Newberg SD 29J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410872001272",
    },
    {
        "school": "Mountain View Middle School",
        "district": "Newberg SD 29J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410872001273",
    },
    {
        "school": "Newberg Senior High School",
        "district": "Newberg SD 29J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410872001274",
    },
    {
        "school": "Antonia Crater Elementary School",
        "district": "Newberg SD 29J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410872001291",
    },
    {
        "school": "Chehalem Valley Middle School",
        "district": "Newberg SD 29J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410872001309",
    },
    {
        "school": "Faulconer-Chapman School",
        "district": "Sheridan SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411122001285",
    },
    {
        "school": "Sheridan High School",
        "district": "Sheridan SD 48J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411122001287",
    },
    {
        "school": "Sheridan Japanese School",
        "district": "Sheridan SD 48J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411122001450",
    },
    {
        "school": "Willamina Elementary School",
        "district": "Willamina SD 30J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411335001276",
    },
    {
        "school": "Willamina High School",
        "district": "Willamina SD 30J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411335001277",
    },
    {
        "school": "Crooked River Elementary School",
        "district": "Crook County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410372000238",
    },
    {
        "school": "Paulina School",
        "district": "Crook County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410372000241",
    },
    {
        "school": "Powell Butte Community Charter School",
        "district": "Crook County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410372000242",
    },
    {
        "school": "Crook County Middle School",
        "district": "Crook County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410372000243",
    },
    {
        "school": "Crook County High School",
        "district": "Crook County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410372000244",
    },
    {
        "school": "Brockway Elementary School",
        "district": "Winston-Dillard SD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411349001573",
    },
    {
        "school": "Camas Valley School",
        "district": "Camas Valley SD 21J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410261000315",
    },
    {
        "school": "Days Creek Charter School",
        "district": "Douglas County SD 15",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410396000308",
    },
    {
        "school": "North Douglas Elementary School",
        "district": "North Douglas SD 22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410435000316",
    },
    {
        "school": "North Douglas High School",
        "district": "North Douglas SD 22",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410435000317",
    },
    {
        "school": "Elkton Charter School",
        "district": "Elkton SD 34",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410462000322",
    },
    {
        "school": "Glendale Elementary School",
        "district": "Glendale SD 77",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410564000326",
    },
    {
        "school": "Glendale Community Charter School",
        "district": "Glendale SD 77",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410564000327",
    },
    {
        "school": "Glide Elementary School",
        "district": "Glide SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410567000302",
    },
    {
        "school": "Glide Middle School",
        "district": "Glide SD 12",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410567000303",
    },
    {
        "school": "Glide High School",
        "district": "Glide SD 12",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410567000305",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Oakland SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410912000285",
    },
    {
        "school": "Oakland Elementary School",
        "district": "Oakland SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410912000286",
    },
    {
        "school": "Oakland High School",
        "district": "Oakland SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410912000287",
    },
    {
        "school": "Highland Elementary School",
        "district": "Reedsport SD 105",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411041000329",
    },
    {
        "school": "Reedsport Community Charter School",
        "district": "Reedsport SD 105",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411041000330",
    },
    {
        "school": "Riddle Elementary School",
        "district": "Riddle SD 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411053000324",
    },
    {
        "school": "Riddle High School",
        "district": "Riddle SD 70",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411053000325",
    },
    {
        "school": "Eastwood Elementary School",
        "district": "Douglas County SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071000288",
    },
    {
        "school": "Fir Grove Elementary School",
        "district": "Douglas County SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071000289",
    },
    {
        "school": "Fullerton IV Elementary School",
        "district": "Douglas County SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071000290",
    },
    {
        "school": "Green Elementary School",
        "district": "Douglas County SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071000291",
    },
    {
        "school": "Hucrest Elementary School",
        "district": "Douglas County SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071000292",
    },
    {
        "school": "Melrose Elementary School",
        "district": "Douglas County SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071000293",
    },
    {
        "school": "Sunnyslope Elementary School",
        "district": "Douglas County SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071000296",
    },
    {
        "school": "Winchester Elementary",
        "district": "Douglas County SD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071000297",
    },
    {
        "school": "John C Fremont Middle School",
        "district": "Douglas County SD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071000298",
    },
    {
        "school": "Joseph Lane Middle School",
        "district": "Douglas County SD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071000299",
    },
    {
        "school": "Roseburg High School",
        "district": "Douglas County SD 4",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411071000300",
    },
    {
        "school": "Canyonville School",
        "district": "South Umpqua SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411161000309",
    },
    {
        "school": "Myrtle Creek Elementary School",
        "district": "South Umpqua SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411161000310",
    },
    {
        "school": "Coffenberry Middle School",
        "district": "South Umpqua SD 19",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411161000311",
    },
    {
        "school": "Tri City Elementary School",
        "district": "South Umpqua SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411161000312",
    },
    {
        "school": "South Umpqua High School",
        "district": "South Umpqua SD 19",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411161000313",
    },
    {
        "school": "East Sutherlin Primary School",
        "district": "Sutherlin SD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411194000338",
    },
    {
        "school": "Sutherlin Middle School",
        "district": "Sutherlin SD 130",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411194000339",
    },
    {
        "school": "West Sutherlin Intermediate",
        "district": "Sutherlin SD 130",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411194000340",
    },
    {
        "school": "Sutherlin High School",
        "district": "Sutherlin SD 130",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411194000341",
    },
    {
        "school": "McGovern Elementary School",
        "district": "Winston-Dillard SD 116",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411349000331",
    },
    {
        "school": "Lookingglass Elementary School",
        "district": "Winston-Dillard SD 116",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411349000333",
    },
    {
        "school": "Winston Middle School",
        "district": "Winston-Dillard SD 116",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411349000335",
    },
    {
        "school": "Douglas High School",
        "district": "Winston-Dillard SD 116",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411349000336",
    },
    {
        "school": "Yoncalla Elementary School",
        "district": "Yoncalla SD 32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411365000319",
    },
    {
        "school": "Yoncalla High School",
        "district": "Yoncalla SD 32",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411365000320",
    },
    {
        "school": "Riverside High School",
        "district": "ODE YCEP District",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004301413",
    },
    {
        "school": "Monroe School",
        "district": "ODE YCEP District",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004301404",
    },
    {
        "school": "New Bridge High School",
        "district": "ODE YCEP District",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004301406",
    },
    {
        "school": "Ocean Dunes High School",
        "district": "ODE YCEP District",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004301412",
    },
    {
        "school": "Four Rivers Community School",
        "district": "Oregon Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410000901592",
    },
    {
        "school": "Samuel Brown Academy",
        "district": "Gervais SD 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410001501588",
    },
    {
        "school": "William P Lord High School",
        "district": "ODE YCEP District",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004300494",
    },
    {
        "school": "Jane Goodall Environmental Middle Charter School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001536",
    },
    {
        "school": "Woodburn Arthur Academy",
        "district": "Woodburn SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353001546",
    },
    {
        "school": "Ash Creek Elementary School",
        "district": "Central SD 13J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410284001461",
    },
    {
        "school": "Harritt Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001600",
    },
    {
        "school": "RiverBend High School",
        "district": "ODE YCEP District",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004301477",
    },
    {
        "school": "Butte Creek Elementary School",
        "district": "Silver Falls SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000127",
    },
    {
        "school": "Mari-Linn Elementary School",
        "district": "North Santiam SD 29J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002000693",
    },
    {
        "school": "Oregon School for the Deaf",
        "district": "Oregon Department of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "OR",
        "nces_id": "410000900062",
    },
    {
        "school": "Gervais Elementary School",
        "district": "Gervais SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001500821",
    },
    {
        "school": "Gervais Middle School",
        "district": "Gervais SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001500831",
    },
    {
        "school": "Gervais High School",
        "district": "Gervais SD 1",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001500853",
    },
    {
        "school": "Sublimity Elementary School",
        "district": "North Santiam SD 29J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002000765",
    },
    {
        "school": "Stayton Elementary School",
        "district": "North Santiam SD 29J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002000833",
    },
    {
        "school": "Stayton Middle School",
        "district": "North Santiam SD 29J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002000834",
    },
    {
        "school": "Stayton High School",
        "district": "North Santiam SD 29J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002000854",
    },
    {
        "school": "Aumsville Elementary School",
        "district": "Cascade SD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410278000767",
    },
    {
        "school": "Turner Elementary School",
        "district": "Cascade SD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410278000835",
    },
    {
        "school": "Cloverdale Elementary School",
        "district": "Cascade SD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410278000851",
    },
    {
        "school": "Cascade Junior High School",
        "district": "Cascade SD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410278000855",
    },
    {
        "school": "Cascade Senior High School",
        "district": "Cascade SD 5",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410278000856",
    },
    {
        "school": "Jefferson Elementary School",
        "district": "Jefferson SD 14J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410671000769",
    },
    {
        "school": "Jefferson High School",
        "district": "Jefferson SD 14J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410671000770",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Jefferson SD 14J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410671001294",
    },
    {
        "school": "Mt Angel Middle School",
        "district": "Mt Angel SD 91",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410855000837",
    },
    {
        "school": "St Marys Public School",
        "district": "Mt Angel SD 91",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410855000838",
    },
    {
        "school": "John F Kennedy High School",
        "district": "Mt Angel SD 91",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410855000839",
    },
    {
        "school": "North Marion Intermediate School",
        "district": "North Marion SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410888000771",
    },
    {
        "school": "North Marion High School",
        "district": "North Marion SD 15",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410888000772",
    },
    {
        "school": "North Marion Middle School",
        "district": "North Marion SD 15",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410888001326",
    },
    {
        "school": "North Marion Primary School",
        "district": "North Marion SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410888001424",
    },
    {
        "school": "Yoshikai Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000547",
    },
    {
        "school": "Crossler Middle School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000659",
    },
    {
        "school": "Houck Middle School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000664",
    },
    {
        "school": "Stephens Middle School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000668",
    },
    {
        "school": "Auburn Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000774",
    },
    {
        "school": "Bush Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000778",
    },
    {
        "school": "Candalaria Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000779",
    },
    {
        "school": "Clear Lake Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000780",
    },
    {
        "school": "Cummings Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000781",
    },
    {
        "school": "Englewood Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000782",
    },
    {
        "school": "Wright Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000783",
    },
    {
        "school": "Four Corners Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000784",
    },
    {
        "school": "Grant Community School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000786",
    },
    {
        "school": "Scott Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000787",
    },
    {
        "school": "Highland Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000789",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000790",
    },
    {
        "school": "Gubser Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000791",
    },
    {
        "school": "Kennedy Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000792",
    },
    {
        "school": "Keizer Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000793",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000795",
    },
    {
        "school": "McKinley Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000796",
    },
    {
        "school": "Eyre Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000797",
    },
    {
        "school": "Morningside Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000799",
    },
    {
        "school": "Hayesville Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000801",
    },
    {
        "school": "Pringle Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000802",
    },
    {
        "school": "Richmond Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000803",
    },
    {
        "school": "Salem Heights Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000805",
    },
    {
        "school": "Schirle Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000806",
    },
    {
        "school": "Sumpter Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000807",
    },
    {
        "school": "Swegle Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000808",
    },
    {
        "school": "Washington Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000809",
    },
    {
        "school": "Judson Middle School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000811",
    },
    {
        "school": "Leslie Middle School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000812",
    },
    {
        "school": "Parrish Middle School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000813",
    },
    {
        "school": "Waldo Middle School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000814",
    },
    {
        "school": "Whiteaker Middle School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000816",
    },
    {
        "school": "McNary High School",
        "district": "Salem-Keizer SD 24J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000817",
    },
    {
        "school": "North Salem High School",
        "district": "Salem-Keizer SD 24J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000818",
    },
    {
        "school": "Sprague High School",
        "district": "Salem-Keizer SD 24J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000819",
    },
    {
        "school": "South Salem High School",
        "district": "Salem-Keizer SD 24J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000820",
    },
    {
        "school": "Howard Street Charter",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001048",
    },
    {
        "school": "McKay High School",
        "district": "Salem-Keizer SD 24J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001296",
    },
    {
        "school": "Claggett Creek Middle School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001440",
    },
    {
        "school": "Weddle Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001441",
    },
    {
        "school": "Lamb Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001442",
    },
    {
        "school": "Hammond Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001443",
    },
    {
        "school": "Hallman Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001444",
    },
    {
        "school": "Miller Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001497",
    },
    {
        "school": "West Salem High School",
        "district": "Salem-Keizer SD 24J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082004191",
    },
    {
        "school": "Lee Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082004192",
    },
    {
        "school": "Optimum Learning Environment Charter School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082004193",
    },
    {
        "school": "Forest Ridge Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082004194",
    },
    {
        "school": "Mark Twain Elementary",
        "district": "Silver Falls SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000762",
    },
    {
        "school": "Silverton Middle School",
        "district": "Silver Falls SD 4J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000763",
    },
    {
        "school": "Robert Frost Elementary School",
        "district": "Silver Falls SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000764",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Silver Falls SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000766",
    },
    {
        "school": "Victor Point Elementary School",
        "district": "Silver Falls SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000822",
    },
    {
        "school": "Pratum Elementary School",
        "district": "Silver Falls SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000825",
    },
    {
        "school": "Bethany Charter School",
        "district": "Silver Falls SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000829",
    },
    {
        "school": "Scotts Mills Elementary School",
        "district": "Silver Falls SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000830",
    },
    {
        "school": "Silver Crest Elementary School",
        "district": "Silver Falls SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000840",
    },
    {
        "school": "Central Howell Elementary School",
        "district": "Silver Falls SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000852",
    },
    {
        "school": "Silverton High School",
        "district": "Silver Falls SD 4J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145000857",
    },
    {
        "school": "St Paul Elementary School",
        "district": "St Paul SD 45",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411176000823",
    },
    {
        "school": "St Paul High School",
        "district": "St Paul SD 45",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411176000824",
    },
    {
        "school": "Nellie Muir Elementary School",
        "district": "Woodburn SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353000841",
    },
    {
        "school": "Washington Elementary School",
        "district": "Woodburn SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353000842",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Woodburn SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353000843",
    },
    {
        "school": "French Prairie Middle School",
        "district": "Woodburn SD 103",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353000844",
    },
    {
        "school": "Heritage Elementary",
        "district": "Woodburn SD 103",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353001051",
    },
    {
        "school": "Valor Middle School",
        "district": "Woodburn SD 103",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353001052",
    },
    {
        "school": "Falls City Elementary School",
        "district": "Falls City SD 57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410000301061",
    },
    {
        "school": "Falls City High School",
        "district": "Falls City SD 57",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410000301062",
    },
    {
        "school": "Independence Elementary School",
        "district": "Central SD 13J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410284001054",
    },
    {
        "school": "Monmouth Elementary School",
        "district": "Central SD 13J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410284001055",
    },
    {
        "school": "Talmadge Middle School",
        "district": "Central SD 13J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410284001057",
    },
    {
        "school": "Central High School",
        "district": "Central SD 13J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410284001058",
    },
    {
        "school": "Lyle Elementary School",
        "district": "Dallas SD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410386001043",
    },
    {
        "school": "Oakdale Heights Elementary School",
        "district": "Dallas SD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410386001044",
    },
    {
        "school": "Luckiamute Valley Charter School",
        "district": "Dallas SD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410386001045",
    },
    {
        "school": "Whitworth Elementary School",
        "district": "Dallas SD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410386001047",
    },
    {
        "school": "LaCreole Middle School",
        "district": "Dallas SD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410386001049",
    },
    {
        "school": "Dallas High School",
        "district": "Dallas SD 2",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410386001050",
    },
    {
        "school": "Perrydale School",
        "district": "Perrydale SD 21",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410953001060",
    },
    {
        "school": "Brush College Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000777",
    },
    {
        "school": "Myers Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000800",
    },
    {
        "school": "Walker Middle School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082000815",
    },
    {
        "school": "Chapman Hill Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001342",
    },
    {
        "school": "Duquesne El Sch",
        "district": "Duquesne City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420801000924",
    },
    {
        "school": "Pittsburgh Spring Garden Early Childhood",
        "district": "Pittsburgh SD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000922",
    },
    {
        "school": "Pittsburgh Chartiers Early Childhood Ctr",
        "district": "Pittsburgh SD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000928",
    },
    {
        "school": "Pittsburgh Miller K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000975",
    },
    {
        "school": "Pittsburgh Lincoln K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000979",
    },
    {
        "school": "Pittsburgh Weil K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000991",
    },
    {
        "school": "Pittsburgh Arsenal K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917003409",
    },
    {
        "school": "West Hills Primary Sch",
        "district": "Armstrong SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420259000945",
    },
    {
        "school": "West Hills Intermediate Sch",
        "district": "Armstrong SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420259000959",
    },
    {
        "school": "Lincoln Park Performing Arts CS",
        "district": "Lincoln Park Performing Arts CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420014300906",
    },
    {
        "school": "Everett Area MS",
        "district": "Everett Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420936000989",
    },
    {
        "school": "Everett Area HS",
        "district": "Everett Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420936001009",
    },
    {
        "school": "Towanda Area El Sch",
        "district": "Towanda Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422355000997",
    },
    {
        "school": "West Chester Bayard Rustin HS",
        "district": "West Chester Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529000969",
    },
    {
        "school": "Harrisburg HS - SciTech Cmp",
        "district": "Harrisburg City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158000967",
    },
    {
        "school": "Marshall Math Science Academy",
        "district": "Harrisburg City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158000981",
    },
    {
        "school": "Widener Partnership CS",
        "district": "Widener Partnership CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420075300937",
    },
    {
        "school": "Penn Wood MS",
        "district": "William Penn SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422639000943",
    },
    {
        "school": "Evergreen Community CS",
        "district": "Evergreen Community CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420074900960",
    },
    {
        "school": "Pocono Mountain West JHS",
        "district": "Pocono Mountain SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421950000961",
    },
    {
        "school": "Shamokin Area MS",
        "district": "Shamokin Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422124000966",
    },
    {
        "school": "Shamokin Area HS",
        "district": "Shamokin Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422124000968",
    },
    {
        "school": "Mastery CS - Thomas Campus",
        "district": "Mastery CS-Thomas Campus",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420014400925",
    },
    {
        "school": "Mastery CS -Shoemaker Campus",
        "district": "Mastery CS-Shoemaker Campus",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420014500944",
    },
    {
        "school": "Science Leadership Academy",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000923",
    },
    {
        "school": "Academy at Palumbo",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000962",
    },
    {
        "school": "School of the Future",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000993",
    },
    {
        "school": "Constitution HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899001010",
    },
    {
        "school": "Mifflinburg Area Intrmd Sch",
        "district": "Mifflinburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422601000998",
    },
    {
        "school": "Delaware County Technical High School-Ma",
        "district": "Delaware County Technical High School",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428020007063",
    },
    {
        "school": "Sugartown El Sch",
        "district": "Great Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421087001461",
    },
    {
        "school": "McConnellsburg MS",
        "district": "Central Fulton SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421485000673",
    },
    {
        "school": "Oswayo Valley MS",
        "district": "Oswayo Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421821000699",
    },
    {
        "school": "Charlotte Lappla El Sch",
        "district": "Wellsboro Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422517000625",
    },
    {
        "school": "Bedford County Technical Center",
        "district": "Bedford County Technical Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "420000107136",
    },
    {
        "school": "Bedford El Sch",
        "district": "Bedford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420318000347",
    },
    {
        "school": "Bedford SHS",
        "district": "Bedford Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420318000726",
    },
    {
        "school": "Bedford MS",
        "district": "Bedford Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420318007021",
    },
    {
        "school": "Chestnut Ridge MS",
        "district": "Chestnut Ridge SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420588000729",
    },
    {
        "school": "Chestnut Ridge Central El Sch",
        "district": "Chestnut Ridge SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420588000730",
    },
    {
        "school": "Chestnut Ridge SHS",
        "district": "Chestnut Ridge SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420588000732",
    },
    {
        "school": "Breezewood El Sch",
        "district": "Everett Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420936000735",
    },
    {
        "school": "Everett Area El Sch",
        "district": "Everett Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420936007006",
    },
    {
        "school": "Northern Bedford Co El Sch",
        "district": "Northern Bedford County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421758007220",
    },
    {
        "school": "Tussey Mountain EL",
        "district": "Tussey Mountain SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422397000752",
    },
    {
        "school": "Tussey Mountain HS",
        "district": "Tussey Mountain SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422397000753",
    },
    {
        "school": "Woodland El Sch",
        "district": "Cameron County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420483001298",
    },
    {
        "school": "Cameron County JSHS",
        "district": "Cameron County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420483001299",
    },
    {
        "school": "Allegheny-Clarion Valley Elem",
        "district": "Allegheny-Clarion Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420231000208",
    },
    {
        "school": "Allegheny-Clarion Valley HS",
        "district": "Allegheny-Clarion Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420231004664",
    },
    {
        "school": "Clarion Area JSHS",
        "district": "Clarion Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420606001475",
    },
    {
        "school": "Clarion Area El Sch",
        "district": "Clarion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420606005217",
    },
    {
        "school": "Clarion-Limestone El Sch",
        "district": "Clarion-Limestone Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420609001479",
    },
    {
        "school": "Clarion-Limestone Area JSHS",
        "district": "Clarion-Limestone Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420609001480",
    },
    {
        "school": "Keystone JSHS",
        "district": "Keystone SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272001486",
    },
    {
        "school": "Keystone El Sch",
        "district": "Keystone SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272006694",
    },
    {
        "school": "North Clarion Co JSHS",
        "district": "North Clarion County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421713001489",
    },
    {
        "school": "North Clarion Co El Sch",
        "district": "North Clarion County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421713005139",
    },
    {
        "school": "Redbank Valley HS",
        "district": "Redbank Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422013001495",
    },
    {
        "school": "Union HS",
        "district": "Union SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422412001501",
    },
    {
        "school": "Rimersburg El Sch",
        "district": "Union SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422412005033",
    },
    {
        "school": "Sligo El Sch",
        "district": "Union SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422412005034",
    },
    {
        "school": "Clarion County Career Center",
        "district": "Clarion County Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428015007056",
    },
    {
        "school": "East Forest JSHS",
        "district": "Forest Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420828006159",
    },
    {
        "school": "East Forest El Sch",
        "district": "Forest Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420828006160",
    },
    {
        "school": "West Forest JSHS",
        "district": "Forest Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420828006161",
    },
    {
        "school": "West Forest El Sch",
        "district": "Forest Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420828006701",
    },
    {
        "school": "Fulton County AVTS",
        "district": "Fulton County AVTS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "420000707253",
    },
    {
        "school": "Forbes Road JSHS",
        "district": "Forbes Road SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420987002246",
    },
    {
        "school": "Forbes Road El Sch",
        "district": "Forbes Road SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420987006840",
    },
    {
        "school": "McConnellsburg El Sch",
        "district": "Central Fulton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421485002248",
    },
    {
        "school": "McConnellsburg HS",
        "district": "Central Fulton SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421485006252",
    },
    {
        "school": "Southern Fulton El Sch",
        "district": "Southern Fulton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422229000093",
    },
    {
        "school": "Southern Fulton JSHS",
        "district": "Southern Fulton SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422229002253",
    },
    {
        "school": "Carmichaels Area HS",
        "district": "Carmichaels Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420507007126",
    },
    {
        "school": "Carmichaels Area El Ctr",
        "district": "Carmichaels Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420507009974",
    },
    {
        "school": "Waynesburg Central El School",
        "district": "Central Greene SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420543000238",
    },
    {
        "school": "Waynesburg Central HS",
        "district": "Central Greene SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420543005118",
    },
    {
        "school": "Miller MS",
        "district": "Central Greene SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420543006010",
    },
    {
        "school": "Jefferson-Morgan MS/HS",
        "district": "Jefferson-Morgan SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421239002280",
    },
    {
        "school": "Jefferson-Morgan El Sch",
        "district": "Jefferson-Morgan SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421239007029",
    },
    {
        "school": "Bobtown El Sch",
        "district": "Southeastern Greene SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422220002271",
    },
    {
        "school": "Mapletown JSHS",
        "district": "Southeastern Greene SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422220002284",
    },
    {
        "school": "Greene County CTC",
        "district": "Greene County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428024007068",
    },
    {
        "school": "Brockway Area JSHS",
        "district": "Brockway Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420426002362",
    },
    {
        "school": "Brockway Area Elementary Sch",
        "district": "Brockway Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420426005148",
    },
    {
        "school": "Pinecreek El Sch",
        "district": "Brookville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420432002368",
    },
    {
        "school": "Hickory Grove El Sch",
        "district": "Brookville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420432005231",
    },
    {
        "school": "Brookville JSHS",
        "district": "Brookville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420432006162",
    },
    {
        "school": "Northside El Sch",
        "district": "Brookville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420432006163",
    },
    {
        "school": "Jefferson County-DuBois AVTS",
        "district": "Jefferson County-DuBois AVTS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "421233505180",
    },
    {
        "school": "Punxsutawney Area HS",
        "district": "Punxsutawney Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421980006165",
    },
    {
        "school": "Austin Area El Sch",
        "district": "Austin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420270006221",
    },
    {
        "school": "Austin Area JSHS",
        "district": "Austin Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420270006222",
    },
    {
        "school": "Coudersport Area El Sch",
        "district": "Coudersport Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420693003868",
    },
    {
        "school": "Coudersport Area JSHS",
        "district": "Coudersport Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420693003869",
    },
    {
        "school": "Galeton Area Sch",
        "district": "Galeton Area SD",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421053006223",
    },
    {
        "school": "Northern Potter JSHS",
        "district": "Northern Potter SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421770003875",
    },
    {
        "school": "Northern Potter Childrens Sch",
        "district": "Northern Potter SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421770006931",
    },
    {
        "school": "Oswayo Valley El Sch",
        "district": "Oswayo Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421821007190",
    },
    {
        "school": "Oswayo Valley HS",
        "district": "Oswayo Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421821007191",
    },
    {
        "school": "Sullivan Co JSHS",
        "district": "Sullivan County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422292004030",
    },
    {
        "school": "Susquehanna County CTC",
        "district": "Susquehanna County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "420000307138",
    },
    {
        "school": "Blue Ridge MS",
        "district": "Blue Ridge SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420390000101",
    },
    {
        "school": "Blue Ridge HS",
        "district": "Blue Ridge SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420390004034",
    },
    {
        "school": "Blue Ridge El Sch",
        "district": "Blue Ridge SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420390006891",
    },
    {
        "school": "Elk Lake El Sch",
        "district": "Elk Lake SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420915006417",
    },
    {
        "school": "Elk Lake JSHS",
        "district": "Elk Lake SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420915006418",
    },
    {
        "school": "Forest City Regional HS",
        "district": "Forest City Regional SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420993006419",
    },
    {
        "school": "Forest City Regional El Sch",
        "district": "Forest City Regional SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420993006420",
    },
    {
        "school": "Montrose Area JSHS",
        "district": "Montrose Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421581004044",
    },
    {
        "school": "Choconut Valley El Sch",
        "district": "Montrose Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421581005354",
    },
    {
        "school": "Lathrop Street El Sch",
        "district": "Montrose Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421581006421",
    },
    {
        "school": "Mountain View JSHS",
        "district": "Mountain View SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421605004049",
    },
    {
        "school": "Mountain View El Sch",
        "district": "Mountain View SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421605009997",
    },
    {
        "school": "Susquehanna Community JSHS",
        "district": "Susquehanna Community SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422298004054",
    },
    {
        "school": "Susquehanna Community El Sch",
        "district": "Susquehanna Community SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422298006885",
    },
    {
        "school": "Cowanesque Valley JSHS",
        "district": "Northern Tioga SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421773004058",
    },
    {
        "school": "Clark Wood El Sch",
        "district": "Northern Tioga SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421773006371",
    },
    {
        "school": "Williamson SHS",
        "district": "Northern Tioga SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421773006373",
    },
    {
        "school": "Westfield Area El Sch",
        "district": "Northern Tioga SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421773007289",
    },
    {
        "school": "Russell B Walter El Sch",
        "district": "Northern Tioga SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421773007291",
    },
    {
        "school": "Liberty El Sch",
        "district": "Southern Tioga SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422237004062",
    },
    {
        "school": "North Penn-Liberty JSHS",
        "district": "Southern Tioga SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422237004064",
    },
    {
        "school": "North Penn-Mansfield JSHS",
        "district": "Southern Tioga SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422237004068",
    },
    {
        "school": "Blossburg El Sch",
        "district": "Southern Tioga SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422237004070",
    },
    {
        "school": "Warren L Miller El Sch",
        "district": "Southern Tioga SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422237004839",
    },
    {
        "school": "Rock L Butler MS",
        "district": "Wellsboro Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422517004079",
    },
    {
        "school": "Wellsboro Area HS",
        "district": "Wellsboro Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422517004080",
    },
    {
        "school": "Don Gill El Sch",
        "district": "Wellsboro Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422517005095",
    },
    {
        "school": "Wallenpaupack Pri Sch",
        "district": "Wallenpaupack Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422475000129",
    },
    {
        "school": "Wallenpaupack South El Sch",
        "district": "Wallenpaupack Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422475004305",
    },
    {
        "school": "Wallenpaupack Area HS",
        "district": "Wallenpaupack Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422475004310",
    },
    {
        "school": "Wallenpaupack Area MS",
        "district": "Wallenpaupack Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422475006956",
    },
    {
        "school": "Wallenpaupack North Intrmd Sch",
        "district": "Wallenpaupack Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422475007248",
    },
    {
        "school": "Lakeside Elementary School",
        "district": "Wayne Highlands SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422497000226",
    },
    {
        "school": "Stourbridge Primary Ctr",
        "district": "Wayne Highlands SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422497004291",
    },
    {
        "school": "Honesdale HS",
        "district": "Wayne Highlands SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422497004295",
    },
    {
        "school": "Damascus Area Sch",
        "district": "Wayne Highlands SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422497006424",
    },
    {
        "school": "Preston Sch",
        "district": "Wayne Highlands SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422497006425",
    },
    {
        "school": "Wayne Highlands MS",
        "district": "Wayne Highlands SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422497006865",
    },
    {
        "school": "Wilson El Sch",
        "district": "Western Wayne SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422607004311",
    },
    {
        "school": "Western Wayne HS",
        "district": "Western Wayne SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422607006704",
    },
    {
        "school": "Western Wayne MS",
        "district": "Western Wayne SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422607009998",
    },
    {
        "school": "East Juniata JSHS",
        "district": "Juniata County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421260002394",
    },
    {
        "school": "Juniata SHS",
        "district": "Juniata County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421260006255",
    },
    {
        "school": "Tuscarora MS",
        "district": "Juniata County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421260007276",
    },
    {
        "school": "Penn-Kidder Campus",
        "district": "Jim Thorpe Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421254000776",
    },
    {
        "school": "Lehigh Valley Academy Regional CS",
        "district": "Lehigh Valley Academy Regional CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420009800635",
    },
    {
        "school": "Lehigh Valley Charter High School for th",
        "district": "Lehigh Valley Charter High School for the Arts",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420009900634",
    },
    {
        "school": "Jim Thorpe Area HS",
        "district": "Jim Thorpe Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421254001307",
    },
    {
        "school": "L B Morris El Sch",
        "district": "Jim Thorpe Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421254006965",
    },
    {
        "school": "Lehighton Area MS",
        "district": "Lehighton Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421350001314",
    },
    {
        "school": "Lehighton Area HS",
        "district": "Lehighton Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421350001315",
    },
    {
        "school": "Towamensing El Sch",
        "district": "Palmerton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421836001319",
    },
    {
        "school": "Palmerton Area HS",
        "district": "Palmerton Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421836004734",
    },
    {
        "school": "Palmerton Area JHS",
        "district": "Palmerton Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421836007174",
    },
    {
        "school": "S S Palmer El Sch",
        "district": "Palmerton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421836007222",
    },
    {
        "school": "Panther Valley El Sch",
        "district": "Panther Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421845001322",
    },
    {
        "school": "Weatherly Area SHS",
        "district": "Weatherly Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422514001327",
    },
    {
        "school": "Weatherly Area El Sch",
        "district": "Weatherly Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422514006446",
    },
    {
        "school": "Weatherly Area MS",
        "district": "Weatherly Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422514006838",
    },
    {
        "school": "Carbon Career & Technical Institute",
        "district": "Carbon Career & Technical Institute",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428013007054",
    },
    {
        "school": "Hiram W Dodd El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002768",
    },
    {
        "school": "Jefferson El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002774",
    },
    {
        "school": "Lehigh Parkway El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002775",
    },
    {
        "school": "McKinley El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002777",
    },
    {
        "school": "Mosser El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002779",
    },
    {
        "school": "Muhlenberg El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002780",
    },
    {
        "school": "Ritter El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002781",
    },
    {
        "school": "Roosevelt El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002782",
    },
    {
        "school": "Union Terrace El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002785",
    },
    {
        "school": "Washington El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002786",
    },
    {
        "school": "Central El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002790",
    },
    {
        "school": "Harrison-Morton MS",
        "district": "Allentown City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002791",
    },
    {
        "school": "Francis D Raub MS",
        "district": "Allentown City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002792",
    },
    {
        "school": "South Mountain MS",
        "district": "Allentown City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002793",
    },
    {
        "school": "William Allen HS",
        "district": "Allentown City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002794",
    },
    {
        "school": "Louis E Dieruff HS",
        "district": "Allentown City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228002795",
    },
    {
        "school": "Trexler MS",
        "district": "Allentown City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228004929",
    },
    {
        "school": "Sheridan El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228006448",
    },
    {
        "school": "Cleveland El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228007117",
    },
    {
        "school": "Calypso El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003436",
    },
    {
        "school": "James Buchanan El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003442",
    },
    {
        "school": "Clearview El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003453",
    },
    {
        "school": "Nitschmann MS",
        "district": "Bethlehem Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003463",
    },
    {
        "school": "Fountain Hill El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357006723",
    },
    {
        "school": "Catasauqua MS",
        "district": "Catasauqua Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420516002797",
    },
    {
        "school": "Catasauqua SHS",
        "district": "Catasauqua Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420516002798",
    },
    {
        "school": "Francis H Sheckler El Sch",
        "district": "Catasauqua Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420516006593",
    },
    {
        "school": "Lower Macungie MS",
        "district": "East Penn SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420855000376",
    },
    {
        "school": "Eyer MS",
        "district": "East Penn SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420855000377",
    },
    {
        "school": "Alburtis El Sch",
        "district": "East Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420855002799",
    },
    {
        "school": "Lincoln El Sch",
        "district": "East Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420855002802",
    },
    {
        "school": "Macungie El Sch",
        "district": "East Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420855002804",
    },
    {
        "school": "Jefferson El Sch",
        "district": "East Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420855002808",
    },
    {
        "school": "Emmaus HS",
        "district": "East Penn SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420855002809",
    },
    {
        "school": "Wescosville El Sch",
        "district": "East Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420855004827",
    },
    {
        "school": "Shoemaker El Sch",
        "district": "East Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420855005239",
    },
    {
        "school": "Peters El Sch",
        "district": "Northern Lehigh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421767002813",
    },
    {
        "school": "Northern Lehigh SHS",
        "district": "Northern Lehigh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421767002818",
    },
    {
        "school": "Slatington El Sch",
        "district": "Northern Lehigh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421767006727",
    },
    {
        "school": "Northern Lehigh MS",
        "district": "Northern Lehigh SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421767006829",
    },
    {
        "school": "Northwestern Lehigh MS",
        "district": "Northwestern Lehigh SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421785000035",
    },
    {
        "school": "Weisenberg El Sch",
        "district": "Northwestern Lehigh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421785002819",
    },
    {
        "school": "Northwestern Lehigh HS",
        "district": "Northwestern Lehigh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421785002821",
    },
    {
        "school": "Northwestern Lehigh El Sch",
        "district": "Northwestern Lehigh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421785006449",
    },
    {
        "school": "Springhouse MS",
        "district": "Parkland SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421851000476",
    },
    {
        "school": "Orefield MS",
        "district": "Parkland SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421851000478",
    },
    {
        "school": "Ironton Sch",
        "district": "Parkland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421851002823",
    },
    {
        "school": "Cetronia Sch",
        "district": "Parkland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421851002824",
    },
    {
        "school": "Schnecksville Sch",
        "district": "Parkland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421851002825",
    },
    {
        "school": "Parkway Manor Sch",
        "district": "Parkland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421851002826",
    },
    {
        "school": "Kratzer Sch",
        "district": "Parkland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421851002827",
    },
    {
        "school": "Parkland HS",
        "district": "Parkland SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421851002829",
    },
    {
        "school": "Fogelsville Sch",
        "district": "Parkland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421851004672",
    },
    {
        "school": "Kernsville Sch",
        "district": "Parkland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421851006801",
    },
    {
        "school": "Western Salisbury El Sch",
        "district": "Salisbury Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422073002832",
    },
    {
        "school": "Salisbury SHS",
        "district": "Salisbury Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422073002833",
    },
    {
        "school": "Salisbury MS",
        "district": "Salisbury Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422073005365",
    },
    {
        "school": "Harry S Truman El Sch",
        "district": "Salisbury Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422073006864",
    },
    {
        "school": "Liberty Bell El Sch",
        "district": "Southern Lehigh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422235002838",
    },
    {
        "school": "Southern Lehigh SHS",
        "district": "Southern Lehigh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422235002839",
    },
    {
        "school": "Southern Lehigh MS",
        "district": "Southern Lehigh SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422235004808",
    },
    {
        "school": "Hopewell El Sch",
        "district": "Southern Lehigh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422235005240",
    },
    {
        "school": "Whitehall HS",
        "district": "Whitehall-Coplay SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422625002848",
    },
    {
        "school": "Whitehall-Coplay MS",
        "district": "Whitehall-Coplay SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422625005241",
    },
    {
        "school": "George D Steckel El Sch",
        "district": "Whitehall-Coplay SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422625006841",
    },
    {
        "school": "Clarence M Gockley El Sch",
        "district": "Whitehall-Coplay SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422625006983",
    },
    {
        "school": "Lehigh Career & Technical Institute",
        "district": "Lehigh Career & Technical Institute",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428029007076",
    },
    {
        "school": "Washington El Sch",
        "district": "Bangor Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420300003430",
    },
    {
        "school": "Bangor Area HS",
        "district": "Bangor Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420300003434",
    },
    {
        "school": "Bangor Area MS",
        "district": "Bangor Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420300005257",
    },
    {
        "school": "Lincoln El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003443",
    },
    {
        "school": "Governor Wolf El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003449",
    },
    {
        "school": "Spring Garden El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003452",
    },
    {
        "school": "Marvine El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003454",
    },
    {
        "school": "Miller Heights El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003455",
    },
    {
        "school": "Farmersville El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003456",
    },
    {
        "school": "Freemansburg El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003458",
    },
    {
        "school": "Hanover El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003459",
    },
    {
        "school": "Northeast MS",
        "district": "Bethlehem Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003462",
    },
    {
        "school": "Broughal MS",
        "district": "Bethlehem Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003464",
    },
    {
        "school": "Liberty HS",
        "district": "Bethlehem Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357003465",
    },
    {
        "school": "East Hills MS",
        "district": "Bethlehem Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357004956",
    },
    {
        "school": "Freedom HS",
        "district": "Bethlehem Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357004957",
    },
    {
        "school": "Asa Packer El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357005063",
    },
    {
        "school": "Thomas Jefferson El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357006633",
    },
    {
        "school": "William Penn El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357006634",
    },
    {
        "school": "Donegan El Sch",
        "district": "Bethlehem Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420357006722",
    },
    {
        "school": "Palmer El Sch",
        "district": "Easton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420885003473",
    },
    {
        "school": "Forks El Sch",
        "district": "Easton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420885003477",
    },
    {
        "school": "March El Sch",
        "district": "Easton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420885003478",
    },
    {
        "school": "Easton Area HS",
        "district": "Easton Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420885003482",
    },
    {
        "school": "Cheston El Sch",
        "district": "Easton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420885004915",
    },
    {
        "school": "Tracy El Sch",
        "district": "Easton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420885005064",
    },
    {
        "school": "Paxinosa El Sch",
        "district": "Easton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420885005350",
    },
    {
        "school": "Saucon Valley El Sch",
        "district": "Saucon Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421173003485",
    },
    {
        "school": "Saucon Valley SHS",
        "district": "Saucon Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421173005352",
    },
    {
        "school": "Saucon Valley MS",
        "district": "Saucon Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421173007274",
    },
    {
        "school": "Kenneth N Butz Jr El Sch",
        "district": "Nazareth Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421638003488",
    },
    {
        "school": "Shafer El Sch",
        "district": "Nazareth Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421638003493",
    },
    {
        "school": "Nazareth Area MS",
        "district": "Nazareth Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421638003494",
    },
    {
        "school": "Nazareth Area HS",
        "district": "Nazareth Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421638003495",
    },
    {
        "school": "Lower Nazareth El Sch",
        "district": "Nazareth Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421638006717",
    },
    {
        "school": "Colonel John Siegfried El Sch",
        "district": "Northampton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421737000166",
    },
    {
        "school": "Lehigh El Sch",
        "district": "Northampton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421737003499",
    },
    {
        "school": "Moore El Sch",
        "district": "Northampton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421737003500",
    },
    {
        "school": "Northampton Area HS",
        "district": "Northampton Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421737003505",
    },
    {
        "school": "George Wolf El Sch",
        "district": "Northampton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421737005062",
    },
    {
        "school": "Northampton Area MS",
        "district": "Northampton Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421737005258",
    },
    {
        "school": "Plainfield El Sch",
        "district": "Pen Argyl Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421857003511",
    },
    {
        "school": "Wind Gap MS",
        "district": "Pen Argyl Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421857005351",
    },
    {
        "school": "Pen Argyl Area HS",
        "district": "Pen Argyl Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421857006439",
    },
    {
        "school": "Avona El Sch",
        "district": "Wilson Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422655003516",
    },
    {
        "school": "Williams Township El Sch",
        "district": "Wilson Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422655003520",
    },
    {
        "school": "Wilson Area HS",
        "district": "Wilson Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422655003522",
    },
    {
        "school": "Wilson Area Intermediate Sch",
        "district": "Wilson Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422655006785",
    },
    {
        "school": "Wilson Borough El Sch",
        "district": "Wilson Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422655007251",
    },
    {
        "school": "Bethlehem AVTS",
        "district": "Bethlehem AVTS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428037007083",
    },
    {
        "school": "Career Institute of Technology",
        "district": "Career Institute of Technology",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428038007084",
    },
    {
        "school": "Central PA Digital Lrng Foundation CS",
        "district": "Central PA Digital Learning Foundation CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420009500655",
    },
    {
        "school": "Central HS",
        "district": "Spring Cove SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422253000941",
    },
    {
        "school": "Kimmel Alternative School",
        "district": "Altoona Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420234000152",
    },
    {
        "school": "Baker El Sch",
        "district": "Altoona Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420234000891",
    },
    {
        "school": "Juniata El Sch",
        "district": "Altoona Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420234000895",
    },
    {
        "school": "Pleasant Valley El Sch",
        "district": "Altoona Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420234000902",
    },
    {
        "school": "Irving El Sch",
        "district": "Altoona Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420234000908",
    },
    {
        "school": "Altoona Area HS",
        "district": "Altoona Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420234000913",
    },
    {
        "school": "Juniata Gap El Sch",
        "district": "Altoona Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420234000930",
    },
    {
        "school": "Logan El Sch",
        "district": "Altoona Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420234000933",
    },
    {
        "school": "Mowrie A Ebner El Sch",
        "district": "Altoona Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420234007254",
    },
    {
        "school": "Lewis M Myers El Sch",
        "district": "Bellwood-Antis SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420330000914",
    },
    {
        "school": "Bellwood-Antis HS",
        "district": "Bellwood-Antis SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420330000917",
    },
    {
        "school": "Bellwood Antis MS",
        "district": "Bellwood-Antis SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420330007170",
    },
    {
        "school": "Claysburg-Kimmel El Sch",
        "district": "Claysburg-Kimmel SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420612000066",
    },
    {
        "school": "Claysburg-Kimmel HS",
        "district": "Claysburg-Kimmel SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420612000921",
    },
    {
        "school": "Foot of Ten El Sch",
        "district": "Hollidaysburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421194000088",
    },
    {
        "school": "Hollidaysburg Area JHS",
        "district": "Hollidaysburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421194000927",
    },
    {
        "school": "Hollidaysburg Area SHS",
        "district": "Hollidaysburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421194005207",
    },
    {
        "school": "Frankstown El Sch",
        "district": "Hollidaysburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421194006195",
    },
    {
        "school": "Charles W Longer El Sch",
        "district": "Hollidaysburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421194007121",
    },
    {
        "school": "Spring Cove MS",
        "district": "Spring Cove SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422253005130",
    },
    {
        "school": "Martinsburg El Sch",
        "district": "Spring Cove SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422253009984",
    },
    {
        "school": "Tyrone Area MS",
        "district": "Tyrone Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422403000277",
    },
    {
        "school": "Tyrone Area El Sch",
        "district": "Tyrone Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422403000443",
    },
    {
        "school": "Tyrone Area HS",
        "district": "Tyrone Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422403000949",
    },
    {
        "school": "Williamsburg Community El Sch",
        "district": "Williamsburg Community SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422643000950",
    },
    {
        "school": "Williamsburg Community JSHS",
        "district": "Williamsburg Community SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422643000951",
    },
    {
        "school": "Greater Altoona CTC",
        "district": "Greater Altoona CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428008007049",
    },
    {
        "school": "Danville Ctr Adolescent Female",
        "district": "Danville Ctr Adolescent Female",
        "level": "High",
        "type": "Alternative Education School",
        "state": "PA",
        "nces_id": "420004900462",
    },
    {
        "school": "Danville Area MS",
        "district": "Danville Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420732003424",
    },
    {
        "school": "Danville Area SHS",
        "district": "Danville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420732003425",
    },
    {
        "school": "Liberty-Valley El Sch",
        "district": "Danville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420732004833",
    },
    {
        "school": "North Central Secure Trmnt Unt",
        "district": "North Central Secure Trmnt Unt",
        "level": "High",
        "type": "Alternative Education School",
        "state": "PA",
        "nces_id": "420993307194",
    },
    {
        "school": "Appleman El Sch",
        "district": "Benton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420339001594",
    },
    {
        "school": "Berwick Area HS",
        "district": "Berwick Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420348001605",
    },
    {
        "school": "Nescopeck El Sch",
        "district": "Berwick Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420348006349",
    },
    {
        "school": "Berwick Area MS",
        "district": "Berwick Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420348006808",
    },
    {
        "school": "Memorial El Sch",
        "district": "Bloomsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420384001606",
    },
    {
        "school": "W W Evans Memorial El Sch",
        "district": "Bloomsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420384001608",
    },
    {
        "school": "Beaver-Main El Sch",
        "district": "Bloomsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420384001610",
    },
    {
        "school": "Bloomsburg Area MS",
        "district": "Bloomsburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420384001611",
    },
    {
        "school": "Bloomsburg Area HS",
        "district": "Bloomsburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420384001612",
    },
    {
        "school": "Central Columbia SHS",
        "district": "Central Columbia SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420537001619",
    },
    {
        "school": "Central Columbia MS",
        "district": "Central Columbia SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420537005390",
    },
    {
        "school": "Central Columbia El Sch",
        "district": "Central Columbia SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420537007260",
    },
    {
        "school": "Columbia-Montour AVTS",
        "district": "Columbia-Montour AVTS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "420636505178",
    },
    {
        "school": "Millville Area JSHS",
        "district": "Millville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421545001623",
    },
    {
        "school": "Millville Area El Sch",
        "district": "Millville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421545007007",
    },
    {
        "school": "Southern Columbia MS",
        "district": "Southern Columbia Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422226000558",
    },
    {
        "school": "Southern Columbia HS",
        "district": "Southern Columbia Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422226001627",
    },
    {
        "school": "Hartman El Ctr",
        "district": "Southern Columbia Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422226006900",
    },
    {
        "school": "Salem El Sch",
        "district": "Berwick Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420348001597",
    },
    {
        "school": "Floyd C Fretz MS",
        "district": "Bradford Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420402000281",
    },
    {
        "school": "School Street El Sch",
        "district": "Bradford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420402000349",
    },
    {
        "school": "Bradford Area HS",
        "district": "Bradford Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420402004691",
    },
    {
        "school": "George Blaisdell El Sch",
        "district": "Bradford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420402007037",
    },
    {
        "school": "Kane Area MS",
        "district": "Kane Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421266003100",
    },
    {
        "school": "Kane Area El Sch",
        "district": "Kane Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421266005244",
    },
    {
        "school": "Kane Area HS",
        "district": "Kane Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421266005245",
    },
    {
        "school": "Otto-Eldred El Sch",
        "district": "Otto-Eldred SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421824003106",
    },
    {
        "school": "Otto-Eldred JSHS",
        "district": "Otto-Eldred SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421824003107",
    },
    {
        "school": "Port Allegany JSHS",
        "district": "Port Allegany SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421953003111",
    },
    {
        "school": "Port Allegany El Sch",
        "district": "Port Allegany SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421953007235",
    },
    {
        "school": "Smethport Area El Sch",
        "district": "Smethport Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422169003116",
    },
    {
        "school": "Smethport Area JSHS",
        "district": "Smethport Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422169003117",
    },
    {
        "school": "Seneca Highlands Career and Technical Ce",
        "district": "Seneca Highlands Career and Technical Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428063007105",
    },
    {
        "school": "South Mountain Secure Trmnt Un",
        "district": "South Mountain Secure Trmnt Unit",
        "level": "High",
        "type": "Alternative Education School",
        "state": "PA",
        "nces_id": "420002500355",
    },
    {
        "school": "Chambersburg Area MS - North",
        "district": "Chambersburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555002190",
    },
    {
        "school": "Chambersburg Area SHS",
        "district": "Chambersburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555002191",
    },
    {
        "school": "Buchanan El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555002192",
    },
    {
        "school": "Stevens El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555002196",
    },
    {
        "school": "Grandview El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555002208",
    },
    {
        "school": "Scotland El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555002209",
    },
    {
        "school": "Guilford Hills El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555002215",
    },
    {
        "school": "South Hamilton El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555002216",
    },
    {
        "school": "Lurgan El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555002225",
    },
    {
        "school": "Falling Spring El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555004825",
    },
    {
        "school": "Fayetteville El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555006273",
    },
    {
        "school": "Hamilton Heights El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555006274",
    },
    {
        "school": "Chambersburg Area MS - South",
        "district": "Chambersburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555006615",
    },
    {
        "school": "Fannett-Metal MS",
        "district": "Fannett-Metal SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420966000283",
    },
    {
        "school": "Fannett-Metal SHS",
        "district": "Fannett-Metal SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420966002201",
    },
    {
        "school": "Fannett-Metal El Sch",
        "district": "Fannett-Metal SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420966006826",
    },
    {
        "school": "Greencastle-Antrim Pri Sch",
        "district": "Greencastle-Antrim SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421101000158",
    },
    {
        "school": "Greencastle-Antrim El Sch",
        "district": "Greencastle-Antrim SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421101002202",
    },
    {
        "school": "Greencastle-Antrim SHS",
        "district": "Greencastle-Antrim SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421101002206",
    },
    {
        "school": "Greencastle-Antrim MS",
        "district": "Greencastle-Antrim SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421101005117",
    },
    {
        "school": "Montgomery El Sch",
        "district": "Tuscarora SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422274002221",
    },
    {
        "school": "Mountain View El Sch",
        "district": "Tuscarora SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422274002222",
    },
    {
        "school": "St Thomas El Sch",
        "district": "Tuscarora SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422274002226",
    },
    {
        "school": "James Buchanan HS",
        "district": "Tuscarora SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422274006280",
    },
    {
        "school": "James Buchanan MS",
        "district": "Tuscarora SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422274006281",
    },
    {
        "school": "Mercersburg El Sch",
        "district": "Tuscarora SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422274006282",
    },
    {
        "school": "Fairview Avenue El Sch",
        "district": "Waynesboro Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422511002233",
    },
    {
        "school": "Hooverville El Sch",
        "district": "Waynesboro Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422511002234",
    },
    {
        "school": "Mowrey El Sch",
        "district": "Waynesboro Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422511002238",
    },
    {
        "school": "Waynesboro Area SHS",
        "district": "Waynesboro Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422511002243",
    },
    {
        "school": "Summitview El Sch",
        "district": "Waynesboro Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422511005330",
    },
    {
        "school": "Franklin County CTC",
        "district": "Franklin County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428023007067",
    },
    {
        "school": "Clearfield Area JSHS",
        "district": "Clearfield Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420615006236",
    },
    {
        "school": "Curwensville Area JSHS",
        "district": "Curwensville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420714001529",
    },
    {
        "school": "Curwensville Area El Sch",
        "district": "Curwensville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420714006238",
    },
    {
        "school": "Oklahoma El Sch",
        "district": "Dubois Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420783001532",
    },
    {
        "school": "Dubois Area MS",
        "district": "Dubois Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420783001541",
    },
    {
        "school": "Dubois Area SHS",
        "district": "Dubois Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420783006156",
    },
    {
        "school": "Juniata El Sch",
        "district": "Dubois Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420783006157",
    },
    {
        "school": "Wasson Avenue El Sch",
        "district": "Dubois Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420783006918",
    },
    {
        "school": "Harmony Area El Sch",
        "district": "Harmony Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421152007272",
    },
    {
        "school": "Moshannon Valley JSHS",
        "district": "Moshannon Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421596001550",
    },
    {
        "school": "Moshannon Valley El Sch",
        "district": "Moshannon Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421596006929",
    },
    {
        "school": "West Branch Area HS",
        "district": "West Branch Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422523001566",
    },
    {
        "school": "West Branch Area El Sch",
        "district": "West Branch Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422523006599",
    },
    {
        "school": "Clearfield County CTC",
        "district": "Clearfield County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428016007057",
    },
    {
        "school": "C G Johnson El Sch",
        "district": "Dubois Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420783002385",
    },
    {
        "school": "Philipsburg El Sch",
        "district": "Philipsburg-Osceola Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421902001555",
    },
    {
        "school": "Philipsburg-Osceola Area HS",
        "district": "Philipsburg-Osceola Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421902001560",
    },
    {
        "school": "Osceola Mills El Sch",
        "district": "Philipsburg-Osceola Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421902006239",
    },
    {
        "school": "Pocono Mountain West HS",
        "district": "Pocono Mountain SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421950000679",
    },
    {
        "school": "Swiftwater El Ctr",
        "district": "Pocono Mountain SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421950000680",
    },
    {
        "school": "Stroudsburg MS",
        "district": "Stroudsburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422286000884",
    },
    {
        "school": "Pleasant Valley El Sch",
        "district": "Pleasant Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421929000163",
    },
    {
        "school": "Pleasant Valley Intrmd Sch",
        "district": "Pleasant Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421929000546",
    },
    {
        "school": "Pleasant Valley HS",
        "district": "Pleasant Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421929003210",
    },
    {
        "school": "Pleasant Valley MS",
        "district": "Pleasant Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421929007297",
    },
    {
        "school": "Clear Run El Ctr",
        "district": "Pocono Mountain SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421950000299",
    },
    {
        "school": "Tobyhanna El Ctr",
        "district": "Pocono Mountain SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421950003214",
    },
    {
        "school": "Pocono Mountain East HS",
        "district": "Pocono Mountain SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421950003216",
    },
    {
        "school": "Stroudsburg JHS",
        "district": "Stroudsburg Area SD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422286000472",
    },
    {
        "school": "B F Morey El Sch",
        "district": "Stroudsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422286003221",
    },
    {
        "school": "Stroudsburg HS",
        "district": "Stroudsburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422286003224",
    },
    {
        "school": "Chipperfield El Sch",
        "district": "Stroudsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422286006683",
    },
    {
        "school": "Arlington Heights El Sch",
        "district": "Stroudsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422286007149",
    },
    {
        "school": "Monroe Career & Tech Inst",
        "district": "Monroe Career & Tech Inst",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428032007079",
    },
    {
        "school": "J T Lambert Intermediate Sch",
        "district": "East Stroudsburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420867000051",
    },
    {
        "school": "Resica El Sch",
        "district": "East Stroudsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420867000130",
    },
    {
        "school": "Middle Smithfield El Sch",
        "district": "East Stroudsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420867003201",
    },
    {
        "school": "Smithfield El Sch",
        "district": "East Stroudsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420867003202",
    },
    {
        "school": "J M Hill El Sch",
        "district": "East Stroudsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420867003204",
    },
    {
        "school": "East Stroudsburg El Sch",
        "district": "East Stroudsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420867006798",
    },
    {
        "school": "East Stroudsburg SHS South",
        "district": "East Stroudsburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420867006935",
    },
    {
        "school": "Bushkill El Sch",
        "district": "East Stroudsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420867000373",
    },
    {
        "school": "East Stroudsburg SHS North",
        "district": "East Stroudsburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420867000518",
    },
    {
        "school": "Lehman Intermediate Sch",
        "district": "East Stroudsburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420867000522",
    },
    {
        "school": "Perseus House CS of Excellence",
        "district": "Perseus House CS of Excellence",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420011500738",
    },
    {
        "school": "Montessori Regional CS",
        "district": "Montessori Regional CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420012400818",
    },
    {
        "school": "Corry Area MS",
        "district": "Corry Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420686000795",
    },
    {
        "school": "Robert Benjamin Wiley Community CS",
        "district": "Robert Benjamin Wiley Community CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420002000342",
    },
    {
        "school": "Corry Area Intrmd Sch",
        "district": "Corry Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420686001997",
    },
    {
        "school": "Corry Area HS",
        "district": "Corry Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420686001998",
    },
    {
        "school": "Northwest PA Collegiate Academy",
        "district": "Erie City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930000273",
    },
    {
        "school": "Grover Cleveland El Sch",
        "district": "Erie City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930002001",
    },
    {
        "school": "Diehl Sch",
        "district": "Erie City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930002003",
    },
    {
        "school": "Edison El Sch",
        "district": "Erie City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930002004",
    },
    {
        "school": "Harding Sch",
        "district": "Erie City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930002009",
    },
    {
        "school": "Jefferson El Sch",
        "district": "Erie City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930002011",
    },
    {
        "school": "Lincoln El Sch",
        "district": "Erie City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930002013",
    },
    {
        "school": "Perry El Sch",
        "district": "Erie City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930002018",
    },
    {
        "school": "JoAnna Connell Sch",
        "district": "Erie City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930002021",
    },
    {
        "school": "Woodrow Wilson MS",
        "district": "Erie City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930002025",
    },
    {
        "school": "Pfeiffer-Burleigh Sch",
        "district": "Erie City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930007035",
    },
    {
        "school": "McKinley El Sch",
        "district": "Erie City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930007142",
    },
    {
        "school": "Fairview El Sch",
        "district": "Fairview SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420957000206",
    },
    {
        "school": "Fairview MS",
        "district": "Fairview SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420957002032",
    },
    {
        "school": "Fairview HS",
        "district": "Fairview SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420957006737",
    },
    {
        "school": "Waterford El Sch",
        "district": "Fort LeBoeuf SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420999002035",
    },
    {
        "school": "Robison El Sch",
        "district": "Fort LeBoeuf SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420999002036",
    },
    {
        "school": "Fort LeBoeuf SHS",
        "district": "Fort LeBoeuf SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420999002037",
    },
    {
        "school": "Mill Village El Sch",
        "district": "Fort LeBoeuf SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420999005226",
    },
    {
        "school": "Fort LeBoeuf MS",
        "district": "Fort LeBoeuf SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420999005328",
    },
    {
        "school": "Edinboro El Sch",
        "district": "General McLane SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421065002038",
    },
    {
        "school": "McKean El Sch",
        "district": "General McLane SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421065002039",
    },
    {
        "school": "General McLane HS",
        "district": "General McLane SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421065002040",
    },
    {
        "school": "James W Parker MS",
        "district": "General McLane SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421065005225",
    },
    {
        "school": "Elk Valley El Sch",
        "district": "Girard SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421074002042",
    },
    {
        "school": "Girard HS",
        "district": "Girard SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421074002043",
    },
    {
        "school": "Rice Avenue MS",
        "district": "Girard SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421074006777",
    },
    {
        "school": "Klein El Sch",
        "district": "Harbor Creek SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421149002046",
    },
    {
        "school": "Clark El Sch",
        "district": "Harbor Creek SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421149002047",
    },
    {
        "school": "Harbor Creek Junior HS",
        "district": "Harbor Creek SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421149002048",
    },
    {
        "school": "Rolling Ridge El Sch",
        "district": "Harbor Creek SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421149005227",
    },
    {
        "school": "Iroquois El Sch",
        "district": "Iroquois SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421221002052",
    },
    {
        "school": "Iroquois JSHS",
        "district": "Iroquois SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421221004817",
    },
    {
        "school": "Walnut Creek MS",
        "district": "Millcreek Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421533000085",
    },
    {
        "school": "Asbury El Sch",
        "district": "Millcreek Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421533002053",
    },
    {
        "school": "Belle Valley El Sch",
        "district": "Millcreek Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421533002054",
    },
    {
        "school": "Tracy El Sch",
        "district": "Millcreek Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421533002059",
    },
    {
        "school": "Westlake MS",
        "district": "Millcreek Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421533002062",
    },
    {
        "school": "Chestnut Hill El Sch",
        "district": "Millcreek Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421533004724",
    },
    {
        "school": "James S Wilson MS",
        "district": "Millcreek Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421533004954",
    },
    {
        "school": "Grandview El Sch",
        "district": "Millcreek Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421533005329",
    },
    {
        "school": "North East MS",
        "district": "North East SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421716000043",
    },
    {
        "school": "Earle C Davis Primary",
        "district": "North East SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421716004946",
    },
    {
        "school": "North East Intrmd El",
        "district": "North East SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421716006144",
    },
    {
        "school": "North East HS",
        "district": "North East SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421716006145",
    },
    {
        "school": "Springfield El Sch",
        "district": "Northwestern SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421788002070",
    },
    {
        "school": "Northwestern El Sch",
        "district": "Northwestern SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421788005144",
    },
    {
        "school": "Northwestern MS",
        "district": "Northwestern SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421788006146",
    },
    {
        "school": "Northwestern SHS",
        "district": "Northwestern SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421788006745",
    },
    {
        "school": "Union City HS",
        "district": "Union City Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422409002075",
    },
    {
        "school": "Union City El Sch",
        "district": "Union City Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422409006795",
    },
    {
        "school": "Union City MS",
        "district": "Union City Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422409009966",
    },
    {
        "school": "Wattsburg Area El Ctr",
        "district": "Wattsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422508000274",
    },
    {
        "school": "Seneca HS",
        "district": "Wattsburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422508006148",
    },
    {
        "school": "Wattsburg Area MS",
        "district": "Wattsburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422508006654",
    },
    {
        "school": "Erie County Technical School",
        "district": "Erie County Technical School",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428021007064",
    },
    {
        "school": "Conewago Valley Intrmd Sch",
        "district": "Conewago Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420655000841",
    },
    {
        "school": "Bermudian Springs HS",
        "district": "Bermudian Springs SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420345000003",
    },
    {
        "school": "Bermudian Springs MS",
        "district": "Bermudian Springs SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420345006921",
    },
    {
        "school": "Bermudian Springs El Sch",
        "district": "Bermudian Springs SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420345009986",
    },
    {
        "school": "New Oxford SHS",
        "district": "Conewago Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420655000017",
    },
    {
        "school": "New Oxford El Sch",
        "district": "Conewago Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420655006267",
    },
    {
        "school": "Conewago Twp El Sch",
        "district": "Conewago Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420655006268",
    },
    {
        "school": "New Oxford MS",
        "district": "Conewago Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420655006898",
    },
    {
        "school": "Fairfield Area HS",
        "district": "Fairfield Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420954006269",
    },
    {
        "school": "Fairfield Area El Sch",
        "district": "Fairfield Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420954006270",
    },
    {
        "school": "Fairfield Area MS",
        "district": "Fairfield Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420954009987",
    },
    {
        "school": "Gettysburg Area MS",
        "district": "Gettysburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421071000010",
    },
    {
        "school": "Lincoln El Sch",
        "district": "Gettysburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421071000452",
    },
    {
        "school": "James Gettys El Sch",
        "district": "Gettysburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421071005126",
    },
    {
        "school": "Gettysburg Area HS",
        "district": "Gettysburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421071006271",
    },
    {
        "school": "Maple Avenue MS",
        "district": "Littlestown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421398000013",
    },
    {
        "school": "Littlestown SHS",
        "district": "Littlestown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421398000014",
    },
    {
        "school": "Arendtsville El Sch",
        "district": "Upper Adams SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422430000018",
    },
    {
        "school": "Bendersville El Sch",
        "district": "Upper Adams SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422430000019",
    },
    {
        "school": "Biglerville HS",
        "district": "Upper Adams SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422430000021",
    },
    {
        "school": "Upper Adams MS",
        "district": "Upper Adams SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422430000155",
    },
    {
        "school": "Commonwealth Charter Academy CS",
        "district": "Commonwealth Charter Academy CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420011900756",
    },
    {
        "school": "Elmwood Academy",
        "district": "Mechanicsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421503000862",
    },
    {
        "school": "Infinity CS",
        "district": "Infinity CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420011800724",
    },
    {
        "school": "Pennsylvania Distance Learning CS",
        "district": "Pennsylvania Distance Learning CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420012500839",
    },
    {
        "school": "Central Dauphin MS",
        "district": "Central Dauphin SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540000838",
    },
    {
        "school": "Hershey Early Childhood Ctr",
        "district": "Derry Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420759000667",
    },
    {
        "school": "Price",
        "district": "Lower Dauphin SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421410000881",
    },
    {
        "school": "Robert Reid El Sch",
        "district": "Middletown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421524000703",
    },
    {
        "school": "Rowland Academy",
        "district": "Harrisburg City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158000456",
    },
    {
        "school": "Oak Flat El Sch",
        "district": "Big Spring SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420366000038",
    },
    {
        "school": "Newville El Sch",
        "district": "Big Spring SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420366001676",
    },
    {
        "school": "Big Spring HS",
        "district": "Big Spring SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420366001677",
    },
    {
        "school": "Big Spring MS",
        "district": "Big Spring SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420366006326",
    },
    {
        "school": "Camp Hill MS",
        "district": "Camp Hill SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420486000289",
    },
    {
        "school": "Eisenhower El Sch",
        "district": "Camp Hill SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420486001678",
    },
    {
        "school": "Hoover El Sch",
        "district": "Camp Hill SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420486001680",
    },
    {
        "school": "Camp Hill SHS",
        "district": "Camp Hill SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420486001682",
    },
    {
        "school": "Letort El Sch",
        "district": "Carlisle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420501001683",
    },
    {
        "school": "Mt Holly Springs El Sch",
        "district": "Carlisle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420501001686",
    },
    {
        "school": "North Dickinson El Sch",
        "district": "Carlisle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420501001687",
    },
    {
        "school": "Crestview El Sch",
        "district": "Carlisle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420501001689",
    },
    {
        "school": "Mooreland El Sch",
        "district": "Carlisle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420501001690",
    },
    {
        "school": "Hamilton El Sch",
        "district": "Carlisle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420501001691",
    },
    {
        "school": "Bellaire El Sch",
        "district": "Carlisle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420501001692",
    },
    {
        "school": "Carlisle Area HS",
        "district": "Carlisle Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420501001694",
    },
    {
        "school": "Wilson MS",
        "district": "Carlisle Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420501007010",
    },
    {
        "school": "Lamberton MS",
        "district": "Carlisle Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420501007011",
    },
    {
        "school": "Sporting Hill El Sch",
        "district": "Cumberland Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420711001695",
    },
    {
        "school": "Shaull El Sch",
        "district": "Cumberland Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420711001696",
    },
    {
        "school": "Middlesex El Sch",
        "district": "Cumberland Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420711001697",
    },
    {
        "school": "Monroe El Sch",
        "district": "Cumberland Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420711001698",
    },
    {
        "school": "Silver Spring El Sch",
        "district": "Cumberland Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420711001699",
    },
    {
        "school": "Green Ridge El Sch",
        "district": "Cumberland Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420711001700",
    },
    {
        "school": "Cumberland Valley HS",
        "district": "Cumberland Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420711001701",
    },
    {
        "school": "Mountain View MS",
        "district": "Cumberland Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420711004849",
    },
    {
        "school": "Hampden El Sch",
        "district": "Cumberland Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420711005020",
    },
    {
        "school": "Eagle View MS",
        "district": "Cumberland Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420711006714",
    },
    {
        "school": "East Pennsboro El Sch",
        "district": "East Pennsboro Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420858001705",
    },
    {
        "school": "East Pennsboro Area SHS",
        "district": "East Pennsboro Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420858001707",
    },
    {
        "school": "West Creek Hills El Sch",
        "district": "East Pennsboro Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420858004850",
    },
    {
        "school": "East Pennsboro Area MS",
        "district": "East Pennsboro Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420858005220",
    },
    {
        "school": "Broad Street El Sch",
        "district": "Mechanicsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421503001709",
    },
    {
        "school": "Shepherdstown El Sch",
        "district": "Mechanicsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421503001711",
    },
    {
        "school": "Mechanicsburg MS",
        "district": "Mechanicsburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421503001715",
    },
    {
        "school": "Upper Allen El Sch",
        "district": "Mechanicsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421503004851",
    },
    {
        "school": "Northside El Sch",
        "district": "Mechanicsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421503005021",
    },
    {
        "school": "Mechanicsburg Area SHS",
        "district": "Mechanicsburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421503005098",
    },
    {
        "school": "Grace B Luhrs Univ Elem",
        "district": "Shippensburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422157001724",
    },
    {
        "school": "Shippensburg Area SHS",
        "district": "Shippensburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422157005221",
    },
    {
        "school": "Yellow Breeches MS",
        "district": "South Middleton SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422205000455",
    },
    {
        "school": "W.G. Rice El Sch",
        "district": "South Middleton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422205001730",
    },
    {
        "school": "Boiling Springs HS",
        "district": "South Middleton SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422205006328",
    },
    {
        "school": "Cumberland Perry AVTS",
        "district": "Cumberland Perry AVTS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428018007059",
    },
    {
        "school": "Sylvan Heights Science CS",
        "district": "Sylvan Heights Science CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420002700366",
    },
    {
        "school": "Swatara MS",
        "district": "Central Dauphin SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001742",
    },
    {
        "school": "Central Dauphin East MS",
        "district": "Central Dauphin SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001744",
    },
    {
        "school": "Central Dauphin SHS",
        "district": "Central Dauphin SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001745",
    },
    {
        "school": "Central Dauphin East SHS",
        "district": "Central Dauphin SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001746",
    },
    {
        "school": "Linglestown El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001777",
    },
    {
        "school": "Paxtonia El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001778",
    },
    {
        "school": "Phillips El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001779",
    },
    {
        "school": "South Side El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001780",
    },
    {
        "school": "North Side El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001781",
    },
    {
        "school": "Middle Paxton El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001791",
    },
    {
        "school": "Paxtang El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001795",
    },
    {
        "school": "Rutherford El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001811",
    },
    {
        "school": "Chambers Hill El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001812",
    },
    {
        "school": "West Hanover El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540001817",
    },
    {
        "school": "Tri-Community El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540005320",
    },
    {
        "school": "Linglestown MS",
        "district": "Central Dauphin SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540006783",
    },
    {
        "school": "Mountain View El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540007261",
    },
    {
        "school": "Lawnton El Sch",
        "district": "Central Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420540009939",
    },
    {
        "school": "Dauphin County Technical School",
        "district": "Dauphin County Technical School",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "420738505278",
    },
    {
        "school": "Hershey Primary El Sch",
        "district": "Derry Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420759001749",
    },
    {
        "school": "Hershey HS",
        "district": "Derry Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420759004801",
    },
    {
        "school": "Hershey MS",
        "district": "Derry Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420759006678",
    },
    {
        "school": "Hershey Intrmd El Sch",
        "district": "Derry Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420759007266",
    },
    {
        "school": "Halifax Area El Sch",
        "district": "Halifax Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421131005038",
    },
    {
        "school": "Halifax Area HS",
        "district": "Halifax Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421131006330",
    },
    {
        "school": "Halifax Area MS",
        "district": "Halifax Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421131006331",
    },
    {
        "school": "Scott Sch",
        "district": "Harrisburg City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158000557",
    },
    {
        "school": "Foose Sch",
        "district": "Harrisburg City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158001766",
    },
    {
        "school": "Harrisburg HS",
        "district": "Harrisburg City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158006333",
    },
    {
        "school": "Lower Dauphin MS",
        "district": "Lower Dauphin SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421410000122",
    },
    {
        "school": "Conewago El Sch",
        "district": "Lower Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421410001747",
    },
    {
        "school": "East Hanover El Sch",
        "district": "Lower Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421410001752",
    },
    {
        "school": "Nye El Sch",
        "district": "Lower Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421410001774",
    },
    {
        "school": "Londonderry El Sch",
        "district": "Lower Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421410001775",
    },
    {
        "school": "Lower Dauphin HS",
        "district": "Lower Dauphin SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421410001776",
    },
    {
        "school": "South Hanover El Sch",
        "district": "Lower Dauphin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421410001797",
    },
    {
        "school": "Middletown Area MS",
        "district": "Middletown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421524001785",
    },
    {
        "school": "Kunkel El Sch",
        "district": "Middletown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421524001788",
    },
    {
        "school": "Middletown Area HS",
        "district": "Middletown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421524001790",
    },
    {
        "school": "Lenkerville El Sch",
        "district": "Millersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421536001793",
    },
    {
        "school": "Millersburg Area SHS",
        "district": "Millersburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421536001794",
    },
    {
        "school": "Millersburg Area MS",
        "district": "Millersburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421536006682",
    },
    {
        "school": "Steelton-Highspire El Sch",
        "district": "Steelton-Highspire SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422280001799",
    },
    {
        "school": "Steelton-Highspire HS",
        "district": "Steelton-Highspire SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422280001801",
    },
    {
        "school": "Thomas W Holtzman Jr El Sch",
        "district": "Susquehanna Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422301001802",
    },
    {
        "school": "Susquehanna Twp MS",
        "district": "Susquehanna Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422301001805",
    },
    {
        "school": "Susquehanna Twp HS",
        "district": "Susquehanna Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422301001806",
    },
    {
        "school": "Sara Lindemuth El Sch",
        "district": "Susquehanna Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422301004945",
    },
    {
        "school": "Upper Dauphin Area MS",
        "district": "Upper Dauphin Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422436006339",
    },
    {
        "school": "Upper Dauphin Area HS",
        "district": "Upper Dauphin Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422436006340",
    },
    {
        "school": "Upper Dauphin Area El Sch",
        "district": "Upper Dauphin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422436009967",
    },
    {
        "school": "Shippensburg Area MS",
        "district": "Shippensburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422157001729",
    },
    {
        "school": "Loysville Youth Dev Ctr",
        "district": "Loysville Youth Dev Ctr",
        "level": "High",
        "type": "Alternative Education School",
        "state": "PA",
        "nces_id": "420993207193",
    },
    {
        "school": "Greenwood MS",
        "district": "Greenwood SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421119000220",
    },
    {
        "school": "Greenwood HS",
        "district": "Greenwood SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421119006341",
    },
    {
        "school": "Greenwood El Sch",
        "district": "Greenwood SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421119007001",
    },
    {
        "school": "Newport El Sch",
        "district": "Newport SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421689005260",
    },
    {
        "school": "Susquenita MS",
        "district": "Susquenita SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422304000052",
    },
    {
        "school": "Susquenita HS",
        "district": "Susquenita SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422304003589",
    },
    {
        "school": "Susquenita El Sch",
        "district": "Susquenita SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422304006608",
    },
    {
        "school": "Carroll El Sch",
        "district": "West Perry SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422574003594",
    },
    {
        "school": "West Perry SHS",
        "district": "West Perry SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422574003596",
    },
    {
        "school": "West Perry MS",
        "district": "West Perry SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422574003597",
    },
    {
        "school": "New Bloomfield El Sch",
        "district": "West Perry SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422574004920",
    },
    {
        "school": "Blain El Sch",
        "district": "West Perry SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422574006344",
    },
    {
        "school": "Mount Union-Kistler El Sch",
        "district": "Mount Union Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421602000670",
    },
    {
        "school": "Youth Forestry Camp #3",
        "district": "Youth Forestry Camp #3",
        "level": "High",
        "type": "Alternative Education School",
        "state": "PA",
        "nces_id": "420993107192",
    },
    {
        "school": "Southside El Sch",
        "district": "Huntingdon Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421209000354",
    },
    {
        "school": "Standing Stone El Sch",
        "district": "Huntingdon Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421209000451",
    },
    {
        "school": "Huntingdon Area SHS",
        "district": "Huntingdon Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421209002305",
    },
    {
        "school": "Huntingdon Area MS",
        "district": "Huntingdon Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421209005333",
    },
    {
        "school": "Juniata Valley JSHS",
        "district": "Juniata Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421263002308",
    },
    {
        "school": "Juniata Valley El Sch",
        "district": "Juniata Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421263005230",
    },
    {
        "school": "Shirley Twp El Sch",
        "district": "Mount Union Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421602002291",
    },
    {
        "school": "Mapleton-Union El Sch",
        "district": "Mount Union Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421602002295",
    },
    {
        "school": "Mount Union Area JHS",
        "district": "Mount Union Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421602002297",
    },
    {
        "school": "Rockhill El Sch",
        "district": "Southern Huntingdon County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422232002309",
    },
    {
        "school": "Shade Gap El Sch",
        "district": "Southern Huntingdon County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422232002310",
    },
    {
        "school": "Spring Farms El Sch",
        "district": "Southern Huntingdon County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422232002312",
    },
    {
        "school": "Southern Huntingdon Co HS/MS",
        "district": "Southern Huntingdon County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422232002313",
    },
    {
        "school": "Huntingdon County CTC",
        "district": "Huntingdon County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428025007069",
    },
    {
        "school": "Blairsville El Sch",
        "district": "Blairsville-Saltsburg SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420375000135",
    },
    {
        "school": "Blairsville MS",
        "district": "Blairsville-Saltsburg SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420375002317",
    },
    {
        "school": "Saltsburg El Sch",
        "district": "Blairsville-Saltsburg SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420375002352",
    },
    {
        "school": "Saltsburg MS/HS",
        "district": "Blairsville-Saltsburg SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420375002353",
    },
    {
        "school": "Blairsville SHS",
        "district": "Blairsville-Saltsburg SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420375004706",
    },
    {
        "school": "Ben Franklin El Sch",
        "district": "Indiana Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421215002314",
    },
    {
        "school": "Eisenhower El Sch",
        "district": "Indiana Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421215002321",
    },
    {
        "school": "Horace Mann El Sch",
        "district": "Indiana Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421215002322",
    },
    {
        "school": "Indiana Area JHS",
        "district": "Indiana Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421215002324",
    },
    {
        "school": "Indiana Area SHS",
        "district": "Indiana Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421215002325",
    },
    {
        "school": "East Pike El Sch",
        "district": "Indiana Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421215004964",
    },
    {
        "school": "Homer-Center JSHS",
        "district": "Homer-Center SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421329002331",
    },
    {
        "school": "Homer-Center El Sch",
        "district": "Homer-Center SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421329006797",
    },
    {
        "school": "Marion Center Area JR/SR HS",
        "district": "Marion Center Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421473002339",
    },
    {
        "school": "Penns Manor Area JSHS",
        "district": "Penns Manor Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421878002345",
    },
    {
        "school": "Penns Manor Area El Sch",
        "district": "Penns Manor Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421878007028",
    },
    {
        "school": "Purchase Line JSHS",
        "district": "Purchase Line SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421983002350",
    },
    {
        "school": "Purchase Line El Sch",
        "district": "Purchase Line SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421983006893",
    },
    {
        "school": "United JSHS",
        "district": "United SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422424002358",
    },
    {
        "school": "United El Sch",
        "district": "United SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422424006680",
    },
    {
        "school": "Indiana County Technology Center",
        "district": "Indiana County Technology Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428066007107",
    },
    {
        "school": "Blacklick Valley JSHS",
        "district": "Blacklick Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420369005135",
    },
    {
        "school": "Blacklick Valley El Ctr",
        "district": "Blacklick Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420369006828",
    },
    {
        "school": "Cambria Heights El Sch",
        "district": "Cambria Heights SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420474000025",
    },
    {
        "school": "Cambria Heights MS",
        "district": "Cambria Heights SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420474001199",
    },
    {
        "school": "Cambria Heights SHS",
        "district": "Cambria Heights SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420474005212",
    },
    {
        "school": "Central Cambria MS",
        "district": "Central Cambria SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420534001202",
    },
    {
        "school": "Jackson El Sch",
        "district": "Central Cambria SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420534001205",
    },
    {
        "school": "Central Cambria HS",
        "district": "Central Cambria SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420534001208",
    },
    {
        "school": "Cambria El Sch",
        "district": "Central Cambria SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420534006646",
    },
    {
        "school": "Conemaugh Valley JSHS",
        "district": "Conemaugh Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420643005136",
    },
    {
        "school": "Conemaugh Valley El Sch",
        "district": "Conemaugh Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420643005213",
    },
    {
        "school": "Ferndale El Sch",
        "district": "Ferndale Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420975001223",
    },
    {
        "school": "Ferndale Area JSHS",
        "district": "Ferndale Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420975001225",
    },
    {
        "school": "Forest Hills El Sch",
        "district": "Forest Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420994006899",
    },
    {
        "school": "Glendale JSHS",
        "district": "Glendale SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421083005219",
    },
    {
        "school": "Glendale El Sch",
        "district": "Glendale SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421083006952",
    },
    {
        "school": "Greater Johnstown SHS",
        "district": "Greater Johnstown SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421095001251",
    },
    {
        "school": "Greater Johnstown MS",
        "district": "Greater Johnstown SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421095001252",
    },
    {
        "school": "Greater Johnstown CTC",
        "district": "Greater Johnstown CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "421097005288",
    },
    {
        "school": "Penn Cambria HS",
        "district": "Penn Cambria SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421377001213",
    },
    {
        "school": "Penn Cambria Primary Sch",
        "district": "Penn Cambria SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421377001255",
    },
    {
        "school": "Penn Cambria Pre-Primary",
        "district": "Penn Cambria SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421377006202",
    },
    {
        "school": "Penn Cambria MS",
        "district": "Penn Cambria SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421377006990",
    },
    {
        "school": "Penn Cambria Intrmd Sch",
        "district": "Penn Cambria SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421377007172",
    },
    {
        "school": "Northern Cambria HS",
        "district": "Northern Cambria SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421761006201",
    },
    {
        "school": "Northern Cambria El Sch",
        "district": "Northern Cambria SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421761006859",
    },
    {
        "school": "Northern Cambria MS",
        "district": "Northern Cambria SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421761006860",
    },
    {
        "school": "Portage Area JSHS",
        "district": "Portage Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421956001270",
    },
    {
        "school": "Richland El Sch",
        "district": "Richland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422025001278",
    },
    {
        "school": "Westmont Hilltop El Sch",
        "district": "Westmont Hilltop SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422613001290",
    },
    {
        "school": "Admiral Peary AVTS",
        "district": "Admiral Peary AVTS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428012007053",
    },
    {
        "school": "Phoenix Academy",
        "district": "Lancaster SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314003410",
    },
    {
        "school": "Donegal Primary School",
        "district": "Donegal SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420765000778",
    },
    {
        "school": "Schaeffer Sch",
        "district": "Manheim Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421458000624",
    },
    {
        "school": "La Academia Partnership Charter School",
        "district": "La Academia Partnership Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420002600359",
    },
    {
        "school": "Denver El Sch",
        "district": "Cocalico SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420627002506",
    },
    {
        "school": "Adamstown El Sch",
        "district": "Cocalico SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420627002510",
    },
    {
        "school": "Reamstown El Sch",
        "district": "Cocalico SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420627005053",
    },
    {
        "school": "Cocalico MS",
        "district": "Cocalico SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420627006289",
    },
    {
        "school": "Cocalico SHS",
        "district": "Cocalico SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420627006290",
    },
    {
        "school": "Columbia HS",
        "district": "Columbia Borough SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420636002515",
    },
    {
        "school": "Park El Sch",
        "district": "Columbia Borough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420636006998",
    },
    {
        "school": "Brownstown El Sch",
        "district": "Conestoga Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420648002517",
    },
    {
        "school": "Smoketown El Sch",
        "district": "Conestoga Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420648002521",
    },
    {
        "school": "Leola El Sch",
        "district": "Conestoga Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420648002522",
    },
    {
        "school": "Gerald G Huesken MS",
        "district": "Conestoga Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420648002531",
    },
    {
        "school": "Conestoga Valley SHS",
        "district": "Conestoga Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420648002532",
    },
    {
        "school": "Fritz El Sch",
        "district": "Conestoga Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420648005113",
    },
    {
        "school": "Donegal HS",
        "district": "Donegal SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420765002539",
    },
    {
        "school": "Donegal JHS",
        "district": "Donegal SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420765007201",
    },
    {
        "school": "Brecknock El Sch",
        "district": "Eastern Lancaster County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420882002500",
    },
    {
        "school": "Blue Ball El Sch",
        "district": "Eastern Lancaster County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420882002552",
    },
    {
        "school": "Garden Spot SHS",
        "district": "Eastern Lancaster County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420882002554",
    },
    {
        "school": "New Holland Elementary",
        "district": "Eastern Lancaster County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420882004707",
    },
    {
        "school": "Garden Spot MS",
        "district": "Eastern Lancaster County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420882007267",
    },
    {
        "school": "Bainbridge El Sch",
        "district": "Elizabethtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420912002555",
    },
    {
        "school": "Mill Road El Sch",
        "district": "Elizabethtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420912002558",
    },
    {
        "school": "Rheems El Sch",
        "district": "Elizabethtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420912002559",
    },
    {
        "school": "East High Street El Sch",
        "district": "Elizabethtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420912002561",
    },
    {
        "school": "Elizabethtown Area SHS",
        "district": "Elizabethtown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420912002562",
    },
    {
        "school": "Elizabethtown Area MS",
        "district": "Elizabethtown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420912006862",
    },
    {
        "school": "Akron El Sch",
        "district": "Ephrata Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420927002564",
    },
    {
        "school": "Clay El Sch",
        "district": "Ephrata Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420927002568",
    },
    {
        "school": "Highland El Sch",
        "district": "Ephrata Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420927002570",
    },
    {
        "school": "Ephrata SHS",
        "district": "Ephrata Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420927006293",
    },
    {
        "school": "Ephrata MS",
        "district": "Ephrata Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420927006712",
    },
    {
        "school": "Fulton El Sch",
        "district": "Ephrata Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420927007268",
    },
    {
        "school": "Landisville MS",
        "district": "Hempfield SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421179000118",
    },
    {
        "school": "Landisville Pri Ctr",
        "district": "Hempfield SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421179000160",
    },
    {
        "school": "East Petersburg El Sch",
        "district": "Hempfield SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421179002574",
    },
    {
        "school": "Rohrerstown El Sch",
        "district": "Hempfield SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421179002575",
    },
    {
        "school": "Mountville El Sch",
        "district": "Hempfield SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421179002576",
    },
    {
        "school": "Farmdale El Sch",
        "district": "Hempfield SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421179002577",
    },
    {
        "school": "Hempfield SHS",
        "district": "Hempfield SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421179002578",
    },
    {
        "school": "Centerville MS",
        "district": "Hempfield SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421179005055",
    },
    {
        "school": "Centerville El Sch",
        "district": "Hempfield SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421179005236",
    },
    {
        "school": "Landisville Intrmd Ctr",
        "district": "Hempfield SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421179006294",
    },
    {
        "school": "Hans Herr El Sch",
        "district": "Lampeter-Strasburg SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421311002606",
    },
    {
        "school": "Lampeter-Strasburg SHS",
        "district": "Lampeter-Strasburg SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421311002607",
    },
    {
        "school": "Martin Meylin MS",
        "district": "Lampeter-Strasburg SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421311006297",
    },
    {
        "school": "Fulton El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002581",
    },
    {
        "school": "Lafayette El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002584",
    },
    {
        "school": "Ross El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002587",
    },
    {
        "school": "George Washington El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002589",
    },
    {
        "school": "Thomas Wharton El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002590",
    },
    {
        "school": "Wickersham El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002591",
    },
    {
        "school": "Hamilton El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002592",
    },
    {
        "school": "Hand MS",
        "district": "Lancaster SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002593",
    },
    {
        "school": "Reynolds MS",
        "district": "Lancaster SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002594",
    },
    {
        "school": "Lincoln MS",
        "district": "Lancaster SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002595",
    },
    {
        "school": "McCaskey Campus",
        "district": "Lancaster SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002596",
    },
    {
        "school": "James Buchanan El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002597",
    },
    {
        "school": "Burrowes Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002598",
    },
    {
        "school": "Elizabeth R Martin El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002599",
    },
    {
        "school": "Wheatland MS",
        "district": "Lancaster SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314002600",
    },
    {
        "school": "King El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314005056",
    },
    {
        "school": "Price El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314006762",
    },
    {
        "school": "Carter and MacRae El Sch",
        "district": "Lancaster SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421314007281",
    },
    {
        "school": "Manheim Central SHS",
        "district": "Manheim Central SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421455002618",
    },
    {
        "school": "Reidenbaugh El Sch",
        "district": "Manheim Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421458000097",
    },
    {
        "school": "Neff Sch",
        "district": "Manheim Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421458000214",
    },
    {
        "school": "Brecht Sch",
        "district": "Manheim Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421458000505",
    },
    {
        "school": "Manheim Twp HS",
        "district": "Manheim Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421458002623",
    },
    {
        "school": "Nitrauer Sch",
        "district": "Manheim Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421458004708",
    },
    {
        "school": "Manheim Twp MS",
        "district": "Manheim Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421458005114",
    },
    {
        "school": "Bucher Sch",
        "district": "Manheim Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421458006733",
    },
    {
        "school": "Manor Middle School",
        "district": "Penn Manor SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421863000119",
    },
    {
        "school": "Conestoga El Sch",
        "district": "Penn Manor SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421863002516",
    },
    {
        "school": "Hambright El Sch",
        "district": "Penn Manor SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421863002626",
    },
    {
        "school": "Letort El Sch",
        "district": "Penn Manor SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421863002627",
    },
    {
        "school": "Martic El Sch",
        "district": "Penn Manor SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421863002628",
    },
    {
        "school": "Eshleman El Sch",
        "district": "Penn Manor SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421863002629",
    },
    {
        "school": "Penn Manor HS",
        "district": "Penn Manor SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421863002633",
    },
    {
        "school": "Pequea El Sch",
        "district": "Penn Manor SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421863002634",
    },
    {
        "school": "Marticville MS",
        "district": "Penn Manor SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421863005238",
    },
    {
        "school": "Central Manor El Sch",
        "district": "Penn Manor SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421863007175",
    },
    {
        "school": "Paradise El Sch",
        "district": "Pequea Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421890002647",
    },
    {
        "school": "Salisbury El Sch",
        "district": "Pequea Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421890002648",
    },
    {
        "school": "Pequea Valley HS",
        "district": "Pequea Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421890002649",
    },
    {
        "school": "Pequea Valley Intrmd Sch",
        "district": "Pequea Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421890006300",
    },
    {
        "school": "Clermont El Sch",
        "district": "Solanco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422181000036",
    },
    {
        "school": "Providence El Sch",
        "district": "Solanco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422181002654",
    },
    {
        "school": "Quarryville El Sch",
        "district": "Solanco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422181002655",
    },
    {
        "school": "Bart-Colerain El Sch",
        "district": "Solanco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422181002656",
    },
    {
        "school": "Smith MS",
        "district": "Solanco SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422181002657",
    },
    {
        "school": "Solanco HS",
        "district": "Solanco SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422181002658",
    },
    {
        "school": "Swift MS",
        "district": "Solanco SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422181005054",
    },
    {
        "school": "John R Bonfield El Sch",
        "district": "Warwick SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422496000120",
    },
    {
        "school": "Lititz El Sch",
        "district": "Warwick SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422496002660",
    },
    {
        "school": "John Beck El Sch",
        "district": "Warwick SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422496002661",
    },
    {
        "school": "Warwick SHS",
        "district": "Warwick SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422496002663",
    },
    {
        "school": "Kissel Hill El Sch",
        "district": "Warwick SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422496004823",
    },
    {
        "school": "Warwick MS",
        "district": "Warwick SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422496005336",
    },
    {
        "school": "Lancaster County CTC-Brownstown Campus",
        "district": "Lancaster County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428027007072",
    },
    {
        "school": "Lancaster County CTC-Mt Joy Campus",
        "district": "Lancaster County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428027007073",
    },
    {
        "school": "Lancaster County CTC-Willow St Campus",
        "district": "Lancaster County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428027007074",
    },
    {
        "school": "Cleona El Sch",
        "district": "Annville-Cleona SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420249002723",
    },
    {
        "school": "Annville El Sch",
        "district": "Annville-Cleona SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420249002724",
    },
    {
        "school": "Annville Cleona HS",
        "district": "Annville-Cleona SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420249002725",
    },
    {
        "school": "Ebenezer El Sch",
        "district": "Cornwall-Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420684002728",
    },
    {
        "school": "South Lebanon El Sch",
        "district": "Cornwall-Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420684002729",
    },
    {
        "school": "Cedar Crest HS",
        "district": "Cornwall-Lebanon SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420684004800",
    },
    {
        "school": "Cedar Crest MS",
        "district": "Cornwall-Lebanon SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420684006301",
    },
    {
        "school": "Cornwall El Sch",
        "district": "Cornwall-Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420684006302",
    },
    {
        "school": "Union Canal El Sch",
        "district": "Cornwall-Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420684009945",
    },
    {
        "school": "Jackson El Sch",
        "district": "Eastern Lebanon County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420846002735",
    },
    {
        "school": "Eastern Lebanon Co SHS",
        "district": "Eastern Lebanon County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420846002740",
    },
    {
        "school": "Fort Zeller El Sch",
        "district": "Eastern Lebanon County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420846006611",
    },
    {
        "school": "Eastern Lebanon Co MS",
        "district": "Eastern Lebanon County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420846006612",
    },
    {
        "school": "Southwest El Sch",
        "district": "Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421344002743",
    },
    {
        "school": "Southeast El Sch",
        "district": "Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421344002746",
    },
    {
        "school": "Lebanon MS",
        "district": "Lebanon SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421344002754",
    },
    {
        "school": "Lebanon SHS",
        "district": "Lebanon SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421344005155",
    },
    {
        "school": "Houck El Sch",
        "district": "Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421344005337",
    },
    {
        "school": "Harding El Sch",
        "district": "Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421344006616",
    },
    {
        "school": "Northwest El Sch",
        "district": "Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421344006894",
    },
    {
        "school": "Fredericksburg El Sch",
        "district": "Northern Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421764002755",
    },
    {
        "school": "Lickdale El Sch",
        "district": "Northern Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421764002756",
    },
    {
        "school": "Jonestown El Sch",
        "district": "Northern Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421764002757",
    },
    {
        "school": "East Hanover El Sch",
        "district": "Northern Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421764002758",
    },
    {
        "school": "Northern Lebanon SHS",
        "district": "Northern Lebanon SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421764002760",
    },
    {
        "school": "Forge Road El Sch",
        "district": "Palmyra Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421839002761",
    },
    {
        "school": "Pine Street El Sch",
        "district": "Palmyra Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421839002764",
    },
    {
        "school": "Palmyra Area MS",
        "district": "Palmyra Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421839002765",
    },
    {
        "school": "Palmyra Area SHS",
        "district": "Palmyra Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421839002766",
    },
    {
        "school": "Lebanon County CTC",
        "district": "Lebanon County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428028007075",
    },
    {
        "school": "Linntown El Sch",
        "district": "Lewisburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421359004081",
    },
    {
        "school": "Kelly El Sch",
        "district": "Lewisburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421359004084",
    },
    {
        "school": "Lewisburg HS",
        "district": "Lewisburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421359004085",
    },
    {
        "school": "Donald H Eichhorn MS",
        "district": "Lewisburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421359004665",
    },
    {
        "school": "Mifflinburg Area SHS",
        "district": "Mifflinburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422601004091",
    },
    {
        "school": "Mifflinburg El Sch",
        "district": "Mifflinburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422601006360",
    },
    {
        "school": "Mifflinburg Area MS",
        "district": "Mifflinburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422601006809",
    },
    {
        "school": "SUN Area Technical Institute",
        "district": "SUN Area Technical Institute",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428042007086",
    },
    {
        "school": "New Day Charter School",
        "district": "New Day Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420011400713",
    },
    {
        "school": "Lewistown El Sch",
        "district": "Mifflin County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421529000784",
    },
    {
        "school": "Strodes Mills El Sch",
        "district": "Mifflin County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421529003196",
    },
    {
        "school": "East Derry El Sch",
        "district": "Mifflin County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421529006261",
    },
    {
        "school": "Bucktail Area MS",
        "district": "Keystone Central SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272500797",
    },
    {
        "school": "Sugar Valley Rural CS",
        "district": "Sugar Valley Rural CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420006300510",
    },
    {
        "school": "Keystone Central CTC",
        "district": "Keystone Central CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428067007108",
    },
    {
        "school": "Liberty-Curtin El Sch",
        "district": "Keystone Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272504917",
    },
    {
        "school": "Central Mountain HS",
        "district": "Keystone Central SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272500446",
    },
    {
        "school": "Central Mountain MS",
        "district": "Keystone Central SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272500449",
    },
    {
        "school": "Mill Hall El Sch",
        "district": "Keystone Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272501570",
    },
    {
        "school": "Woodward El Sch",
        "district": "Keystone Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272501588",
    },
    {
        "school": "Dickey El Sch",
        "district": "Keystone Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272504815",
    },
    {
        "school": "Bucktail HS",
        "district": "Keystone Central SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272506241",
    },
    {
        "school": "Renovo El Sch",
        "district": "Keystone Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272506242",
    },
    {
        "school": "Robb El Sch",
        "district": "Keystone Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421272506245",
    },
    {
        "school": "Conneaut Lake-Sadsbury El Sch",
        "district": "Conneaut SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420659006132",
    },
    {
        "school": "Conneaut Valley El Sch",
        "district": "Conneaut SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420659006133",
    },
    {
        "school": "Cochranton JSHS",
        "district": "Crawford Central SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420708001632",
    },
    {
        "school": "Second District El Sch",
        "district": "Crawford Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420708001645",
    },
    {
        "school": "Neason Hill El Sch",
        "district": "Crawford Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420708001650",
    },
    {
        "school": "First District El Sch",
        "district": "Crawford Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420708001651",
    },
    {
        "school": "Meadville MS",
        "district": "Crawford Central SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420708001653",
    },
    {
        "school": "Meadville Area SHS",
        "district": "Crawford Central SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420708001654",
    },
    {
        "school": "Cochranton El Sch",
        "district": "Crawford Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420708005037",
    },
    {
        "school": "West End El Sch",
        "district": "Crawford Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420708007265",
    },
    {
        "school": "Cambridge Springs JSHS",
        "district": "Penncrest SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421874001629",
    },
    {
        "school": "Cambridge Springs El Sch",
        "district": "Penncrest SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421874001630",
    },
    {
        "school": "Saegertown JSHS",
        "district": "Penncrest SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421874006136",
    },
    {
        "school": "Maplewood El Sch",
        "district": "Penncrest SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421874006137",
    },
    {
        "school": "Maplewood JSHS",
        "district": "Penncrest SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421874006942",
    },
    {
        "school": "Saegertown El Sch",
        "district": "Penncrest SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421874009957",
    },
    {
        "school": "Early Childhood Lc",
        "district": "Titusville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422349000046",
    },
    {
        "school": "Titusville MS",
        "district": "Titusville Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422349000441",
    },
    {
        "school": "Main Street El Sch",
        "district": "Titusville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422349001663",
    },
    {
        "school": "Hydetown El Sch",
        "district": "Titusville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422349001666",
    },
    {
        "school": "Titusville SHS",
        "district": "Titusville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422349001668",
    },
    {
        "school": "Crawford County CTC",
        "district": "Crawford County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428017007058",
    },
    {
        "school": "Pleasantville El Sch",
        "district": "Titusville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422349006168",
    },
    {
        "school": "Jamestown Area El Sch",
        "district": "Jamestown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421230006127",
    },
    {
        "school": "Jamestown Area JSHS",
        "district": "Jamestown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421230006126",
    },
    {
        "school": "Lincoln JSHS",
        "district": "Ellwood City Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420924002675",
    },
    {
        "school": "Laurel HS",
        "district": "Laurel SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421338002680",
    },
    {
        "school": "Laurel El Sch",
        "district": "Laurel SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421338007209",
    },
    {
        "school": "Lawrence County CTC",
        "district": "Lawrence County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "421339004940",
    },
    {
        "school": "Mohawk SHS",
        "district": "Mohawk Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421554002686",
    },
    {
        "school": "Mohawk El Sch",
        "district": "Mohawk Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421554007129",
    },
    {
        "school": "Neshannock Memorial El Sch",
        "district": "Neshannock Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421644002688",
    },
    {
        "school": "Neshannock JSHS",
        "district": "Neshannock Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421644002689",
    },
    {
        "school": "Croton Pre-Kdg Ctr",
        "district": "New Castle Area SD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421662002701",
    },
    {
        "school": "New Castle SHS",
        "district": "New Castle Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421662002704",
    },
    {
        "school": "Washington Intrmd Sch",
        "district": "New Castle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421662007218",
    },
    {
        "school": "Shenango El Sch",
        "district": "Shenango Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422151002706",
    },
    {
        "school": "Shenango HS",
        "district": "Shenango Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422151002708",
    },
    {
        "school": "Union Memorial El Sch",
        "district": "Union Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422406002709",
    },
    {
        "school": "Union Area HS",
        "district": "Union Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422406002712",
    },
    {
        "school": "Union Area MS",
        "district": "Union Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422406007036",
    },
    {
        "school": "Wilmington Area MS",
        "district": "Wilmington Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422652000033",
    },
    {
        "school": "Wilmington Area HS",
        "district": "Wilmington Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422652002721",
    },
    {
        "school": "Wilmington Area El Sch",
        "district": "Wilmington Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422652006963",
    },
    {
        "school": "Dingman-Delaware MS",
        "district": "Delaware Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420753000132",
    },
    {
        "school": "Dingman-Delaware Primary Sch",
        "district": "Delaware Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420753000474",
    },
    {
        "school": "Dingman-Delaware El Sch",
        "district": "Delaware Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420753003864",
    },
    {
        "school": "Delaware Valley MS",
        "district": "Delaware Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420753003865",
    },
    {
        "school": "Shohola El Sch",
        "district": "Delaware Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420753003866",
    },
    {
        "school": "Delaware Valley HS",
        "district": "Delaware Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420753005261",
    },
    {
        "school": "Delaware Valley El Sch",
        "district": "Delaware Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420753007200",
    },
    {
        "school": "Cranberry Area JSHS",
        "district": "Cranberry Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420705004098",
    },
    {
        "school": "Cranberry El Sch",
        "district": "Cranberry Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420705006595",
    },
    {
        "school": "Hasson Heights Sch",
        "district": "Oil City Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421809004115",
    },
    {
        "school": "Smedley Street Sch",
        "district": "Oil City Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421809004116",
    },
    {
        "school": "Oil City SHS",
        "district": "Oil City Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421809004931",
    },
    {
        "school": "Oil City Area MS",
        "district": "Oil City Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421809007292",
    },
    {
        "school": "Rocky Grove JSHS",
        "district": "Valley Grove SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422463004126",
    },
    {
        "school": "Venango Technology Center",
        "district": "Venango Technology Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428043007087",
    },
    {
        "school": "Sandycreek El Sch",
        "district": "Franklin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421020004101",
    },
    {
        "school": "Franklin Area JSHS",
        "district": "Franklin Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421020004106",
    },
    {
        "school": "Central El Sch",
        "district": "Franklin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421020004667",
    },
    {
        "school": "Victory El Sch",
        "district": "Franklin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421020006166",
    },
    {
        "school": "Center for Student Lrng CS Pennsbury",
        "district": "Center for Student Learning CS at Pennsbury",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420010000662",
    },
    {
        "school": "Bristol MS",
        "district": "Bristol Borough SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420420000686",
    },
    {
        "school": "Tohickon MS",
        "district": "Central Bucks SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531000643",
    },
    {
        "school": "Central Bucks HS-South",
        "district": "Central Bucks SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531000785",
    },
    {
        "school": "Bridge Valley El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531000798",
    },
    {
        "school": "Council Rock HS South",
        "district": "Council Rock SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696000691",
    },
    {
        "school": "New Hope-Solebury Upper El Sch",
        "district": "New Hope-Solebury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421686000851",
    },
    {
        "school": "Pfaff El Sch",
        "district": "Quakertown Community SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421989000854",
    },
    {
        "school": "Avon Grove CS",
        "district": "Avon Grove CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420010100656",
    },
    {
        "school": "Pennsylvania Leadership CS",
        "district": "Pennsylvania Leadership Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420012700837",
    },
    {
        "school": "Scott MS",
        "district": "Coatesville Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420624000728",
    },
    {
        "school": "Downingtown HS East Campus",
        "district": "Downingtown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771000706",
    },
    {
        "school": "French Creek El Sch",
        "district": "Owen J Roberts SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421827000628",
    },
    {
        "school": "Pocopson El Sch",
        "district": "Unionville-Chadds Ford SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422421000677",
    },
    {
        "school": "Chadds Ford El Sch",
        "district": "Unionville-Chadds Ford SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422421000709",
    },
    {
        "school": "Bethel Springs El Sch",
        "district": "Garnet Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421059000641",
    },
    {
        "school": "Walter M Senkow El Sch",
        "district": "Upper Darby SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432000893",
    },
    {
        "school": "Colwyn El Sch",
        "district": "William Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422639000710",
    },
    {
        "school": "Achievement House CS",
        "district": "Achievement House CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420012800843",
    },
    {
        "school": "Ad Prima CS",
        "district": "Ad Prima CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420012900846",
    },
    {
        "school": "Agora Cyber CS",
        "district": "Agora Cyber CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420014000896",
    },
    {
        "school": "Schwenksville El Sch",
        "district": "Perkiomen Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421893000727",
    },
    {
        "school": "Perkiomen Valley MS-West",
        "district": "Perkiomen Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421893000796",
    },
    {
        "school": "Vernfield El Sch",
        "district": "Souderton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422187000697",
    },
    {
        "school": "Upper Providence El Sch",
        "district": "Spring-Ford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422256000716",
    },
    {
        "school": "Spring-Ford MS 7th Grade Ctr",
        "district": "Spring-Ford Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422256000835",
    },
    {
        "school": "Spring-Ford MS 8th Grade Ctr",
        "district": "Spring-Ford Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422256000836",
    },
    {
        "school": "Upper Moreland Primary Sch",
        "district": "Upper Moreland Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422451000814",
    },
    {
        "school": "Upper Moreland Intermediate Sch",
        "district": "Upper Moreland Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422451000815",
    },
    {
        "school": "First Philadelphia Preparatory Charter S",
        "district": "First Philadelphia Preparatory Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420009300687",
    },
    {
        "school": "Green Woods CS",
        "district": "Green Woods CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420010400690",
    },
    {
        "school": "West Phila. Achievement CES",
        "district": "West Phila. Achievement CES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420010500657",
    },
    {
        "school": "Wissahickon CS",
        "district": "Wissahickon CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420010600659",
    },
    {
        "school": "Philadelphia Electrical & Tech CHS",
        "district": "Philadelphia Electrical & Tech CHS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420010700678",
    },
    {
        "school": "Belmont Charter School",
        "district": "Belmont Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420010800692",
    },
    {
        "school": "Discovery Charter School",
        "district": "Discovery Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420012100757",
    },
    {
        "school": "KIPP Philadelphia Charter School",
        "district": "KIPP Philadelphia Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420012200758",
    },
    {
        "school": "Maritime Academy CS",
        "district": "Maritime Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420012300759",
    },
    {
        "school": "Philadelphia Montessori CS",
        "district": "Philadelphia Montessori CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420013000849",
    },
    {
        "school": "Northwood Academy CS",
        "district": "Northwood Academy CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420013900894",
    },
    {
        "school": "Folk Arts-Cultural Treasures CS",
        "district": "Folk Arts-Cultural Treasures CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420014100897",
    },
    {
        "school": "Paul Robeson HS for Human Services",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000765",
    },
    {
        "school": "Parkway Center City Middle College",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000771",
    },
    {
        "school": "Parkway West",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000821",
    },
    {
        "school": "Lankenau HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000824",
    },
    {
        "school": "Randolph A. Philip AVT HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "421899000826",
    },
    {
        "school": "Motivation HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000830",
    },
    {
        "school": "Philadelphia Military Acad at Elverson",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000899",
    },
    {
        "school": "Kensington Creative & Performing Arts HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000901",
    },
    {
        "school": "Kensington Health Sciences",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000907",
    },
    {
        "school": "Hereford El Sch",
        "district": "Upper Perkiomen SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422454007246",
    },
    {
        "school": "School Lane CS",
        "district": "School Lane CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420003000379",
    },
    {
        "school": "Bucks County Montessori CS",
        "district": "Bucks County Montessori CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420006900562",
    },
    {
        "school": "Cornwells El Sch",
        "district": "Bensalem Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420333001006",
    },
    {
        "school": "Samuel K Faust El Sch",
        "district": "Bensalem Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420333001008",
    },
    {
        "school": "Benjamin Rush El Sch",
        "district": "Bensalem Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420333004675",
    },
    {
        "school": "Bensalem Twp HS",
        "district": "Bensalem Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420333005116",
    },
    {
        "school": "Belmont Hills El Sch",
        "district": "Bensalem Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420333005211",
    },
    {
        "school": "Cecelia Snyder MS",
        "district": "Bensalem Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420333006451",
    },
    {
        "school": "Valley El Sch",
        "district": "Bensalem Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420333006788",
    },
    {
        "school": "Russell C Struble El Sch",
        "district": "Bensalem Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420333006896",
    },
    {
        "school": "Robert K Shafer MS",
        "district": "Bensalem Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420333007030",
    },
    {
        "school": "Warren Snyder-John Girotti El Sch",
        "district": "Bristol Borough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420420001013",
    },
    {
        "school": "Bristol HS",
        "district": "Bristol Borough SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420420001014",
    },
    {
        "school": "Roosevelt MS",
        "district": "Bristol Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420423001027",
    },
    {
        "school": "Truman SHS",
        "district": "Bristol Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420423001029",
    },
    {
        "school": "William Tennent HS",
        "district": "Centennial SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420519001040",
    },
    {
        "school": "McDonald El Sch",
        "district": "Centennial SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420519005007",
    },
    {
        "school": "Klinger MS",
        "district": "Centennial SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420519009937",
    },
    {
        "school": "Log College MS",
        "district": "Centennial SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420519009938",
    },
    {
        "school": "Cold Spring El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531000171",
    },
    {
        "school": "Jamison El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531000301",
    },
    {
        "school": "Groveland El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531000539",
    },
    {
        "school": "Mill Creek El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531000540",
    },
    {
        "school": "Lenape MS",
        "district": "Central Bucks SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531001041",
    },
    {
        "school": "Tamanend MS",
        "district": "Central Bucks SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531001042",
    },
    {
        "school": "Central Bucks HS-West",
        "district": "Central Bucks SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531001043",
    },
    {
        "school": "Buckingham El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531001044",
    },
    {
        "school": "Kutz El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531001047",
    },
    {
        "school": "Gayman El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531001048",
    },
    {
        "school": "Linden El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531001057",
    },
    {
        "school": "Butler El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531001081",
    },
    {
        "school": "Titus El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531001131",
    },
    {
        "school": "Unami MS",
        "district": "Central Bucks SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531004678",
    },
    {
        "school": "Barclay El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531004683",
    },
    {
        "school": "Doyle El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531004852",
    },
    {
        "school": "Central Bucks HS-East",
        "district": "Central Bucks SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531005133",
    },
    {
        "school": "Pine Run El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531005306",
    },
    {
        "school": "Holicong MS",
        "district": "Central Bucks SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531005307",
    },
    {
        "school": "Warwick El Sch",
        "district": "Central Bucks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420531010004",
    },
    {
        "school": "Newtown El Sch",
        "district": "Council Rock SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696000172",
    },
    {
        "school": "Maureen M Welch El Sch",
        "district": "Council Rock SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696000544",
    },
    {
        "school": "Goodnoe El Sch",
        "district": "Council Rock SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696001086",
    },
    {
        "school": "Richboro El Sch",
        "district": "Council Rock SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696001087",
    },
    {
        "school": "Churchville El Sch",
        "district": "Council Rock SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696001088",
    },
    {
        "school": "Sol Feinstone El Sch",
        "district": "Council Rock SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696001130",
    },
    {
        "school": "Holland El Sch",
        "district": "Council Rock SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696004680",
    },
    {
        "school": "Council Rock HS North",
        "district": "Council Rock SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696005096",
    },
    {
        "school": "Rolling Hills El Sch",
        "district": "Council Rock SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696005308",
    },
    {
        "school": "Newtown MS",
        "district": "Council Rock SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696006453",
    },
    {
        "school": "Hillcrest El Sch",
        "district": "Council Rock SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696007264",
    },
    {
        "school": "Maple Point MS",
        "district": "Neshaminy SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421641000103",
    },
    {
        "school": "Joseph E Ferderbar El Sch",
        "district": "Neshaminy SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421641001069",
    },
    {
        "school": "Miller El Sch",
        "district": "Neshaminy SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421641001071",
    },
    {
        "school": "Schweitzer El Sch",
        "district": "Neshaminy SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421641001072",
    },
    {
        "school": "Sandburg MS",
        "district": "Neshaminy SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421641001076",
    },
    {
        "school": "Poquessing MS",
        "district": "Neshaminy SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421641001077",
    },
    {
        "school": "Buck El Sch",
        "district": "Neshaminy SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421641005154",
    },
    {
        "school": "Neshaminy HS",
        "district": "Neshaminy SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421641006455",
    },
    {
        "school": "Hoover El Sch",
        "district": "Neshaminy SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421641007161",
    },
    {
        "school": "New Hope-Solebury MS",
        "district": "New Hope-Solebury SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421686000381",
    },
    {
        "school": "New Hope-Solebury Lower El Sch",
        "district": "New Hope-Solebury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421686001082",
    },
    {
        "school": "New Hope-Solebury HS",
        "district": "New Hope-Solebury SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421686001084",
    },
    {
        "school": "Springfield El Sch",
        "district": "Palisades SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421833001091",
    },
    {
        "school": "Palisades HS",
        "district": "Palisades SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421833001094",
    },
    {
        "school": "Tinicum El Sch",
        "district": "Palisades SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421833006456",
    },
    {
        "school": "Durham-Nockamixon El Sch",
        "district": "Palisades SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421833007221",
    },
    {
        "school": "Palisades MS",
        "district": "Palisades SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421833010005",
    },
    {
        "school": "Seylar El Sch",
        "district": "Pennridge SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421875001052",
    },
    {
        "school": "Bedminster El Sch",
        "district": "Pennridge SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421875001053",
    },
    {
        "school": "Deibler El Sch",
        "district": "Pennridge SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421875001054",
    },
    {
        "school": "Grasse El Sch",
        "district": "Pennridge SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421875001055",
    },
    {
        "school": "Patricia A Guth El Sch",
        "district": "Pennridge SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421875001097",
    },
    {
        "school": "Sellersville El Sch",
        "district": "Pennridge SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421875001098",
    },
    {
        "school": "Pennridge South MS",
        "district": "Pennridge SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421875001099",
    },
    {
        "school": "Pennridge HS",
        "district": "Pennridge SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421875001100",
    },
    {
        "school": "Pennridge Central MS",
        "district": "Pennridge SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421875004681",
    },
    {
        "school": "West Rockhill El Sch",
        "district": "Pennridge SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421875009958",
    },
    {
        "school": "Fallsington El Sch",
        "district": "Pennsbury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884000231",
    },
    {
        "school": "Afton El Sch",
        "district": "Pennsbury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884000303",
    },
    {
        "school": "Penn Valley El Sch",
        "district": "Pennsbury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884001101",
    },
    {
        "school": "Quarry Hill El Sch",
        "district": "Pennsbury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884001102",
    },
    {
        "school": "Oxford Valley El Sch",
        "district": "Pennsbury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884001106",
    },
    {
        "school": "Manor El Sch",
        "district": "Pennsbury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884001107",
    },
    {
        "school": "Makefield El Sch",
        "district": "Pennsbury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884001109",
    },
    {
        "school": "Eleanor Roosevelt El Sch",
        "district": "Pennsbury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884001111",
    },
    {
        "school": "Walt Disney El Sch",
        "district": "Pennsbury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884001112",
    },
    {
        "school": "William Penn MS",
        "district": "Pennsbury SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884001113",
    },
    {
        "school": "Pennwood MS",
        "district": "Pennsbury SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884001116",
    },
    {
        "school": "Pennsbury HS",
        "district": "Pennsbury SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884004682",
    },
    {
        "school": "Edgewood El Sch",
        "district": "Pennsbury SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884004853",
    },
    {
        "school": "Charles H Boehm MS",
        "district": "Pennsbury SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884009959",
    },
    {
        "school": "Trumbauersville El Sch",
        "district": "Quakertown Community SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421989000479",
    },
    {
        "school": "Richland El Sch",
        "district": "Quakertown Community SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421989001121",
    },
    {
        "school": "Neidig El Sch",
        "district": "Quakertown Community SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421989001122",
    },
    {
        "school": "Quakertown Community HS",
        "district": "Quakertown Community SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421989001128",
    },
    {
        "school": "Strayer MS",
        "district": "Quakertown Community SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421989004965",
    },
    {
        "school": "Quakertown El Sch",
        "district": "Quakertown Community SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421989005132",
    },
    {
        "school": "Bucks County Technical High School",
        "district": "Bucks County Technical High School",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428009007050",
    },
    {
        "school": "Middle Bucks Institute of Technology",
        "district": "Middle Bucks Institute of Technology",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428010007051",
    },
    {
        "school": "Upper Bucks County Technical School",
        "district": "Upper Bucks County Technical School",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428011007052",
    },
    {
        "school": "Chester Co Family Academy CS",
        "district": "Chester Co Family Academy CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420001200311",
    },
    {
        "school": "Collegium CS",
        "district": "Collegium CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420005000485",
    },
    {
        "school": "Renaissance Academy CS",
        "district": "Renaissance Academy CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420006700511",
    },
    {
        "school": "21st Century Cyber CS",
        "district": "21st Century Cyber CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420009100597",
    },
    {
        "school": "Avon Grove Intrmd Sch",
        "district": "Avon Grove SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420279001365",
    },
    {
        "school": "Avon Grove HS",
        "district": "Avon Grove SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420279001367",
    },
    {
        "school": "Fred S Engle MS",
        "district": "Avon Grove SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420279005216",
    },
    {
        "school": "Penn London El Sch",
        "district": "Avon Grove SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420279010008",
    },
    {
        "school": "Chester Co Technical College HS-Brandywi",
        "district": "Chester County Technical College HS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "420290000011",
    },
    {
        "school": "Chester Co Technical College HS-Pickerin",
        "district": "Chester County Technical College HS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "420290000015",
    },
    {
        "school": "Rainbow El Sch",
        "district": "Coatesville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420624001370",
    },
    {
        "school": "East Fallowfield El Sch",
        "district": "Coatesville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420624001374",
    },
    {
        "school": "Kings Highway El Sch",
        "district": "Coatesville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420624001375",
    },
    {
        "school": "Caln El Sch",
        "district": "Coatesville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420624001376",
    },
    {
        "school": "Coatesville Area SHS",
        "district": "Coatesville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420624005012",
    },
    {
        "school": "Reeceville El Sch",
        "district": "Coatesville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420624010009",
    },
    {
        "school": "Lionville MS",
        "district": "Downingtown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771000307",
    },
    {
        "school": "Downingtown MS",
        "district": "Downingtown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771000308",
    },
    {
        "school": "Downingtown HS West Campus",
        "district": "Downingtown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771001387",
    },
    {
        "school": "Beaver Creek El Sch",
        "district": "Downingtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771001391",
    },
    {
        "school": "Brandywine-Wallace El Sch",
        "district": "Downingtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771001431",
    },
    {
        "school": "Pickering Valley El Sch",
        "district": "Downingtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771001432",
    },
    {
        "school": "East Ward El Sch",
        "district": "Downingtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771005011",
    },
    {
        "school": "Lionville El Sch",
        "district": "Downingtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771006476",
    },
    {
        "school": "West Bradford El Sch",
        "district": "Downingtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771006477",
    },
    {
        "school": "Uwchlan Hills El Sch",
        "district": "Downingtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771006621",
    },
    {
        "school": "Shamona Creek El Sch",
        "district": "Downingtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771009948",
    },
    {
        "school": "Bradford Hgts El Sch",
        "district": "Downingtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771009949",
    },
    {
        "school": "General Wayne El Sch",
        "district": "Great Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421087000606",
    },
    {
        "school": "Charlestown El Sch",
        "district": "Great Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421087001368",
    },
    {
        "school": "Great Valley MS",
        "district": "Great Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421087001422",
    },
    {
        "school": "Great Valley HS",
        "district": "Great Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421087001424",
    },
    {
        "school": "Kathryn D. Markley El Sch",
        "district": "Great Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421087006479",
    },
    {
        "school": "New Garden El Sch",
        "district": "Kennett Consolidated SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421269001400",
    },
    {
        "school": "Greenwood El Sch",
        "district": "Kennett Consolidated SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421269001401",
    },
    {
        "school": "Kennett HS",
        "district": "Kennett Consolidated SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421269006482",
    },
    {
        "school": "Kennett MS",
        "district": "Kennett Consolidated SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421269006834",
    },
    {
        "school": "Octorara Primary LC",
        "district": "Octorara Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421803000543",
    },
    {
        "school": "Octorara El Sch",
        "district": "Octorara Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421803001413",
    },
    {
        "school": "Octorara Area JSHS",
        "district": "Octorara Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421803001414",
    },
    {
        "school": "Owen J Roberts HS",
        "district": "Owen J Roberts SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421827001406",
    },
    {
        "school": "Owen J Roberts MS",
        "district": "Owen J Roberts SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421827005010",
    },
    {
        "school": "North Coventry El Sch",
        "district": "Owen J Roberts SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421827006487",
    },
    {
        "school": "East Vincent El Sch",
        "district": "Owen J Roberts SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421827007294",
    },
    {
        "school": "East Coventry El Sch",
        "district": "Owen J Roberts SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421827010011",
    },
    {
        "school": "Penn's Grove Sch",
        "district": "Oxford Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421830001418",
    },
    {
        "school": "Oxford Area HS",
        "district": "Oxford Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421830001420",
    },
    {
        "school": "Nottingham Sch",
        "district": "Oxford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421830006623",
    },
    {
        "school": "Jordan Bank Sch",
        "district": "Oxford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421830006624",
    },
    {
        "school": "Phoenixville Area MS",
        "district": "Phoenixville Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421905001425",
    },
    {
        "school": "Phoenixville Area HS",
        "district": "Phoenixville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421905001426",
    },
    {
        "school": "Barkley El Sch",
        "district": "Phoenixville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421905001430",
    },
    {
        "school": "Schuylkill El Sch",
        "district": "Phoenixville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421905004841",
    },
    {
        "school": "Spring City El Sch",
        "district": "Spring-Ford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422256000233",
    },
    {
        "school": "Tredyffrin-Easttown MS",
        "district": "Tredyffrin-Easttown SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422364001421",
    },
    {
        "school": "Conestoga SHS",
        "district": "Tredyffrin-Easttown SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422364001423",
    },
    {
        "school": "Devon El Sch",
        "district": "Tredyffrin-Easttown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422364001434",
    },
    {
        "school": "Valley Forge El Sch",
        "district": "Tredyffrin-Easttown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422364001438",
    },
    {
        "school": "Hillside El Sch",
        "district": "Tredyffrin-Easttown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422364001439",
    },
    {
        "school": "New Eagle El Sch",
        "district": "Tredyffrin-Easttown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422364001440",
    },
    {
        "school": "Valley Forge MS",
        "district": "Tredyffrin-Easttown SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422364004689",
    },
    {
        "school": "Beaumont El Sch",
        "district": "Tredyffrin-Easttown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422364004690",
    },
    {
        "school": "Unionville El Sch",
        "district": "Unionville-Chadds Ford SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422421001442",
    },
    {
        "school": "Unionville HS",
        "district": "Unionville-Chadds Ford SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422421001443",
    },
    {
        "school": "Charles F Patton MS",
        "district": "Unionville-Chadds Ford SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422421006719",
    },
    {
        "school": "Hillendale El Sch",
        "district": "Unionville-Chadds Ford SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422421007303",
    },
    {
        "school": "East Bradford El Sch",
        "district": "West Chester Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529001392",
    },
    {
        "school": "East Goshen El Sch",
        "district": "West Chester Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529001395",
    },
    {
        "school": "Stetson MS",
        "district": "West Chester Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529001451",
    },
    {
        "school": "E N Peirce MS",
        "district": "West Chester Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529001452",
    },
    {
        "school": "West Chester Henderson HS",
        "district": "West Chester Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529001453",
    },
    {
        "school": "Fern Hill El Sch",
        "district": "West Chester Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529001454",
    },
    {
        "school": "Exton El Sch",
        "district": "West Chester Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529001456",
    },
    {
        "school": "Mary C Howse El Sch",
        "district": "West Chester Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529001457",
    },
    {
        "school": "Westtown-Thornbury El Sch",
        "district": "West Chester Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529001458",
    },
    {
        "school": "Glen Acres El Sch",
        "district": "West Chester Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529004812",
    },
    {
        "school": "Penn Wood El Sch",
        "district": "West Chester Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529004813",
    },
    {
        "school": "J R Fugett MS",
        "district": "West Chester Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529005137",
    },
    {
        "school": "West Chester East HS",
        "district": "West Chester Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529006734",
    },
    {
        "school": "Hillsdale El Sch",
        "district": "West Chester Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529006910",
    },
    {
        "school": "Sarah W Starkweather El Sch",
        "district": "West Chester Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422529010012",
    },
    {
        "school": "Chester Community CS",
        "district": "Chester Community CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420003500388",
    },
    {
        "school": "Stetser El Sch",
        "district": "Chester-Upland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420586001829",
    },
    {
        "school": "Main Street Sch",
        "district": "Chester-Upland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420586001958",
    },
    {
        "school": "Chester HS",
        "district": "Chester-Upland SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420586006492",
    },
    {
        "school": "Boothwyn El Sch",
        "district": "Chichester SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420591001843",
    },
    {
        "school": "Linwood El Sch",
        "district": "Chichester SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420591001847",
    },
    {
        "school": "Chichester SHS",
        "district": "Chichester SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420591001849",
    },
    {
        "school": "Marcus Hook El Sch",
        "district": "Chichester SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420591001893",
    },
    {
        "school": "Hilltop El Sch",
        "district": "Chichester SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420591005322",
    },
    {
        "school": "Chichester MS",
        "district": "Chichester SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420591009943",
    },
    {
        "school": "Garnet Valley El Sch",
        "district": "Garnet Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421059000316",
    },
    {
        "school": "Garnet Valley HS",
        "district": "Garnet Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421059001869",
    },
    {
        "school": "Concord El Sch",
        "district": "Garnet Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421059006506",
    },
    {
        "school": "Garnet Valley MS",
        "district": "Garnet Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421059010013",
    },
    {
        "school": "Chatham Park El Sch",
        "district": "Haverford Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421167001871",
    },
    {
        "school": "Lynnewood El Sch",
        "district": "Haverford Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421167001874",
    },
    {
        "school": "Manoa El Sch",
        "district": "Haverford Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421167001875",
    },
    {
        "school": "Chestnutwold El Sch",
        "district": "Haverford Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421167001876",
    },
    {
        "school": "Coopertown El Sch",
        "district": "Haverford Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421167001877",
    },
    {
        "school": "Haverford MS",
        "district": "Haverford Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421167001878",
    },
    {
        "school": "Haverford SHS",
        "district": "Haverford Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421167001879",
    },
    {
        "school": "Kindergarten Academy",
        "district": "Interboro SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421217000524",
    },
    {
        "school": "Glenolden Sch",
        "district": "Interboro SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421217001881",
    },
    {
        "school": "Norwood Sch",
        "district": "Interboro SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421217001883",
    },
    {
        "school": "Interboro SHS",
        "district": "Interboro SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421217001885",
    },
    {
        "school": "Tinicum Sch",
        "district": "Interboro SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421217004847",
    },
    {
        "school": "Prospect Park Sch",
        "district": "Interboro SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421217006508",
    },
    {
        "school": "Russell El Sch",
        "district": "Marple Newtown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421476001894",
    },
    {
        "school": "Worrall El Sch",
        "district": "Marple Newtown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421476001896",
    },
    {
        "school": "Culbertson El Sch",
        "district": "Marple Newtown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421476001898",
    },
    {
        "school": "Loomis El Sch",
        "district": "Marple Newtown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421476001899",
    },
    {
        "school": "Paxon Hollow MS",
        "district": "Marple Newtown SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421476001901",
    },
    {
        "school": "Marple Newtown SHS",
        "district": "Marple Newtown SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421476001902",
    },
    {
        "school": "Coebourn El Sch",
        "district": "Penn-Delco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421858001910",
    },
    {
        "school": "Aston El Sch",
        "district": "Penn-Delco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421858001911",
    },
    {
        "school": "Parkside El Sch",
        "district": "Penn-Delco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421858001912",
    },
    {
        "school": "Sun Valley HS",
        "district": "Penn-Delco SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421858001915",
    },
    {
        "school": "Northley MS",
        "district": "Penn-Delco SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421858005143",
    },
    {
        "school": "Pennell El Sch",
        "district": "Penn-Delco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421858005223",
    },
    {
        "school": "Radnor El Sch",
        "district": "Radnor Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421992000609",
    },
    {
        "school": "Radnor SHS",
        "district": "Radnor Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421992001921",
    },
    {
        "school": "Ithan El Sch",
        "district": "Radnor Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421992006510",
    },
    {
        "school": "Radnor MS",
        "district": "Radnor Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421992006511",
    },
    {
        "school": "Wayne El Sch",
        "district": "Radnor Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421992006512",
    },
    {
        "school": "Amosland El Sch",
        "district": "Ridley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422037001925",
    },
    {
        "school": "Edgewood El Sch",
        "district": "Ridley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422037001926",
    },
    {
        "school": "Grace Park El Sch",
        "district": "Ridley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422037001928",
    },
    {
        "school": "Leedom El Sch",
        "district": "Ridley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422037001930",
    },
    {
        "school": "Woodlyn El Sch",
        "district": "Ridley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422037001932",
    },
    {
        "school": "Ridley HS",
        "district": "Ridley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422037001934",
    },
    {
        "school": "Lakeview El Sch",
        "district": "Ridley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422037004705",
    },
    {
        "school": "Eddystone El Sch",
        "district": "Ridley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422037005043",
    },
    {
        "school": "Ridley MS",
        "district": "Ridley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422037007299",
    },
    {
        "school": "Indian Lane El Sch",
        "district": "Rose Tree Media SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422055000049",
    },
    {
        "school": "Rose Tree El Sch",
        "district": "Rose Tree Media SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422055001937",
    },
    {
        "school": "Glenwood El Sch",
        "district": "Rose Tree Media SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422055001940",
    },
    {
        "school": "Penncrest HS",
        "district": "Rose Tree Media SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422055001942",
    },
    {
        "school": "Media El Sch",
        "district": "Rose Tree Media SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422055006514",
    },
    {
        "school": "Springton Lake MS",
        "district": "Rose Tree Media SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422055006625",
    },
    {
        "school": "Darby Twp Sch",
        "district": "Southeast Delco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422240001861",
    },
    {
        "school": "Sharon Hill Sch",
        "district": "Southeast Delco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422240001943",
    },
    {
        "school": "Harris Sch",
        "district": "Southeast Delco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422240006501",
    },
    {
        "school": "Delcroft Sch",
        "district": "Southeast Delco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422240006505",
    },
    {
        "school": "Academy Park HS",
        "district": "Southeast Delco SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422240006516",
    },
    {
        "school": "Richardson MS",
        "district": "Springfield SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422260001949",
    },
    {
        "school": "Springfield HS",
        "district": "Springfield SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422260001950",
    },
    {
        "school": "Sabold El Sch",
        "district": "Springfield SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422260006518",
    },
    {
        "school": "Scenic Hills El Sch",
        "district": "Springfield SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422260006519",
    },
    {
        "school": "Primos El Sch",
        "district": "Upper Darby SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432000042",
    },
    {
        "school": "Upper Darby Kdg Ctr",
        "district": "Upper Darby SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432000317",
    },
    {
        "school": "Aronimink El Sch",
        "district": "Upper Darby SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432001959",
    },
    {
        "school": "Bywood El Sch",
        "district": "Upper Darby SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432001960",
    },
    {
        "school": "Garrettford El Sch",
        "district": "Upper Darby SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432001964",
    },
    {
        "school": "Highland Park El Sch",
        "district": "Upper Darby SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432001965",
    },
    {
        "school": "Hillcrest El Sch",
        "district": "Upper Darby SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432001966",
    },
    {
        "school": "Stonehurst Hills El Sch",
        "district": "Upper Darby SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432001968",
    },
    {
        "school": "Westbrook Park El Sch",
        "district": "Upper Darby SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432001969",
    },
    {
        "school": "Beverly Hills MS",
        "district": "Upper Darby SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432001970",
    },
    {
        "school": "Drexel Hill MS",
        "district": "Upper Darby SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432001971",
    },
    {
        "school": "Upper Darby SHS",
        "district": "Upper Darby SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432001972",
    },
    {
        "school": "Nether Providence El Sch",
        "district": "Wallingford-Swarthmore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422479001905",
    },
    {
        "school": "Wallingford El Sch",
        "district": "Wallingford-Swarthmore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422479001906",
    },
    {
        "school": "Strath Haven MS",
        "district": "Wallingford-Swarthmore SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422479001908",
    },
    {
        "school": "Swarthmore-Rutledge Sch",
        "district": "Wallingford-Swarthmore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422479001952",
    },
    {
        "school": "Strath Haven HS",
        "district": "Wallingford-Swarthmore SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422479005287",
    },
    {
        "school": "Bell Avenue School",
        "district": "William Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422639000104",
    },
    {
        "school": "Ardmore Avenue Sch",
        "district": "William Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422639001887",
    },
    {
        "school": "East Lansdowne El Sch",
        "district": "William Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422639001890",
    },
    {
        "school": "W B Evans Magnet Sch",
        "district": "William Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422639001974",
    },
    {
        "school": "Aldan El Sch",
        "district": "William Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422639006509",
    },
    {
        "school": "Park Lane El Sch",
        "district": "William Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422639007249",
    },
    {
        "school": "Delaware County Technical High School-As",
        "district": "Delaware County Technical High School",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428020007061",
    },
    {
        "school": "Delaware County Technical High School-Fo",
        "district": "Delaware County Technical High School",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428020007062",
    },
    {
        "school": "Laboratory CS",
        "district": "Laboratory CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420004400406",
    },
    {
        "school": "Souderton CS Collaborative",
        "district": "Souderton CS Collaborative",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420007000514",
    },
    {
        "school": "Pennsylvania Virtual CS",
        "district": "Pennsylvania Virtual CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420008800587",
    },
    {
        "school": "Copper Beech Sch",
        "district": "Abington SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420204000620",
    },
    {
        "school": "Rydal East Sch",
        "district": "Abington SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420204003226",
    },
    {
        "school": "Highland Sch",
        "district": "Abington SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420204003229",
    },
    {
        "school": "Overlook Sch",
        "district": "Abington SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420204003232",
    },
    {
        "school": "Roslyn Sch",
        "district": "Abington SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420204003234",
    },
    {
        "school": "Abington SHS",
        "district": "Abington SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420204003241",
    },
    {
        "school": "Abington JHS",
        "district": "Abington SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420204003242",
    },
    {
        "school": "Willow Hill Sch",
        "district": "Abington SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420204004910",
    },
    {
        "school": "McKinley Sch",
        "district": "Abington SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420204005075",
    },
    {
        "school": "Lower Gwynedd El Sch",
        "district": "Wissahickon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420240000304",
    },
    {
        "school": "Wissahickon MS",
        "district": "Wissahickon SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420240003245",
    },
    {
        "school": "Wissahickon SHS",
        "district": "Wissahickon SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420240003247",
    },
    {
        "school": "Stony Creek El Sch",
        "district": "Wissahickon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420240003414",
    },
    {
        "school": "Blue Bell El Sch",
        "district": "Wissahickon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420240006470",
    },
    {
        "school": "Shady Grove El Sch",
        "district": "Wissahickon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420240006835",
    },
    {
        "school": "Cheltenham El Sch",
        "district": "Cheltenham SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420576003250",
    },
    {
        "school": "Myers El Sch",
        "district": "Cheltenham SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420576003252",
    },
    {
        "school": "Wyncote El Sch",
        "district": "Cheltenham SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420576003255",
    },
    {
        "school": "Glenside El Sch",
        "district": "Cheltenham SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420576003256",
    },
    {
        "school": "Elkins Park Sch",
        "district": "Cheltenham SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420576003257",
    },
    {
        "school": "Cheltenham HS",
        "district": "Cheltenham SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420576003260",
    },
    {
        "school": "Cedarbrook MS",
        "district": "Cheltenham SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420576005250",
    },
    {
        "school": "Crooked Billet El Sch",
        "district": "Hatboro-Horsham SD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421161003268",
    },
    {
        "school": "Simmons El Sch",
        "district": "Hatboro-Horsham SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421161003270",
    },
    {
        "school": "Hallowell El Sch",
        "district": "Hatboro-Horsham SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421161003271",
    },
    {
        "school": "Hatboro-Horsham SHS",
        "district": "Hatboro-Horsham SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421161003272",
    },
    {
        "school": "Blair Mill El Sch",
        "district": "Hatboro-Horsham SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421161005079",
    },
    {
        "school": "Keith Valley MS",
        "district": "Hatboro-Horsham SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421161006639",
    },
    {
        "school": "Pennypack El Sch",
        "district": "Hatboro-Horsham SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421161007206",
    },
    {
        "school": "Jenkintown El Sch",
        "district": "Jenkintown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421242003276",
    },
    {
        "school": "Belmont Hills El Sch",
        "district": "Lower Merion SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421416000482",
    },
    {
        "school": "Cynwyd Sch",
        "district": "Lower Merion SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421416003286",
    },
    {
        "school": "Merion El Sch",
        "district": "Lower Merion SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421416003287",
    },
    {
        "school": "Penn Valley Sch",
        "district": "Lower Merion SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421416003288",
    },
    {
        "school": "Penn Wynne Sch",
        "district": "Lower Merion SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421416003289",
    },
    {
        "school": "Gladwyne Sch",
        "district": "Lower Merion SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421416003291",
    },
    {
        "school": "Bala-Cynwyd MS",
        "district": "Lower Merion SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421416003293",
    },
    {
        "school": "Welsh Valley MS",
        "district": "Lower Merion SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421416003294",
    },
    {
        "school": "Lower Merion HS",
        "district": "Lower Merion SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421416003295",
    },
    {
        "school": "Harriton SHS",
        "district": "Lower Merion SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421416003296",
    },
    {
        "school": "Pine Road El Sch",
        "district": "Lower Moreland Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421419003297",
    },
    {
        "school": "Lower Moreland HS",
        "district": "Lower Moreland Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421419004960",
    },
    {
        "school": "Murray Avenue Sch",
        "district": "Lower Moreland Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421419007282",
    },
    {
        "school": "Worcester El Sch",
        "district": "Methacton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421425000483",
    },
    {
        "school": "Eagleville El Sch",
        "district": "Methacton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421425003303",
    },
    {
        "school": "Methacton HS",
        "district": "Methacton SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421425003305",
    },
    {
        "school": "Woodland El Sch",
        "district": "Methacton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421425005252",
    },
    {
        "school": "Arcola Intrmd Sch",
        "district": "Methacton SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421425006716",
    },
    {
        "school": "Arrowhead El Sch",
        "district": "Methacton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421425006845",
    },
    {
        "school": "Whitehall El Sch",
        "district": "Norristown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698000047",
    },
    {
        "school": "Cole Manor El Sch",
        "district": "Norristown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698003263",
    },
    {
        "school": "East Norriton MS",
        "district": "Norristown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698003265",
    },
    {
        "school": "Hancock El Sch",
        "district": "Norristown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698003318",
    },
    {
        "school": "Stewart MS",
        "district": "Norristown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698003320",
    },
    {
        "school": "Eisenhower MS",
        "district": "Norristown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698003321",
    },
    {
        "school": "Marshall Street El Sch",
        "district": "Norristown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698003408",
    },
    {
        "school": "Gotwals El Sch",
        "district": "Norristown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698005080",
    },
    {
        "school": "Paul V Fly El Sch",
        "district": "Norristown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698005253",
    },
    {
        "school": "Norristown Area HS",
        "district": "Norristown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698006729",
    },
    {
        "school": "Roosevelt Altern Sch",
        "district": "Norristown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698007146",
    },
    {
        "school": "Bridle Path El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728000133",
    },
    {
        "school": "Walton Farm El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728000134",
    },
    {
        "school": "Kulp El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728003275",
    },
    {
        "school": "York Avenue El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728003278",
    },
    {
        "school": "Oak Park El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728003280",
    },
    {
        "school": "Knapp El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728003309",
    },
    {
        "school": "Pennbrook MS",
        "district": "North Penn SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728003322",
    },
    {
        "school": "Pennfield MS",
        "district": "North Penn SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728003323",
    },
    {
        "school": "Penndale MS",
        "district": "North Penn SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728003324",
    },
    {
        "school": "North Wales El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728003325",
    },
    {
        "school": "Inglewood El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728003379",
    },
    {
        "school": "Gwyn-Nor El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728004831",
    },
    {
        "school": "Hatfield El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728005344",
    },
    {
        "school": "North Penn SHS",
        "district": "North Penn SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728005345",
    },
    {
        "school": "General Nash El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728006907",
    },
    {
        "school": "Montgomery El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728007173",
    },
    {
        "school": "Gwynedd Square El Sch",
        "district": "North Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421728010006",
    },
    {
        "school": "Evergreen El Sch",
        "district": "Perkiomen Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421893000232",
    },
    {
        "school": "Skippack El Sch",
        "district": "Perkiomen Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421893000382",
    },
    {
        "school": "Perkiomen Valley MS-East",
        "district": "Perkiomen Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421893003326",
    },
    {
        "school": "South El Sch",
        "district": "Perkiomen Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421893003327",
    },
    {
        "school": "Perkiomen Valley HS",
        "district": "Perkiomen Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421893003328",
    },
    {
        "school": "Conshohocken El Sch",
        "district": "Colonial SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421947003261",
    },
    {
        "school": "Ridge Park El Sch",
        "district": "Colonial SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421947003332",
    },
    {
        "school": "Plymouth-Whitemarsh SHS",
        "district": "Colonial SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421947003333",
    },
    {
        "school": "Whitemarsh El Sch",
        "district": "Colonial SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421947003411",
    },
    {
        "school": "Plymouth El Sch",
        "district": "Colonial SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421947004711",
    },
    {
        "school": "Colonial MS",
        "district": "Colonial SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421947005077",
    },
    {
        "school": "Colonial El Sch",
        "district": "Colonial SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421947007176",
    },
    {
        "school": "Lower Pottsgrove El Sch",
        "district": "Pottsgrove SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421965003334",
    },
    {
        "school": "West Pottsgrove El Sch",
        "district": "Pottsgrove SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421965003336",
    },
    {
        "school": "Ringing Rocks El Sch",
        "district": "Pottsgrove SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421965003337",
    },
    {
        "school": "Pottsgrove SHS",
        "district": "Pottsgrove SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421965003338",
    },
    {
        "school": "Pottsgrove MS",
        "district": "Pottsgrove SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421965006746",
    },
    {
        "school": "Franklin El Sch",
        "district": "Pottstown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421968003339",
    },
    {
        "school": "Lincoln El Sch",
        "district": "Pottstown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421968003341",
    },
    {
        "school": "Rupert El Sch",
        "district": "Pottstown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421968003342",
    },
    {
        "school": "Barth El Sch",
        "district": "Pottstown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421968003345",
    },
    {
        "school": "Pottstown MS",
        "district": "Pottstown SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421968003346",
    },
    {
        "school": "Pottstown SHS",
        "district": "Pottstown SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421968003348",
    },
    {
        "school": "Franconia El Sch",
        "district": "Souderton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422187003266",
    },
    {
        "school": "Souderton Area SHS",
        "district": "Souderton Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422187003354",
    },
    {
        "school": "E M Crouthamel El Sch",
        "district": "Souderton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422187003357",
    },
    {
        "school": "Indian Crest MS",
        "district": "Souderton Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422187004721",
    },
    {
        "school": "Indian Valley MS",
        "district": "Souderton Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422187004722",
    },
    {
        "school": "West Broad Street El Sch",
        "district": "Souderton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422187004900",
    },
    {
        "school": "Oak Ridge El Sch",
        "district": "Souderton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422187009965",
    },
    {
        "school": "Limerick El Sch",
        "district": "Spring-Ford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422256003358",
    },
    {
        "school": "Royersford El Sch",
        "district": "Spring-Ford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422256003364",
    },
    {
        "school": "Spring-Ford Intrmd Sch 5th/6th",
        "district": "Spring-Ford Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422256003365",
    },
    {
        "school": "Spring-Ford SHS 9-12 Ctr",
        "district": "Spring-Ford Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422256003367",
    },
    {
        "school": "Oaks El Sch",
        "district": "Spring-Ford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422256004809",
    },
    {
        "school": "Brooke El Sch",
        "district": "Spring-Ford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422256010007",
    },
    {
        "school": "Springfield Twp El Sch-Enfield",
        "district": "Springfield Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422262003368",
    },
    {
        "school": "Springfield Twp El Sch-Erdenhm",
        "district": "Springfield Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422262003370",
    },
    {
        "school": "Springfield Twp MS",
        "district": "Springfield Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422262003375",
    },
    {
        "school": "Springfield Twp HS",
        "district": "Springfield Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422262003376",
    },
    {
        "school": "Maple Glen El Sch",
        "district": "Upper Dublin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422439000538",
    },
    {
        "school": "Jarrettown El Sch",
        "district": "Upper Dublin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422439003382",
    },
    {
        "school": "Fitzwater El Sch",
        "district": "Upper Dublin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422439003385",
    },
    {
        "school": "Sandy Run MS",
        "district": "Upper Dublin SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422439004943",
    },
    {
        "school": "Upper Dublin HS",
        "district": "Upper Dublin SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422439005078",
    },
    {
        "school": "Fort Washington El Sch",
        "district": "Upper Dublin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422439005251",
    },
    {
        "school": "Candlebrook El Sch",
        "district": "Upper Merion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422448003389",
    },
    {
        "school": "Roberts El Sch",
        "district": "Upper Merion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422448003391",
    },
    {
        "school": "Upper Merion MS",
        "district": "Upper Merion Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422448003394",
    },
    {
        "school": "Upper Merion HS",
        "district": "Upper Merion Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422448003395",
    },
    {
        "school": "Caley El Sch",
        "district": "Upper Merion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422448004832",
    },
    {
        "school": "Bridgeport El Sch",
        "district": "Upper Merion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422448006468",
    },
    {
        "school": "Upper Moreland HS",
        "district": "Upper Moreland Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422451003401",
    },
    {
        "school": "Upper Moreland MS",
        "district": "Upper Moreland Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422451005249",
    },
    {
        "school": "Upper Perkiomen MS",
        "district": "Upper Perkiomen SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422454003406",
    },
    {
        "school": "Upper Perkiomen HS",
        "district": "Upper Perkiomen SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422454005081",
    },
    {
        "school": "Marlborough El Sch",
        "district": "Upper Perkiomen SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422454009968",
    },
    {
        "school": "Central Montco Technical High School",
        "district": "Central Montco Technical High School",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428033007080",
    },
    {
        "school": "Eastern Center for Arts & Technology",
        "district": "Eastern Center for Arts & Technology",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428034007081",
    },
    {
        "school": "Western Montgomery CTC",
        "district": "Western Montgomery CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428036007082",
    },
    {
        "school": "North Montco Tech Career Center",
        "district": "North Montco Tech Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428059007102",
    },
    {
        "school": "Community Academy of Philadelphia CS",
        "district": "Community Academy of Philadelphia CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420001300318",
    },
    {
        "school": "Harambee Institute of Science and Techno",
        "district": "Harambee Institute of Science and Technology CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420001400319",
    },
    {
        "school": "Youth Build Phila CS",
        "district": "Youth Build Phila CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420001600324",
    },
    {
        "school": "Preparatory CS of Mathematics Science Te",
        "district": "Preparatory CS of Mathematics Science Tech and Careers",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420003600391",
    },
    {
        "school": "Imhotep Institute CHS",
        "district": "Imhotep Institute CHS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420003800393",
    },
    {
        "school": "Alliance for Progress CS",
        "district": "Alliance for Progress CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420003900398",
    },
    {
        "school": "Multicultural Academy CS",
        "district": "Multicultural Academy CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420004000399",
    },
    {
        "school": "West Oak Lane CS",
        "district": "West Oak Lane CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420004100403",
    },
    {
        "school": "Inquiry Charter School",
        "district": "Inquiry Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420004200404",
    },
    {
        "school": "Eugenio Maria DE Hostos CS",
        "district": "Eugenio Maria De Hostos CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420004300405",
    },
    {
        "school": "MAST Community CS",
        "district": "MAST Community CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420005100488",
    },
    {
        "school": "Christopher Columbus CS",
        "district": "Christopher Columbus CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420005200489",
    },
    {
        "school": "Charter High School for Architecture and",
        "district": "Charter High School for Architecture and Design",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420005300493",
    },
    {
        "school": "Universal Institute CS",
        "district": "Universal Institute CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420005500495",
    },
    {
        "school": "Math Civics and Sciences CS",
        "district": "Math Civics and Sciences CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420005600496",
    },
    {
        "school": "Young Scholars CS",
        "district": "Young Scholars CS",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420005800500",
    },
    {
        "school": "Freire CS",
        "district": "Freire CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420006000502",
    },
    {
        "school": "Philadelphia Academy CS",
        "district": "Philadelphia Academy CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420006100503",
    },
    {
        "school": "Mastery CS-Hardy Williams",
        "district": "Mastery CS-Hardy Williams",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420006200504",
    },
    {
        "school": "Global Leadership Academy CS",
        "district": "Global Leadership Academy CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420007300515",
    },
    {
        "school": "Philadelphia Performing Arts CS",
        "district": "Philadelphia Performing Arts CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420007400529",
    },
    {
        "school": "New Foundations CS",
        "district": "New Foundations CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420007500531",
    },
    {
        "school": "Esperanza Academy Charter School",
        "district": "Esperanza Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420007600552",
    },
    {
        "school": "Franklin Towne CHS",
        "district": "Franklin Towne CHS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420007700554",
    },
    {
        "school": "Mariana Bracetti Academy CS",
        "district": "Mariana Bracetti Academy CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420007900564",
    },
    {
        "school": "Mastery CHS-Lenfest Campus",
        "district": "Mastery CHS-Lenfest Campus",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420008400578",
    },
    {
        "school": "People for People CS",
        "district": "People for People CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420008500586",
    },
    {
        "school": "Richard Allen Preparatory CS",
        "district": "Richard Allen Preparatory CS",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420008600585",
    },
    {
        "school": "Independence CS",
        "district": "Independence CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420008700584",
    },
    {
        "school": "Russell Byers CS",
        "district": "Russell Byers CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420009200577",
    },
    {
        "school": "Feltonville Sch of Arts & Sciences",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000054",
    },
    {
        "school": "Cayuga School",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000105",
    },
    {
        "school": "Overbrook Elementary School",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000237",
    },
    {
        "school": "Marshall Thurgood",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000329",
    },
    {
        "school": "Munoz-Marin Luis",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000331",
    },
    {
        "school": "Washington Grover Jr Sch",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000549",
    },
    {
        "school": "Gamp",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000551",
    },
    {
        "school": "Swenson Arts & Technology HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "421899000572",
    },
    {
        "school": "Penn Alexander Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899000619",
    },
    {
        "school": "Bryant William C Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003601",
    },
    {
        "school": "Catharine Joseph Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003602",
    },
    {
        "school": "McMichael Morton Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003611",
    },
    {
        "school": "Patterson John M Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003613",
    },
    {
        "school": "Rhoads James Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003614",
    },
    {
        "school": "Washington Martha Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003615",
    },
    {
        "school": "Penrose Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003616",
    },
    {
        "school": "Bache-Martin Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003618",
    },
    {
        "school": "Bregy F Amedee Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003620",
    },
    {
        "school": "Childs George W Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003622",
    },
    {
        "school": "Gideon Edward Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003625",
    },
    {
        "school": "Kelley William D Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003626",
    },
    {
        "school": "McDaniel Delaplaine Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003629",
    },
    {
        "school": "Meade Gen George C Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003630",
    },
    {
        "school": "Stanton Edwin M Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003635",
    },
    {
        "school": "Waring Laura W Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003636",
    },
    {
        "school": "Fell D Newlin Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003639",
    },
    {
        "school": "Jackson Andrew Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003642",
    },
    {
        "school": "Jenks Abram Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003644",
    },
    {
        "school": "Kearny Gen Philip Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003645",
    },
    {
        "school": "Key Francis Scott Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003646",
    },
    {
        "school": "Kirkbride Eliza B Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003647",
    },
    {
        "school": "McCall Gen George A Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003648",
    },
    {
        "school": "Meredith William M Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003649",
    },
    {
        "school": "Nebinger George W Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003650",
    },
    {
        "school": "Sharswood George Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003653",
    },
    {
        "school": "Southwark Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003654",
    },
    {
        "school": "Spring Garden Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003655",
    },
    {
        "school": "Taggart John H Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003657",
    },
    {
        "school": "Blaine James G Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003662",
    },
    {
        "school": "Blankenburg Rudolph Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003663",
    },
    {
        "school": "Lewis C Cassidy Academics Plus Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003664",
    },
    {
        "school": "Samuel Gompers Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003668",
    },
    {
        "school": "Lamberton Robert E Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003670",
    },
    {
        "school": "Peirce Thomas M Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003675",
    },
    {
        "school": "Brown Henry A Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003684",
    },
    {
        "school": "Dunbar Paul L Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003687",
    },
    {
        "school": "Elkin Lewis Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003688",
    },
    {
        "school": "Hunter William H Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003693",
    },
    {
        "school": "Ludlow James R Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003694",
    },
    {
        "school": "Moffet John Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003697",
    },
    {
        "school": "Richmond Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003701",
    },
    {
        "school": "Sheppard Isaac Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003702",
    },
    {
        "school": "Welsh John Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003703",
    },
    {
        "school": "Day Anna B Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003706",
    },
    {
        "school": "Franklin S Edmonds Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003708",
    },
    {
        "school": "Emlen Eleanor C Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003709",
    },
    {
        "school": "Hill Freedman World Academy",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003711",
    },
    {
        "school": "Henry Charles W Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003712",
    },
    {
        "school": "Houston Henry E Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003713",
    },
    {
        "school": "John Story Jenks Academy for the Arts an",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003714",
    },
    {
        "school": "Lingelbach Anna L Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003717",
    },
    {
        "school": "Logan James Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003718",
    },
    {
        "school": "McCloskey John F Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003719",
    },
    {
        "school": "Mifflin Thomas Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003720",
    },
    {
        "school": "Pennell Joseph Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003722",
    },
    {
        "school": "Rowen William Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003724",
    },
    {
        "school": "Shawmont Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003725",
    },
    {
        "school": "Dobson James Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003726",
    },
    {
        "school": "Steel Edward Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003727",
    },
    {
        "school": "Widener Memorial Sch",
        "district": "Philadelphia City SD",
        "level": "Other",
        "type": "Special education school",
        "state": "PA",
        "nces_id": "421899003728",
    },
    {
        "school": "Barton Clara Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003732",
    },
    {
        "school": "Carnell Laura H Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003734",
    },
    {
        "school": "Ellwood Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003738",
    },
    {
        "school": "Finletter Thomas K Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003739",
    },
    {
        "school": "Hopkinson Francis Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003742",
    },
    {
        "school": "Howe Julia Ward Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003743",
    },
    {
        "school": "Lawton Henry W Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003744",
    },
    {
        "school": "Bridesburg Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003745",
    },
    {
        "school": "Lowell James R Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003746",
    },
    {
        "school": "Morrison Andrew J Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003749",
    },
    {
        "school": "Olney El Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003750",
    },
    {
        "school": "Feltonville Intermediate School",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003751",
    },
    {
        "school": "Sullivan James J Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003753",
    },
    {
        "school": "Ziegler William H Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003754",
    },
    {
        "school": "Taylor Bayard Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003755",
    },
    {
        "school": "Allen Ethan Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003758",
    },
    {
        "school": "Comly Watson Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003760",
    },
    {
        "school": "Crossan Kennedy C Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003762",
    },
    {
        "school": "Disston Hamilton Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003763",
    },
    {
        "school": "Forrest Edwin Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003764",
    },
    {
        "school": "Fox Chase Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003765",
    },
    {
        "school": "Holme Thomas Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003766",
    },
    {
        "school": "Mayfair Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003769",
    },
    {
        "school": "Moore J Hampton Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003770",
    },
    {
        "school": "Rhawnhurst Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003771",
    },
    {
        "school": "Solis-Cohen Solomon Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003773",
    },
    {
        "school": "Spruance Gilbert Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003774",
    },
    {
        "school": "Girard Stephen Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003776",
    },
    {
        "school": "Farrell Louis H Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003779",
    },
    {
        "school": "Fitzpatrick Aloysius L Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003781",
    },
    {
        "school": "Comegys Benjamin B Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003782",
    },
    {
        "school": "Powel Samuel Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003783",
    },
    {
        "school": "Dick William Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003786",
    },
    {
        "school": "Marshall John Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003797",
    },
    {
        "school": "Mitchell El Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003798",
    },
    {
        "school": "Sheridan Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003800",
    },
    {
        "school": "Pollock Robert B Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003801",
    },
    {
        "school": "Frank Anne Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003803",
    },
    {
        "school": "Anderson Add B Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003804",
    },
    {
        "school": "Arthur Chester A Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003805",
    },
    {
        "school": "Masterman Julia R Sec Sch",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003808",
    },
    {
        "school": "Cooke Jay MS",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003815",
    },
    {
        "school": "Fels Samuel HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003816",
    },
    {
        "school": "Furness Horace HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003818",
    },
    {
        "school": "Harding Warren G MS",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003820",
    },
    {
        "school": "Sayre William L MS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003825",
    },
    {
        "school": "Wagner Gen Louis MS",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003835",
    },
    {
        "school": "Wilson Woodrow MS",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003836",
    },
    {
        "school": "Strawberry Mansion HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003839",
    },
    {
        "school": "Dobbins AVT HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "421899003841",
    },
    {
        "school": "Mastbaum Jules E AVTS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "421899003842",
    },
    {
        "school": "Girls HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003843",
    },
    {
        "school": "Roxborough HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003844",
    },
    {
        "school": "Lincoln HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003845",
    },
    {
        "school": "Bartram John - Main",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003847",
    },
    {
        "school": "Central HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003848",
    },
    {
        "school": "Edison HS/Fareira Skills",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "421899003849",
    },
    {
        "school": "Frankford HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003850",
    },
    {
        "school": "Franklin Benjamin HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003851",
    },
    {
        "school": "Northeast HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003855",
    },
    {
        "school": "Overbrook HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003857",
    },
    {
        "school": "South Philadelphia HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003859",
    },
    {
        "school": "West Philadelphia HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899003860",
    },
    {
        "school": "Saul W B Agricultural School",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "421899003861",
    },
    {
        "school": "Greenberg Joseph Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899004726",
    },
    {
        "school": "Decatur Stephen Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899004727",
    },
    {
        "school": "Locke Alain Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899004732",
    },
    {
        "school": "Morris Robert Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899004868",
    },
    {
        "school": "Loesche William H Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899004961",
    },
    {
        "school": "Stearne Allen M Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899004963",
    },
    {
        "school": "Duckrey Tanner Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005040",
    },
    {
        "school": "John Hancock Demonstration Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005041",
    },
    {
        "school": "Hackett Horatio B Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005120",
    },
    {
        "school": "Potter-Thomas Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005121",
    },
    {
        "school": "Cook-Wissahickon Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005122",
    },
    {
        "school": "Cramp William Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005123",
    },
    {
        "school": "Webster Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005124",
    },
    {
        "school": "Hartranft John F Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005125",
    },
    {
        "school": "Bethune Mary McLeod Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005183",
    },
    {
        "school": "Hamilton Andrew Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005185",
    },
    {
        "school": "Greenfield Albert M Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005186",
    },
    {
        "school": "Heston Edward Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005187",
    },
    {
        "school": "Wright Richard R Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005188",
    },
    {
        "school": "Allen Dr Ethel Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005292",
    },
    {
        "school": "McKinley William Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005293",
    },
    {
        "school": "Kelly John B Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899005294",
    },
    {
        "school": "Adaire Alexander Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006524",
    },
    {
        "school": "Conwell Russell MS",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006525",
    },
    {
        "school": "Washington George HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006527",
    },
    {
        "school": "Harrington Avery D Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006528",
    },
    {
        "school": "Brown Joseph H Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006529",
    },
    {
        "school": "Lea Henry C Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006530",
    },
    {
        "school": "Longstreth William C Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006533",
    },
    {
        "school": "McClure Alexander K Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006534",
    },
    {
        "school": "Morton Thomas G Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006535",
    },
    {
        "school": "Samuel Pennypacker Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006539",
    },
    {
        "school": "Willard Frances E Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006544",
    },
    {
        "school": "Parkway Northwest",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006548",
    },
    {
        "school": "King Martin Luther HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006675",
    },
    {
        "school": "Prince Hall",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006765",
    },
    {
        "school": "Clemente Roberto MS",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006767",
    },
    {
        "school": "Meehan Austin MS",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006768",
    },
    {
        "school": "Franklin LC",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006822",
    },
    {
        "school": "Amy At Martin",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006823",
    },
    {
        "school": "Baldi C C A MS",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006824",
    },
    {
        "school": "Fitler Academics Plus",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006913",
    },
    {
        "school": "Overbrook Edu Ctr",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006960",
    },
    {
        "school": "Creative and Performing Arts",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006996",
    },
    {
        "school": "Carver HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007023",
    },
    {
        "school": "Middle Years Alternative",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007223",
    },
    {
        "school": "Amy NW",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007224",
    },
    {
        "school": "Bodine William W HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007225",
    },
    {
        "school": "DeBurgos Bilingual Magnet MS",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007229",
    },
    {
        "school": "Franklin Benjamin Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899010014",
    },
    {
        "school": "City CHS",
        "district": "City CHS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420009400663",
    },
    {
        "school": "Propel CS-Homestead",
        "district": "Propel CS-Homestead",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420011100749",
    },
    {
        "school": "The New Academy CS",
        "district": "The New Academy CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420013300866",
    },
    {
        "school": "Propel CS-McKeesport",
        "district": "Propel CS-McKeesport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420013400867",
    },
    {
        "school": "Propel CS-East",
        "district": "Propel CS-East",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420013500869",
    },
    {
        "school": "Pittsburgh Roosevelt K -5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000684",
    },
    {
        "school": "South Allegheny El Sch",
        "district": "South Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422191000693",
    },
    {
        "school": "Donaldson Elem Sch",
        "district": "West Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422520000707",
    },
    {
        "school": "Apollo-Ridge Elem Sch",
        "district": "Apollo-Ridge SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420255000779",
    },
    {
        "school": "Highland El Sch",
        "district": "Ambridge Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420244000800",
    },
    {
        "school": "Dutch Ridge El Sch",
        "district": "Beaver Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420312000842",
    },
    {
        "school": "Central El Sch",
        "district": "Big Beaver Falls Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420363000799",
    },
    {
        "school": "South Butler Primary Sch",
        "district": "South Butler County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422193000645",
    },
    {
        "school": "South Butler Intermediate EL Sch",
        "district": "South Butler County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422193000646",
    },
    {
        "school": "California Area El Sch",
        "district": "California Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420471000813",
    },
    {
        "school": "North Strabane Intrmd Sch",
        "district": "Canon-McMillan SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420489000717",
    },
    {
        "school": "Mount Pleasant Area JHS",
        "district": "Mount Pleasant Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421617000790",
    },
    {
        "school": "Sunset Valley El Sch",
        "district": "Norwin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421794000644",
    },
    {
        "school": "Sheridan Terrace El Sch",
        "district": "Norwin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421794000704",
    },
    {
        "school": "Hillcrest Intermediate Sch",
        "district": "Norwin SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421794000705",
    },
    {
        "school": "Apollo-Ridge HS",
        "district": "Apollo-Ridge SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420255002320",
    },
    {
        "school": "Apollo-Ridge MS",
        "district": "Apollo-Ridge SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420255006570",
    },
    {
        "school": "West Shamokin JSHS",
        "district": "Armstrong SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420259000517",
    },
    {
        "school": "Dayton El Sch",
        "district": "Armstrong SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420259000569",
    },
    {
        "school": "Lenape El Sch",
        "district": "Armstrong SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420259005002",
    },
    {
        "school": "Elderton El Sch",
        "district": "Armstrong SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420259006574",
    },
    {
        "school": "Shannock Valley El Sch",
        "district": "Armstrong SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420259006577",
    },
    {
        "school": "Lenape Tech",
        "district": "Lenape Tech",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "420260004807",
    },
    {
        "school": "David Leech El Sch",
        "district": "Leechburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421347006579",
    },
    {
        "school": "Manchester Academic CS",
        "district": "Manchester Academic CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420001700336",
    },
    {
        "school": "Urban Pathways 6-12 CS",
        "district": "Urban Pathways 6-12 CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420001800337",
    },
    {
        "school": "Urban Academy of Greater Pittsburgh CS",
        "district": "Urban Academy of Greater Pittsburgh CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420001900338",
    },
    {
        "school": "Spectrum CS",
        "district": "Spectrum CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420006400530",
    },
    {
        "school": "Springdale JSHS",
        "district": "Allegheny Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420219000029",
    },
    {
        "school": "Acmetonia El Sch",
        "district": "Allegheny Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420219005296",
    },
    {
        "school": "Avonworth El Sch",
        "district": "Avonworth SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420282000034",
    },
    {
        "school": "Avonworth MS",
        "district": "Avonworth SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420282000559",
    },
    {
        "school": "Avonworth HS",
        "district": "Avonworth SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420282005199",
    },
    {
        "school": "Richland El Sch",
        "district": "Pine-Richland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420285000111",
    },
    {
        "school": "Hance El Sch",
        "district": "Pine-Richland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420285000312",
    },
    {
        "school": "Wexford El Sch",
        "district": "Pine-Richland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420285000313",
    },
    {
        "school": "Pine-Richland MS",
        "district": "Pine-Richland SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420285000314",
    },
    {
        "school": "Pine-Richland HS",
        "district": "Pine-Richland SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420285000315",
    },
    {
        "school": "McAnnulty El Sch",
        "district": "Baldwin-Whitehall SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420297000037",
    },
    {
        "school": "Whitehall El Sch",
        "district": "Baldwin-Whitehall SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420297000048",
    },
    {
        "school": "Baldwin SHS",
        "district": "Baldwin-Whitehall SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420297000050",
    },
    {
        "school": "Paynter El Sch",
        "district": "Baldwin-Whitehall SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420297005194",
    },
    {
        "school": "Harrison MS",
        "district": "Baldwin-Whitehall SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420297006787",
    },
    {
        "school": "Bethel Memorial El Sch",
        "district": "Bethel Park SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420351000055",
    },
    {
        "school": "William Penn El Sch",
        "district": "Bethel Park SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420351000060",
    },
    {
        "school": "Independence MS",
        "district": "Bethel Park SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420351000061",
    },
    {
        "school": "Bethel Park HS",
        "district": "Bethel Park SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420351000062",
    },
    {
        "school": "Abraham Lincoln El Sch",
        "district": "Bethel Park SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420351004802",
    },
    {
        "school": "George Washington El Sch",
        "district": "Bethel Park SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420351004902",
    },
    {
        "school": "Benjamin Franklin El Sch",
        "district": "Bethel Park SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420351009977",
    },
    {
        "school": "Neil Armstrong 5-6 MS",
        "district": "Bethel Park SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420351009978",
    },
    {
        "school": "Moore Sch",
        "district": "Brentwood Borough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420414000068",
    },
    {
        "school": "Elroy Avenue El Sch",
        "district": "Brentwood Borough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420414000069",
    },
    {
        "school": "Brentwood SHS",
        "district": "Brentwood Borough SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420414000070",
    },
    {
        "school": "Brentwood MS",
        "district": "Brentwood Borough SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420414009979",
    },
    {
        "school": "Carnegie El Sch",
        "district": "Carlynton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420504000077",
    },
    {
        "school": "Crafton El Sch",
        "district": "Carlynton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420504000078",
    },
    {
        "school": "Carlynton JSHS",
        "district": "Carlynton SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420504000079",
    },
    {
        "school": "Chartiers Valley MS",
        "district": "Chartiers Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420570000094",
    },
    {
        "school": "Chartiers Valley Intrmd School",
        "district": "Chartiers Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420570000114",
    },
    {
        "school": "Chartiers Valley Primary Sch",
        "district": "Chartiers Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420570000194",
    },
    {
        "school": "Chartiers Valley HS",
        "district": "Chartiers Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420570006706",
    },
    {
        "school": "Clairton El Sch",
        "district": "Clairton City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420603000063",
    },
    {
        "school": "Cornell El Sch",
        "district": "Cornell SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420681006944",
    },
    {
        "school": "Deer Lakes MS",
        "district": "Deer Lakes SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420754000431",
    },
    {
        "school": "Deer Lakes HS",
        "district": "Deer Lakes SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420754000513",
    },
    {
        "school": "East Union Intrmd Sch",
        "district": "Deer Lakes SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420754006695",
    },
    {
        "school": "Curtisville Pri Ctr",
        "district": "Deer Lakes SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420754009947",
    },
    {
        "school": "Central El Sch",
        "district": "Elizabeth Forward SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420909000136",
    },
    {
        "school": "William Penn El Sch",
        "district": "Elizabeth Forward SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420909000139",
    },
    {
        "school": "Mt Vernon El Sch",
        "district": "Elizabeth Forward SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420909000142",
    },
    {
        "school": "Elizabeth Forward SHS",
        "district": "Elizabeth Forward SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420909000144",
    },
    {
        "school": "Greenock El Sch",
        "district": "Elizabeth Forward SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420909000257",
    },
    {
        "school": "Elizabeth Forward MS",
        "district": "Elizabeth Forward SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420909004804",
    },
    {
        "school": "Dorseyville MS",
        "district": "Fox Chapel Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421007000147",
    },
    {
        "school": "Fairview El Sch",
        "district": "Fox Chapel Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421007000149",
    },
    {
        "school": "Kerr El Sch",
        "district": "Fox Chapel Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421007000153",
    },
    {
        "school": "Fox Chapel Area HS",
        "district": "Fox Chapel Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421007000156",
    },
    {
        "school": "OHara El Sch",
        "district": "Fox Chapel Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421007000461",
    },
    {
        "school": "Hartwood El Sch",
        "district": "Fox Chapel Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421007006780",
    },
    {
        "school": "Evergreen El Sch",
        "district": "Gateway SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421062000157",
    },
    {
        "school": "University Park El Sch",
        "district": "Gateway SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421062000165",
    },
    {
        "school": "Gateway MS",
        "district": "Gateway SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421062000167",
    },
    {
        "school": "Moss Side MS",
        "district": "Gateway SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421062000169",
    },
    {
        "school": "Gateway SHS",
        "district": "Gateway SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421062000170",
    },
    {
        "school": "Ramsey El Sch",
        "district": "Gateway SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421062005191",
    },
    {
        "school": "Dr Cleveland Steward Jr El Sch",
        "district": "Gateway SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421062009980",
    },
    {
        "school": "Central El Sch",
        "district": "Hampton Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421140000175",
    },
    {
        "school": "Wyland El Sch",
        "district": "Hampton Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421140000176",
    },
    {
        "school": "Poff El Sch",
        "district": "Hampton Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421140000178",
    },
    {
        "school": "Hampton MS",
        "district": "Hampton Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421140000179",
    },
    {
        "school": "Hampton HS",
        "district": "Hampton Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421140005190",
    },
    {
        "school": "Highlands Early Childhood Center",
        "district": "Highlands SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421188000182",
    },
    {
        "school": "Highlands El Sch",
        "district": "Highlands SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421188000191",
    },
    {
        "school": "Highlands SHS",
        "district": "Highlands SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421188005153",
    },
    {
        "school": "Highlands MS",
        "district": "Highlands SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421188007275",
    },
    {
        "school": "Dormont El Sch",
        "district": "Keystone Oaks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421275000195",
    },
    {
        "school": "Keystone Oaks MS",
        "district": "Keystone Oaks SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421275000197",
    },
    {
        "school": "Fred L Aiken El Sch",
        "district": "Keystone Oaks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421275000203",
    },
    {
        "school": "Myrtle Ave Sch",
        "district": "Keystone Oaks SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421275000204",
    },
    {
        "school": "Keystone Oaks HS",
        "district": "Keystone Oaks SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421275005112",
    },
    {
        "school": "Founders Hall Middle Sch",
        "district": "McKeesport Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421494000565",
    },
    {
        "school": "McKeesport Area SHS",
        "district": "McKeesport Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421494006105",
    },
    {
        "school": "Montour HS",
        "district": "Montour SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421572005017",
    },
    {
        "school": "J H Brooks El Sch",
        "district": "Moon Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421583000148",
    },
    {
        "school": "Bon Meade El Sch",
        "district": "Moon Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421583000240",
    },
    {
        "school": "Moon SHS",
        "district": "Moon Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421583004951",
    },
    {
        "school": "Washington El Sch",
        "district": "Mt Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421611000245",
    },
    {
        "school": "Lincoln El Sch",
        "district": "Mt Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421611000246",
    },
    {
        "school": "Markham El Sch",
        "district": "Mt Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421611000247",
    },
    {
        "school": "Howe El Sch",
        "district": "Mt Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421611000248",
    },
    {
        "school": "Foster El Sch",
        "district": "Mt Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421611000249",
    },
    {
        "school": "Jefferson El Sch",
        "district": "Mt Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421611000250",
    },
    {
        "school": "Hoover El Sch",
        "district": "Mt Lebanon SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421611000251",
    },
    {
        "school": "Mt Lebanon SHS",
        "district": "Mt Lebanon SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421611000254",
    },
    {
        "school": "Mellon MS",
        "district": "Mt Lebanon SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421611000339",
    },
    {
        "school": "Jefferson MS",
        "district": "Mt Lebanon SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421611000340",
    },
    {
        "school": "Edgewood El STEAM Academy",
        "district": "Woodland Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421650007015",
    },
    {
        "school": "Wilkins El STEAM Academy",
        "district": "Woodland Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421650007022",
    },
    {
        "school": "Woodland Hills HS",
        "district": "Woodland Hills SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421650007214",
    },
    {
        "school": "Marshall El Sch",
        "district": "North Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421701000023",
    },
    {
        "school": "Marshall MS",
        "district": "North Allegheny SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421701000080",
    },
    {
        "school": "Bradford Woods El Sch",
        "district": "North Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421701000263",
    },
    {
        "school": "Franklin El Sch",
        "district": "North Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421701000265",
    },
    {
        "school": "Ingomar El Sch",
        "district": "North Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421701000266",
    },
    {
        "school": "McKnight El Sch",
        "district": "North Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421701000268",
    },
    {
        "school": "Peebles El Sch",
        "district": "North Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421701000269",
    },
    {
        "school": "Ingomar MS",
        "district": "North Allegheny SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421701000270",
    },
    {
        "school": "Carson MS",
        "district": "North Allegheny SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421701005108",
    },
    {
        "school": "Hosack El Sch",
        "district": "North Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421701006603",
    },
    {
        "school": "McIntyre El Sch",
        "district": "North Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421722000004",
    },
    {
        "school": "West View El Sch",
        "district": "North Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421722000290",
    },
    {
        "school": "Ross El Sch",
        "district": "North Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421722000291",
    },
    {
        "school": "North Hills MS",
        "district": "North Hills SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421722006106",
    },
    {
        "school": "North Hills SHS",
        "district": "North Hills SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421722007122",
    },
    {
        "school": "Avalon El Sch",
        "district": "Northgate SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421777000030",
    },
    {
        "school": "Northgate MSHS",
        "district": "Northgate SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421777000053",
    },
    {
        "school": "Bellevue El Sch",
        "district": "Northgate SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421777006977",
    },
    {
        "school": "Penn Hills SHS",
        "district": "Penn Hills SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421859000309",
    },
    {
        "school": "Linton MS",
        "district": "Penn Hills SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421859005019",
    },
    {
        "school": "Pittsburgh Spring Hill K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000045",
    },
    {
        "school": "Pittsburgh Banksville K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000253",
    },
    {
        "school": "Pittsburgh Woolslair K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000255",
    },
    {
        "school": "Pittsburgh Carmalt K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000326",
    },
    {
        "school": "Pittsburgh Concord K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000330",
    },
    {
        "school": "Pittsburgh Montessori K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000351",
    },
    {
        "school": "Pittsburgh Minadeo K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000363",
    },
    {
        "school": "Pittsburgh Morrow K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000365",
    },
    {
        "school": "Pittsburgh Phillips K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000395",
    },
    {
        "school": "Pittsburgh Grandview K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000400",
    },
    {
        "school": "Pittsburgh Allderdice HS",
        "district": "Pittsburgh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000409",
    },
    {
        "school": "Pittsburgh Carrick HS",
        "district": "Pittsburgh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000412",
    },
    {
        "school": "Pittsburgh Allegheny K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000413",
    },
    {
        "school": "Pittsburgh Allegheny 6-8",
        "district": "Pittsburgh SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000414",
    },
    {
        "school": "Pittsburgh Perry HS",
        "district": "Pittsburgh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000416",
    },
    {
        "school": "Pittsburgh Classical 6-8",
        "district": "Pittsburgh SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000598",
    },
    {
        "school": "Pittsburgh South Brook 6-8",
        "district": "Pittsburgh SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000599",
    },
    {
        "school": "Pittsburgh West Liberty K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917000600",
    },
    {
        "school": "Pittsburgh Beechwood K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006019",
    },
    {
        "school": "Pittsburgh Colfax K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006022",
    },
    {
        "school": "Pittsburgh Dilworth K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006024",
    },
    {
        "school": "Pittsburgh Fulton K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006026",
    },
    {
        "school": "Pittsburgh Greenfield K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006028",
    },
    {
        "school": "Pittsburgh Liberty K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006042",
    },
    {
        "school": "Pittsburgh Linden K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006044",
    },
    {
        "school": "Pittsburgh Oliver",
        "district": "Pittsburgh SD",
        "level": "Other",
        "type": "Special education school",
        "state": "PA",
        "nces_id": "421917006047",
    },
    {
        "school": "Pittsburgh Pioneer",
        "district": "Pittsburgh SD",
        "level": "Other",
        "type": "Special education school",
        "state": "PA",
        "nces_id": "421917006664",
    },
    {
        "school": "Pittsburgh Conroy",
        "district": "Pittsburgh SD",
        "level": "Other",
        "type": "Special education school",
        "state": "PA",
        "nces_id": "421917006811",
    },
    {
        "school": "Pittsburgh Brashear HS",
        "district": "Pittsburgh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006915",
    },
    {
        "school": "Pittsburgh Sterrett 6-8",
        "district": "Pittsburgh SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917007039",
    },
    {
        "school": "Pittsburgh Schiller 6-8",
        "district": "Pittsburgh SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917007132",
    },
    {
        "school": "Center El Sch",
        "district": "Plum Borough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421935000427",
    },
    {
        "school": "Plum SHS",
        "district": "Plum Borough SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421935000435",
    },
    {
        "school": "Oblock JHS",
        "district": "Plum Borough SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421935005105",
    },
    {
        "school": "Pivik El Sch",
        "district": "Plum Borough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421935007298",
    },
    {
        "school": "Quaker Valley MS",
        "district": "Quaker Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421986000447",
    },
    {
        "school": "Quaker Valley HS",
        "district": "Quaker Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421986000448",
    },
    {
        "school": "Edgeworth El Sch",
        "district": "Quaker Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421986006108",
    },
    {
        "school": "Osborne El Sch",
        "district": "Quaker Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421986006852",
    },
    {
        "school": "Tenth Street El Sch",
        "district": "Riverview SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422043000295",
    },
    {
        "school": "Verner El Sch",
        "district": "Riverview SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422043006109",
    },
    {
        "school": "Riverview JSHS",
        "district": "Riverview SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422043006928",
    },
    {
        "school": "South Fayette MS",
        "district": "South Fayette Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422058000258",
    },
    {
        "school": "South Fayette Twp El Sch",
        "district": "South Fayette Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422058000468",
    },
    {
        "school": "South Fayette Twp HS",
        "district": "South Fayette Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422058000470",
    },
    {
        "school": "Scott Primary Sch",
        "district": "Shaler Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422120000458",
    },
    {
        "school": "Shaler Area HS",
        "district": "Shaler Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422120000460",
    },
    {
        "school": "Burchfield Primary Sch",
        "district": "Shaler Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422120004696",
    },
    {
        "school": "Reserve Primary Sch",
        "district": "Shaler Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422120004843",
    },
    {
        "school": "Marzolf Primary Sch",
        "district": "Shaler Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422120005101",
    },
    {
        "school": "South Park SHS",
        "district": "South Park SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422206000467",
    },
    {
        "school": "South Park Elem Center",
        "district": "South Park SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422206000583",
    },
    {
        "school": "South Park MS",
        "district": "South Park SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422206006906",
    },
    {
        "school": "Barrett El Sch",
        "district": "Steel Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422279000193",
    },
    {
        "school": "Steel Valley SHS",
        "district": "Steel Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422279000196",
    },
    {
        "school": "Park El Sch",
        "district": "Steel Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422279000259",
    },
    {
        "school": "Steel Valley MS",
        "district": "Steel Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422279000260",
    },
    {
        "school": "Sto-Rox Primary Ctr",
        "district": "Sto-Rox SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422283000261",
    },
    {
        "school": "Sto-Rox JSHS",
        "district": "Sto-Rox SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422283000477",
    },
    {
        "school": "Eisenhower El Sch",
        "district": "Upper Saint Clair SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422457000490",
    },
    {
        "school": "Fort Couch MS",
        "district": "Upper Saint Clair SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422457000491",
    },
    {
        "school": "Upper Saint Clair HS",
        "district": "Upper Saint Clair SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422457000492",
    },
    {
        "school": "Streams El Sch",
        "district": "Upper Saint Clair SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422457004859",
    },
    {
        "school": "Baker El Sch",
        "district": "Upper Saint Clair SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422457005195",
    },
    {
        "school": "Boyce MS",
        "district": "Upper Saint Clair SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422457005196",
    },
    {
        "school": "West Allegheny SHS",
        "district": "West Allegheny SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422520000509",
    },
    {
        "school": "McKee El Sch",
        "district": "West Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422520005366",
    },
    {
        "school": "Wilson El Sch",
        "district": "West Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422520005367",
    },
    {
        "school": "West Allegheny MS",
        "district": "West Allegheny SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422520006895",
    },
    {
        "school": "Jefferson Hills Intermediate Sch",
        "district": "West Jefferson Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422559000081",
    },
    {
        "school": "Gill Hall El Sch",
        "district": "West Jefferson Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422559000516",
    },
    {
        "school": "McClellan El Sch",
        "district": "West Jefferson Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422559000519",
    },
    {
        "school": "Thomas Jefferson HS",
        "district": "West Jefferson Hills SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422559000523",
    },
    {
        "school": "Pleasant Hills MS",
        "district": "West Jefferson Hills SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422559004867",
    },
    {
        "school": "Clara Barton El Sch",
        "district": "West Mifflin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422568000528",
    },
    {
        "school": "West Mifflin Area MS",
        "district": "West Mifflin Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422568000535",
    },
    {
        "school": "West Mifflin Area HS",
        "district": "West Mifflin Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422568000536",
    },
    {
        "school": "Turner Intermediate Sch",
        "district": "Wilkinsburg Borough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422637000553",
    },
    {
        "school": "Kelly Primary Sch",
        "district": "Wilkinsburg Borough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422637005106",
    },
    {
        "school": "A W Beattie Career Center",
        "district": "A W Beattie Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428001007041",
    },
    {
        "school": "Forbes Road CTC",
        "district": "Forbes Road CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428002007042",
    },
    {
        "school": "McKeesport Area Tech Ctr",
        "district": "McKeesport Area Tech Ctr",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428003007043",
    },
    {
        "school": "Parkway West CTC",
        "district": "Parkway West CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428004007252",
    },
    {
        "school": "Steel Center for Career and Technical Ed",
        "district": "Steel Center for Career and Technical Education",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428005007045",
    },
    {
        "school": "Sugarcreek El Sch",
        "district": "Karns City Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420960000083",
    },
    {
        "school": "South Buffalo El Sch",
        "district": "Freeport Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421044000592",
    },
    {
        "school": "Freeport Area SHS",
        "district": "Freeport Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421044000594",
    },
    {
        "school": "Pennsylvania Cyber CS",
        "district": "Pennsylvania Cyber CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420007100534",
    },
    {
        "school": "Aliquippa El Sch",
        "district": "Aliquippa SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420213000615",
    },
    {
        "school": "Economy El Sch",
        "district": "Ambridge Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420244000629",
    },
    {
        "school": "State Street El Sch",
        "district": "Ambridge Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420244000632",
    },
    {
        "school": "Ambridge Area MS",
        "district": "Ambridge Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420244000633",
    },
    {
        "school": "Ambridge Area HS",
        "district": "Ambridge Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420244006555",
    },
    {
        "school": "Beaver Area MS",
        "district": "Beaver Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420312000106",
    },
    {
        "school": "College Square El Sch",
        "district": "Beaver Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420312000639",
    },
    {
        "school": "Beaver Area SHS",
        "district": "Beaver Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420312000640",
    },
    {
        "school": "Beaver Falls MS",
        "district": "Big Beaver Falls Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420363000648",
    },
    {
        "school": "Beaver Falls Area SHS",
        "district": "Big Beaver Falls Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420363000649",
    },
    {
        "school": "Big Beaver El Sch",
        "district": "Big Beaver Falls Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420363000650",
    },
    {
        "school": "Highland MS",
        "district": "Blackhawk SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420368806558",
    },
    {
        "school": "Northwestern Primary Sch",
        "district": "Blackhawk SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420368806559",
    },
    {
        "school": "Patterson Primary Sch",
        "district": "Blackhawk SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420368806560",
    },
    {
        "school": "Blackhawk HS",
        "district": "Blackhawk SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420368806707",
    },
    {
        "school": "Blackhawk Intermediate Sch",
        "district": "Blackhawk SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420368807154",
    },
    {
        "school": "Freedom Area SHS",
        "district": "Freedom Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421038006563",
    },
    {
        "school": "Independence El Sch",
        "district": "Hopewell Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421203000671",
    },
    {
        "school": "Hopewell El Sch",
        "district": "Hopewell Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421203000672",
    },
    {
        "school": "Hopewell JHS",
        "district": "Hopewell Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421203000674",
    },
    {
        "school": "Hopewell SHS",
        "district": "Hopewell Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421203000675",
    },
    {
        "school": "Margaret Ross El Sch",
        "district": "Hopewell Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421203009954",
    },
    {
        "school": "Midland El/MS",
        "district": "Midland Borough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421527006566",
    },
    {
        "school": "New Brighton Area MS",
        "district": "New Brighton Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421653000694",
    },
    {
        "school": "New Brighton Area HS",
        "district": "New Brighton Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421653000695",
    },
    {
        "school": "New Brighton Area El Sch",
        "district": "New Brighton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421653006720",
    },
    {
        "school": "Riverside HS",
        "district": "Riverside Beaver County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421743000700",
    },
    {
        "school": "Rochester High School",
        "district": "Rochester Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422046000712",
    },
    {
        "school": "Rochester Area El Sch",
        "district": "Rochester Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422046010017",
    },
    {
        "school": "South Side HS",
        "district": "South Side Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422223000714",
    },
    {
        "school": "South Side El Sch",
        "district": "South Side Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422223006568",
    },
    {
        "school": "South Side MS",
        "district": "South Side Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422223006937",
    },
    {
        "school": "Fairview El Sch",
        "district": "Western Beaver County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422604000715",
    },
    {
        "school": "Western Beaver Co JSHS",
        "district": "Western Beaver County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422604000719",
    },
    {
        "school": "Beaver County CTC",
        "district": "Beaver County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428050007095",
    },
    {
        "school": "Emily Brittain El Sch",
        "district": "Butler Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420459001134",
    },
    {
        "school": "Mcquistion El Sch",
        "district": "Butler Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420459001138",
    },
    {
        "school": "Northwest El Sch",
        "district": "Butler Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420459001142",
    },
    {
        "school": "Center Twp Sch",
        "district": "Butler Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420459001148",
    },
    {
        "school": "Connoquenessing El Sch",
        "district": "Butler Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420459001150",
    },
    {
        "school": "Summit El Sch",
        "district": "Butler Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420459001184",
    },
    {
        "school": "Butler Area IHS",
        "district": "Butler Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420459006690",
    },
    {
        "school": "Chicora El Sch",
        "district": "Karns City Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420960001153",
    },
    {
        "school": "Karns City HS",
        "district": "Karns City Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420960001154",
    },
    {
        "school": "Buffalo El Sch",
        "district": "Freeport Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421044000591",
    },
    {
        "school": "Mars Area El Sch",
        "district": "Mars Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421479001155",
    },
    {
        "school": "Mars Area Primary Ctr",
        "district": "Mars Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421479001158",
    },
    {
        "school": "Mars Area SHS",
        "district": "Mars Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421479001159",
    },
    {
        "school": "Mars Area MS",
        "district": "Mars Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421479005363",
    },
    {
        "school": "Moniteau JSHS",
        "district": "Moniteau SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421710001164",
    },
    {
        "school": "Dassa McKinney El Sch",
        "district": "Moniteau SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421710006605",
    },
    {
        "school": "Moraine El Sch",
        "district": "Slippery Rock Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422166001169",
    },
    {
        "school": "Slippery Rock Area El Sch",
        "district": "Slippery Rock Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422166001171",
    },
    {
        "school": "Slippery Rock Area HS",
        "district": "Slippery Rock Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422166001172",
    },
    {
        "school": "Slippery Rock Area MS",
        "district": "Slippery Rock Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422166006647",
    },
    {
        "school": "Knoch MS",
        "district": "South Butler County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422193000198",
    },
    {
        "school": "Knoch HS",
        "district": "South Butler County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422193001177",
    },
    {
        "school": "Evans City MS",
        "district": "Seneca Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422244000262",
    },
    {
        "school": "Haine MS",
        "district": "Seneca Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422244000267",
    },
    {
        "school": "Connoquenessing Valley El Sch",
        "district": "Seneca Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422244001178",
    },
    {
        "school": "Rowan El Sch",
        "district": "Seneca Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422244001179",
    },
    {
        "school": "Evans City El Sch",
        "district": "Seneca Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422244001180",
    },
    {
        "school": "Haine El Sch",
        "district": "Seneca Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422244004907",
    },
    {
        "school": "Ryan Gloyer MS",
        "district": "Seneca Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422244005311",
    },
    {
        "school": "Butler County AVTS",
        "district": "Butler County AVTS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428052007097",
    },
    {
        "school": "Albert Gallatin North MS",
        "district": "Albert Gallatin Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420210000407",
    },
    {
        "school": "Albert Gallatin South MS",
        "district": "Albert Gallatin Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420210000408",
    },
    {
        "school": "George J Plava El Sch",
        "district": "Albert Gallatin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420210002129",
    },
    {
        "school": "Smithfield El Sch",
        "district": "Albert Gallatin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420210004921",
    },
    {
        "school": "Friendship Hill El Sch",
        "district": "Albert Gallatin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420210004922",
    },
    {
        "school": "Albert Gallatin Area SHS",
        "district": "Albert Gallatin Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420210006001",
    },
    {
        "school": "Masontown El Sch",
        "district": "Albert Gallatin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420210006002",
    },
    {
        "school": "Marion El Sch",
        "district": "Belle Vernon Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420321004328",
    },
    {
        "school": "Brownsville Area MS",
        "district": "Brownsville Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420408002154",
    },
    {
        "school": "Brownsville Area HS",
        "district": "Brownsville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420408004818",
    },
    {
        "school": "Bullskin El Sch",
        "district": "Connellsville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420666002097",
    },
    {
        "school": "Connellsville Area MS",
        "district": "Connellsville Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420666002105",
    },
    {
        "school": "Springfield El Sch",
        "district": "Connellsville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420666002172",
    },
    {
        "school": "West Crawford El Sch",
        "district": "Connellsville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420666004939",
    },
    {
        "school": "Dunbar Twp El Sch",
        "district": "Connellsville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420666005048",
    },
    {
        "school": "Connellsville Area SHS",
        "district": "Connellsville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420666005228",
    },
    {
        "school": "Frazier HS",
        "district": "Frazier SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421035002126",
    },
    {
        "school": "Frazier El Sch",
        "district": "Frazier SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421035006686",
    },
    {
        "school": "Frazier MS",
        "district": "Frazier SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421035007203",
    },
    {
        "school": "Clark El Sch",
        "district": "Laurel Highlands SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421332002146",
    },
    {
        "school": "Hatfield El Sch",
        "district": "Laurel Highlands SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421332002163",
    },
    {
        "school": "Hutchinson El Sch",
        "district": "Laurel Highlands SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421332004700",
    },
    {
        "school": "Marshall El Sch",
        "district": "Laurel Highlands SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421332004820",
    },
    {
        "school": "Laurel Highlands MS",
        "district": "Laurel Highlands SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421332005146",
    },
    {
        "school": "Laurel Highlands SHS",
        "district": "Laurel Highlands SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421332006600",
    },
    {
        "school": "Marclay Sch",
        "district": "Uniontown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422415002137",
    },
    {
        "school": "Menallen Sch",
        "district": "Uniontown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422415002139",
    },
    {
        "school": "Ben Franklin Sch",
        "district": "Uniontown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422415002182",
    },
    {
        "school": "Uniontown Area SHS",
        "district": "Uniontown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422415002184",
    },
    {
        "school": "Wharton Sch",
        "district": "Uniontown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422415002185",
    },
    {
        "school": "Franklin Sch",
        "district": "Uniontown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422415006007",
    },
    {
        "school": "A J McMullen Sch",
        "district": "Uniontown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422415006933",
    },
    {
        "school": "Connellsville Area Career & Technical Ce",
        "district": "Connellsville Area Career & Technical Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428022007066",
    },
    {
        "school": "Fayette County Career & Technical Instit",
        "district": "Fayette County Career & Technical Institute",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428056007099",
    },
    {
        "school": "Avella Area JSHS",
        "district": "Avella Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420276004165",
    },
    {
        "school": "Avella El Center",
        "district": "Avella Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420276007118",
    },
    {
        "school": "Bentworth El Ctr",
        "district": "Bentworth SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420336000242",
    },
    {
        "school": "Bentworth SHS",
        "district": "Bentworth SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420336004188",
    },
    {
        "school": "Bentworth MS",
        "district": "Bentworth SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420336004189",
    },
    {
        "school": "Bethlehem-Center SHS",
        "district": "Bethlehem-Center SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420360004181",
    },
    {
        "school": "Bethlehem-Center MS",
        "district": "Bethlehem-Center SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420360005267",
    },
    {
        "school": "Bethlehem-Center El Sch",
        "district": "Bethlehem-Center SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420360006975",
    },
    {
        "school": "Burgettstown El Ctr",
        "district": "Burgettstown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420450000243",
    },
    {
        "school": "Burgettstown MS/HS",
        "district": "Burgettstown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420450004195",
    },
    {
        "school": "California Area SHS",
        "district": "California Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420471004203",
    },
    {
        "school": "California Area MS",
        "district": "California Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420471006939",
    },
    {
        "school": "Wylandville El Sch",
        "district": "Canon-McMillan SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420489004214",
    },
    {
        "school": "Canon-McMillan SHS",
        "district": "Canon-McMillan SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420489004217",
    },
    {
        "school": "South Central El",
        "district": "Canon-McMillan SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420489004937",
    },
    {
        "school": "Hills-Hendersonville El Sch",
        "district": "Canon-McMillan SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420489004938",
    },
    {
        "school": "Cecil Intrmd Sch",
        "district": "Canon-McMillan SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420489007258",
    },
    {
        "school": "Canonsburg MS",
        "district": "Canon-McMillan SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420489007259",
    },
    {
        "school": "Borland Manor El Sch",
        "district": "Canon-McMillan SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420489009936",
    },
    {
        "school": "Charleroi Area HS",
        "district": "Charleroi SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420564004715",
    },
    {
        "school": "Charleroi Area MS",
        "district": "Charleroi SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420564007199",
    },
    {
        "school": "Charleroi Area El Ctr",
        "district": "Charleroi SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420564009942",
    },
    {
        "school": "Allison Park El Sch",
        "district": "Chartiers-Houston SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420573004234",
    },
    {
        "school": "Chartiers-Houston JSHS",
        "district": "Chartiers-Houston SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420573009975",
    },
    {
        "school": "Fort Cherry JSHS",
        "district": "Fort Cherry SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420996004242",
    },
    {
        "school": "Fort Cherry El Ctr",
        "district": "Fort Cherry SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420996007270",
    },
    {
        "school": "Joe Walker El Sch",
        "district": "McGuffey SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421488004244",
    },
    {
        "school": "Claysville El Sch",
        "district": "McGuffey SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421488004248",
    },
    {
        "school": "McGuffey HS",
        "district": "McGuffey SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421488004249",
    },
    {
        "school": "McGuffey MS",
        "district": "McGuffey SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421488006976",
    },
    {
        "school": "McMurray El Sch",
        "district": "Peters Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421896000075",
    },
    {
        "school": "Bower Hill El Sch",
        "district": "Peters Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421896000410",
    },
    {
        "school": "Pleasant Valley El Sch",
        "district": "Peters Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421896004255",
    },
    {
        "school": "Peters Twp MS",
        "district": "Peters Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421896004256",
    },
    {
        "school": "Peters Twp HS",
        "district": "Peters Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421896005083",
    },
    {
        "school": "Ringgold El Sch North",
        "district": "Ringgold SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422040004268",
    },
    {
        "school": "Ringgold MS",
        "district": "Ringgold SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422040004271",
    },
    {
        "school": "Ringgold SHS",
        "district": "Ringgold SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422040007238",
    },
    {
        "school": "Trinity West El Sch",
        "district": "Trinity Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422376000076",
    },
    {
        "school": "Trinity North El Sch",
        "district": "Trinity Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422376000110",
    },
    {
        "school": "Trinity South El Sch",
        "district": "Trinity Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422376000141",
    },
    {
        "school": "Trinity East El Sch",
        "district": "Trinity Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422376004276",
    },
    {
        "school": "Trinity SHS",
        "district": "Trinity Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422376006012",
    },
    {
        "school": "Trinity MS",
        "district": "Trinity Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422376006638",
    },
    {
        "school": "Washington Park El Sch",
        "district": "Washington SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422499000184",
    },
    {
        "school": "Washington HS",
        "district": "Washington SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422499004286",
    },
    {
        "school": "Washington Junior High School",
        "district": "Washington SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422499006912",
    },
    {
        "school": "Mon Valley CTC",
        "district": "Mon Valley CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428045007089",
    },
    {
        "school": "Western Area CTC",
        "district": "Western Area CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428046007090",
    },
    {
        "school": "Dr Robert Ketterer CS Inc",
        "district": "Dr Robert Ketterer CS Inc",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420002100344",
    },
    {
        "school": "Rostraver El Sch",
        "district": "Belle Vernon Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420321004325",
    },
    {
        "school": "Belle Vernon Area HS",
        "district": "Belle Vernon Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420321004930",
    },
    {
        "school": "Bon Air El Sch",
        "district": "Burrell SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420453004333",
    },
    {
        "school": "Stewart El Sch",
        "district": "Burrell SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420453004336",
    },
    {
        "school": "Charles A Huston MS",
        "district": "Burrell SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420453004339",
    },
    {
        "school": "Burrell HS",
        "district": "Burrell SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420453004340",
    },
    {
        "school": "Derry Area MS",
        "district": "Derry Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420756004351",
    },
    {
        "school": "Derry Area SHS",
        "district": "Derry Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420756004352",
    },
    {
        "school": "Grandview El Sch",
        "district": "Derry Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420756006927",
    },
    {
        "school": "Franklin Regional MS",
        "district": "Franklin Regional SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421023000442",
    },
    {
        "school": "Newlonsburg El Sch",
        "district": "Franklin Regional SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421023004354",
    },
    {
        "school": "Sloan El Sch",
        "district": "Franklin Regional SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421023004357",
    },
    {
        "school": "Franklin Regional SHS",
        "district": "Franklin Regional SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421023004360",
    },
    {
        "school": "Heritage El Sch",
        "district": "Franklin Regional SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421023007202",
    },
    {
        "school": "Greensburg-Salem MS",
        "district": "Greensburg Salem SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421092004372",
    },
    {
        "school": "Greensburg-Salem HS",
        "district": "Greensburg Salem SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421092004373",
    },
    {
        "school": "Nicely El Sch",
        "district": "Greensburg Salem SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421092005165",
    },
    {
        "school": "Metzgar El Sch",
        "district": "Greensburg Salem SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421092005166",
    },
    {
        "school": "Amos K Hutchinson El Sch",
        "district": "Greensburg Salem SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421092009982",
    },
    {
        "school": "Baggaley El Sch",
        "district": "Greater Latrobe SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421098004379",
    },
    {
        "school": "Mountain View El Sch",
        "district": "Greater Latrobe SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421098004380",
    },
    {
        "school": "Latrobe El Sch",
        "district": "Greater Latrobe SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421098004386",
    },
    {
        "school": "Greater Latrobe SHS",
        "district": "Greater Latrobe SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421098004845",
    },
    {
        "school": "Greater Latrobe JHS",
        "district": "Greater Latrobe SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421098006957",
    },
    {
        "school": "Fort Allen El Sch",
        "district": "Hempfield Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421176004389",
    },
    {
        "school": "Maxwell El Sch",
        "district": "Hempfield Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421176004394",
    },
    {
        "school": "West Hempfield El Sch",
        "district": "Hempfield Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421176004399",
    },
    {
        "school": "West Point El Sch",
        "district": "Hempfield Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421176004400",
    },
    {
        "school": "Hempfield Area SHS",
        "district": "Hempfield Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421176004404",
    },
    {
        "school": "Stanwood El Sch",
        "district": "Hempfield Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421176005359",
    },
    {
        "school": "Harrold MS",
        "district": "Hempfield Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421176009951",
    },
    {
        "school": "Wendover MS",
        "district": "Hempfield Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421176009952",
    },
    {
        "school": "West Hempfield MS",
        "district": "Hempfield Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421176009953",
    },
    {
        "school": "Kiski Area HS",
        "district": "Kiski Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421284004431",
    },
    {
        "school": "Kiski Area South Primary Sch",
        "district": "Kiski Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421284004516",
    },
    {
        "school": "Kiski Area IHS",
        "district": "Kiski Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421284007277",
    },
    {
        "school": "Kiski Area North Primary Sch",
        "district": "Kiski Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421284007278",
    },
    {
        "school": "Kiski Area East Primary Sch",
        "district": "Kiski Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421284007279",
    },
    {
        "school": "Ligonier Valley MS",
        "district": "Ligonier Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421371004440",
    },
    {
        "school": "Ligonier Valley HS",
        "district": "Ligonier Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421371004442",
    },
    {
        "school": "Mellon El Sch",
        "district": "Ligonier Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421371005361",
    },
    {
        "school": "Laurel Valley El Sch",
        "district": "Ligonier Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421371006940",
    },
    {
        "school": "Monessen MS",
        "district": "Monessen City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421560000087",
    },
    {
        "school": "Monessen El Ctr",
        "district": "Monessen City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421560004444",
    },
    {
        "school": "Monessen SHS",
        "district": "Monessen City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421560006181",
    },
    {
        "school": "Donegal El Sch",
        "district": "Mount Pleasant Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421617004454",
    },
    {
        "school": "Norvelt El Sch",
        "district": "Mount Pleasant Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421617004455",
    },
    {
        "school": "Ramsay El Sch",
        "district": "Mount Pleasant Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421617004457",
    },
    {
        "school": "Mount Pleasant Area HS",
        "district": "Mount Pleasant Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421617004458",
    },
    {
        "school": "Martin Sch",
        "district": "New Kensington-Arnold SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421674004466",
    },
    {
        "school": "Norwin MS",
        "district": "Norwin SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421794004482",
    },
    {
        "school": "Norwin SHS",
        "district": "Norwin SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421794004717",
    },
    {
        "school": "Stewartsville El Sch",
        "district": "Norwin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421794005270",
    },
    {
        "school": "McCullough El Sch",
        "district": "Penn-Trafford SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421866004490",
    },
    {
        "school": "Penn MS",
        "district": "Penn-Trafford SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421866004492",
    },
    {
        "school": "Harrison Park El Sch",
        "district": "Penn-Trafford SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421866006185",
    },
    {
        "school": "Level Green El Sch",
        "district": "Penn-Trafford SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421866006186",
    },
    {
        "school": "Sunrise El Sch",
        "district": "Penn-Trafford SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421866006187",
    },
    {
        "school": "Trafford MS",
        "district": "Penn-Trafford SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421866006189",
    },
    {
        "school": "Penn Trafford HS",
        "district": "Penn-Trafford SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421866006648",
    },
    {
        "school": "Trafford El Sch",
        "district": "Penn-Trafford SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421866007131",
    },
    {
        "school": "Mendon El Sch",
        "district": "Yough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422115004507",
    },
    {
        "school": "Yough Intrmd/MS Sch",
        "district": "Yough SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422115004508",
    },
    {
        "school": "H W Good El Sch",
        "district": "Yough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422115004512",
    },
    {
        "school": "Yough SHS",
        "district": "Yough SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422115004735",
    },
    {
        "school": "West Newton El Sch",
        "district": "Yough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422115004966",
    },
    {
        "school": "Southmoreland SHS",
        "district": "Southmoreland SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422241006191",
    },
    {
        "school": "Southmoreland El Sch",
        "district": "Southmoreland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422241006932",
    },
    {
        "school": "Central Westmoreland CTC",
        "district": "Central Westmoreland CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428047007091",
    },
    {
        "school": "Eastern Westmoreland CTC",
        "district": "Eastern Westmoreland CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428048007092",
    },
    {
        "school": "Northern Westmoreland CTC",
        "district": "Northern Westmoreland CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428049007093",
    },
    {
        "school": "Blue Mountain El Cressona Sch",
        "district": "Blue Mountain SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420387000138",
    },
    {
        "school": "Blue Mountain El West Sch",
        "district": "Blue Mountain SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420387003887",
    },
    {
        "school": "Blue Mountain HS",
        "district": "Blue Mountain SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420387003891",
    },
    {
        "school": "Blue Mountain El East Sch",
        "district": "Blue Mountain SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420387004659",
    },
    {
        "school": "Blue Mountain MS",
        "district": "Blue Mountain SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420387005263",
    },
    {
        "school": "North Schuylkill JSHS",
        "district": "North Schuylkill SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421011003883",
    },
    {
        "school": "Mahanoy Area El Sch",
        "district": "Mahanoy Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421443007283",
    },
    {
        "school": "Early Childhood Edu Ctr",
        "district": "Minersville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421551004836",
    },
    {
        "school": "Minersville Area JSHS",
        "district": "Minersville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421551006583",
    },
    {
        "school": "Minersville Area El Ctr",
        "district": "Minersville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421551006699",
    },
    {
        "school": "Pine Grove El Sch",
        "district": "Pine Grove Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421914003909",
    },
    {
        "school": "Pine Grove Area HS",
        "district": "Pine Grove Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421914003910",
    },
    {
        "school": "Pine Grove Area MS",
        "district": "Pine Grove Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421914005262",
    },
    {
        "school": "Clarke El Ctr",
        "district": "Pottsville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421971003915",
    },
    {
        "school": "Pottsville Area HS",
        "district": "Pottsville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421971003924",
    },
    {
        "school": "Lengel MS",
        "district": "Pottsville Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421971005265",
    },
    {
        "school": "Schuylkill Haven MS",
        "district": "Schuylkill Haven Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422091003935",
    },
    {
        "school": "Schuylkill Haven SHS",
        "district": "Schuylkill Haven Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422091005264",
    },
    {
        "school": "Schuylkill Haven El Ctr",
        "district": "Schuylkill Haven Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422091010019",
    },
    {
        "school": "Shenandoah Valley El Sch",
        "district": "Shenandoah Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422149003938",
    },
    {
        "school": "Shenandoah Valley JSHS",
        "district": "Shenandoah Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422149003940",
    },
    {
        "school": "Saint Clair Area El/MS",
        "district": "Saint Clair Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422271003930",
    },
    {
        "school": "Tamaqua Area MS",
        "district": "Tamaqua Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422322000548",
    },
    {
        "school": "West Penn Twp El Sch",
        "district": "Tamaqua Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422322003948",
    },
    {
        "school": "Tamaqua Area SHS",
        "district": "Tamaqua Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422322005070",
    },
    {
        "school": "Tamaqua El Sch",
        "district": "Tamaqua Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422322007031",
    },
    {
        "school": "Mahantongo El Sch",
        "district": "Tri-Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422370003954",
    },
    {
        "school": "Hegins-Hubley El Sch",
        "district": "Tri-Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422370003955",
    },
    {
        "school": "Tri-Valley JSHS",
        "district": "Tri-Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422370003957",
    },
    {
        "school": "Williams Valley El Sch",
        "district": "Williams Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422640000040",
    },
    {
        "school": "Williams Valley JSHS",
        "district": "Williams Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422640003914",
    },
    {
        "school": "Schuylkill Technology Centers-North Camp",
        "district": "Schuylkill Technology Centers",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428062007103",
    },
    {
        "school": "Schuylkill Technology Centers-South Camp",
        "district": "Schuylkill Technology Centers",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428062007104",
    },
    {
        "school": "Mt Penn Primary Ctr",
        "district": "Antietam SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420248000863",
    },
    {
        "school": "Reiffton Sch",
        "district": "Exeter Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420948000702",
    },
    {
        "school": "Antietam MS/HS",
        "district": "Antietam SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420248000820",
    },
    {
        "school": "Mt Penn El Sch",
        "district": "Antietam SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420248005205",
    },
    {
        "school": "Pine Forge El Sch",
        "district": "Boyertown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420396000761",
    },
    {
        "school": "Colebrookdale El Sch",
        "district": "Boyertown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420396000762",
    },
    {
        "school": "Earl El Sch",
        "district": "Boyertown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420396000763",
    },
    {
        "school": "Washington El Sch",
        "district": "Boyertown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420396000766",
    },
    {
        "school": "Boyertown Area MS-West",
        "district": "Boyertown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420396006305",
    },
    {
        "school": "Boyertown Area SHS",
        "district": "Boyertown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420396006306",
    },
    {
        "school": "Boyertown El Sch",
        "district": "Boyertown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420396006307",
    },
    {
        "school": "Brandywine Heights El Sch",
        "district": "Brandywine Heights Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420405000768",
    },
    {
        "school": "Brandywine Heights HS",
        "district": "Brandywine Heights Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420405006308",
    },
    {
        "school": "Conrad Weiser MS",
        "district": "Conrad Weiser Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420678000537",
    },
    {
        "school": "Conrad Weiser HS",
        "district": "Conrad Weiser Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420678000777",
    },
    {
        "school": "Conrad Weiser West El Sch",
        "district": "Conrad Weiser Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420678005203",
    },
    {
        "school": "Conrad Weiser East El Sch",
        "district": "Conrad Weiser Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420678009944",
    },
    {
        "school": "Daniel Boone Area MS",
        "district": "Daniel Boone Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420729000364",
    },
    {
        "school": "Daniel Boone Area HS",
        "district": "Daniel Boone Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420729004810",
    },
    {
        "school": "Owatin Creek El Sch",
        "district": "Exeter Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420948000783",
    },
    {
        "school": "Lorane El Sch",
        "district": "Exeter Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420948000786",
    },
    {
        "school": "Exeter Twp JHS",
        "district": "Exeter Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420948000787",
    },
    {
        "school": "Exeter Twp SHS",
        "district": "Exeter Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420948000788",
    },
    {
        "school": "Jacksonwald El Sch",
        "district": "Exeter Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420948006731",
    },
    {
        "school": "Andrew Maier El Sch",
        "district": "Fleetwood Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420978000791",
    },
    {
        "school": "Fleetwood SHS",
        "district": "Fleetwood Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420978005023",
    },
    {
        "school": "Fleetwood MS",
        "district": "Fleetwood Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420978006311",
    },
    {
        "school": "Brecknock El Sch",
        "district": "Governor Mifflin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421086000793",
    },
    {
        "school": "Cumru El Sch",
        "district": "Governor Mifflin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421086000794",
    },
    {
        "school": "Governor Mifflin MS",
        "district": "Governor Mifflin SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421086000801",
    },
    {
        "school": "Governor Mifflin SHS",
        "district": "Governor Mifflin SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421086000802",
    },
    {
        "school": "Intermediate Sch",
        "district": "Governor Mifflin SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421086006794",
    },
    {
        "school": "Hamburg Area Middle School",
        "district": "Hamburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421134000216",
    },
    {
        "school": "Hamburg Area HS",
        "district": "Hamburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421134000808",
    },
    {
        "school": "Perry El Sch",
        "district": "Hamburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421134000809",
    },
    {
        "school": "Greenwich-Lenhartsville El Sch",
        "district": "Kutztown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421293000810",
    },
    {
        "school": "Kutztown Area SHS",
        "district": "Kutztown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421293000816",
    },
    {
        "school": "Kutztown Area MS",
        "district": "Kutztown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421293006315",
    },
    {
        "school": "Kutztown El Sch",
        "district": "Kutztown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421293006316",
    },
    {
        "school": "Muhlenberg MS",
        "district": "Muhlenberg SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421620000827",
    },
    {
        "school": "Muhlenberg El Ctr",
        "district": "Muhlenberg SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421620004919",
    },
    {
        "school": "Muhlenberg HS",
        "district": "Muhlenberg SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421620006610",
    },
    {
        "school": "Oley Valley El Sch",
        "district": "Oley Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421815000099",
    },
    {
        "school": "Oley Valley SHS",
        "district": "Oley Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421815006318",
    },
    {
        "school": "Oley Valley MS",
        "district": "Oley Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421815006319",
    },
    {
        "school": "Tenth & Penn El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004000284",
    },
    {
        "school": "Tyson-Schoener El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004000831",
    },
    {
        "school": "Thirteenth & Union El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004000832",
    },
    {
        "school": "Amanda E Stout El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004000840",
    },
    {
        "school": "Glenside El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004000844",
    },
    {
        "school": "Riverside El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004000845",
    },
    {
        "school": "Lauers Park El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004000852",
    },
    {
        "school": "Southern MS",
        "district": "Reading SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004000855",
    },
    {
        "school": "Northwest MS",
        "district": "Reading SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004000856",
    },
    {
        "school": "Northeast MS",
        "district": "Reading SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004000858",
    },
    {
        "school": "Reading SHS",
        "district": "Reading SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004000859",
    },
    {
        "school": "Twelfth & Marion El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004005025",
    },
    {
        "school": "Tenth & Green El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004005026",
    },
    {
        "school": "Thirteenth & Green El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004005027",
    },
    {
        "school": "Sixteenth & Haak El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004005028",
    },
    {
        "school": "Northwest El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004005206",
    },
    {
        "school": "Schuylkill Valley El Sch",
        "district": "Schuylkill Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422097000161",
    },
    {
        "school": "Schuylkill Valley HS",
        "district": "Schuylkill Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422097000864",
    },
    {
        "school": "Schuylkill Valley MS",
        "district": "Schuylkill Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422097006888",
    },
    {
        "school": "Tulpehocken JSHS",
        "district": "Tulpehocken Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422382004670",
    },
    {
        "school": "Bethel El Sch",
        "district": "Tulpehocken Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422382006321",
    },
    {
        "school": "Penn Bernville El Sch",
        "district": "Tulpehocken Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422382006322",
    },
    {
        "school": "Robeson El Ctr",
        "district": "Twin Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422400000868",
    },
    {
        "school": "Twin Valley HS",
        "district": "Twin Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422400000873",
    },
    {
        "school": "Twin Valley MS",
        "district": "Twin Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422400009991",
    },
    {
        "school": "Spring Ridge El Sch",
        "district": "Wilson SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422658000162",
    },
    {
        "school": "Whitfield El Sch",
        "district": "Wilson SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422658000883",
    },
    {
        "school": "Cornwall Terrace El Sch",
        "district": "Wilson SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422658006773",
    },
    {
        "school": "Wilson HS",
        "district": "Wilson SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422658006980",
    },
    {
        "school": "Wilson West MS",
        "district": "Wilson SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422658006981",
    },
    {
        "school": "Wilson Southern MS",
        "district": "Wilson SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422658006982",
    },
    {
        "school": "West Reading El Ctr",
        "district": "Wyomissing Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422676000885",
    },
    {
        "school": "Wyomissing Hills El Ctr",
        "district": "Wyomissing Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422676000886",
    },
    {
        "school": "Wyomissing Area JSHS",
        "district": "Wyomissing Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422676000887",
    },
    {
        "school": "Berks CTC-East Campus",
        "district": "Berks CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428006007046",
    },
    {
        "school": "Berks CTC-West Campus",
        "district": "Berks CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428006007047",
    },
    {
        "school": "Reading Muhlenberg CTC",
        "district": "Reading Muhlenberg CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428007007048",
    },
    {
        "school": "Honey Brook El Ctr",
        "district": "Twin Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422400000872",
    },
    {
        "school": "Twin Valley El Ctr",
        "district": "Twin Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422400005029",
    },
    {
        "school": "Gilbertsville El Sch",
        "district": "Boyertown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420396000754",
    },
    {
        "school": "New Hanover-Upper Frederick El",
        "district": "Boyertown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420396000755",
    },
    {
        "school": "Boyertown Area MS-East",
        "district": "Boyertown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420396006804",
    },
    {
        "school": "Johnsonburg Area El Sch",
        "district": "Johnsonburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421257005326",
    },
    {
        "school": "Johnsonburg Area HS",
        "district": "Johnsonburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421257006218",
    },
    {
        "school": "Francis S Grandinetti El Sch",
        "district": "Ridgway Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422031000117",
    },
    {
        "school": "Ridgway Area HS",
        "district": "Ridgway Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422031001989",
    },
    {
        "school": "Ridgway Area MS",
        "district": "Ridgway Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422031006805",
    },
    {
        "school": "Bennetts Valley El Sch",
        "district": "Saint Marys Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422064001978",
    },
    {
        "school": "Fox Twp El Sch",
        "district": "Saint Marys Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422064001991",
    },
    {
        "school": "St Marys Area MS",
        "district": "Saint Marys Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422064001992",
    },
    {
        "school": "St Marys Area SHS",
        "district": "Saint Marys Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422064005169",
    },
    {
        "school": "South St Marys Street El Sch",
        "district": "Saint Marys Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422064006697",
    },
    {
        "school": "Audrielle Lynch-Ellen Bustin El Sch",
        "district": "Athens Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420267000626",
    },
    {
        "school": "Athens Area HS",
        "district": "Athens Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420267000958",
    },
    {
        "school": "Canton JSHS",
        "district": "Canton Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420492000988",
    },
    {
        "school": "Canton Area El Sch",
        "district": "Canton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420492005303",
    },
    {
        "school": "Northeast Bradford JSHS",
        "district": "Northeast Bradford SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421746000964",
    },
    {
        "school": "Northeast Bradford El Sch",
        "district": "Northeast Bradford SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421746005209",
    },
    {
        "school": "Sayre Area HS",
        "district": "Sayre Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422085000965",
    },
    {
        "school": "Snyder El Sch",
        "district": "Sayre Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422085006713",
    },
    {
        "school": "Morrow El Sch",
        "district": "Towanda Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422355004811",
    },
    {
        "school": "Towanda Area JSHS",
        "district": "Towanda Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422355005208",
    },
    {
        "school": "W R Croman Primary Sch",
        "district": "Troy Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422379000996",
    },
    {
        "school": "Troy Area JSHS",
        "district": "Troy Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422379001000",
    },
    {
        "school": "Northern Tier Career Center",
        "district": "Northern Tier Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428051007096",
    },
    {
        "school": "Wyalusing Valley JSHS",
        "district": "Wyalusing Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422670001005",
    },
    {
        "school": "Fell CS",
        "district": "Fell CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420009600688",
    },
    {
        "school": "Bear Creek Community CS",
        "district": "Bear Creek Community CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420012600848",
    },
    {
        "school": "GNA El Ctr",
        "district": "Greater Nanticoke Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421629000733",
    },
    {
        "school": "Martin F Quinn Pittston Area Primary Ctr",
        "district": "Pittston Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421920000666",
    },
    {
        "school": "Youth Forestry Camp #2",
        "district": "Youth Forestry Camp #2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "PA",
        "nces_id": "420993407195",
    },
    {
        "school": "Clarks Summit El Sch",
        "district": "Abington Heights SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420201000371",
    },
    {
        "school": "Waverly Sch",
        "district": "Abington Heights SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420201002402",
    },
    {
        "school": "Newton-Ransom Sch",
        "district": "Abington Heights SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420201002407",
    },
    {
        "school": "Abington Heights HS",
        "district": "Abington Heights SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420201005091",
    },
    {
        "school": "South Abington Sch",
        "district": "Abington Heights SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420201006398",
    },
    {
        "school": "Abington Heights MS",
        "district": "Abington Heights SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420201006839",
    },
    {
        "school": "Carbondale El Sch",
        "district": "Carbondale Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420498000225",
    },
    {
        "school": "Carbondale Area JSHS",
        "district": "Carbondale Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420498002420",
    },
    {
        "school": "Dunmore El Ctr",
        "district": "Dunmore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420798006591",
    },
    {
        "school": "Lakeland El Sch - Scott Campus",
        "district": "Lakeland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421305006403",
    },
    {
        "school": "Lakeland JSHS",
        "district": "Lakeland SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421305006404",
    },
    {
        "school": "Lakeland El Sch - Mayfield Campus",
        "district": "Lakeland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421305007171",
    },
    {
        "school": "Mid Valley El Ctr",
        "district": "Mid Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421517002423",
    },
    {
        "school": "Moscow El Sch",
        "district": "North Pocono SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421731000128",
    },
    {
        "school": "Jefferson El Sch",
        "district": "North Pocono SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421731002444",
    },
    {
        "school": "North Pocono HS",
        "district": "North Pocono SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421731002446",
    },
    {
        "school": "North Pocono MS",
        "district": "North Pocono SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421731005233",
    },
    {
        "school": "Old Forge El Sch",
        "district": "Old Forge SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421812002448",
    },
    {
        "school": "Old Forge JSHS",
        "district": "Old Forge SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421812002449",
    },
    {
        "school": "Northeast Intrmd Sch",
        "district": "Scranton SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109000612",
    },
    {
        "school": "John Adams #4",
        "district": "Scranton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109002455",
    },
    {
        "school": "Frances Willard #32",
        "district": "Scranton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109002474",
    },
    {
        "school": "George Bancroft #34",
        "district": "Scranton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109002476",
    },
    {
        "school": "Isaac Tripp El Sch",
        "district": "Scranton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109002481",
    },
    {
        "school": "South Scranton Intrmd Sch",
        "district": "Scranton SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109002487",
    },
    {
        "school": "West Scranton HS",
        "district": "Scranton SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109002489",
    },
    {
        "school": "John F. Kennedy #7",
        "district": "Scranton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109004736",
    },
    {
        "school": "William Prescott #38",
        "district": "Scranton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109004857",
    },
    {
        "school": "John G Whittier #2",
        "district": "Scranton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109004858",
    },
    {
        "school": "Robert Morris #27",
        "district": "Scranton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109004952",
    },
    {
        "school": "Charles Sumner #18",
        "district": "Scranton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109005149",
    },
    {
        "school": "Neil Armstrong #40",
        "district": "Scranton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109005232",
    },
    {
        "school": "Scranton HS",
        "district": "Scranton SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109006413",
    },
    {
        "school": "West Scranton Intrmd Sch",
        "district": "Scranton SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109006791",
    },
    {
        "school": "McNichols Plaza",
        "district": "Scranton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422109006970",
    },
    {
        "school": "Riverside JSHS",
        "district": "Riverside SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422325002496",
    },
    {
        "school": "Riverside El Sch East",
        "district": "Riverside SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422325005093",
    },
    {
        "school": "Riverside El Sch West",
        "district": "Riverside SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422325006748",
    },
    {
        "school": "Valley View Intrmd Sch",
        "district": "Valley View SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422465000298",
    },
    {
        "school": "Valley View HS",
        "district": "Valley View SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422465006775",
    },
    {
        "school": "Valley View El Ctr",
        "district": "Valley View SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422465006776",
    },
    {
        "school": "Valley View MS",
        "district": "Valley View SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422465009969",
    },
    {
        "school": "CTC of Lackawanna County",
        "district": "CTC of Lackawanna County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428026009930",
    },
    {
        "school": "Fairview El Sch",
        "district": "Crestwood SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420546002858",
    },
    {
        "school": "Rice El Sch",
        "district": "Crestwood SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420546005341",
    },
    {
        "school": "Wycallis Primary Center",
        "district": "Dallas SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420720000463",
    },
    {
        "school": "Dallas Intermediate Sch",
        "district": "Dallas SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420720002868",
    },
    {
        "school": "Dallas SHS",
        "district": "Dallas SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420720002869",
    },
    {
        "school": "Dallas MS",
        "district": "Dallas SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420720005150",
    },
    {
        "school": "Hanover Area JSHS",
        "district": "Hanover Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421142002891",
    },
    {
        "school": "Hanover Area Memorial El Sch",
        "district": "Hanover Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421142007205",
    },
    {
        "school": "Lee Park El Sch",
        "district": "Hanover Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421142007271",
    },
    {
        "school": "Hazleton Area HS",
        "district": "Hazleton Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421170000026",
    },
    {
        "school": "West Hazleton El/MS",
        "district": "Hazleton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421170000370",
    },
    {
        "school": "Drums El/MS",
        "district": "Hazleton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421170000547",
    },
    {
        "school": "Freeland El/MS",
        "district": "Hazleton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421170006718",
    },
    {
        "school": "Heights Terrace El/MS",
        "district": "Hazleton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421170006930",
    },
    {
        "school": "Valley El/MS",
        "district": "Hazleton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421170009996",
    },
    {
        "school": "Ross El Sch",
        "district": "Lake-Lehman SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421302002920",
    },
    {
        "school": "Lehman-Jackson El Sch",
        "district": "Lake-Lehman SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421302002922",
    },
    {
        "school": "Lake-Lehman JSHS",
        "district": "Lake-Lehman SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421302002924",
    },
    {
        "school": "Lake-Noxen El Sch",
        "district": "Lake-Lehman SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421302007207",
    },
    {
        "school": "Greater Nanticoke Area SHS",
        "district": "Greater Nanticoke Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421629005242",
    },
    {
        "school": "Northwest Area Intermediate Sch",
        "district": "Northwest Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421779002955",
    },
    {
        "school": "Northwest Area Primary Sch",
        "district": "Northwest Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421779002956",
    },
    {
        "school": "Northwest Area HS",
        "district": "Northwest Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421779002958",
    },
    {
        "school": "Pittston Area SHS",
        "district": "Pittston Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421920005058",
    },
    {
        "school": "Pittston Area MS",
        "district": "Pittston Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421920006385",
    },
    {
        "school": "Pittston City Intrmd Ctr",
        "district": "Pittston Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421920006622",
    },
    {
        "school": "West Side CTC",
        "district": "West Side CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "422587005059",
    },
    {
        "school": "Dana El Ctr",
        "district": "Wyoming Valley West SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422595002878",
    },
    {
        "school": "Schuyler Avenue El Sch",
        "district": "Wyoming Valley West SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422595002917",
    },
    {
        "school": "Third Avenue El Sch",
        "district": "Wyoming Valley West SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422595002918",
    },
    {
        "school": "Wyoming Valley West SHS",
        "district": "Wyoming Valley West SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422595006391",
    },
    {
        "school": "Chester Street El Sch",
        "district": "Wyoming Valley West SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422595006392",
    },
    {
        "school": "Wyoming Valley West MS",
        "district": "Wyoming Valley West SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422595006986",
    },
    {
        "school": "Solomon/Plains El Sch",
        "district": "Wilkes-Barre Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422630000294",
    },
    {
        "school": "Solomon/Plains JHS",
        "district": "Wilkes-Barre Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422630000296",
    },
    {
        "school": "Dodson El Sch",
        "district": "Wilkes-Barre Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422630002995",
    },
    {
        "school": "James M Coughlin JSHS",
        "district": "Wilkes-Barre Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422630003007",
    },
    {
        "school": "G A R Memorial JSHS",
        "district": "Wilkes-Barre Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422630003008",
    },
    {
        "school": "Elmer L Meyers JSHS",
        "district": "Wilkes-Barre Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422630003009",
    },
    {
        "school": "Daniel J Flood El Sch",
        "district": "Wilkes-Barre Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422630005152",
    },
    {
        "school": "Heights/Murray El Sch",
        "district": "Wilkes-Barre Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422630006923",
    },
    {
        "school": "Dr David W Kistler El Sch",
        "district": "Wilkes-Barre Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422630006924",
    },
    {
        "school": "Wyoming Area Primary Ctr",
        "district": "Wyoming Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422673002874",
    },
    {
        "school": "Wyoming Area Kindergarten Ctr",
        "district": "Wyoming Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422673002875",
    },
    {
        "school": "Wyoming Area Sec Ctr",
        "district": "Wyoming Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422673006390",
    },
    {
        "school": "Wyoming Area Intermediate Ctr",
        "district": "Wyoming Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422673009972",
    },
    {
        "school": "Wilkes-Barre Area CTC",
        "district": "Wilkes-Barre Area CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428030007077",
    },
    {
        "school": "Hazleton Area Career Center",
        "district": "Hazleton Area Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428057007100",
    },
    {
        "school": "Lackawanna Trail El Ctr",
        "district": "Lackawanna Trail SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421299004524",
    },
    {
        "school": "Lackawanna Trail JSHS",
        "district": "Lackawanna Trail SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421299004528",
    },
    {
        "school": "Tunkhannock HS",
        "district": "Tunkhannock Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422385005271",
    },
    {
        "school": "Midd-West MS",
        "district": "Midd-West SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421521000817",
    },
    {
        "school": "Middleburg El Sch",
        "district": "Midd-West SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421521003961",
    },
    {
        "school": "Midd-West HS",
        "district": "Midd-West SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421521003962",
    },
    {
        "school": "Selinsgrove Intrmd Sch",
        "district": "Selinsgrove Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422112000293",
    },
    {
        "school": "Selinsgrove Area El Sch",
        "district": "Selinsgrove Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422112003968",
    },
    {
        "school": "Selinsgrove Area HS",
        "district": "Selinsgrove Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422112003969",
    },
    {
        "school": "Selinsgrove Area MS",
        "district": "Selinsgrove Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422112006817",
    },
    {
        "school": "Berlin Brothersvalley MS",
        "district": "Berlin Brothersvalley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420342000527",
    },
    {
        "school": "Berlin Brothersvalley El Sch",
        "district": "Berlin Brothersvalley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420342006206",
    },
    {
        "school": "Berlin Brothersvalley SHS",
        "district": "Berlin Brothersvalley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420342006207",
    },
    {
        "school": "Conemaugh Twp Area El Sch",
        "district": "Conemaugh Township Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420642003977",
    },
    {
        "school": "Conemaugh Twp Area MS/SHS",
        "district": "Conemaugh Township Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420642003978",
    },
    {
        "school": "North Star HS",
        "district": "North Star SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421011503988",
    },
    {
        "school": "North Star Central El Sch",
        "district": "North Star SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421011504837",
    },
    {
        "school": "North Star East MS",
        "district": "North Star SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421011509950",
    },
    {
        "school": "Meyersdale Area MS",
        "district": "Meyersdale Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421515000444",
    },
    {
        "school": "Meyersdale Area HS",
        "district": "Meyersdale Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421515003994",
    },
    {
        "school": "Meyersdale Area El Sch",
        "district": "Meyersdale Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421515006208",
    },
    {
        "school": "Rockwood Area El Sch",
        "district": "Rockwood Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422052006209",
    },
    {
        "school": "Rockwood Area JSHS",
        "district": "Rockwood Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422052006210",
    },
    {
        "school": "Salisbury-Elk Lick JSHS",
        "district": "Salisbury-Elk Lick SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422076004002",
    },
    {
        "school": "Salisbury-Elk Lick El Sch",
        "district": "Salisbury-Elk Lick SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422076006818",
    },
    {
        "school": "Shade JSHS",
        "district": "Shade-Central City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422118004006",
    },
    {
        "school": "Cairnbrook El Sch",
        "district": "Shade-Central City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422118006594",
    },
    {
        "school": "Shanksville-Stonycreek El Sch",
        "district": "Shanksville-Stonycreek SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422127000091",
    },
    {
        "school": "Shanksville-Stonycreek MS",
        "district": "Shanksville-Stonycreek SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422127000092",
    },
    {
        "school": "Shanksville-Stonycreek HS",
        "district": "Shanksville-Stonycreek SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422127006800",
    },
    {
        "school": "Eagle View El Sch",
        "district": "Somerset Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422184000279",
    },
    {
        "school": "Maple Ridge El Sch",
        "district": "Somerset Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422184004009",
    },
    {
        "school": "Turkeyfoot Valley Area El Sch",
        "district": "Turkeyfoot Valley Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422388006215",
    },
    {
        "school": "Turkeyfoot Valley Area JSHS",
        "district": "Turkeyfoot Valley Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422388006216",
    },
    {
        "school": "Windber El Sch",
        "district": "Windber Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422661000280",
    },
    {
        "school": "Windber Area HS",
        "district": "Windber Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422661004026",
    },
    {
        "school": "Windber Area MS",
        "district": "Windber Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422661007178",
    },
    {
        "school": "Somerset County Technology Center",
        "district": "Somerset County Technology Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428040007085",
    },
    {
        "school": "Young Scholars of Central PA CS",
        "district": "Young Scholars of Central PA CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420013700879",
    },
    {
        "school": "Gray's Woods El Sch",
        "district": "State College Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422277000676",
    },
    {
        "school": "Centre Learning Community CS",
        "district": "Centre Learning Community CS",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420002300350",
    },
    {
        "school": "Nittany Valley CS",
        "district": "Nittany Valley CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420002400352",
    },
    {
        "school": "Wingate El Sch",
        "district": "Bald Eagle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420291001330",
    },
    {
        "school": "Port Matilda El Sch",
        "district": "Bald Eagle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420291001331",
    },
    {
        "school": "Howard El Sch",
        "district": "Bald Eagle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420291001333",
    },
    {
        "school": "Mountaintop Area El Sch",
        "district": "Bald Eagle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420291001334",
    },
    {
        "school": "Bald Eagle Area JSHS",
        "district": "Bald Eagle Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420291001335",
    },
    {
        "school": "Benner El Sch",
        "district": "Bellefonte Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420324001339",
    },
    {
        "school": "Marion-Walker El Sch",
        "district": "Bellefonte Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420324001340",
    },
    {
        "school": "Bellefonte El Sch",
        "district": "Bellefonte Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420324001341",
    },
    {
        "school": "Bellefonte Area MS",
        "district": "Bellefonte Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420324001342",
    },
    {
        "school": "Bellefonte Area HS",
        "district": "Bellefonte Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420324001343",
    },
    {
        "school": "Pleasant Gap El Sch",
        "district": "Bellefonte Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420324006229",
    },
    {
        "school": "Miles Township El Sch",
        "district": "Penns Valley Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421881001346",
    },
    {
        "school": "Centre Hall-Potter El Sch",
        "district": "Penns Valley Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421881001347",
    },
    {
        "school": "Penns Valley Area JSHS",
        "district": "Penns Valley Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421881006231",
    },
    {
        "school": "Penns Valley Area El and Intrmd Sch",
        "district": "Penns Valley Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421881006847",
    },
    {
        "school": "Mount Nittany MS",
        "district": "State College Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422277000154",
    },
    {
        "school": "Ferguson Twp El Sch",
        "district": "State College Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422277001350",
    },
    {
        "school": "Corl Street El Sch",
        "district": "State College Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422277001354",
    },
    {
        "school": "Easterly Parkway El Sch",
        "district": "State College Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422277001356",
    },
    {
        "school": "Spring Creek El Sch",
        "district": "State College Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422277001357",
    },
    {
        "school": "Mount Nittany El Sch",
        "district": "State College Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422277001358",
    },
    {
        "school": "Radio Park El Sch",
        "district": "State College Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422277001359",
    },
    {
        "school": "State College Area HS",
        "district": "State College Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422277001364",
    },
    {
        "school": "Park Forest El Sch",
        "district": "State College Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422277006233",
    },
    {
        "school": "Park Forest MS",
        "district": "State College Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422277006234",
    },
    {
        "school": "Central PA Institute of Science & Techno",
        "district": "Central PA Institute of Science & Technology",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428053007098",
    },
    {
        "school": "Chief Shikellamy Sch",
        "district": "Shikellamy SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422154000683",
    },
    {
        "school": "Susq-Cyber CS",
        "district": "Susq-Cyber CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420002800368",
    },
    {
        "school": "Line Mountain HS",
        "district": "Line Mountain SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421446003532",
    },
    {
        "school": "Line Mountain El Sch",
        "district": "Line Mountain SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421446006786",
    },
    {
        "school": "Milton HS",
        "district": "Milton Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421548003541",
    },
    {
        "school": "James F Baugher El Sch",
        "district": "Milton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421548005353",
    },
    {
        "school": "Milton Area MS",
        "district": "Milton Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421548006863",
    },
    {
        "school": "Mount Carmel Area El Sch",
        "district": "Mount Carmel Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421599000292",
    },
    {
        "school": "Mount Carmel Area HS",
        "district": "Mount Carmel Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421599006936",
    },
    {
        "school": "Shamokin Area El Sch",
        "district": "Shamokin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422124007009",
    },
    {
        "school": "Priestley Sch",
        "district": "Shikellamy SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422154003549",
    },
    {
        "school": "Oaklyn Sch",
        "district": "Shikellamy SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422154003567",
    },
    {
        "school": "Shikellamy HS",
        "district": "Shikellamy SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422154003569",
    },
    {
        "school": "Grace S Beck Sch",
        "district": "Shikellamy SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422154006357",
    },
    {
        "school": "Warrior Run MS",
        "district": "Warrior Run SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422487003575",
    },
    {
        "school": "Warrior Run HS",
        "district": "Warrior Run SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422487005103",
    },
    {
        "school": "Northumberland County CTC",
        "district": "Northumberland County CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428049107094",
    },
    {
        "school": "White Deer El Sch",
        "district": "Milton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421548003537",
    },
    {
        "school": "Tidioute Community CS",
        "district": "Tidioute Community CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420013600874",
    },
    {
        "school": "Warren Area El Ctr",
        "district": "Warren County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422482000878",
    },
    {
        "school": "Youngsville El Sch",
        "district": "Warren County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422482004133",
    },
    {
        "school": "Youngsville MS/HS",
        "district": "Warren County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422482004135",
    },
    {
        "school": "Eisenhower M/HS",
        "district": "Warren County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422482004143",
    },
    {
        "school": "Sheffield M/HS",
        "district": "Warren County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422482004146",
    },
    {
        "school": "Beaty-Warren MS",
        "district": "Warren County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422482004148",
    },
    {
        "school": "Warren Area HS",
        "district": "Warren County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422482004149",
    },
    {
        "school": "Warren County AVTS",
        "district": "Warren County AVTS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428044007088",
    },
    {
        "school": "Rommelt El Sch",
        "district": "South Williamsport Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422214000652",
    },
    {
        "school": "George A Ferrell El Sch",
        "district": "East Lycoming SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420849003018",
    },
    {
        "school": "Joseph C Ashkar El Sch",
        "district": "East Lycoming SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420849003019",
    },
    {
        "school": "Carl G Renn El Sch",
        "district": "East Lycoming SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420849003021",
    },
    {
        "school": "Hughesville JSHS",
        "district": "East Lycoming SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420849006364",
    },
    {
        "school": "Avis El Sch",
        "district": "Jersey Shore Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421248003031",
    },
    {
        "school": "Jersey Shore MS",
        "district": "Jersey Shore Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421248003033",
    },
    {
        "school": "Jersey Shore Area SHS",
        "district": "Jersey Shore Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421248003034",
    },
    {
        "school": "Salladasburg El Sch",
        "district": "Jersey Shore Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421248005060",
    },
    {
        "school": "Jersey Shore Area El Sch",
        "district": "Jersey Shore Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421248005243",
    },
    {
        "school": "Donald E. Schick Sch",
        "district": "Loyalsock Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421431003036",
    },
    {
        "school": "Loyalsock Twp MS",
        "district": "Loyalsock Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421431003037",
    },
    {
        "school": "Loyalsock Twp SHS",
        "district": "Loyalsock Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421431004828",
    },
    {
        "school": "Montgomery El Sch",
        "district": "Montgomery Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421566003039",
    },
    {
        "school": "Montgomery JSHS",
        "district": "Montgomery Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421566003040",
    },
    {
        "school": "Lyter El Sch",
        "district": "Montoursville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421575003042",
    },
    {
        "school": "Loyalsock Valley El Sch",
        "district": "Montoursville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421575003044",
    },
    {
        "school": "Montoursville Area SHS",
        "district": "Montoursville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421575003045",
    },
    {
        "school": "C E McCall MS",
        "district": "Montoursville Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421575005343",
    },
    {
        "school": "Ward L Myers El Sch",
        "district": "Muncy SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421623003047",
    },
    {
        "school": "Muncy JSHS",
        "district": "Muncy SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421623003048",
    },
    {
        "school": "Central El Sch",
        "district": "South Williamsport Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422214003054",
    },
    {
        "school": "South Williamsport Area JSHS",
        "district": "South Williamsport Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422214003056",
    },
    {
        "school": "Cochran Primary Sch",
        "district": "Williamsport Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422646000571",
    },
    {
        "school": "Jackson Primary Sch",
        "district": "Williamsport Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422646003058",
    },
    {
        "school": "Curtin Intrmd Sch",
        "district": "Williamsport Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422646003073",
    },
    {
        "school": "Hepburn-Lycoming Primary Sch",
        "district": "Williamsport Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422646006367",
    },
    {
        "school": "Williamsport Area SHS",
        "district": "Williamsport Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422646006368",
    },
    {
        "school": "Lycoming Valley Intrmd Sch",
        "district": "Williamsport Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422646006861",
    },
    {
        "school": "Stevens Primary Sch",
        "district": "Williamsport Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422646007250",
    },
    {
        "school": "Lycoming CTC",
        "district": "Lycoming CTC",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428939309994",
    },
    {
        "school": "South Eastern Intrmd Sch",
        "district": "South Eastern SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422217000627",
    },
    {
        "school": "Hillside El Sch",
        "district": "West Shore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583001716",
    },
    {
        "school": "Cedar Cliff HS",
        "district": "West Shore SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583001732",
    },
    {
        "school": "Washington Heights El Sch",
        "district": "West Shore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583001734",
    },
    {
        "school": "Lower Allen El Sch",
        "district": "West Shore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583001735",
    },
    {
        "school": "Highland El Sch",
        "district": "West Shore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583001736",
    },
    {
        "school": "Rossmoyne El Sch",
        "district": "West Shore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583001738",
    },
    {
        "school": "Allen MS",
        "district": "West Shore SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583001741",
    },
    {
        "school": "Crossroads MS",
        "district": "West Shore SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583000100",
    },
    {
        "school": "Fishing Creek El Sch",
        "district": "West Shore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583004583",
    },
    {
        "school": "Newberry El Sch",
        "district": "West Shore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583004585",
    },
    {
        "school": "Fairview El Sch",
        "district": "West Shore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583004588",
    },
    {
        "school": "Red Land SHS",
        "district": "West Shore SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583004704",
    },
    {
        "school": "Red Mill El Sch",
        "district": "West Shore SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583009993",
    },
    {
        "school": "Crispus Attucks CS",
        "district": "Crispus Attucks CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420004800453",
    },
    {
        "school": "Lincoln CS",
        "district": "Lincoln CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420006500567",
    },
    {
        "school": "Sinking Springs El Sch",
        "district": "Central York SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420549000607",
    },
    {
        "school": "Hayshire El Sch",
        "district": "Central York SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420549004537",
    },
    {
        "school": "Roundtown El Sch",
        "district": "Central York SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420549004539",
    },
    {
        "school": "North Hills El Sch",
        "district": "Central York SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420549004540",
    },
    {
        "school": "Central York MS",
        "district": "Central York SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420549004544",
    },
    {
        "school": "Central York HS",
        "district": "Central York SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420549004545",
    },
    {
        "school": "Stony Brook El Sch",
        "district": "Central York SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420549005088",
    },
    {
        "school": "Dallastown El Sch",
        "district": "Dallastown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420723004546",
    },
    {
        "school": "Loganville-Springfield El Sch",
        "district": "Dallastown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420723004547",
    },
    {
        "school": "York Twp El Sch",
        "district": "Dallastown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420723004549",
    },
    {
        "school": "Ore Valley El Sch",
        "district": "Dallastown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420723004551",
    },
    {
        "school": "Dallastown Area SHS",
        "district": "Dallastown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420723004553",
    },
    {
        "school": "Leaders Heights El Sch",
        "district": "Dallastown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420723004701",
    },
    {
        "school": "Dallastown Area MS",
        "district": "Dallastown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420723006598",
    },
    {
        "school": "North Salem El Sch",
        "district": "Dover Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420768000356",
    },
    {
        "school": "Weigelstown El Sch",
        "district": "Dover Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420768004556",
    },
    {
        "school": "Leib El Sch",
        "district": "Dover Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420768004557",
    },
    {
        "school": "Dover Area HS",
        "district": "Dover Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420768004558",
    },
    {
        "school": "Dover Area Intrmd Sch",
        "district": "Dover Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420768006283",
    },
    {
        "school": "Eastern York MS",
        "district": "Eastern York SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420879000159",
    },
    {
        "school": "Canadochly El Sch",
        "district": "Eastern York SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420879004559",
    },
    {
        "school": "Wrightsville El Sch",
        "district": "Eastern York SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420879004563",
    },
    {
        "school": "Eastern York HS",
        "district": "Eastern York SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420879004564",
    },
    {
        "school": "Kreutz Creek El Sch",
        "district": "Eastern York SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420879006285",
    },
    {
        "school": "Clearview El Sch",
        "district": "Hanover Public SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421145004565",
    },
    {
        "school": "Hanover Street El Sch",
        "district": "Hanover Public SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421145004566",
    },
    {
        "school": "Washington El Sch",
        "district": "Hanover Public SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421145004568",
    },
    {
        "school": "Hanover MS",
        "district": "Hanover Public SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421145004570",
    },
    {
        "school": "Hanover SHS",
        "district": "Hanover Public SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421145004571",
    },
    {
        "school": "Mt Wolf El Sch",
        "district": "Northeastern York SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421752000067",
    },
    {
        "school": "Spring Forge Intrd Sch",
        "district": "Northeastern York SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421752000525",
    },
    {
        "school": "Conewago El Sch",
        "district": "Northeastern York SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421752004572",
    },
    {
        "school": "Northeastern SHS",
        "district": "Northeastern York SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421752004577",
    },
    {
        "school": "Northeastern MS",
        "district": "Northeastern York SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421752004578",
    },
    {
        "school": "Orendorf El Sch",
        "district": "Northeastern York SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421752005272",
    },
    {
        "school": "York Haven El Sch",
        "district": "Northeastern York SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421752009988",
    },
    {
        "school": "South Mountain El Sch",
        "district": "Northern York County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421776000459",
    },
    {
        "school": "Dillsburg El Sch",
        "district": "Northern York County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421776004579",
    },
    {
        "school": "Wellsville Campus",
        "district": "Northern York County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421776004580",
    },
    {
        "school": "Northern El Sch",
        "district": "Northern York County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421776004581",
    },
    {
        "school": "Northern HS",
        "district": "Northern York County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421776006345",
    },
    {
        "school": "Northern MS",
        "district": "Northern York County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421776006346",
    },
    {
        "school": "N Hopewell-Winterstown El Sch",
        "district": "Red Lion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422010004589",
    },
    {
        "school": "Locust Grove El Sch",
        "district": "Red Lion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422010004593",
    },
    {
        "school": "Mazie Gable El Sch",
        "district": "Red Lion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422010004595",
    },
    {
        "school": "Red Lion Area JHS",
        "district": "Red Lion Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422010004597",
    },
    {
        "school": "Red Lion Area SHS",
        "district": "Red Lion Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422010004598",
    },
    {
        "school": "Pleasant View El Sch",
        "district": "Red Lion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422010005362",
    },
    {
        "school": "Clearview El Sch",
        "district": "Red Lion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422010006837",
    },
    {
        "school": "South Eastern MS",
        "district": "South Eastern SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422217000611",
    },
    {
        "school": "Delta-Peach Bottom El Sch",
        "district": "South Eastern SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422217004599",
    },
    {
        "school": "Stewartstown El Sch",
        "district": "South Eastern SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422217004600",
    },
    {
        "school": "Fawn Area El Sch",
        "district": "South Eastern SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422217004601",
    },
    {
        "school": "Kennard-Dale HS",
        "district": "South Eastern SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422217004602",
    },
    {
        "school": "Shrewsbury El Sch",
        "district": "Southern York County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422238000357",
    },
    {
        "school": "Friendship El Sch",
        "district": "Southern York County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422238004613",
    },
    {
        "school": "Susquehannock HS",
        "district": "Southern York County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422238004614",
    },
    {
        "school": "Southern MS",
        "district": "Southern York County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422238006286",
    },
    {
        "school": "Southern El Sch",
        "district": "Southern York County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422238006692",
    },
    {
        "school": "Baresville El Sch",
        "district": "South Western SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422247004603",
    },
    {
        "school": "Manheim El Sch",
        "district": "South Western SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422247004605",
    },
    {
        "school": "Park Hills El Sch",
        "district": "South Western SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422247004606",
    },
    {
        "school": "West Manheim El Sch",
        "district": "South Western SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422247004607",
    },
    {
        "school": "South Western SHS",
        "district": "South Western SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422247004608",
    },
    {
        "school": "Markle Intrmd Sch",
        "district": "South Western SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422247006641",
    },
    {
        "school": "New Salem El Sch",
        "district": "Spring Grove Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422259004617",
    },
    {
        "school": "Spring Grove El Sch",
        "district": "Spring Grove Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422259004618",
    },
    {
        "school": "Paradise El Sch",
        "district": "Spring Grove Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422259004620",
    },
    {
        "school": "Spring Grove Area Intrmd Sch",
        "district": "Spring Grove Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422259004622",
    },
    {
        "school": "Spring Grove Area HS",
        "district": "Spring Grove Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422259004623",
    },
    {
        "school": "Spring Grove Area MS",
        "district": "Spring Grove Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422259006725",
    },
    {
        "school": "Lincolnway El Sch",
        "district": "West York Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422598004625",
    },
    {
        "school": "Trimmer El Sch",
        "district": "West York Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422598004629",
    },
    {
        "school": "West York Area HS",
        "district": "West York Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422598006705",
    },
    {
        "school": "West York Area MS",
        "district": "West York Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422598009971",
    },
    {
        "school": "York Co School of Technology",
        "district": "York Co School of Technology",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "422681005168",
    },
    {
        "school": "William Penn SHS",
        "district": "York City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422682004647",
    },
    {
        "school": "East York El Sch",
        "district": "York Suburban SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422685004648",
    },
    {
        "school": "York Suburban MS",
        "district": "York Suburban SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422685004657",
    },
    {
        "school": "York Suburban SHS",
        "district": "York Suburban SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422685004658",
    },
    {
        "school": "Indian Rock El Sch",
        "district": "York Suburban SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422685006688",
    },
    {
        "school": "Valley View El Sch",
        "district": "York Suburban SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422685007305",
    },
    {
        "school": "Mercer Area MS",
        "district": "Mercer Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421512000792",
    },
    {
        "school": "Keystone Education Center CS",
        "district": "Keystone Education Center CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420001100272",
    },
    {
        "school": "Commodore Perry Sch",
        "district": "Commodore Perry SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420639000202",
    },
    {
        "school": "Commodore Perry JSHS",
        "district": "Commodore Perry SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420639006122",
    },
    {
        "school": "Farrell Area HS/UMS",
        "district": "Farrell Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420969005248",
    },
    {
        "school": "Farrell Area ES/LMS",
        "district": "Farrell Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420969007143",
    },
    {
        "school": "Greenville JSHS",
        "district": "Greenville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421116003137",
    },
    {
        "school": "Highland Primary Center",
        "district": "Grove City Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421122003143",
    },
    {
        "school": "Grove City Area HS",
        "district": "Grove City Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421122003145",
    },
    {
        "school": "George Jr Republic HS",
        "district": "Grove City Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421122006125",
    },
    {
        "school": "Hillview Intermediate Center",
        "district": "Grove City Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421122006844",
    },
    {
        "school": "George Jr Republic MS",
        "district": "Grove City Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421122009981",
    },
    {
        "school": "Artman El Sch",
        "district": "Hermitage SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421182003146",
    },
    {
        "school": "Karen A. Ionta El Sch",
        "district": "Hermitage SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421182003147",
    },
    {
        "school": "Hickory HS",
        "district": "Hermitage SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421182003150",
    },
    {
        "school": "Delahunty MS",
        "district": "Hermitage SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421182005247",
    },
    {
        "school": "Oakview El Sch",
        "district": "Lakeview SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421308003154",
    },
    {
        "school": "Lakeview HS",
        "district": "Lakeview SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421308003155",
    },
    {
        "school": "Lakeview MS",
        "district": "Lakeview SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421308007208",
    },
    {
        "school": "Mercer Area El Sch",
        "district": "Mercer Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421512003157",
    },
    {
        "school": "Mercer Area SHS",
        "district": "Mercer Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421512003158",
    },
    {
        "school": "Reynolds El Sch",
        "district": "Reynolds SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422022003164",
    },
    {
        "school": "Reynolds JSHS",
        "district": "Reynolds SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422022003165",
    },
    {
        "school": "Musser El Sch",
        "district": "Sharon City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422133003170",
    },
    {
        "school": "West Hill El Sch",
        "district": "Sharon City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422133003171",
    },
    {
        "school": "Case Avenue El Sch",
        "district": "Sharon City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422133003173",
    },
    {
        "school": "Sharpsville Area MS",
        "district": "Sharpsville Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422142000084",
    },
    {
        "school": "Sharpsville Area El Sch",
        "district": "Sharpsville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422142000618",
    },
    {
        "school": "Sharpsville Area SHS",
        "district": "Sharpsville Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422142003124",
    },
    {
        "school": "West Middlesex Area JSHS",
        "district": "West Middlesex Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422565006129",
    },
    {
        "school": "Luther W Low El Sch",
        "district": "West Middlesex Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422565006803",
    },
    {
        "school": "Oakview El Sch",
        "district": "West Middlesex Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422565009970",
    },
    {
        "school": "Mercer County Career Center",
        "district": "Mercer County Career Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "428031007078",
    },
    {
        "school": "SEGUNDO RUIZ BELVIS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000764",
    },
    {
        "school": "JAIME COIRA ORTIZ (SU POZAS)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000712",
    },
    {
        "school": "REGINO VEGA MARTINEZ (NUEVA ELEMENTAL BO SANTA CLARA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000713",
    },
    {
        "school": "SUPERIOR URBANA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000714",
    },
    {
        "school": "CRISTOBAL SANTANA MELECIO (NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000717",
    },
    {
        "school": "ECOLOGICA DE CULEBRA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000732",
    },
    {
        "school": "LUIS NEGRON LOPEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000734",
    },
    {
        "school": "DRA. MARIA CADILLA DE MARTINEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000745",
    },
    {
        "school": "CRISTINA (AMADA) MARTINEZ MARTINEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000750",
    },
    {
        "school": "DRA. MARIA SOCORRO LACOT",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001828",
    },
    {
        "school": "JOSEFA DEL RIO GUERRERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001844",
    },
    {
        "school": "ERNESTO VICENTE CARATTINI (ELEMENTAL BO CEIBA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001845",
    },
    {
        "school": "FERMIN DELGADO DIAZ (SU BO PENA POBRE)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001885",
    },
    {
        "school": "DR ALFREDO M AGUAYO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001886",
    },
    {
        "school": "ELEMENTAL BO HIGUILLAR (ECOLOGICA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001889",
    },
    {
        "school": "LIBRE DE MUSICA Y BELLAS ARTES ERNESTO RAMOS ANTONINI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Not reported",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001897",
    },
    {
        "school": "NUEVA ELEMENTAL URBANA DE GUAYNABO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001925",
    },
    {
        "school": "NUEVA BRIGIDA ALVAREZ RODRIGUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001931",
    },
    {
        "school": "SUSANA RIVERA-NUEVA (ELEMENTAL BO LLANOS)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001933",
    },
    {
        "school": "PABLO DAVID BURGOS MARRERO (NUEVA SUP CON DEPART VOCACIONAL)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001935",
    },
    {
        "school": "CENTRO RESIDENCIAL DE OPORTUNIDADES EDUCATIVAS DE CEIBA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001940",
    },
    {
        "school": "CARMEN BOZELLO DE HUYKE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001946",
    },
    {
        "school": "PADRE ANIBAL REYES BELEN (SUP NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000628",
    },
    {
        "school": "ELEMENTAL NUEVA (FACTOR V)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000607",
    },
    {
        "school": "SU BARRIO SABANA HOYOS (NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000612",
    },
    {
        "school": "SUPERIOR URBANA NUEVA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000685",
    },
    {
        "school": "ELEMENTAL BARRIO LAS 400",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000619",
    },
    {
        "school": "DON LUIS MUNOZ MARIN (ELEMENTAL URBANA NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000582",
    },
    {
        "school": "CLAUDIO FERRER COTTO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000618",
    },
    {
        "school": "LEONARDO VALENTIN TIRADO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000613",
    },
    {
        "school": "JORGE ROSARIO DEL VALLE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000621",
    },
    {
        "school": "ANITA OTERO HERNANDEZ (ESC. ESP BELLAS ARTES HUMACAO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000671",
    },
    {
        "school": "PEDRO COLON SANTIAGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000566",
    },
    {
        "school": "FRANCISCO PRADO PICART",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000623",
    },
    {
        "school": "ELEMENTAL URBANA NUEVA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000608",
    },
    {
        "school": "ALFONSO CASTA MARTINEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000626",
    },
    {
        "school": "RUBEN RODRIGUEZ FIGUEROA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000698",
    },
    {
        "school": "FRANCISCO LOPEZ CRUZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000706",
    },
    {
        "school": "NELIDA MELENDEZ MELENDEZ (ELEM. URBANA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000669",
    },
    {
        "school": "CARMEN FELICIANO CARRERA (INTERMEDIA BO PALMER)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000715",
    },
    {
        "school": "ELEMENTAL NUEVA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000609",
    },
    {
        "school": "AURORA MENDEZ CHARNECO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000690",
    },
    {
        "school": "SUPERIOR VOCACIONAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000710",
    },
    {
        "school": "DANIEL SERRANO RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000602",
    },
    {
        "school": "FRANCISCO ZAYAS SANTANA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000646",
    },
    {
        "school": "RAMON LOPEZ BERRIOS (EMILIA BONILLA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000716",
    },
    {
        "school": "LOAIZA CORDERO DEL ROSARIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000697",
    },
    {
        "school": "PROFESORA JUANA ROSARIO CARRERO (ESCUELA INTERMEDIA NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000551",
    },
    {
        "school": "DRA. CARMEN DELIA COLON MARTINEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000571",
    },
    {
        "school": "LUIS FELIPE RODRIGUEZ GARCIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000668",
    },
    {
        "school": "PAPA JUAN XXIII",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000666",
    },
    {
        "school": "SALVADOR BRAU ELEMENTAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000617",
    },
    {
        "school": "ROMAN COLON CORREA (RIO JUEYES)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000554",
    },
    {
        "school": "SABINO RIVERA BERRIOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000564",
    },
    {
        "school": "GLORIA MARIA BORRERO OLIVERAS (SEGUNDA UNIDAD BO. MACANA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000595",
    },
    {
        "school": "ELEMENTAL NUEVA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000591",
    },
    {
        "school": "LUIS LLORENS TORRES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000627",
    },
    {
        "school": "WILFREDO LAFUENTE ORTIZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000590",
    },
    {
        "school": "EUGENIO MARIA DE HOSTOS (INTERMEDIA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000592",
    },
    {
        "school": "SU NUEVA BO. MEDIANIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000675",
    },
    {
        "school": "RAMON MARIA TORRES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000593",
    },
    {
        "school": "TOMAS MASSO RIVERA MORALES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000614",
    },
    {
        "school": "DR EFRAIN GONZALEZ TEJERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000567",
    },
    {
        "school": "LYSANDER BORRERO TERRY",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000594",
    },
    {
        "school": "DOMINGO PIETRI RUIZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000507",
    },
    {
        "school": "RAFAEL APARICIO JIMENEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001132",
    },
    {
        "school": "JOSE EMILIO LUGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001133",
    },
    {
        "school": "DOMINGO MASSOL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001145",
    },
    {
        "school": "HECTOR I. RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001151",
    },
    {
        "school": "DR. CARLOS GONZALEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000753",
    },
    {
        "school": "JOSE GONZALEZ RUIZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000762",
    },
    {
        "school": "ANSELMO VILLARRUBIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000765",
    },
    {
        "school": "AQUILINO CABAN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000767",
    },
    {
        "school": "JUAN LINO SANTIAGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000773",
    },
    {
        "school": "SU EPIFANIO ESTRADA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000774",
    },
    {
        "school": "SU JUAN B. SOTO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000775",
    },
    {
        "school": "CENTRO VOCACIONAL ESPECIAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003000776",
    },
    {
        "school": "ELADIO TIRADO LOPEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001869",
    },
    {
        "school": "LYDIA MELENDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002018",
    },
    {
        "school": "JUAN SUAREZ PELEGRINA (NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000396",
    },
    {
        "school": "CENTRO DE ADIESTRAMIENTO Y BELLAS ARTES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Not reported",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000426",
    },
    {
        "school": "JOSE DE DIEGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000730",
    },
    {
        "school": "SALVADOR FUENTES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000731",
    },
    {
        "school": "HOMERO RIVERA SOLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000741",
    },
    {
        "school": "ANA M. JAVARIZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000744",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000747",
    },
    {
        "school": "SU CONCHITA IGUARTUA DE SUAREZ (SU ADAMS)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000749",
    },
    {
        "school": "BENITO CEREZO MARQUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001984",
    },
    {
        "school": "ESTER FELICIANO MENDOZA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001985",
    },
    {
        "school": "ANTONIO BADILLO HERNANDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001986",
    },
    {
        "school": "DR. PEDRO ALBIZU CAMPOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000159",
    },
    {
        "school": "ALFONSO LOPEZ O'NEILL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000213",
    },
    {
        "school": "SU BAYAMONCITO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000224",
    },
    {
        "school": "CARMEN D ORTIZ ORTIZ (SU SUMIDERO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000225",
    },
    {
        "school": "LUIS MUNOZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001854",
    },
    {
        "school": "BONIFACIO SANCHEZ  JIMENEZ (GANDARA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000160",
    },
    {
        "school": "FEDERICO DEGETAU II",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000207",
    },
    {
        "school": "RAFAEL PONT FLORES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001569",
    },
    {
        "school": "RABANAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001577",
    },
    {
        "school": "SU JOSE CELSO BARBOSA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001582",
    },
    {
        "school": "SU CARMEN ZENAIDA VEGA (LA PLATA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001583",
    },
    {
        "school": "SU PASTO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001584",
    },
    {
        "school": "CARMEN CASASUS MARTI (ELEM URBANA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000308",
    },
    {
        "school": "ANTONIO GONZALEZ SUAREZ (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000779",
    },
    {
        "school": "ISABEL SUAREZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000780",
    },
    {
        "school": "ESCUELA ESPECIALIZADA BILINGUE ALCIDES FIGUEROA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000781",
    },
    {
        "school": "ESPINO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000795",
    },
    {
        "school": "LUIS MUNOZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002060",
    },
    {
        "school": "ANGELICA GOMEZ DE BETANCOURT",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000048",
    },
    {
        "school": "SU FEDERICO DEGETAU",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000063",
    },
    {
        "school": "SU EUGENIO MARIA DE HOSTOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000065",
    },
    {
        "school": "ESCUELA DE BELLAS ARTES (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Not reported",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000314",
    },
    {
        "school": "SUPERIOR VOCACIONAL (ANTONIO LUCHETTI)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000414",
    },
    {
        "school": "JOHN W. HARRIS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001683",
    },
    {
        "school": "COTTO ANEXO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003001684",
    },
    {
        "school": "JULIO SEIJO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001685",
    },
    {
        "school": "FRANCISCO G. PACHIN MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001692",
    },
    {
        "school": "TRINA PADILLA DE SANZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001707",
    },
    {
        "school": "ELBA LUGO CARRION (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001708",
    },
    {
        "school": "SU MANUEL RUIZ GANDIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001717",
    },
    {
        "school": "DR. CAYETANO COLL Y TOSTE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001719",
    },
    {
        "school": "SU ENRIQUE DE JESUS BORRAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001720",
    },
    {
        "school": "ELI RAMOS ROSARIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001722",
    },
    {
        "school": "ABELARDO MARTINEZ OTERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001879",
    },
    {
        "school": "ESCUELA LIBRE DE MUSICA (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Not reported",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001883",
    },
    {
        "school": "VICTOR ROJAS  1",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003002037",
    },
    {
        "school": "LUIS MUNOZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002039",
    },
    {
        "school": "ADALBERTO SANCHEZ MORALES (ELEM. BO. ANCONES)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000522",
    },
    {
        "school": "JOSE M. MASSARI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001205",
    },
    {
        "school": "JOSE HORACIO CORA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001214",
    },
    {
        "school": "DOLORES GONZALEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001964",
    },
    {
        "school": "NUEVA INTERMEDIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001723",
    },
    {
        "school": "FERNANDO SURIA CHAVEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001724",
    },
    {
        "school": "IMBERY",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001729",
    },
    {
        "school": "PETROAMERICA PAGAN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000254",
    },
    {
        "school": "PABLO COLON BERDECIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000257",
    },
    {
        "school": "INOCENCIO CINTRON ZAYAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000259",
    },
    {
        "school": "EL FARALLON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000260",
    },
    {
        "school": "JOSE COLON GONZALEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000263",
    },
    {
        "school": "ANTONIO VAZQUEZ RAMOS (SU LA LOMA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000266",
    },
    {
        "school": "FEDERICO DEGETAU (SU PALO HINCADO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000268",
    },
    {
        "school": "RAMON T. RIVERA (SU LAJITA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000269",
    },
    {
        "school": "LUIS MUNOZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001902",
    },
    {
        "school": "FRANCISCO GAZTAMBIDE VEGA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000364",
    },
    {
        "school": "NUEVA ESCUELA SU ANTONIO RIVERA (NUEVA ESC SU DE BAYAMON)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000453",
    },
    {
        "school": "JOSEFITA MONSERRATE DE SELLES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001497",
    },
    {
        "school": "CARMEN GOMEZ TEJERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001498",
    },
    {
        "school": "MARIA E. BAS DE VAZQUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001499",
    },
    {
        "school": "DR. JOSE A. PADIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003001500",
    },
    {
        "school": "MARIANO FELIU BALSEIRO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001501",
    },
    {
        "school": "LUIS PALES MATOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001502",
    },
    {
        "school": "FAUSTINO SANTIAGO MONTALVO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001503",
    },
    {
        "school": "MIGUEL DE CERVANTES SAAVEDRA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001505",
    },
    {
        "school": "TOMAS C. ONGAY",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001506",
    },
    {
        "school": "HERMINIA RIVERA FERNANDEZ (GUARAGUAO CARRETERA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001509",
    },
    {
        "school": "ANDRES C. GONZALEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001510",
    },
    {
        "school": "JOSE M. TORRES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001511",
    },
    {
        "school": "BERNARDO HUYKE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001516",
    },
    {
        "school": "RAFAEL COLON SALGADO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001517",
    },
    {
        "school": "CRISTOBAL COLON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001518",
    },
    {
        "school": "CARLOS ORAMA PADILLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001520",
    },
    {
        "school": "INES MARIA MENDOZA DE MUNOZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001522",
    },
    {
        "school": "JOSE CAMPECHE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001525",
    },
    {
        "school": "DR. JOSE ANTONIO DAVILA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001526",
    },
    {
        "school": "JESUS SANCHEZ ERAZO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001527",
    },
    {
        "school": "DR. AGUSTIN STAHL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001528",
    },
    {
        "school": "REXVILLE ELEMENTAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001530",
    },
    {
        "school": "MARTA VELEZ DE FAJARDO (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001531",
    },
    {
        "school": "MIGUEL MELENDEZ MUNOZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001533",
    },
    {
        "school": "FRANCISCO MANRIQUE CABRERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001534",
    },
    {
        "school": "JULIO RESSY",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001535",
    },
    {
        "school": "SU CACIQUE MAJAGUA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001540",
    },
    {
        "school": "MARIA VAZQUEZ DE UMPIERRE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001543",
    },
    {
        "school": "DR. HIRAM GONZALEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001547",
    },
    {
        "school": "EPIFANIO FERNANDEZ VANGA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001548",
    },
    {
        "school": "JUAN MORELL CAMPOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001551",
    },
    {
        "school": "PABLO CASALS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001554",
    },
    {
        "school": "VIRGILIO DAVILA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001558",
    },
    {
        "school": "RAMON MORALES PENA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001561",
    },
    {
        "school": "JUAN RAMON JIMENEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001563",
    },
    {
        "school": "CACIQUE AGUEYBANA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001564",
    },
    {
        "school": "LUDOVICO COSTOSO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003001566",
    },
    {
        "school": "PEDRO P. CASABLANCA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001840",
    },
    {
        "school": "PEDRO NELSON COLBERG",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000798",
    },
    {
        "school": "JAMES GARFIELD",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000805",
    },
    {
        "school": "SEBASTIAN PABON ALVES (COROZO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000809",
    },
    {
        "school": "SU FEDERICO DEGETAU",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000813",
    },
    {
        "school": "SU CARMEN VIGNALS ROSARIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000814",
    },
    {
        "school": "SU ANTONIO ACARON CORREA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000815",
    },
    {
        "school": "INES MARIA MENDOZA DE MUNOZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002019",
    },
    {
        "school": "MONSERRATE LEON DE IRIZARRY",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002059",
    },
    {
        "school": "SEVERO E. COLBERG RAMIREZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002079",
    },
    {
        "school": "ROSA C. BENITEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000227",
    },
    {
        "school": "CHARLES E. MINER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000228",
    },
    {
        "school": "JUSTINA VAZQUEZ MENDOZA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000230",
    },
    {
        "school": "ANTONIO S PEDREIRA (PRE-TEC)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000232",
    },
    {
        "school": "HAYDEE CABALLERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000233",
    },
    {
        "school": "CIPRIANO MANRIQUE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000240",
    },
    {
        "school": "JOSE MERCADO (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000243",
    },
    {
        "school": "SU SANDALIO MARCANO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000252",
    },
    {
        "school": "DR. JUAN JOSE OSUNA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000253",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000271",
    },
    {
        "school": "PAULA MOJICA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000272",
    },
    {
        "school": "DIEGO VAZQUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000274",
    },
    {
        "school": "MYRNA M. FUENTES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000275",
    },
    {
        "school": "CONCEPCION MENDEZ CANO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000276",
    },
    {
        "school": "LUIS RAMOS GONZALEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000278",
    },
    {
        "school": "GERARDO SELLES SOLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000279",
    },
    {
        "school": "JOSE GAUTIER BENITEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000280",
    },
    {
        "school": "REPUBLICA DE COSTA RICA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000281",
    },
    {
        "school": "BENITA GONZALEZ QUINONES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000288",
    },
    {
        "school": "PEDRO MILLAN RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000289",
    },
    {
        "school": "PEPITA GARRIGA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000290",
    },
    {
        "school": "ABELARDO DIAZ MORALES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000291",
    },
    {
        "school": "NICOLAS AGUAYO ALDEA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000295",
    },
    {
        "school": "MANUELA TORO MORICE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000296",
    },
    {
        "school": "FRANCISCO VALDES ROLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000301",
    },
    {
        "school": "JESUS T. PINERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000302",
    },
    {
        "school": "FELIPE RIVERA CENTENO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001867",
    },
    {
        "school": "ELOISA PASCUAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001871",
    },
    {
        "school": "PEPITA ARENAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001899",
    },
    {
        "school": "ANTONIO DOMINGUEZ NIEVES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002000",
    },
    {
        "school": "ANTONIO S PAOLI (MUSICA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Not reported",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002043",
    },
    {
        "school": "INES MARIA MENDOZA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002051",
    },
    {
        "school": "SUPERIOR MIGUEL F SANTIAGO ECHEGARAY (SANTIAGO R PALMER SUP)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000195",
    },
    {
        "school": "LUIS F. CRESPO (SUP. NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000340",
    },
    {
        "school": "AMALIA LOPEZ DE AVILA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000375",
    },
    {
        "school": "PEDRO AMADOR",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001736",
    },
    {
        "school": "RALPH W. EMERSON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001747",
    },
    {
        "school": "SU SANTIAGO R. PALMER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001749",
    },
    {
        "school": "ANTONIO REYES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001750",
    },
    {
        "school": "SU JOAQUIN VAZQUEZ CRUZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001751",
    },
    {
        "school": "JUANA RODRIGUEZ MUNDO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000524",
    },
    {
        "school": "ANTONIO R. BARCELO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000525",
    },
    {
        "school": "LUIS HERNAIZ VERONNE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000526",
    },
    {
        "school": "DR PEDRO ALBIZU CAMPOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000530",
    },
    {
        "school": "JOSE CALZADA FERRER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000536",
    },
    {
        "school": "JOSE SANTOS QUINONEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001833",
    },
    {
        "school": "EDUARDO GARCIA CARRILLO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002029",
    },
    {
        "school": "ISAAC DEL ROSARIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001426",
    },
    {
        "school": "RAFAEL CORDERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001427",
    },
    {
        "school": "ONOFRE CARBALLEIRA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001431",
    },
    {
        "school": "FRANCISCO OLLER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001432",
    },
    {
        "school": "MERCEDES GARCIA DE COLORADO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001859",
    },
    {
        "school": "VIRGINIA VAZQUEZ MENDOZA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000138",
    },
    {
        "school": "BENIGNO CARRION",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000172",
    },
    {
        "school": "EMERITA LEON ELEMENTAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000174",
    },
    {
        "school": "BENIGNO FERNANDEZ GARCIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000176",
    },
    {
        "school": "BENJAMIN HARRISON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000178",
    },
    {
        "school": "MIGUEL MELENDEZ MUNOZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000179",
    },
    {
        "school": "SU EUGENIO MARIA DE HOSTOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000199",
    },
    {
        "school": "SU GERARDO SELLES SOLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000201",
    },
    {
        "school": "CENTRO ADIEST. VOC. GABRIEL BIBILONI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003000204",
    },
    {
        "school": "DR. RAMON EMETERIO BETANCES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001898",
    },
    {
        "school": "SANTIAGO IGLESIAS PANTIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000518",
    },
    {
        "school": "IRMA PEDRAZA RUIZ (INTERMEDIA NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001979",
    },
    {
        "school": "HATO VIEJO CUMBRE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000071",
    },
    {
        "school": "SU FRANCISCO SERRANO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000079",
    },
    {
        "school": "SU TORIBIO RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000080",
    },
    {
        "school": "JUAN ANTONIO CORRETJER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000193",
    },
    {
        "school": "JESUS T. PINERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000148",
    },
    {
        "school": "EDUCACION BILINGUE LUIS MUNOZ IGLESIAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000149",
    },
    {
        "school": "CLEMENCIA MELENDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000151",
    },
    {
        "school": "SU CERTENEJAS II",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000157",
    },
    {
        "school": "SU JUAN D. STUBBE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000168",
    },
    {
        "school": "RUTH EVELYN CRUZ SANTOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000203",
    },
    {
        "school": "HERMINIO W SANTAELLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000237",
    },
    {
        "school": "JOSE M ESPADA ZAYAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000553",
    },
    {
        "school": "JOSE RAMON RODRIGUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000921",
    },
    {
        "school": "PURIFICACION RODRIGUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000922",
    },
    {
        "school": "BENJAMIN FRANKLIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000924",
    },
    {
        "school": "FLORENCIO SANTIAGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000925",
    },
    {
        "school": "RAMON JOSE DAVILA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000926",
    },
    {
        "school": "SU EUGENIO NAZARIO SOTO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000930",
    },
    {
        "school": "JOSE FELIPE ZAYAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001842",
    },
    {
        "school": "INES M. MENDOZA DE MUNOZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000007",
    },
    {
        "school": "JUANA COLON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000126",
    },
    {
        "school": "ESCUELA ESPECIALIZADA EN BEISBOL-MANUEL CRUZ MACEIRA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000137",
    },
    {
        "school": "SU RAMON ALEJANDRO AYALA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000143",
    },
    {
        "school": "SU OSCAR PORRATA DORIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000144",
    },
    {
        "school": "SU MARIA C. SANTIAGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000145",
    },
    {
        "school": "LUIS MUNOZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001900",
    },
    {
        "school": "MANUEL BOU GALI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001437",
    },
    {
        "school": "EMILIO R. DELGADO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001438",
    },
    {
        "school": "FIDEL LOPEZ COLON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001439",
    },
    {
        "school": "GENARO BOU",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001440",
    },
    {
        "school": "SU JULIAN MARRERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001448",
    },
    {
        "school": "DR. JOSE PADIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001449",
    },
    {
        "school": "SU NICOLAS RODRIGUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001450",
    },
    {
        "school": "SU DEMETRIO RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001451",
    },
    {
        "school": "JACINTO LOPEZ MARTINEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001409",
    },
    {
        "school": "RICARDO ARROYO LARACUENTE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001410",
    },
    {
        "school": "JOSE SANTOS ALEGRIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001411",
    },
    {
        "school": "LUISA M. VALDERRAMA (SAN ANTONIO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001415",
    },
    {
        "school": "RAMON QUINONES PACHECO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000502",
    },
    {
        "school": "GABINO SOTO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000503",
    },
    {
        "school": "ANTONIO VALERO BERNABE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000509",
    },
    {
        "school": "MARIA I. DONES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000511",
    },
    {
        "school": "INES ENCARNACION",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000513",
    },
    {
        "school": "DR. SANTIAGO VEVE CALZADA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001906",
    },
    {
        "school": "ROSA PASCUAL PARIS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001980",
    },
    {
        "school": "RICARDO RODRIGUEZ TORRES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000374",
    },
    {
        "school": "JUANITA RAMIREZ GONZALEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001752",
    },
    {
        "school": "JUAN PONCE DE LEON II",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001753",
    },
    {
        "school": "AUREA E. QUILES CLAUDIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000059",
    },
    {
        "school": "MARIA L MCDOUGALL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001153",
    },
    {
        "school": "AGRIPINA SEDA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001155",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001158",
    },
    {
        "school": "ELSA E COUTO ANNONI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001164",
    },
    {
        "school": "MAGUEYES II",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001165",
    },
    {
        "school": "FRANCISCO GARCIA BOYRIE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000055",
    },
    {
        "school": "VICENTE PALES ANES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001069",
    },
    {
        "school": "DR RAFAEL LOPEZ LANDRON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001074",
    },
    {
        "school": "RAFAEL ANTONIO DELGADO MATEO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001084",
    },
    {
        "school": "OSCAR HERNANDEZ GUEVARRA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001087",
    },
    {
        "school": "SU JUAN ALEMANY SILVA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001092",
    },
    {
        "school": "SIMON MADERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001870",
    },
    {
        "school": "ADELA BRENES TEXIDOR",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001976",
    },
    {
        "school": "GENARO CAUTINO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001999",
    },
    {
        "school": "WASHINGTON I",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002001",
    },
    {
        "school": "DALILA TORRES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001185",
    },
    {
        "school": "ARISTIDES CALES QUIROS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001186",
    },
    {
        "school": "HERMINIO ARZOLA EMMANUELLI (QUEBRADAS)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001193",
    },
    {
        "school": "HIPOLITO GARCIA BORRERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001196",
    },
    {
        "school": "ASUNCION RODRIGUEZ DE SALA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002064",
    },
    {
        "school": "MATIAS GONZALEZ GARCIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000112",
    },
    {
        "school": "MARGARITA RIVERA DE JANER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000113",
    },
    {
        "school": "SU VIDAL SERRANO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000121",
    },
    {
        "school": "VILLA MARINA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001880",
    },
    {
        "school": "SU JOSEFINA SITIRICHE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002047",
    },
    {
        "school": "DRA. CONCHITA CUEVAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002048",
    },
    {
        "school": "LORENZO COBALLES GANDIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000084",
    },
    {
        "school": "CARMEN NOELIA PERAZA TOLEDO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000087",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000088",
    },
    {
        "school": "EUGENIO MARIA DE HOSTOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000090",
    },
    {
        "school": "SU RAFAEL ZAMOT CRUZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000092",
    },
    {
        "school": "TIMOTEO DELGADO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000093",
    },
    {
        "school": "LUIS MELENDEZ RODRIGUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000094",
    },
    {
        "school": "SU ALFREDO DORRINGTON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000818",
    },
    {
        "school": "RAMON E. RODRIGUEZ DIAZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001861",
    },
    {
        "school": "20 DE SEPTIEMBRE DE 1988",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000010",
    },
    {
        "school": "LIDIA FIOL SCARANO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000140",
    },
    {
        "school": "LEONCIO MELENDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000161",
    },
    {
        "school": "SUP VOC MANUEL MEDIAVILLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000162",
    },
    {
        "school": "CASIANO CEPEDA PRE-VOCACIONAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003000313",
    },
    {
        "school": "ESC. LIBRE DE MUSICA HUMACAO (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Not reported",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000357",
    },
    {
        "school": "SUPERIOR ISIDRO A SANCHEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000418",
    },
    {
        "school": "AVELINO PENA REYES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003000419",
    },
    {
        "school": "ANA DELIA FLORES SANTANA  VOC",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000471",
    },
    {
        "school": "CARMEN PILAR SANTOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000475",
    },
    {
        "school": "RUFINO VIGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000477",
    },
    {
        "school": "CARLOS RIVERA UFRET",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000478",
    },
    {
        "school": "ANA ROQUE DE DUPREY",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000479",
    },
    {
        "school": "BRAULIO AYALA PEREZ (MAMBICHE BLANCO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000480",
    },
    {
        "school": "ANTONIO ROSA GUZMAN (BO. MARIANA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000482",
    },
    {
        "school": "CANDIDO BERRIOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000487",
    },
    {
        "school": "RAMON QUINONES MEDINA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000491",
    },
    {
        "school": "BERTA ZALDUONDO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000506",
    },
    {
        "school": "DR. JOSE N. GANDARA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001570",
    },
    {
        "school": "SU AGAPITO LOPEZ FLORES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001865",
    },
    {
        "school": "ANA J. CANDELAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001901",
    },
    {
        "school": "CAMILO VALLES MATIENZO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001913",
    },
    {
        "school": "JOSEFINA FERRERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001914",
    },
    {
        "school": "PETRA MERCADO BOUGART",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002003",
    },
    {
        "school": "JUAN PONCE DE LEON (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Secondary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002028",
    },
    {
        "school": "GEORGINA BAQUERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002032",
    },
    {
        "school": "LUZ A CRUZ DE SANTANA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002053",
    },
    {
        "school": "ELEMENTAL CEFERINA CORDERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000450",
    },
    {
        "school": "FRANCISCO MENDOZA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000703",
    },
    {
        "school": "MATEO HERNANDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000718",
    },
    {
        "school": "EPIFANIO ESTRADA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000719",
    },
    {
        "school": "ANTONIO GEIGEL PAREDES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000722",
    },
    {
        "school": "JOSE C. ROSARIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000723",
    },
    {
        "school": "SU JOSE A VARGAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000724",
    },
    {
        "school": "DR. HERIBERTO DOMENECH",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001874",
    },
    {
        "school": "IRMA DELIZ DE MUNOZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001892",
    },
    {
        "school": "ANGELICA TORO (NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001167",
    },
    {
        "school": "JOSEFINA LEON ZAYAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001169",
    },
    {
        "school": "MIGUEL A SASTRE OLIVER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001170",
    },
    {
        "school": "SAN PATRICIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001171",
    },
    {
        "school": "SU ANTONIO ROMERO MUNIZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001179",
    },
    {
        "school": "SU ANTONIA SERRANO GONZALEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001180",
    },
    {
        "school": "SU NEMESIO R. CANALES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001181",
    },
    {
        "school": "FELIPE COLON DIAZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000026",
    },
    {
        "school": "RUTHFORD B HAYES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000036",
    },
    {
        "school": "DR. MAXIMO DONOSO SANCHEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000359",
    },
    {
        "school": "MANUEL F FERNANDEZ JUNCOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000942",
    },
    {
        "school": "JUAN SERAPIO MANGUAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000964",
    },
    {
        "school": "SU ZOILO GRACIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000968",
    },
    {
        "school": "LUIS MUNOZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000970",
    },
    {
        "school": "DR PEDRO ALBIZU CAMPOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001820",
    },
    {
        "school": "CARMEN BELEN VEIGA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001826",
    },
    {
        "school": "ALFONSO DIAZ LEBRON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000462",
    },
    {
        "school": "JUAN A SANCHEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000463",
    },
    {
        "school": "CARMEN ARZUAGA DE RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000468",
    },
    {
        "school": "PEDRO BOSCH",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000470",
    },
    {
        "school": "SU PEDRO RIVERA MOLINA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000472",
    },
    {
        "school": "SU CLARA M. ARAMBURU",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000473",
    },
    {
        "school": "ISABEL FLORES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001916",
    },
    {
        "school": "JOSE A. LOPEZ CASTRO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001981",
    },
    {
        "school": "JOSE COLLAZO COLON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001982",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000576",
    },
    {
        "school": "ROSENDO MATIENZO CINTRON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000579",
    },
    {
        "school": "RAMON OLIVARES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000584",
    },
    {
        "school": "SU JUAN CANCIO ORTIZ DE LA RENTA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000585",
    },
    {
        "school": "JOSE RODRIGUEZ DE SOTO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001154",
    },
    {
        "school": "LEONIDES MORALES RODRIGUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001855",
    },
    {
        "school": "ELEMENTAL DANIEL VELEZ SOTO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000451",
    },
    {
        "school": "DOMINGO APONTE COLLAZO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001611",
    },
    {
        "school": "GEORGE WASHINGTON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001615",
    },
    {
        "school": "JULIO LEBRON SOTO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001631",
    },
    {
        "school": "PROFESOR RAFAEL ALICEA VAZQUEZ (JOSEFINA LINARES)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001633",
    },
    {
        "school": "SU ANGELICA DELGADO (SU AMERICA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001635",
    },
    {
        "school": "GABRIELA MISTRAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001637",
    },
    {
        "school": "RAMON DE JESUS SIERRA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001895",
    },
    {
        "school": "FLORENCIA GARCIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000381",
    },
    {
        "school": "CARMEN BENITEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000443",
    },
    {
        "school": "RAMON POWER Y GIRALT",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000445",
    },
    {
        "school": "JOSE DE DIEGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000449",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000454",
    },
    {
        "school": "LA FERMINA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000458",
    },
    {
        "school": "SANTIAGO TORRES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001915",
    },
    {
        "school": "GERMAN RIECKEHOFF",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000335",
    },
    {
        "school": "MARIA M SIMMONS DE RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000547",
    },
    {
        "school": "RAFAEL N. COCA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000424",
    },
    {
        "school": "SU ALEJANDRINA RIOS (SU SABANA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000434",
    },
    {
        "school": "PETRA CORRETJER DE ONEILL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000304",
    },
    {
        "school": "NUEVA JUAN S MARCHAND",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000371",
    },
    {
        "school": "TEODOMIRO TABOAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001639",
    },
    {
        "school": "JUAN A. SANCHEZ DAVILA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001640",
    },
    {
        "school": "JESUS T. PINERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001641",
    },
    {
        "school": "FERNANDO CALLEJO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001643",
    },
    {
        "school": "EVARISTO CAMACHO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001649",
    },
    {
        "school": "FRANCISCO MENENDEZ BALBANE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001650",
    },
    {
        "school": "FELIX CORDOVA DAVILA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001651",
    },
    {
        "school": "ANTONIO VELEZ ALVARADO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001654",
    },
    {
        "school": "SUPERIOR URBANA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000394",
    },
    {
        "school": "RAUL YBARRA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000645",
    },
    {
        "school": "INDIERA FRIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000647",
    },
    {
        "school": "LA CARMEN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001847",
    },
    {
        "school": "SU HIGINIO FIGUEROA VILLEGAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000420",
    },
    {
        "school": "MANUEL ORTIZ SUYA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000422",
    },
    {
        "school": "ESTEBAN ROSADO BAEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000142",
    },
    {
        "school": "ELVIRA RUPERTO QUILES (RIO CANAS ABAJO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000166",
    },
    {
        "school": "MARIANO RIERA PALMER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000656",
    },
    {
        "school": "MANUEL A. BARRETO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000659",
    },
    {
        "school": "JOSE GAUTIER BENITEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000660",
    },
    {
        "school": "DR PEDRO PEREA FAJARDO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000662",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000676",
    },
    {
        "school": "RAFAEL MARTINEZ NADAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000678",
    },
    {
        "school": "SEGUNDO RUIZ BELVIS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000681",
    },
    {
        "school": "MARIA LUISA ARCELAY",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000684",
    },
    {
        "school": "MARIA DOLORES FARIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000687",
    },
    {
        "school": "CENTRO RESIDENCIAL DE OPORTUNIDADES EDUCATIVAS DE MAYAGUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000689",
    },
    {
        "school": "OLGA MAS RAMIREZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000693",
    },
    {
        "school": "ELPIDIO H. RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001863",
    },
    {
        "school": "SUPERIOR CATALINA MORALES FLORES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000494",
    },
    {
        "school": "TOMAS VERA AYALA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000631",
    },
    {
        "school": "CERRO GORDO MEDINA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000637",
    },
    {
        "school": "CUCHILLAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000640",
    },
    {
        "school": "JUAN DE DIOS QUINONES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000641",
    },
    {
        "school": "DR EFRAIN SANCHEZ HIDALGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001923",
    },
    {
        "school": "MARCELINO RODRIGUEZ ROMAN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001929",
    },
    {
        "school": "LUIS COLON (ADOLFO BABILONIA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001983",
    },
    {
        "school": "JORGE L MARRERO PADILLA (ELEMENTAL URBANA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000031",
    },
    {
        "school": "FRANCISCO RIVERA CLAUDIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000032",
    },
    {
        "school": "JAIME A. COLLAZO DEL RIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000033",
    },
    {
        "school": "ESPERANZA GONZALEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000035",
    },
    {
        "school": "JUANA G AVILES (FRANQUEZ)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000039",
    },
    {
        "school": "RAMON TORRES RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000043",
    },
    {
        "school": "SU JOSE R. BARRERAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000045",
    },
    {
        "school": "OSCAR RODRIGUEZ RIVERA (BARAHONA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000046",
    },
    {
        "school": "ANGEL G QUINTERO ALFARO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000131",
    },
    {
        "school": "EUGENIO BRAC",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000390",
    },
    {
        "school": "FIDELINA MELENDEZ MONSANTO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000392",
    },
    {
        "school": "JUAN JOSE MAUNEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000393",
    },
    {
        "school": "LUTGARDA RIVERA REYES (FLORIDA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000398",
    },
    {
        "school": "QUEBRADA GRANDE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000405",
    },
    {
        "school": "SU SILVERIO GARCIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002031",
    },
    {
        "school": "FRANCISCO MORALES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000097",
    },
    {
        "school": "BERNARDA ROBLES DE HEVIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000104",
    },
    {
        "school": "ROSA LUZ ZAYAS (CEDRO ARRIBA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000105",
    },
    {
        "school": "SU ADOLFO GARCIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000109",
    },
    {
        "school": "SU PEDRO FERNANDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000110",
    },
    {
        "school": "FRANCISCO ROQUE MUNOZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000542",
    },
    {
        "school": "COLEEN VAZQUEZ URRUTIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001962",
    },
    {
        "school": "MERCEDES ROSADO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001995",
    },
    {
        "school": "SILVESTRE MARTINEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002077",
    },
    {
        "school": "ALBERTO MELENDEZ TORRES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001657",
    },
    {
        "school": "JOSE ROJAS CORTES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001658",
    },
    {
        "school": "VISITACION PAGAN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001659",
    },
    {
        "school": "SU MATRULLAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001671",
    },
    {
        "school": "SU BOTIJAS 1",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001672",
    },
    {
        "school": "SU ANA JOAQUINA ORTIZ ORTIZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001673",
    },
    {
        "school": "ANGEL RAFAEL DIAZ COLON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001675",
    },
    {
        "school": "SU BONIFACIO ALVARADO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001676",
    },
    {
        "school": "SU SANAMUERTOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001677",
    },
    {
        "school": "MARIA DAVILA SEMIDEY",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000366",
    },
    {
        "school": "JOSEFINA MUNOZ DE BERNIER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000367",
    },
    {
        "school": "CECILIO LEBRON RAMOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000368",
    },
    {
        "school": "GUILLERMO RIEFKHOL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000384",
    },
    {
        "school": "SU JOAQUIN PARRILLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000388",
    },
    {
        "school": "RAFAELINA E. LEBRON FLORES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000490",
    },
    {
        "school": "JOSEFA VELEZ BAUZA (SUPERIOR URBANA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000402",
    },
    {
        "school": "WEBSTER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000972",
    },
    {
        "school": "RAFAEL IRIZARRY RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000974",
    },
    {
        "school": "SU JORGE LUCAS VALDIVIESO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000989",
    },
    {
        "school": "RAMON PEREZ PURCELL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000990",
    },
    {
        "school": "TALLABOA ALTA INTERMEDIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000991",
    },
    {
        "school": "MIGUEL GONZALEZ BAUZA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002067",
    },
    {
        "school": "ANTONIO PAOLI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000053",
    },
    {
        "school": "BELLAS ARTES DE PONCE (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Not reported",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000167",
    },
    {
        "school": "DR. JOSE CELSO BARBOSA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001020",
    },
    {
        "school": "JAIME L. DREW",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001022",
    },
    {
        "school": "LIBRADO NET",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001027",
    },
    {
        "school": "JULIO ALVARADO TRICOCHE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001028",
    },
    {
        "school": "EDUARDO NEUMANN GANDIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001029",
    },
    {
        "school": "DR. PILA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001030",
    },
    {
        "school": "ABRAHAM LINCOLN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001038",
    },
    {
        "school": "JOSEFINA BOYA LEON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001041",
    },
    {
        "school": "ANGELA CORDERO BERNARD",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001042",
    },
    {
        "school": "ANDRES GRILLASCA SALAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001043",
    },
    {
        "school": "ISMAEL MALDONADO LUGARO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001044",
    },
    {
        "school": "PONCE HIGH SCHOOL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001045",
    },
    {
        "school": "RAMON MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003001046",
    },
    {
        "school": "CAPITANEJO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001050",
    },
    {
        "school": "ERNESTO RAMOS ANTONINI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001057",
    },
    {
        "school": "JULIO COLLAZO SILVA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001062",
    },
    {
        "school": "LUCY GRILLASCA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001095",
    },
    {
        "school": "HEMETERIO COLON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001100",
    },
    {
        "school": "LILA MARIA MERCEDES MAYORAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001101",
    },
    {
        "school": "BERNARDINO CORDERO BERNARD",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001102",
    },
    {
        "school": "FERNANDO LUIS MALAVE OLIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001104",
    },
    {
        "school": "RODULFO DEL VALLE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001107",
    },
    {
        "school": "HERMINIA GARCIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001109",
    },
    {
        "school": "DR. RAFAEL PUJALS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001111",
    },
    {
        "school": "SUPERIOR JUAN SERRALES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001125",
    },
    {
        "school": "MANUEL GONZALEZ PATO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001832",
    },
    {
        "school": "SOR ISOLINA FERRE (VILLA DEL CARMEN)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001836",
    },
    {
        "school": "JUAN CUEVAS ABOY",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001843",
    },
    {
        "school": "BETHZAIDA VELAZQUEZ SUPERIOR",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001849",
    },
    {
        "school": "LLANOS DEL SUR",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001850",
    },
    {
        "school": "JUAN MORELL CAMPOS (MUSICA )",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Not reported",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001930",
    },
    {
        "school": "JARDINES DE PONCE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001936",
    },
    {
        "school": "SUPERIOR JARDINES DE PONCE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001937",
    },
    {
        "school": "EUGENIO LE COMPTE BENITEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001938",
    },
    {
        "school": "AUREA E. RIVERA COLLAZO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002010",
    },
    {
        "school": "SANTA TERESITA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002011",
    },
    {
        "school": "CARMEN SOLA DE PEDREIRA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002022",
    },
    {
        "school": "DR PEDRO ALBIZU CAMPOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002035",
    },
    {
        "school": "INTERMEDIA JUAN SERRALLES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002082",
    },
    {
        "school": "DR. PEDRO ALBIZU CAMPOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000101",
    },
    {
        "school": "MANUEL RAMOS HERNANDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000331",
    },
    {
        "school": "RAMON EMETERIO BETANCES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001693",
    },
    {
        "school": "JUAN ALEJO ARIZMENDI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001695",
    },
    {
        "school": "SU LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001703",
    },
    {
        "school": "SU HONORIO HERNANDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001704",
    },
    {
        "school": "MANUEL GARCIA PEREZ (NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000399",
    },
    {
        "school": "CONRADO RODRIGUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000587",
    },
    {
        "school": "RAFAEL DE JESUS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000346",
    },
    {
        "school": "LIBERATA IRALDO (NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000347",
    },
    {
        "school": "PEDRO FALU ORELLANO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000348",
    },
    {
        "school": "FELIX SANCHEZ CRUZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000354",
    },
    {
        "school": "RAFAEL REXACH DUENO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000362",
    },
    {
        "school": "CASIANO CEPEDA (INTERMEDIA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000363",
    },
    {
        "school": "EDMUNDO DEL VALLE CRUZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001822",
    },
    {
        "school": "JOSE R. GAZTAMBIDE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000559",
    },
    {
        "school": "BLANCA MALARET",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000562",
    },
    {
        "school": "SU DAVID ANTONGIORGI CORDOVA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000573",
    },
    {
        "school": "MANUEL GONZALEZ MELO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000599",
    },
    {
        "school": "SU URBANA SALINAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000310",
    },
    {
        "school": "SU SABANA LLANA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000464",
    },
    {
        "school": "FELIX GARAY ORTIZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000998",
    },
    {
        "school": "LAS MAREAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001001",
    },
    {
        "school": "JOSE PADIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001006",
    },
    {
        "school": "COQUI INTERMEDIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001007",
    },
    {
        "school": "STELLA MARQUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001990",
    },
    {
        "school": "EUGENIO GUERRA CRUZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002066",
    },
    {
        "school": "HENRY W. LONGFELLOW",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000538",
    },
    {
        "school": "JULIO VICTOR GUZMAN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000539",
    },
    {
        "school": "LOLA RODRIGUEZ DE TIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000540",
    },
    {
        "school": "BARTOLOME DE LAS CASAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000544",
    },
    {
        "school": "MARIANO ABRIL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000545",
    },
    {
        "school": "GEORGINA ALVARADO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000550",
    },
    {
        "school": "HERMINIA C. RAMIREZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000552",
    },
    {
        "school": "SU FRANCISCO MARIA QUINONES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000556",
    },
    {
        "school": "LAURA MERCADO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000557",
    },
    {
        "school": "FEDERICO ASENJO (PRE-TECNICA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000061",
    },
    {
        "school": "JUAN PONCE DE LEON (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000076",
    },
    {
        "school": "INSTITUTO LOAIZA CORDERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000242",
    },
    {
        "school": "ANTERA ROSADO FUENTES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000345",
    },
    {
        "school": "LCDO GUILLERMO ATILES MOREAU",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000408",
    },
    {
        "school": "BELEN BLANCO DE ZEQUEIRA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000435",
    },
    {
        "school": "JOBOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000437",
    },
    {
        "school": "MEDIANIA ALTA ELEMENTAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000440",
    },
    {
        "school": "BRYAN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000606",
    },
    {
        "school": "DR SILVERIO MEDINA GAUD (CONSUMO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000611",
    },
    {
        "school": "SU LAURO GONZALEZ HIJO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000615",
    },
    {
        "school": "ANTONIA B. CAIMARY",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001251",
    },
    {
        "school": "MANUEL BOADA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001253",
    },
    {
        "school": "DR. JULIO J. HENNA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001256",
    },
    {
        "school": "ALEJANDRO TAPIA Y RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001258",
    },
    {
        "school": "FRAY BARTOLOME DE LAS CASAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001262",
    },
    {
        "school": "ERNESTO RAMOS ANTONINI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001265",
    },
    {
        "school": "DR. FACUNDO BUESO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001266",
    },
    {
        "school": "ALBERT EINSTEIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001267",
    },
    {
        "school": "MANUEL ELZABURU VIZCARRONDO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001268",
    },
    {
        "school": "DR. FRANCISCO HERNANDEZ Y GAETAN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001273",
    },
    {
        "school": "LUIS LLORENS TORRES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001274",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001275",
    },
    {
        "school": "LUIS RODRIGUEZ CABRERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001277",
    },
    {
        "school": "ABRAHAM LINCOLN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001278",
    },
    {
        "school": "RAFAEL MARIA DE LABRA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001279",
    },
    {
        "school": "REPUBLICA DEL PERU",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001280",
    },
    {
        "school": "RAFAEL CORDERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001281",
    },
    {
        "school": "PADRE RUFO (BILINGUE)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001282",
    },
    {
        "school": "JOSE JULIAN ACOSTA (TEATRO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001283",
    },
    {
        "school": "RAMON POWER Y GIRALT",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001285",
    },
    {
        "school": "CENTRAL ARTES VISUALES (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001286",
    },
    {
        "school": "DR. JOSE CELSO BARBOSA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001287",
    },
    {
        "school": "RAFAEL RIVERA OTERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001289",
    },
    {
        "school": "LUIS MUNIZ SOUFFRONT",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001290",
    },
    {
        "school": "EVARISTO RIVERA CHEVREMONT",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001293",
    },
    {
        "school": "RAFAEL HERNANDEZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001294",
    },
    {
        "school": "JUAN B. HUYKE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001298",
    },
    {
        "school": "REPUBLICA DE BRAZIL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001299",
    },
    {
        "school": "JULIO SELLES SOLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001300",
    },
    {
        "school": "WILLIAM D. BOYCE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001301",
    },
    {
        "school": "SOTERO FIGUEROA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001302",
    },
    {
        "school": "LUZ ENEIDA COLON (LA CUMBRE)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001305",
    },
    {
        "school": "EL SENORIAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001307",
    },
    {
        "school": "AMALIA MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001309",
    },
    {
        "school": "SU DR ARTURO MORALES CARRION",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001310",
    },
    {
        "school": "INES M MENDOZA VDA DE MUNOZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001318",
    },
    {
        "school": "JUAN ANTONIO CORRETJER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001319",
    },
    {
        "school": "FELIPE GUTIERREZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001323",
    },
    {
        "school": "VILLA CAPRI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001326",
    },
    {
        "school": "BERWIND ELEMENTAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001328",
    },
    {
        "school": "BERWIND INTERMEDIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001330",
    },
    {
        "school": "ANTONIO SARRIERA EGOZCUE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001332",
    },
    {
        "school": "BERWIND SUPERIOR",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001333",
    },
    {
        "school": "AMALIA MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001336",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001337",
    },
    {
        "school": "ANGELES PASTOR (SAN MARTIN)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001339",
    },
    {
        "school": "SAN AGUSTIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001341",
    },
    {
        "school": "CARMEN GOMEZ TEJERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001344",
    },
    {
        "school": "VILLA GRANADA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001346",
    },
    {
        "school": "REPUBLICA DE COLOMBIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001347",
    },
    {
        "school": "MIGUEL SUCH",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001348",
    },
    {
        "school": "RAMON VILA MAYO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001349",
    },
    {
        "school": "SANTIAGO IGLESIAS PANTIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001350",
    },
    {
        "school": "JUANITA GARCIA PERAZA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001351",
    },
    {
        "school": "MANUEL A. PEREZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001352",
    },
    {
        "school": "RAFAEL HERNANDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001354",
    },
    {
        "school": "GUSTAVO A. BECQUER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001356",
    },
    {
        "school": "PACHIN MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001358",
    },
    {
        "school": "JUAN RAMON JIMENEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001359",
    },
    {
        "school": "JUAN PONCE DE LEON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001361",
    },
    {
        "school": "EMILIO DEL TORO CUEVAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001362",
    },
    {
        "school": "PEDRO CARLOS TIMOTHEE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001363",
    },
    {
        "school": "ELEONOR ROOSEVELT",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001364",
    },
    {
        "school": "DR. ANTONIO S. PEDREIRA (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001370",
    },
    {
        "school": "PEDRO C. TIMOTHEE ANEXO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003001371",
    },
    {
        "school": "LAS AMERICAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001373",
    },
    {
        "school": "GABRIELA MISTRAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001374",
    },
    {
        "school": "VICTOR PARES COLLAZO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003001376",
    },
    {
        "school": "JUAN JOSE OSUNA (ESPSECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001377",
    },
    {
        "school": "ERNESTO RAMOS ANTONINI (MUSICA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001378",
    },
    {
        "school": "TRINA PADILLA DE SANZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001379",
    },
    {
        "school": "LUIS MUNOZ RIVERA II",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001381",
    },
    {
        "school": "SANTIAGO IGLESIAS PANTIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001384",
    },
    {
        "school": "RAMON MARIN SOLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001387",
    },
    {
        "school": "RAFAEL MARTINEZ NADAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001388",
    },
    {
        "school": "ROSALINA C. MARTINEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001391",
    },
    {
        "school": "MARGARITA JANER PALACIOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001392",
    },
    {
        "school": "SANTA ROSA III",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001394",
    },
    {
        "school": "BETTY ROSADO DE VEGA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001405",
    },
    {
        "school": "MARIANO ABRIL ELEMENTAL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001407",
    },
    {
        "school": "PEDRO MOCZO BANIET",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001457",
    },
    {
        "school": "PASCASIO P. SANCERRIT",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001459",
    },
    {
        "school": "ROBERTO CLEMENTE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001460",
    },
    {
        "school": "EDUARDO J. SALDANA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001467",
    },
    {
        "school": "PETRA ROMAN VIGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001468",
    },
    {
        "school": "DR. JOSE M. LAZARO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001469",
    },
    {
        "school": "MARIA TERESA SERRANO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001470",
    },
    {
        "school": "JESUS MARIA SANROMA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001471",
    },
    {
        "school": "FRANCISCO MATIAS LUGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001472",
    },
    {
        "school": "DR. MODESTO RIVERA RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001473",
    },
    {
        "school": "AGUSTIN CABRERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001475",
    },
    {
        "school": "MANUEL FEBRES GONZALEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001476",
    },
    {
        "school": "LUZ AMERICA CALDERON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001477",
    },
    {
        "school": "JOSE SEVERO QUINONES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001481",
    },
    {
        "school": "JESUS MANUEL SUAREZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001490",
    },
    {
        "school": "JESUS T. PINERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001494",
    },
    {
        "school": "SALVADOR BRAU",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001495",
    },
    {
        "school": "JOSE F. DIAZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001591",
    },
    {
        "school": "RENE MARQUES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001839",
    },
    {
        "school": "JUAN E. MIRANDA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001852",
    },
    {
        "school": "JOSEFINA BARCELO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001853",
    },
    {
        "school": "GILBERTO CONCEPCION DE GRACIA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001878",
    },
    {
        "school": "GUILLERMINA ROSADO DE AYALA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001881",
    },
    {
        "school": "EVA Y PATRIA CUSTODIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001928",
    },
    {
        "school": "CENTRO EUGENIO MARIA DE HOSTOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003001941",
    },
    {
        "school": "UNIVERSITY GARDENS (ESPECIALIZADA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001943",
    },
    {
        "school": "GASPAR VILA MAYANS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001944",
    },
    {
        "school": "JULIAN E BLANCO (BALLET)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001991",
    },
    {
        "school": "RVDO FELIX CASTRO RODRIGUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001992",
    },
    {
        "school": "CELSO GONZALEZ VAILLANT",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002002",
    },
    {
        "school": "VENUS GARDENS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002012",
    },
    {
        "school": "FRANCISCO (PRISCO) FUENTES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002013",
    },
    {
        "school": "LA ESPERANZA (LUIS PALES MATOS)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003002023",
    },
    {
        "school": "JUANA A MENDEZ (METROPOLIS)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002025",
    },
    {
        "school": "LORENZO VIZCARRONDO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002069",
    },
    {
        "school": "ANGEL P. MILLAN ROHENA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002073",
    },
    {
        "school": "NEMESIO R. CANALES I",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002084",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000004",
    },
    {
        "school": "GENEROSO MORALES MUNOZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000005",
    },
    {
        "school": "JOSE CAMPECHE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000006",
    },
    {
        "school": "SU JAGUAL ADENTRO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000016",
    },
    {
        "school": "SU CARLOS ZAYAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000030",
    },
    {
        "school": "DRA. MARIA T DELGADO DE MARCANO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000311",
    },
    {
        "school": "MANUEL MENDEZ LICIAGA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000501",
    },
    {
        "school": "AUREA FUENTES MENDEZ (CALABAZAS INFANTES)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000854",
    },
    {
        "school": "SU BERNALDO MENDEZ JIMENEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000856",
    },
    {
        "school": "SU MAXIMINO A. SALAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000858",
    },
    {
        "school": "SU CARMELO SERRANO CUBANO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000859",
    },
    {
        "school": "EMILIO SCHARON RODRIGUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001927",
    },
    {
        "school": "ERNESTINA MENDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002017",
    },
    {
        "school": "PATRIA LATORRE RAMIREZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002062",
    },
    {
        "school": "ELVIRA M. COLON NEGRON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000182",
    },
    {
        "school": "MARTIN G. BRUMBAUGH",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001009",
    },
    {
        "school": "MANUEL MARTIN MONSERRATE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001011",
    },
    {
        "school": "ANA VALLDEJULY (JAUCA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001013",
    },
    {
        "school": "PEDRO MELENDEZ SANTIAGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001019",
    },
    {
        "school": "ADELA ROLON FUENTES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000370",
    },
    {
        "school": "VIOLANTA JIMENEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001238",
    },
    {
        "school": "JOSE PABLO MORALES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001239",
    },
    {
        "school": "NICOLAS SEVILLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001240",
    },
    {
        "school": "JOSE MARIA DEL VALLE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001241",
    },
    {
        "school": "MANUEL VELILLA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001249",
    },
    {
        "school": "MARIA C. OSORIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001876",
    },
    {
        "school": "ABELARDO DIAZ ALFARO (INT. PINAS)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002076",
    },
    {
        "school": "ALEJANDRO JR CRUZ (GALATEO PARCELAS)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002078",
    },
    {
        "school": "MARTIN GARCIA GIUSTI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000409",
    },
    {
        "school": "DELIA DAVILA DE CABAN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001219",
    },
    {
        "school": "DR. EFRAIN SANCHEZ HIDALGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001220",
    },
    {
        "school": "CARMEN BARROSO MORALES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001222",
    },
    {
        "school": "DR PEDRO ALBIZU CAMPOS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001223",
    },
    {
        "school": "FRANCISCA DAVILA SEMPRIT",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001226",
    },
    {
        "school": "LUIS M. SANTIAGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001228",
    },
    {
        "school": "ADOLFINA IRIZARRY DE PUIG",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001230",
    },
    {
        "school": "JOSE ROBLES OTERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001231",
    },
    {
        "school": "ALTINENCIA VALLE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001232",
    },
    {
        "school": "JOSE NEVAREZ LOPEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001233",
    },
    {
        "school": "ERNESTINA BRACERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001236",
    },
    {
        "school": "BASILIO MILAN HERNANDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001835",
    },
    {
        "school": "MARIA TERESA PINEIRO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001875",
    },
    {
        "school": "MARIA J. CORREDOR RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001998",
    },
    {
        "school": "ILEANA DE GRACIA (SUPERIOR NUEVA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000410",
    },
    {
        "school": "CARLOS F DANIELS (VOC. DE AREA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001483",
    },
    {
        "school": "TULIO LARRINAGA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001586",
    },
    {
        "school": "FAIR VIEW",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001587",
    },
    {
        "school": "ANDRES VALCARCEL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001588",
    },
    {
        "school": "MEDARDO CARAZO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001589",
    },
    {
        "school": "JESUS SILVA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001597",
    },
    {
        "school": "HERMINA DIAZ APONTE (LAGO ALTO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001599",
    },
    {
        "school": "ELEMENTAL URBANA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001783",
    },
    {
        "school": "ANTONIO PAOLI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001784",
    },
    {
        "school": "APOLO SAN ANTONIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001787",
    },
    {
        "school": "LADISLAO MARTINEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001788",
    },
    {
        "school": "ELISA DAVILA VAZQUEZ (ESPINOSA ADENTRO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001790",
    },
    {
        "school": "EL CONQUISTADOR",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001830",
    },
    {
        "school": "PETRA ZENON DE FABERY",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003002070",
    },
    {
        "school": "BERNARDO GONZALEZ COLON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001758",
    },
    {
        "school": "MARIA LIBERTAD GOMEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001760",
    },
    {
        "school": "FRANCISCO RAMOS SANCHEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001761",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001762",
    },
    {
        "school": "FRANCISCO JORDAN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001776",
    },
    {
        "school": "SU MARTA LAFONTAINE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001777",
    },
    {
        "school": "ANTONIO TULLA TORRES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001778",
    },
    {
        "school": "INOCENCIO A. MONTERO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001781",
    },
    {
        "school": "JOSE VIZCARRONDO (SU ANGELES)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001782",
    },
    {
        "school": "JUDITH A VIVAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001971",
    },
    {
        "school": "FRANCISCO FELICIE MARTINEZ (SU BRENAS)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000531",
    },
    {
        "school": "RAFAEL HERNANDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001785",
    },
    {
        "school": "IGNACIO MIRANDA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001786",
    },
    {
        "school": "CENTRO DE ADIESTRAMIENTO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "PR",
        "nces_id": "720003000249",
    },
    {
        "school": "SAN VICENTE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001798",
    },
    {
        "school": "ANGEL SANDIN MARTINEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001799",
    },
    {
        "school": "LINO PADRO RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001800",
    },
    {
        "school": "RAFAEL HERNANDEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001816",
    },
    {
        "school": "MANUEL MARTINEZ DAVILA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001818",
    },
    {
        "school": "SU ALMIRANTE NORTE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001819",
    },
    {
        "school": "AGAPITO ROSARIO ROSARIO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002026",
    },
    {
        "school": "JUAN QUIRINDONGO MORELL (SUPERIOR)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002085",
    },
    {
        "school": "JUANITA RIVERA ALBERT",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000337",
    },
    {
        "school": "PLAYA GRANDE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000339",
    },
    {
        "school": "ADRIANNE SERRANO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000343",
    },
    {
        "school": "SU HATILLO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000875",
    },
    {
        "school": "NORMA I. TORRES COLON",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001834",
    },
    {
        "school": "JOSE F. CINTRON Y ANEXO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000303",
    },
    {
        "school": "TEODORO AGUILAR MORA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000306",
    },
    {
        "school": "MARTA SANCHEZ (GUAYABO)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000315",
    },
    {
        "school": "JAIME C. RODRIGUEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000320",
    },
    {
        "school": "CRISTOBAL DEL CAMPO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000323",
    },
    {
        "school": "SU ANDRES SANDIN MARTINEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000324",
    },
    {
        "school": "SU JESUS T SANABRIA CRUZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000327",
    },
    {
        "school": "SU ROGELIO ROSADO (SU PLAYITA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000328",
    },
    {
        "school": "SU ASUNCION LUGO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000329",
    },
    {
        "school": "SU MANUEL ORTIZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000330",
    },
    {
        "school": "ROSA COSTA VALDIVESO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001864",
    },
    {
        "school": "LUIS MUNOZ MARIN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001873",
    },
    {
        "school": "PROFESORA LUISA MONSEGUR VELEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000515",
    },
    {
        "school": "LENA M. FRANCESCH (RUBIAS KM. 25)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000882",
    },
    {
        "school": "ARTURO LLUBERAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000884",
    },
    {
        "school": "DORIS MARTINEZ (ALMACIGO ALTO 2)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000887",
    },
    {
        "school": "LUIS MUNOZ RIVERA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000897",
    },
    {
        "school": "SANTIAGO NEGRONI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000901",
    },
    {
        "school": "ELVIRA VICENTE",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000902",
    },
    {
        "school": "SUPERIOR OCUPACIONAL Y TECNICA DE YAUCO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003000903",
    },
    {
        "school": "LUIS A. FERRE AGUAYO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000908",
    },
    {
        "school": "BENICIA VELEZ",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000909",
    },
    {
        "school": "SU JAIME CASTANER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003000918",
    },
    {
        "school": "ERNESTO RAMOS ANTONINI",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002007",
    },
    {
        "school": "JOSE ONOFRE TORRES FERMOSO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002009",
    },
    {
        "school": "INES MARIA MENDOZA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003002068",
    },
    {
        "school": "DCYF Alternative Ed. Program",
        "district": "DCYF",
        "level": "High",
        "type": "Alternative Education School",
        "state": "RI",
        "nces_id": "440000900413",
    },
    {
        "school": "NEL/CPS Construction Career",
        "district": "Cranston",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000229",
    },
    {
        "school": "Orchard Farms El. School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000277",
    },
    {
        "school": "Arlington School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000042",
    },
    {
        "school": "Cranston High School East",
        "district": "Cranston",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000044",
    },
    {
        "school": "Cranston High School West",
        "district": "Cranston",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000045",
    },
    {
        "school": "Daniel D. Waterman School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000046",
    },
    {
        "school": "Eden Park School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000047",
    },
    {
        "school": "Edgewood Highland",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000048",
    },
    {
        "school": "Edward S. Rhodes School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000049",
    },
    {
        "school": "Garden City School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000050",
    },
    {
        "school": "Gladstone Street School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000051",
    },
    {
        "school": "Glen Hills School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000052",
    },
    {
        "school": "Hugh B. Bain Middle School",
        "district": "Cranston",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000053",
    },
    {
        "school": "Oak Lawn School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000059",
    },
    {
        "school": "Park View Middle School",
        "district": "Cranston",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000060",
    },
    {
        "school": "Stadium School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000063",
    },
    {
        "school": "Stone Hill School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000064",
    },
    {
        "school": "Western Hills Middle School",
        "district": "Cranston",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000067",
    },
    {
        "school": "W. R. Dutemple School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000068",
    },
    {
        "school": "Woodridge School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000069",
    },
    {
        "school": "George J. Peters School",
        "district": "Cranston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000351",
    },
    {
        "school": "Cranston Career & Tech Center",
        "district": "Cranston",
        "level": "High",
        "type": "Career and Technical School",
        "state": "RI",
        "nces_id": "440024000458",
    },
    {
        "school": "Springbrook Elementary School",
        "district": "Westerly",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440117000120",
    },
    {
        "school": "Westerly Middle School",
        "district": "Westerly",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440117000319",
    },
    {
        "school": "Dunn's Corners School",
        "district": "Westerly",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440117000321",
    },
    {
        "school": "Westerly High School",
        "district": "Westerly",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440117000325",
    },
    {
        "school": "State Street School",
        "district": "Westerly",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440117000362",
    },
    {
        "school": "Alan Shawn Feinstein MS of Cov",
        "district": "Coventry",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440021000465",
    },
    {
        "school": "Wakefield Hills El. School",
        "district": "West Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440114000238",
    },
    {
        "school": "R.I. School for the Deaf",
        "district": "R.I. Sch for the Deaf",
        "level": "Other",
        "type": "Special education school",
        "state": "RI",
        "nces_id": "440000100380",
    },
    {
        "school": "Metropolitan Career Tech Ctr",
        "district": "MET Career and Tech",
        "level": "High",
        "type": "Career and Technical School",
        "state": "RI",
        "nces_id": "440000300121",
    },
    {
        "school": "Davies Career-Tech High School",
        "district": "Davies Career and Tech",
        "level": "High",
        "type": "Career and Technical School",
        "state": "RI",
        "nces_id": "440000400379",
    },
    {
        "school": "Urban Collaborative Program",
        "district": "Urban Collaborative",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440000500271",
    },
    {
        "school": "The Learning Community",
        "district": "Learning Community",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440000600326",
    },
    {
        "school": "BEACON Charter School",
        "district": "Beacon Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440000800297",
    },
    {
        "school": "Blackstone Academy Charter",
        "district": "Blackstone Academy",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003600246",
    },
    {
        "school": "Leviton Dual Language School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000237",
    },
    {
        "school": "E-Cubed Academy",
        "district": "Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000323",
    },
    {
        "school": "Dr. Jorge Alvarez HS",
        "district": "Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000344",
    },
    {
        "school": "The Compass School",
        "district": "The Compass School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003500245",
    },
    {
        "school": "Chariho Alternative Learning A",
        "district": "Chariho",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "RI",
        "nces_id": "440015000286",
    },
    {
        "school": "Block Island School",
        "district": "New Shoreham",
        "level": "Other",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440069000149",
    },
    {
        "school": "Hope High School",
        "district": "Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000224",
    },
    {
        "school": "Barrington High School",
        "district": "Barrington",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003000001",
    },
    {
        "school": "Barrington Middle School",
        "district": "Barrington",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003000002",
    },
    {
        "school": "Hampden Meadows School",
        "district": "Barrington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003000003",
    },
    {
        "school": "Nayatt School",
        "district": "Barrington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003000004",
    },
    {
        "school": "Sowams Elementary School",
        "district": "Barrington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003000005",
    },
    {
        "school": "Primrose Hill School",
        "district": "Barrington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003000006",
    },
    {
        "school": "Mt. Hope High School",
        "district": "Bristol Warren",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440006500009",
    },
    {
        "school": "Guiteras School",
        "district": "Bristol Warren",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440006500012",
    },
    {
        "school": "Rockwell School",
        "district": "Bristol Warren",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440006500016",
    },
    {
        "school": "Hugh Cole School",
        "district": "Bristol Warren",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440006500278",
    },
    {
        "school": "Kickemuit Middle School",
        "district": "Bristol Warren",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440006500282",
    },
    {
        "school": "Blackrock School",
        "district": "Coventry",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440021000031",
    },
    {
        "school": "Coventry High School",
        "district": "Coventry",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440021000032",
    },
    {
        "school": "Washington Oak School",
        "district": "Coventry",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440021000034",
    },
    {
        "school": "Hopkins Hill School",
        "district": "Coventry",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440021000035",
    },
    {
        "school": "Western Coventry School",
        "district": "Coventry",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440021000041",
    },
    {
        "school": "Tiogue School",
        "district": "Coventry",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440021000365",
    },
    {
        "school": "East Greenwich High",
        "district": "East Greenwich",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440030000086",
    },
    {
        "school": "Archie R. Cole MS",
        "district": "East Greenwich",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440030000087",
    },
    {
        "school": "Frenchtown School",
        "district": "East Greenwich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440030000088",
    },
    {
        "school": "James H. Eldredge School",
        "district": "East Greenwich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440030000089",
    },
    {
        "school": "Meadowbrook Farms School",
        "district": "East Greenwich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440030000090",
    },
    {
        "school": "George Hanaford School",
        "district": "East Greenwich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440030000377",
    },
    {
        "school": "Mildred E. Lineham School",
        "district": "Exeter-West Greenwich",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440036000112",
    },
    {
        "school": "Exeter-West Greenwich Reg. Jr.",
        "district": "Exeter-West Greenwich",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440036000390",
    },
    {
        "school": "Exeter-West Greenwich Regional",
        "district": "Exeter-West Greenwich",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440036000391",
    },
    {
        "school": "Cedar Hill School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000285",
    },
    {
        "school": "Warwick Early Learning Center",
        "district": "Warwick",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000287",
    },
    {
        "school": "Greenwood School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000291",
    },
    {
        "school": "Holliman School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000293",
    },
    {
        "school": "Hoxsie School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000294",
    },
    {
        "school": "Lippitt School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000296",
    },
    {
        "school": "Norwood School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000298",
    },
    {
        "school": "Oakland Beach School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000299",
    },
    {
        "school": "Park School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000300",
    },
    {
        "school": "Pilgrim High School",
        "district": "Warwick",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000301",
    },
    {
        "school": "Robertson School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000304",
    },
    {
        "school": "Scott School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000305",
    },
    {
        "school": "Sherman School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000306",
    },
    {
        "school": "Toll Gate High School",
        "district": "Warwick",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000307",
    },
    {
        "school": "Warwick Neck School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000308",
    },
    {
        "school": "Winman Middle School",
        "district": "Warwick",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000311",
    },
    {
        "school": "Wyman School",
        "district": "Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000312",
    },
    {
        "school": "Warwick Career and Tech Center",
        "district": "Warwick",
        "level": "High",
        "type": "Career and Technical School",
        "state": "RI",
        "nces_id": "440111000462",
    },
    {
        "school": "John F. Deering Middle",
        "district": "West Warwick",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440114000313",
    },
    {
        "school": "John F. Horgan School",
        "district": "West Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440114000315",
    },
    {
        "school": "West Warwick High School",
        "district": "West Warwick",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440114000318",
    },
    {
        "school": "Greenbush Elementary School",
        "district": "West Warwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440114000402",
    },
    {
        "school": "Jamestown School-Lawn",
        "district": "Jamestown",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440051000123",
    },
    {
        "school": "Jamestown School-Melrose",
        "district": "Jamestown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440051000404",
    },
    {
        "school": "Wilbur and McMahon Schools",
        "district": "Little Compton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440060000140",
    },
    {
        "school": "Aquidneck School",
        "district": "Middletown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440063000141",
    },
    {
        "school": "Joseph H. Gaudet School",
        "district": "Middletown",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440063000144",
    },
    {
        "school": "Middletown High School",
        "district": "Middletown",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440063000147",
    },
    {
        "school": "Forest Avenue School",
        "district": "Middletown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440063000405",
    },
    {
        "school": "Frank E. Thompson Middle",
        "district": "Newport",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440072000155",
    },
    {
        "school": "Rogers High School",
        "district": "Newport",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440072000159",
    },
    {
        "school": "Newport Area Career Tech Ctr",
        "district": "Newport",
        "level": "High",
        "type": "Career and Technical School",
        "state": "RI",
        "nces_id": "440072000460",
    },
    {
        "school": "Howard Hathaway School",
        "district": "Portsmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440087000204",
    },
    {
        "school": "Melville School",
        "district": "Portsmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440087000206",
    },
    {
        "school": "Portsmouth High School",
        "district": "Portsmouth",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440087000207",
    },
    {
        "school": "Portsmouth Middle School",
        "district": "Portsmouth",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440087000208",
    },
    {
        "school": "Pocasset School",
        "district": "Tiverton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440105000273",
    },
    {
        "school": "Tiverton High School",
        "district": "Tiverton",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440105000274",
    },
    {
        "school": "Tiverton Middle School",
        "district": "Tiverton",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440105000275",
    },
    {
        "school": "Ranger School",
        "district": "Tiverton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440105000276",
    },
    {
        "school": "Fort Barton School",
        "district": "Tiverton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440105000357",
    },
    {
        "school": "International Charter School",
        "district": "International Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003400226",
    },
    {
        "school": "Austin T. Levy School",
        "district": "Burrillville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440009000018",
    },
    {
        "school": "Burrillville High School",
        "district": "Burrillville",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440009000019",
    },
    {
        "school": "William Callahan School",
        "district": "Burrillville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440009000022",
    },
    {
        "school": "Steere Farm Elementary School",
        "district": "Burrillville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440009000057",
    },
    {
        "school": "Burrillville Middle School",
        "district": "Burrillville",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440009000383",
    },
    {
        "school": "Calcutt Middle School",
        "district": "Central Falls",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440012000024",
    },
    {
        "school": "G. Harold Hunt School",
        "district": "Central Falls",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440012000025",
    },
    {
        "school": "Central Falls Sr High",
        "district": "Central Falls",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440012000026",
    },
    {
        "school": "Ella Risk School",
        "district": "Central Falls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440012000027",
    },
    {
        "school": "Veterans Memorial Elementary",
        "district": "Central Falls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440012000385",
    },
    {
        "school": "B.F. Norton Elementary School",
        "district": "Cumberland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440027000039",
    },
    {
        "school": "Ashton School",
        "district": "Cumberland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440027000070",
    },
    {
        "school": "Community School",
        "district": "Cumberland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440027000075",
    },
    {
        "school": "Cumberland High School",
        "district": "Cumberland",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440027000076",
    },
    {
        "school": "John J. McLaughlin Cumberland",
        "district": "Cumberland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440027000077",
    },
    {
        "school": "Joseph L. McCourt MS",
        "district": "Cumberland",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440027000078",
    },
    {
        "school": "Garvin Memorial",
        "district": "Cumberland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440027000081",
    },
    {
        "school": "North Cumberland Middle",
        "district": "Cumberland",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440027000082",
    },
    {
        "school": "Cumberland Preschool Center",
        "district": "Cumberland",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440027000188",
    },
    {
        "school": "Agnes B. Hennessey School",
        "district": "East Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000091",
    },
    {
        "school": "Waddington School",
        "district": "East Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000092",
    },
    {
        "school": "East Providence High",
        "district": "East Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000097",
    },
    {
        "school": "Kent Heights School",
        "district": "East Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000099",
    },
    {
        "school": "Orlo Avenue School",
        "district": "East Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000103",
    },
    {
        "school": "Riverside Middle School",
        "district": "East Providence",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000105",
    },
    {
        "school": "Silver Spring School",
        "district": "East Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000106",
    },
    {
        "school": "Emma G. Whiteknact School",
        "district": "East Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000109",
    },
    {
        "school": "Edward Martin Middle",
        "district": "East Providence",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000348",
    },
    {
        "school": "Myron J. Francis Elementary",
        "district": "East Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000389",
    },
    {
        "school": "East Providence Career Tech",
        "district": "East Providence",
        "level": "High",
        "type": "Career and Technical School",
        "state": "RI",
        "nces_id": "440033000459",
    },
    {
        "school": "Capt. Isaac Paine El. School",
        "district": "Foster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440039000114",
    },
    {
        "school": "Ponaganset High School",
        "district": "Foster-Glocester",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440042000116",
    },
    {
        "school": "Ponaganset Middle School",
        "district": "Foster-Glocester",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440042000117",
    },
    {
        "school": "Fogarty Memorial",
        "district": "Glocester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440045000119",
    },
    {
        "school": "West Glocester Elementary",
        "district": "Glocester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440045000403",
    },
    {
        "school": "Brown Avenue School",
        "district": "Johnston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440054000125",
    },
    {
        "school": "Graniteville School",
        "district": "Johnston",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440054000127",
    },
    {
        "school": "Johnston Senior High",
        "district": "Johnston",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440054000128",
    },
    {
        "school": "Nicholas A. Ferri Middle",
        "district": "Johnston",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440054000129",
    },
    {
        "school": "Sarah Dyer Barnes School",
        "district": "Johnston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440054000130",
    },
    {
        "school": "Thornton School",
        "district": "Johnston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440054000131",
    },
    {
        "school": "Winsor Hill School",
        "district": "Johnston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440054000132",
    },
    {
        "school": "Early Childhood Center",
        "district": "Johnston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440054000452",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Lincoln",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440057000062",
    },
    {
        "school": "Lincoln Central Elem.",
        "district": "Lincoln",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440057000134",
    },
    {
        "school": "Lincoln Senior High School",
        "district": "Lincoln",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440057000135",
    },
    {
        "school": "Lonsdale Elementary",
        "district": "Lincoln",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440057000137",
    },
    {
        "school": "Northern Lincoln Elem.",
        "district": "Lincoln",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440057000138",
    },
    {
        "school": "Saylesville Elementary",
        "district": "Lincoln",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440057000139",
    },
    {
        "school": "Birchwood Middle School",
        "district": "North Providence",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440078000173",
    },
    {
        "school": "Centredale School",
        "district": "North Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440078000174",
    },
    {
        "school": "Greystone School",
        "district": "North Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440078000176",
    },
    {
        "school": "James L. McGuire School",
        "district": "North Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440078000177",
    },
    {
        "school": "Dr. Edward Ricci School",
        "district": "North Providence",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440078000178",
    },
    {
        "school": "North Providence High",
        "district": "North Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440078000180",
    },
    {
        "school": "Stephen Olney School",
        "district": "North Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440078000181",
    },
    {
        "school": "Joseph A. Whelan School",
        "district": "North Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440078000182",
    },
    {
        "school": "North Smitfield HS",
        "district": "North Smithfield",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440081000186",
    },
    {
        "school": "North Smithfield Elementary",
        "district": "North Smithfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440081000399",
    },
    {
        "school": "Agnes E. Little School",
        "district": "Pawtucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000187",
    },
    {
        "school": "Curvin-McCabe School",
        "district": "Pawtucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000189",
    },
    {
        "school": "Cunningham School",
        "district": "Pawtucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000190",
    },
    {
        "school": "Elizabeth Baldwin School",
        "district": "Pawtucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000191",
    },
    {
        "school": "Fallon Memorial School",
        "district": "Pawtucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000192",
    },
    {
        "school": "Flora S. Curtis School",
        "district": "Pawtucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000193",
    },
    {
        "school": "Francis J. Varieur School",
        "district": "Pawtucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000194",
    },
    {
        "school": "Henry J. Winters School",
        "district": "Pawtucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000195",
    },
    {
        "school": "Potter-Burns School",
        "district": "Pawtucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000196",
    },
    {
        "school": "Joseph Jenks Middle School",
        "district": "Pawtucket",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000197",
    },
    {
        "school": "Lyman B. Goff Middle School",
        "district": "Pawtucket",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000198",
    },
    {
        "school": "Nathanael Greene School",
        "district": "Pawtucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000199",
    },
    {
        "school": "Samuel Slater Middle School",
        "district": "Pawtucket",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000200",
    },
    {
        "school": "Charles E. Shea High School",
        "district": "Pawtucket",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000201",
    },
    {
        "school": "William E. Tolman High",
        "district": "Pawtucket",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000202",
    },
    {
        "school": "Veazie Street School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000013",
    },
    {
        "school": "Academy for Career Exploration",
        "district": "Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000055",
    },
    {
        "school": "Robert L. Bailey IV",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000071",
    },
    {
        "school": "Frank D. Spaziano Annex",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000093",
    },
    {
        "school": "Alfred Lima  Sr. El School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000124",
    },
    {
        "school": "Charles N. Fortes Academy",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000133",
    },
    {
        "school": "Cornel Young & Charlotte Woods",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000156",
    },
    {
        "school": "Anthony Carnevale Elementary",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000162",
    },
    {
        "school": "Governor Christopher DelSesto",
        "district": "Providence",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000175",
    },
    {
        "school": "W B Cooley & Acad Internationa",
        "district": "Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000209",
    },
    {
        "school": "Asa Messer El. School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000213",
    },
    {
        "school": "Alan Shawn Feinstein Elem.",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000215",
    },
    {
        "school": "Harry Kizirian Elementary",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000216",
    },
    {
        "school": "Central High School",
        "district": "Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000217",
    },
    {
        "school": "Classical High School",
        "district": "Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000218",
    },
    {
        "school": "Vartan Gregorian El. School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000221",
    },
    {
        "school": "George J. West El. School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000222",
    },
    {
        "school": "Gilbert Stuart Middle School",
        "district": "Providence",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000223",
    },
    {
        "school": "Carl G. Lauro El. School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000227",
    },
    {
        "school": "Frank D. Spaziano Elem School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000228",
    },
    {
        "school": "Martin Luther King El. School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000230",
    },
    {
        "school": "Mary E. Fogarty El. School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000231",
    },
    {
        "school": "Mount Pleasant High",
        "district": "Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000232",
    },
    {
        "school": "Nathanael Greene Middle",
        "district": "Providence",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000234",
    },
    {
        "school": "Pleasant View School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000236",
    },
    {
        "school": "Reservoir Avenue School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000240",
    },
    {
        "school": "Robert F. Kennedy El. School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000241",
    },
    {
        "school": "Roger Williams Middle",
        "district": "Providence",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000242",
    },
    {
        "school": "Lillian Feinstein El. School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000243",
    },
    {
        "school": "Webster Avenue School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000247",
    },
    {
        "school": "William D'Abate Elem. School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000248",
    },
    {
        "school": "Esek Hopkins Middle",
        "district": "Providence",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000401",
    },
    {
        "school": "Scituate Middle School",
        "district": "Scituate",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440096000036",
    },
    {
        "school": "Clayville School",
        "district": "Scituate",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440096000252",
    },
    {
        "school": "Hope School",
        "district": "Scituate",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440096000253",
    },
    {
        "school": "North Scituate School",
        "district": "Scituate",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440096000254",
    },
    {
        "school": "Scituate High School",
        "district": "Scituate",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440096000255",
    },
    {
        "school": "Anna M. McCabe School",
        "district": "Smithfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440099000256",
    },
    {
        "school": "Raymond LaPerche School",
        "district": "Smithfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440099000257",
    },
    {
        "school": "Old County Road School",
        "district": "Smithfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440099000258",
    },
    {
        "school": "Smithfield High School",
        "district": "Smithfield",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440099000259",
    },
    {
        "school": "Vincent J. Gallagher Middle",
        "district": "Smithfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440099000260",
    },
    {
        "school": "William Winsor School",
        "district": "Smithfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440099000261",
    },
    {
        "school": "Bernon Heights School",
        "district": "Woonsocket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440120000327",
    },
    {
        "school": "Leo A. Savoie School",
        "district": "Woonsocket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440120000330",
    },
    {
        "school": "Kevin K. Coleman School",
        "district": "Woonsocket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440120000331",
    },
    {
        "school": "Globe Park School",
        "district": "Woonsocket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440120000334",
    },
    {
        "school": "Harris School",
        "district": "Woonsocket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440120000336",
    },
    {
        "school": "Woonsocket High School",
        "district": "Woonsocket",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440120000345",
    },
    {
        "school": "Woonsocket Career an Tech Ctr.",
        "district": "Woonsocket",
        "level": "High",
        "type": "Career and Technical School",
        "state": "RI",
        "nces_id": "440120000464",
    },
    {
        "school": "Kingston Hill Academy",
        "district": "Kingston Hill Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003300225",
    },
    {
        "school": "Chariho High School",
        "district": "Chariho",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440015000029",
    },
    {
        "school": "Charlestown Elementary School",
        "district": "Chariho",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440015000030",
    },
    {
        "school": "Ashaway Elementary School",
        "district": "Chariho",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440015000122",
    },
    {
        "school": "Richmond Elementary School",
        "district": "Chariho",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440015000251",
    },
    {
        "school": "Hope Valley Elementary School",
        "district": "Chariho",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440015000349",
    },
    {
        "school": "Chariho Regional Middle School",
        "district": "Chariho",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440015000386",
    },
    {
        "school": "Chariho Career and Tech Center",
        "district": "Chariho",
        "level": "High",
        "type": "Career and Technical School",
        "state": "RI",
        "nces_id": "440015000457",
    },
    {
        "school": "Wawaloam School",
        "district": "Exeter-West Greenwich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440036000038",
    },
    {
        "school": "Metcalf School",
        "district": "Exeter-West Greenwich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440036000111",
    },
    {
        "school": "Narragansett Elementary",
        "district": "Narragansett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440066000150",
    },
    {
        "school": "Narragansett High School",
        "district": "Narragansett",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440066000151",
    },
    {
        "school": "Narragansett Pier School",
        "district": "Narragansett",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440066000396",
    },
    {
        "school": "Davisville Middle School",
        "district": "North Kingstown",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440075000165",
    },
    {
        "school": "Forest Park El. School",
        "district": "North Kingstown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440075000166",
    },
    {
        "school": "Hamilton School",
        "district": "North Kingstown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440075000167",
    },
    {
        "school": "North Kingstown Sr. High",
        "district": "North Kingstown",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440075000168",
    },
    {
        "school": "Suzanne M. Henseler Quidnesset",
        "district": "North Kingstown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440075000169",
    },
    {
        "school": "Stony Lane El. School",
        "district": "North Kingstown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440075000170",
    },
    {
        "school": "Wickford Middle School",
        "district": "North Kingstown",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440075000172",
    },
    {
        "school": "Fishing Cove El. School",
        "district": "North Kingstown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440075000398",
    },
    {
        "school": "Broad Rock Middle School",
        "district": "South Kingstown",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440102000210",
    },
    {
        "school": "Matunuck School",
        "district": "South Kingstown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440102000263",
    },
    {
        "school": "Peace Dale School",
        "district": "South Kingstown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440102000264",
    },
    {
        "school": "South Kingstown High",
        "district": "South Kingstown",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440102000265",
    },
    {
        "school": "Curtis Corner Middle School",
        "district": "South Kingstown",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440102000266",
    },
    {
        "school": "Wakefield School",
        "district": "South Kingstown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440102000269",
    },
    {
        "school": "West Kingston School",
        "district": "South Kingstown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440102000270",
    },
    {
        "school": "Daniel Island School",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001472",
    },
    {
        "school": "Orange Grove Charter School",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001457",
    },
    {
        "school": "Academy for Teaching and Learning",
        "district": "Chester 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450153001020",
    },
    {
        "school": "Summerton Early Childhood Center",
        "district": "Clarendon 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450174001494",
    },
    {
        "school": "Thomas E. Kerns Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001035",
    },
    {
        "school": "Sterling School",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001466",
    },
    {
        "school": "Ocean Bay Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001458",
    },
    {
        "school": "Ocean Bay Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001470",
    },
    {
        "school": "Black Water Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001471",
    },
    {
        "school": "Oak Pointe Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282001054",
    },
    {
        "school": "Carolina School for Inquiry",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001463",
    },
    {
        "school": "Sandlapper Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001075",
    },
    {
        "school": "Polo Road Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001076",
    },
    {
        "school": "Oakridge Middle",
        "district": "York 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450384001100",
    },
    {
        "school": "Springfield Middle",
        "district": "York 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001102",
    },
    {
        "school": "Barnwell Elementary",
        "district": "Barnwell 45",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450108001163",
    },
    {
        "school": "Pageland Elementary",
        "district": "Chesterfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000870",
    },
    {
        "school": "Chesterfield-Ruby Middle",
        "district": "Chesterfield 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156001173",
    },
    {
        "school": "John C. Calhoun Elementary",
        "district": "Abbeville 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450069000002",
    },
    {
        "school": "Wright Middle",
        "district": "Abbeville 60",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450069000010",
    },
    {
        "school": "Abbeville High",
        "district": "Abbeville 60",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450069000011",
    },
    {
        "school": "Dixie High",
        "district": "Abbeville 60",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450069000012",
    },
    {
        "school": "Cherokee Trail Elementary",
        "district": "Abbeville 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450069000065",
    },
    {
        "school": "Diamond Hill Elementary",
        "district": "Abbeville 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450069000066",
    },
    {
        "school": "Long Cane Primary",
        "district": "Abbeville 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450069000071",
    },
    {
        "school": "Abbeville County Career Center",
        "district": "Abbeville 60",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450069001188",
    },
    {
        "school": "Westwood Elementary",
        "district": "Abbeville 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450069001379",
    },
    {
        "school": "Allendale Fairfax High",
        "district": "Allendale 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450075000064",
    },
    {
        "school": "Allendale Elementary",
        "district": "Allendale 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450075001184",
    },
    {
        "school": "Allendale-Fairfax Middle",
        "district": "Allendale 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450075001415",
    },
    {
        "school": "Bamberg-Ehrhardt High",
        "district": "Bamberg 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450093000119",
    },
    {
        "school": "Bamberg-Ehrhardt Middle",
        "district": "Bamberg 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450093000120",
    },
    {
        "school": "Denmark Olar High",
        "district": "Bamberg 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450096000122",
    },
    {
        "school": "Denmark-Olar Middle",
        "district": "Bamberg 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450096000123",
    },
    {
        "school": "Denmark-Olar Elementary",
        "district": "Bamberg 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450096001426",
    },
    {
        "school": "Barnwell County Career Center",
        "district": "Barnwell 80",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450098000127",
    },
    {
        "school": "Macedonia Elementary-Middle",
        "district": "Barnwell 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450102000124",
    },
    {
        "school": "Blackville-Hilda High",
        "district": "Barnwell 19",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450102000126",
    },
    {
        "school": "Kelly Edwards Elementary",
        "district": "Barnwell 29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450105000128",
    },
    {
        "school": "Williston-Elko High",
        "district": "Barnwell 29",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450105000129",
    },
    {
        "school": "Williston-Elko Middle",
        "district": "Barnwell 29",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450105001327",
    },
    {
        "school": "Barnwell Primary",
        "district": "Barnwell 45",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450108000130",
    },
    {
        "school": "Guinyard-Butler Middle",
        "district": "Barnwell 45",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450108000131",
    },
    {
        "school": "Barnwell High",
        "district": "Barnwell 45",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450108000132",
    },
    {
        "school": "Cheraw Intermediate",
        "district": "Chesterfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000170",
    },
    {
        "school": "Cheraw Primary",
        "district": "Chesterfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000303",
    },
    {
        "school": "Edwards Elementary",
        "district": "Chesterfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000305",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Chesterfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000306",
    },
    {
        "school": "Petersburg Primary",
        "district": "Chesterfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000307",
    },
    {
        "school": "McBee Elementary",
        "district": "Chesterfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000308",
    },
    {
        "school": "Plainview Elementary",
        "district": "Chesterfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000309",
    },
    {
        "school": "Ruby Elementary",
        "district": "Chesterfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000310",
    },
    {
        "school": "Cheraw High",
        "district": "Chesterfield 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000314",
    },
    {
        "school": "Chesterfield High",
        "district": "Chesterfield 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000315",
    },
    {
        "school": "Long Middle",
        "district": "Chesterfield 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000316",
    },
    {
        "school": "McBee High",
        "district": "Chesterfield 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000317",
    },
    {
        "school": "Central High",
        "district": "Chesterfield 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000318",
    },
    {
        "school": "New Heights Middle",
        "district": "Chesterfield 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450156000319",
    },
    {
        "school": "F. E. Dubose Career Center",
        "district": "Clarendon 80",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450160000328",
    },
    {
        "school": "Scott's Branch Middle",
        "district": "Clarendon 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450174000188",
    },
    {
        "school": "St. Paul Elementary",
        "district": "Clarendon 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450174000321",
    },
    {
        "school": "Scott's Branch High",
        "district": "Clarendon 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450174000323",
    },
    {
        "school": "Manning Primary",
        "district": "Clarendon 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450177000325",
    },
    {
        "school": "Manning Junior High",
        "district": "Clarendon 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450177000326",
    },
    {
        "school": "Manning High",
        "district": "Clarendon 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450177000327",
    },
    {
        "school": "Phoenix Charter High",
        "district": "Clarendon 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450177000431",
    },
    {
        "school": "Manning Early Childhood Center",
        "district": "Clarendon 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450177000551",
    },
    {
        "school": "Manning Elementary",
        "district": "Clarendon 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450177001439",
    },
    {
        "school": "Walker-Gamble Elementary",
        "district": "Clarendon 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450180000329",
    },
    {
        "school": "East Clarendon Middle-High",
        "district": "Clarendon 03",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450180000331",
    },
    {
        "school": "Brunson Elementary",
        "district": "Hampton 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450243000605",
    },
    {
        "school": "Hampton Elementary",
        "district": "Hampton 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450243000606",
    },
    {
        "school": "Varnville Elementary",
        "district": "Hampton 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450243000607",
    },
    {
        "school": "Fennell Elementary",
        "district": "Hampton 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450243000608",
    },
    {
        "school": "North District Middle",
        "district": "Hampton 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450243000609",
    },
    {
        "school": "Wade Hampton High",
        "district": "Hampton 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450243000610",
    },
    {
        "school": "Ben Hazel Primary",
        "district": "Hampton 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450243001428",
    },
    {
        "school": "Estill Elementary",
        "district": "Hampton 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450246000611",
    },
    {
        "school": "Estill Middle",
        "district": "Hampton 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450246000612",
    },
    {
        "school": "Estill High",
        "district": "Hampton 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450246000613",
    },
    {
        "school": "Lee Central High",
        "district": "Lee 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450267000559",
    },
    {
        "school": "Dennis Elementary",
        "district": "Lee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450267000709",
    },
    {
        "school": "Lower Lee Elementary",
        "district": "Lee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450267000711",
    },
    {
        "school": "West Lee Elementary",
        "district": "Lee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450267000712",
    },
    {
        "school": "Lee County Career and Technology Center",
        "district": "Lee 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450267000718",
    },
    {
        "school": "McCormick Elementary",
        "district": "McCormick 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450300000800",
    },
    {
        "school": "McCormick Middle",
        "district": "McCormick 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450300000803",
    },
    {
        "school": "McCormick High",
        "district": "McCormick 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450300000804",
    },
    {
        "school": "Hemingway Career and Technology Center",
        "district": "Williamsburg 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450378000237",
    },
    {
        "school": "W.M. Anderson Primary",
        "district": "Williamsburg 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450378001094",
    },
    {
        "school": "Greeleyville Elementary",
        "district": "Williamsburg 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450378001096",
    },
    {
        "school": "Kenneth Gardner Elementary",
        "district": "Williamsburg 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450378001099",
    },
    {
        "school": "Kingstree Middle Magnet",
        "district": "Williamsburg 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450378001107",
    },
    {
        "school": "Hemingway High",
        "district": "Williamsburg 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450378001108",
    },
    {
        "school": "Kingstree Senior High",
        "district": "Williamsburg 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450378001111",
    },
    {
        "school": "C. E. Murray High",
        "district": "Williamsburg 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450378001112",
    },
    {
        "school": "Mt. Lebanon Elementary",
        "district": "Anderson 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450087001492",
    },
    {
        "school": "Career and Technology Center of Anderson 1 & 2",
        "district": "Anderson 80",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450076001380",
    },
    {
        "school": "Cedar Grove Elementary",
        "district": "Anderson 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078000067",
    },
    {
        "school": "Concrete Primary",
        "district": "Anderson 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078000068",
    },
    {
        "school": "West Pelzer Elementary",
        "district": "Anderson 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078000070",
    },
    {
        "school": "Spearman Elementary",
        "district": "Anderson 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078000072",
    },
    {
        "school": "Palmetto Middle",
        "district": "Anderson 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078000074",
    },
    {
        "school": "Palmetto High",
        "district": "Anderson 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078000076",
    },
    {
        "school": "Wren High",
        "district": "Anderson 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078000077",
    },
    {
        "school": "Hunt Meadows Elementary",
        "district": "Anderson 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078000545",
    },
    {
        "school": "Powdersville Elementary",
        "district": "Anderson 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078000686",
    },
    {
        "school": "Wren Middle",
        "district": "Anderson 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078001203",
    },
    {
        "school": "Palmetto Elementary",
        "district": "Anderson 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078001324",
    },
    {
        "school": "Wren Elementary",
        "district": "Anderson 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078001325",
    },
    {
        "school": "Powdersville Middle",
        "district": "Anderson 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078001444",
    },
    {
        "school": "Belton Elementary",
        "district": "Anderson 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450081000078",
    },
    {
        "school": "Marshall Primary",
        "district": "Anderson 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450081000079",
    },
    {
        "school": "Honea Path Elementary",
        "district": "Anderson 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450081000080",
    },
    {
        "school": "Wright Elementary",
        "district": "Anderson 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450081000081",
    },
    {
        "school": "Belton Honea Path High",
        "district": "Anderson 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450081000084",
    },
    {
        "school": "Belton Middle",
        "district": "Anderson 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450081001204",
    },
    {
        "school": "Honea Path Middle",
        "district": "Anderson 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450081001205",
    },
    {
        "school": "Iva Elementary",
        "district": "Anderson 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450084000086",
    },
    {
        "school": "Starr Elementary",
        "district": "Anderson 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450084000087",
    },
    {
        "school": "Starr-Iva Middle",
        "district": "Anderson 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450084000088",
    },
    {
        "school": "Crescent High",
        "district": "Anderson 03",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450084000089",
    },
    {
        "school": "La France Elementary",
        "district": "Anderson 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450087000090",
    },
    {
        "school": "Pendleton Elementary",
        "district": "Anderson 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450087000091",
    },
    {
        "school": "Townville Elementary",
        "district": "Anderson 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450087000092",
    },
    {
        "school": "Pendleton High",
        "district": "Anderson 04",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450087000094",
    },
    {
        "school": "Riverside Middle",
        "district": "Anderson 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450087001326",
    },
    {
        "school": "Centerville Elementary",
        "district": "Anderson 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000096",
    },
    {
        "school": "Concord Elementary",
        "district": "Anderson 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000097",
    },
    {
        "school": "Homeland Park Primary",
        "district": "Anderson 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000099",
    },
    {
        "school": "Nevitt Forest Elementary",
        "district": "Anderson 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000101",
    },
    {
        "school": "South Fant School of Early Education",
        "district": "Anderson 05",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000102",
    },
    {
        "school": "Varennes Elementary",
        "district": "Anderson 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000103",
    },
    {
        "school": "Whitehall Elementary",
        "district": "Anderson 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000106",
    },
    {
        "school": "Calhoun Academy of the Arts",
        "district": "Anderson 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000107",
    },
    {
        "school": "T. L. Hanna High",
        "district": "Anderson 05",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000108",
    },
    {
        "school": "McCants Middle",
        "district": "Anderson 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000110",
    },
    {
        "school": "Westside High",
        "district": "Anderson 05",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000113",
    },
    {
        "school": "Midway Elementary",
        "district": "Anderson 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000687",
    },
    {
        "school": "McLees Elementary",
        "district": "Anderson 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090000690",
    },
    {
        "school": "New Prospect Elementary",
        "district": "Anderson 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090001206",
    },
    {
        "school": "Mossy Creek Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001007",
    },
    {
        "school": "Belvedere Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000016",
    },
    {
        "school": "Byrd Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000018",
    },
    {
        "school": "J. D. Lever Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000019",
    },
    {
        "school": "Clearwater Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000020",
    },
    {
        "school": "East Aiken School of the Arts",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000023",
    },
    {
        "school": "Gloverville Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000025",
    },
    {
        "school": "Greendale Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000026",
    },
    {
        "school": "Hammond Hill Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000027",
    },
    {
        "school": "Millbrook Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000030",
    },
    {
        "school": "North Aiken Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000031",
    },
    {
        "school": "North Augusta Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000032",
    },
    {
        "school": "Ridge Spring-Monetta Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000034",
    },
    {
        "school": "Warrenville Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000040",
    },
    {
        "school": "Chukker Creek Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000045",
    },
    {
        "school": "Aiken High",
        "district": "Aiken 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000046",
    },
    {
        "school": "Paul Knox Middle",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000050",
    },
    {
        "school": "North Augusta Middle",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000054",
    },
    {
        "school": "North Augusta High",
        "district": "Aiken 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000055",
    },
    {
        "school": "Ridge Spring-Monetta  High",
        "district": "Aiken 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000056",
    },
    {
        "school": "Wagener-Sally High",
        "district": "Aiken 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000057",
    },
    {
        "school": "Aiken County Career Center",
        "district": "Aiken 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450072000058",
    },
    {
        "school": "Lloyd-Kennedy Charter",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000682",
    },
    {
        "school": "Horse Creek Academy",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072000684",
    },
    {
        "school": "Aiken Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001189",
    },
    {
        "school": "Cyril B. Busbee Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001191",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001193",
    },
    {
        "school": "Langley-Bath-Clearwater Middle",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001194",
    },
    {
        "school": "Leavelle McCampbell Middle",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001196",
    },
    {
        "school": "M. B. Kennedy Middle",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001197",
    },
    {
        "school": "Midland Valley High",
        "district": "Aiken 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001198",
    },
    {
        "school": "New Ellenton STEAM Magnet Middle",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001199",
    },
    {
        "school": "Oakwood-Windsor Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001200",
    },
    {
        "school": "Schofield Middle",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001201",
    },
    {
        "school": "South Aiken High",
        "district": "Aiken 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001202",
    },
    {
        "school": "Jackson STEM Magnet",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001321",
    },
    {
        "school": "Silver Bluff High",
        "district": "Aiken 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001323",
    },
    {
        "school": "Redcliffe Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001390",
    },
    {
        "school": "Johnston-Edgefield-Trenton Middle",
        "district": "Edgefield 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450207000037",
    },
    {
        "school": "Merriwether Middle",
        "district": "Edgefield 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450207000038",
    },
    {
        "school": "Douglas Elementary",
        "district": "Edgefield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450207000408",
    },
    {
        "school": "W. E. Parker Elementary",
        "district": "Edgefield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450207000410",
    },
    {
        "school": "Merriwether Elementary",
        "district": "Edgefield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450207000411",
    },
    {
        "school": "Johnston Elementary",
        "district": "Edgefield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450207000412",
    },
    {
        "school": "Strom Thurmond High",
        "district": "Edgefield 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450207000413",
    },
    {
        "school": "Strom Thurmond Career and Technology Center",
        "district": "Edgefield 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450207001417",
    },
    {
        "school": "Blenheim  Middle School of Discovery",
        "district": "Marlboro 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450297000024",
    },
    {
        "school": "Bennettsville Primary",
        "district": "Marlboro 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450297000783",
    },
    {
        "school": "McColl Elementary/Middle",
        "district": "Marlboro 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450297000789",
    },
    {
        "school": "Clio Elementary",
        "district": "Marlboro 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450297001431",
    },
    {
        "school": "Wallace Elementary/Middle",
        "district": "Marlboro 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450297001433",
    },
    {
        "school": "Marlboro County High",
        "district": "Marlboro 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450297001434",
    },
    {
        "school": "Goose Creek Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000822",
    },
    {
        "school": "Sangaree Middle",
        "district": "Berkeley 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001166",
    },
    {
        "school": "James Island Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000830",
    },
    {
        "school": "Charleston Development Academy",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000838",
    },
    {
        "school": "East Cooper Montessori Charter",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000856",
    },
    {
        "school": "Greg Mathis Charter High",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000857",
    },
    {
        "school": "Laurel Hill Primary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000944",
    },
    {
        "school": "James Island Charter High",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001168",
    },
    {
        "school": "Drayton Hall Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001167",
    },
    {
        "school": "Eagle Nest Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001483",
    },
    {
        "school": "William M. Reeves Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001488",
    },
    {
        "school": "River Oaks Middle",
        "district": "Dorchester 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001489",
    },
    {
        "school": "Mount Holly Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000003",
    },
    {
        "school": "Devon Forest Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000035",
    },
    {
        "school": "Berkeley Intermediate",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000082",
    },
    {
        "school": "Berkeley Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000154",
    },
    {
        "school": "Boulder Bluff Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000155",
    },
    {
        "school": "Cainhoy Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000156",
    },
    {
        "school": "Cross Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000157",
    },
    {
        "school": "College Park Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000158",
    },
    {
        "school": "Timberland High",
        "district": "Berkeley 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000160",
    },
    {
        "school": "J. K. Gourdin Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000161",
    },
    {
        "school": "Henry E. Bonner Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000162",
    },
    {
        "school": "St. Stephen Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000165",
    },
    {
        "school": "Whitesville Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000166",
    },
    {
        "school": "Westview Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000167",
    },
    {
        "school": "Hanahan Middle",
        "district": "Berkeley 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000169",
    },
    {
        "school": "Sedgefield Middle",
        "district": "Berkeley 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000171",
    },
    {
        "school": "St. Stephen Middle",
        "district": "Berkeley 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000172",
    },
    {
        "school": "College Park Middle",
        "district": "Berkeley 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000173",
    },
    {
        "school": "Berkeley High",
        "district": "Berkeley 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000174",
    },
    {
        "school": "Cross High",
        "district": "Berkeley 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000176",
    },
    {
        "school": "Goose Creek High",
        "district": "Berkeley 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000177",
    },
    {
        "school": "Hanahan High",
        "district": "Berkeley 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000178",
    },
    {
        "school": "Hanahan Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000423",
    },
    {
        "school": "Westview Primary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117000704",
    },
    {
        "school": "Marrington Middle School of the Arts",
        "district": "Berkeley 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001158",
    },
    {
        "school": "Howe Hall AIMS Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001159",
    },
    {
        "school": "Marrington Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001161",
    },
    {
        "school": "Berkeley Middle",
        "district": "Berkeley 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001207",
    },
    {
        "school": "Macedonia Middle",
        "district": "Berkeley 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001208",
    },
    {
        "school": "Sangaree Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001209",
    },
    {
        "school": "Westview Middle",
        "district": "Berkeley 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001210",
    },
    {
        "school": "Stratford High",
        "district": "Berkeley 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001351",
    },
    {
        "school": "Sangaree Intermediate",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001403",
    },
    {
        "school": "Charleston School of the Arts",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000083",
    },
    {
        "school": "Academic Magnet High",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000168",
    },
    {
        "school": "Chicora Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000197",
    },
    {
        "school": "A. C. Corcoran Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000199",
    },
    {
        "school": "Edmund A. Burns Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000200",
    },
    {
        "school": "Jane Edwards Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000201",
    },
    {
        "school": "Mary Ford Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000202",
    },
    {
        "school": "W. B. Goodwin Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000204",
    },
    {
        "school": "Minnie Hughes Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000205",
    },
    {
        "school": "Hunley Park Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000206",
    },
    {
        "school": "Ladson Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000207",
    },
    {
        "school": "Lambs Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000208",
    },
    {
        "school": "Memminger Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000210",
    },
    {
        "school": "Midland Park Primary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000211",
    },
    {
        "school": "E.B. Ellington Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000212",
    },
    {
        "school": "Mitchell Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000213",
    },
    {
        "school": "Jennie Moore Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000214",
    },
    {
        "school": "Morningside Middle",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000215",
    },
    {
        "school": "Mt. Pleasant Academy",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000216",
    },
    {
        "school": "Murray-LaSaine Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000218",
    },
    {
        "school": "North Charleston Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000219",
    },
    {
        "school": "Oakland Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000220",
    },
    {
        "school": "Malcolm C. Hursey Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000222",
    },
    {
        "school": "Matilda F. Dunston Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000224",
    },
    {
        "school": "Edith L. Frierson Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000225",
    },
    {
        "school": "Sanders-Clyde Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000226",
    },
    {
        "school": "Pepperhill Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000227",
    },
    {
        "school": "James Simons Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000228",
    },
    {
        "school": "Springfield Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000229",
    },
    {
        "school": "St. Andrew's School of Math and Science",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000230",
    },
    {
        "school": "Angel Oak Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000231",
    },
    {
        "school": "Stiles Point Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000232",
    },
    {
        "school": "Stono Park Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000233",
    },
    {
        "school": "Sullivan's Island Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000234",
    },
    {
        "school": "Mamie P. Whitesides Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000236",
    },
    {
        "school": "Charleston Progressive",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000240",
    },
    {
        "school": "C. E. Williams Middle School for Creative and Scientific Art",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000249",
    },
    {
        "school": "Baptist Hill High",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000250",
    },
    {
        "school": "North Charleston High",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000251",
    },
    {
        "school": "Garrett Academy of Technology",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000257",
    },
    {
        "school": "Wando High",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000261",
    },
    {
        "school": "St. Johns High",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000264",
    },
    {
        "school": "RB Stall High",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000265",
    },
    {
        "school": "Charles Pinckney Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000429",
    },
    {
        "school": "Thomas C. Cario Middle",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000430",
    },
    {
        "school": "West Ashley High",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000548",
    },
    {
        "school": "West Ashley Middle",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144000707",
    },
    {
        "school": "Northwoods Middle",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001211",
    },
    {
        "school": "Harbor View Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001214",
    },
    {
        "school": "Haut Gap Middle",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001215",
    },
    {
        "school": "Laing Middle",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001217",
    },
    {
        "school": "Moultrie Middle",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001218",
    },
    {
        "school": "Burke High",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001328",
    },
    {
        "school": "James B. Edwards Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001329",
    },
    {
        "school": "Military Magnet Academy",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001330",
    },
    {
        "school": "St. James Santee Elementary-Middle",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001352",
    },
    {
        "school": "Ashley River Creative Arts Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001363",
    },
    {
        "school": "Buist Academy",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001382",
    },
    {
        "school": "Mt. Zion Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001404",
    },
    {
        "school": "Belle Hall Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001438",
    },
    {
        "school": "Harleyville Elementary",
        "district": "Dorchester 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450000200435",
    },
    {
        "school": "St. George Middle",
        "district": "Dorchester 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450000200439",
    },
    {
        "school": "William Memorial Elementary",
        "district": "Dorchester 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450000200444",
    },
    {
        "school": "Woodland High",
        "district": "Dorchester 04",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450000200445",
    },
    {
        "school": "Dorchester Career and Technology Center",
        "district": "Dorchester 80",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450199000407",
    },
    {
        "school": "Fort Dorchester High",
        "district": "Dorchester 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201000007",
    },
    {
        "school": "Beech Hill Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201000008",
    },
    {
        "school": "Gregg Middle",
        "district": "Dorchester 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201000242",
    },
    {
        "school": "Knightsville Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201000395",
    },
    {
        "school": "Summerville Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201000397",
    },
    {
        "school": "James H. Spann Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201000398",
    },
    {
        "school": "Rollings Middle School of the Arts",
        "district": "Dorchester 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201000399",
    },
    {
        "school": "Newington Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201000400",
    },
    {
        "school": "Summerville High",
        "district": "Dorchester 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201000402",
    },
    {
        "school": "Alston Middle",
        "district": "Dorchester 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201000403",
    },
    {
        "school": "Fort Dorchester Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201000715",
    },
    {
        "school": "Flowertown Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001231",
    },
    {
        "school": "Charles B. DuBose Middle",
        "district": "Dorchester 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001384",
    },
    {
        "school": "Oakbrook Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001405",
    },
    {
        "school": "Oakbrook Middle",
        "district": "Dorchester 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001406",
    },
    {
        "school": "Windsor Hill Arts Infused Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001447",
    },
    {
        "school": "South Pointe High",
        "district": "York 03",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001004",
    },
    {
        "school": "The Palmetto School at the Children?s Attention Home",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001006",
    },
    {
        "school": "India Hook Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001491",
    },
    {
        "school": "Nation Ford High",
        "district": "York 04",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001103",
    },
    {
        "school": "Cotton Belt Elementary",
        "district": "York 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450381000366",
    },
    {
        "school": "Jefferson Elementary",
        "district": "York 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450381001120",
    },
    {
        "school": "York Comprehensive High",
        "district": "York 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450381001122",
    },
    {
        "school": "Floyd D. Johnson Technology Center",
        "district": "York 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450381001123",
    },
    {
        "school": "York Middle",
        "district": "York 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450381001412",
    },
    {
        "school": "Hickory Grove-Sharon Elementary",
        "district": "York 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450381001422",
    },
    {
        "school": "Hunter Street Elementary",
        "district": "York 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450381001456",
    },
    {
        "school": "Griggs Road Elementary",
        "district": "York 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450384000044",
    },
    {
        "school": "Crowders Creek Elementary",
        "district": "York 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450384000522",
    },
    {
        "school": "Bethany Elementary",
        "district": "York 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450384001124",
    },
    {
        "school": "Bethel Elementary",
        "district": "York 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450384001125",
    },
    {
        "school": "Kinard Elementary",
        "district": "York 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450384001126",
    },
    {
        "school": "Clover Middle",
        "district": "York 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450384001127",
    },
    {
        "school": "Clover High",
        "district": "York 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450384001129",
    },
    {
        "school": "Saluda Trail Middle",
        "district": "York 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387000537",
    },
    {
        "school": "Old Pointe Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387000816",
    },
    {
        "school": "Central Child Development Center",
        "district": "York 03",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387000817",
    },
    {
        "school": "Belleview Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001131",
    },
    {
        "school": "Ebenezer Avenue Elementary: Traditional Montesorri Inquiry",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001132",
    },
    {
        "school": "Ebinport Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001133",
    },
    {
        "school": "Finley Road Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001135",
    },
    {
        "school": "Lesslie Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001136",
    },
    {
        "school": "Northside Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001137",
    },
    {
        "school": "Oakdale Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001138",
    },
    {
        "school": "Richmond Drive Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001139",
    },
    {
        "school": "Rosewood Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001140",
    },
    {
        "school": "Sunset Park Center for Accelerated Studies",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001141",
    },
    {
        "school": "York Road Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001143",
    },
    {
        "school": "Independence Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001144",
    },
    {
        "school": "Mount Gallant Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001145",
    },
    {
        "school": "Castle Heights Middle",
        "district": "York 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001146",
    },
    {
        "school": "W. C. Sullivan Middle",
        "district": "York 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001147",
    },
    {
        "school": "Rawlinson Road Middle",
        "district": "York 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001148",
    },
    {
        "school": "Northwestern High",
        "district": "York 03",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001149",
    },
    {
        "school": "Rock Hill High",
        "district": "York 03",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001150",
    },
    {
        "school": "Applied Technology Center",
        "district": "York 03",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450387001151",
    },
    {
        "school": "Gold Hill Elementary",
        "district": "York 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390000062",
    },
    {
        "school": "Gold Hill Middle",
        "district": "York 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390000368",
    },
    {
        "school": "Orchard Park Elementary",
        "district": "York 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390000663",
    },
    {
        "school": "Springfield Elementary",
        "district": "York 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390000666",
    },
    {
        "school": "Fort Mill Elementary",
        "district": "York 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001153",
    },
    {
        "school": "Riverview Elementary",
        "district": "York 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001154",
    },
    {
        "school": "Fort Mill Middle",
        "district": "York 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001155",
    },
    {
        "school": "Fort Mill High",
        "district": "York 04",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001156",
    },
    {
        "school": "Chester Park Elementary School for the Arts",
        "district": "Chester 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450153001171",
    },
    {
        "school": "Chester Park Elementary School of Literacy and Technology",
        "district": "Chester 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450153001172",
    },
    {
        "school": "Chester Park School Elementary of Inquiry",
        "district": "Chester 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450153000036",
    },
    {
        "school": "Great Falls Elementary",
        "district": "Chester 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450153000291",
    },
    {
        "school": "Lewisville Elementary",
        "district": "Chester 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450153000292",
    },
    {
        "school": "Chester Senior High",
        "district": "Chester 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450153000298",
    },
    {
        "school": "Chester Middle",
        "district": "Chester 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450153000299",
    },
    {
        "school": "Great Falls High",
        "district": "Chester 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450153000300",
    },
    {
        "school": "Lewisville High",
        "district": "Chester 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450153000301",
    },
    {
        "school": "Chester County Career Center",
        "district": "Chester 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450153000302",
    },
    {
        "school": "Lewisville Middle",
        "district": "Chester 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450153001225",
    },
    {
        "school": "Pleasant Hill Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000976",
    },
    {
        "school": "Pleasant Hill Middle",
        "district": "Lexington 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000977",
    },
    {
        "school": "Carolina Springs Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001484",
    },
    {
        "school": "Carolina Springs Middle",
        "district": "Lexington 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001493",
    },
    {
        "school": "Manning High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000100939",
    },
    {
        "school": "Richland One Charter Middle College",
        "district": "Richland 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001195",
    },
    {
        "school": "Kelly Mill Middle",
        "district": "Richland 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000927",
    },
    {
        "school": "Blythewood High",
        "district": "Richland 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000928",
    },
    {
        "school": "Longleaf Middle",
        "district": "Richland 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001081",
    },
    {
        "school": "Saluda Primary",
        "district": "Saluda 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450346000936",
    },
    {
        "school": "Calhoun County High",
        "district": "Calhoun 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450125000187",
    },
    {
        "school": "Sandy Run School",
        "district": "Calhoun 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450125000424",
    },
    {
        "school": "Kelly Miller Elementary",
        "district": "Fairfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450210000416",
    },
    {
        "school": "McCrorey-Liston School of Technology",
        "district": "Fairfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450210000417",
    },
    {
        "school": "Geiger Elementary",
        "district": "Fairfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450210000419",
    },
    {
        "school": "Fairfield Middle",
        "district": "Fairfield 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450210000421",
    },
    {
        "school": "Fairfield Career and Technology Center",
        "district": "Fairfield 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450210001232",
    },
    {
        "school": "Fairfield Central High",
        "district": "Fairfield 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450210001392",
    },
    {
        "school": "Fairfield Elementary",
        "district": "Fairfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450210001407",
    },
    {
        "school": "Fairfield Magnet for Math and Science",
        "district": "Fairfield 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450210001448",
    },
    {
        "school": "Wateree Elementary",
        "district": "Kershaw 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000009",
    },
    {
        "school": "Leslie M. Stover Middle",
        "district": "Kershaw 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000465",
    },
    {
        "school": "Baron Dekalb Elementary",
        "district": "Kershaw 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000654",
    },
    {
        "school": "Bethune Elementary",
        "district": "Kershaw 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000655",
    },
    {
        "school": "Blaney Elementary",
        "district": "Kershaw 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000656",
    },
    {
        "school": "Jackson School",
        "district": "Kershaw 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000657",
    },
    {
        "school": "Lugoff Elementary",
        "district": "Kershaw 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000658",
    },
    {
        "school": "Midway Elementary",
        "district": "Kershaw 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000659",
    },
    {
        "school": "Mt. Pisgah Elementary",
        "district": "Kershaw 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000660",
    },
    {
        "school": "Pine Tree Hill Elementary",
        "district": "Kershaw 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000661",
    },
    {
        "school": "Lugoff-Elgin Middle",
        "district": "Kershaw 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000662",
    },
    {
        "school": "Lugoff-Elgin High",
        "district": "Kershaw 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000665",
    },
    {
        "school": "Camden High",
        "district": "Kershaw 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000667",
    },
    {
        "school": "Dr. Gilbert G. Woolard Technology Center",
        "district": "Kershaw 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450255000669",
    },
    {
        "school": "Doby's Mill Elementary",
        "district": "Kershaw 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000760",
    },
    {
        "school": "North Central Middle",
        "district": "Kershaw 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255000766",
    },
    {
        "school": "Camden Middle",
        "district": "Kershaw 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255001257",
    },
    {
        "school": "Camden Elementary",
        "district": "Kershaw 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255001258",
    },
    {
        "school": "North Central High",
        "district": "Kershaw 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450255001259",
    },
    {
        "school": "Saluda Elementary",
        "district": "Saluda 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450346000979",
    },
    {
        "school": "Hollywood Elementary",
        "district": "Saluda 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450346000980",
    },
    {
        "school": "Saluda Middle",
        "district": "Saluda 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450346000981",
    },
    {
        "school": "Saluda High",
        "district": "Saluda 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450346000982",
    },
    {
        "school": "MacDougall High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000101376",
    },
    {
        "school": "Turbeville High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000100238",
    },
    {
        "school": "Trenton High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000100148",
    },
    {
        "school": "Ridgeland High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000100266",
    },
    {
        "school": "Lee High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000100063",
    },
    {
        "school": "Saxe Gotha Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000014",
    },
    {
        "school": "White Knoll Middle",
        "district": "Lexington 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000015",
    },
    {
        "school": "Gilbert Middle",
        "district": "Lexington 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000041",
    },
    {
        "school": "Midway Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000052",
    },
    {
        "school": "Lake Murray Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000476",
    },
    {
        "school": "White Knoll High",
        "district": "Lexington 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000582",
    },
    {
        "school": "Pelion Middle",
        "district": "Lexington 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000583",
    },
    {
        "school": "Gilbert Primary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000586",
    },
    {
        "school": "Gilbert Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000719",
    },
    {
        "school": "Lexington Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000720",
    },
    {
        "school": "Pelion Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000721",
    },
    {
        "school": "Oak Grove Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000722",
    },
    {
        "school": "Lexington High",
        "district": "Lexington 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000724",
    },
    {
        "school": "Pelion High",
        "district": "Lexington 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000725",
    },
    {
        "school": "Gilbert High",
        "district": "Lexington 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270000726",
    },
    {
        "school": "Lexington Technology Center",
        "district": "Lexington 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450270000727",
    },
    {
        "school": "Lexington Middle",
        "district": "Lexington 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001268",
    },
    {
        "school": "Red Bank Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001269",
    },
    {
        "school": "White Knoll Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001429",
    },
    {
        "school": "Congaree Elementary",
        "district": "Lexington 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273000730",
    },
    {
        "school": "Saluda River Academy for the Arts",
        "district": "Lexington 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273000733",
    },
    {
        "school": "Springdale Elementary",
        "district": "Lexington 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273000734",
    },
    {
        "school": "Herbert A. Wood Elementary",
        "district": "Lexington 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273000736",
    },
    {
        "school": "Airport High",
        "district": "Lexington 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273000741",
    },
    {
        "school": "Brookland-Cayce Senior High",
        "district": "Lexington 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273000742",
    },
    {
        "school": "Cyril B. Busbee Creative Arts Academy",
        "district": "Lexington 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273001270",
    },
    {
        "school": "Northside Middle",
        "district": "Lexington 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273001271",
    },
    {
        "school": "Pine Ridge Middle",
        "district": "Lexington 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273001272",
    },
    {
        "school": "R. H. Fulmer Middle",
        "district": "Lexington 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273001273",
    },
    {
        "school": "Batesburg-Leesville Elementary",
        "district": "Lexington 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450276000744",
    },
    {
        "school": "Batesburg-Leesville Primary",
        "district": "Lexington 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450276000745",
    },
    {
        "school": "Batesburg-Leesville High",
        "district": "Lexington 03",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450276000748",
    },
    {
        "school": "Batesburg-Leesville Middle",
        "district": "Lexington 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450276001274",
    },
    {
        "school": "Sandhills Elementary",
        "district": "Lexington 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450279000615",
    },
    {
        "school": "Sandhills Primary",
        "district": "Lexington 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450279000631",
    },
    {
        "school": "Frances F. Mack Intermediate",
        "district": "Lexington 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450279000749",
    },
    {
        "school": "Sandhills Middle",
        "district": "Lexington 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450279000751",
    },
    {
        "school": "Swansea High",
        "district": "Lexington 04",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450279000752",
    },
    {
        "school": "Dutch Fork High",
        "district": "Lexington 05",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000017",
    },
    {
        "school": "Lake Murray Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000247",
    },
    {
        "school": "River Springs Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000248",
    },
    {
        "school": "Dutch Fork Middle",
        "district": "Lexington 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000339",
    },
    {
        "school": "Chapin Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000753",
    },
    {
        "school": "Irmo Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000755",
    },
    {
        "school": "Leaphart Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000756",
    },
    {
        "school": "Seven Oaks Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000757",
    },
    {
        "school": "Irmo Middle",
        "district": "Lexington 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000758",
    },
    {
        "school": "Irmo High",
        "district": "Lexington 05",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000759",
    },
    {
        "school": "Ballentine Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000776",
    },
    {
        "school": "CrossRoads Intermediate",
        "district": "Lexington 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282001169",
    },
    {
        "school": "Chapin High",
        "district": "Lexington 05",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282001170",
    },
    {
        "school": "Nursery Road Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282001277",
    },
    {
        "school": "Harbison West Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282001345",
    },
    {
        "school": "Chapin Intermediate",
        "district": "Lexington 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282001450",
    },
    {
        "school": "Sara Babb High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000101378",
    },
    {
        "school": "Dutch Fork Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282000754",
    },
    {
        "school": "H. E. Corley Elementary",
        "district": "Lexington 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282001441",
    },
    {
        "school": "Carver-Lyon Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000487",
    },
    {
        "school": "Burton Pack Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000499",
    },
    {
        "school": "Pine Grove Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000504",
    },
    {
        "school": "Southeast Middle",
        "district": "Richland 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000507",
    },
    {
        "school": "Watkins-Nance Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000638",
    },
    {
        "school": "Forest Heights Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000649",
    },
    {
        "school": "Brockman Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000813",
    },
    {
        "school": "Arden Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000907",
    },
    {
        "school": "Bradley Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000910",
    },
    {
        "school": "Brennen Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000911",
    },
    {
        "school": "Annie Burnside Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000913",
    },
    {
        "school": "Gadsden Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000918",
    },
    {
        "school": "A. J. Lewis Greenview Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000919",
    },
    {
        "school": "Hopkins Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000920",
    },
    {
        "school": "Horrell Hill Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000921",
    },
    {
        "school": "Hyatt Park Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000922",
    },
    {
        "school": "Logan Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000924",
    },
    {
        "school": "Mill Creek Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000925",
    },
    {
        "school": "A. C. Moore Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000926",
    },
    {
        "school": "South Kilbourne Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000929",
    },
    {
        "school": "Satchel Ford Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000930",
    },
    {
        "school": "Sandel Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000931",
    },
    {
        "school": "H. B. Rhame Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000932",
    },
    {
        "school": "J. P. Thomas Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000933",
    },
    {
        "school": "Webber School",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000935",
    },
    {
        "school": "W. A. Perry Middle",
        "district": "Richland 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000946",
    },
    {
        "school": "Columbia High",
        "district": "Richland 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000949",
    },
    {
        "school": "Dreher High",
        "district": "Richland 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000950",
    },
    {
        "school": "Eau Claire High",
        "district": "Richland 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000951",
    },
    {
        "school": "A. C. Flora High",
        "district": "Richland 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000952",
    },
    {
        "school": "C. A. Johnson High",
        "district": "Richland 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000953",
    },
    {
        "school": "W.J. Keenan High",
        "district": "Richland 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000954",
    },
    {
        "school": "Lower Richland High",
        "district": "Richland 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336000955",
    },
    {
        "school": "Pendergrass Fairwold School",
        "district": "Richland 01",
        "level": "Other",
        "type": "Special education school",
        "state": "SC",
        "nces_id": "450336000957",
    },
    {
        "school": "Samuel A. Heyward Career and Technology Center",
        "district": "Richland 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450336000963",
    },
    {
        "school": "Alcorn Middle",
        "district": "Richland 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001295",
    },
    {
        "school": "Caughman Road Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001297",
    },
    {
        "school": "Crayton Middle",
        "district": "Richland 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001298",
    },
    {
        "school": "W. G. Sanders Middle",
        "district": "Richland 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001299",
    },
    {
        "school": "Hand Middle",
        "district": "Richland 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001300",
    },
    {
        "school": "Heyward Gibbes Middle",
        "district": "Richland 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001301",
    },
    {
        "school": "Hopkins Middle",
        "district": "Richland 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001302",
    },
    {
        "school": "Meadowfield Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001303",
    },
    {
        "school": "Edward E. Taylor Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001305",
    },
    {
        "school": "Rosewood Elementary",
        "district": "Richland 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001306",
    },
    {
        "school": "St. Andrews Middle",
        "district": "Richland 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450336001308",
    },
    {
        "school": "Rice Creek Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000042",
    },
    {
        "school": "Ridge View High",
        "district": "Richland 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000118",
    },
    {
        "school": "Blythewood Middle",
        "district": "Richland 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000203",
    },
    {
        "school": "Killian Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000342",
    },
    {
        "school": "Bookman Road Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000344",
    },
    {
        "school": "Lake Carolina Elementary Lower Campus",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000650",
    },
    {
        "school": "Round Top Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000814",
    },
    {
        "school": "Bethel-Hanberry Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000966",
    },
    {
        "school": "L. W. Conder Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000968",
    },
    {
        "school": "Forest Lake Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000969",
    },
    {
        "school": "Joseph Keels Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000970",
    },
    {
        "school": "L. B. Nelson Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000971",
    },
    {
        "school": "Windsor Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000972",
    },
    {
        "school": "E. L. Wright Middle",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000973",
    },
    {
        "school": "Spring Valley High",
        "district": "Richland 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339000975",
    },
    {
        "school": "Dent Middle",
        "district": "Richland 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001311",
    },
    {
        "school": "Richland Northeast High",
        "district": "Richland 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001312",
    },
    {
        "school": "North Springs Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001348",
    },
    {
        "school": "Pontiac Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001442",
    },
    {
        "school": "Summit Parkway Middle",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001443",
    },
    {
        "school": "Birchwood School",
        "district": "Dept of Juvenile Justice",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450342001185",
    },
    {
        "school": "Evaluation and Detention Center",
        "district": "Dept of Juvenile Justice",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450342001186",
    },
    {
        "school": "Willow Lane School",
        "district": "Dept of Juvenile Justice",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450342001187",
    },
    {
        "school": "Tyger River High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000100255",
    },
    {
        "school": "Wateree River High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000101423",
    },
    {
        "school": "Dillon County Applied Technology Center",
        "district": "Dillon 80",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450187000388",
    },
    {
        "school": "East Elementary",
        "district": "Dillon 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450192000381",
    },
    {
        "school": "South Elementary",
        "district": "Dillon 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450192000382",
    },
    {
        "school": "Gordon Elementary",
        "district": "Dillon 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450192000383",
    },
    {
        "school": "Stewart Heights Elementary",
        "district": "Dillon 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450192000384",
    },
    {
        "school": "Dillon High",
        "district": "Dillon 04",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450192000385",
    },
    {
        "school": "Latta Elementary",
        "district": "Dillon 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450195000389",
    },
    {
        "school": "Latta Middle",
        "district": "Dillon 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450195000390",
    },
    {
        "school": "Latta High",
        "district": "Dillon 03",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450195000391",
    },
    {
        "school": "Palmetto Youth Academy Charter",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000958",
    },
    {
        "school": "Darlington High",
        "district": "Darlington 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000095",
    },
    {
        "school": "Darlington Middle",
        "district": "Darlington 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000098",
    },
    {
        "school": "Southside Early Childhood Center",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000100",
    },
    {
        "school": "Mayo High For Math Science & Technology",
        "district": "Darlington 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000190",
    },
    {
        "school": "Brockington Elementary",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000350",
    },
    {
        "school": "Cain Elementary",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000351",
    },
    {
        "school": "Carolina Elementary",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000352",
    },
    {
        "school": "Lamar Elementary",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000353",
    },
    {
        "school": "North Hartsville Elementary",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000354",
    },
    {
        "school": "Pate Elementary",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000355",
    },
    {
        "school": "Rosenwald Elementary/Middle",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000356",
    },
    {
        "school": "Spaulding Elementary",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000359",
    },
    {
        "school": "Brunson-Dargan Elementary",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000360",
    },
    {
        "school": "St. Johns Elementary",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000362",
    },
    {
        "school": "Thornwell School for the Arts",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000363",
    },
    {
        "school": "West Hartsville Elementary",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000364",
    },
    {
        "school": "Washington St. Elementary",
        "district": "Darlington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000365",
    },
    {
        "school": "Hartsville Middle",
        "district": "Darlington 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000369",
    },
    {
        "school": "Hartsville High",
        "district": "Darlington 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000370",
    },
    {
        "school": "Lamar High",
        "district": "Darlington 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000371",
    },
    {
        "school": "Spaulding Middle",
        "district": "Darlington 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450186000374",
    },
    {
        "school": "Henry L. Sneed Middle",
        "district": "Florence 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000048",
    },
    {
        "school": "Briggs Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000425",
    },
    {
        "school": "Carver Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000426",
    },
    {
        "school": "Delmae Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000427",
    },
    {
        "school": "Greenwood Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000428",
    },
    {
        "school": "North Vista Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000432",
    },
    {
        "school": "Royall Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000433",
    },
    {
        "school": "Savannah Grove Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000434",
    },
    {
        "school": "Henry Timrod Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000436",
    },
    {
        "school": "Wallace Gregg Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000437",
    },
    {
        "school": "John W. Moore Middle",
        "district": "Florence 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000438",
    },
    {
        "school": "South Florence High",
        "district": "Florence 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000440",
    },
    {
        "school": "Williams Middle",
        "district": "Florence 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000441",
    },
    {
        "school": "Wilson High",
        "district": "Florence 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000442",
    },
    {
        "school": "West Florence High",
        "district": "Florence 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213000443",
    },
    {
        "school": "Florence Career Center",
        "district": "Florence 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450213000446",
    },
    {
        "school": "McLaurin Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213001234",
    },
    {
        "school": "Theodore Lester Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213001235",
    },
    {
        "school": "Dewey-Carter Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213001331",
    },
    {
        "school": "Southside Middle",
        "district": "Florence 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213001332",
    },
    {
        "school": "Hannah Pamplico High",
        "district": "Florence 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450216000450",
    },
    {
        "school": "Hannah-Pamplico Elementary/Middle",
        "district": "Florence 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450216001409",
    },
    {
        "school": "Main Street Elementary",
        "district": "Florence 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450219000451",
    },
    {
        "school": "J. C. Lynch Elementary",
        "district": "Florence 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450219000453",
    },
    {
        "school": "Olanta Elementary",
        "district": "Florence 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450219000454",
    },
    {
        "school": "Scranton Elementary",
        "district": "Florence 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450219000456",
    },
    {
        "school": "Lake City High",
        "district": "Florence 03",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450219000458",
    },
    {
        "school": "Timmonsville High",
        "district": "Florence 04",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450222000723",
    },
    {
        "school": "Johnson Middle",
        "district": "Florence 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450222000737",
    },
    {
        "school": "Brockington Elementary",
        "district": "Florence 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450222000738",
    },
    {
        "school": "Johnsonville Elementary",
        "district": "Florence 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450225000466",
    },
    {
        "school": "Johnsonville Middle",
        "district": "Florence 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450225000467",
    },
    {
        "school": "Johnsonville High",
        "district": "Florence 05",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450225000468",
    },
    {
        "school": "Blacksburg Primary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000859",
    },
    {
        "school": "Alma Elementary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000269",
    },
    {
        "school": "Blacksburg Middle",
        "district": "Cherokee 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000271",
    },
    {
        "school": "Corinth Elementary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000273",
    },
    {
        "school": "Draytonville Elementary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000274",
    },
    {
        "school": "Mary Bramlett Elementary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000275",
    },
    {
        "school": "Goucher Elementary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000276",
    },
    {
        "school": "B. D. Lee Elementary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000278",
    },
    {
        "school": "Luther L. Vaughan  Elementary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000282",
    },
    {
        "school": "Blacksburg High",
        "district": "Cherokee 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000283",
    },
    {
        "school": "John E. Ewing Middle",
        "district": "Cherokee 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000284",
    },
    {
        "school": "Gaffney High",
        "district": "Cherokee 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000285",
    },
    {
        "school": "Limestone-Central Elementary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000287",
    },
    {
        "school": "Institute of Innovation",
        "district": "Cherokee 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450150000288",
    },
    {
        "school": "Grassy Pond Elementary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000296",
    },
    {
        "school": "Northwest Elementary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000297",
    },
    {
        "school": "Gaffney Middle",
        "district": "Cherokee 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150000549",
    },
    {
        "school": "Blacksburg Elementary",
        "district": "Cherokee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450150001391",
    },
    {
        "school": "Andrews Elementary",
        "district": "Georgetown 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000469",
    },
    {
        "school": "Brown's Ferry Elementary",
        "district": "Georgetown 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000470",
    },
    {
        "school": "Pleasant Hill Elementary",
        "district": "Georgetown 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000472",
    },
    {
        "school": "Kensington Elementary",
        "district": "Georgetown 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000473",
    },
    {
        "school": "Maryville Elementary",
        "district": "Georgetown 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000474",
    },
    {
        "school": "McDonald Elementary",
        "district": "Georgetown 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000475",
    },
    {
        "school": "Rosemary Middle",
        "district": "Georgetown 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000478",
    },
    {
        "school": "Plantersville Elementary",
        "district": "Georgetown 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000479",
    },
    {
        "school": "Waccamaw Elementary",
        "district": "Georgetown 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000480",
    },
    {
        "school": "Sampit Elementary",
        "district": "Georgetown 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000481",
    },
    {
        "school": "Andrews High",
        "district": "Georgetown 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000482",
    },
    {
        "school": "Georgetown High",
        "district": "Georgetown 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000485",
    },
    {
        "school": "Carvers Bay High",
        "district": "Georgetown 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000554",
    },
    {
        "school": "Carvers Bay Middle",
        "district": "Georgetown 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000555",
    },
    {
        "school": "Waccamaw Middle",
        "district": "Georgetown 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228000739",
    },
    {
        "school": "Georgetown Middle",
        "district": "Georgetown 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228001333",
    },
    {
        "school": "Waccamaw High",
        "district": "Georgetown 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228001440",
    },
    {
        "school": "Langston Charter Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000961",
    },
    {
        "school": "Robert E. Cashion Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001179",
    },
    {
        "school": "Cherrydale Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001180",
    },
    {
        "school": "Waterloo Elementary",
        "district": "Laurens 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450261000558",
    },
    {
        "school": "Ford Elementary",
        "district": "Laurens 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450261000693",
    },
    {
        "school": "E. B. Morse Elementary",
        "district": "Laurens 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450261000696",
    },
    {
        "school": "Laurens Elementary",
        "district": "Laurens 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450261000697",
    },
    {
        "school": "Sanders Middle",
        "district": "Laurens 55",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450261000699",
    },
    {
        "school": "Laurens Middle",
        "district": "Laurens 55",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450261000700",
    },
    {
        "school": "Laurens District 55 High",
        "district": "Laurens 55",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450261000701",
    },
    {
        "school": "M. S. Bailey Child Development Center",
        "district": "Laurens 56",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450264000702",
    },
    {
        "school": "Clinton Elementary",
        "district": "Laurens 56",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450264000703",
    },
    {
        "school": "Joanna Woodson Elementary",
        "district": "Laurens 56",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450264000705",
    },
    {
        "school": "Clinton High",
        "district": "Laurens 56",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450264000708",
    },
    {
        "school": "Clinton Middle",
        "district": "Laurens 56",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450264001264",
    },
    {
        "school": "Eastside Elementary",
        "district": "Laurens 56",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450264001397",
    },
    {
        "school": "Woodmont High",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000574",
    },
    {
        "school": "Heritage Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000049",
    },
    {
        "school": "Oakview Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000114",
    },
    {
        "school": "Chandler Creek Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000449",
    },
    {
        "school": "Mauldin Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000455",
    },
    {
        "school": "Riverside Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000459",
    },
    {
        "school": "Alexander Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000488",
    },
    {
        "school": "Brook Glenn Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000489",
    },
    {
        "school": "Armstrong Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000490",
    },
    {
        "school": "Augusta Circle Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000492",
    },
    {
        "school": "Berea Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000494",
    },
    {
        "school": "Bethel Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000495",
    },
    {
        "school": "Blythe Academy",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000496",
    },
    {
        "school": "Brushy Creek Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000497",
    },
    {
        "school": "Bryson Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000498",
    },
    {
        "school": "Sue Cleveland Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000500",
    },
    {
        "school": "Sara Collins Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000501",
    },
    {
        "school": "Crestview Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000503",
    },
    {
        "school": "Duncan Chapel Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000506",
    },
    {
        "school": "East North Street Academy",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000509",
    },
    {
        "school": "Fork Shoals School",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000512",
    },
    {
        "school": "Fountain Inn Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000513",
    },
    {
        "school": "Hollis Academy",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000514",
    },
    {
        "school": "Lake Forest Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000515",
    },
    {
        "school": "Mauldin Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000517",
    },
    {
        "school": "Mitchell Road Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000518",
    },
    {
        "school": "Monaview Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000519",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000521",
    },
    {
        "school": "Paris Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000523",
    },
    {
        "school": "Pelham Road Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000524",
    },
    {
        "school": "Simpsonville Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000526",
    },
    {
        "school": "Skyland Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000528",
    },
    {
        "school": "Slater Marietta Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000529",
    },
    {
        "school": "Stone Academy",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000530",
    },
    {
        "school": "Summit Drive Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000531",
    },
    {
        "school": "Taylors Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000532",
    },
    {
        "school": "Tigerville Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000533",
    },
    {
        "school": "Welcome Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000536",
    },
    {
        "school": "Westcliffe Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000539",
    },
    {
        "school": "Woodland Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000540",
    },
    {
        "school": "Ellen Woodside Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000541",
    },
    {
        "school": "Greenbrier Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000542",
    },
    {
        "school": "Grove Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000544",
    },
    {
        "school": "Bryson Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000546",
    },
    {
        "school": "Berea High",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000560",
    },
    {
        "school": "Blue Ridge High",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000561",
    },
    {
        "school": "Carolina Academy (High)",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000562",
    },
    {
        "school": "Eastside High",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000563",
    },
    {
        "school": "Greenville Senior High Academy",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000564",
    },
    {
        "school": "Greer High",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000565",
    },
    {
        "school": "Wade Hampton High",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000566",
    },
    {
        "school": "Hillcrest High",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000567",
    },
    {
        "school": "J. L. Mann High Academy",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000568",
    },
    {
        "school": "Mauldin High",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000569",
    },
    {
        "school": "Riverside High",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000571",
    },
    {
        "school": "Southside High",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000572",
    },
    {
        "school": "Travelers Rest High",
        "district": "Greenville 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000573",
    },
    {
        "school": "Washington Center",
        "district": "Greenville 01",
        "level": "Other",
        "type": "Special education school",
        "state": "SC",
        "nces_id": "450231000576",
    },
    {
        "school": "Donaldson Career Center",
        "district": "Greenville 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450231000578",
    },
    {
        "school": "J. Harley Bonds Career Center",
        "district": "Greenville 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450231000579",
    },
    {
        "school": "Enoree Career Center",
        "district": "Greenville 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450231000580",
    },
    {
        "school": "Bell's Crossing Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231000740",
    },
    {
        "school": "Golden Strip Career and Technology Center",
        "district": "Greenville 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450231001164",
    },
    {
        "school": "Beck International Academy",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001240",
    },
    {
        "school": "Berea Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001241",
    },
    {
        "school": "Greenville Middle Academy",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001243",
    },
    {
        "school": "Greer Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001244",
    },
    {
        "school": "Hillcrest Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001245",
    },
    {
        "school": "Hughes Academy of Science and Technology",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001247",
    },
    {
        "school": "Lakeview Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001248",
    },
    {
        "school": "League Academy",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001249",
    },
    {
        "school": "Northwest Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001251",
    },
    {
        "school": "Northwood Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001252",
    },
    {
        "school": "Sevier Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001253",
    },
    {
        "school": "Tanglewood Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001254",
    },
    {
        "school": "Gateway Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001334",
    },
    {
        "school": "Overbrook Child Development Center",
        "district": "Greenville 01",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001335",
    },
    {
        "school": "Plain Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001336",
    },
    {
        "school": "Woodmont Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001337",
    },
    {
        "school": "Buena Vista Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001365",
    },
    {
        "school": "Blue Ridge Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001393",
    },
    {
        "school": "Ambler Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000881",
    },
    {
        "school": "Central Academy of the Arts",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000882",
    },
    {
        "school": "Crosswell Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000883",
    },
    {
        "school": "Dacusville Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000884",
    },
    {
        "school": "East End Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000885",
    },
    {
        "school": "Forest Acres Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000886",
    },
    {
        "school": "Hagood Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000887",
    },
    {
        "school": "Liberty Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000890",
    },
    {
        "school": "Clemson Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000891",
    },
    {
        "school": "Pickens Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000892",
    },
    {
        "school": "Six Mile Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000893",
    },
    {
        "school": "West End Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000894",
    },
    {
        "school": "McKissick Academy of Science and Technology",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000895",
    },
    {
        "school": "Dacusville Middle",
        "district": "Pickens 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000896",
    },
    {
        "school": "R. C. Edwards Middle",
        "district": "Pickens 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000897",
    },
    {
        "school": "Richard H. Gettys Middle",
        "district": "Pickens 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000898",
    },
    {
        "school": "D. W. Daniel High",
        "district": "Pickens 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000899",
    },
    {
        "school": "Easley High",
        "district": "Pickens 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000902",
    },
    {
        "school": "Liberty High",
        "district": "Pickens 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000903",
    },
    {
        "school": "Pickens High",
        "district": "Pickens 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333000904",
    },
    {
        "school": "Pickens County Career and Technology Center",
        "district": "Pickens 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450333000905",
    },
    {
        "school": "Pickens Middle",
        "district": "Pickens 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333001293",
    },
    {
        "school": "Liberty Middle",
        "district": "Pickens 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333001385",
    },
    {
        "school": "Westview Middle",
        "district": "Greenwood 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234000871",
    },
    {
        "school": "G. Frank Russell Technology Center",
        "district": "Greenwood 80",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450000700597",
    },
    {
        "school": "Springfield Elementary",
        "district": "Greenwood 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234000051",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Greenwood 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234000585",
    },
    {
        "school": "Mathews Elementary",
        "district": "Greenwood 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234000587",
    },
    {
        "school": "Merrywood Elementary",
        "district": "Greenwood 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234000588",
    },
    {
        "school": "Pinecrest Elementary",
        "district": "Greenwood 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234000590",
    },
    {
        "school": "Hodges Elementary",
        "district": "Greenwood 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234000591",
    },
    {
        "school": "Woodfields Elementary",
        "district": "Greenwood 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234000592",
    },
    {
        "school": "Emerald High",
        "district": "Greenwood 50",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234000593",
    },
    {
        "school": "Northside Middle",
        "district": "Greenwood 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234000594",
    },
    {
        "school": "Greenwood High",
        "district": "Greenwood 50",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234000596",
    },
    {
        "school": "Brewer Middle",
        "district": "Greenwood 50",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234001255",
    },
    {
        "school": "Eleanor S. Rice Elementary",
        "district": "Greenwood 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234001338",
    },
    {
        "school": "Ware Shoals Elementary Middle",
        "district": "Greenwood 51",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450237000598",
    },
    {
        "school": "Ware Shoals Primary",
        "district": "Greenwood 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450237000599",
    },
    {
        "school": "Ware Shoals High",
        "district": "Greenwood 51",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450237000601",
    },
    {
        "school": "Ninety Six Elementary",
        "district": "Greenwood 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450240000602",
    },
    {
        "school": "Edgewood Middle",
        "district": "Greenwood 52",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450240000603",
    },
    {
        "school": "Ninety Six High",
        "district": "Greenwood 52",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450240000604",
    },
    {
        "school": "Ninety Six Primary",
        "district": "Greenwood 52",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450240000746",
    },
    {
        "school": "Okatie Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000819",
    },
    {
        "school": "Hilton Head Island Early Childhood Center",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000941",
    },
    {
        "school": "Hilton Head Island School for the Creative Arts",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000942",
    },
    {
        "school": "Hilton Head Island Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000943",
    },
    {
        "school": "Bluffton High",
        "district": "Beaufort 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001165",
    },
    {
        "school": "Ridgeland-Hardeeville High",
        "district": "Jasper 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450252001487",
    },
    {
        "school": "Beaufort-Jasper Academy for Career Excellence",
        "district": "Beaufort 80",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450110000152",
    },
    {
        "school": "Joseph S. Shanklin Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000047",
    },
    {
        "school": "Beaufort Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000135",
    },
    {
        "school": "Broad River Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000136",
    },
    {
        "school": "Lady's Island Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000140",
    },
    {
        "school": "Mossy Oaks Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000141",
    },
    {
        "school": "Port Royal Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000142",
    },
    {
        "school": "Michael C. Riley Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000143",
    },
    {
        "school": "St. Helena Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000145",
    },
    {
        "school": "Beaufort High",
        "district": "Beaufort 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000147",
    },
    {
        "school": "Battery Creek High",
        "district": "Beaufort 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000149",
    },
    {
        "school": "Coosa Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000270",
    },
    {
        "school": "Whale Branch Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000392",
    },
    {
        "school": "Bluffton Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000418",
    },
    {
        "school": "H. E. McCracken Middle",
        "district": "Beaufort 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000420",
    },
    {
        "school": "Whale Branch Middle",
        "district": "Beaufort 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000422",
    },
    {
        "school": "Beaufort Middle",
        "district": "Beaufort 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111000547",
    },
    {
        "school": "Hilton Head Island High",
        "district": "Beaufort 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001350",
    },
    {
        "school": "Lady's Island Middle",
        "district": "Beaufort 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001360",
    },
    {
        "school": "Hilton Head Island Middle",
        "district": "Beaufort 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001361",
    },
    {
        "school": "Hardeeville Elementary",
        "district": "Jasper 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450252001395",
    },
    {
        "school": "Ridgeland Elementary",
        "district": "Jasper 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450252001396",
    },
    {
        "school": "Hardeeville-Ridgeland Middle",
        "district": "Jasper 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450252001449",
    },
    {
        "school": "Indian Land Middle",
        "district": "Lancaster 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258001490",
    },
    {
        "school": "Buford Middle",
        "district": "Lancaster 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000039",
    },
    {
        "school": "Discovery Charter of Lancaster",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000556",
    },
    {
        "school": "Brooklyn Springs Elementary",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000670",
    },
    {
        "school": "Buford Elementary",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000671",
    },
    {
        "school": "Clinton Elementary",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000673",
    },
    {
        "school": "Erwin Elementary",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000675",
    },
    {
        "school": "Heath Springs Elementary",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000677",
    },
    {
        "school": "Indian Land Elementary",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000678",
    },
    {
        "school": "Kershaw Elementary",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000680",
    },
    {
        "school": "McDonald Green Elementary",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000681",
    },
    {
        "school": "Andrew Jackson Middle",
        "district": "Lancaster 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000685",
    },
    {
        "school": "Andrew Jackson High",
        "district": "Lancaster 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000688",
    },
    {
        "school": "Indian Land High",
        "district": "Lancaster 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000689",
    },
    {
        "school": "Lancaster High",
        "district": "Lancaster 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258000691",
    },
    {
        "school": "A. R. Rucker Middle",
        "district": "Lancaster 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258001260",
    },
    {
        "school": "Buford High",
        "district": "Lancaster 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258001261",
    },
    {
        "school": "North Elementary",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258001262",
    },
    {
        "school": "South Middle",
        "district": "Lancaster 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258001263",
    },
    {
        "school": "Aynor Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000872",
    },
    {
        "school": "St. James High",
        "district": "Horry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000900",
    },
    {
        "school": "Waterway Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000901",
    },
    {
        "school": "Bridgewater Academy Charter",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000906",
    },
    {
        "school": "Academy for Technology and Academics",
        "district": "Horry 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450249001037",
    },
    {
        "school": "Burgess Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001486",
    },
    {
        "school": "Carolina Forest Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000191",
    },
    {
        "school": "Seaside Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000192",
    },
    {
        "school": "Forestbrook Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000243",
    },
    {
        "school": "Carolina Forest High",
        "district": "Horry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000244",
    },
    {
        "school": "Socastee Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000246",
    },
    {
        "school": "Aynor Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000614",
    },
    {
        "school": "Daisy Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000616",
    },
    {
        "school": "Green Sea Floyds Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000617",
    },
    {
        "school": "Conway Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000618",
    },
    {
        "school": "South Conway Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000621",
    },
    {
        "school": "Loris Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000622",
    },
    {
        "school": "Midland Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000623",
    },
    {
        "school": "North Myrtle Beach Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000625",
    },
    {
        "school": "Homewood Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000626",
    },
    {
        "school": "Kingston Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000628",
    },
    {
        "school": "Waccamaw Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000629",
    },
    {
        "school": "Pee Dee Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000630",
    },
    {
        "school": "Lakewood Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000632",
    },
    {
        "school": "Conway Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000634",
    },
    {
        "school": "Loris Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000637",
    },
    {
        "school": "Socastee High",
        "district": "Horry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000639",
    },
    {
        "school": "Myrtle Beach High",
        "district": "Horry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000640",
    },
    {
        "school": "Green Sea Floyds High",
        "district": "Horry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000641",
    },
    {
        "school": "Conway High",
        "district": "Horry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000642",
    },
    {
        "school": "Loris High",
        "district": "Horry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000643",
    },
    {
        "school": "North Myrtle Beach High",
        "district": "Horry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000644",
    },
    {
        "school": "Aynor High",
        "district": "Horry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000645",
    },
    {
        "school": "Academy For Arts/Science/Technology",
        "district": "Horry 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450249000647",
    },
    {
        "school": "Palmetto Bays Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249000747",
    },
    {
        "school": "Whittemore Park Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001178",
    },
    {
        "school": "Myrtle Beach Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001340",
    },
    {
        "school": "St. James Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001341",
    },
    {
        "school": "Forestbrook Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001418",
    },
    {
        "school": "St. James Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001419",
    },
    {
        "school": "Whitmire Community School (Elementary)",
        "district": "Newberry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303000059",
    },
    {
        "school": "Boundary St. Elementary",
        "district": "Newberry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303000805",
    },
    {
        "school": "Little Mountain Elementary",
        "district": "Newberry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303000807",
    },
    {
        "school": "Reuben Elementary",
        "district": "Newberry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303000811",
    },
    {
        "school": "Newberry Elementary",
        "district": "Newberry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303000812",
    },
    {
        "school": "Mid-Carolina High",
        "district": "Newberry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303000818",
    },
    {
        "school": "Whitmire Community School (High)",
        "district": "Newberry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303000820",
    },
    {
        "school": "Newberry County Career Center",
        "district": "Newberry 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450303000821",
    },
    {
        "school": "Gallman Elementary",
        "district": "Newberry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303001281",
    },
    {
        "school": "Pomaria-Garmany Elementary",
        "district": "Newberry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303001282",
    },
    {
        "school": "Mid-Carolina Middle",
        "district": "Newberry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303001283",
    },
    {
        "school": "Newberry Middle",
        "district": "Newberry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303001284",
    },
    {
        "school": "Newberry High",
        "district": "Newberry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303001285",
    },
    {
        "school": "Prosperity-Rikard Elementary",
        "district": "Newberry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450303001286",
    },
    {
        "school": "Cope Area Career Center",
        "district": "Orangeburg 80",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450000800863",
    },
    {
        "school": "West Oak Middle",
        "district": "Oconee 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306001477",
    },
    {
        "school": "Fair-Oak Elementary",
        "district": "Oconee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306000194",
    },
    {
        "school": "Orchard Park Elementary",
        "district": "Oconee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306000252",
    },
    {
        "school": "Keowee Elementary",
        "district": "Oconee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306000824",
    },
    {
        "school": "Northside Elementary",
        "district": "Oconee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306000825",
    },
    {
        "school": "James M. Brown Elementary",
        "district": "Oconee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306000828",
    },
    {
        "school": "Ravenel Elementary",
        "district": "Oconee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306000829",
    },
    {
        "school": "Tamassee-Salem Elementary",
        "district": "Oconee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306000832",
    },
    {
        "school": "Walhalla Elementary",
        "district": "Oconee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306000834",
    },
    {
        "school": "Westminster Elementary",
        "district": "Oconee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306000835",
    },
    {
        "school": "Seneca High",
        "district": "Oconee 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306000841",
    },
    {
        "school": "Walhalla High",
        "district": "Oconee 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306000842",
    },
    {
        "school": "Fred P. Hamilton Career Center",
        "district": "Oconee 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450306000844",
    },
    {
        "school": "Walhalla Middle",
        "district": "Oconee 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306001288",
    },
    {
        "school": "West-Oak High",
        "district": "Oconee 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306001357",
    },
    {
        "school": "Seneca Middle",
        "district": "Oconee 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306001436",
    },
    {
        "school": "SC School for the Blind High",
        "district": "Deaf & Blind School",
        "level": "High",
        "type": "Special education school",
        "state": "SC",
        "nces_id": "450000401226",
    },
    {
        "school": "SC School for the Deaf High",
        "district": "Deaf & Blind School",
        "level": "High",
        "type": "Special education school",
        "state": "SC",
        "nces_id": "450000401227",
    },
    {
        "school": "SC School for the Deaf Elementary/Middle",
        "district": "Deaf & Blind School",
        "level": "Elementary",
        "type": "Special education school",
        "state": "SC",
        "nces_id": "450000401228",
    },
    {
        "school": "SC School for the Blind Elementary/Middle",
        "district": "Deaf & Blind School",
        "level": "Elementary",
        "type": "Special education school",
        "state": "SC",
        "nces_id": "450000401246",
    },
    {
        "school": "Inman Intermediate",
        "district": "Spartanburg 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450348001475",
    },
    {
        "school": "Boiling Springs High Ninth Grade Campus",
        "district": "Spartanburg 02",
        "level": "Secondary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351000937",
    },
    {
        "school": "Oakland Elementary",
        "district": "Spartanburg 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351000938",
    },
    {
        "school": "Florence Chapel Middle",
        "district": "Spartanburg 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360000997",
    },
    {
        "school": "James Byrnes Freshman Academy",
        "district": "Spartanburg 05",
        "level": "Secondary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360001476",
    },
    {
        "school": "Cedar Springs Academy",
        "district": "Deaf & Blind School",
        "level": "Other",
        "type": "Special education school",
        "state": "SC",
        "nces_id": "450000401402",
    },
    {
        "school": "R. D. Anderson Applied Technology Center",
        "district": "Spartanburg 81",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450001001039",
    },
    {
        "school": "H. B. Swofford Career Center",
        "district": "Spartanburg 82",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450001100991",
    },
    {
        "school": "Daniel Morgan Technology Center",
        "district": "Spartanburg 80",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450347001056",
    },
    {
        "school": "Landrum Middle",
        "district": "Spartanburg 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450348000060",
    },
    {
        "school": "Campobello-Gramling School",
        "district": "Spartanburg 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450348000983",
    },
    {
        "school": "O. P. Earle Elementary",
        "district": "Spartanburg 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450348000984",
    },
    {
        "school": "Holly Springs-Motlow Elementary",
        "district": "Spartanburg 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450348000985",
    },
    {
        "school": "Inman Elementary",
        "district": "Spartanburg 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450348000986",
    },
    {
        "school": "New Prospect Elementary",
        "district": "Spartanburg 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450348000987",
    },
    {
        "school": "Chapman High",
        "district": "Spartanburg 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450348000988",
    },
    {
        "school": "Landrum High",
        "district": "Spartanburg 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450348000989",
    },
    {
        "school": "T.E. Mabry Middle",
        "district": "Spartanburg 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450348000990",
    },
    {
        "school": "Carlisle-Foster's Grove Elementary",
        "district": "Spartanburg 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351000146",
    },
    {
        "school": "Boiling Springs Elementary",
        "district": "Spartanburg 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351000992",
    },
    {
        "school": "Chesnee Elementary",
        "district": "Spartanburg 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351000994",
    },
    {
        "school": "Cooley Springs-Fingerville Elementary",
        "district": "Spartanburg 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351000995",
    },
    {
        "school": "James H. Hendrix  Elementary",
        "district": "Spartanburg 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351000996",
    },
    {
        "school": "Mayo Elementary",
        "district": "Spartanburg 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351000998",
    },
    {
        "school": "Boiling Springs High",
        "district": "Spartanburg 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351001000",
    },
    {
        "school": "Chesnee High",
        "district": "Spartanburg 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351001001",
    },
    {
        "school": "Boiling Springs Middle",
        "district": "Spartanburg 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351001002",
    },
    {
        "school": "Boiling Springs Intermediate",
        "district": "Spartanburg 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351001410",
    },
    {
        "school": "Chesnee Middle",
        "district": "Spartanburg 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351001451",
    },
    {
        "school": "Cannons Elementary",
        "district": "Spartanburg 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450354001003",
    },
    {
        "school": "Cowpens Elementary",
        "district": "Spartanburg 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450354001005",
    },
    {
        "school": "Pacolet Elementary",
        "district": "Spartanburg 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450354001008",
    },
    {
        "school": "Cowpens Middle",
        "district": "Spartanburg 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450354001009",
    },
    {
        "school": "Broome High",
        "district": "Spartanburg 03",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450354001010",
    },
    {
        "school": "Middle School of Pacolet",
        "district": "Spartanburg 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450354001011",
    },
    {
        "school": "Woodruff Primary",
        "district": "Spartanburg 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450357001012",
    },
    {
        "school": "Woodruff Elementary",
        "district": "Spartanburg 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450357001013",
    },
    {
        "school": "Woodruff Middle",
        "district": "Spartanburg 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450357001014",
    },
    {
        "school": "Woodruff High",
        "district": "Spartanburg 04",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450357001015",
    },
    {
        "school": "Beech Springs Intermediate",
        "district": "Spartanburg 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360000209",
    },
    {
        "school": "River Ridge Elementary",
        "district": "Spartanburg 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360000253",
    },
    {
        "school": "Berry Shoals Intermediate",
        "district": "Spartanburg 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360000651",
    },
    {
        "school": "Duncan Elementary School of the Arts",
        "district": "Spartanburg 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360001016",
    },
    {
        "school": "Reidville Elementary",
        "district": "Spartanburg 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360001018",
    },
    {
        "school": "Wellford Academy of Science and Technology",
        "district": "Spartanburg 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360001021",
    },
    {
        "school": "James F. Byrnes High",
        "district": "Spartanburg 05",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360001022",
    },
    {
        "school": "D. R. Hill Middle",
        "district": "Spartanburg 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360001023",
    },
    {
        "school": "Roebuck Elementary",
        "district": "Spartanburg 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363000029",
    },
    {
        "school": "Anderson Mill Elementary",
        "district": "Spartanburg 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363000349",
    },
    {
        "school": "Arcadia Elementary",
        "district": "Spartanburg 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363001024",
    },
    {
        "school": "Fairforest Elementary",
        "district": "Spartanburg 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363001025",
    },
    {
        "school": "Lone Oak Elementary",
        "district": "Spartanburg 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363001027",
    },
    {
        "school": "Pauline-Glenn Springs Elementary",
        "district": "Spartanburg 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363001028",
    },
    {
        "school": "Jesse S. Bobo Elementary",
        "district": "Spartanburg 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363001031",
    },
    {
        "school": "West View Elementary",
        "district": "Spartanburg 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363001032",
    },
    {
        "school": "Woodland Heights Elementary",
        "district": "Spartanburg 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363001033",
    },
    {
        "school": "Dorman High",
        "district": "Spartanburg 06",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363001038",
    },
    {
        "school": "Fairforest Middle",
        "district": "Spartanburg 06",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363001314",
    },
    {
        "school": "L. E. Gable Middle",
        "district": "Spartanburg 06",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363001315",
    },
    {
        "school": "R. P. Dawkins Middle",
        "district": "Spartanburg 06",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450363001316",
    },
    {
        "school": "Jesse Boyd Elementary",
        "district": "Spartanburg 07",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450366001040",
    },
    {
        "school": "E. P. Todd School",
        "district": "Spartanburg 07",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450366001041",
    },
    {
        "school": "The Cleveland Academy of Leadership",
        "district": "Spartanburg 07",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450366001042",
    },
    {
        "school": "Pine St. Elementary",
        "district": "Spartanburg 07",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450366001046",
    },
    {
        "school": "Mary H. Wright Elementary",
        "district": "Spartanburg 07",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450366001048",
    },
    {
        "school": "Carver Middle",
        "district": "Spartanburg 07",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450366001049",
    },
    {
        "school": "McCracken Middle",
        "district": "Spartanburg 07",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450366001051",
    },
    {
        "school": "Spartanburg High",
        "district": "Spartanburg 07",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450366001052",
    },
    {
        "school": "Buffalo Elementary",
        "district": "Union 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450375001082",
    },
    {
        "school": "Foster Park Elementary",
        "district": "Union 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450375001085",
    },
    {
        "school": "Jonesville Elementary Middle",
        "district": "Union 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450375001086",
    },
    {
        "school": "Monarch Elementary",
        "district": "Union 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450375001088",
    },
    {
        "school": "Sims Middle",
        "district": "Union 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450375001089",
    },
    {
        "school": "Union County High",
        "district": "Union 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450375001092",
    },
    {
        "school": "Northside Elementary",
        "district": "Colleton 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450183000189",
    },
    {
        "school": "Bells Elementary",
        "district": "Colleton 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450183000332",
    },
    {
        "school": "Black Street Early Childhood Center",
        "district": "Colleton 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450183000333",
    },
    {
        "school": "Cottageville Elementary",
        "district": "Colleton 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450183000336",
    },
    {
        "school": "Forest Hills Elementary",
        "district": "Colleton 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450183000337",
    },
    {
        "school": "Colleton County High",
        "district": "Colleton 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450183000347",
    },
    {
        "school": "Thunderbolt Career and Technology Center",
        "district": "Colleton 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450183000348",
    },
    {
        "school": "Hendersonville Elementary",
        "district": "Colleton 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450183000713",
    },
    {
        "school": "Grass Ranch Colony High School - 15",
        "district": "Kimball School District 07-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463822001185",
    },
    {
        "school": "Elk Mountain Virtual High School - 92",
        "district": "Elk Mountain School District 16-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462130001186",
    },
    {
        "school": "Contract - 02",
        "district": "Big Stone City School District 25-1",
        "level": "Other",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460696001182",
    },
    {
        "school": "Madison Elementary - 07",
        "district": "Madison Central School District 39-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463960001189",
    },
    {
        "school": "Westwood Rural Elementary - 05",
        "district": "Britton-Hecla School District 45-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004101180",
    },
    {
        "school": "Hitchcock-Tulare Elementary - 05",
        "district": "Hitchcock Tulare School District 56-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004601167",
    },
    {
        "school": "E. A. G. L. E. Center High School - 07",
        "district": "Eagle Butte School District 20-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "462010001233",
    },
    {
        "school": "Brentwood Colony Elementary - 05",
        "district": "Faulkton Area Schools 24-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462403001090",
    },
    {
        "school": "Blumengard Colony Elementary - 06",
        "district": "Faulkton Area Schools 24-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462403001158",
    },
    {
        "school": "Thunderbird Colony Elementary - 10",
        "district": "Faulkton Area Schools 24-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462403001160",
    },
    {
        "school": "Britton-Hecla Elementary - 02",
        "district": "Britton-Hecla School District 45-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004101140",
    },
    {
        "school": "Britton-Hecla High School - 01",
        "district": "Britton-Hecla School District 45-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004101141",
    },
    {
        "school": "Britton-Hecla Middle School - 03",
        "district": "Britton-Hecla School District 45-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004101142",
    },
    {
        "school": "Sunset Colony Elementary - 04",
        "district": "Britton-Hecla School District 45-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004101143",
    },
    {
        "school": "Shannon Colony Elementary - 08",
        "district": "Howard School District 48-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460002501161",
    },
    {
        "school": "Sisseton High School - 01",
        "district": "Sisseton School District 54-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460005301239",
    },
    {
        "school": "Westside Elementary - 03",
        "district": "Sisseton School District 54-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460005301241",
    },
    {
        "school": "Sanborn Central Elementary - 06",
        "district": "Sanborn Central School District 55-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460393201162",
    },
    {
        "school": "Hitchcock-Tulare High School - 01",
        "district": "Hitchcock Tulare School District 56-6",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004601163",
    },
    {
        "school": "Hitchcock-Tulare Jr. High School - 02",
        "district": "Hitchcock Tulare School District 56-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004601164",
    },
    {
        "school": "Spink Colony Elementary - 03",
        "district": "Hitchcock Tulare School District 56-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004601165",
    },
    {
        "school": "Glendale Colony Elementary - 04",
        "district": "Hitchcock Tulare School District 56-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004601166",
    },
    {
        "school": "Onida Elementary - 04",
        "district": "Agar-Blunt-Onida School District 58-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004200655",
    },
    {
        "school": "Sully Buttes High School - 07",
        "district": "Agar-Blunt-Onida School District 58-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004200656",
    },
    {
        "school": "Blunt Elementary - 03",
        "district": "Agar-Blunt-Onida School District 58-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004200855",
    },
    {
        "school": "Sully Buttes Middle School - 06",
        "district": "Agar-Blunt-Onida School District 58-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004200939",
    },
    {
        "school": "Plankinton Elementary - 02",
        "district": "Plankinton School District 01-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465571000507",
    },
    {
        "school": "Plankinton High School - 01",
        "district": "Plankinton School District 01-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465571000508",
    },
    {
        "school": "Plankinton Jr. High - 03",
        "district": "Plankinton School District 01-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465571000927",
    },
    {
        "school": "White Lake Elementary - 02",
        "district": "White Lake School District 01-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467851000745",
    },
    {
        "school": "White Lake High School - 01",
        "district": "White Lake School District 01-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467851000746",
    },
    {
        "school": "White Lake Jr. High - 03",
        "district": "White Lake School District 01-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467851000950",
    },
    {
        "school": "Shamrock Colony Elementary - 05",
        "district": "Willow Lake School District 12-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467935001137",
    },
    {
        "school": "Bennett County High School - 01",
        "district": "Bennett County School District 03-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460624000042",
    },
    {
        "school": "Martin Elementary - 03",
        "district": "Bennett County School District 03-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460624000045",
    },
    {
        "school": "Bennett County Middle School - 06",
        "district": "Bennett County School District 03-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460624001015",
    },
    {
        "school": "Avon Elementary - 02",
        "district": "Avon School District 04-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460427000028",
    },
    {
        "school": "Avon High School - 01",
        "district": "Avon School District 04-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460427000029",
    },
    {
        "school": "Avon Jr. High - 05",
        "district": "Avon School District 04-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460427000829",
    },
    {
        "school": "Hutterische Colony Elementary - 18",
        "district": "Bon Homme School District 04-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460740000060",
    },
    {
        "school": "Springfield Elementary - 03",
        "district": "Bon Homme School District 04-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460740000061",
    },
    {
        "school": "Tabor Elementary - 05",
        "district": "Bon Homme School District 04-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460740000063",
    },
    {
        "school": "Tyndall Elementary - 04",
        "district": "Bon Homme School District 04-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460740000064",
    },
    {
        "school": "Bon Homme High School - 01",
        "district": "Bon Homme School District 04-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460740000065",
    },
    {
        "school": "Bon Homme Middle School - 02",
        "district": "Bon Homme School District 04-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460740000987",
    },
    {
        "school": "Scotland Elementary - 02",
        "district": "Scotland School District 04-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466518000568",
    },
    {
        "school": "Scotland High School - 01",
        "district": "Scotland School District 04-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466518000569",
    },
    {
        "school": "Scotland Middle School - 05",
        "district": "Scotland School District 04-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466518000933",
    },
    {
        "school": "Chamberlain Elementary - 03",
        "district": "Chamberlain School District 07-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461200000118",
    },
    {
        "school": "Chamberlain High School - 01",
        "district": "Chamberlain School District 07-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461200000119",
    },
    {
        "school": "Chamberlain Jr. High - 02",
        "district": "Chamberlain School District 07-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461200000889",
    },
    {
        "school": "Kimball Middle School - 04",
        "district": "Kimball School District 07-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463822000142",
    },
    {
        "school": "Kimball Elementary - 02",
        "district": "Kimball School District 07-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463822000354",
    },
    {
        "school": "Kimball High School - 01",
        "district": "Kimball School District 07-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463822000355",
    },
    {
        "school": "Grass Ranch Colony Elementary - 13",
        "district": "Kimball School District 07-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463822000917",
    },
    {
        "school": "Belle Fourche High School - 01",
        "district": "Belle Fourche School District 09-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460561000038",
    },
    {
        "school": "South Park Elementary - 03",
        "district": "Belle Fourche School District 09-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460561000269",
    },
    {
        "school": "North Park Elementary - 08",
        "district": "Belle Fourche School District 09-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460561000289",
    },
    {
        "school": "Belle Fourche Middle School - 07",
        "district": "Belle Fourche School District 09-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460561001117",
    },
    {
        "school": "Newell Elementary - 02",
        "district": "Newell School District 09-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465085000468",
    },
    {
        "school": "Newell High School - 01",
        "district": "Newell School District 09-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465085000469",
    },
    {
        "school": "Newell Middle School - 04",
        "district": "Newell School District 09-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465085000968",
    },
    {
        "school": "Herreid Elementary - 02",
        "district": "Herreid School District 10-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463243000277",
    },
    {
        "school": "Herreid High School - 01",
        "district": "Herreid School District 10-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463243000278",
    },
    {
        "school": "Herreid Middle School - 03",
        "district": "Herreid School District 10-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463243000910",
    },
    {
        "school": "Andes Central Elementary - 02",
        "district": "Andes Central School District 11-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463954000359",
    },
    {
        "school": "Andes Central High School - 01",
        "district": "Andes Central School District 11-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463954000360",
    },
    {
        "school": "Andes Central Middle School - 04",
        "district": "Andes Central School District 11-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463954000850",
    },
    {
        "school": "Lakeview Colony Elementary - 05",
        "district": "Andes Central School District 11-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463954001080",
    },
    {
        "school": "Clearfield Colony Elementary - 07",
        "district": "Tripp-Delmont School District 33-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467245001091",
    },
    {
        "school": "Wagner Elementary - 02",
        "district": "Wagner Community School District 11-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467542000694",
    },
    {
        "school": "Wagner High School - 01",
        "district": "Wagner Community School District 11-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467542000695",
    },
    {
        "school": "Wagner Middle School - 03",
        "district": "Wagner Community School District 11-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467542000942",
    },
    {
        "school": "Clark Elementary - 02",
        "district": "Clark School District 12-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461294000132",
    },
    {
        "school": "Clark High School - 01",
        "district": "Clark School District 12-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461294000133",
    },
    {
        "school": "Clark Middle School - 03",
        "district": "Clark School District 12-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461294000890",
    },
    {
        "school": "Fordham Colony Elementary - 04",
        "district": "Clark School District 12-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461294001081",
    },
    {
        "school": "Hillcrest Colony Elementary - 05",
        "district": "Clark School District 12-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461294001082",
    },
    {
        "school": "Clark Colony Elementary - 05",
        "district": "Doland School District 56-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461917001101",
    },
    {
        "school": "Willow Lake Elementary - 02",
        "district": "Willow Lake School District 12-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467935000755",
    },
    {
        "school": "Willow Lake High School - 01",
        "district": "Willow Lake School District 12-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467935000756",
    },
    {
        "school": "Willow Lake Middle School - 03",
        "district": "Willow Lake School District 12-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467935000952",
    },
    {
        "school": "Mayfield Colony Elementary - 04",
        "district": "Willow Lake School District 12-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467935001067",
    },
    {
        "school": "McIntosh Elementary - 02",
        "district": "McIntosh School District 15-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464626000410",
    },
    {
        "school": "McIntosh High School - 01",
        "district": "McIntosh School District 15-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464626000411",
    },
    {
        "school": "McIntosh Jr. High - 03",
        "district": "McIntosh School District 15-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464626000921",
    },
    {
        "school": "McLaughlin Elementary - 02",
        "district": "McLaughlin School District 15-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464638000415",
    },
    {
        "school": "McLaughlin High School - 01",
        "district": "McLaughlin School District 15-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464638000416",
    },
    {
        "school": "McLaughlin Middle School - 03",
        "district": "McLaughlin School District 15-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464638000922",
    },
    {
        "school": "Wakpala Elementary - 02",
        "district": "Smee School District 15-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467560000698",
    },
    {
        "school": "Wakpala High School - 01",
        "district": "Smee School District 15-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467560000699",
    },
    {
        "school": "Custer Elementary - 02",
        "district": "Custer School District 16-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461695000154",
    },
    {
        "school": "Custer High School - 01",
        "district": "Custer School District 16-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461695000155",
    },
    {
        "school": "Hermosa Elementary - 04",
        "district": "Custer School District 16-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461695000159",
    },
    {
        "school": "Custer Jr. High - 05",
        "district": "Custer School District 16-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461695000992",
    },
    {
        "school": "Red Shirt School - 04",
        "district": "Oglala Lakota County 65-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466546000575",
    },
    {
        "school": "Waubay Elementary - 02",
        "district": "Waubay School District 18-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467668000719",
    },
    {
        "school": "Waubay High School - 01",
        "district": "Waubay School District 18-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467668000720",
    },
    {
        "school": "Waubay Middle School - 03",
        "district": "Waubay School District 18-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467668000945",
    },
    {
        "school": "Webster Area Elementary - 03",
        "district": "Webster Area 18-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467699000723",
    },
    {
        "school": "Webster Area High School - 01",
        "district": "Webster Area 18-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467699000724",
    },
    {
        "school": "Webster Area Middle School - 02",
        "district": "Webster Area 18-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467699000947",
    },
    {
        "school": "Deuel High School - 01",
        "district": "Deuel School District 19-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460003601010",
    },
    {
        "school": "Clear Lake Elementary - 02",
        "district": "Deuel School District 19-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460003601011",
    },
    {
        "school": "Clear Lake Middle School - 04",
        "district": "Deuel School District 19-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460003601013",
    },
    {
        "school": "Eagle Butte Upper Elementary - 03",
        "district": "Eagle Butte School District 20-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462010000605",
    },
    {
        "school": "Eagle Butte Primary - 02",
        "district": "Eagle Butte School District 20-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462010000897",
    },
    {
        "school": "Eagle Butte Jr. High - 06",
        "district": "Eagle Butte School District 20-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462010000898",
    },
    {
        "school": "Eagle Butte High School - 01",
        "district": "Eagle Butte School District 20-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462010000956",
    },
    {
        "school": "Timber Lake Elementary - 02",
        "district": "Timber Lake School District 20-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467188000664",
    },
    {
        "school": "Timber Lake High School - 01",
        "district": "Timber Lake School District 20-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467188000665",
    },
    {
        "school": "Timber Lake Middle School - 03",
        "district": "Timber Lake School District 20-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467188000940",
    },
    {
        "school": "Armour Elementary - 02",
        "district": "Armour School District 21-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460378000023",
    },
    {
        "school": "Armour High School - 01",
        "district": "Armour School District 21-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460378000024",
    },
    {
        "school": "Armour Middle School - 03",
        "district": "Armour School District 21-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460378000878",
    },
    {
        "school": "Greenwood Colony Elementary - 05",
        "district": "Tripp-Delmont School District 33-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467245000067",
    },
    {
        "school": "Edgemont Elementary - 03",
        "district": "Edgemont School District 23-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462085000181",
    },
    {
        "school": "Edgemont High School - 01",
        "district": "Edgemont School District 23-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462085000182",
    },
    {
        "school": "Elk Mountain Elementary - 01",
        "district": "Elk Mountain School District 16-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462130000899",
    },
    {
        "school": "Hot Springs Elementary - 02",
        "district": "Hot Springs School District 23-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463448000287",
    },
    {
        "school": "Hot Springs High School - 01",
        "district": "Hot Springs School District 23-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463448000288",
    },
    {
        "school": "Hot Springs Middle School - 06",
        "district": "Hot Springs School District 23-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463448000911",
    },
    {
        "school": "Oelrichs Elementary - 02",
        "district": "Oelrichs School District 23-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465277000481",
    },
    {
        "school": "Oelrichs High School - 01",
        "district": "Oelrichs School District 23-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465277000482",
    },
    {
        "school": "Oelrichs Jr. High - 03",
        "district": "Oelrichs School District 23-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465277000608",
    },
    {
        "school": "Faulkton Elementary - 02",
        "district": "Faulkton Area Schools 24-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462403000202",
    },
    {
        "school": "Faulkton High School - 01",
        "district": "Faulkton Area Schools 24-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462403000203",
    },
    {
        "school": "Faulkton Jr. High - 08",
        "district": "Faulkton Area Schools 24-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462403000204",
    },
    {
        "school": "Koch Elementary - 03",
        "district": "Milbank School District 25-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460000200423",
    },
    {
        "school": "Milbank High School - 01",
        "district": "Milbank School District 25-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460000200424",
    },
    {
        "school": "Milbank Middle School - 02",
        "district": "Milbank School District 25-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460000200425",
    },
    {
        "school": "Big Stone City Elementary - 01",
        "district": "Big Stone City School District 25-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460696000053",
    },
    {
        "school": "Big Stone City Middle School - 03",
        "district": "Big Stone City School District 25-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460696000352",
    },
    {
        "school": "South Central Elementary - 03",
        "district": "South Central 26-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460767000882",
    },
    {
        "school": "Burke Elementary - 02",
        "district": "Burke School District 26-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460951200100",
    },
    {
        "school": "Burke High School - 01",
        "district": "Burke School District 26-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460951200101",
    },
    {
        "school": "Burke Middle School - 04",
        "district": "Burke School District 26-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460951201043",
    },
    {
        "school": "Gregory Elementary - 02",
        "district": "Gregory School District 26-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462988000238",
    },
    {
        "school": "Gregory High School - 01",
        "district": "Gregory School District 26-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462988000239",
    },
    {
        "school": "Philip Jr. High - 03",
        "district": "Haakon School District 27-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463049000247",
    },
    {
        "school": "Philip Elementary - 02",
        "district": "Haakon School District 27-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463049000255",
    },
    {
        "school": "Philip High School - 01",
        "district": "Haakon School District 27-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463049000256",
    },
    {
        "school": "Milesville Elementary - 08",
        "district": "Haakon School District 27-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463049000647",
    },
    {
        "school": "Miller Elementary - 02",
        "district": "Miller 29-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464794200429",
    },
    {
        "school": "Miller High School - 01",
        "district": "Miller 29-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464794200430",
    },
    {
        "school": "Millerdale Colony Elementary - 11",
        "district": "Miller 29-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464794200431",
    },
    {
        "school": "Miller Jr. High - 04",
        "district": "Miller 29-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464794201051",
    },
    {
        "school": "Buffalo Elementary - 02",
        "district": "Harding County School District 31-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460930000087",
    },
    {
        "school": "Harding County High School - 01",
        "district": "Harding County School District 31-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460930000088",
    },
    {
        "school": "Ludlow Elementary - 06",
        "district": "Harding County School District 31-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460930000667",
    },
    {
        "school": "Camp Crook Elementary - 08",
        "district": "Harding County School District 31-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460930000701",
    },
    {
        "school": "Harding County Middle School - 03",
        "district": "Harding County School District 31-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460930000887",
    },
    {
        "school": "Freeman Elementary - 02",
        "district": "Freeman School District 33-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462550000219",
    },
    {
        "school": "Freeman High School - 01",
        "district": "Freeman School District 33-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462550000220",
    },
    {
        "school": "Tschetter Colony Elementary - 03",
        "district": "Freeman School District 33-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462550000221",
    },
    {
        "school": "Wolf Creek Colony Elementary - 04",
        "district": "Freeman School District 33-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462550000222",
    },
    {
        "school": "Freeman Jr. High - 05",
        "district": "Freeman School District 33-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462550000842",
    },
    {
        "school": "Maxwell Colony Elementary - 04",
        "district": "Menno School District 33-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464710000418",
    },
    {
        "school": "Menno Elementary - 02",
        "district": "Menno School District 33-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464710000419",
    },
    {
        "school": "Menno High School - 01",
        "district": "Menno School District 33-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464710000420",
    },
    {
        "school": "Menno Middle School - 05",
        "district": "Menno School District 33-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464710000965",
    },
    {
        "school": "Old Elm Spring Colony Elementary - 03",
        "district": "Parkston School District 33-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465430000489",
    },
    {
        "school": "New Elm Spring Colony Elementary - 08",
        "district": "Parkston School District 33-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465430000490",
    },
    {
        "school": "Parkston Elementary - 02",
        "district": "Parkston School District 33-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465430000491",
    },
    {
        "school": "Parkston High School - 01",
        "district": "Parkston School District 33-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465430000492",
    },
    {
        "school": "Parkston Jr. High - 05",
        "district": "Parkston School District 33-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465430000926",
    },
    {
        "school": "Our Home",
        "district": "Parkston School District 33-3",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "465430001132",
    },
    {
        "school": "Tripp-Delmont High School - 01",
        "district": "Tripp-Delmont School District 33-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467245000050",
    },
    {
        "school": "Tripp-Delmont Jr. High - 02",
        "district": "Tripp-Delmont School District 33-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467245000059",
    },
    {
        "school": "Tripp Elementary - 03",
        "district": "Tripp-Delmont School District 33-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467245000062",
    },
    {
        "school": "Wessington Springs Jr. High - 04",
        "district": "Wessington Springs School District 36-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467746000076",
    },
    {
        "school": "Spring Valley Colony Elementary - 05",
        "district": "Wessington Springs School District 36-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467746000731",
    },
    {
        "school": "Wessington Springs Elementary - 02",
        "district": "Wessington Springs School District 36-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467746000732",
    },
    {
        "school": "Wessington Springs High School - 01",
        "district": "Wessington Springs School District 36-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467746000733",
    },
    {
        "school": "Jones County Elementary - 02",
        "district": "Jones County School District 37-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461958000358",
    },
    {
        "school": "Jones County High School - 01",
        "district": "Jones County School District 37-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461958000803",
    },
    {
        "school": "Jones County Middle School - 04",
        "district": "Jones County School District 37-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461958000955",
    },
    {
        "school": "Spring Lake Colony Elementary - 04",
        "district": "Oldham - Ramona School District 39-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102701112",
    },
    {
        "school": "Arlington Elementary - 02",
        "district": "Arlington School District 38-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460372000021",
    },
    {
        "school": "Arlington High School - 01",
        "district": "Arlington School District 38-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460372000022",
    },
    {
        "school": "Arlington Jr. High - 03",
        "district": "Arlington School District 38-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460372000877",
    },
    {
        "school": "Laura Ingalls Wilder Elementary - 02",
        "district": "De Smet School District 38-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461785000162",
    },
    {
        "school": "De Smet High School - 01",
        "district": "De Smet School District 38-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461785000163",
    },
    {
        "school": "De Smet Middle School - 03",
        "district": "De Smet School District 38-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461785000993",
    },
    {
        "school": "Lake Preston Elementary - 02",
        "district": "Lake Preston School District 38-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463999000367",
    },
    {
        "school": "Lake Preston High School - 01",
        "district": "Lake Preston School District 38-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463999000368",
    },
    {
        "school": "Lake Preston Middle School - 03",
        "district": "Lake Preston School District 38-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463999000918",
    },
    {
        "school": "Oldham-Ramona High School - 01",
        "district": "Oldham - Ramona School District 39-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102701027",
    },
    {
        "school": "Oldham-Ramona Elementary - 02",
        "district": "Oldham - Ramona School District 39-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102701030",
    },
    {
        "school": "Oldham-Ramona Jr. High - 03",
        "district": "Oldham - Ramona School District 39-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102701035",
    },
    {
        "school": "Madison High School - 01",
        "district": "Madison Central School District 39-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463960000363",
    },
    {
        "school": "Madison Middle School - 02",
        "district": "Madison Central School District 39-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463960000364",
    },
    {
        "school": "Rutland Elementary - 02",
        "district": "Rutland School District 39-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466414000562",
    },
    {
        "school": "Rutland High School - 01",
        "district": "Rutland School District 39-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466414000563",
    },
    {
        "school": "Rutland Jr. High - 03",
        "district": "Rutland School District 39-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466414000932",
    },
    {
        "school": "Presho Elementary - 03",
        "district": "Lyman School District 42-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464477000397",
    },
    {
        "school": "Lyman High School - 01",
        "district": "Lyman School District 42-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464477000398",
    },
    {
        "school": "Kennebec Elementary - 04",
        "district": "Lyman School District 42-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464477000728",
    },
    {
        "school": "Lyman Middle School - 02",
        "district": "Lyman School District 42-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464477000812",
    },
    {
        "school": "Eureka Elementary - 02",
        "district": "Eureka School District 44-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462256000195",
    },
    {
        "school": "Eureka High School - 01",
        "district": "Eureka School District 44-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462256000196",
    },
    {
        "school": "Eureka Jr. High - 03",
        "district": "Eureka School District 44-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462256000958",
    },
    {
        "school": "Leola Elementary - 02",
        "district": "Leola School District 44-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464164000390",
    },
    {
        "school": "Leola High School - 01",
        "district": "Leola School District 44-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464164000391",
    },
    {
        "school": "Long Lake Colony Elementary - 05",
        "district": "Leola School District 44-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464164000393",
    },
    {
        "school": "Spring Creek Colony Elementary - 04",
        "district": "Leola School District 44-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464164000394",
    },
    {
        "school": "Leola Jr. High - 03",
        "district": "Leola School District 44-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464164000919",
    },
    {
        "school": "Grassland Colony Elementary - 06",
        "district": "Leola School District 44-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464164001069",
    },
    {
        "school": "Langford Area Elementary - 02",
        "district": "Langford Area 45-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464086000369",
    },
    {
        "school": "Langford Area High School - 01",
        "district": "Langford Area 45-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464086000370",
    },
    {
        "school": "Langford Area Middle School - 03",
        "district": "Langford Area 45-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464086000851",
    },
    {
        "school": "Newport Colony Elementary - 04",
        "district": "Langford Area 45-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464086001097",
    },
    {
        "school": "Norris Elementary - 08",
        "district": "White River School District 47-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467857000749",
    },
    {
        "school": "White River Elementary - 02",
        "district": "White River School District 47-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467857000753",
    },
    {
        "school": "White River High School - 01",
        "district": "White River School District 47-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467857000754",
    },
    {
        "school": "White River Middle School - 04",
        "district": "White River School District 47-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467857000951",
    },
    {
        "school": "Howard Elementary - 02",
        "district": "Howard School District 48-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460002500304",
    },
    {
        "school": "Howard High School - 01",
        "district": "Howard School District 48-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460002500305",
    },
    {
        "school": "Howard Jr. High - 05",
        "district": "Howard School District 48-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460002500913",
    },
    {
        "school": "Colman-Egan High School - 01",
        "district": "Colman-Egan School District 50-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461410000091",
    },
    {
        "school": "Colman-Egan Jr. High - 02",
        "district": "Colman-Egan School District 50-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461410000092",
    },
    {
        "school": "Colman Elementary - 03",
        "district": "Colman-Egan School District 50-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461410000093",
    },
    {
        "school": "Flandreau Middle School - 03",
        "district": "Flandreau School District 50-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462439000205",
    },
    {
        "school": "Flandreau High School - 01",
        "district": "Flandreau School District 50-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462439000206",
    },
    {
        "school": "Flandreau Elementary - 04",
        "district": "Flandreau School District 50-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462439000207",
    },
    {
        "school": "Pleasant Valley Colony Elementary - 06",
        "district": "Flandreau School District 50-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462439001119",
    },
    {
        "school": "Bison Elementary - 02",
        "district": "Bison School District 52-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460705000054",
    },
    {
        "school": "Bison High School - 01",
        "district": "Bison School District 52-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460705000055",
    },
    {
        "school": "Bison Jr. High - 04",
        "district": "Bison School District 52-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460705000879",
    },
    {
        "school": "Lemmon Elementary - 02",
        "district": "Lemmon School District 52-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464152000381",
    },
    {
        "school": "Lemmon High School - 01",
        "district": "Lemmon School District 52-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464152000382",
    },
    {
        "school": "Lemmon Jr. High - 06",
        "district": "Lemmon School District 52-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464152000852",
    },
    {
        "school": "Gettysburg Elementary - 02",
        "district": "Gettysburg School District 53-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462697000231",
    },
    {
        "school": "Gettysburg High School - 01",
        "district": "Gettysburg School District 53-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462697000232",
    },
    {
        "school": "Gettysburg Middle School - 03",
        "district": "Gettysburg School District 53-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462697000959",
    },
    {
        "school": "Hoven Elementary - 02",
        "district": "Hoven School District 53-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463460000297",
    },
    {
        "school": "Hoven High School - 01",
        "district": "Hoven School District 53-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463460000298",
    },
    {
        "school": "Hoven Jr. High - 03",
        "district": "Hoven School District 53-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463460000912",
    },
    {
        "school": "Wilmot Elementary - 02",
        "district": "Wilmot School District 54-7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460000300757",
    },
    {
        "school": "Wilmot High School - 01",
        "district": "Wilmot School District 54-7",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460000300758",
    },
    {
        "school": "Wilmot Jr. High - 03",
        "district": "Wilmot School District 54-7",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460000300872",
    },
    {
        "school": "Rosholt Elementary - 02",
        "district": "Rosholt School District 54-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466336000556",
    },
    {
        "school": "Rosholt High School - 01",
        "district": "Rosholt School District 54-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466336000557",
    },
    {
        "school": "White Rock Colony Elementary - 03",
        "district": "Rosholt School District 54-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466336000558",
    },
    {
        "school": "Rosholt Middle School - 04",
        "district": "Rosholt School District 54-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466336001053",
    },
    {
        "school": "Summit Elementary - 02",
        "district": "Summit School District 54-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467014000662",
    },
    {
        "school": "Summit High School - 01",
        "district": "Summit School District 54-6",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467014000663",
    },
    {
        "school": "Sanborn Central High School - 01",
        "district": "Sanborn Central School District 55-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460393200099",
    },
    {
        "school": "Sanborn Central Middle School - 02",
        "district": "Sanborn Central School District 55-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460393200102",
    },
    {
        "school": "Upland Colony Elementary - 05",
        "district": "Sanborn Central School District 55-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460393200120",
    },
    {
        "school": "Woonsocket Elementary - 03",
        "district": "Woonsocket School District 55-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468019000789",
    },
    {
        "school": "Woonsocket High School - 01",
        "district": "Woonsocket School District 55-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468019000790",
    },
    {
        "school": "Batesland School - 01",
        "district": "Oglala Lakota County 65-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466546000573",
    },
    {
        "school": "Wolf Creek School - 02",
        "district": "Oglala Lakota County 65-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466546000574",
    },
    {
        "school": "Rockyford School - 03",
        "district": "Oglala Lakota County 65-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466546000576",
    },
    {
        "school": "Doland Elementary - 03",
        "district": "Doland School District 56-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461917000170",
    },
    {
        "school": "Doland High School - 01",
        "district": "Doland School District 56-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461917000171",
    },
    {
        "school": "Doland Jr. High - 02",
        "district": "Doland School District 56-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461917000895",
    },
    {
        "school": "Hillside Colony Elementary - 04",
        "district": "Doland School District 56-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461917001100",
    },
    {
        "school": "Northwestern High School - 01",
        "district": "Northwestern Area School District 56-7",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465175000475",
    },
    {
        "school": "Northwestern Elementary - 04",
        "district": "Northwestern Area School District 56-7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465175000820",
    },
    {
        "school": "Northwestern Middle School - 02",
        "district": "Northwestern Area School District 56-7",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465175000924",
    },
    {
        "school": "Redfield Elementary - 03",
        "district": "Redfield School District 56-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466045000551",
    },
    {
        "school": "Redfield High School - 01",
        "district": "Redfield School District 56-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466045000552",
    },
    {
        "school": "Redfield Middle School - 02",
        "district": "Redfield School District 56-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466045000858",
    },
    {
        "school": "George S Mickelson Alternative High School - 04",
        "district": "Redfield School District 56-4",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "466045001102",
    },
    {
        "school": "Klein Elementary - 08",
        "district": "Todd County School District 66-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467209000503",
    },
    {
        "school": "Lakeview Elementary - 09",
        "district": "Todd County School District 66-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467209000504",
    },
    {
        "school": "Littleburg Elementary - 12",
        "district": "Todd County School District 66-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467209000506",
    },
    {
        "school": "O'Kreek Elementary - 14",
        "district": "Todd County School District 66-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467209000509",
    },
    {
        "school": "He Dog Elementary - 05",
        "district": "Todd County School District 66-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467209000669",
    },
    {
        "school": "Rosebud Elementary - 04",
        "district": "Todd County School District 66-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467209000675",
    },
    {
        "school": "Spring Creek Elementary - 07",
        "district": "Todd County School District 66-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467209000677",
    },
    {
        "school": "Todd County High School - 01",
        "district": "Todd County School District 66-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467209000678",
    },
    {
        "school": "Todd County Middle School - 10",
        "district": "Todd County School District 66-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467209000814",
    },
    {
        "school": "Resource Center - 11",
        "district": "Todd County School District 66-1",
        "level": "Other",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "467209000864",
    },
    {
        "school": "Colome Elementary - 02",
        "district": "Colome Consolidated 59-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461413000140",
    },
    {
        "school": "Colome High School - 01",
        "district": "Colome Consolidated 59-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461413000141",
    },
    {
        "school": "Colome Middle School - 03",
        "district": "Colome Consolidated 59-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461413000893",
    },
    {
        "school": "Winner Elementary - 04",
        "district": "Winner School District 59-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467971000479",
    },
    {
        "school": "Winner High School - 01",
        "district": "Winner School District 59-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467971000781",
    },
    {
        "school": "Winner Middle School - 02",
        "district": "Winner School District 59-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467971000782",
    },
    {
        "school": "Selby High School - 01",
        "district": "Selby Area School District 62-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102801028",
    },
    {
        "school": "Selby Elementary - 02",
        "district": "Selby Area School District 62-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102801032",
    },
    {
        "school": "Selby Middle School - 03",
        "district": "Selby Area School District 62-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102801036",
    },
    {
        "school": "Jamesville Colony Elementary - 03",
        "district": "Menno School District 33-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464710000417",
    },
    {
        "school": "Dupree Elementary - 02",
        "district": "Dupree School District 64-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461945000799",
    },
    {
        "school": "Dupree High School - 01",
        "district": "Dupree School District 64-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461945000800",
    },
    {
        "school": "Dupree Jr. High - 04",
        "district": "Dupree School District 64-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461945000896",
    },
    {
        "school": "Groton Area High School - 01",
        "district": "Groton Area School District 06-6",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004501155",
    },
    {
        "school": "Groton Area Elementary - 02",
        "district": "Groton Area School District 06-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004501156",
    },
    {
        "school": "Groton Area Middle School - 04",
        "district": "Groton Area School District 06-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004501157",
    },
    {
        "school": "SDSBVI Elementary - 01",
        "district": "SD SCH FOR THE BLIND & VISUALLY IMPAIRED",
        "level": "Elementary",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "460002900253",
    },
    {
        "school": "SDSBVI High School - 02",
        "district": "SD SCH FOR THE BLIND & VISUALLY IMPAIRED",
        "level": "High",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "460002900258",
    },
    {
        "school": "C C Lee Elementary - 05",
        "district": "Aberdeen School District 06-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460207000002",
    },
    {
        "school": "Central High School - 01",
        "district": "Aberdeen School District 06-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460207000003",
    },
    {
        "school": "Holgate Middle School - 02",
        "district": "Aberdeen School District 06-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460207000005",
    },
    {
        "school": "Lincoln Elementary - 08",
        "district": "Aberdeen School District 06-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460207000007",
    },
    {
        "school": "May Overby Elementary - 09",
        "district": "Aberdeen School District 06-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460207000008",
    },
    {
        "school": "O M Tiffany Elementary - 11",
        "district": "Aberdeen School District 06-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460207000009",
    },
    {
        "school": "Simmons Elementary - 10",
        "district": "Aberdeen School District 06-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460207000010",
    },
    {
        "school": "Simmons Middle School - 03",
        "district": "Aberdeen School District 06-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460207000011",
    },
    {
        "school": "New Beginnings - 89",
        "district": "Aberdeen School District 06-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "460207001130",
    },
    {
        "school": "Frederick Elementary - 02",
        "district": "Frederick Area School District 06-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462140000189",
    },
    {
        "school": "Frederick High School - 01",
        "district": "Frederick Area School District 06-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462140000190",
    },
    {
        "school": "Frederick Jr. High - 03",
        "district": "Frederick Area School District 06-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462140000957",
    },
    {
        "school": "Warner Elementary - 02",
        "district": "Warner School District 06-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467602000708",
    },
    {
        "school": "Warner High School - 01",
        "district": "Warner School District 06-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467602000709",
    },
    {
        "school": "Warner Middle School - 03",
        "district": "Warner School District 06-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467602000710",
    },
    {
        "school": "Bowdle Elementary - 02",
        "district": "Bowdle School District 22-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460780000068",
    },
    {
        "school": "Bowdle High School - 01",
        "district": "Bowdle School District 22-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460780000069",
    },
    {
        "school": "Bowdle Jr. High - 03",
        "district": "Bowdle School District 22-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460780000883",
    },
    {
        "school": "Edmunds Central High School - 01",
        "district": "Edmunds Central School District 22-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463444000031",
    },
    {
        "school": "Edmunds Central Middle School - 02",
        "district": "Edmunds Central School District 22-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463444000032",
    },
    {
        "school": "Edmunds Central Elementary - 05",
        "district": "Edmunds Central School District 22-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463444001066",
    },
    {
        "school": "Ipswich Elementary - 02",
        "district": "Ipswich Public School District 22-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463606000332",
    },
    {
        "school": "Ipswich High School - 01",
        "district": "Ipswich Public School District 22-6",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463606000333",
    },
    {
        "school": "Rosette Colony Elementary - 03",
        "district": "Ipswich Public School District 22-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463606000334",
    },
    {
        "school": "Ipswich Middle School - 04",
        "district": "Ipswich Public School District 22-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463606000914",
    },
    {
        "school": "Deerfield Colony Elementary - 05",
        "district": "Ipswich Public School District 22-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463606001085",
    },
    {
        "school": "Pembrook Colony Elementary - 06",
        "district": "Ipswich Public School District 22-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463606001086",
    },
    {
        "school": "Rolland Colony Elementary - 05",
        "district": "Elkton School District 05-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462139001168",
    },
    {
        "school": "Norfeld Colony Elementary - 07",
        "district": "Deubrook Area School District 05-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467830001154",
    },
    {
        "school": "Brookings High School - 01",
        "district": "Brookings School District 05-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460852000082",
    },
    {
        "school": "George S. Mickelson Middle School - 02",
        "district": "Brookings School District 05-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460852000083",
    },
    {
        "school": "Hillcrest Elementary - 04",
        "district": "Brookings School District 05-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460852000085",
    },
    {
        "school": "Medary Elementary - 05",
        "district": "Brookings School District 05-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460852000086",
    },
    {
        "school": "Elkton Elementary - 02",
        "district": "Elkton School District 05-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462139000187",
    },
    {
        "school": "Elkton High School - 01",
        "district": "Elkton School District 05-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462139000188",
    },
    {
        "school": "Elkton Jr. High - 03",
        "district": "Elkton School District 05-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462139000901",
    },
    {
        "school": "Newdale Colony Elementary - 04",
        "district": "Elkton School District 05-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462139001078",
    },
    {
        "school": "Sioux Valley High School - 01",
        "district": "Sioux Valley School District 05-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466630000612",
    },
    {
        "school": "Sioux Valley Middle School - 04",
        "district": "Sioux Valley School District 05-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466630000613",
    },
    {
        "school": "Sioux Valley Elementary - 02",
        "district": "Sioux Valley School District 05-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466630000614",
    },
    {
        "school": "Deubrook High School - 01",
        "district": "Deubrook Area School District 05-6",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467830000012",
    },
    {
        "school": "Deubrook Jr. High - 02",
        "district": "Deubrook Area School District 05-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467830000016",
    },
    {
        "school": "Deubrook Elementary - 03",
        "district": "Deubrook Area School District 05-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467830000559",
    },
    {
        "school": "Iroquois Elementary - 04",
        "district": "Iroquois School District 02-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463615001144",
    },
    {
        "school": "Huron Colony Elementary - 13",
        "district": "Huron School District 02-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463548000312",
    },
    {
        "school": "Huron High School - 01",
        "district": "Huron School District 02-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463548000313",
    },
    {
        "school": "Huron Middle School - 02",
        "district": "Huron School District 02-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463548000314",
    },
    {
        "school": "Riverside Colony Elementary - 15",
        "district": "Huron School District 02-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463548000318",
    },
    {
        "school": "Our Home ASAP - 12",
        "district": "Huron School District 02-2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "463548000570",
    },
    {
        "school": "Wolsey Wessington Middle School - 03",
        "district": "Wolsey Wessington School District 02-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468010000546",
    },
    {
        "school": "Wolsey Wessington Elementary - 02",
        "district": "Wolsey Wessington School District 02-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468010000783",
    },
    {
        "school": "Wolsey Wessington High School - 01",
        "district": "Wolsey Wessington School District 02-6",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468010000784",
    },
    {
        "school": "Iroquois High School - 01",
        "district": "Iroquois School District 02-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463615000339",
    },
    {
        "school": "Pearl Creek Colony Elementary - 05",
        "district": "Iroquois School District 02-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463615000340",
    },
    {
        "school": "Iroquois Middle School - 02",
        "district": "Iroquois School District 02-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463615000916",
    },
    {
        "school": "Ethan Elementary - 02",
        "district": "Ethan School District 17-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462250000193",
    },
    {
        "school": "Ethan High School - 01",
        "district": "Ethan School District 17-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462250000194",
    },
    {
        "school": "Ethan Jr. High - 03",
        "district": "Ethan School District 17-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462250000903",
    },
    {
        "school": "Mitchell Middle School - 02",
        "district": "Mitchell School District 17-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464839000437",
    },
    {
        "school": "Longfellow Elementary - 05",
        "district": "Mitchell School District 17-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464839000441",
    },
    {
        "school": "Mitchell High School - 01",
        "district": "Mitchell School District 17-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464839000442",
    },
    {
        "school": "L. B. Williams Elementary - 03",
        "district": "Mitchell School District 17-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464839000520",
    },
    {
        "school": "Gertie Belle Rogers Elementary - 04",
        "district": "Mitchell School District 17-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464839000591",
    },
    {
        "school": "Mount Vernon Elementary - 02",
        "district": "Mount Vernon School District 17-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464965000454",
    },
    {
        "school": "Mount Vernon High School- 01",
        "district": "Mount Vernon School District 17-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464965000455",
    },
    {
        "school": "Mount Vernon Middle School - 03",
        "district": "Mount Vernon School District 17-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464965000967",
    },
    {
        "school": "Millbrook Colony Elementary - 04",
        "district": "Hanson School District 30-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460264000015",
    },
    {
        "school": "Hanson High School - 01",
        "district": "Hanson School District 30-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460264000017",
    },
    {
        "school": "Hanson Middle School - 02",
        "district": "Hanson School District 30-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460264000018",
    },
    {
        "school": "Oaklane Colony Elementary - 05",
        "district": "Hanson School District 30-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460264000875",
    },
    {
        "school": "Hanson Elementary - 06",
        "district": "Hanson School District 30-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460264000876",
    },
    {
        "school": "Bridgewater-Emery High School - 01",
        "district": "Bridgewater-Emery 30-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462142000074",
    },
    {
        "school": "Bridgewater-Emery Middle School - 04",
        "district": "Bridgewater-Emery 30-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462142000902",
    },
    {
        "school": "Rockport Colony Elementary- 10",
        "district": "Mitchell School District 17-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464839000444",
    },
    {
        "school": "Rosedale Colony Elementary - 11",
        "district": "Mitchell School District 17-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464839000445",
    },
    {
        "school": "Buchanan Elementary - 03",
        "district": "Pierre School District 32-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465526000494",
    },
    {
        "school": "Jefferson Elementary - 06",
        "district": "Pierre School District 32-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465526000495",
    },
    {
        "school": "T F Riggs High School - 01",
        "district": "Pierre School District 32-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465526000500",
    },
    {
        "school": "Georgia Morse Middle School - 02",
        "district": "Pierre School District 32-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465526000501",
    },
    {
        "school": "Stanley County Elementary - 08",
        "district": "Stanley County School District 57-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462485000213",
    },
    {
        "school": "Stanley County High School - 01",
        "district": "Stanley County School District 57-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462485000217",
    },
    {
        "school": "Stanley County Middle School - 02",
        "district": "Stanley County School District 57-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462485000841",
    },
    {
        "school": "Cheyenne Elementary - 06",
        "district": "Stanley County School District 57-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462485000849",
    },
    {
        "school": "Atall Elementary - 17",
        "district": "Meade School District 46-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993001236",
    },
    {
        "school": "Whitewood Elementary - 04",
        "district": "Meade School District 46-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993000652",
    },
    {
        "school": "Maurine Elementary - 04",
        "district": "Faith School District 46-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462294000412",
    },
    {
        "school": "Faith Elementary - 02",
        "district": "Faith School District 46-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462294000805",
    },
    {
        "school": "Faith High School - 01",
        "district": "Faith School District 46-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462294000806",
    },
    {
        "school": "Faith Jr. High - 06",
        "district": "Faith School District 46-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462294000995",
    },
    {
        "school": "Sturgis Brown High School - 01",
        "district": "Meade School District 46-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993000633",
    },
    {
        "school": "Sturgis Elementary - 03",
        "district": "Meade School District 46-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993000637",
    },
    {
        "school": "Piedmont Valley Elementary - 05",
        "district": "Meade School District 46-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993000644",
    },
    {
        "school": "Sturgis Williams Middle School - 02",
        "district": "Meade School District 46-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993000653",
    },
    {
        "school": "Hereford Elementary - 08",
        "district": "Meade School District 46-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993000735",
    },
    {
        "school": "Central Meade County School - 09",
        "district": "Meade School District 46-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993000736",
    },
    {
        "school": "Elm Springs Elementary - 13",
        "district": "Meade School District 46-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993000740",
    },
    {
        "school": "Opal Elementary - 15",
        "district": "Meade School District 46-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993000741",
    },
    {
        "school": "Black Hawk Elementary - 03",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000538",
    },
    {
        "school": "Douglas High School - 03",
        "district": "Douglas School District 51-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461941000174",
    },
    {
        "school": "Douglas Middle School - 01",
        "district": "Douglas School District 51-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461941000176",
    },
    {
        "school": "Vandenberg Elementary - 02",
        "district": "Douglas School District 51-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461941000436",
    },
    {
        "school": "Douglas Preschool - 08",
        "district": "Douglas School District 51-1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461941001125",
    },
    {
        "school": "Hill City Elementary - 02",
        "district": "Hill City School District 51-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463336000279",
    },
    {
        "school": "Hill City High School - 01",
        "district": "Hill City School District 51-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463336000280",
    },
    {
        "school": "Hill City Middle School - 04",
        "district": "Hill City School District 51-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463336000848",
    },
    {
        "school": "New Underwood Jr. High - 04",
        "district": "New Underwood School District 51-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465067000456",
    },
    {
        "school": "New Underwood Elementary - 02",
        "district": "New Underwood School District 51-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465067000463",
    },
    {
        "school": "New Underwood High School - 01",
        "district": "New Underwood School District 51-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465067000464",
    },
    {
        "school": "Southwest Middle School - 38",
        "district": "Rapid City Area School District 51-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000457",
    },
    {
        "school": "Stevens High School - 42",
        "district": "Rapid City Area School District 51-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000525",
    },
    {
        "school": "South Canyon Elementary - 15",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000527",
    },
    {
        "school": "East Middle School - 30",
        "district": "Rapid City Area School District 51-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000528",
    },
    {
        "school": "Central High School - 41",
        "district": "Rapid City Area School District 51-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000529",
    },
    {
        "school": "Woodrow Wilson Elementary - 17",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000530",
    },
    {
        "school": "North Middle School - 35",
        "district": "Rapid City Area School District 51-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000532",
    },
    {
        "school": "South Middle School - 36",
        "district": "Rapid City Area School District 51-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000533",
    },
    {
        "school": "General Beadle Elementary - 01",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000536",
    },
    {
        "school": "Knollwood Heights Elementary - 08",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000539",
    },
    {
        "school": "Canyon Lake Elementary - 04",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000540",
    },
    {
        "school": "Robbinsdale Elementary - 14",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000541",
    },
    {
        "school": "Corral Drive Elementary - 21",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000542",
    },
    {
        "school": "Pinedale Elementary - 11",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000547",
    },
    {
        "school": "Grandview Elementary - 06",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000548",
    },
    {
        "school": "Meadowbrook Elementary - 10",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000549",
    },
    {
        "school": "Horace Mann Elementary - 07",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000550",
    },
    {
        "school": "West Middle School - 37",
        "district": "Rapid City Area School District 51-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000822",
    },
    {
        "school": "Rapid Valley Elementary - 12",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000823",
    },
    {
        "school": "South Park Elementary - 16",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000824",
    },
    {
        "school": "Valley View Elementary - 13",
        "district": "Rapid City Area School District 51-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465982000969",
    },
    {
        "school": "Jefferson Building - 64",
        "district": "Rapid City Area School District 51-4",
        "level": "Other",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "465982001072",
    },
    {
        "school": "Wall Elementary - 02",
        "district": "Wall School District 51-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467566000704",
    },
    {
        "school": "Wall High School - 01",
        "district": "Wall School District 51-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467566000705",
    },
    {
        "school": "Big White Elementary - 08",
        "district": "Wall School District 51-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467566000779",
    },
    {
        "school": "Wall Middle School - 06",
        "district": "Wall School District 51-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467566001057",
    },
    {
        "school": "Alcester-Hudson Elementary - 04",
        "district": "Alcester-Hudson School District 61-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460002800013",
    },
    {
        "school": "Alcester-Hudson High School - 01",
        "district": "Alcester-Hudson School District 61-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460002800014",
    },
    {
        "school": "Alcester-Hudson Jr. High - 03",
        "district": "Alcester-Hudson School District 61-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460002800874",
    },
    {
        "school": "Beresford Elementary - 02",
        "district": "Beresford School District 61-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460636000047",
    },
    {
        "school": "Beresford High School - 01",
        "district": "Beresford School District 61-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460636000048",
    },
    {
        "school": "Beresford Middle School - 03",
        "district": "Beresford School District 61-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460636000051",
    },
    {
        "school": "Elk Point-Jefferson Elementary - 02",
        "district": "Elk Point-Jefferson School District 61-7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462134000185",
    },
    {
        "school": "Elk Point-Jefferson High School - 01",
        "district": "Elk Point-Jefferson School District 61-7",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462134000186",
    },
    {
        "school": "Elk Point-Jefferson Middle School - 03",
        "district": "Elk Point-Jefferson School District 61-7",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462134000900",
    },
    {
        "school": "Dakota Valley Elementary - 02",
        "district": "Dakota Valley School District 61-8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463699000251",
    },
    {
        "school": "Dakota Valley High School - 01",
        "district": "Dakota Valley School District 61-8",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463699000345",
    },
    {
        "school": "Dakota Valley Middle School - 03",
        "district": "Dakota Valley School District 61-8",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463699000809",
    },
    {
        "school": "Dakota Valley Upper Elementary - 04",
        "district": "Dakota Valley School District 61-8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463699001075",
    },
    {
        "school": "Tea Area Legacy Elementary - 01",
        "district": "Tea Area School District 41-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460005200388",
    },
    {
        "school": "Tea Area Middle School - 02",
        "district": "Tea Area School District 41-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460005200853",
    },
    {
        "school": "Tea Area High School - 03",
        "district": "Tea Area School District 41-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460005201235",
    },
    {
        "school": "Explorer Elementary - 04",
        "district": "Harrisburg School District 41-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463135001169",
    },
    {
        "school": "Robert Bennis Elementary - 05",
        "district": "Brandon Valley School District 49-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460795001237",
    },
    {
        "school": "Structured Teaching - 12",
        "district": "Sioux Falls School District 49-5",
        "level": "High",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "466627001138",
    },
    {
        "school": "Bridges At Horace Mann - 52",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001139",
    },
    {
        "school": "Elementary Immersion Center - 43",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001175",
    },
    {
        "school": "Discovery Elementary - 26",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001238",
    },
    {
        "school": "Rustic Acres Elementary - 04",
        "district": "Chester Area School District 39-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461230001092",
    },
    {
        "school": "McCook Central Elementary - 02",
        "district": "McCook Central School District 43-7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102600404",
    },
    {
        "school": "McCook Central High School - 01",
        "district": "McCook Central School District 43-7",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102601026",
    },
    {
        "school": "McCook Central Middle School - 03",
        "district": "McCook Central School District 43-7",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102601034",
    },
    {
        "school": "Canistota Elementary - 02",
        "district": "Canistota School District 43-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461032000104",
    },
    {
        "school": "Canistota High School - 01",
        "district": "Canistota School District 43-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461032000105",
    },
    {
        "school": "Canistota Middle School - 03",
        "district": "Canistota School District 43-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461032001016",
    },
    {
        "school": "Montrose Elementary - 02",
        "district": "Montrose School District 43-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464878000451",
    },
    {
        "school": "Montrose High School - 01",
        "district": "Montrose School District 43-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464878000452",
    },
    {
        "school": "Montrose Middle School - 03",
        "district": "Montrose School District 43-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464878000966",
    },
    {
        "school": "Orland Colony Elementary - 04",
        "district": "Montrose School District 43-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464878001095",
    },
    {
        "school": "Chester High School - 01",
        "district": "Chester Area School District 39-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461230000130",
    },
    {
        "school": "Chester Elementary -02",
        "district": "Chester Area School District 39-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461230000131",
    },
    {
        "school": "Chester Middle School - 03",
        "district": "Chester Area School District 39-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461230000832",
    },
    {
        "school": "Centerville Elementary - 02",
        "district": "Centerville School District 60-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461176000115",
    },
    {
        "school": "Centerville High School - 01",
        "district": "Centerville School District 60-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461176000116",
    },
    {
        "school": "Centerville Middle School - 03",
        "district": "Centerville School District 60-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461176001023",
    },
    {
        "school": "Marion Elementary - 02",
        "district": "Marion School District 60-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464545000407",
    },
    {
        "school": "Marion High School - 01",
        "district": "Marion School District 60-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464545000408",
    },
    {
        "school": "Marion Middle School - 03",
        "district": "Marion School District 60-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464545001050",
    },
    {
        "school": "Parker Elementary - 02",
        "district": "Parker School District 60-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465427000487",
    },
    {
        "school": "Parker High School - 01",
        "district": "Parker School District 60-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465427000488",
    },
    {
        "school": "Parker Jr. High - 03",
        "district": "Parker School District 60-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465427000925",
    },
    {
        "school": "Viborg-Hurley Elementary - 02",
        "district": "Viborg-Hurley School District 60-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467452000692",
    },
    {
        "school": "Viborg-Hurley High School - 01",
        "district": "Viborg-Hurley School District 60-6",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467452000693",
    },
    {
        "school": "Lawrence Elementary - 02",
        "district": "Canton School District 41-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461056000108",
    },
    {
        "school": "Canton High School - 01",
        "district": "Canton School District 41-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461056000109",
    },
    {
        "school": "Canton Middle School - 04",
        "district": "Canton School District 41-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461056000831",
    },
    {
        "school": "Liberty Elementary - 02",
        "district": "Harrisburg School District 41-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463135000263",
    },
    {
        "school": "Harrisburg High School - 01",
        "district": "Harrisburg School District 41-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463135000264",
    },
    {
        "school": "Harrisburg South Middle School - 03",
        "district": "Harrisburg School District 41-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463135000847",
    },
    {
        "school": "Lennox Elementary - 02",
        "district": "Lennox School District 41-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464155000386",
    },
    {
        "school": "Lennox High School - 01",
        "district": "Lennox School District 41-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464155000387",
    },
    {
        "school": "Worthing Elementary - 05",
        "district": "Lennox School District 41-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464155000389",
    },
    {
        "school": "Lennox Jr. High - 08",
        "district": "Lennox School District 41-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464155000963",
    },
    {
        "school": "Teachwell Academy High School - 01",
        "district": "East Dakota Educational Cooperative",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "460002700983",
    },
    {
        "school": "Baltic Elementary - 02",
        "district": "Baltic School District 49-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460468000035",
    },
    {
        "school": "Baltic High School - 01",
        "district": "Baltic School District 49-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460468000036",
    },
    {
        "school": "Baltic Middle School - 03",
        "district": "Baltic School District 49-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460468000986",
    },
    {
        "school": "Brandon Valley High School - 01",
        "district": "Brandon Valley School District 49-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460795000071",
    },
    {
        "school": "Brandon Valley Middle School - 02",
        "district": "Brandon Valley School District 49-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460795000072",
    },
    {
        "school": "Valley Springs Elementary - 04",
        "district": "Brandon Valley School District 49-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460795000073",
    },
    {
        "school": "Brandon Elementary - 03",
        "district": "Brandon Valley School District 49-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460795000414",
    },
    {
        "school": "Dell Rapids Elementary - 02",
        "district": "Dell Rapids School District 49-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461812000164",
    },
    {
        "school": "Dell Rapids High School - 01",
        "district": "Dell Rapids School District 49-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461812000165",
    },
    {
        "school": "Dell Rapids Middle School - 03",
        "district": "Dell Rapids School District 49-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461812000837",
    },
    {
        "school": "Garretson Elementary - 02",
        "district": "Garretson School District 49-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462637000223",
    },
    {
        "school": "Garretson High School - 01",
        "district": "Garretson School District 49-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462637000224",
    },
    {
        "school": "Garretson Middle School - 03",
        "district": "Garretson School District 49-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462637000843",
    },
    {
        "school": "West Central Humboldt Elementary - 02",
        "district": "West Central School District 49-7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463171000273",
    },
    {
        "school": "West Central High School - 01",
        "district": "West Central School District 49-7",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463171000274",
    },
    {
        "school": "West Central Hartford Elementary - 05",
        "district": "West Central School District 49-7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463171000777",
    },
    {
        "school": "West Central Middle School - 04",
        "district": "West Central School District 49-7",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463171000909",
    },
    {
        "school": "Tri-Valley High School - 01",
        "district": "Tri-Valley School District 49-6",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464494000405",
    },
    {
        "school": "Tri-Valley Jr. High School - 03",
        "district": "Tri-Valley School District 49-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464494000406",
    },
    {
        "school": "Tri-Valley Elementary - 02",
        "district": "Tri-Valley School District 49-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464494000776",
    },
    {
        "school": "Terry Redlin Elementary - 11",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000579",
    },
    {
        "school": "Cleveland Elementary - 14",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000581",
    },
    {
        "school": "Edison Middle School - 06",
        "district": "Sioux Falls School District 49-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000583",
    },
    {
        "school": "Eugene Field A+ Elementary - 16",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000585",
    },
    {
        "school": "Garfield Elementary - 19",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000587",
    },
    {
        "school": "Harvey Dunn Elementary - 54",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000588",
    },
    {
        "school": "Hayward Elementary - 38",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000590",
    },
    {
        "school": "Laura B. Anderson Elementary - 10",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000597",
    },
    {
        "school": "Laura Wilder Elementary - 31",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000598",
    },
    {
        "school": "Lincoln High School - 02",
        "district": "Sioux Falls School District 49-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000600",
    },
    {
        "school": "Lowell Elementary - 28",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000602",
    },
    {
        "school": "Patrick Henry Middle School - 07",
        "district": "Sioux Falls School District 49-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000604",
    },
    {
        "school": "Renberg Elementary - 42",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000606",
    },
    {
        "school": "Robert Frost Elementary - 18",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000607",
    },
    {
        "school": "Summit Oaks-Day",
        "district": "Sioux Falls School District 49-5",
        "level": "Other",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "466627000609",
    },
    {
        "school": "Washington High School - 01",
        "district": "Sioux Falls School District 49-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000610",
    },
    {
        "school": "Whittier Middle School - 08",
        "district": "Sioux Falls School District 49-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000611",
    },
    {
        "school": "Anne Sullivan Elementary - 20",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000770",
    },
    {
        "school": "Oscar Howe Elementary - 58",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000813",
    },
    {
        "school": "Hawthorne Elementary - 56",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000936",
    },
    {
        "school": "John F. Kennedy Elementary - 57",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627000976",
    },
    {
        "school": "Roosevelt High School - 03",
        "district": "Sioux Falls School District 49-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001063",
    },
    {
        "school": "John Harris Elementary - 23",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001064",
    },
    {
        "school": "Memorial Middle School - 04",
        "district": "Sioux Falls School District 49-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001070",
    },
    {
        "school": "Success Academy - 39",
        "district": "Sioux Falls School District 49-5",
        "level": "High",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "466627001121",
    },
    {
        "school": "Community Campus - 41",
        "district": "Sioux Falls School District 49-5",
        "level": "High",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "466627001122",
    },
    {
        "school": "Flex - 45",
        "district": "Sioux Falls School District 49-5",
        "level": "High",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "466627001123",
    },
    {
        "school": "All City Elementary - 50",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001128",
    },
    {
        "school": "Challenge Center - 51",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001129",
    },
    {
        "school": "Summit Oaks-Residential",
        "district": "Sioux Falls School District 49-5",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "466627001133",
    },
    {
        "school": "Lead-Deadwood Career & Technical Education - 10",
        "district": "Lead-Deadwood School District 40-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "464130001145",
    },
    {
        "school": "Lead-Deadwood Elementary - 03",
        "district": "Lead-Deadwood School District 40-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464130000372",
    },
    {
        "school": "Lead-Deadwood Middle School - 02",
        "district": "Lead-Deadwood School District 40-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464130000373",
    },
    {
        "school": "Lead-Deadwood High School - 01",
        "district": "Lead-Deadwood School District 40-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464130000374",
    },
    {
        "school": "West Elementary - 03",
        "district": "Spearfish School District 40-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466693000392",
    },
    {
        "school": "Creekside Elementary - 07",
        "district": "Spearfish School District 40-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466693000401",
    },
    {
        "school": "Spearfish Middle School - 05",
        "district": "Spearfish School District 40-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466693000622",
    },
    {
        "school": "Spearfish High School - 01",
        "district": "Spearfish School District 40-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466693000623",
    },
    {
        "school": "Developmental Disabilities Program - 01",
        "district": "Black Hills Special Services Cooperative",
        "level": "Other",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "468012001001",
    },
    {
        "school": "Austin Elementary - 03",
        "district": "Vermillion School District 13-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467437000300",
    },
    {
        "school": "Jolley Elementary - 04",
        "district": "Vermillion School District 13-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467437000301",
    },
    {
        "school": "Vermillion Middle School - 02",
        "district": "Vermillion School District 13-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467437000690",
    },
    {
        "school": "Vermillion High School - 01",
        "district": "Vermillion School District 13-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467437000691",
    },
    {
        "school": "Florence Elementary - 02",
        "district": "Florence School District 14-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462454000208",
    },
    {
        "school": "Florence High School - 01",
        "district": "Florence School District 14-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462454000209",
    },
    {
        "school": "Florence Middle School - 03",
        "district": "Florence School District 14-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462454000589",
    },
    {
        "school": "Henry Elementary - 02",
        "district": "Henry School District 14-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463234000275",
    },
    {
        "school": "Henry High School - 01",
        "district": "Henry School District 14-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463234000276",
    },
    {
        "school": "Henry Middle School - 03",
        "district": "Henry School District 14-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463234001047",
    },
    {
        "school": "McKinley Elementary - 06",
        "district": "Watertown School District 14-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467662000713",
    },
    {
        "school": "Mellette Elementary - 07",
        "district": "Watertown School District 14-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467662000714",
    },
    {
        "school": "Roosevelt Elementary - 08",
        "district": "Watertown School District 14-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467662000716",
    },
    {
        "school": "Watertown High School - 01",
        "district": "Watertown School District 14-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467662000717",
    },
    {
        "school": "Watertown Middle School - 02",
        "district": "Watertown School District 14-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467662000718",
    },
    {
        "school": "Lincoln Elementary - 05",
        "district": "Watertown School District 14-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467662000944",
    },
    {
        "school": "Jefferson Elementary - 09",
        "district": "Watertown School District 14-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467662001083",
    },
    {
        "school": "Waverly-South Shore Elementary - 02",
        "district": "Waverly School District 14-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467674000721",
    },
    {
        "school": "Waverly-South Shore High School - 01",
        "district": "Waverly School District 14-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467674000722",
    },
    {
        "school": "Waverly-South Shore Middle School - 03",
        "district": "Waverly School District 14-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467674000946",
    },
    {
        "school": "Castlewood Elementary - 02",
        "district": "Castlewood School District 28-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461128000113",
    },
    {
        "school": "Castlewood High School - 01",
        "district": "Castlewood School District 28-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461128000114",
    },
    {
        "school": "Castlewood Jr. High - 03",
        "district": "Castlewood School District 28-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461128000954",
    },
    {
        "school": "Claremont Colony Elementary - 04",
        "district": "Castlewood School District 28-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461128001126",
    },
    {
        "school": "Estelline Elementary - 02",
        "district": "Estelline School District 28-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462241000191",
    },
    {
        "school": "Estelline High School - 01",
        "district": "Estelline School District 28-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462241000192",
    },
    {
        "school": "Estelline Middle School - 03",
        "district": "Estelline School District 28-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462241001045",
    },
    {
        "school": "Hamlin Middle School - 02",
        "district": "Hamlin School District 28-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463080000259",
    },
    {
        "school": "Hamlin High School - 01",
        "district": "Hamlin School District 28-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463080000260",
    },
    {
        "school": "Hamlin Elementary - 09",
        "district": "Hamlin School District 28-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463080001111",
    },
    {
        "school": "Gayville-Volin High School - 01",
        "district": "Gayville-Volin School District 63-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462649000227",
    },
    {
        "school": "Gayville-Volin Elementary - 02",
        "district": "Gayville-Volin School District 63-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462649000228",
    },
    {
        "school": "Gayville-Volin Middle School - 03",
        "district": "Gayville-Volin School District 63-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462649000844",
    },
    {
        "school": "Beadle Elementary - 03",
        "district": "Yankton School District 63-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043000791",
    },
    {
        "school": "Lincoln Elementary - 04",
        "district": "Yankton School District 63-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043000793",
    },
    {
        "school": "Stewart Elementary - 05",
        "district": "Yankton School District 63-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043000795",
    },
    {
        "school": "Yankton High School - 01",
        "district": "Yankton School District 63-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043000798",
    },
    {
        "school": "Webster Elementary - 06",
        "district": "Yankton School District 63-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043001009",
    },
    {
        "school": "Carpenters Elementary School",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030002099",
    },
    {
        "school": "Stone Memorial High School",
        "district": "Cumberland County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090002100",
    },
    {
        "school": "A. Z. Kelley Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002116",
    },
    {
        "school": "Thurgood Marshall Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002121",
    },
    {
        "school": "De Kalb County Adult High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470099002117",
    },
    {
        "school": "Red Boiling Springs Elementary",
        "district": "Macon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470255002115",
    },
    {
        "school": "Marvin Wright Elementary School",
        "district": "Maury County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276002120",
    },
    {
        "school": "Barkers Mill Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303002108",
    },
    {
        "school": "Kenton Elementary School",
        "district": "Gibson Co Sp Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470140002118",
    },
    {
        "school": "Jo Byrns Elementary School",
        "district": "Robertson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360002109",
    },
    {
        "school": "Stewarts Creek Elementary School",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002110",
    },
    {
        "school": "Stewarts Creek Middle School",
        "district": "Rutherford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002111",
    },
    {
        "school": "Cumberland Gap High School",
        "district": "Claiborne County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063001690",
    },
    {
        "school": "Claiborne High School",
        "district": "Claiborne County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063001691",
    },
    {
        "school": "Clay County High School",
        "district": "Clay County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470066001694",
    },
    {
        "school": "South Fentress Elementary School",
        "district": "Fentress County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470123002029",
    },
    {
        "school": "Paul G. Caywood Elementary",
        "district": "Lexington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470246002031",
    },
    {
        "school": "Roan Creek Elementary",
        "district": "Johnson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470216001836",
    },
    {
        "school": "Cornersville Elementary",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470267001869",
    },
    {
        "school": "Oak Grove Elementary",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470267001870",
    },
    {
        "school": "Madisonville Intermediate School",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300001883",
    },
    {
        "school": "Vonore Middle School",
        "district": "Monroe County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300002069",
    },
    {
        "school": "Sweetwater Primary School",
        "district": "Sweetwater",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470405002034",
    },
    {
        "school": "Central Middle School",
        "district": "Morgan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470309001884",
    },
    {
        "school": "Spring City Middle School",
        "district": "Rhea County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470351002035",
    },
    {
        "school": "Big Sandy School",
        "district": "Benton County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470024000049",
    },
    {
        "school": "Briarwood School",
        "district": "Benton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470024000050",
    },
    {
        "school": "Camden Elementary",
        "district": "Benton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470024000051",
    },
    {
        "school": "Camden Central High School",
        "district": "Benton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470024000052",
    },
    {
        "school": "Holladay Elementary",
        "district": "Benton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470024000053",
    },
    {
        "school": "Benton County Academy",
        "district": "Benton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470024000250",
    },
    {
        "school": "Camden Jr High School",
        "district": "Benton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470024001033",
    },
    {
        "school": "Senator Frank P. Lashlee Career and Technical Center",
        "district": "Benton County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "TN",
        "nces_id": "470024001828",
    },
    {
        "school": "Bledsoe County High School",
        "district": "Bledsoe County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470027000055",
    },
    {
        "school": "Cecil B Rigsby Elementary",
        "district": "Bledsoe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470027000057",
    },
    {
        "school": "Mary V Wheeler Elementary",
        "district": "Bledsoe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470027000059",
    },
    {
        "school": "Pikeville Elementary",
        "district": "Bledsoe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470027000060",
    },
    {
        "school": "Bledsoe County Middle School",
        "district": "Bledsoe County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470027001035",
    },
    {
        "school": "Carroll County Special Learning Center",
        "district": "Carroll County",
        "level": "Other",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470048001874",
    },
    {
        "school": "Carroll Co Tech Center",
        "district": "Carroll County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "TN",
        "nces_id": "470048001917",
    },
    {
        "school": "Central Elementary",
        "district": "Hollow Rock - Bruceton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470189000627",
    },
    {
        "school": "Central High School",
        "district": "Hollow Rock - Bruceton",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470189000628",
    },
    {
        "school": "Huntingdon Middle School",
        "district": "Huntingdon Special School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470201000645",
    },
    {
        "school": "Huntingdon High School",
        "district": "Huntingdon Special School District",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470201000646",
    },
    {
        "school": "Huntingdon Primary",
        "district": "Huntingdon Special School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470201000647",
    },
    {
        "school": "McKenzie Elementary",
        "district": "McKenzie",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470279000983",
    },
    {
        "school": "McKenzie High School",
        "district": "McKenzie",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470279000984",
    },
    {
        "school": "McKenzie Middle School",
        "district": "McKenzie",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470279000985",
    },
    {
        "school": "Clarksburg School",
        "district": "South Carroll",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470390000064",
    },
    {
        "school": "West Carroll Primary",
        "district": "West Carroll Sp Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470449000149",
    },
    {
        "school": "West Carroll Junior/Senior High School",
        "district": "West Carroll Sp Dist",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470449001913",
    },
    {
        "school": "West Carroll Elementary School",
        "district": "West Carroll Sp Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470449001914",
    },
    {
        "school": "Clairfield Elementary",
        "district": "Claiborne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063000245",
    },
    {
        "school": "Ellen Myers Primary",
        "district": "Claiborne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063000246",
    },
    {
        "school": "Forge Ridge School",
        "district": "Claiborne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063000247",
    },
    {
        "school": "H. Y. Livesay Middle School",
        "district": "Claiborne County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063000249",
    },
    {
        "school": "Midway Elementary",
        "district": "Claiborne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063000251",
    },
    {
        "school": "Powell Valley Elementary",
        "district": "Claiborne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063000252",
    },
    {
        "school": "Soldiers Memorial Middle School",
        "district": "Claiborne County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063000254",
    },
    {
        "school": "Springdale Elementary",
        "district": "Claiborne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063000255",
    },
    {
        "school": "Tazewell-New Tazewell Elementary",
        "district": "Claiborne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063000256",
    },
    {
        "school": "Claiborne Adult High School",
        "district": "Claiborne County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063000901",
    },
    {
        "school": "The Alpha School",
        "district": "Claiborne County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470063001391",
    },
    {
        "school": "Celina K-8",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470066000258",
    },
    {
        "school": "Hermitage Springs Elementary School",
        "district": "Clay County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470066000261",
    },
    {
        "school": "Clay Co Adult High School",
        "district": "Clay County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470066001049",
    },
    {
        "school": "Alamo Elementary",
        "district": "Alamo",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470003000001",
    },
    {
        "school": "Bells Elementary",
        "district": "Bells",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470021000045",
    },
    {
        "school": "Crockett County High School",
        "district": "Crockett County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470085001897",
    },
    {
        "school": "Friendship Elementary",
        "district": "Crockett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470085001898",
    },
    {
        "school": "Gadsden Elementary",
        "district": "Crockett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470085001899",
    },
    {
        "school": "Maury City Elementary",
        "district": "Crockett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470085001902",
    },
    {
        "school": "Crockett County Middle School",
        "district": "Crockett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470085001920",
    },
    {
        "school": "Decaturville Elementary",
        "district": "Decatur County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470096000316",
    },
    {
        "school": "Parsons Elementary",
        "district": "Decatur County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470096000317",
    },
    {
        "school": "Decatur County Middle School",
        "district": "Decatur County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470096000319",
    },
    {
        "school": "Riverside High School",
        "district": "Decatur County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470096001245",
    },
    {
        "school": "De Kalb County High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470099000322",
    },
    {
        "school": "DeKalb Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470099000323",
    },
    {
        "school": "Smithville Elementary",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470099000324",
    },
    {
        "school": "DeKalb West Elementary",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470099000325",
    },
    {
        "school": "Northside Elementary",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470099001246",
    },
    {
        "school": "Allardt Elementary",
        "district": "Fentress County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470123000373",
    },
    {
        "school": "Clarkrange High School",
        "district": "Fentress County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470123000377",
    },
    {
        "school": "Pine Haven Elementary",
        "district": "Fentress County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470123000381",
    },
    {
        "school": "York Elementary",
        "district": "Fentress County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470123000383",
    },
    {
        "school": "Fentress Co Adult High School",
        "district": "Fentress County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470123000598",
    },
    {
        "school": "Bradford High School",
        "district": "Bradford",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470139000425",
    },
    {
        "school": "Bradford Elementary",
        "district": "Bradford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470139000606",
    },
    {
        "school": "Dyer Elementary",
        "district": "Gibson Co Sp Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470140000411",
    },
    {
        "school": "Gibson County High School",
        "district": "Gibson Co Sp Dist",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470140000416",
    },
    {
        "school": "South Gibson County Elementary School",
        "district": "Gibson Co Sp Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470140000417",
    },
    {
        "school": "Rutherford Elementary",
        "district": "Gibson Co Sp Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470140000419",
    },
    {
        "school": "Spring Hill Elementary",
        "district": "Gibson Co Sp Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470140000421",
    },
    {
        "school": "Yorkville Elementary",
        "district": "Gibson Co Sp Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470140000423",
    },
    {
        "school": "South Gibson County Middle School",
        "district": "Gibson Co Sp Dist",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470140001247",
    },
    {
        "school": "Humboldt Junior/Senior High School",
        "district": "Humboldt City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470195000636",
    },
    {
        "school": "Milan Elementary",
        "district": "Milan",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470297000464",
    },
    {
        "school": "Milan High School",
        "district": "Milan",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470297001189",
    },
    {
        "school": "Milan Middle School",
        "district": "Milan",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470297001190",
    },
    {
        "school": "Peabody High School",
        "district": "Trenton",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470410001703",
    },
    {
        "school": "Trenton Middle School",
        "district": "Trenton",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470410001704",
    },
    {
        "school": "Trenton Elementary",
        "district": "Trenton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470410001705",
    },
    {
        "school": "Bridgeforth Middle School",
        "district": "Giles County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470141000427",
    },
    {
        "school": "Elkton Elementary",
        "district": "Giles County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470141000428",
    },
    {
        "school": "Giles Co High School",
        "district": "Giles County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470141000429",
    },
    {
        "school": "Minor Hill School",
        "district": "Giles County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470141000430",
    },
    {
        "school": "Pulaski Elementary",
        "district": "Giles County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470141000431",
    },
    {
        "school": "Richland Elementary",
        "district": "Giles County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470141000432",
    },
    {
        "school": "Richland School",
        "district": "Giles County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470141000433",
    },
    {
        "school": "Southside Elementary",
        "district": "Giles County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470141002022",
    },
    {
        "school": "Coalmont Elementary",
        "district": "Grundy County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470153000463",
    },
    {
        "school": "Grundy County High School",
        "district": "Grundy County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470153000469",
    },
    {
        "school": "Palmer Elementary",
        "district": "Grundy County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470153000471",
    },
    {
        "school": "Pelham Elementary",
        "district": "Grundy County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470153000472",
    },
    {
        "school": "Swiss Memorial Elementary",
        "district": "Grundy County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470153000475",
    },
    {
        "school": "North Elementary",
        "district": "Grundy County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470153001838",
    },
    {
        "school": "Tracy Elementary",
        "district": "Grundy County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470153001839",
    },
    {
        "school": "Hancock County Elementary",
        "district": "Hancock County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470162000534",
    },
    {
        "school": "Hancock High School",
        "district": "Hancock County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470162000535",
    },
    {
        "school": "Bolivar Elementary",
        "district": "Hardeman County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470165000539",
    },
    {
        "school": "Bolivar Middle School",
        "district": "Hardeman County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470165000540",
    },
    {
        "school": "Central High School",
        "district": "Hardeman County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470165000541",
    },
    {
        "school": "Grand Junction Elementary",
        "district": "Hardeman County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470165000542",
    },
    {
        "school": "Hornsby Elementary",
        "district": "Hardeman County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470165000545",
    },
    {
        "school": "Middleton Elementary",
        "district": "Hardeman County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470165000546",
    },
    {
        "school": "Middleton High School",
        "district": "Hardeman County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470165000547",
    },
    {
        "school": "Toone Elementary",
        "district": "Hardeman County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470165000548",
    },
    {
        "school": "Whiteville Elementary",
        "district": "Hardeman County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470165000550",
    },
    {
        "school": "Hardin County High School",
        "district": "Hardin County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470168000553",
    },
    {
        "school": "Hardin County Middle School",
        "district": "Hardin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470168000554",
    },
    {
        "school": "Parris South Elementary",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470168000558",
    },
    {
        "school": "Pickwick Southside School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470168000559",
    },
    {
        "school": "West Hardin Elementary",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470168000562",
    },
    {
        "school": "Bargerton Elementary",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470180000600",
    },
    {
        "school": "Beaver Elementary",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470180000601",
    },
    {
        "school": "Lexington High School",
        "district": "Henderson County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470180000603",
    },
    {
        "school": "Pin Oak Elementary",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470180000605",
    },
    {
        "school": "Scotts Hill Elementary",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470180000609",
    },
    {
        "school": "South Haven Elementary",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470180000611",
    },
    {
        "school": "Westover Elementary",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470180000612",
    },
    {
        "school": "Scotts Hill High School",
        "district": "Henderson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470180001427",
    },
    {
        "school": "South Side Elementary",
        "district": "Henderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470180001953",
    },
    {
        "school": "Lexington Middle School",
        "district": "Lexington",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470246000875",
    },
    {
        "school": "Houston Co Adult High School",
        "district": "Houston County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470192000313",
    },
    {
        "school": "Erin Elementary",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470192000630",
    },
    {
        "school": "Houston Co Middle School",
        "district": "Houston County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470192000631",
    },
    {
        "school": "Tennessee Ridge Elementary",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470192000632",
    },
    {
        "school": "Houston Co High School",
        "district": "Houston County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470192001441",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Humphreys County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470198000639",
    },
    {
        "school": "Mc Ewen High School",
        "district": "Humphreys County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470198000641",
    },
    {
        "school": "Waverly Central High School",
        "district": "Humphreys County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470198000642",
    },
    {
        "school": "Waverly Elementary",
        "district": "Humphreys County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470198000643",
    },
    {
        "school": "Waverly Jr High School",
        "district": "Humphreys County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470198000644",
    },
    {
        "school": "Mc Ewen Elementary",
        "district": "Humphreys County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470198001442",
    },
    {
        "school": "McEwen Jr. High School",
        "district": "Humphreys County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470198001450",
    },
    {
        "school": "Doe Elementary",
        "district": "Johnson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470216000694",
    },
    {
        "school": "Johnson Co High School",
        "district": "Johnson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470216000696",
    },
    {
        "school": "Johnson Co Middle School",
        "district": "Johnson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470216000697",
    },
    {
        "school": "Laurel Elementary",
        "district": "Johnson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470216000698",
    },
    {
        "school": "Mountain City Elementary",
        "district": "Johnson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470216000699",
    },
    {
        "school": "Shady Valley Elementary",
        "district": "Johnson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470216000701",
    },
    {
        "school": "Lake Co High School",
        "district": "Lake County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470228000826",
    },
    {
        "school": "Lara Kendall Elementary",
        "district": "Lake County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470228000827",
    },
    {
        "school": "Margaret Newton Elementary",
        "district": "Lake County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470228000829",
    },
    {
        "school": "Ripley Elementary",
        "district": "Lauderdale County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470231000549",
    },
    {
        "school": "Halls Elementary School",
        "district": "Lauderdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470231000833",
    },
    {
        "school": "Halls High School",
        "district": "Lauderdale County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470231000834",
    },
    {
        "school": "Ripley High School",
        "district": "Lauderdale County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470231000838",
    },
    {
        "school": "Ripley Primary",
        "district": "Lauderdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470231000840",
    },
    {
        "school": "Ripley Middle School",
        "district": "Lauderdale County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470231001970",
    },
    {
        "school": "Halls Junior High School",
        "district": "Lauderdale County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470231001997",
    },
    {
        "school": "Lewis County Middle School",
        "district": "Lewis County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470243000872",
    },
    {
        "school": "Lewis County Elementary",
        "district": "Lewis County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470243000873",
    },
    {
        "school": "Lewis Co High School",
        "district": "Lewis County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470243000874",
    },
    {
        "school": "Lewis County Intermediate School",
        "district": "Lewis County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470243001468",
    },
    {
        "school": "Fayetteville High School",
        "district": "Fayetteville",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470120000371",
    },
    {
        "school": "Ralph Askins School",
        "district": "Fayetteville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470120000372",
    },
    {
        "school": "Fayetteville Middle School",
        "district": "Fayetteville",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470120001470",
    },
    {
        "school": "Adamsville Elementary",
        "district": "McNairy County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470288000997",
    },
    {
        "school": "Adamsville High School",
        "district": "McNairy County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470288000998",
    },
    {
        "school": "Bethel Springs Elementary",
        "district": "McNairy County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470288000999",
    },
    {
        "school": "McNairy Central High School",
        "district": "McNairy County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470288001000",
    },
    {
        "school": "Michie Elementary",
        "district": "McNairy County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470288001001",
    },
    {
        "school": "Ramer Elementary",
        "district": "McNairy County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470288001002",
    },
    {
        "school": "Selmer Elementary",
        "district": "McNairy County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470288001003",
    },
    {
        "school": "Selmer Middle School",
        "district": "McNairy County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470288001004",
    },
    {
        "school": "Chapel Hill Elementary",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470267000482",
    },
    {
        "school": "Lewisburg Middle School",
        "district": "Marshall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470267000844",
    },
    {
        "school": "Cornersville School",
        "district": "Marshall County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470267000948",
    },
    {
        "school": "Forrest School",
        "district": "Marshall County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470267000950",
    },
    {
        "school": "Marshall Co High School",
        "district": "Marshall County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470267000953",
    },
    {
        "school": "Marshall Elementary",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470267001885",
    },
    {
        "school": "Westhills Elementary",
        "district": "Marshall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470267001956",
    },
    {
        "school": "Meigs South Elementary",
        "district": "Meigs County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470291001005",
    },
    {
        "school": "Meigs North Elementary",
        "district": "Meigs County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470291001007",
    },
    {
        "school": "Meigs County High School",
        "district": "Meigs County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470291001009",
    },
    {
        "school": "Meigs Middle School",
        "district": "Meigs County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470291001982",
    },
    {
        "school": "Sequoyah High School",
        "district": "Monroe County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300000409",
    },
    {
        "school": "Coker Creek Elementary",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300001193",
    },
    {
        "school": "Madisonville Primary",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300001194",
    },
    {
        "school": "Madisonville Middle School",
        "district": "Monroe County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300001196",
    },
    {
        "school": "Rural Vale Elementary",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300001198",
    },
    {
        "school": "Sweetwater High School",
        "district": "Monroe County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300001199",
    },
    {
        "school": "Tellico Plains Elementary",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300001200",
    },
    {
        "school": "Tellico Plains High School",
        "district": "Monroe County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300001201",
    },
    {
        "school": "Tellico Plains Junior High School",
        "district": "Monroe County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300001202",
    },
    {
        "school": "Vonore Elementary",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470300001203",
    },
    {
        "school": "Brown Intermediate School",
        "district": "Sweetwater",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470405001686",
    },
    {
        "school": "Sweetwater Elementary",
        "district": "Sweetwater",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470405001687",
    },
    {
        "school": "Sweetwater Jr High School",
        "district": "Sweetwater",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470405001688",
    },
    {
        "school": "Central Elementary",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470309001226",
    },
    {
        "school": "Central High School",
        "district": "Morgan County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470309001227",
    },
    {
        "school": "Coalfield School",
        "district": "Morgan County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470309001230",
    },
    {
        "school": "Morgan County Career and Technical Center",
        "district": "Morgan County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "TN",
        "nces_id": "470309001233",
    },
    {
        "school": "Oakdale School",
        "district": "Morgan County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470309001235",
    },
    {
        "school": "Petros Joyner Elementary",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470309001236",
    },
    {
        "school": "Sunbright School",
        "district": "Morgan County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470309001238",
    },
    {
        "school": "Perry County High School",
        "district": "Perry County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470339001348",
    },
    {
        "school": "Linden Elementary",
        "district": "Perry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470339001432",
    },
    {
        "school": "Lobelville Elementary",
        "district": "Perry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470339001433",
    },
    {
        "school": "Linden Middle School",
        "district": "Perry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470339001434",
    },
    {
        "school": "Pickett Co High School",
        "district": "Pickett County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470342001437",
    },
    {
        "school": "Pickett County Elementary",
        "district": "Pickett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470342001438",
    },
    {
        "school": "Dayton City Elementary",
        "district": "Dayton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470093000315",
    },
    {
        "school": "Frazier Elementary",
        "district": "Rhea County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470351001463",
    },
    {
        "school": "Graysville Elementary School",
        "district": "Rhea County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470351001465",
    },
    {
        "school": "Rhea County High School",
        "district": "Rhea County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470351001467",
    },
    {
        "school": "Spring City Elementary",
        "district": "Rhea County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470351001469",
    },
    {
        "school": "Oneida Middle School",
        "district": "Oneida",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470330000031",
    },
    {
        "school": "Oneida Elementary",
        "district": "Oneida",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470330001412",
    },
    {
        "school": "Oneida High School",
        "district": "Oneida",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470330001413",
    },
    {
        "school": "Burchfield Elementary",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470372001533",
    },
    {
        "school": "Huntsville Elementary",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470372001535",
    },
    {
        "school": "Robbins Elementary",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470372001538",
    },
    {
        "school": "Scott High School",
        "district": "Scott County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470372001539",
    },
    {
        "school": "Huntsville Middle School",
        "district": "Scott County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470372001540",
    },
    {
        "school": "Winfield Elementary",
        "district": "Scott County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470372001541",
    },
    {
        "school": "Fairview Elementary",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470372001965",
    },
    {
        "school": "Spencer Elementary",
        "district": "Van Buren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470432001737",
    },
    {
        "school": "Van Buren Co High School",
        "district": "Van Buren County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470432001738",
    },
    {
        "school": "Collinwood Elementary",
        "district": "Wayne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470444001767",
    },
    {
        "school": "Collinwood High School",
        "district": "Wayne County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470444001768",
    },
    {
        "school": "Collinwood Middle School",
        "district": "Wayne County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470444001769",
    },
    {
        "school": "Frank Hughes School",
        "district": "Wayne County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470444001771",
    },
    {
        "school": "Wayne County High School",
        "district": "Wayne County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470444001773",
    },
    {
        "school": "Wayne County Technology Center",
        "district": "Wayne County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "TN",
        "nces_id": "470444001774",
    },
    {
        "school": "Waynesboro Elementary",
        "district": "Wayne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470444001775",
    },
    {
        "school": "Waynesboro Middle School",
        "district": "Wayne County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470444001776",
    },
    {
        "school": "Dresden Elementary",
        "district": "Weakley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470447001777",
    },
    {
        "school": "Dresden High School",
        "district": "Weakley County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470447001778",
    },
    {
        "school": "Dresden Middle School",
        "district": "Weakley County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470447001779",
    },
    {
        "school": "Gleason School",
        "district": "Weakley County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470447001780",
    },
    {
        "school": "Greenfield School",
        "district": "Weakley County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470447001782",
    },
    {
        "school": "Martin Elementary",
        "district": "Weakley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470447001784",
    },
    {
        "school": "Martin Middle School",
        "district": "Weakley County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470447001785",
    },
    {
        "school": "Sharon School",
        "district": "Weakley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470447001788",
    },
    {
        "school": "Weakley County Center For Adult  Continuing Education",
        "district": "Weakley County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470447001789",
    },
    {
        "school": "Westview High School",
        "district": "Weakley County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470447001790",
    },
    {
        "school": "Martin Primary",
        "district": "Weakley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470447001866",
    },
    {
        "school": "Northfield Elementary School",
        "district": "White County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470450001363",
    },
    {
        "school": "Bon De Croft Elementary",
        "district": "White County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470450001792",
    },
    {
        "school": "Cassville Elementary",
        "district": "White County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470450001793",
    },
    {
        "school": "Doyle Elementary",
        "district": "White County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470450001795",
    },
    {
        "school": "Findlay Elementary",
        "district": "White County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470450001797",
    },
    {
        "school": "White County High School",
        "district": "White County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470450001798",
    },
    {
        "school": "White Co Middle School",
        "district": "White County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470450001800",
    },
    {
        "school": "Woodland Park Elementary",
        "district": "White County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470450001980",
    },
    {
        "school": "Athens City Middle School",
        "district": "Athens",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470012000025",
    },
    {
        "school": "City Park Elementary",
        "district": "Athens",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470012000026",
    },
    {
        "school": "Ingleside Elementary",
        "district": "Athens",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470012000027",
    },
    {
        "school": "North City Elementary",
        "district": "Athens",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470012000028",
    },
    {
        "school": "Westside Elementary",
        "district": "Athens",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470012000029",
    },
    {
        "school": "Etowah Elementary",
        "district": "Etowah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470114000356",
    },
    {
        "school": "Rogers Creek Elementary",
        "district": "McMinn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470282000030",
    },
    {
        "school": "Calhoun Elementary",
        "district": "McMinn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470282000986",
    },
    {
        "school": "Central High School",
        "district": "McMinn County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470282000987",
    },
    {
        "school": "E K Baker Elementary",
        "district": "McMinn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470282000989",
    },
    {
        "school": "Englewood Elementary",
        "district": "McMinn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470282000990",
    },
    {
        "school": "McMinn High School",
        "district": "McMinn County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470282000993",
    },
    {
        "school": "Mountain View Elementary",
        "district": "McMinn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470282000994",
    },
    {
        "school": "Niota Elementary",
        "district": "McMinn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470282000995",
    },
    {
        "school": "Riceville Elementary",
        "district": "McMinn County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470282000996",
    },
    {
        "school": "Anderson Early Childhood",
        "district": "Haywood County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470177000591",
    },
    {
        "school": "East Side Elementary",
        "district": "Haywood County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470177000595",
    },
    {
        "school": "Haywood Elementary",
        "district": "Haywood County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470177000596",
    },
    {
        "school": "Haywood High School",
        "district": "Haywood County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470177000597",
    },
    {
        "school": "Haywood Middle School",
        "district": "Haywood County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470177001952",
    },
    {
        "school": "Battle Academy For Teaching  Learning",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159001787",
    },
    {
        "school": "Tommie F. Brown Academy",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159001791",
    },
    {
        "school": "Hardy Elementary School",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159001809",
    },
    {
        "school": "Griffith Elementary",
        "district": "Sequatchie County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470375001542",
    },
    {
        "school": "Sequatchie Co High School",
        "district": "Sequatchie County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470375001544",
    },
    {
        "school": "Sequatchie Co Middle School",
        "district": "Sequatchie County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470375001546",
    },
    {
        "school": "Hunter Middle School",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000374",
    },
    {
        "school": "Loftis Middle School",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000389",
    },
    {
        "school": "North Hamilton Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000397",
    },
    {
        "school": "Allen Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000489",
    },
    {
        "school": "Alpine Crest Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000490",
    },
    {
        "school": "Apison Elementary School",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000491",
    },
    {
        "school": "Brown Middle School",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000494",
    },
    {
        "school": "Central High School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000495",
    },
    {
        "school": "Daisy Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000496",
    },
    {
        "school": "East Ridge Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000500",
    },
    {
        "school": "East Ridge High School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000501",
    },
    {
        "school": "East Ridge Middle School",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000502",
    },
    {
        "school": "Middle Valley Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000504",
    },
    {
        "school": "Harrison Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000506",
    },
    {
        "school": "Lookout Mountain Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000509",
    },
    {
        "school": "Ooltewah Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000513",
    },
    {
        "school": "Ooltewah High School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000514",
    },
    {
        "school": "Ooltewah Middle School",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000515",
    },
    {
        "school": "Red Bank Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000516",
    },
    {
        "school": "Red Bank High School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000517",
    },
    {
        "school": "Red Bank Middle School",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000518",
    },
    {
        "school": "Sale Creek Middle / High School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000520",
    },
    {
        "school": "Sequoyah High School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000521",
    },
    {
        "school": "Signal Mountain Middle/High School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000523",
    },
    {
        "school": "Snow Hill Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000524",
    },
    {
        "school": "Soddy Daisy High School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000525",
    },
    {
        "school": "Soddy Daisy Middle School",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000526",
    },
    {
        "school": "Soddy Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000527",
    },
    {
        "school": "Spring Creek Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000528",
    },
    {
        "school": "Thrasher Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000529",
    },
    {
        "school": "Westview Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000530",
    },
    {
        "school": "Bess T Shepherd Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000618",
    },
    {
        "school": "Big Ridge Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000624",
    },
    {
        "school": "Brainerd High School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000626",
    },
    {
        "school": "Normal Park Museum Magnet School",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000650",
    },
    {
        "school": "Chatt High Center For Creative Arts",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000666",
    },
    {
        "school": "Chattanooga School For Arts And Sciences Upper",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000669",
    },
    {
        "school": "Chattanooga School For The Arts And Science Lower",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000674",
    },
    {
        "school": "Clifton Hills Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000691",
    },
    {
        "school": "Dalewood Middle School",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000704",
    },
    {
        "school": "DuPont Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000711",
    },
    {
        "school": "East Brainerd Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000716",
    },
    {
        "school": "Barger Academy",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000731",
    },
    {
        "school": "Hixson Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000746",
    },
    {
        "school": "Hixson High School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000750",
    },
    {
        "school": "Hixson Middle School",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000751",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000757",
    },
    {
        "school": "The Howard School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000759",
    },
    {
        "school": "Lakeside Academy",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000762",
    },
    {
        "school": "Chattanooga School For The Liberal Arts",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000763",
    },
    {
        "school": "Lookout Valley Middle / High School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000781",
    },
    {
        "school": "Rivermont Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000795",
    },
    {
        "school": "Orchard Knob Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000800",
    },
    {
        "school": "Orchard Knob Middle",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000801",
    },
    {
        "school": "Tyner Academy",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000802",
    },
    {
        "school": "Tyner Middle Academy",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000812",
    },
    {
        "school": "Lookout Valley Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000818",
    },
    {
        "school": "Woodmore Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000828",
    },
    {
        "school": "Calvin Donaldson Environmental Science Academy",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159000938",
    },
    {
        "school": "East Side Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159001103",
    },
    {
        "school": "Nolan Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159001104",
    },
    {
        "school": "East Lake Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159001276",
    },
    {
        "school": "East Lake Academy Of Fine Arts",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159001285",
    },
    {
        "school": "Hamilton County Collegiate High at Chattanooga State",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159001416",
    },
    {
        "school": "McConnell Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159001995",
    },
    {
        "school": "Wolftever Creek Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159001996",
    },
    {
        "school": "Wallace A. Smith Elementary",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159002004",
    },
    {
        "school": "Jasper Elementary School",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470264000935",
    },
    {
        "school": "Marion Co High School",
        "district": "Marion County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470264000936",
    },
    {
        "school": "Monteagle Elementary",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470264000937",
    },
    {
        "school": "South Pittsburg Elementary",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470264000940",
    },
    {
        "school": "South Pittsburg High School",
        "district": "Marion County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470264000941",
    },
    {
        "school": "Whitwell Middle School",
        "district": "Marion County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470264000943",
    },
    {
        "school": "Whitwell High School",
        "district": "Marion County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470264000944",
    },
    {
        "school": "Whitwell Elementary",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470264001471",
    },
    {
        "school": "Jasper Middle School",
        "district": "Marion County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470264001850",
    },
    {
        "school": "Richard Hardy Memorial School",
        "district": "Richard City",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470354001474",
    },
    {
        "school": "Stewart County Middle School",
        "district": "Stewart County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470396002091",
    },
    {
        "school": "Stewart County Adult High School",
        "district": "Stewart County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470396002093",
    },
    {
        "school": "Dover Elementary",
        "district": "Stewart County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470396001610",
    },
    {
        "school": "North Stewart Elementary",
        "district": "Stewart County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470396001611",
    },
    {
        "school": "Stewart Co High School",
        "district": "Stewart County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470396001612",
    },
    {
        "school": "Kenwood Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303000102",
    },
    {
        "school": "Hazelwood Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303000410",
    },
    {
        "school": "Liberty Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303000484",
    },
    {
        "school": "Kenwood High",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303000850",
    },
    {
        "school": "Sango Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303000851",
    },
    {
        "school": "Rossview Middle",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303000951",
    },
    {
        "school": "Glenellen Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001121",
    },
    {
        "school": "Barksdale Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001205",
    },
    {
        "school": "Burt Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001206",
    },
    {
        "school": "Byrns Darden Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001207",
    },
    {
        "school": "Montgomery Central Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001208",
    },
    {
        "school": "Montgomery Central High",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001209",
    },
    {
        "school": "Clarksville High",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001210",
    },
    {
        "school": "Cumberland Heights Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001211",
    },
    {
        "school": "East Montgomery Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001212",
    },
    {
        "school": "Moore Magnet Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001216",
    },
    {
        "school": "Norman Smith Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001217",
    },
    {
        "school": "New Providence Middle",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001218",
    },
    {
        "school": "Northwest High",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001219",
    },
    {
        "school": "Ringgold Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001220",
    },
    {
        "school": "St. Bethlehem Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001221",
    },
    {
        "school": "Woodlawn Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001222",
    },
    {
        "school": "Rossview High",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001477",
    },
    {
        "school": "Northeast High",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001855",
    },
    {
        "school": "Richview Middle",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001856",
    },
    {
        "school": "Minglewood Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001984",
    },
    {
        "school": "Montgomery Central Middle",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303001985",
    },
    {
        "school": "Northeast Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303002010",
    },
    {
        "school": "Northeast Middle",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303002011",
    },
    {
        "school": "Polk County High School",
        "district": "Polk County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470345001900",
    },
    {
        "school": "Copper Basin Elementary School",
        "district": "Polk County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470345002070",
    },
    {
        "school": "Black Fox Elementary School",
        "district": "Bradley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000087",
    },
    {
        "school": "Ocoee Middle School",
        "district": "Bradley County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000089",
    },
    {
        "school": "Bradley Central High School",
        "district": "Bradley County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000090",
    },
    {
        "school": "Charleston Elementary School",
        "district": "Bradley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000092",
    },
    {
        "school": "Hopewell Elementary School",
        "district": "Bradley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000094",
    },
    {
        "school": "Michigan Avenue Elementary School",
        "district": "Bradley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000096",
    },
    {
        "school": "North Lee Elementary School",
        "district": "Bradley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000098",
    },
    {
        "school": "Oak Grove Elementary School",
        "district": "Bradley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000099",
    },
    {
        "school": "Prospect Elementary School",
        "district": "Bradley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000100",
    },
    {
        "school": "Taylor Elementary School",
        "district": "Bradley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000101",
    },
    {
        "school": "Lake Forest Middle School",
        "district": "Bradley County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000104",
    },
    {
        "school": "Valley View Elementary School",
        "district": "Bradley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000105",
    },
    {
        "school": "Waterville Community Elementary School",
        "district": "Bradley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000106",
    },
    {
        "school": "North Cleveland GOAL Academy",
        "district": "Bradley County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033000293",
    },
    {
        "school": "Walker Valley High School",
        "district": "Bradley County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033001388",
    },
    {
        "school": "D.P. Yates Primary",
        "district": "Cleveland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470069000061",
    },
    {
        "school": "Arnold Memorial Elementary",
        "district": "Cleveland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470069000263",
    },
    {
        "school": "Cleveland High",
        "district": "Cleveland",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470069000265",
    },
    {
        "school": "Cleveland Middle",
        "district": "Cleveland",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470069000266",
    },
    {
        "school": "E.L. Ross Elementary",
        "district": "Cleveland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470069000267",
    },
    {
        "school": "G.R. Stuart Elementary",
        "district": "Cleveland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470069000268",
    },
    {
        "school": "Mayfield Elementary",
        "district": "Cleveland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470069000269",
    },
    {
        "school": "Blythe-Bower Elementary",
        "district": "Cleveland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470069000270",
    },
    {
        "school": "Benton Elementary",
        "district": "Polk County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470345001439",
    },
    {
        "school": "Copper Basin High School",
        "district": "Polk County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470345001440",
    },
    {
        "school": "Chilhowee Middle School",
        "district": "Polk County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470345001444",
    },
    {
        "school": "South Polk Elementary",
        "district": "Polk County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470345001445",
    },
    {
        "school": "E. A. Cox Middle School",
        "district": "Maury County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000846",
    },
    {
        "school": "J. R. Baker Elementary",
        "district": "Maury County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000961",
    },
    {
        "school": "J. Brown Elementary",
        "district": "Maury County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000962",
    },
    {
        "school": "Columbia Central High School",
        "district": "Maury County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000964",
    },
    {
        "school": "Culleoka Unit School",
        "district": "Maury County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000967",
    },
    {
        "school": "Hampshire Unit School",
        "district": "Maury County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000969",
    },
    {
        "school": "Highland Park Elementary",
        "district": "Maury County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000970",
    },
    {
        "school": "McDowell Elementary",
        "district": "Maury County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000973",
    },
    {
        "school": "Mt Pleasant High School",
        "district": "Maury County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000974",
    },
    {
        "school": "J E Woody Elementary",
        "district": "Maury County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000976",
    },
    {
        "school": "Riverside Elementary",
        "district": "Maury County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000977",
    },
    {
        "school": "Santa Fe Unit School",
        "district": "Maury County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000979",
    },
    {
        "school": "Spring Hill Elementary",
        "district": "Maury County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000980",
    },
    {
        "school": "Spring Hill High School",
        "district": "Maury County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000981",
    },
    {
        "school": "Whitthorne Middle School",
        "district": "Maury County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276000982",
    },
    {
        "school": "R Howell Elementary",
        "district": "Maury County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276001118",
    },
    {
        "school": "Mt. Pleasant Middle Visual Perform. Arts",
        "district": "Maury County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276001473",
    },
    {
        "school": "J E Woodard Elementary",
        "district": "Maury County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276002007",
    },
    {
        "school": "Jackson County Middle School",
        "district": "Jackson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470207001829",
    },
    {
        "school": "Algood Middle School",
        "district": "Putnam County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001901",
    },
    {
        "school": "Upperman High School",
        "district": "Putnam County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001903",
    },
    {
        "school": "Jackson County High School",
        "district": "Jackson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470207000661",
    },
    {
        "school": "Dodson Branch Elementary",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470207000662",
    },
    {
        "school": "Gainesboro Elementary",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470207000665",
    },
    {
        "school": "R.E.A.C.H. Academy",
        "district": "Overton County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470333000412",
    },
    {
        "school": "Overton Adult High School",
        "district": "Overton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470333000952",
    },
    {
        "school": "Allons Elementary",
        "district": "Overton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470333001414",
    },
    {
        "school": "Hilham Elementary",
        "district": "Overton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470333001417",
    },
    {
        "school": "Livingston Academy",
        "district": "Overton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470333001419",
    },
    {
        "school": "Livingston Middle School",
        "district": "Overton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470333001420",
    },
    {
        "school": "Rickman Elementary",
        "district": "Overton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470333001423",
    },
    {
        "school": "Wilson Elementary",
        "district": "Overton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470333001425",
    },
    {
        "school": "A H Roberts Elementary",
        "district": "Overton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470333001977",
    },
    {
        "school": "Putnam Co Adult High School",
        "district": "Putnam County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348000367",
    },
    {
        "school": "Cane Creek Elementary",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348000413",
    },
    {
        "school": "Avery Trace Middle School",
        "district": "Putnam County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348000497",
    },
    {
        "school": "Cornerstone Elementary",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001449",
    },
    {
        "school": "Capshaw Elementary",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001451",
    },
    {
        "school": "Jere Whitson Elementary",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001453",
    },
    {
        "school": "Monterey High School",
        "district": "Putnam County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001454",
    },
    {
        "school": "Northeast Elementary",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001455",
    },
    {
        "school": "Park View Elementary",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001456",
    },
    {
        "school": "Cookeville High School",
        "district": "Putnam County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001457",
    },
    {
        "school": "Sycamore Elementary",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001459",
    },
    {
        "school": "Upperman Middle School",
        "district": "Putnam County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001461",
    },
    {
        "school": "Burks Elementary",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348001487",
    },
    {
        "school": "Frank P. Brown Elementary",
        "district": "Cumberland County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090002052",
    },
    {
        "school": "Crab Orchard Elementary",
        "district": "Cumberland County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090000301",
    },
    {
        "school": "Cumberland County High School",
        "district": "Cumberland County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090000303",
    },
    {
        "school": "Glenn Martin Elementary",
        "district": "Cumberland County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090000305",
    },
    {
        "school": "Homestead Elementary School",
        "district": "Cumberland County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090000306",
    },
    {
        "school": "Pine View Elementary",
        "district": "Cumberland County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090000309",
    },
    {
        "school": "Pleasant Hill Elementary",
        "district": "Cumberland County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090000310",
    },
    {
        "school": "Stone Elementary",
        "district": "Cumberland County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090001050",
    },
    {
        "school": "South Cumberland Elementary",
        "district": "Cumberland County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090001835",
    },
    {
        "school": "North Cumberland Elementary",
        "district": "Cumberland County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090001877",
    },
    {
        "school": "Dyer County High School",
        "district": "Dyer County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470105002028",
    },
    {
        "school": "Northview Middle School",
        "district": "Dyer County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470105000339",
    },
    {
        "school": "Fifth Consolidated School",
        "district": "Dyer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470105000340",
    },
    {
        "school": "Finley Elementary",
        "district": "Dyer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470105000341",
    },
    {
        "school": "Holice Powell Elementary",
        "district": "Dyer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470105000342",
    },
    {
        "school": "Newbern Elementary School",
        "district": "Dyer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470105000343",
    },
    {
        "school": "Trimble Elementary",
        "district": "Dyer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470105000345",
    },
    {
        "school": "Three Oaks Middle School",
        "district": "Dyer County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470105000934",
    },
    {
        "school": "Dyersburg Intermediate School",
        "district": "Dyersburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470108000346",
    },
    {
        "school": "Dyersburg High School",
        "district": "Dyersburg",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470108000347",
    },
    {
        "school": "Dyersburg Primary",
        "district": "Dyersburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470108000349",
    },
    {
        "school": "Dyersburg Middle School",
        "district": "Dyersburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470108001402",
    },
    {
        "school": "Chuckey Doak Middle School",
        "district": "Greene County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147002062",
    },
    {
        "school": "Baileyton Elementary",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000441",
    },
    {
        "school": "Camp Creek Elementary",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000442",
    },
    {
        "school": "Chuckey Elementary",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000444",
    },
    {
        "school": "Chuckey Doak High School",
        "district": "Greene County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000445",
    },
    {
        "school": "Debusk Elementary",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000446",
    },
    {
        "school": "Doak Elementary",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000447",
    },
    {
        "school": "McDonald Elementary",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000450",
    },
    {
        "school": "Mosheim Elementary",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000451",
    },
    {
        "school": "North Greene High School",
        "district": "Greene County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000453",
    },
    {
        "school": "Ottway Elementary",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000454",
    },
    {
        "school": "South Greene High School",
        "district": "Greene County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000455",
    },
    {
        "school": "West Greene High School",
        "district": "Greene County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147000458",
    },
    {
        "school": "Nolachuckey Elementary",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147001837",
    },
    {
        "school": "Eastview Elementary",
        "district": "Greeneville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470150000465",
    },
    {
        "school": "Greeneville High School",
        "district": "Greeneville",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470150000467",
    },
    {
        "school": "Greeneville Middle School",
        "district": "Greeneville",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470150000468",
    },
    {
        "school": "Highland Elementary",
        "district": "Greeneville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470150000470",
    },
    {
        "school": "Tusculum View Elementary",
        "district": "Greeneville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470150000476",
    },
    {
        "school": "C Hal Henard Elementary",
        "district": "Greeneville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470150001879",
    },
    {
        "school": "Greeneville/Greene Co Center For Technology",
        "district": "Greeneville",
        "level": "High",
        "type": "Career and Technical School",
        "state": "TN",
        "nces_id": "470150001880",
    },
    {
        "school": "Harriman Middle School",
        "district": "Roane County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359000566",
    },
    {
        "school": "Harriman High School",
        "district": "Roane County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359000567",
    },
    {
        "school": "Bowers Elementary",
        "district": "Roane County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359000569",
    },
    {
        "school": "Midway Middle School",
        "district": "Roane County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359002036",
    },
    {
        "school": "Cherokee Middle School",
        "district": "Roane County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001475",
    },
    {
        "school": "Kingston Elementary",
        "district": "Roane County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001479",
    },
    {
        "school": "Midtown Elementary",
        "district": "Roane County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001480",
    },
    {
        "school": "Midway Elementary",
        "district": "Roane County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001481",
    },
    {
        "school": "Midway High School",
        "district": "Roane County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001482",
    },
    {
        "school": "Oliver Springs Middle",
        "district": "Roane County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001483",
    },
    {
        "school": "Oliver Springs High School",
        "district": "Roane County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001484",
    },
    {
        "school": "Ridge View Elementary",
        "district": "Roane County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001485",
    },
    {
        "school": "Roane County High School",
        "district": "Roane County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001486",
    },
    {
        "school": "Midtown Educational Center",
        "district": "Roane County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001488",
    },
    {
        "school": "Rockwood High School",
        "district": "Roane County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001489",
    },
    {
        "school": "Rockwood Middle School",
        "district": "Roane County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359001490",
    },
    {
        "school": "Isaac Lane Technology Magnet Elementary",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258001843",
    },
    {
        "school": "Thelma Barker Elementary",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258001844",
    },
    {
        "school": "Liberty Technology Magnet High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258002032",
    },
    {
        "school": "Madison Academic Magnet High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258002033",
    },
    {
        "school": "Chester County Junior High School",
        "district": "Chester County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470060000238",
    },
    {
        "school": "East Chester Elementary School",
        "district": "Chester County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470060000239",
    },
    {
        "school": "Jacks Creek Elementary",
        "district": "Chester County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470060000240",
    },
    {
        "school": "W Chester Elementary School",
        "district": "Chester County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470060000242",
    },
    {
        "school": "Chester County High School",
        "district": "Chester County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470060000894",
    },
    {
        "school": "Chester County Middle School",
        "district": "Chester County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470060001919",
    },
    {
        "school": "Northeast Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258000083",
    },
    {
        "school": "South Elementary",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258000085",
    },
    {
        "school": "Alexander Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258000648",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258000655",
    },
    {
        "school": "Community Montessori School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258000656",
    },
    {
        "school": "Parkview Learning Center",
        "district": "Madison County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470258000659",
    },
    {
        "school": "Nova Early Learning Center",
        "district": "Madison County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258000660",
    },
    {
        "school": "Denmark Elementary",
        "district": "Madison County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258000915",
    },
    {
        "school": "North Side High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258000920",
    },
    {
        "school": "Pope School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258000924",
    },
    {
        "school": "South Side High School",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258000925",
    },
    {
        "school": "West-Bemis Middle School",
        "district": "Madison County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258000927",
    },
    {
        "school": "Arlington Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258001336",
    },
    {
        "school": "Washington County Adult High School",
        "district": "Washington County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438002095",
    },
    {
        "school": "Central Elementary",
        "district": "Carter County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000151",
    },
    {
        "school": "Cloudland Elementary School",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000152",
    },
    {
        "school": "Cloudland High School",
        "district": "Carter County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000153",
    },
    {
        "school": "Hampton Elementary",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000154",
    },
    {
        "school": "Hampton High School",
        "district": "Carter County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000155",
    },
    {
        "school": "Happy Valley Elementary",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000156",
    },
    {
        "school": "Happy Valley High School",
        "district": "Carter County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000157",
    },
    {
        "school": "Happy Valley Middle School",
        "district": "Carter County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000158",
    },
    {
        "school": "Hunter Elementary",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000159",
    },
    {
        "school": "Keenburg Elementary",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000160",
    },
    {
        "school": "Little Milligan",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000161",
    },
    {
        "school": "Unaka Elementary",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000166",
    },
    {
        "school": "Unaka High School",
        "district": "Carter County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000167",
    },
    {
        "school": "Valley Forge Elementary",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470051000168",
    },
    {
        "school": "Siam Learning Center",
        "district": "Carter County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470051000296",
    },
    {
        "school": "East Side Elementary",
        "district": "Elizabethton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470111000350",
    },
    {
        "school": "Elizabethton High School",
        "district": "Elizabethton",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470111000351",
    },
    {
        "school": "Harold McCormick Elementary",
        "district": "Elizabethton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470111000352",
    },
    {
        "school": "T A Dugger Junior High School",
        "district": "Elizabethton",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470111000353",
    },
    {
        "school": "West Side Elementary",
        "district": "Elizabethton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470111000355",
    },
    {
        "school": "Unicoi Co Middle School",
        "district": "Unicoi County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470423000047",
    },
    {
        "school": "Love Chapel Elementary",
        "district": "Unicoi County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470423001719",
    },
    {
        "school": "Rock Creek Elementary",
        "district": "Unicoi County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470423001721",
    },
    {
        "school": "Temple Hill Elementary",
        "district": "Unicoi County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470423001722",
    },
    {
        "school": "Unicoi Co High School",
        "district": "Unicoi County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470423001723",
    },
    {
        "school": "Unicoi Elementary",
        "district": "Unicoi County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470423001724",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Johnson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213000424",
    },
    {
        "school": "Fairmont Elementary",
        "district": "Johnson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213000672",
    },
    {
        "school": "Woodland Elementary",
        "district": "Johnson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213000673",
    },
    {
        "school": "North Side Elementary",
        "district": "Johnson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213000683",
    },
    {
        "school": "Science Hill High School",
        "district": "Johnson City",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213000686",
    },
    {
        "school": "South Side Elementary",
        "district": "Johnson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213000687",
    },
    {
        "school": "Towne Acres Elementary",
        "district": "Johnson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213000690",
    },
    {
        "school": "Indian Trail Intermediate School",
        "district": "Johnson City",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213000988",
    },
    {
        "school": "Lake Ridge Elementary",
        "district": "Johnson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213000991",
    },
    {
        "school": "Cherokee Elementary",
        "district": "Johnson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213001881",
    },
    {
        "school": "Daniel Boone High School",
        "district": "Washington County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438001756",
    },
    {
        "school": "David Crockett High School",
        "district": "Washington County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438001757",
    },
    {
        "school": "Fall Branch Elementary",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438001758",
    },
    {
        "school": "Gray Elementary School",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438001759",
    },
    {
        "school": "Jonesborough Elementary",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438001760",
    },
    {
        "school": "Jonesborough Middle School",
        "district": "Washington County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438001761",
    },
    {
        "school": "Lamar Elementary",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438001762",
    },
    {
        "school": "South Central Elementary",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438001763",
    },
    {
        "school": "Sulphur Springs Elementary",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438001764",
    },
    {
        "school": "West View School",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438001765",
    },
    {
        "school": "University School",
        "district": "Washington County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438001893",
    },
    {
        "school": "Bulls Gap School",
        "district": "Hawkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000572",
    },
    {
        "school": "Carter's Valley Elementary",
        "district": "Hawkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000573",
    },
    {
        "school": "Church Hill Elementary",
        "district": "Hawkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000574",
    },
    {
        "school": "Church Hill Middle School",
        "district": "Hawkins County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000575",
    },
    {
        "school": "Clinch School",
        "district": "Hawkins County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000576",
    },
    {
        "school": "Hawkins Elementary",
        "district": "Hawkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000580",
    },
    {
        "school": "Keplar Elementary",
        "district": "Hawkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000581",
    },
    {
        "school": "McPheeter's Bend Elementary",
        "district": "Hawkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000583",
    },
    {
        "school": "Mooresburg Elementary",
        "district": "Hawkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000584",
    },
    {
        "school": "Mt Carmel Elementary",
        "district": "Hawkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000585",
    },
    {
        "school": "Rogersville Middle School",
        "district": "Hawkins County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000587",
    },
    {
        "school": "St Clair Elementary",
        "district": "Hawkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000588",
    },
    {
        "school": "Surgoinsville Elementary",
        "district": "Hawkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000589",
    },
    {
        "school": "Surgoinsville Middle School",
        "district": "Hawkins County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174000590",
    },
    {
        "school": "Joseph Rogers Primary School",
        "district": "Hawkins County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174001424",
    },
    {
        "school": "Volunteer High School",
        "district": "Hawkins County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174001841",
    },
    {
        "school": "Cherokee High School",
        "district": "Hawkins County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174001842",
    },
    {
        "school": "George Washington Elementary School",
        "district": "Kingsport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470219000715",
    },
    {
        "school": "Rogersville Elementary",
        "district": "Rogersville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470366001508",
    },
    {
        "school": "Anderson Elementary",
        "district": "Bristol",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470036000107",
    },
    {
        "school": "Avoca Elementary",
        "district": "Bristol",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470036000108",
    },
    {
        "school": "Fairmount Elementary",
        "district": "Bristol",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470036000111",
    },
    {
        "school": "Haynesfield Elementary",
        "district": "Bristol",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470036000112",
    },
    {
        "school": "Holston View Elementary",
        "district": "Bristol",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470036000113",
    },
    {
        "school": "Vance Middle School",
        "district": "Bristol",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470036000114",
    },
    {
        "school": "Tennessee High School",
        "district": "Bristol",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470036000116",
    },
    {
        "school": "Theodore Roosevelt Elementary School",
        "district": "Kingsport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470219000190",
    },
    {
        "school": "Dobyns - Bennett High School",
        "district": "Kingsport",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470219000706",
    },
    {
        "school": "Andrew Jackson Elementary School",
        "district": "Kingsport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470219000707",
    },
    {
        "school": "Thomas Jefferson Elementary School",
        "district": "Kingsport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470219000708",
    },
    {
        "school": "Andrew Johnson Elementary School",
        "district": "Kingsport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470219000709",
    },
    {
        "school": "Abraham Lincoln Elementary School",
        "district": "Kingsport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470219000710",
    },
    {
        "school": "Ross N. Robinson Middle School",
        "district": "Kingsport",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470219000713",
    },
    {
        "school": "John Sevier Middle School",
        "district": "Kingsport",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470219000714",
    },
    {
        "school": "Palmer Early Learning Center",
        "district": "Kingsport",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470219001167",
    },
    {
        "school": "John F. Kennedy Elementary School",
        "district": "Kingsport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470219002005",
    },
    {
        "school": "Blountville Elementary",
        "district": "Sullivan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001617",
    },
    {
        "school": "Blountville Middle School",
        "district": "Sullivan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001618",
    },
    {
        "school": "Bluff City Elementary",
        "district": "Sullivan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001619",
    },
    {
        "school": "Bluff City Middle School",
        "district": "Sullivan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001620",
    },
    {
        "school": "Central Heights Elementary",
        "district": "Sullivan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001623",
    },
    {
        "school": "Sullivan Central High School",
        "district": "Sullivan County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001624",
    },
    {
        "school": "Colonial Heights Middle",
        "district": "Sullivan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001628",
    },
    {
        "school": "Sullivan East High School",
        "district": "Sullivan County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001630",
    },
    {
        "school": "Emmett Elementary",
        "district": "Sullivan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001631",
    },
    {
        "school": "Holston Elementary",
        "district": "Sullivan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001634",
    },
    {
        "school": "Holston Middle School",
        "district": "Sullivan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001635",
    },
    {
        "school": "Holston Valley Middle School",
        "district": "Sullivan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001637",
    },
    {
        "school": "Indian Springs Elementary",
        "district": "Sullivan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001638",
    },
    {
        "school": "Mary Hughes School",
        "district": "Sullivan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001645",
    },
    {
        "school": "Miller Perry Elementary",
        "district": "Sullivan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001646",
    },
    {
        "school": "Rock Springs Elementary",
        "district": "Sullivan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001648",
    },
    {
        "school": "Sullivan Gardens K-8",
        "district": "Sullivan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001649",
    },
    {
        "school": "Sullivan North High School",
        "district": "Sullivan County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001862",
    },
    {
        "school": "Sullivan South High School",
        "district": "Sullivan County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399001863",
    },
    {
        "school": "Eagleton Elementary",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030001669",
    },
    {
        "school": "Amherst Elementary School",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222002065",
    },
    {
        "school": "Anderson County Career  Technical Center",
        "district": "Anderson County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "TN",
        "nces_id": "470009000003",
    },
    {
        "school": "Andersonville Elementary",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000004",
    },
    {
        "school": "Briceville Elementary",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000005",
    },
    {
        "school": "Claxton Elementary",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000006",
    },
    {
        "school": "Clinton Middle School",
        "district": "Anderson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000007",
    },
    {
        "school": "Clinton High School",
        "district": "Anderson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000008",
    },
    {
        "school": "Dutch Valley Elementary",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000011",
    },
    {
        "school": "Fairview Elementary",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000012",
    },
    {
        "school": "Lake City Elementary",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000014",
    },
    {
        "school": "Lake City Middle School",
        "district": "Anderson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000015",
    },
    {
        "school": "Norris Elementary",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000018",
    },
    {
        "school": "Norris Middle School",
        "district": "Anderson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000019",
    },
    {
        "school": "Norwood Elementary",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000020",
    },
    {
        "school": "Norwood Middle School",
        "district": "Anderson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009000021",
    },
    {
        "school": "Anderson County High School",
        "district": "Anderson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009001871",
    },
    {
        "school": "Grand Oaks Elementary",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009002002",
    },
    {
        "school": "Clinton Elementary",
        "district": "Clinton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470072000271",
    },
    {
        "school": "North Clinton Elementary",
        "district": "Clinton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470072000272",
    },
    {
        "school": "South Clinton Elementary",
        "district": "Clinton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470072001949",
    },
    {
        "school": "Glenwood Elementary",
        "district": "Oak Ridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470324001393",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Oak Ridge",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470324001394",
    },
    {
        "school": "Linden Elementary",
        "district": "Oak Ridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470324001395",
    },
    {
        "school": "Oak Ridge High School",
        "district": "Oak Ridge",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470324001396",
    },
    {
        "school": "Robertsville Middle School",
        "district": "Oak Ridge",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470324001397",
    },
    {
        "school": "Willow Brook Elementary",
        "district": "Oak Ridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470324001398",
    },
    {
        "school": "Woodland Elementary",
        "district": "Oak Ridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470324001399",
    },
    {
        "school": "Preschool",
        "district": "Oak Ridge",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470324001963",
    },
    {
        "school": "Alcoa Elementary",
        "district": "Alcoa",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470006000234",
    },
    {
        "school": "Alcoa High School",
        "district": "Alcoa",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470006000235",
    },
    {
        "school": "Alcoa Middle School",
        "district": "Alcoa",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470006000236",
    },
    {
        "school": "Eagleton Middle School",
        "district": "Blount County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030000065",
    },
    {
        "school": "Fairview Elementary",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030000068",
    },
    {
        "school": "Friendsville Elementary",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030000070",
    },
    {
        "school": "Heritage High School",
        "district": "Blount County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030000072",
    },
    {
        "school": "Lanier Elementary",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030000074",
    },
    {
        "school": "Porter Elementary",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030000078",
    },
    {
        "school": "Rockford Elementary",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030000081",
    },
    {
        "school": "Townsend Elementary",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030000084",
    },
    {
        "school": "Walland Elementary School",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030000086",
    },
    {
        "school": "Heritage Middle School",
        "district": "Blount County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030001041",
    },
    {
        "school": "Carpenters Middle School",
        "district": "Blount County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030001387",
    },
    {
        "school": "Union Grove Middle School",
        "district": "Blount County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030001652",
    },
    {
        "school": "William Blount High School",
        "district": "Blount County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030001830",
    },
    {
        "school": "Middlesettlements",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030001873",
    },
    {
        "school": "Montvale Elementary",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030001916",
    },
    {
        "school": "Mary Blount Elementary",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030001991",
    },
    {
        "school": "Foothills Elementary",
        "district": "Maryville",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470270000360",
    },
    {
        "school": "John Sevier Elementary",
        "district": "Maryville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470270000957",
    },
    {
        "school": "Maryville High School",
        "district": "Maryville",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470270000958",
    },
    {
        "school": "Maryville Junior High School",
        "district": "Maryville",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470270000959",
    },
    {
        "school": "Sam Houston Elementary",
        "district": "Maryville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470270000960",
    },
    {
        "school": "Montgomery Ridge Intermediate School",
        "district": "Maryville",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470270001242",
    },
    {
        "school": "A L Lotts Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000076",
    },
    {
        "school": "Sam E. Hill Primary School",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000077",
    },
    {
        "school": "Richard Yoakley School",
        "district": "Knox County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470222000314",
    },
    {
        "school": "Dogwood Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000403",
    },
    {
        "school": "Fair Garden Family/Community Center",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470222000407",
    },
    {
        "school": "Christenberry Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000473",
    },
    {
        "school": "Adrian Burnett Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000717",
    },
    {
        "school": "Ball Camp Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000719",
    },
    {
        "school": "Blue Grass Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000720",
    },
    {
        "school": "Bonny Kate Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000721",
    },
    {
        "school": "Brickey McCloud Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000722",
    },
    {
        "school": "Carter Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000724",
    },
    {
        "school": "Carter High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000725",
    },
    {
        "school": "Carter Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000726",
    },
    {
        "school": "Cedar Bluff Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000728",
    },
    {
        "school": "Cedar Bluff Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000729",
    },
    {
        "school": "Corryton Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000730",
    },
    {
        "school": "South Doyle High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000732",
    },
    {
        "school": "South Doyle Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000733",
    },
    {
        "school": "Farragut High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000735",
    },
    {
        "school": "Farragut Intermediate",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000736",
    },
    {
        "school": "Farragut Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000737",
    },
    {
        "school": "Farragut Primary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000738",
    },
    {
        "school": "Gap Creek Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000739",
    },
    {
        "school": "Gibbs Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000740",
    },
    {
        "school": "Gibbs High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000741",
    },
    {
        "school": "Halls Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000742",
    },
    {
        "school": "Halls High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000743",
    },
    {
        "school": "Halls Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000744",
    },
    {
        "school": "Karns Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000747",
    },
    {
        "school": "Karns High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000748",
    },
    {
        "school": "Karns Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000749",
    },
    {
        "school": "Mt Olive Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000752",
    },
    {
        "school": "New Hopewell Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000753",
    },
    {
        "school": "Powell Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000754",
    },
    {
        "school": "Powell High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000755",
    },
    {
        "school": "Powell Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000756",
    },
    {
        "school": "Ritta Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000758",
    },
    {
        "school": "Sunnyview Primary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000761",
    },
    {
        "school": "Ft Sanders Education Development  Center",
        "district": "Knox County",
        "level": "Other",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470222000764",
    },
    {
        "school": "Austin East High/Magnet",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000767",
    },
    {
        "school": "Bearden Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000768",
    },
    {
        "school": "Bearden High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000769",
    },
    {
        "school": "Bearden Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000770",
    },
    {
        "school": "Beaumont Elementary/Magnet",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000772",
    },
    {
        "school": "Belle Morris Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000773",
    },
    {
        "school": "Central High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000775",
    },
    {
        "school": "Chilhowee Intermediate",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000776",
    },
    {
        "school": "Fountain City Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000782",
    },
    {
        "school": "Fulton High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000783",
    },
    {
        "school": "Green Magnet Math And Science Academy",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000785",
    },
    {
        "school": "Gresham Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000786",
    },
    {
        "school": "Holston Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000787",
    },
    {
        "school": "Inskip Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000788",
    },
    {
        "school": "Knox Adaptive Education Center",
        "district": "Knox County",
        "level": "Other",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470222000791",
    },
    {
        "school": "Lonsdale Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000793",
    },
    {
        "school": "Maynard Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000794",
    },
    {
        "school": "Mooreland Heights Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000796",
    },
    {
        "school": "Northwest Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000797",
    },
    {
        "school": "Norwood Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000798",
    },
    {
        "school": "Pleasant Ridge Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000803",
    },
    {
        "school": "Pond Gap Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000804",
    },
    {
        "school": "Ridgedale Alternative School",
        "district": "Knox County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470222000805",
    },
    {
        "school": "Rocky Hill Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000806",
    },
    {
        "school": "Sarah Moore Greene Magnet Technology Academy",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000809",
    },
    {
        "school": "Sequoyah Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000810",
    },
    {
        "school": "Shannondale Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000811",
    },
    {
        "school": "South Knox Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000814",
    },
    {
        "school": "Spring Hill Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000816",
    },
    {
        "school": "Sterchi Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000817",
    },
    {
        "school": "Vine Middle/Magnet",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000820",
    },
    {
        "school": "West Haven Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000821",
    },
    {
        "school": "West High School",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000822",
    },
    {
        "school": "West Hills Elementary",
        "district": "Knox County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000823",
    },
    {
        "school": "West View Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000824",
    },
    {
        "school": "Whittle Springs Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222000825",
    },
    {
        "school": "West Valley Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222001117",
    },
    {
        "school": "Hardin Valley Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222001328",
    },
    {
        "school": "Lincoln Park Technology and Trade Center",
        "district": "Knox County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222001464",
    },
    {
        "school": "Copper Ridge Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222001846",
    },
    {
        "school": "East Knox Elementary",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222001847",
    },
    {
        "school": "Lenoir City High School",
        "district": "Lenoir City",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470240000868",
    },
    {
        "school": "Lenoir City Intermediate/Middle School",
        "district": "Lenoir City",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470240000869",
    },
    {
        "school": "Lenoir City Elementary",
        "district": "Lenoir City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470240001955",
    },
    {
        "school": "Eaton Elementary",
        "district": "Loudon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470252000892",
    },
    {
        "school": "Ft Loudoun Middle School",
        "district": "Loudon County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470252000893",
    },
    {
        "school": "Greenback School",
        "district": "Loudon County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470252000896",
    },
    {
        "school": "Highland Park Elementary",
        "district": "Loudon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470252000897",
    },
    {
        "school": "Loudon Elementary",
        "district": "Loudon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470252000899",
    },
    {
        "school": "Loudon High School",
        "district": "Loudon County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470252000900",
    },
    {
        "school": "North Middle School",
        "district": "Loudon County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470252000903",
    },
    {
        "school": "Philadelphia Elementary",
        "district": "Loudon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470252000904",
    },
    {
        "school": "Steekee Elementary",
        "district": "Loudon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470252000905",
    },
    {
        "school": "Union County High School",
        "district": "Union County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470429000870",
    },
    {
        "school": "Union County Alternative Center",
        "district": "Union County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470429001362",
    },
    {
        "school": "Big Ridge Elementary",
        "district": "Union County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470429001731",
    },
    {
        "school": "H Maynard Middle School",
        "district": "Union County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470429001732",
    },
    {
        "school": "Luttrell Elementary",
        "district": "Union County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470429001733",
    },
    {
        "school": "Maynardville Elementary",
        "district": "Union County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470429001734",
    },
    {
        "school": "Sharps Chapel Elementary",
        "district": "Union County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470429001735",
    },
    {
        "school": "Campbell County Comprehensive High School",
        "district": "Campbell County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000117",
    },
    {
        "school": "Caryville Elementary",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000118",
    },
    {
        "school": "Elk Valley Elementary",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000121",
    },
    {
        "school": "Jacksboro Elementary",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000122",
    },
    {
        "school": "Jacksboro Middle School",
        "district": "Campbell County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000123",
    },
    {
        "school": "Jellico Elementary",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000124",
    },
    {
        "school": "Jellico High School",
        "district": "Campbell County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000125",
    },
    {
        "school": "Lafollette Middle School",
        "district": "Campbell County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000127",
    },
    {
        "school": "Valley View Elementary",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000135",
    },
    {
        "school": "White Oak Elementary",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000136",
    },
    {
        "school": "Wynn Habersham Elementary",
        "district": "Campbell County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000138",
    },
    {
        "school": "Campbell Co Adult High School",
        "district": "Campbell County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042000886",
    },
    {
        "school": "David Crockett Elementary",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000841",
    },
    {
        "school": "E O Coffman Middle School",
        "district": "Lawrence County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000842",
    },
    {
        "school": "Ethridge Elementary",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000843",
    },
    {
        "school": "Ingram Sowell Elementary",
        "district": "Lawrence County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000845",
    },
    {
        "school": "Lawrence Co High School",
        "district": "Lawrence County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000847",
    },
    {
        "school": "Lawrenceburg Public",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000849",
    },
    {
        "school": "South Lawrence Elementary",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000852",
    },
    {
        "school": "Loretto High School",
        "district": "Lawrence County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000853",
    },
    {
        "school": "New Prospect Elementary",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000854",
    },
    {
        "school": "Summertown Elementary",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000858",
    },
    {
        "school": "Summertown High School",
        "district": "Lawrence County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000859",
    },
    {
        "school": "Lawrence County Adult High School",
        "district": "Lawrence County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234000942",
    },
    {
        "school": "Leoma Elementary",
        "district": "Lawrence County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470234001940",
    },
    {
        "school": "Hickory Creek School",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470435000204",
    },
    {
        "school": "Bobby Ray Memorial",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470435000422",
    },
    {
        "school": "Centertown Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470435001740",
    },
    {
        "school": "Dibrell Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470435001741",
    },
    {
        "school": "Eastside Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470435001742",
    },
    {
        "school": "Irving College Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470435001744",
    },
    {
        "school": "Morrison Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470435001745",
    },
    {
        "school": "Warren County Middle School",
        "district": "Warren County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470435001748",
    },
    {
        "school": "Warren County High School",
        "district": "Warren County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470435001749",
    },
    {
        "school": "West Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470435001750",
    },
    {
        "school": "West Junior High School",
        "district": "Fayette County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470117001752",
    },
    {
        "school": "Covington Integrated Arts Academy",
        "district": "Tipton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408002049",
    },
    {
        "school": "Austin Peay Elementary School",
        "district": "Tipton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408002094",
    },
    {
        "school": "Oakland Elementary",
        "district": "Fayette County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470117000366",
    },
    {
        "school": "Southwest Elementary",
        "district": "Fayette County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470117000369",
    },
    {
        "school": "East Jr. High School",
        "district": "Fayette County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470117001411",
    },
    {
        "school": "Fayette Ware Comprehensive High School",
        "district": "Fayette County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470117001921",
    },
    {
        "school": "La Grange Moscow Elementary",
        "district": "Fayette County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470117001994",
    },
    {
        "school": "Crestview Middle School",
        "district": "Tipton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408000043",
    },
    {
        "school": "Munford Middle School",
        "district": "Tipton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408000046",
    },
    {
        "school": "Brighton High School",
        "district": "Tipton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408000505",
    },
    {
        "school": "Brighton Middle School",
        "district": "Tipton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408001228",
    },
    {
        "school": "Brighton Elementary",
        "district": "Tipton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408001689",
    },
    {
        "school": "Covington High School",
        "district": "Tipton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408001692",
    },
    {
        "school": "Drummonds Elementary",
        "district": "Tipton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408001693",
    },
    {
        "school": "Munford Elementary",
        "district": "Tipton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408001699",
    },
    {
        "school": "Munford High School",
        "district": "Tipton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408001700",
    },
    {
        "school": "Crestview Elementary",
        "district": "Tipton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408001892",
    },
    {
        "school": "Jefferson County Adult High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210002105",
    },
    {
        "school": "Bean Station Elementary",
        "district": "Grainger County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470144000434",
    },
    {
        "school": "Joppa Elementary",
        "district": "Grainger County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470144000435",
    },
    {
        "school": "Rutledge Elementary School",
        "district": "Grainger County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470144000436",
    },
    {
        "school": "Grainger High School",
        "district": "Grainger County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470144000437",
    },
    {
        "school": "Washburn School",
        "district": "Grainger County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470144000440",
    },
    {
        "school": "Grainger Co Adult High",
        "district": "Grainger County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470144000607",
    },
    {
        "school": "Alpha Elementary",
        "district": "Hamblen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000100477",
    },
    {
        "school": "East Ridge Middle School",
        "district": "Hamblen County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000100479",
    },
    {
        "school": "Fairview Marguerite",
        "district": "Hamblen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000100480",
    },
    {
        "school": "Manley Elementary",
        "district": "Hamblen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000100481",
    },
    {
        "school": "Russellville Elementary",
        "district": "Hamblen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000100483",
    },
    {
        "school": "Union Heights Elementary",
        "district": "Hamblen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000100485",
    },
    {
        "school": "Whitesburg Elementary",
        "district": "Hamblen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000100487",
    },
    {
        "school": "Witt Elementary",
        "district": "Hamblen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000100488",
    },
    {
        "school": "Hamblen County Alternative School",
        "district": "Hamblen County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470000101268",
    },
    {
        "school": "West View Middle School",
        "district": "Hamblen County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000101271",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Hamblen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000101929",
    },
    {
        "school": "John Hay Elementary",
        "district": "Hamblen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000101930",
    },
    {
        "school": "Lincoln Heights Elementary",
        "district": "Hamblen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000101931",
    },
    {
        "school": "Lincoln Heights Middle School",
        "district": "Hamblen County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000101933",
    },
    {
        "school": "Meadowview Middle School",
        "district": "Hamblen County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000101934",
    },
    {
        "school": "Morristown East High",
        "district": "Hamblen County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000101935",
    },
    {
        "school": "Morristown West High",
        "district": "Hamblen County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000101936",
    },
    {
        "school": "West Elementary",
        "district": "Hamblen County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470000101937",
    },
    {
        "school": "Dandridge Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210000671",
    },
    {
        "school": "Jefferson Co High School",
        "district": "Jefferson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210000675",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210000676",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210000677",
    },
    {
        "school": "Maury Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210000681",
    },
    {
        "school": "New Market Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210000682",
    },
    {
        "school": "Piedmont Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210000684",
    },
    {
        "school": "Rush Strong Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210000685",
    },
    {
        "school": "Talbott Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210000689",
    },
    {
        "school": "White Pine Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210000693",
    },
    {
        "school": "East Hickman High School",
        "district": "Hickman County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470186002104",
    },
    {
        "school": "Croft Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001695",
    },
    {
        "school": "Haynes Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001696",
    },
    {
        "school": "Head Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001697",
    },
    {
        "school": "Hickman Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001698",
    },
    {
        "school": "John Early Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001701",
    },
    {
        "school": "Jones Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001702",
    },
    {
        "school": "Stanford Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001707",
    },
    {
        "school": "Lockeland Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001755",
    },
    {
        "school": "Nashville School Of The Arts",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001815",
    },
    {
        "school": "Smithson Craighead Academy",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001941",
    },
    {
        "school": "Thomas A. Edison Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002053",
    },
    {
        "school": "Glendale Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002054",
    },
    {
        "school": "William Henry Oliver Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002058",
    },
    {
        "school": "May Werthan Shayne Elementary School",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002059",
    },
    {
        "school": "Warner Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002060",
    },
    {
        "school": "Middle College High",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002101",
    },
    {
        "school": "Ruby Major Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002102",
    },
    {
        "school": "KIPP Academy Nashville",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002103",
    },
    {
        "school": "Creek Wood High School",
        "district": "Dickson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102001727",
    },
    {
        "school": "Dickson County Adult High School",
        "district": "Dickson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102002061",
    },
    {
        "school": "Coopertown Middle School",
        "district": "Robertson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360002071",
    },
    {
        "school": "Scales Elementary School",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315002073",
    },
    {
        "school": "Blackman Middle School",
        "district": "Rutherford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001904",
    },
    {
        "school": "Rock Springs Middle School",
        "district": "Rutherford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001906",
    },
    {
        "school": "Christiana Middle School",
        "district": "Rutherford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002037",
    },
    {
        "school": "Siegel High School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002038",
    },
    {
        "school": "LaVergne Middle School",
        "district": "Rutherford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002072",
    },
    {
        "school": "Smith County Middle School",
        "district": "Smith County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470387001942",
    },
    {
        "school": "Gordonsville High School",
        "district": "Smith County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470387002047",
    },
    {
        "school": "Station Camp High School",
        "district": "Sumner County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001943",
    },
    {
        "school": "Benny C. Bills Elementary School",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001944",
    },
    {
        "school": "Harold B. Williams Elementary School",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001945",
    },
    {
        "school": "Station Camp Middle School",
        "district": "Sumner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402002048",
    },
    {
        "school": "Ravenwood High School",
        "district": "Williamson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001946",
    },
    {
        "school": "Winstead Elementary School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002027",
    },
    {
        "school": "Chapman's Retreat Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002050",
    },
    {
        "school": "Independence High School",
        "district": "Williamson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002096",
    },
    {
        "school": "Sunset Elementary School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002097",
    },
    {
        "school": "Sunset Middle School",
        "district": "Williamson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002098",
    },
    {
        "school": "Auburn Elementary",
        "district": "Cannon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470045000139",
    },
    {
        "school": "Cannon County High School",
        "district": "Cannon County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470045000140",
    },
    {
        "school": "East Side Elementary",
        "district": "Cannon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470045000141",
    },
    {
        "school": "Short Mountain Elementary",
        "district": "Cannon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470045000142",
    },
    {
        "school": "West Side Elementary",
        "district": "Cannon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470045000143",
    },
    {
        "school": "Woodbury Grammar",
        "district": "Cannon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470045000144",
    },
    {
        "school": "Woodland Elementary",
        "district": "Cannon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470045000145",
    },
    {
        "school": "East Hickman Middle School",
        "district": "Hickman County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470186000024",
    },
    {
        "school": "Centerville Elementary",
        "district": "Hickman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470186000621",
    },
    {
        "school": "East Hickman Elementary",
        "district": "Hickman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470186000622",
    },
    {
        "school": "Hickman Co Middle School",
        "district": "Hickman County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470186000623",
    },
    {
        "school": "Hickman Co Sr High School",
        "district": "Hickman County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470186000625",
    },
    {
        "school": "Centerville Intermediate School",
        "district": "Hickman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470186001295",
    },
    {
        "school": "East Hickman Intermediate School",
        "district": "Hickman County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470186001296",
    },
    {
        "school": "Macon County High School",
        "district": "Macon County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470255000839",
    },
    {
        "school": "Central Elementary",
        "district": "Macon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470255000906",
    },
    {
        "school": "Fairlane Elementary",
        "district": "Macon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470255000908",
    },
    {
        "school": "Macon County Junior High School",
        "district": "Macon County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470255000910",
    },
    {
        "school": "Red Boiling Springs School",
        "district": "Macon County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470255000912",
    },
    {
        "school": "Westside Elementary",
        "district": "Macon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470255000913",
    },
    {
        "school": "Lafayette Elementary School",
        "district": "Macon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470255002024",
    },
    {
        "school": "Carthage Elementary",
        "district": "Smith County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470387001596",
    },
    {
        "school": "Defeated Elementary",
        "district": "Smith County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470387001598",
    },
    {
        "school": "Forks River Elementary",
        "district": "Smith County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470387001599",
    },
    {
        "school": "Gordonsville Elementary School",
        "district": "Smith County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470387001601",
    },
    {
        "school": "New Middleton Elementary",
        "district": "Smith County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470387001602",
    },
    {
        "school": "Smith County High School",
        "district": "Smith County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470387001604",
    },
    {
        "school": "Union Heights Elementary",
        "district": "Smith County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470387001607",
    },
    {
        "school": "Jim Satterfield Middle School",
        "district": "Trousdale County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470417000508",
    },
    {
        "school": "Trousdale Co Elementary",
        "district": "Trousdale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470417001708",
    },
    {
        "school": "Trousdale Co High School",
        "district": "Trousdale County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470417001709",
    },
    {
        "school": "Ida B. Wells Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001269",
    },
    {
        "school": "Ashland City Elementary",
        "district": "Cheatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057000227",
    },
    {
        "school": "Cheatham Co Central",
        "district": "Cheatham County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057000228",
    },
    {
        "school": "East Cheatham Elementary",
        "district": "Cheatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057000229",
    },
    {
        "school": "Kingston Springs Elementary",
        "district": "Cheatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057000230",
    },
    {
        "school": "Pegram Elementary Fine Arts Magnet School",
        "district": "Cheatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057000231",
    },
    {
        "school": "Pleasant View Elementary",
        "district": "Cheatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057000232",
    },
    {
        "school": "West Cheatham Elementary",
        "district": "Cheatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057000233",
    },
    {
        "school": "Sycamore Middle School",
        "district": "Cheatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057000361",
    },
    {
        "school": "Cheatham Middle School",
        "district": "Cheatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057000888",
    },
    {
        "school": "Harpeth Middle School",
        "district": "Cheatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057000890",
    },
    {
        "school": "Harpeth High School",
        "district": "Cheatham County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057000891",
    },
    {
        "school": "Sycamore High School",
        "district": "Cheatham County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057001834",
    },
    {
        "school": "W.A. Bass Alternative Learning Center",
        "district": "Davidson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470318000299",
    },
    {
        "school": "Hull-Jackson Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318000461",
    },
    {
        "school": "Cora Howe School",
        "district": "Davidson County",
        "level": "Other",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470318000462",
    },
    {
        "school": "East Nashville Magnet High School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318000592",
    },
    {
        "school": "Antioch Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001052",
    },
    {
        "school": "Mt. View Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001062",
    },
    {
        "school": "Donelson Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001243",
    },
    {
        "school": "Alex Green Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001254",
    },
    {
        "school": "Amqui Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001255",
    },
    {
        "school": "Andrew Jackson Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001256",
    },
    {
        "school": "Antioch High School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001257",
    },
    {
        "school": "Apollo Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001258",
    },
    {
        "school": "Moses McKissack Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001260",
    },
    {
        "school": "Bellevue Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001261",
    },
    {
        "school": "Bellshire Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001262",
    },
    {
        "school": "Buena Vista Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001267",
    },
    {
        "school": "Chadwell Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001273",
    },
    {
        "school": "Charlotte Park Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001274",
    },
    {
        "school": "Cockrill Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001275",
    },
    {
        "school": "Cole Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001277",
    },
    {
        "school": "Hattie Cotton Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001279",
    },
    {
        "school": "Crieve Hall Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001280",
    },
    {
        "school": "Cumberland Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001281",
    },
    {
        "school": "Dan Mills Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001283",
    },
    {
        "school": "Dodson Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001284",
    },
    {
        "school": "DuPont Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001287",
    },
    {
        "school": "DuPont Tyler Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001288",
    },
    {
        "school": "DuPont Hadley Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001289",
    },
    {
        "school": "Eakin Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001290",
    },
    {
        "school": "Fall-Hamilton Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001294",
    },
    {
        "school": "Gateway Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001297",
    },
    {
        "school": "Glencliff Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001298",
    },
    {
        "school": "Glencliff High School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001299",
    },
    {
        "school": "Glengarry Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001301",
    },
    {
        "school": "Glenview Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001303",
    },
    {
        "school": "Goodlettsville Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001304",
    },
    {
        "school": "Goodlettsville Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001305",
    },
    {
        "school": "Gower Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001306",
    },
    {
        "school": "Gra-Mar Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001307",
    },
    {
        "school": "Granbery Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001308",
    },
    {
        "school": "H. G. Hill Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001309",
    },
    {
        "school": "Harpeth Valley Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001310",
    },
    {
        "school": "Harris-Hillman Special Education",
        "district": "Davidson County",
        "level": "Other",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470318001311",
    },
    {
        "school": "Haywood Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001313",
    },
    {
        "school": "Hermitage Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001315",
    },
    {
        "school": "Meigs Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001317",
    },
    {
        "school": "Hillsboro High",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001318",
    },
    {
        "school": "Hillwood High",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001319",
    },
    {
        "school": "Hume - Fogg High",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001320",
    },
    {
        "school": "Inglewood Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001321",
    },
    {
        "school": "Isaac Litton Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001322",
    },
    {
        "school": "Jere Baxter Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001323",
    },
    {
        "school": "Joelton Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001324",
    },
    {
        "school": "Joelton Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001325",
    },
    {
        "school": "John B. Whitsitt Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001326",
    },
    {
        "school": "John Overton High",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001327",
    },
    {
        "school": "Julia Green Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001331",
    },
    {
        "school": "Robert E. Lillard Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001332",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001334",
    },
    {
        "school": "Maplewood High",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001337",
    },
    {
        "school": "Margaret Allen Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001338",
    },
    {
        "school": "McGavock Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001341",
    },
    {
        "school": "McGavock High",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001342",
    },
    {
        "school": "McMurray Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001344",
    },
    {
        "school": "John Trotwood Moore Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001346",
    },
    {
        "school": "Napier Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001350",
    },
    {
        "school": "Neely's Bend Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001351",
    },
    {
        "school": "Norman Binkley Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001353",
    },
    {
        "school": "Old Center Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001355",
    },
    {
        "school": "Paragon Mills Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001356",
    },
    {
        "school": "Park Avenue Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001357",
    },
    {
        "school": "Pennington Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001360",
    },
    {
        "school": "Percy Priest Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001361",
    },
    {
        "school": "Rose Park Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001365",
    },
    {
        "school": "Rosebank Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001366",
    },
    {
        "school": "Shwab Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001368",
    },
    {
        "school": "Stratford STEM Magnet School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001370",
    },
    {
        "school": "Stratton Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001371",
    },
    {
        "school": "Sylvan Park Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001372",
    },
    {
        "school": "Tom Joy Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001373",
    },
    {
        "school": "Tusculum Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001374",
    },
    {
        "school": "Two Rivers Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001375",
    },
    {
        "school": "Una Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001376",
    },
    {
        "school": "Carter-Lawrence Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001379",
    },
    {
        "school": "West End Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001382",
    },
    {
        "school": "Westmeade Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001383",
    },
    {
        "school": "Isaiah T. Creswell Middle School of the Arts",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001384",
    },
    {
        "school": "Whites Creek High",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001386",
    },
    {
        "school": "Wright Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001389",
    },
    {
        "school": "Henry C. Maxwell Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001651",
    },
    {
        "school": "Pearl-Cohn High",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001924",
    },
    {
        "school": "Hunters Lane High",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001961",
    },
    {
        "school": "Martin Luther King Jr School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001962",
    },
    {
        "school": "J. E. Moss Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001986",
    },
    {
        "school": "Tulip Grove Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318001999",
    },
    {
        "school": "Murrell at Glenn School",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470318002013",
    },
    {
        "school": "Renaissance High School",
        "district": "Williamson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001031",
    },
    {
        "school": "Stuart Burns Elementary",
        "district": "Dickson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102000326",
    },
    {
        "school": "New Directions Academy",
        "district": "Dickson County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102000327",
    },
    {
        "school": "Charlotte Middle School",
        "district": "Dickson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102000328",
    },
    {
        "school": "Dickson County High School",
        "district": "Dickson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102000329",
    },
    {
        "school": "Dickson Elementary",
        "district": "Dickson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102000330",
    },
    {
        "school": "Dickson Middle School",
        "district": "Dickson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102000331",
    },
    {
        "school": "Oakmont Elementary",
        "district": "Dickson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102000332",
    },
    {
        "school": "Vanleer Elementary",
        "district": "Dickson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102000334",
    },
    {
        "school": "White Bluff Elementary",
        "district": "Dickson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102000335",
    },
    {
        "school": "W James Middle School",
        "district": "Dickson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102000336",
    },
    {
        "school": "Charlotte Elementary",
        "district": "Dickson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102001073",
    },
    {
        "school": "Centennial Elementary",
        "district": "Dickson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102001094",
    },
    {
        "school": "The Discovery School",
        "district": "Dickson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102001102",
    },
    {
        "school": "East Robertson High School",
        "district": "Robertson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360000032",
    },
    {
        "school": "Robert F. Woodall Elementary",
        "district": "Robertson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360000109",
    },
    {
        "school": "Bransford Elementary",
        "district": "Robertson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001491",
    },
    {
        "school": "Cheatham Park Elementary",
        "district": "Robertson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001492",
    },
    {
        "school": "Coopertown Elementary",
        "district": "Robertson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001493",
    },
    {
        "school": "Greenbrier Elementary",
        "district": "Robertson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001496",
    },
    {
        "school": "Greenbrier High School",
        "district": "Robertson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001497",
    },
    {
        "school": "Greenbrier Middle School",
        "district": "Robertson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001498",
    },
    {
        "school": "Jo Byrns High School",
        "district": "Robertson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001500",
    },
    {
        "school": "Krisle Elementary",
        "district": "Robertson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001501",
    },
    {
        "school": "Springfield High School",
        "district": "Robertson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001503",
    },
    {
        "school": "Springfield Middle School",
        "district": "Robertson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001504",
    },
    {
        "school": "Watauga Elementary",
        "district": "Robertson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001505",
    },
    {
        "school": "Westside Elementary",
        "district": "Robertson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001506",
    },
    {
        "school": "White House Heritage High School",
        "district": "Robertson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360001507",
    },
    {
        "school": "East Robertson Elementary",
        "district": "Robertson County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360002015",
    },
    {
        "school": "Erma Siegel Elementary",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315000966",
    },
    {
        "school": "Discovery School",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315001248",
    },
    {
        "school": "Bradley Academy - An Arts Integrated School",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315001249",
    },
    {
        "school": "Hobgood Elementary",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315001250",
    },
    {
        "school": "Mitchell-Neilson Elementary",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315001251",
    },
    {
        "school": "John Pittard Elementary",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315001253",
    },
    {
        "school": "Northfield Elementary",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315001975",
    },
    {
        "school": "Black Fox Elementary",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315002012",
    },
    {
        "school": "Stewartsboro Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369000115",
    },
    {
        "school": "Rutherford County Adult High School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369000370",
    },
    {
        "school": "Cedar Grove Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369000855",
    },
    {
        "school": "Barfield Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369000955",
    },
    {
        "school": "Rock Springs Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369000963",
    },
    {
        "school": "Blackman High School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001354",
    },
    {
        "school": "Blackman Elementary School",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001502",
    },
    {
        "school": "Buchanan Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001509",
    },
    {
        "school": "Christiana Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001511",
    },
    {
        "school": "John Colemon Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001512",
    },
    {
        "school": "Daniel McKee Alternative School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470369001513",
    },
    {
        "school": "David Youree Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001514",
    },
    {
        "school": "Eagleville School",
        "district": "Rutherford County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001516",
    },
    {
        "school": "Holloway High School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001517",
    },
    {
        "school": "Kittrell Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001518",
    },
    {
        "school": "Lascassas Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001519",
    },
    {
        "school": "Lavergne Primary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001520",
    },
    {
        "school": "Homer Pittard Campus School",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001521",
    },
    {
        "school": "McFadden School Of Excellence",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001522",
    },
    {
        "school": "Oakland High School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001523",
    },
    {
        "school": "Riverdale High School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001524",
    },
    {
        "school": "Rockvale Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001525",
    },
    {
        "school": "Roy L Waldron Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001526",
    },
    {
        "school": "Smyrna West Alternative School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470369001528",
    },
    {
        "school": "Smyrna Middle School",
        "district": "Rutherford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001529",
    },
    {
        "school": "Smyrna Primary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001530",
    },
    {
        "school": "Thurman Francis Arts Academy/Magnet School for the Arts",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001531",
    },
    {
        "school": "Walter Hill Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001532",
    },
    {
        "school": "Siegel Middle School",
        "district": "Rutherford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001534",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001537",
    },
    {
        "school": "Smyrna Elementary",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001889",
    },
    {
        "school": "Lavergne High School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001987",
    },
    {
        "school": "Smyrna High School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369001988",
    },
    {
        "school": "Robert E Ellis Middle",
        "district": "Sumner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402000408",
    },
    {
        "school": "E B Wilson",
        "district": "Sumner County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402000863",
    },
    {
        "school": "J W Wiseman Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402000975",
    },
    {
        "school": "Madison Creek Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402000978",
    },
    {
        "school": "Jack Anderson Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001179",
    },
    {
        "school": "Joe Shafer Middle School",
        "district": "Sumner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001213",
    },
    {
        "school": "Vena Stuart Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001215",
    },
    {
        "school": "R T Fisher Alternative",
        "district": "Sumner County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470402001225",
    },
    {
        "school": "Beech Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001656",
    },
    {
        "school": "Bethpage Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001657",
    },
    {
        "school": "Gallatin Senior High School",
        "district": "Sumner County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001659",
    },
    {
        "school": "Guild Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001660",
    },
    {
        "school": "Gene W. Brown Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001661",
    },
    {
        "school": "Hendersonville High School",
        "district": "Sumner County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001662",
    },
    {
        "school": "Howard Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001663",
    },
    {
        "school": "T. W. Hunter Middle School",
        "district": "Sumner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001664",
    },
    {
        "school": "Merrol Hyde Magnet School",
        "district": "Sumner County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001665",
    },
    {
        "school": "Lakeside Park Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001666",
    },
    {
        "school": "Millersville Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001667",
    },
    {
        "school": "Nannie Berry Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001668",
    },
    {
        "school": "North Sumner Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001670",
    },
    {
        "school": "Oakmont Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001671",
    },
    {
        "school": "Portland High School",
        "district": "Sumner County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001672",
    },
    {
        "school": "Portland East Middle School",
        "district": "Sumner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001673",
    },
    {
        "school": "Clyde Riggs Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001674",
    },
    {
        "school": "Union Elementary School",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001676",
    },
    {
        "school": "Rucker Stewart Middle",
        "district": "Sumner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001677",
    },
    {
        "school": "V G Hawkins Middle School",
        "district": "Sumner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001678",
    },
    {
        "school": "Walton Ferry Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001680",
    },
    {
        "school": "George A Whitten Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001681",
    },
    {
        "school": "Westmoreland Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001682",
    },
    {
        "school": "Westmoreland High School",
        "district": "Sumner County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001683",
    },
    {
        "school": "White House High School",
        "district": "Sumner County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001684",
    },
    {
        "school": "White House Middle School",
        "district": "Sumner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001685",
    },
    {
        "school": "Indian Lake Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001864",
    },
    {
        "school": "Watt Hardison Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001865",
    },
    {
        "school": "Beech Sr High School",
        "district": "Sumner County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001891",
    },
    {
        "school": "Westmoreland Middle School",
        "district": "Sumner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402001989",
    },
    {
        "school": "Freedom Middle School",
        "district": "Franklin SSD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470126000219",
    },
    {
        "school": "Franklin Elementary",
        "district": "Franklin SSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470126000390",
    },
    {
        "school": "Johnson Elementary",
        "district": "Franklin SSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470126000396",
    },
    {
        "school": "Freedom Intermediate",
        "district": "Franklin SSD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470126000414",
    },
    {
        "school": "Poplar Grove K-4",
        "district": "Franklin SSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470126001381",
    },
    {
        "school": "Poplar Grove 5-8",
        "district": "Franklin SSD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470126001385",
    },
    {
        "school": "Liberty Elementary",
        "district": "Franklin SSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470126001951",
    },
    {
        "school": "Moore Elementary",
        "district": "Franklin SSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470126002003",
    },
    {
        "school": "Oak View Elem School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453000215",
    },
    {
        "school": "Edmondson Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453000443",
    },
    {
        "school": "Hunters Bend Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453000456",
    },
    {
        "school": "Centennial High School",
        "district": "Williamson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453000511",
    },
    {
        "school": "Heritage Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001239",
    },
    {
        "school": "Kenrose Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001240",
    },
    {
        "school": "Heritage Middle School",
        "district": "Williamson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001364",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001369",
    },
    {
        "school": "Bethesda Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001801",
    },
    {
        "school": "College Grove Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001802",
    },
    {
        "school": "Fairview Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001803",
    },
    {
        "school": "Fairview High School",
        "district": "Williamson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001804",
    },
    {
        "school": "Franklin High School",
        "district": "Williamson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001805",
    },
    {
        "school": "Fred J Page High School",
        "district": "Williamson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001806",
    },
    {
        "school": "Grassland Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001807",
    },
    {
        "school": "Hillsboro Elementary/ Middle School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001808",
    },
    {
        "school": "Lipscomb Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001810",
    },
    {
        "school": "Nolensville Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001811",
    },
    {
        "school": "Brentwood Middle School",
        "district": "Williamson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001812",
    },
    {
        "school": "Trinity Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001814",
    },
    {
        "school": "Scales Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001867",
    },
    {
        "school": "Brentwood High School",
        "district": "Williamson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001894",
    },
    {
        "school": "Fairview Middle School",
        "district": "Williamson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001895",
    },
    {
        "school": "Fred J Page Middle School",
        "district": "Williamson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001896",
    },
    {
        "school": "Grassland Middle School",
        "district": "Williamson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453001969",
    },
    {
        "school": "Crockett Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002020",
    },
    {
        "school": "Walnut Grove Elementary",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002021",
    },
    {
        "school": "Castle Heights Elementary",
        "district": "Lebanon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470237000532",
    },
    {
        "school": "Byars Dowdy Elementary",
        "district": "Lebanon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470237000862",
    },
    {
        "school": "Sam Houston Elementary",
        "district": "Lebanon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470237000866",
    },
    {
        "school": "Walter J. Baird Middle School",
        "district": "Lebanon",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470237000867",
    },
    {
        "school": "Coles Ferry Elementary",
        "district": "Lebanon",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470237001998",
    },
    {
        "school": "W A Wright Elementary",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455000054",
    },
    {
        "school": "Rutland Elementary",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001241",
    },
    {
        "school": "Mt. Juliet Middle School",
        "district": "Wilson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001636",
    },
    {
        "school": "Wilson Central High School",
        "district": "Wilson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001641",
    },
    {
        "school": "Watertown Elementary",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001766",
    },
    {
        "school": "Carroll Oakland Elementary",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001816",
    },
    {
        "school": "Gladeville Elementary",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001817",
    },
    {
        "school": "Lakeview Elementary School",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001818",
    },
    {
        "school": "Lebanon High School",
        "district": "Wilson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001819",
    },
    {
        "school": "Mt. Juliet High School",
        "district": "Wilson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001820",
    },
    {
        "school": "Mt. Juliet Elementary",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001821",
    },
    {
        "school": "West Wilson Middle School",
        "district": "Wilson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001822",
    },
    {
        "school": "Southside Elementary",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001823",
    },
    {
        "school": "Tuckers Crossroads Elementary",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001824",
    },
    {
        "school": "Watertown High School",
        "district": "Wilson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001825",
    },
    {
        "school": "West Elementary",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001826",
    },
    {
        "school": "Stoner Creek Elementary",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455001981",
    },
    {
        "school": "Bridgeport Elementary",
        "district": "Cocke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075000273",
    },
    {
        "school": "Centerview Elementary",
        "district": "Cocke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075000274",
    },
    {
        "school": "Cocke Co High School",
        "district": "Cocke County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075000275",
    },
    {
        "school": "Cosby Elementary",
        "district": "Cocke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075000277",
    },
    {
        "school": "Del Rio Elementary",
        "district": "Cocke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075000278",
    },
    {
        "school": "Edgemont Elementary",
        "district": "Cocke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075000279",
    },
    {
        "school": "Grassy Fork Elementary",
        "district": "Cocke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075000280",
    },
    {
        "school": "Northwest Elementary",
        "district": "Cocke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075000282",
    },
    {
        "school": "Parrottsville Elementary",
        "district": "Cocke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075000283",
    },
    {
        "school": "Smoky Mountain Elementary",
        "district": "Cocke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075000284",
    },
    {
        "school": "Cocke Co Adult High School",
        "district": "Cocke County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075000297",
    },
    {
        "school": "Cosby High School",
        "district": "Cocke County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470075001392",
    },
    {
        "school": "Newport Grammar School",
        "district": "Newport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470321001390",
    },
    {
        "school": "Dorothy And Noble Harrelson School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470183002063",
    },
    {
        "school": "Lakewood Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470183002064",
    },
    {
        "school": "Lakewood Elementary",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470183000466",
    },
    {
        "school": "E. W. Grove School",
        "district": "Henry County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470183000615",
    },
    {
        "school": "Henry Elementary",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470183000616",
    },
    {
        "school": "Henry Co High School",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470183000617",
    },
    {
        "school": "Paris Elementary",
        "district": "Paris",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470336001110",
    },
    {
        "school": "W G Rhea Elementary",
        "district": "Paris",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470336001428",
    },
    {
        "school": "W O Inman Middle School",
        "district": "Paris",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470336001429",
    },
    {
        "school": "Boyds Creek Elementary School",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378002074",
    },
    {
        "school": "Northview Intermediate School",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378000968",
    },
    {
        "school": "Seymour Intermediate",
        "district": "Sevier County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378000971",
    },
    {
        "school": "Parkway Academy",
        "district": "Sevier County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470378001131",
    },
    {
        "school": "Pigeon Forge High School",
        "district": "Sevier County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001133",
    },
    {
        "school": "Catons Chapel Elementary",
        "district": "Sevier County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001548",
    },
    {
        "school": "Gatlinburg Pittman High",
        "district": "Sevier County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001549",
    },
    {
        "school": "Jones Cove Elementary",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001550",
    },
    {
        "school": "New Center Elementary",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001551",
    },
    {
        "school": "Northview Elementary",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001552",
    },
    {
        "school": "Pi Beta Phi Elementary",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001554",
    },
    {
        "school": "Pigeon Forge Middle School",
        "district": "Sevier County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001555",
    },
    {
        "school": "Pittman Center Elementary",
        "district": "Sevier County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001556",
    },
    {
        "school": "Sevier County High School",
        "district": "Sevier County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001557",
    },
    {
        "school": "Sevierville Primary",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001559",
    },
    {
        "school": "Sevierville Middle School",
        "district": "Sevier County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001560",
    },
    {
        "school": "Seymour Primary",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001561",
    },
    {
        "school": "Seymour High School",
        "district": "Sevier County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001562",
    },
    {
        "school": "T Lawson Early Childhood Education Center",
        "district": "Sevier County",
        "level": "Other",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470378001563",
    },
    {
        "school": "Wearwood Elementary",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001564",
    },
    {
        "school": "Pigeon Forge Primary",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001966",
    },
    {
        "school": "Seymour Junior High",
        "district": "Sevier County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378001967",
    },
    {
        "school": "Sevierville Intermediate",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378002016",
    },
    {
        "school": "Cascade High School",
        "district": "Bedford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018000034",
    },
    {
        "school": "Eakin Elementary",
        "district": "Bedford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018000035",
    },
    {
        "school": "Shelbyville Central High School",
        "district": "Bedford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018000036",
    },
    {
        "school": "Harris Middle School",
        "district": "Bedford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018000037",
    },
    {
        "school": "Community High School",
        "district": "Bedford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018000039",
    },
    {
        "school": "East Side Elementary",
        "district": "Bedford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018000040",
    },
    {
        "school": "Thomas Magnet Elementary School",
        "district": "Bedford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018000041",
    },
    {
        "school": "Liberty Elementary",
        "district": "Bedford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018000042",
    },
    {
        "school": "South Side Elementary",
        "district": "Bedford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018000044",
    },
    {
        "school": "Cascade Elementary",
        "district": "Bedford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018000578",
    },
    {
        "school": "Community Elementary School",
        "district": "Bedford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018000582",
    },
    {
        "school": "Coffee County Central High School",
        "district": "Coffee County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470078000285",
    },
    {
        "school": "Coffee County Middle School",
        "district": "Coffee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470078000286",
    },
    {
        "school": "East Coffee Elementary",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470078000287",
    },
    {
        "school": "Hickerson Elementary",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470078000288",
    },
    {
        "school": "Hillsboro Elementary",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470078000289",
    },
    {
        "school": "New Union Elementary",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470078000291",
    },
    {
        "school": "North Coffee Elementary",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470078000292",
    },
    {
        "school": "Coffee County Koss Center",
        "district": "Coffee County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470078000298",
    },
    {
        "school": "College Street Elementary",
        "district": "Manchester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470261000929",
    },
    {
        "school": "Westwood Elementary",
        "district": "Manchester",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470261000930",
    },
    {
        "school": "Westwood Middle School",
        "district": "Manchester",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470261000931",
    },
    {
        "school": "Bel Aire Elementary",
        "district": "Tullahoma",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470420001710",
    },
    {
        "school": "East Lincoln Elementary",
        "district": "Tullahoma",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470420001711",
    },
    {
        "school": "East Middle School",
        "district": "Tullahoma",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470420001712",
    },
    {
        "school": "Jack T Farrar Elementary",
        "district": "Tullahoma",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470420001713",
    },
    {
        "school": "Robert E Lee Elementary",
        "district": "Tullahoma",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470420001714",
    },
    {
        "school": "Tullahoma High School",
        "district": "Tullahoma",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470420001715",
    },
    {
        "school": "West Middle School",
        "district": "Tullahoma",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470420001716",
    },
    {
        "school": "North Lake Elementary",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470129000069",
    },
    {
        "school": "Broadview Elementary",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470129000384",
    },
    {
        "school": "Clark Memorial School",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470129000385",
    },
    {
        "school": "Cowan Elementary",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470129000386",
    },
    {
        "school": "Decherd Elementary",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470129000387",
    },
    {
        "school": "Franklin Co High School",
        "district": "Franklin County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470129000388",
    },
    {
        "school": "Huntland School",
        "district": "Franklin County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470129000395",
    },
    {
        "school": "North Middle School",
        "district": "Franklin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470129000399",
    },
    {
        "school": "Rock Creek Elementary",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470129000401",
    },
    {
        "school": "Sewanee Elementary",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470129000402",
    },
    {
        "school": "South Middle School",
        "district": "Franklin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470129000405",
    },
    {
        "school": "South Lincoln School",
        "district": "Lincoln County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470249000079",
    },
    {
        "school": "Unity School",
        "district": "Lincoln County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470249000080",
    },
    {
        "school": "Blanche School",
        "district": "Lincoln County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470249000877",
    },
    {
        "school": "Stone Bridge Academy",
        "district": "Lincoln County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470249000881",
    },
    {
        "school": "Flintville School",
        "district": "Lincoln County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470249000884",
    },
    {
        "school": "Highland Rim School",
        "district": "Lincoln County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470249000885",
    },
    {
        "school": "Lincoln County High School",
        "district": "Lincoln County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470249001849",
    },
    {
        "school": "Lynchburg Elementary",
        "district": "Moore County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470306001223",
    },
    {
        "school": "Moore County High School",
        "district": "Moore County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470306001224",
    },
    {
        "school": "Obion County Central High School",
        "district": "Obion County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470327001406",
    },
    {
        "school": "South Fulton Elementary",
        "district": "Obion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470327001408",
    },
    {
        "school": "South Fulton Middle / High School",
        "district": "Obion County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470327001409",
    },
    {
        "school": "Lake Road Elementary",
        "district": "Obion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470327001925",
    },
    {
        "school": "Black Oak Elementary",
        "district": "Obion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470327001964",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Obion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470327001976",
    },
    {
        "school": "Ridgemont Elementary",
        "district": "Obion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470327002014",
    },
    {
        "school": "Union City Elementary School",
        "district": "Union City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470426001726",
    },
    {
        "school": "Union City High School",
        "district": "Union City",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470426001729",
    },
    {
        "school": "Union City Middle School",
        "district": "Union City",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470426001730",
    },
    {
        "school": "BROOKS ACADEMY OF SCIENCE AND ENGINEERING",
        "district": "BROOKS ACADEMIES OF TEXAS",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026811128",
    },
    {
        "school": "BEXAR COUNTY JUVENILE JUSTICE ACADEMY (BCJJA)",
        "district": "MEDINA VALLEY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483006011304",
    },
    {
        "school": "LOPEZ MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294011132",
    },
    {
        "school": "HARRIS MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294011133",
    },
    {
        "school": "FISHER EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312011137",
    },
    {
        "school": "WANKE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312011138",
    },
    {
        "school": "NEW BOSTON DAEP",
        "district": "HUBBARD ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482370011150",
    },
    {
        "school": "BERRY MILLER J H",
        "district": "PEARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444011152",
    },
    {
        "school": "MASSEY RANCH EL",
        "district": "PEARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444011153",
    },
    {
        "school": "JAMES EARL RUDDER H S",
        "district": "BRYAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179011154",
    },
    {
        "school": "ARTHUR L DAVILA MIDDLE",
        "district": "BRYAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179011155",
    },
    {
        "school": "IDEA FRONTIER ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021111384",
    },
    {
        "school": "BRITE EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168011486",
    },
    {
        "school": "DAVID G SANCHEZ EL",
        "district": "LA FERIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482604011160",
    },
    {
        "school": "SAN BENITO RIVERSIDE MIDDLE",
        "district": "SAN BENITO CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879011161",
    },
    {
        "school": "JUDGE OSCAR DE LA FUENTE EL",
        "district": "SAN BENITO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879011162",
    },
    {
        "school": "SANTA ROSA DAEP",
        "district": "SANTA ROSA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483936011163",
    },
    {
        "school": "CAMERON COUNTY JJAEP",
        "district": "SANTA ROSA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483936011400",
    },
    {
        "school": "LIBERTY H S",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001011166",
    },
    {
        "school": "OGLE EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001011167",
    },
    {
        "school": "CORBELL EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001011168",
    },
    {
        "school": "SEM EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001011169",
    },
    {
        "school": "TAYLOR EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001011170",
    },
    {
        "school": "DR JACK COCKRILL MIDDLE",
        "district": "MCKINNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985011171",
    },
    {
        "school": "JESSE MCGOWEN EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985011172",
    },
    {
        "school": "NAOMI PRESS EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985011173",
    },
    {
        "school": "OTTO MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510011174",
    },
    {
        "school": "PARKER ROAD EL",
        "district": "PLANO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510011175",
    },
    {
        "school": "MCCREARY RD EL",
        "district": "PLANO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510011176",
    },
    {
        "school": "SCHELL EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510011177",
    },
    {
        "school": "ACHIEVE ACADEMY",
        "district": "WYLIE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484653011178",
    },
    {
        "school": "RAYMOND B COOPER J H",
        "district": "WYLIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653011179",
    },
    {
        "school": "DR AL DRAPER INTERMED",
        "district": "WYLIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653011180",
    },
    {
        "school": "CHURCH HILL MIDDLE",
        "district": "COMAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473011552",
    },
    {
        "school": "GOLDEN RULE",
        "district": "GOLDEN RULE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023711465",
    },
    {
        "school": "LA ACADEMIA DE ESTRELLAS",
        "district": "LA ACADEMIA DE ESTRELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027011188",
    },
    {
        "school": "RICHLAND COLLEGIATE H S OF MATH SCIENCE ENGINEERIN",
        "district": "RICHLAND COLLEGIATE HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027111189",
    },
    {
        "school": "EARLY COLLEGE H S",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305011190",
    },
    {
        "school": "MCLAUGHLIN STRICKLAND EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305011192",
    },
    {
        "school": "EWELL D WALKER MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623011193",
    },
    {
        "school": "BILLY EARL DADE MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623011195",
    },
    {
        "school": "SAM TASBY MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623011196",
    },
    {
        "school": "TRINIDAD GARZA EARLY COLLEGE AT MT VIEW",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623011197",
    },
    {
        "school": "BELT LINE EL",
        "district": "LANCASTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482667011199",
    },
    {
        "school": "TERRY MIDDLE",
        "district": "MESQUITE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039011201",
    },
    {
        "school": "SUNNYVALE MIDDLE",
        "district": "SUNNYVALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484188011203",
    },
    {
        "school": "AMARILLO COLLEGIATE ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480016311503",
    },
    {
        "school": "DENTON CO J J A E P",
        "district": "ARGYLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480867011206",
    },
    {
        "school": "KILLIAN MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730011204",
    },
    {
        "school": "HUNT EL",
        "district": "CUERO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481596011209",
    },
    {
        "school": "WAXAHACHIE GLOBAL H S",
        "district": "WAXAHACHIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473011211",
    },
    {
        "school": "DAVINCI SCHOOL FOR SCIENCE AND THE ARTS",
        "district": "BURNHAM WOOD CHARTER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003711452",
    },
    {
        "school": "TRIUMPH PUBLIC HIGH SCHOOLS-EL PASO EAST",
        "district": "TRIUMPH PUBLIC HIGH SCHOOLS-EL PASO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480010611212",
    },
    {
        "school": "JOSE J ALDERETE MIDDLE",
        "district": "CANUTILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481278011215",
    },
    {
        "school": "CONGRESSMAN SILVESTRE & CAROLINA SCHOOL",
        "district": "CANUTILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481278011216",
    },
    {
        "school": "MISSION EARLY COLLEGE H S",
        "district": "SOCORRO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071011217",
    },
    {
        "school": "SPEC RAFAEL HERNANDO MIDDLE",
        "district": "SOCORRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071011218",
    },
    {
        "school": "DAVID CROCKETT MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965011219",
    },
    {
        "school": "OAKLAND EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965011220",
    },
    {
        "school": "ROSA PARKS EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965011221",
    },
    {
        "school": "CORNERSTONE EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965011222",
    },
    {
        "school": "TOMPKINS H S",
        "district": "KATY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517011271",
    },
    {
        "school": "CARDIFF J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517011272",
    },
    {
        "school": "PERCY W NEBLETT EL",
        "district": "SHERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008011225",
    },
    {
        "school": "HENRY W SORY EL",
        "district": "SHERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008011226",
    },
    {
        "school": "HIGH POINT EL",
        "district": "NAVASOTA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483219011227",
    },
    {
        "school": "NAVARRO INT",
        "district": "NAVARRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483216011228",
    },
    {
        "school": "YES PREP - EAST END",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020911415",
    },
    {
        "school": "HARMONY SCIENCE ACAD (EL PASO)",
        "district": "HARMONY SCIENCE ACAD (EL PASO)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027211213",
    },
    {
        "school": "HARMONY SCHOOL OF EXCELLENCE-HOUSTON",
        "district": "HARMONY SCHOOL OF EXCELLENCE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027411244",
    },
    {
        "school": "STEP CHARTER EL",
        "district": "STEP CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027511245",
    },
    {
        "school": "ALDINE EDUCATION CENTER",
        "district": "ALDINE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480771011250",
    },
    {
        "school": "ALIEF LEARNING CTR (K-6)",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480783011491",
    },
    {
        "school": "CROSSROADS",
        "district": "ALIEF ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480783011510",
    },
    {
        "school": "CYPRESS WOODS H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011252",
    },
    {
        "school": "CYPRESS RANCH H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011253",
    },
    {
        "school": "CYPRESS LAKES H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011254",
    },
    {
        "school": "HOPPER MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011255",
    },
    {
        "school": "ANDRE EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011256",
    },
    {
        "school": "POSTMA EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011257",
    },
    {
        "school": "BLACK EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011258",
    },
    {
        "school": "WARNER EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011259",
    },
    {
        "school": "MCFEE EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011260",
    },
    {
        "school": "EAST EARLY COLLEGE H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364011262",
    },
    {
        "school": "HOUSTON ACADEMY FOR INTERNATIONAL STUDIES",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364011263",
    },
    {
        "school": "HARPER DAEP",
        "district": "HOUSTON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482364011265",
    },
    {
        "school": "TSU CHARTER LAB SCH",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364011385",
    },
    {
        "school": "KINGWOOD PARK H S",
        "district": "HUMBLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391011266",
    },
    {
        "school": "SUMMER CREEK H S",
        "district": "HUMBLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391011267",
    },
    {
        "school": "WOODCREEK MIDDLE",
        "district": "HUMBLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391011268",
    },
    {
        "school": "FALL CREEK EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391011269",
    },
    {
        "school": "LAKESHORE EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391011270",
    },
    {
        "school": "JJAEP CAMPUS",
        "district": "HUMBLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482391011544",
    },
    {
        "school": "BENIGNUS EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574011273",
    },
    {
        "school": "VISTAS H S",
        "district": "KLEIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482574011462",
    },
    {
        "school": "CARL WUNSCHE SR H S",
        "district": "SPRING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122011277",
    },
    {
        "school": "ROOSTER SPRINGS EL",
        "district": "DRIPPING SPRINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000811280",
    },
    {
        "school": "IDEA QUEST ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021111427",
    },
    {
        "school": "VALLEY VIEW SOUTH EL",
        "district": "VALLEY VIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484380011283",
    },
    {
        "school": "BORGER INT",
        "district": "BORGER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481089011286",
    },
    {
        "school": "LEWIS EL",
        "district": "FORNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956011290",
    },
    {
        "school": "CIBOLO CREEK EL",
        "district": "BOERNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071011291",
    },
    {
        "school": "VAN RAUB EL",
        "district": "BOERNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071011292",
    },
    {
        "school": "FREDDA NOTTINGHAM ALTERNATIVE EDUCATION CENTER",
        "district": "DAYTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481641011383",
    },
    {
        "school": "DEVERS AEP",
        "district": "DEVERS ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481692011295",
    },
    {
        "school": "BENNETT EL",
        "district": "FRENSHIP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983011299",
    },
    {
        "school": "CENTENNIAL EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850011296",
    },
    {
        "school": "ROBERTS EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850011297",
    },
    {
        "school": "CROSSTIMBERS ACADEMY",
        "district": "CROSSTIMBERS ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480027811303",
    },
    {
        "school": "AXTELL/BE DAEP",
        "district": "BRUCEVILLE-EDDY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481173011401",
    },
    {
        "school": "KAUFMAN EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500011309",
    },
    {
        "school": "MAGNOLIA WEST H S",
        "district": "MAGNOLIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874011311",
    },
    {
        "school": "LONE STAR EL",
        "district": "MONTGOMERY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483126011310",
    },
    {
        "school": "BENS BRANCH EL",
        "district": "NEW CANEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240011438",
    },
    {
        "school": "NACOGDOCHES COUNTY DAEP COOP",
        "district": "GARRISON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482040011313",
    },
    {
        "school": "MALCOLM RECTOR TECHNICAL H S",
        "district": "NACOGDOCHES ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483209011314",
    },
    {
        "school": "SAM HOUSTON EL",
        "district": "CORSICANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481533011315",
    },
    {
        "school": "COLLEGIATE H S",
        "district": "CORPUS CHRISTI ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481527011318",
    },
    {
        "school": "TRADEWIND EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813011319",
    },
    {
        "school": "NORTH HEIGHTS ALTER",
        "district": "RIVER ROAD ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483726011320",
    },
    {
        "school": "FAIRVIEW ACCELERATED",
        "district": "BALLINGER ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480930011322",
    },
    {
        "school": "WALL SPECIAL PROGRAMS",
        "district": "OLFEN ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483357011543",
    },
    {
        "school": "SNYDER ACADEMY",
        "district": "HERMLEIGH ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482304011324",
    },
    {
        "school": "DR BRYAN C JACK EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347011326",
    },
    {
        "school": "VETERANS MIDDLE",
        "district": "RIO GRANDE CITY CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714011327",
    },
    {
        "school": "WINFREE ACADEMY NORTH RICHLAND HILLS",
        "district": "WINFREE ACADEMY CHARTER SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020211185",
    },
    {
        "school": "FORT WORTH ACADEMY OF FINE ARTS EL",
        "district": "FORT WORTH ACADEMY OF FINE ARTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023111512",
    },
    {
        "school": "SUE CROUCH EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591011419",
    },
    {
        "school": "PRAIRIE VISTA",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770011344",
    },
    {
        "school": "GREENFIELD EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770011345",
    },
    {
        "school": "COMANCHE SPRINGS EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770011346",
    },
    {
        "school": "TRINITY SPRINGS MIDDLE",
        "district": "KELLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526011330",
    },
    {
        "school": "INDEPENDENCE EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526011331",
    },
    {
        "school": "FRIENDSHIP EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526011332",
    },
    {
        "school": "TRINITY MEADOWS INT",
        "district": "KELLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526011333",
    },
    {
        "school": "LUCYLE COLLINS MIDDLE SCHOOL",
        "district": "LAKE WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482649011341",
    },
    {
        "school": "MARILYN MILLER EL",
        "district": "LAKE WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482649011342",
    },
    {
        "school": "MANSFIELD LEGACY H S",
        "district": "MANSFIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011334",
    },
    {
        "school": "JAMES COBLE MIDDLE",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011335",
    },
    {
        "school": "ANNA MAY DAULTON EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011336",
    },
    {
        "school": "CORA SPENCER EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011337",
    },
    {
        "school": "LOUISE CABANISS EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011338",
    },
    {
        "school": "CAROL HOLT EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011339",
    },
    {
        "school": "MARY LILLARD I S",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011340",
    },
    {
        "school": "CRAIG MIDDLE",
        "district": "ABILENE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744011347",
    },
    {
        "school": "DAY NURSERY OF ABILENE",
        "district": "ABILENE ISD",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480744011348",
    },
    {
        "school": "HARMONY SCIENCE ACAD (SAN ANTONIO)",
        "district": "HARMONY SCIENCE ACAD (SAN ANTONIO)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026611126",
    },
    {
        "school": "RICHARDS SCH FOR YOUNG WOMEN LEADERS",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894011354",
    },
    {
        "school": "READ PRE-K CENTER",
        "district": "AUSTIN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011355",
    },
    {
        "school": "CREEDMOOR EL",
        "district": "DEL VALLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662011360",
    },
    {
        "school": "BLAKE MANOR EL",
        "district": "MANOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889011359",
    },
    {
        "school": "KELLY LANE MIDDLE",
        "district": "PFLUGERVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483011356",
    },
    {
        "school": "HIGHLAND PARK EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483011358",
    },
    {
        "school": "ISCHOOL VIRTUAL ACADEMY OF TEXAS",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480016309583",
    },
    {
        "school": "BATESVILLE SCHOOL",
        "district": "UVALDE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484372011429",
    },
    {
        "school": "HERITAGE ACADEMY OF DEL RIO",
        "district": "HERITAGE ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480008011493",
    },
    {
        "school": "HUNTSVILLE CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016308127",
    },
    {
        "school": "HECTOR J GARCIA EARLY COLLEGE H S",
        "district": "LAREDO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679011365",
    },
    {
        "school": "CCJJAEP",
        "district": "LYFORD CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482862011366",
    },
    {
        "school": "CCJJAEP",
        "district": "RAYMONDVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483654011367",
    },
    {
        "school": "COTTONWOOD CREEK EL",
        "district": "HUTTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482410011368",
    },
    {
        "school": "KNOX WILEY MIDDLE",
        "district": "LEANDER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703011369",
    },
    {
        "school": "JIM PLAIN EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703011370",
    },
    {
        "school": "WILLIAM J WINKLEY EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703011371",
    },
    {
        "school": "BILL BURDEN EL",
        "district": "LIBERTY HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482742011376",
    },
    {
        "school": "WILSON CO J J A E P",
        "district": "FALLS CITY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481902011482",
    },
    {
        "school": "CARDENAS CENTER",
        "district": "EDGEWOOD ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001609",
    },
    {
        "school": "ATASCOSA JUVENILE DETENTION CTR",
        "district": "PEARSALL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483447009244",
    },
    {
        "school": "SEYMOUR MIDDLE",
        "district": "SEYMOUR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483978009109",
    },
    {
        "school": "LAMESA DAEP",
        "district": "BORDEN COUNTY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481086010450",
    },
    {
        "school": "MCLENNAN COUNTY CHALLENGE ACADEMY",
        "district": "VALLEY MILLS ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484376010452",
    },
    {
        "school": "VALLEY MILLS DAEP",
        "district": "VALLEY MILLS ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484376010453",
    },
    {
        "school": "FALLS CAREER H S",
        "district": "MARBLE FALLS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482901010469",
    },
    {
        "school": "SPICEWOOD EL",
        "district": "MARBLE FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482901010470",
    },
    {
        "school": "PITTSBURG INT",
        "district": "PITTSBURG ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483501009157",
    },
    {
        "school": "EAGLE LAKE INT",
        "district": "RICE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483697011184",
    },
    {
        "school": "WALL SPECIAL PROGRAMS",
        "district": "PAINT ROCK ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483398009184",
    },
    {
        "school": "VERIBEST PPCD",
        "district": "PAINT ROCK ISD",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483398009185",
    },
    {
        "school": "FAIRVIEW SPECIAL PROGRAMS",
        "district": "PAINT ROCK ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483398010545",
    },
    {
        "school": "G O A L S PROGRAM",
        "district": "HALLETTSVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482212009327",
    },
    {
        "school": "G O A L S PROGRAM",
        "district": "MOULTON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483156009496",
    },
    {
        "school": "GOALS",
        "district": "NORDHEIM ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483288009640",
    },
    {
        "school": "CARRIZO SPRINGS EL",
        "district": "CARRIZO SPRINGS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481299009648",
    },
    {
        "school": "CISCO LEARNING CENTER",
        "district": "CISCO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481407009215",
    },
    {
        "school": "ECTOR EL",
        "district": "ECTOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481803009561",
    },
    {
        "school": "TRENTON MIDDLE",
        "district": "TRENTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484314009560",
    },
    {
        "school": "P A C",
        "district": "FLOYDADA ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481944009238",
    },
    {
        "school": "FLOYDADA ISD DAEP",
        "district": "FLOYDADA ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481944009239",
    },
    {
        "school": "LOCKNEY DAEP",
        "district": "LOCKNEY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482789009240",
    },
    {
        "school": "WORTHAM DAEP",
        "district": "WORTHAM ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484647010676",
    },
    {
        "school": "TEAGUE DAEP",
        "district": "TEAGUE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484230010675",
    },
    {
        "school": "NIXON-SMILEY PACE",
        "district": "NIXON-SMILEY CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483274010685",
    },
    {
        "school": "HASKELL J H",
        "district": "HASKELL CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482274011279",
    },
    {
        "school": "HILL COUNTY JJAEP",
        "district": "MOUNT CALM ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483162010842",
    },
    {
        "school": "HILL CO J J A E P",
        "district": "ABBOTT ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480738010837",
    },
    {
        "school": "HILL CO J J A E P",
        "district": "AQUILLA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480852010845",
    },
    {
        "school": "HILL COUNTY JJAEP",
        "district": "BLUM ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481065010846",
    },
    {
        "school": "HILL CO J J A E P",
        "district": "HILLSBORO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482328009309",
    },
    {
        "school": "HILLSBORO INT",
        "district": "HILLSBORO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482328009310",
    },
    {
        "school": "HILL CO J J A E P",
        "district": "HUBBARD ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482373009617",
    },
    {
        "school": "HILL CO J J A E P",
        "district": "WHITNEY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484572010843",
    },
    {
        "school": "FORT HANCOCK H S",
        "district": "FT HANCOCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482013010849",
    },
    {
        "school": "FORT HANCOCK MIDDLE",
        "district": "FT HANCOCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482013010850",
    },
    {
        "school": "BENITO MARTINEZ EL",
        "district": "FT HANCOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482013010851",
    },
    {
        "school": "FLORESVILLE ALTERNATIVE CENTER CHOICE PROGRAM",
        "district": "RUNGE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483831010866",
    },
    {
        "school": "SPRINGLAKE-EARTH DAEP",
        "district": "SPRINGLAKE-EARTH ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484125010877",
    },
    {
        "school": "WALLACE ACCELERATED H S",
        "district": "COLORADO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481464010962",
    },
    {
        "school": "JEFFERSON PRI SCH",
        "district": "JEFFERSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482473011300",
    },
    {
        "school": "MASON J H",
        "district": "MASON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482928011301",
    },
    {
        "school": "MILANO J H",
        "district": "MILANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483069009351",
    },
    {
        "school": "BOWIE INT",
        "district": "BOWIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481099009664",
    },
    {
        "school": "ONALASKA JR/SR HIGH",
        "district": "ONALASKA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483369009481",
    },
    {
        "school": "RAINS INT",
        "district": "RAINS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483636009464",
    },
    {
        "school": "HILL COUNTRY YOUTH RANCH",
        "district": "BIG SPRINGS CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480022711321",
    },
    {
        "school": "FAIRVIEW ACCELERATED EDUCATIONAL COOP",
        "district": "PAINT ROCK ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483398010543",
    },
    {
        "school": "FAIRVIEW SCHOOL (DAEP)",
        "district": "PAINT ROCK ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483398010544",
    },
    {
        "school": "FAIRVIEW DAEP",
        "district": "ROBERT LEE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483738010482",
    },
    {
        "school": "FAIRVIEW SPECIAL PROGRAMS",
        "district": "ROBERT LEE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483738010485",
    },
    {
        "school": "FAIRVIEW DAEP",
        "district": "STERLING CITY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484155009372",
    },
    {
        "school": "WALL SPECIAL PROGRAMS",
        "district": "STERLING CITY ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484155009373",
    },
    {
        "school": "MABANK DAEP",
        "district": "MARTINS MILL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482922011074",
    },
    {
        "school": "YANTIS EL",
        "district": "YANTIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484659009578",
    },
    {
        "school": "NEWCASTLE SCHOOL",
        "district": "NEWCASTLE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483270011372",
    },
    {
        "school": "ZAPATA NORTH EL",
        "district": "ZAPATA COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484671009446",
    },
    {
        "school": "ZAPATA SOUTH EL",
        "district": "ZAPATA COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484671009447",
    },
    {
        "school": "FIDEL AND ANDREA R VILLARREAL EL",
        "district": "ZAPATA COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484671009448",
    },
    {
        "school": "MARY DESHAZO EL",
        "district": "MULESHOE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483189003546",
    },
    {
        "school": "MULESHOE H S",
        "district": "MULESHOE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483189003547",
    },
    {
        "school": "WATSON J H",
        "district": "MULESHOE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483189003548",
    },
    {
        "school": "DILLMAN EL",
        "district": "MULESHOE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483189003549",
    },
    {
        "school": "P E P",
        "district": "MULESHOE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483189008094",
    },
    {
        "school": "SEYMOUR EL",
        "district": "SEYMOUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483978004519",
    },
    {
        "school": "SEYMOUR H S",
        "district": "SEYMOUR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483978004520",
    },
    {
        "school": "BLANCO MIDDLE",
        "district": "BLANCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481032000419",
    },
    {
        "school": "BLANCO EL",
        "district": "BLANCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481032000514",
    },
    {
        "school": "BLANCO H S",
        "district": "BLANCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481032000515",
    },
    {
        "school": "LYNDON B JOHNSON H S",
        "district": "JOHNSON CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482484002777",
    },
    {
        "school": "LYNDON B JOHNSON MIDDLE",
        "district": "JOHNSON CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482484006125",
    },
    {
        "school": "BORDEN COUNTY SCHOOL",
        "district": "BORDEN COUNTY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481086000552",
    },
    {
        "school": "CLIFTON MIDDLE",
        "district": "CLIFTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481440000420",
    },
    {
        "school": "CLIFTON EL",
        "district": "CLIFTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481440000930",
    },
    {
        "school": "CLIFTON H S",
        "district": "CLIFTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481440000931",
    },
    {
        "school": "CRANFILLS GAP SCHOOL",
        "district": "CRANFILLS GAP ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481557001129",
    },
    {
        "school": "IREDELL SCHOOL",
        "district": "IREDELL ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482436002714",
    },
    {
        "school": "KOPPERL SCHOOL",
        "district": "KOPPERL ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482589002917",
    },
    {
        "school": "MERIDIAN H S",
        "district": "MERIDIAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483030003394",
    },
    {
        "school": "MERIDIAN EL",
        "district": "MERIDIAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483030006178",
    },
    {
        "school": "MORGAN SCHOOL",
        "district": "MORGAN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483138003520",
    },
    {
        "school": "VALLEY MILLS EL",
        "district": "VALLEY MILLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484376004976",
    },
    {
        "school": "VALLEY MILLS H S",
        "district": "VALLEY MILLS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484376004977",
    },
    {
        "school": "VALLEY MILLS J H",
        "district": "VALLEY MILLS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484376007525",
    },
    {
        "school": "ALPINE EL",
        "district": "ALPINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480795000123",
    },
    {
        "school": "ALPINE H S",
        "district": "ALPINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480795000124",
    },
    {
        "school": "ALPINE MIDDLE",
        "district": "ALPINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480795000125",
    },
    {
        "school": "MARATHON INDEPENDENT SCHOOL DIST",
        "district": "MARATHON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482898003272",
    },
    {
        "school": "SAN VICENTE EL",
        "district": "SAN VICENTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483906005809",
    },
    {
        "school": "BIG BEND H S",
        "district": "TERLINGUA CSD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484239007193",
    },
    {
        "school": "SILVERTON SCHOOL",
        "district": "SILVERTON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484029004565",
    },
    {
        "school": "FALFURRIAS EL",
        "district": "BROOKS COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481158000629",
    },
    {
        "school": "FALFURRIAS H S",
        "district": "BROOKS COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481158000630",
    },
    {
        "school": "FALFURRIAS J H",
        "district": "BROOKS COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481158000631",
    },
    {
        "school": "LASATER EL",
        "district": "BROOKS COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481158000632",
    },
    {
        "school": "BERTRAM EL",
        "district": "BURNET CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481222000721",
    },
    {
        "school": "SHADY GROVE EL",
        "district": "BURNET CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481222000722",
    },
    {
        "school": "BURNET H S",
        "district": "BURNET CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481222000723",
    },
    {
        "school": "BURNET MIDDLE",
        "district": "BURNET CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481222000724",
    },
    {
        "school": "QUEST H S",
        "district": "BURNET CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481222003287",
    },
    {
        "school": "RJ RICHEY EL",
        "district": "BURNET CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481222005851",
    },
    {
        "school": "MARBLE FALLS EL",
        "district": "MARBLE FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482901003273",
    },
    {
        "school": "MARBLE FALLS H S",
        "district": "MARBLE FALLS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482901003274",
    },
    {
        "school": "MARBLE FALLS MIDDLE",
        "district": "MARBLE FALLS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482901003275",
    },
    {
        "school": "COLT EL",
        "district": "MARBLE FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482901006014",
    },
    {
        "school": "HIGHLAND LAKES EL",
        "district": "MARBLE FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482901007819",
    },
    {
        "school": "PITTSBURG H S",
        "district": "PITTSBURG ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483501003937",
    },
    {
        "school": "PITTSBURG EL",
        "district": "PITTSBURG ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483501003938",
    },
    {
        "school": "PITTSBURG J H",
        "district": "PITTSBURG ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483501003939",
    },
    {
        "school": "PITTSBURG PRI",
        "district": "PITTSBURG ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483501003940",
    },
    {
        "school": "ATLANTA EL",
        "district": "ATLANTA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480888000283",
    },
    {
        "school": "ATLANTA H S",
        "district": "ATLANTA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480888000284",
    },
    {
        "school": "ATLANTA MIDDLE",
        "district": "ATLANTA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480888000285",
    },
    {
        "school": "ATLANTA PRI",
        "district": "ATLANTA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480888000286",
    },
    {
        "school": "CORRECTIVE BEHAVIOR CTR",
        "district": "ATLANTA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480888008469",
    },
    {
        "school": "AVINGER SCHOOL",
        "district": "AVINGER ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480909000378",
    },
    {
        "school": "BLOOMBURG SCHOOL",
        "district": "BLOOMBURG ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481044000523",
    },
    {
        "school": "HUGHES SPRINGS EL",
        "district": "HUGHES SPRINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482385002636",
    },
    {
        "school": "HUGHES SPRINGS H S",
        "district": "HUGHES SPRINGS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482385002637",
    },
    {
        "school": "HUGHES SPRINGS J H",
        "district": "HUGHES SPRINGS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482385002638",
    },
    {
        "school": "LINDEN EL",
        "district": "LINDEN-KILDARE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482754003095",
    },
    {
        "school": "LINDEN-KILDARE H S",
        "district": "LINDEN-KILDARE CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482754003097",
    },
    {
        "school": "MAE LUSTER STEPHENS J H",
        "district": "LINDEN-KILDARE CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482754003098",
    },
    {
        "school": "MCLEOD EL",
        "district": "MCLEOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482991003365",
    },
    {
        "school": "MCLEOD H S",
        "district": "MCLEOD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482991003366",
    },
    {
        "school": "MCLEOD MIDDLE",
        "district": "MCLEOD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482991021160",
    },
    {
        "school": "QUEEN CITY H S",
        "district": "QUEEN CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483621004071",
    },
    {
        "school": "MORRIS UPCHURCH MIDDLE",
        "district": "QUEEN CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483621004072",
    },
    {
        "school": "J K HILEMAN EL",
        "district": "QUEEN CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483621004073",
    },
    {
        "school": "DIMMITT H S",
        "district": "DIMMITT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481716001487",
    },
    {
        "school": "DIMMITT MIDDLE",
        "district": "DIMMITT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481716001488",
    },
    {
        "school": "RICHARDSON EL",
        "district": "DIMMITT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481716001489",
    },
    {
        "school": "HART ISD",
        "district": "HART ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482265002300",
    },
    {
        "school": "NAZARETH SCHOOL",
        "district": "NAZARETH ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483222003573",
    },
    {
        "school": "CHILDRESS H S",
        "district": "CHILDRESS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481386000871",
    },
    {
        "school": "CHILDRESS J H",
        "district": "CHILDRESS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481386000872",
    },
    {
        "school": "CHILDRESS EL",
        "district": "CHILDRESS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481386000873",
    },
    {
        "school": "MORTON SCHOOL",
        "district": "MORTON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483147003523",
    },
    {
        "school": "P E P",
        "district": "MORTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483147008145",
    },
    {
        "school": "WHITEFACE SCHOOL",
        "district": "WHITEFACE CISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484557005181",
    },
    {
        "school": "PANTHER CREEK SCHOOL",
        "district": "PANTHER CREEK CISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000706343",
    },
    {
        "school": "COLEMAN H S",
        "district": "COLEMAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481455000943",
    },
    {
        "school": "COLEMAN J H",
        "district": "COLEMAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481455000944",
    },
    {
        "school": "COLEMAN EL",
        "district": "COLEMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481455000945",
    },
    {
        "school": "SANTA ANNA EL",
        "district": "SANTA ANNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483921004470",
    },
    {
        "school": "SANTA ANNA SECONDARY",
        "district": "SANTA ANNA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483921004471",
    },
    {
        "school": "WELLINGTON H S",
        "district": "WELLINGTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484489005111",
    },
    {
        "school": "WELLINGTON J H",
        "district": "WELLINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484489006800",
    },
    {
        "school": "WELLINGTON EL",
        "district": "WELLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484489006801",
    },
    {
        "school": "COLUMBUS EL",
        "district": "COLUMBUS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481470000962",
    },
    {
        "school": "COLUMBUS H S",
        "district": "COLUMBUS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481470000963",
    },
    {
        "school": "COLUMBUS J H",
        "district": "COLUMBUS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481470000964",
    },
    {
        "school": "GARWOOD EL",
        "district": "RICE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483697004117",
    },
    {
        "school": "RICE H S",
        "district": "RICE CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483697004118",
    },
    {
        "school": "SHERIDAN EL",
        "district": "RICE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483697004119",
    },
    {
        "school": "WEIMAR EL",
        "district": "WEIMAR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484482005105",
    },
    {
        "school": "WEIMAR H S",
        "district": "WEIMAR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484482005106",
    },
    {
        "school": "WEIMAR J H",
        "district": "WEIMAR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484482005107",
    },
    {
        "school": "COMANCHE EL",
        "district": "COMANCHE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481476000975",
    },
    {
        "school": "COMANCHE H S",
        "district": "COMANCHE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481476000976",
    },
    {
        "school": "JEFFERIES J H",
        "district": "COMANCHE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481476000977",
    },
    {
        "school": "DE LEON EL",
        "district": "DE LEON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481644001404",
    },
    {
        "school": "DE LEON H S",
        "district": "DE LEON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481644001405",
    },
    {
        "school": "PERKINS MIDDLE",
        "district": "DE LEON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481644021193",
    },
    {
        "school": "GUSTINE SCHOOL",
        "district": "GUSTINE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482199002215",
    },
    {
        "school": "SIDNEY SCHOOL",
        "district": "SIDNEY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484017004556",
    },
    {
        "school": "PAINT ROCK SCHOOL",
        "district": "PAINT ROCK ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483398003779",
    },
    {
        "school": "PADUCAH SCHOOL",
        "district": "PADUCAH ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483390003775",
    },
    {
        "school": "CRANE EL",
        "district": "CRANE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481554001125",
    },
    {
        "school": "CRANE H S",
        "district": "CRANE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481554001126",
    },
    {
        "school": "CRANE MIDDLE",
        "district": "CRANE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481554001127",
    },
    {
        "school": "OZONA H S",
        "district": "CROCKETT COUNTY CONSOLIDATED CSD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481569001132",
    },
    {
        "school": "OZONA MIDDLE",
        "district": "CROCKETT COUNTY CONSOLIDATED CSD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481569001134",
    },
    {
        "school": "VAN HORN SCHOOL",
        "district": "CULBERSON COUNTY-ALLAMOORE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481599001171",
    },
    {
        "school": "DALHART J H",
        "district": "DALHART ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481620006237",
    },
    {
        "school": "DALHART INT",
        "district": "DALHART ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481620006238",
    },
    {
        "school": "X I T SECONDARY SCHOOL",
        "district": "DALHART ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481620007237",
    },
    {
        "school": "TEXLINE SCHOOL",
        "district": "TEXLINE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484257004868",
    },
    {
        "school": "CUERO H S",
        "district": "CUERO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481596001164",
    },
    {
        "school": "CUERO J H",
        "district": "CUERO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481596001165",
    },
    {
        "school": "J C FRENCH EL",
        "district": "CUERO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481596001167",
    },
    {
        "school": "MEYERSVILLE EL",
        "district": "MEYERSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483045003427",
    },
    {
        "school": "NORDHEIM SCHOOL",
        "district": "NORDHEIM ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483288003624",
    },
    {
        "school": "G O A L S PROGRAM",
        "district": "SHINER ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484011007673",
    },
    {
        "school": "WESTHOFF EL",
        "district": "WESTHOFF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484524005157",
    },
    {
        "school": "YOAKUM H S",
        "district": "YOAKUM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484662005299",
    },
    {
        "school": "YOAKUM INT",
        "district": "YOAKUM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484662005300",
    },
    {
        "school": "YOAKUM J H",
        "district": "YOAKUM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484662005301",
    },
    {
        "school": "YOAKUM PRI",
        "district": "YOAKUM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484662005302",
    },
    {
        "school": "YORKTOWN H S",
        "district": "YORKTOWN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484665005303",
    },
    {
        "school": "YORKTOWN J H",
        "district": "YORKTOWN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484665005304",
    },
    {
        "school": "YORKTOWN EL",
        "district": "YORKTOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484665005305",
    },
    {
        "school": "SPUR SCHOOL",
        "district": "SPUR ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000204732",
    },
    {
        "school": "PATTON SPRINGS SCHOOL",
        "district": "PATTON SPRINGS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483438003858",
    },
    {
        "school": "CARRIZO SPRINGS H S",
        "district": "CARRIZO SPRINGS CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481299000785",
    },
    {
        "school": "CARRIZO SPRINGS J H",
        "district": "CARRIZO SPRINGS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481299000786",
    },
    {
        "school": "CARRIZO SPRINGS INT",
        "district": "CARRIZO SPRINGS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481299000788",
    },
    {
        "school": "CLARENDON EL",
        "district": "CLARENDON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481416000892",
    },
    {
        "school": "CLARENDON H S",
        "district": "CLARENDON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481416000893",
    },
    {
        "school": "HEDLEY SCHOOL",
        "district": "HEDLEY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482285002317",
    },
    {
        "school": "NORMAN M THOMAS EL",
        "district": "FREER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481982005366",
    },
    {
        "school": "FREER H S",
        "district": "FREER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481982005367",
    },
    {
        "school": "FREER J H",
        "district": "FREER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481982005368",
    },
    {
        "school": "RAMIREZ EL",
        "district": "RAMIREZ CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483642004086",
    },
    {
        "school": "COLLINS-PARR EL",
        "district": "SAN DIEGO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483882004428",
    },
    {
        "school": "SAN DIEGO H S",
        "district": "SAN DIEGO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483882004430",
    },
    {
        "school": "BERNARDA JAIME J H",
        "district": "SAN DIEGO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483882004431",
    },
    {
        "school": "BENAVIDES SECONDARY",
        "district": "BENAVIDES ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "489913005627",
    },
    {
        "school": "BENAVIDES EL",
        "district": "BENAVIDES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "489913005628",
    },
    {
        "school": "CISCO H S",
        "district": "CISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481407000887",
    },
    {
        "school": "CISCO EL",
        "district": "CISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481407000888",
    },
    {
        "school": "CISCO J H",
        "district": "CISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481407005855",
    },
    {
        "school": "EASTLAND H S",
        "district": "EASTLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481796001563",
    },
    {
        "school": "EASTLAND MIDDLE",
        "district": "EASTLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481796001564",
    },
    {
        "school": "SIEBERT EL",
        "district": "EASTLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481796001565",
    },
    {
        "school": "MAXFIELD EL",
        "district": "GORMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482127002128",
    },
    {
        "school": "GORMAN H S",
        "district": "GORMAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482127002129",
    },
    {
        "school": "RANGER H S",
        "district": "RANGER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483648004090",
    },
    {
        "school": "RANGER EL",
        "district": "RANGER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483648006602",
    },
    {
        "school": "RANGER MIDDLE",
        "district": "RANGER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483648008537",
    },
    {
        "school": "RISING STAR EL",
        "district": "RISING STAR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483723004188",
    },
    {
        "school": "RISING STAR H S",
        "district": "RISING STAR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483723004189",
    },
    {
        "school": "ROCKSPRINGS K-12",
        "district": "ROCKSPRINGS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000304219",
    },
    {
        "school": "NUECES CANYON EL",
        "district": "NUECES CANYON CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483324003738",
    },
    {
        "school": "NUECES CANYON JH/HS",
        "district": "NUECES CANYON CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483324003739",
    },
    {
        "school": "CHILTON SCHOOL",
        "district": "CHILTON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481392000879",
    },
    {
        "school": "LOTT EL",
        "district": "ROSEBUD-LOTT ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483790004239",
    },
    {
        "school": "ROSEBUD PRI",
        "district": "ROSEBUD-LOTT ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483790004241",
    },
    {
        "school": "ROSEBUD-LOTT H S",
        "district": "ROSEBUD-LOTT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483790004242",
    },
    {
        "school": "ROSEBUD-LOTT MIDDLE",
        "district": "ROSEBUD-LOTT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483790004243",
    },
    {
        "school": "WESTPHALIA EL",
        "district": "WESTPHALIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484533005160",
    },
    {
        "school": "BONHAM H S",
        "district": "BONHAM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481080000545",
    },
    {
        "school": "EVANS EL",
        "district": "BONHAM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481080000546",
    },
    {
        "school": "RATHER L H",
        "district": "BONHAM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481080000547",
    },
    {
        "school": "BAILEY INGLISH EARLY CHILDHOOD CENTER",
        "district": "BONHAM ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481080000548",
    },
    {
        "school": "FINLEY-OATES EL",
        "district": "BONHAM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481080007599",
    },
    {
        "school": "DODD CITY SCHOOL",
        "district": "DODD CITY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481728001494",
    },
    {
        "school": "ECTOR H S",
        "district": "ECTOR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481803001599",
    },
    {
        "school": "HONEY GROVE EL",
        "district": "HONEY GROVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482346002379",
    },
    {
        "school": "HONEY GROVE H S",
        "district": "HONEY GROVE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482346002380",
    },
    {
        "school": "HONEY GROVE MIDDLE",
        "district": "HONEY GROVE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482346006711",
    },
    {
        "school": "LEONARD EL",
        "district": "LEONARD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482721003053",
    },
    {
        "school": "LEONARD H S",
        "district": "LEONARD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482721003054",
    },
    {
        "school": "LEONARD J H",
        "district": "LEONARD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482721006290",
    },
    {
        "school": "LEONARD INT",
        "district": "LEONARD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482721008781",
    },
    {
        "school": "RAYBURN H S",
        "district": "SAM RAYBURN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483864004292",
    },
    {
        "school": "SAM RAYBURN EL",
        "district": "SAM RAYBURN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483864004293",
    },
    {
        "school": "SAVOY H S",
        "district": "SAVOY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483945004484",
    },
    {
        "school": "TRENTON EL",
        "district": "TRENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484314004901",
    },
    {
        "school": "TRENTON H S",
        "district": "TRENTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484314004902",
    },
    {
        "school": "FAYETTEVILLE SCHOOLS",
        "district": "FAYETTEVILLE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481914001784",
    },
    {
        "school": "FLATONIA EL",
        "district": "FLATONIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481928001788",
    },
    {
        "school": "FLATONIA SECONDARY",
        "district": "FLATONIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481928001789",
    },
    {
        "school": "LA GRANGE H S",
        "district": "LA GRANGE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482610002933",
    },
    {
        "school": "LA GRANGE MIDDLE",
        "district": "LA GRANGE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482610002934",
    },
    {
        "school": "HERMES/INTERMEDIATE SCHOOL",
        "district": "LA GRANGE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482610006952",
    },
    {
        "school": "ROUND TOP-CARMINE H S",
        "district": "ROUND TOP-CARMINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483810004259",
    },
    {
        "school": "ROUND TOP-CARMINE EL",
        "district": "ROUND TOP-CARMINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483810004260",
    },
    {
        "school": "SCHULENBURG EL",
        "district": "SCHULENBURG ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483954004493",
    },
    {
        "school": "SCHULENBURG SECONDARY",
        "district": "SCHULENBURG ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483954004494",
    },
    {
        "school": "ROBY CISD",
        "district": "ROBY CISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483747004210",
    },
    {
        "school": "ROTAN K-12",
        "district": "ROTAN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483804004245",
    },
    {
        "school": "A B DUNCAN EL",
        "district": "FLOYDADA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481944001801",
    },
    {
        "school": "FLOYDADA H S",
        "district": "FLOYDADA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481944001802",
    },
    {
        "school": "FLOYDADA J H",
        "district": "FLOYDADA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481944001803",
    },
    {
        "school": "LOCKNEY EL",
        "district": "LOCKNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482789003128",
    },
    {
        "school": "LOCKNEY H S",
        "district": "LOCKNEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482789003129",
    },
    {
        "school": "LOCKNEY J H",
        "district": "LOCKNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482789003130",
    },
    {
        "school": "CROWELL SCHOOL",
        "district": "CROWELL ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481587001153",
    },
    {
        "school": "MT VERNON MIDDLE",
        "district": "MOUNT VERNON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483177003539",
    },
    {
        "school": "MT VERNON EL",
        "district": "MOUNT VERNON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483177003540",
    },
    {
        "school": "MT VERNON H S",
        "district": "MOUNT VERNON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483177003541",
    },
    {
        "school": "DEW EL",
        "district": "DEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481698001471",
    },
    {
        "school": "FAIRFIELD EL",
        "district": "FAIRFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481894001769",
    },
    {
        "school": "FAIRFIELD H S",
        "district": "FAIRFIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481894001770",
    },
    {
        "school": "FAIRFIELD J H",
        "district": "FAIRFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481894001772",
    },
    {
        "school": "TEAGUE J H",
        "district": "TEAGUE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484230004046",
    },
    {
        "school": "TEAGUE EL",
        "district": "TEAGUE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484230004812",
    },
    {
        "school": "TEAGUE H S",
        "district": "TEAGUE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484230004813",
    },
    {
        "school": "WORTHAM EL",
        "district": "WORTHAM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484647005289",
    },
    {
        "school": "WORTHAM H S",
        "district": "WORTHAM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484647005290",
    },
    {
        "school": "WORTHAM MIDDLE",
        "district": "WORTHAM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484647007287",
    },
    {
        "school": "DILLEY EL",
        "district": "DILLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481710001482",
    },
    {
        "school": "DILLEY H S",
        "district": "DILLEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481710001483",
    },
    {
        "school": "MARY HARPER MIDDLE",
        "district": "DILLEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481710001484",
    },
    {
        "school": "PEARSALL H S",
        "district": "PEARSALL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483447003867",
    },
    {
        "school": "PEARSALL INT",
        "district": "PEARSALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483447003868",
    },
    {
        "school": "PEARSALL J H",
        "district": "PEARSALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483447003869",
    },
    {
        "school": "TED FLORES EL",
        "district": "PEARSALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483447003871",
    },
    {
        "school": "LOOP SCHOOL",
        "district": "LOOP ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482814003154",
    },
    {
        "school": "SEAGRAVES SCHOOLS",
        "district": "SEAGRAVES ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483960004499",
    },
    {
        "school": "SEMINOLE EL",
        "district": "SEMINOLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483975004514",
    },
    {
        "school": "SEMINOLE H S",
        "district": "SEMINOLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483975004515",
    },
    {
        "school": "SEMINOLE J H",
        "district": "SEMINOLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483975004516",
    },
    {
        "school": "SEMINOLE PRI",
        "district": "SEMINOLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483975004517",
    },
    {
        "school": "YOUNG EL",
        "district": "SEMINOLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483975004518",
    },
    {
        "school": "SEMINOLE SUCCESS CTR",
        "district": "SEMINOLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483975007288",
    },
    {
        "school": "POST EL",
        "district": "POST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483549004025",
    },
    {
        "school": "POST H S",
        "district": "POST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483549004026",
    },
    {
        "school": "POST MIDDLE",
        "district": "POST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483549004027",
    },
    {
        "school": "DOSS EL",
        "district": "DOSS CONSOLIDATED CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481740001503",
    },
    {
        "school": "FREDERICKSBURG H S",
        "district": "FREDERICKSBURG ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481984001940",
    },
    {
        "school": "FREDERICKSBURG MIDDLE",
        "district": "FREDERICKSBURG ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481984001941",
    },
    {
        "school": "FREDERICKSBURG PRI",
        "district": "FREDERICKSBURG ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481984001942",
    },
    {
        "school": "STONEWALL EL",
        "district": "FREDERICKSBURG ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481984001943",
    },
    {
        "school": "FREDERICKSBURG EL",
        "district": "FREDERICKSBURG ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481984006959",
    },
    {
        "school": "ALTER SCH",
        "district": "FREDERICKSBURG ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481984021258",
    },
    {
        "school": "HARPER H S",
        "district": "HARPER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482259002296",
    },
    {
        "school": "HARPER EL",
        "district": "HARPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482259006560",
    },
    {
        "school": "HARPER MIDDLE",
        "district": "HARPER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482259007007",
    },
    {
        "school": "GARDEN CITY EL",
        "district": "GLASSCOCK COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482079002085",
    },
    {
        "school": "GARDEN CITY H S",
        "district": "GLASSCOCK COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482079002086",
    },
    {
        "school": "GONZALES EAST AVENUE PRI",
        "district": "GONZALES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482106002098",
    },
    {
        "school": "GONZALES H S",
        "district": "GONZALES ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482106002099",
    },
    {
        "school": "GONZALES J H",
        "district": "GONZALES ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482106002100",
    },
    {
        "school": "GONZALES NORTH AVENUE INT",
        "district": "GONZALES ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482106002101",
    },
    {
        "school": "GONZALES EL",
        "district": "GONZALES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482106008792",
    },
    {
        "school": "NIXON SMILEY EL",
        "district": "NIXON-SMILEY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483274003617",
    },
    {
        "school": "NIXON-SMILEY H S",
        "district": "NIXON-SMILEY CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483274003618",
    },
    {
        "school": "NIXON-SMILEY MIDDLE",
        "district": "NIXON-SMILEY CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483274005902",
    },
    {
        "school": "NIXON-SMILEY CISD DAEP",
        "district": "NIXON-SMILEY CISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483274007008",
    },
    {
        "school": "WAELDER SCHOOL",
        "district": "WAELDER ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484431005063",
    },
    {
        "school": "ANDERSON-SHIRO EL",
        "district": "ANDERSON-SHIRO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480823000192",
    },
    {
        "school": "ANDERSON-SHIRO JR/SR H S",
        "district": "ANDERSON-SHIRO CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480823000193",
    },
    {
        "school": "IOLA EL",
        "district": "IOLA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482424002700",
    },
    {
        "school": "IOLA H S",
        "district": "IOLA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482424002701",
    },
    {
        "school": "JOHN C WEBB EL",
        "district": "NAVASOTA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483219003569",
    },
    {
        "school": "NAVASOTA H S",
        "district": "NAVASOTA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483219003570",
    },
    {
        "school": "NAVASOTA J H",
        "district": "NAVASOTA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483219006019",
    },
    {
        "school": "RICHARDS EL",
        "district": "RICHARDS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483699004120",
    },
    {
        "school": "RICHARDS H S",
        "district": "RICHARDS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483699004121",
    },
    {
        "school": "AUSTIN EL",
        "district": "MEMPHIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483018003380",
    },
    {
        "school": "MEMPHIS H S",
        "district": "MEMPHIS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483018003381",
    },
    {
        "school": "MEMPHIS MIDDLE",
        "district": "MEMPHIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483018003382",
    },
    {
        "school": "TRAVIS EL",
        "district": "MEMPHIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483018003383",
    },
    {
        "school": "VALLEY SCHOOL",
        "district": "TURKEY-QUITAQUE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484340004926",
    },
    {
        "school": "HAMILTON H S",
        "district": "HAMILTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482223002232",
    },
    {
        "school": "ANN WHITNEY EL",
        "district": "HAMILTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482223005997",
    },
    {
        "school": "HAMILTON J H",
        "district": "HAMILTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482223008225",
    },
    {
        "school": "HICO H S",
        "district": "HICO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482307002345",
    },
    {
        "school": "HICO EL",
        "district": "HICO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482307021284",
    },
    {
        "school": "GRUVER EL",
        "district": "GRUVER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482193002209",
    },
    {
        "school": "GRUVER H S",
        "district": "GRUVER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482193002210",
    },
    {
        "school": "GRUVER J H",
        "district": "GRUVER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482193002211",
    },
    {
        "school": "PRINGLE-MORSE EL-J H",
        "district": "PRINGLE-MORSE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483589004061",
    },
    {
        "school": "GUS BIRDWELL EL",
        "district": "SPEARMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484101004663",
    },
    {
        "school": "SPEARMAN H S",
        "district": "SPEARMAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484101004664",
    },
    {
        "school": "SPEARMAN J H",
        "district": "SPEARMAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484101004665",
    },
    {
        "school": "CHILLICOTHE SCHOOL",
        "district": "CHILLICOTHE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481389000876",
    },
    {
        "school": "QUANAH H S",
        "district": "QUANAH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483618004067",
    },
    {
        "school": "REAGAN EL",
        "district": "QUANAH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483618004068",
    },
    {
        "school": "TRAVIS MIDDLE",
        "district": "QUANAH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483618004069",
    },
    {
        "school": "CHANNING SCHOOL",
        "district": "CHANNING ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481362000857",
    },
    {
        "school": "DALHART EL",
        "district": "DALHART ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481620001202",
    },
    {
        "school": "DALHART H S",
        "district": "DALHART ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481620001203",
    },
    {
        "school": "HARTLEY SCHOOL",
        "district": "HARTLEY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482268002302",
    },
    {
        "school": "HASKELL EL",
        "district": "HASKELL CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482274002304",
    },
    {
        "school": "HASKELL H S",
        "district": "HASKELL CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482274002305",
    },
    {
        "school": "PAINT CREEK SCHOOL",
        "district": "PAINT CREEK ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483396003777",
    },
    {
        "school": "RULE SCHOOL",
        "district": "RULE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483828004270",
    },
    {
        "school": "BAKER EL",
        "district": "CANADIAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481270000765",
    },
    {
        "school": "CANADIAN H S",
        "district": "CANADIAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481270000766",
    },
    {
        "school": "CANADIAN EL",
        "district": "CANADIAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481270005853",
    },
    {
        "school": "CANADIAN MIDDLE",
        "district": "CANADIAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481270005966",
    },
    {
        "school": "ABBOTT SCHOOL",
        "district": "ABBOTT ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480738000006",
    },
    {
        "school": "AQUILLA SCHOOL",
        "district": "AQUILLA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480852000218",
    },
    {
        "school": "BLUM ISD",
        "district": "BLUM ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481065000534",
    },
    {
        "school": "BYNUM SCHOOL",
        "district": "BYNUM ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481236000730",
    },
    {
        "school": "COVINGTON SCHOOL",
        "district": "COVINGTON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481548001121",
    },
    {
        "school": "FRANKLIN EL",
        "district": "HILLSBORO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482328002361",
    },
    {
        "school": "HILLSBORO H S",
        "district": "HILLSBORO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482328002363",
    },
    {
        "school": "HILLSBORO J H",
        "district": "HILLSBORO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482328002364",
    },
    {
        "school": "HILLSBORO EL",
        "district": "HILLSBORO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482328002365",
    },
    {
        "school": "HUBBARD EL",
        "district": "HUBBARD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482373002625",
    },
    {
        "school": "HUBBARD H S",
        "district": "HUBBARD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482373002626",
    },
    {
        "school": "ITASCA EL",
        "district": "ITASCA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482448002742",
    },
    {
        "school": "ITASCA H S",
        "district": "ITASCA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482448002743",
    },
    {
        "school": "HILL CO J J A E P",
        "district": "ITASCA ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482448008298",
    },
    {
        "school": "ITASCA MIDDLE",
        "district": "ITASCA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482448021363",
    },
    {
        "school": "MALONE EL",
        "district": "MALONE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482880003260",
    },
    {
        "school": "MOUNT CALM ISD",
        "district": "MOUNT CALM ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483162003529",
    },
    {
        "school": "PENELOPE SCHOOL",
        "district": "PENELOPE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483456003885",
    },
    {
        "school": "WHITNEY EL",
        "district": "WHITNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484572005194",
    },
    {
        "school": "WHITNEY H S",
        "district": "WHITNEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484572005195",
    },
    {
        "school": "WHITNEY MIDDLE",
        "district": "WHITNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484572005196",
    },
    {
        "school": "WHITNEY INT",
        "district": "WHITNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484572007658",
    },
    {
        "school": "P E P",
        "district": "AMHERST ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480816008318",
    },
    {
        "school": "P E P ALTER CO-OP",
        "district": "WHITEFACE CISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484557003333",
    },
    {
        "school": "CROCKETT EL",
        "district": "CROCKETT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481572001136",
    },
    {
        "school": "CROCKETT H S",
        "district": "CROCKETT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481572001137",
    },
    {
        "school": "CROCKETT J H",
        "district": "CROCKETT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481572001139",
    },
    {
        "school": "EARLY CHILDHOOD CTR",
        "district": "CROCKETT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481572007048",
    },
    {
        "school": "GRAPELAND EL",
        "district": "GRAPELAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482163002176",
    },
    {
        "school": "GRAPELAND H S",
        "district": "GRAPELAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482163002177",
    },
    {
        "school": "GRAPELAND J H",
        "district": "GRAPELAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482163002178",
    },
    {
        "school": "KENNARD ISD",
        "district": "KENNARD ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482547002836",
    },
    {
        "school": "LATEXO EL",
        "district": "LATEXO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482691003034",
    },
    {
        "school": "LATEXO H S",
        "district": "LATEXO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482691003035",
    },
    {
        "school": "LOVELADY EL",
        "district": "LOVELADY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482841003169",
    },
    {
        "school": "LOVELADY J H H S",
        "district": "LOVELADY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482841003170",
    },
    {
        "school": "DELL CITY SCHOOL",
        "district": "DELL CITY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481665001429",
    },
    {
        "school": "SIERRA BLANCA SCHOOL",
        "district": "SIERRA BLANCA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484020004558",
    },
    {
        "school": "BRYSON SCHOOL",
        "district": "BRYSON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481182000695",
    },
    {
        "school": "JACKSBORO EL",
        "district": "JACKSBORO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482453002745",
    },
    {
        "school": "JACKSBORO H S",
        "district": "JACKSBORO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482453002746",
    },
    {
        "school": "JACKSBORO MIDDLE",
        "district": "JACKSBORO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482453002747",
    },
    {
        "school": "PERRIN EL",
        "district": "PERRIN-WHITT CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483463003886",
    },
    {
        "school": "PERRIN H S",
        "district": "PERRIN-WHITT CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483463003887",
    },
    {
        "school": "EDNA H S",
        "district": "EDNA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481821001651",
    },
    {
        "school": "EDNA J H",
        "district": "EDNA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481821001652",
    },
    {
        "school": "GANADO EL",
        "district": "GANADO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482031002006",
    },
    {
        "school": "GANADO H S",
        "district": "GANADO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482031002007",
    },
    {
        "school": "BROOKELAND EL",
        "district": "BROOKELAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481152000624",
    },
    {
        "school": "BROOKELAND H S",
        "district": "BROOKELAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481152000625",
    },
    {
        "school": "BUNA EL",
        "district": "BUNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481209000704",
    },
    {
        "school": "BUNA H S",
        "district": "BUNA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481209000705",
    },
    {
        "school": "BUNA J H",
        "district": "BUNA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481209000706",
    },
    {
        "school": "EVADALE EL",
        "district": "EVADALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481875001752",
    },
    {
        "school": "EVADALE H S",
        "district": "EVADALE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481875001753",
    },
    {
        "school": "JASPER H S",
        "district": "JASPER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482463002758",
    },
    {
        "school": "JASPER J H",
        "district": "JASPER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482463002759",
    },
    {
        "school": "PARNELL EL",
        "district": "JASPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482463002760",
    },
    {
        "school": "JEAN C FEW PRI",
        "district": "JASPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482463008306",
    },
    {
        "school": "KIRBYVILLE EL",
        "district": "KIRBYVILLE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482571002893",
    },
    {
        "school": "KIRBYVILLE H S",
        "district": "KIRBYVILLE CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482571002894",
    },
    {
        "school": "KIRBYVILLE J H",
        "district": "KIRBYVILLE CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482571002895",
    },
    {
        "school": "FT DAVIS SCHOOL",
        "district": "FT DAVIS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482010001962",
    },
    {
        "school": "VALENTINE SCHOOL",
        "district": "VALENTINE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484374004975",
    },
    {
        "school": "HEBBRONVILLE EL",
        "district": "JIM HOGG COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482475002767",
    },
    {
        "school": "HEBBRONVILLE H S",
        "district": "JIM HOGG COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482475002768",
    },
    {
        "school": "HEBBRONVILLE J H",
        "district": "JIM HOGG COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482475002769",
    },
    {
        "school": "FALLS CITY EL",
        "district": "FALLS CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481902001773",
    },
    {
        "school": "FALLS CITY H S",
        "district": "FALLS CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481902001774",
    },
    {
        "school": "ROGER E SIDES EL",
        "district": "KARNES CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482514002802",
    },
    {
        "school": "KARNES CITY H S",
        "district": "KARNES CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482514002803",
    },
    {
        "school": "KARNES CITY J H",
        "district": "KARNES CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482514002804",
    },
    {
        "school": "KARNES CITY J J A E P",
        "district": "KARNES CITY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482514008314",
    },
    {
        "school": "KENEDY H S",
        "district": "KENEDY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482544002832",
    },
    {
        "school": "KENEDY MIDDLE",
        "district": "KENEDY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482544002834",
    },
    {
        "school": "KENEDY EL",
        "district": "KENEDY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482544006004",
    },
    {
        "school": "K ACADEMY",
        "district": "KENEDY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482544007051",
    },
    {
        "school": "FISD JJAEP",
        "district": "KENEDY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482544008315",
    },
    {
        "school": "RUNGE EL",
        "district": "RUNGE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483831004271",
    },
    {
        "school": "RUNGE H S",
        "district": "RUNGE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483831004272",
    },
    {
        "school": "FLORESVILLE ALTERNATIVE CENTER CHOICE PROGRAM",
        "district": "RUNGE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483831008682",
    },
    {
        "school": "JAYTON SCHOOLS",
        "district": "JAYTON-GIRARD ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482466002762",
    },
    {
        "school": "JUNCTION EL",
        "district": "JUNCTION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482502002795",
    },
    {
        "school": "JUNCTION H S",
        "district": "JUNCTION ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482502002796",
    },
    {
        "school": "JUNCTION MIDDLE",
        "district": "JUNCTION ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482502002797",
    },
    {
        "school": "GUTHRIE SCHOOL",
        "district": "GUTHRIE CSD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482202002217",
    },
    {
        "school": "BRACKETT H S",
        "district": "BRACKETT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481107000572",
    },
    {
        "school": "JONES ELEMENTARY/INTERMEDIATE SCHOOL",
        "district": "BRACKETT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481107000573",
    },
    {
        "school": "BRACKETT J H",
        "district": "BRACKETT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481107001638",
    },
    {
        "school": "BENJAMIN SCHOOL",
        "district": "BENJAMIN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480998000468",
    },
    {
        "school": "KNOX CITY SCHOOL",
        "district": "KNOX CITY-O'BRIEN CISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482587005526",
    },
    {
        "school": "MUNDAY EL",
        "district": "MUNDAY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483197003552",
    },
    {
        "school": "MUNDAY SECONDARY",
        "district": "MUNDAY CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483197003553",
    },
    {
        "school": "AMHERST SCHOOL",
        "district": "AMHERST ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480816000188",
    },
    {
        "school": "LITTLEFIELD H S",
        "district": "LITTLEFIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482775003112",
    },
    {
        "school": "LITTLEFIELD EL",
        "district": "LITTLEFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482775003113",
    },
    {
        "school": "LITTLEFIELD J H",
        "district": "LITTLEFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482775003115",
    },
    {
        "school": "LITTLEFIELD PRI",
        "district": "LITTLEFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482775005887",
    },
    {
        "school": "OLTON H S",
        "district": "OLTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483366003758",
    },
    {
        "school": "OLTON J H",
        "district": "OLTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483366003759",
    },
    {
        "school": "HP WEBB EL",
        "district": "OLTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483366003760",
    },
    {
        "school": "SPRINGLAKE-EARTH ELEM/MIDDLE SCHOOL",
        "district": "SPRINGLAKE-EARTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484125004723",
    },
    {
        "school": "SPRINGLAKE-EARTH H S",
        "district": "SPRINGLAKE-EARTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484125004724",
    },
    {
        "school": "SUDAN EL",
        "district": "SUDAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484176004760",
    },
    {
        "school": "SUDAN H S",
        "district": "SUDAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484176004761",
    },
    {
        "school": "P E P ALTER",
        "district": "SUDAN ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484176008966",
    },
    {
        "school": "COTULLA H S",
        "district": "COTULLA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481540001114",
    },
    {
        "school": "ENCINAL EL",
        "district": "COTULLA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481540001115",
    },
    {
        "school": "FRANK NEWMAN MIDDLE",
        "district": "COTULLA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481540006383",
    },
    {
        "school": "RAMIREZ-BURKS EL",
        "district": "COTULLA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481540006384",
    },
    {
        "school": "EZZELL EL",
        "district": "EZZELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481889001764",
    },
    {
        "school": "HALLETTSVILLE EL",
        "district": "HALLETTSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482212002222",
    },
    {
        "school": "HALLETTSVILLE H S",
        "district": "HALLETTSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482212002223",
    },
    {
        "school": "HALLETTSVILLE J H",
        "district": "HALLETTSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482212002224",
    },
    {
        "school": "MOULTON EL",
        "district": "MOULTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483156003527",
    },
    {
        "school": "MOULTON H S",
        "district": "MOULTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483156003528",
    },
    {
        "school": "SHINER EL",
        "district": "SHINER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484011004553",
    },
    {
        "school": "SHINER H S",
        "district": "SHINER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484011004554",
    },
    {
        "school": "SWEET HOME EL",
        "district": "SWEET HOME ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484200004782",
    },
    {
        "school": "VYSEHRAD EL",
        "district": "VYSEHRAD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484425005027",
    },
    {
        "school": "DIME BOX SCHOOL",
        "district": "DIME BOX ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481713001486",
    },
    {
        "school": "GIDDINGS EL",
        "district": "GIDDINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482064002074",
    },
    {
        "school": "GIDDINGS H S",
        "district": "GIDDINGS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482064002075",
    },
    {
        "school": "GIDDINGS MIDDLE",
        "district": "GIDDINGS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482064002076",
    },
    {
        "school": "GIDDINGS INT",
        "district": "GIDDINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482064007674",
    },
    {
        "school": "LEXINGTON EL",
        "district": "LEXINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482733003075",
    },
    {
        "school": "LEXINGTON H S",
        "district": "LEXINGTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482733003076",
    },
    {
        "school": "LEXINGTON MIDDLE",
        "district": "LEXINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482733006292",
    },
    {
        "school": "BUFFALO EL",
        "district": "BUFFALO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481199000700",
    },
    {
        "school": "BUFFALO H S",
        "district": "BUFFALO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481199000701",
    },
    {
        "school": "BUFFALO J H",
        "district": "BUFFALO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481199004922",
    },
    {
        "school": "CENTERVILLE EL",
        "district": "CENTERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481341000840",
    },
    {
        "school": "CENTERVILLE JR-SR H S",
        "district": "CENTERVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481341000841",
    },
    {
        "school": "LEON EL",
        "district": "LEON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482718003051",
    },
    {
        "school": "LEON H S",
        "district": "LEON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482718003052",
    },
    {
        "school": "NORMANGEE EL",
        "district": "NORMANGEE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483291003625",
    },
    {
        "school": "NORMANGEE H S",
        "district": "NORMANGEE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483291003626",
    },
    {
        "school": "OAKWOOD EL",
        "district": "OAKWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483334003741",
    },
    {
        "school": "OAKWOOD H S",
        "district": "OAKWOOD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483334003742",
    },
    {
        "school": "COOLIDGE EL",
        "district": "COOLIDGE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481512004950",
    },
    {
        "school": "COOLIDGE H S",
        "district": "COOLIDGE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481512021408",
    },
    {
        "school": "ENGE-WASHINGTON INT",
        "district": "GROESBECK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482181002201",
    },
    {
        "school": "GROESBECK H S",
        "district": "GROESBECK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482181002202",
    },
    {
        "school": "GROESBECK MIDDLE",
        "district": "GROESBECK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482181006708",
    },
    {
        "school": "A B MCBAY EL",
        "district": "MEXIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483042003424",
    },
    {
        "school": "MEXIA H S",
        "district": "MEXIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483042003425",
    },
    {
        "school": "MEXIA J H",
        "district": "MEXIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483042003426",
    },
    {
        "school": "R Q SIMS INT",
        "district": "MEXIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483042006302",
    },
    {
        "school": "DEVELOPMENTAL CTR",
        "district": "MEXIA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483042007028",
    },
    {
        "school": "KIRKSEY EL",
        "district": "BOOKER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481083000549",
    },
    {
        "school": "BOOKER JH/H S",
        "district": "BOOKER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481083000550",
    },
    {
        "school": "DARROUZETT SCHOOLS",
        "district": "DARROUZETT ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481632001699",
    },
    {
        "school": "FOLLETT SCHOOL",
        "district": "FOLLETT ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481950001806",
    },
    {
        "school": "HIGGINS SCHOOL",
        "district": "HIGGINS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482314002349",
    },
    {
        "school": "GEORGE WEST EL",
        "district": "GEORGE WEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482055002064",
    },
    {
        "school": "GEORGE WEST H S",
        "district": "GEORGE WEST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482055002065",
    },
    {
        "school": "GEORGE WEST J H",
        "district": "GEORGE WEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482055002066",
    },
    {
        "school": "GEORGE WEST PRI",
        "district": "GEORGE WEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482055002067",
    },
    {
        "school": "THREE RIVERS EL",
        "district": "THREE RIVERS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484269004873",
    },
    {
        "school": "THREE RIVERS JR/SR H S",
        "district": "THREE RIVERS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484269004874",
    },
    {
        "school": "LLANO EL",
        "district": "LLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482781003120",
    },
    {
        "school": "LLANO H S",
        "district": "LLANO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482781003121",
    },
    {
        "school": "LLANO J H",
        "district": "LLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482781003122",
    },
    {
        "school": "PACKSADDLE EL",
        "district": "LLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482781008323",
    },
    {
        "school": "NEW HOME SCHOOL",
        "district": "NEW HOME ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483249003605",
    },
    {
        "school": "O'DONNELL SCHOOL",
        "district": "O'DONNELL ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483339003748",
    },
    {
        "school": "TAHOKA H S",
        "district": "TAHOKA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484209004793",
    },
    {
        "school": "TAHOKA EL",
        "district": "TAHOKA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484209004794",
    },
    {
        "school": "TAHOKA MIDDLE",
        "district": "TAHOKA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484209005029",
    },
    {
        "school": "WILSON SCHOOL",
        "district": "WILSON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484599005241",
    },
    {
        "school": "BRADY H S",
        "district": "BRADY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481111000574",
    },
    {
        "school": "BRADY MIDDLE",
        "district": "BRADY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481111000575",
    },
    {
        "school": "BRADY EL",
        "district": "BRADY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481111000576",
    },
    {
        "school": "LOHN SCHOOL",
        "district": "LOHN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482793003132",
    },
    {
        "school": "ROCHELLE SCHOOL",
        "district": "ROCHELLE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483750004212",
    },
    {
        "school": "MCMULLEN COUNTY SCHOOL",
        "district": "MCMULLEN COUNTY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482994003368",
    },
    {
        "school": "MADISONVILLE EL",
        "district": "MADISONVILLE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482871003250",
    },
    {
        "school": "MADISONVILLE H S",
        "district": "MADISONVILLE CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482871003251",
    },
    {
        "school": "MADISONVILLE J H",
        "district": "MADISONVILLE CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482871003252",
    },
    {
        "school": "MADISONVILLE INT",
        "district": "MADISONVILLE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482871005774",
    },
    {
        "school": "NORTH ZULCH ELEMENTARY/SECONDARY",
        "district": "NORTH ZULCH ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483303003670",
    },
    {
        "school": "JEFFERSON EL",
        "district": "JEFFERSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482473002763",
    },
    {
        "school": "JEFFERSON H S",
        "district": "JEFFERSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482473002764",
    },
    {
        "school": "JEFFERSON J H",
        "district": "JEFFERSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482473002765",
    },
    {
        "school": "GRADY SCHOOL",
        "district": "GRADY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482130002131",
    },
    {
        "school": "STANTON EL",
        "district": "STANTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484143004739",
    },
    {
        "school": "STANTON H S",
        "district": "STANTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484143004740",
    },
    {
        "school": "STANTON MIDDLE",
        "district": "STANTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484143004741",
    },
    {
        "school": "MASON EL",
        "district": "MASON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482928003306",
    },
    {
        "school": "MASON H S",
        "district": "MASON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482928003307",
    },
    {
        "school": "MENARD H S",
        "district": "MENARD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483021003385",
    },
    {
        "school": "BUCKHOLTS SCHOOL",
        "district": "BUCKHOLTS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481185000697",
    },
    {
        "school": "CAMERON EL",
        "district": "CAMERON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481264000758",
    },
    {
        "school": "CAMERON MIDDLE",
        "district": "CAMERON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481264000760",
    },
    {
        "school": "CAMERON YOE H S",
        "district": "CAMERON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481264000762",
    },
    {
        "school": "BEN MILAM EL",
        "district": "CAMERON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481264007074",
    },
    {
        "school": "GAUSE EL",
        "district": "GAUSE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482052002063",
    },
    {
        "school": "MILANO H S",
        "district": "MILANO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483069003467",
    },
    {
        "school": "MILANO EL",
        "district": "MILANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483069005556",
    },
    {
        "school": "ROCKDALE EL",
        "district": "ROCKDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483759004215",
    },
    {
        "school": "ROCKDALE H S",
        "district": "ROCKDALE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483759004216",
    },
    {
        "school": "ROCKDALE J H",
        "district": "ROCKDALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483759004217",
    },
    {
        "school": "THORNDALE EL",
        "district": "THORNDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484263004869",
    },
    {
        "school": "THORNDALE H S",
        "district": "THORNDALE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484263004870",
    },
    {
        "school": "THORNDALE MIDDLE",
        "district": "THORNDALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484263007699",
    },
    {
        "school": "GOLDTHWAITE EL",
        "district": "GOLDTHWAITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482100002093",
    },
    {
        "school": "GOLDTHWAITE H S",
        "district": "GOLDTHWAITE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482100002094",
    },
    {
        "school": "GOLDTHWAITE MIDDLE",
        "district": "GOLDTHWAITE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482100008338",
    },
    {
        "school": "MULLIN MAIN",
        "district": "MULLIN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483192005557",
    },
    {
        "school": "PRIDDY SCHOOL",
        "district": "PRIDDY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483582004057",
    },
    {
        "school": "COLORADO H S",
        "district": "COLORADO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481464000951",
    },
    {
        "school": "LORAINE SCHOOL",
        "district": "LORAINE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482817003156",
    },
    {
        "school": "WESTBROOK SCHOOL",
        "district": "WESTBROOK ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484521005156",
    },
    {
        "school": "BOWIE H S",
        "district": "BOWIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481099000563",
    },
    {
        "school": "BOWIE J H",
        "district": "BOWIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481099000564",
    },
    {
        "school": "FORESTBURG SCHOOL",
        "district": "FORESTBURG ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481953001808",
    },
    {
        "school": "GOLD BURG SCHOOL",
        "district": "GOLD BURG ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482097002091",
    },
    {
        "school": "MONTAGUE EL",
        "district": "MONTAGUE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483120003510",
    },
    {
        "school": "NOCONA H S",
        "district": "NOCONA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483279003620",
    },
    {
        "school": "NOCONA EL",
        "district": "NOCONA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483279003622",
    },
    {
        "school": "NOCONA MIDDLE",
        "district": "NOCONA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483279006459",
    },
    {
        "school": "PRAIRIE VALLEY EL",
        "district": "PRAIRIE VALLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483573004043",
    },
    {
        "school": "PRAIRIE VALLEY H S",
        "district": "PRAIRIE VALLEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483573004044",
    },
    {
        "school": "SAINT JO EL",
        "district": "SAINT JO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483852004286",
    },
    {
        "school": "SAINT JO H S",
        "district": "SAINT JO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483852004287",
    },
    {
        "school": "DAINGERFIELD H S",
        "district": "DAINGERFIELD-LONE STAR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481618001196",
    },
    {
        "school": "DAINGERFIELD J H",
        "district": "DAINGERFIELD-LONE STAR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481618001197",
    },
    {
        "school": "WEST EL",
        "district": "DAINGERFIELD-LONE STAR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481618001200",
    },
    {
        "school": "SOUTH EL",
        "district": "DAINGERFIELD-LONE STAR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481618006389",
    },
    {
        "school": "PEWITT EL",
        "district": "PEWITT CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483480003901",
    },
    {
        "school": "PEWITT H S",
        "district": "PEWITT CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483480003902",
    },
    {
        "school": "PEWITT J H",
        "district": "PEWITT CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483480003903",
    },
    {
        "school": "MOTLEY COUNTY SCHOOL",
        "district": "MOTLEY COUNTY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483150003526",
    },
    {
        "school": "BURKEVILLE SCHOOL",
        "district": "BURKEVILLE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481215000713",
    },
    {
        "school": "DEWEYVILLE EL",
        "district": "DEWEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481701001472",
    },
    {
        "school": "DEWEYVILLE H S",
        "district": "DEWEYVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481701001473",
    },
    {
        "school": "NEWTON EL",
        "district": "NEWTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483273003614",
    },
    {
        "school": "NEWTON H S",
        "district": "NEWTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483273003615",
    },
    {
        "school": "NEWTON MIDDLE",
        "district": "NEWTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483273003616",
    },
    {
        "school": "PERRYTON KINDER",
        "district": "PERRYTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483465003888",
    },
    {
        "school": "PERRYTON H S",
        "district": "PERRYTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483465003889",
    },
    {
        "school": "PERRYTON J H",
        "district": "PERRYTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483465003890",
    },
    {
        "school": "JAMES L WRIGHT EL",
        "district": "PERRYTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483465003891",
    },
    {
        "school": "EDWIN F WILLIAMS INT",
        "district": "PERRYTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483465008347",
    },
    {
        "school": "LUDI PENA MARTIN ACCELERATED EDUCATION CENTER",
        "district": "PERRYTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483465009006",
    },
    {
        "school": "ADRIAN SCHOOL",
        "district": "ADRIAN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480750000042",
    },
    {
        "school": "MIMI FARLEY EL",
        "district": "BOYS RANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481104000570",
    },
    {
        "school": "BOYS RANCH H S",
        "district": "BOYS RANCH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481104000571",
    },
    {
        "school": "BLAKEMORE MIDDLE",
        "district": "BOYS RANCH ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481104005141",
    },
    {
        "school": "VEGA EL",
        "district": "VEGA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484398004990",
    },
    {
        "school": "VEGA H S",
        "district": "VEGA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484398004991",
    },
    {
        "school": "WILDORADO SCHOOL",
        "district": "WILDORADO ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484584005225",
    },
    {
        "school": "PANOLA CS",
        "district": "PANOLA CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480021308891",
    },
    {
        "school": "BECKVILLE SUNSET EL",
        "district": "BECKVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480969000436",
    },
    {
        "school": "BECKVILLE JR-SR HIGH SCHOOL",
        "district": "BECKVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480969000437",
    },
    {
        "school": "BAKER-KOONCE INT",
        "district": "CARTHAGE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481311000811",
    },
    {
        "school": "CARTHAGE H S",
        "district": "CARTHAGE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481311000812",
    },
    {
        "school": "LIBBY EL",
        "district": "CARTHAGE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481311000813",
    },
    {
        "school": "CARTHAGE J H",
        "district": "CARTHAGE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481311000814",
    },
    {
        "school": "CARTHAGE PRI",
        "district": "CARTHAGE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481311005419",
    },
    {
        "school": "GARY SCHOOL",
        "district": "GARY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482046002058",
    },
    {
        "school": "BOVINA EL",
        "district": "BOVINA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481095000558",
    },
    {
        "school": "BOVINA H S",
        "district": "BOVINA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481095000559",
    },
    {
        "school": "BOVINA MIDDLE",
        "district": "BOVINA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481095005161",
    },
    {
        "school": "FARWELL EL",
        "district": "FARWELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481911001780",
    },
    {
        "school": "FARWELL H S",
        "district": "FARWELL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481911001781",
    },
    {
        "school": "FARWELL J H",
        "district": "FARWELL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481911001782",
    },
    {
        "school": "FRIONA EL",
        "district": "FRIONA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481998001952",
    },
    {
        "school": "FRIONA H S",
        "district": "FRIONA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481998001953",
    },
    {
        "school": "FRIONA J H",
        "district": "FRIONA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481998001954",
    },
    {
        "school": "FRIONA PRI",
        "district": "FRIONA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481998006704",
    },
    {
        "school": "LAZBUDDIE SCHOOL",
        "district": "LAZBUDDIE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482697003038",
    },
    {
        "school": "BUENA VISTA SCHOOL",
        "district": "BUENA VISTA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481191000699",
    },
    {
        "school": "FORT STOCKTON INT",
        "district": "FORT STOCKTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482019001967",
    },
    {
        "school": "FORT STOCKTON APACHE EL",
        "district": "FORT STOCKTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482019001968",
    },
    {
        "school": "FORT STOCKTON HIGH",
        "district": "FORT STOCKTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482019001971",
    },
    {
        "school": "FORT STOCKTON MIDDLE",
        "district": "FORT STOCKTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482019001972",
    },
    {
        "school": "FORT STOCKTON ALAMO EL",
        "district": "FORT STOCKTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482019006411",
    },
    {
        "school": "IRAAN EL",
        "district": "IRAAN-SHEFFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482433002709",
    },
    {
        "school": "IRAAN H S",
        "district": "IRAAN-SHEFFIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482433002710",
    },
    {
        "school": "IRAAN J H",
        "district": "IRAAN-SHEFFIELD ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482433002711",
    },
    {
        "school": "BIG SANDY SCHOOL",
        "district": "BIG SANDY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481017000472",
    },
    {
        "school": "CORRIGAN-CAMDEN H S",
        "district": "CORRIGAN-CAMDEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481530001098",
    },
    {
        "school": "CORRIGAN-CAMDEN EL",
        "district": "CORRIGAN-CAMDEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481530001099",
    },
    {
        "school": "CORRIGAN-CAMDEN J H",
        "district": "CORRIGAN-CAMDEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481530006382",
    },
    {
        "school": "GOODRICH EL",
        "district": "GOODRICH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482109001873",
    },
    {
        "school": "GOODRICH H S",
        "district": "GOODRICH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482109002104",
    },
    {
        "school": "GOODRICH MIDDLE",
        "district": "GOODRICH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482109007709",
    },
    {
        "school": "LEGGETT EL",
        "district": "LEGGETT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482712003048",
    },
    {
        "school": "LEGGETT H S",
        "district": "LEGGETT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482712003049",
    },
    {
        "school": "TIMBER CREEK EL",
        "district": "LIVINGSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482778003117",
    },
    {
        "school": "LIVINGSTON H S",
        "district": "LIVINGSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482778003118",
    },
    {
        "school": "LIVINGSTON J H",
        "district": "LIVINGSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482778003119",
    },
    {
        "school": "PINE RIDGE PRI",
        "district": "LIVINGSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482778006579",
    },
    {
        "school": "ONALASKA EL",
        "district": "ONALASKA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483369003761",
    },
    {
        "school": "MARFA SCHOOLS",
        "district": "MARFA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482904003277",
    },
    {
        "school": "PRESIDIO EL",
        "district": "PRESIDIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483580004054",
    },
    {
        "school": "PRESIDIO H S",
        "district": "PRESIDIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483580004055",
    },
    {
        "school": "LUCY REDE FRANCO MIDDLE",
        "district": "PRESIDIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483580005906",
    },
    {
        "school": "RAINS EL",
        "district": "RAINS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483636004080",
    },
    {
        "school": "RAINS H S",
        "district": "RAINS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483636004081",
    },
    {
        "school": "RAINS J H",
        "district": "RAINS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483636004082",
    },
    {
        "school": "REAGAN COUNTY EL",
        "district": "REAGAN COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483657004100",
    },
    {
        "school": "REAGAN COUNTY H S",
        "district": "REAGAN COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483657004101",
    },
    {
        "school": "REAGAN COUNTY MIDDLE",
        "district": "REAGAN COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483657004102",
    },
    {
        "school": "BIG SPRINGS CHARTER SCHOOL",
        "district": "BIG SPRINGS CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480022709011",
    },
    {
        "school": "LEAKEY SCHOOL",
        "district": "LEAKEY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482700003040",
    },
    {
        "school": "AVERY EL",
        "district": "AVERY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480906000375",
    },
    {
        "school": "AVERY SECONDARY",
        "district": "AVERY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480906000376",
    },
    {
        "school": "CHEATHAM EL",
        "district": "CLARKSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481419000895",
    },
    {
        "school": "CLARKSVILLE MIDDLE AND H S",
        "district": "CLARKSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481419000896",
    },
    {
        "school": "DETROIT EL",
        "district": "DETROIT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481689001464",
    },
    {
        "school": "DETROIT H S",
        "district": "DETROIT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481689001465",
    },
    {
        "school": "DETROIT J H",
        "district": "DETROIT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481689007058",
    },
    {
        "school": "RIVERCREST H S",
        "district": "RIVERCREST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484212004797",
    },
    {
        "school": "RIVERCREST EL",
        "district": "RIVERCREST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484212009012",
    },
    {
        "school": "AUSTWELL-TIVOLI H S",
        "district": "AUSTWELL-TIVOLI ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480900000371",
    },
    {
        "school": "AUSTWELL-TIVOLI EL",
        "district": "AUSTWELL-TIVOLI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480900000372",
    },
    {
        "school": "REFUGIO H S",
        "district": "REFUGIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483678004111",
    },
    {
        "school": "REFUGIO EL",
        "district": "REFUGIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483678004112",
    },
    {
        "school": "WOODSBORO EL",
        "district": "WOODSBORO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484638005281",
    },
    {
        "school": "WOODSBORO H S",
        "district": "WOODSBORO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484638005282",
    },
    {
        "school": "BALLINGER EL",
        "district": "BALLINGER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480930000388",
    },
    {
        "school": "BALLINGER H S",
        "district": "BALLINGER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480930000389",
    },
    {
        "school": "BALLINGER J H",
        "district": "BALLINGER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480930000390",
    },
    {
        "school": "OLFEN SCHOOL",
        "district": "OLFEN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483357003754",
    },
    {
        "school": "VERIBEST SPECIAL PROGRAMS",
        "district": "OLFEN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483357009014",
    },
    {
        "school": "WINTERS EL",
        "district": "WINTERS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484626005275",
    },
    {
        "school": "WINTERS H S",
        "district": "WINTERS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484626005276",
    },
    {
        "school": "WINTERS J H",
        "district": "WINTERS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484626021472",
    },
    {
        "school": "HEMPHILL EL",
        "district": "HEMPHILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482289002318",
    },
    {
        "school": "HEMPHILL H S",
        "district": "HEMPHILL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482289002319",
    },
    {
        "school": "HEMPHILL MIDDLE",
        "district": "HEMPHILL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482289007424",
    },
    {
        "school": "WEST SABINE EL",
        "district": "WEST SABINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484518005153",
    },
    {
        "school": "WEST SABINE H S",
        "district": "WEST SABINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484518005154",
    },
    {
        "school": "BROADDUS H S",
        "district": "BROADDUS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481143000618",
    },
    {
        "school": "BROADDUS EL",
        "district": "BROADDUS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481143021477",
    },
    {
        "school": "SAN AUGUSTINE EL",
        "district": "SAN AUGUSTINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483876004413",
    },
    {
        "school": "SAN AUGUSTINE H S",
        "district": "SAN AUGUSTINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483876004414",
    },
    {
        "school": "CHEROKEE SCHOOL",
        "district": "CHEROKEE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481374000866",
    },
    {
        "school": "RICHLAND SPRINGS SCHOOL",
        "district": "RICHLAND SPRINGS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483708004169",
    },
    {
        "school": "SAN SABA EL",
        "district": "SAN SABA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483903004456",
    },
    {
        "school": "SAN SABA H S",
        "district": "SAN SABA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483903004457",
    },
    {
        "school": "SAN SABA MIDDLE",
        "district": "SAN SABA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483903004459",
    },
    {
        "school": "ELDORADO EL",
        "district": "SCHLEICHER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483951004491",
    },
    {
        "school": "ELDORADO H S",
        "district": "SCHLEICHER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483951004492",
    },
    {
        "school": "ELDORADO MIDDLE",
        "district": "SCHLEICHER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483951006325",
    },
    {
        "school": "ALBANY JR-SR H S",
        "district": "ALBANY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480768000054",
    },
    {
        "school": "NANCY SMITH EL",
        "district": "ALBANY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480768000055",
    },
    {
        "school": "MORAN SCHOOL",
        "district": "MORAN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483132003518",
    },
    {
        "school": "CENTER EL",
        "district": "CENTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481332000832",
    },
    {
        "school": "CENTER H S",
        "district": "CENTER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481332000833",
    },
    {
        "school": "CENTER MIDDLE",
        "district": "CENTER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481332000834",
    },
    {
        "school": "CENTER INT",
        "district": "CENTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481332000835",
    },
    {
        "school": "F L MOFFETT PRI",
        "district": "CENTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481332006665",
    },
    {
        "school": "EXCELSIOR EL",
        "district": "EXCELSIOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481884001762",
    },
    {
        "school": "JOAQUIN EL",
        "district": "JOAQUIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482481002773",
    },
    {
        "school": "JOAQUIN H S",
        "district": "JOAQUIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482481002774",
    },
    {
        "school": "JOAQUIN J H SCHOOL",
        "district": "JOAQUIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482481009018",
    },
    {
        "school": "SHELBYVILLE SCHOOL",
        "district": "SHELBYVILLE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483996004532",
    },
    {
        "school": "TIMPSON SCHOOL",
        "district": "TIMPSON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484284004886",
    },
    {
        "school": "MARY ALLEN EL",
        "district": "STRATFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484167004755",
    },
    {
        "school": "STRATFORD H S",
        "district": "STRATFORD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484167004756",
    },
    {
        "school": "STRATFORD J H",
        "district": "STRATFORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484167004757",
    },
    {
        "school": "TEXHOMA EL",
        "district": "TEXHOMA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484254004866",
    },
    {
        "school": "BRECKENRIDGE H S",
        "district": "BRECKENRIDGE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481122000595",
    },
    {
        "school": "BRECKENRIDGE J H",
        "district": "BRECKENRIDGE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481122000596",
    },
    {
        "school": "EAST EL",
        "district": "BRECKENRIDGE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481122000597",
    },
    {
        "school": "NORTH EL",
        "district": "BRECKENRIDGE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481122000598",
    },
    {
        "school": "SOUTH EL",
        "district": "BRECKENRIDGE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481122000599",
    },
    {
        "school": "ASPERMONT EL",
        "district": "ASPERMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000600274",
    },
    {
        "school": "ASPERMONT H S",
        "district": "ASPERMONT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000600275",
    },
    {
        "school": "SONORA H S",
        "district": "SONORA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484080004629",
    },
    {
        "school": "SONORA J H",
        "district": "SONORA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484080004630",
    },
    {
        "school": "HAPPY EL",
        "district": "HAPPY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482235002242",
    },
    {
        "school": "HAPPY H S",
        "district": "HAPPY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482235002243",
    },
    {
        "school": "KRESS EL",
        "district": "KRESS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482595002922",
    },
    {
        "school": "KRESS H S",
        "district": "KRESS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482595002923",
    },
    {
        "school": "TULIA H S",
        "district": "TULIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484332004918",
    },
    {
        "school": "TULIA EL",
        "district": "TULIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484332004919",
    },
    {
        "school": "TULIA J H",
        "district": "TULIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484332004920",
    },
    {
        "school": "SANDERSON SCHOOLS",
        "district": "TERRELL COUNTY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484242004837",
    },
    {
        "school": "BROWNFIELD H S",
        "district": "BROWNFIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481161000633",
    },
    {
        "school": "BROWNFIELD MIDDLE",
        "district": "BROWNFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481161000635",
    },
    {
        "school": "COLONIAL HEIGHTS EL",
        "district": "BROWNFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481161000636",
    },
    {
        "school": "OAK GROVE EL",
        "district": "BROWNFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481161000637",
    },
    {
        "school": "MEADOW SCHOOL",
        "district": "MEADOW ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483000003370",
    },
    {
        "school": "WELLMAN-UNION SCHOOL",
        "district": "WELLMAN-UNION CISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484491005114",
    },
    {
        "school": "THROCKMORTON COLLEGIATE ISD",
        "district": "THROCKMORTON COLLEGIATE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484278004880",
    },
    {
        "school": "WOODSON SCHOOL",
        "district": "WOODSON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484641005285",
    },
    {
        "school": "RIVERCREST J H",
        "district": "RIVERCREST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484212004798",
    },
    {
        "school": "APPLE SPRINGS EL",
        "district": "APPLE SPRINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480849000215",
    },
    {
        "school": "APPLE SPRINGS H S",
        "district": "APPLE SPRINGS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480849000216",
    },
    {
        "school": "CENTERVILLE H S",
        "district": "CENTERVILLE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481338000839",
    },
    {
        "school": "GROVETON EL",
        "district": "GROVETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482190002207",
    },
    {
        "school": "GROVETON J H-H S",
        "district": "GROVETON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482190002208",
    },
    {
        "school": "LANSBERRY EL",
        "district": "TRINITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484320004906",
    },
    {
        "school": "TRINITY H S",
        "district": "TRINITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484320004907",
    },
    {
        "school": "TRINITY J H",
        "district": "TRINITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484320006489",
    },
    {
        "school": "CHESTER EL",
        "district": "CHESTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481377000867",
    },
    {
        "school": "CHESTER H S",
        "district": "CHESTER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481377000868",
    },
    {
        "school": "COLMESNEIL EL",
        "district": "COLMESNEIL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481460000949",
    },
    {
        "school": "COLMESNEIL JH/HS",
        "district": "COLMESNEIL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481460000950",
    },
    {
        "school": "SPURGER EL",
        "district": "SPURGER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484134004733",
    },
    {
        "school": "SPURGER H S",
        "district": "SPURGER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484134004734",
    },
    {
        "school": "FRED EL",
        "district": "WARREN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484458005082",
    },
    {
        "school": "WARREN EL",
        "district": "WARREN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484458005083",
    },
    {
        "school": "WARREN H S",
        "district": "WARREN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484458005084",
    },
    {
        "school": "WARREN J H",
        "district": "WARREN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484458005085",
    },
    {
        "school": "WOODVILLE H S",
        "district": "WOODVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484644005286",
    },
    {
        "school": "WOODVILLE MIDDLE",
        "district": "WOODVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484644005287",
    },
    {
        "school": "WOODVILLE EL",
        "district": "WOODVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484644005288",
    },
    {
        "school": "WOODVILLE INT",
        "district": "WOODVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484644006058",
    },
    {
        "school": "MCCAMEY H S",
        "district": "MCCAMEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482970003346",
    },
    {
        "school": "MCCAMEY MIDDLE",
        "district": "MCCAMEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482970003347",
    },
    {
        "school": "MCCAMEY PRI",
        "district": "MCCAMEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482970003348",
    },
    {
        "school": "RANKIN SCHOOL",
        "district": "RANKIN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483651004093",
    },
    {
        "school": "RANCH ACADEMY",
        "district": "RANCH ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480017108398",
    },
    {
        "school": "CANTON EL",
        "district": "CANTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481275000768",
    },
    {
        "school": "CANTON H S",
        "district": "CANTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481275000769",
    },
    {
        "school": "CANTON J H",
        "district": "CANTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481275000770",
    },
    {
        "school": "CANTON INT",
        "district": "CANTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481275006832",
    },
    {
        "school": "EDGEWOOD EL",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481812001633",
    },
    {
        "school": "EDGEWOOD H S",
        "district": "EDGEWOOD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481812001634",
    },
    {
        "school": "EDGEWOOD MIDDLE",
        "district": "EDGEWOOD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481812006247",
    },
    {
        "school": "EDGEWOOD INT",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481812008947",
    },
    {
        "school": "HALLIE RANDALL EL",
        "district": "FRUITVALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482007001960",
    },
    {
        "school": "FRUITVALE H S",
        "district": "FRUITVALE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482007005476",
    },
    {
        "school": "FRUITVALE MIDDLE",
        "district": "FRUITVALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482007008071",
    },
    {
        "school": "GRAND SALINE EL",
        "district": "GRAND SALINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482145002165",
    },
    {
        "school": "GRAND SALINE H S",
        "district": "GRAND SALINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482145002166",
    },
    {
        "school": "GRAND SALINE MIDDLE",
        "district": "GRAND SALINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482145005483",
    },
    {
        "school": "GRAND SALINE INT",
        "district": "GRAND SALINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482145007472",
    },
    {
        "school": "VAN ZANDT CO YOUTH MULTI-SERVICE CTR",
        "district": "GRAND SALINE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482145008069",
    },
    {
        "school": "VAN ZANDT ALTERNATIVE EDUCATION PROG COOP",
        "district": "GRAND SALINE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482145008399",
    },
    {
        "school": "MARTINS MILL H S",
        "district": "MARTINS MILL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482922005776",
    },
    {
        "school": "RHODES EL",
        "district": "VAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484392004984",
    },
    {
        "school": "VAN H S",
        "district": "VAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484392004985",
    },
    {
        "school": "VAN J H",
        "district": "VAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484392004986",
    },
    {
        "school": "WILLS POINT PRI",
        "district": "WILLS POINT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484595005230",
    },
    {
        "school": "WILLS POINT H S",
        "district": "WILLS POINT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484595005231",
    },
    {
        "school": "WILLS POINT MIDDLE",
        "district": "WILLS POINT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484595005232",
    },
    {
        "school": "EARNEST O WOODS INT",
        "district": "WILLS POINT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484595006632",
    },
    {
        "school": "WILLS POINT J H",
        "district": "WILLS POINT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484595008070",
    },
    {
        "school": "GRANDFALLS-ROYALTY SCHOOL",
        "district": "GRANDFALLS-ROYALTY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482148002168",
    },
    {
        "school": "GEORGE CULLENDER KIND",
        "district": "MONAHANS-WICKETT-PYOTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483117003504",
    },
    {
        "school": "MONAHANS H S",
        "district": "MONAHANS-WICKETT-PYOTE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483117003505",
    },
    {
        "school": "WALKER J H",
        "district": "MONAHANS-WICKETT-PYOTE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483117003506",
    },
    {
        "school": "SUDDERTH EL",
        "district": "MONAHANS-WICKETT-PYOTE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483117003508",
    },
    {
        "school": "TATOM EL",
        "district": "MONAHANS-WICKETT-PYOTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483117003509",
    },
    {
        "school": "MONAHANS ED CTR",
        "district": "MONAHANS-WICKETT-PYOTE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483117007746",
    },
    {
        "school": "FORT ELLIOTT SCHOOL",
        "district": "FORT ELLIOTT CISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481140000616",
    },
    {
        "school": "KELTON SCHOOL",
        "district": "KELTON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482529005755",
    },
    {
        "school": "SHAMROCK H S",
        "district": "SHAMROCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483990004526",
    },
    {
        "school": "SHAMROCK MIDDLE",
        "district": "SHAMROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483990007750",
    },
    {
        "school": "SHAMROCK EL",
        "district": "SHAMROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483990007751",
    },
    {
        "school": "WHEELER SCHOOL",
        "district": "WHEELER ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484542005168",
    },
    {
        "school": "KERMIT H S",
        "district": "KERMIT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482556002845",
    },
    {
        "school": "KERMIT J H",
        "district": "KERMIT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482556002846",
    },
    {
        "school": "WINK EL",
        "district": "WINK-LOVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484617005268",
    },
    {
        "school": "WINK H S",
        "district": "WINK-LOVING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484617005269",
    },
    {
        "school": "ALBA-GOLDEN EL",
        "district": "ALBA-GOLDEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480765000052",
    },
    {
        "school": "ALBA-GOLDEN H S",
        "district": "ALBA-GOLDEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480765000053",
    },
    {
        "school": "ALTER SCHOOL",
        "district": "ALBA-GOLDEN ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480765007158",
    },
    {
        "school": "HAWKINS EL",
        "district": "HAWKINS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482277002307",
    },
    {
        "school": "HAWKINS H S / MIDDLE",
        "district": "HAWKINS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482277002308",
    },
    {
        "school": "MINEOLA PRI",
        "district": "MINEOLA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483093003478",
    },
    {
        "school": "MINEOLA EL",
        "district": "MINEOLA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483093003479",
    },
    {
        "school": "MINEOLA H S",
        "district": "MINEOLA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483093003480",
    },
    {
        "school": "MINEOLA MIDDLE",
        "district": "MINEOLA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483093003481",
    },
    {
        "school": "QUITMAN EL",
        "district": "QUITMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483630004077",
    },
    {
        "school": "QUITMAN H S",
        "district": "QUITMAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483630004078",
    },
    {
        "school": "QUITMAN J H",
        "district": "QUITMAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483630004079",
    },
    {
        "school": "MEMORIAL MIDDLE",
        "district": "WINNSBORO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484620005270",
    },
    {
        "school": "WINNSBORO H S",
        "district": "WINNSBORO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484620005272",
    },
    {
        "school": "WINNSBORO EL",
        "district": "WINNSBORO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484620005937",
    },
    {
        "school": "YANTIS SCHOOL",
        "district": "YANTIS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484659005298",
    },
    {
        "school": "KELLEY EL",
        "district": "DENVER CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481677001455",
    },
    {
        "school": "DENVER CITY H S",
        "district": "DENVER CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481677001456",
    },
    {
        "school": "WILLIAM G GRAVITT J H",
        "district": "DENVER CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481677001458",
    },
    {
        "school": "PLAINS EL",
        "district": "PLAINS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483504003941",
    },
    {
        "school": "PLAINS H S",
        "district": "PLAINS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483504003942",
    },
    {
        "school": "PLAINS MIDDLE",
        "district": "PLAINS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483504007102",
    },
    {
        "school": "GRAHAM H S",
        "district": "GRAHAM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482136002135",
    },
    {
        "school": "GRAHAM J H",
        "district": "GRAHAM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482136002136",
    },
    {
        "school": "GRAHAM EL",
        "district": "GRAHAM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482136002138",
    },
    {
        "school": "GRAHAM LEARNING CTR",
        "district": "GRAHAM ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482136021562",
    },
    {
        "school": "OLNEY EL",
        "district": "OLNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483363003755",
    },
    {
        "school": "OLNEY H S",
        "district": "OLNEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483363003756",
    },
    {
        "school": "OLNEY J H",
        "district": "OLNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483363003757",
    },
    {
        "school": "BENAVIDES EL",
        "district": "ZAPATA COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484671005349",
    },
    {
        "school": "ZAPATA H S",
        "district": "ZAPATA COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484671005351",
    },
    {
        "school": "ZAPATA MIDDLE",
        "district": "ZAPATA COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484671005352",
    },
    {
        "school": "DR TOMAS RIVERA EL",
        "district": "CRYSTAL CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481593001159",
    },
    {
        "school": "BENITO JUAREZ MIDDLE",
        "district": "CRYSTAL CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481593001160",
    },
    {
        "school": "CRYSTAL CITY H S",
        "district": "CRYSTAL CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481593001161",
    },
    {
        "school": "STERLING H FLY JR H S",
        "district": "CRYSTAL CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481593001162",
    },
    {
        "school": "LA PRYOR EL",
        "district": "LA PRYOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482625002960",
    },
    {
        "school": "LA PRYOR H S",
        "district": "LA PRYOR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482625002961",
    },
    {
        "school": "SOUTHLAND SCHOOL",
        "district": "SOUTHLAND ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484089004650",
    },
    {
        "school": "BRONTE ISD",
        "district": "BRONTE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481149000623",
    },
    {
        "school": "ROBERT LEE SCHOOL",
        "district": "ROBERT LEE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483738004196",
    },
    {
        "school": "ROBERT LEE EL",
        "district": "ROBERT LEE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483738007549",
    },
    {
        "school": "WALL SP PROG",
        "district": "ROBERT LEE ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483738008476",
    },
    {
        "school": "EDEN CISD",
        "district": "EDEN CISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481807001605",
    },
    {
        "school": "VERIBEST PPCD",
        "district": "EDEN CISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481807008497",
    },
    {
        "school": "MILES H S",
        "district": "MILES ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483075003471",
    },
    {
        "school": "MILES EL",
        "district": "MILES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483075006887",
    },
    {
        "school": "STERLING CITY SCHOOL",
        "district": "STERLING CITY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484155004749",
    },
    {
        "school": "FAIRVIEW DAEP",
        "district": "MILES ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483075008901",
    },
    {
        "school": "FAIRVIEW SPECIAL PROGRAMS",
        "district": "STERLING CITY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484155001935",
    },
    {
        "school": "FAIRVIEW ACCELERATED",
        "district": "STERLING CITY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484155009027",
    },
    {
        "school": "INDUSTRIAL H S",
        "district": "INDUSTRIAL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482415002690",
    },
    {
        "school": "INDUSTRIAL J H",
        "district": "INDUSTRIAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482415002691",
    },
    {
        "school": "INDUSTRIAL EL EAST",
        "district": "INDUSTRIAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482415002693",
    },
    {
        "school": "INDUSTRIAL EL WEST",
        "district": "INDUSTRIAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482415002692",
    },
    {
        "school": "MARLIN HIGH",
        "district": "MARLIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482913003284",
    },
    {
        "school": "BAIRD MIDDLE",
        "district": "BAIRD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480928011158",
    },
    {
        "school": "STAMFORD MIDDLE",
        "district": "STAMFORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484140009515",
    },
    {
        "school": "ADULT LEARNING CTR",
        "district": "ABILENE ISD",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480744009394",
    },
    {
        "school": "CROCKETT EARLY HEADSTART",
        "district": "ABILENE ISD",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480744009396",
    },
    {
        "school": "JUVENILE DETENTION CENTER",
        "district": "ABILENE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480744009497",
    },
    {
        "school": "OCEANS BEHAVIORAL HEALTH",
        "district": "ABILENE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480744011037",
    },
    {
        "school": "NEW J J A E P",
        "district": "JIM NED CISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482478011039",
    },
    {
        "school": "TAYLOR COUNTY LEARNING CENTER",
        "district": "MERKEL ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483034011038",
    },
    {
        "school": "TAYLOR COUNTY LEARNING CENTER",
        "district": "WYLIE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484650009398",
    },
    {
        "school": "BAIRD H S",
        "district": "BAIRD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480928000387",
    },
    {
        "school": "BAIRD EL",
        "district": "BAIRD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480928006360",
    },
    {
        "school": "CROSS PLAINS EL",
        "district": "CROSS PLAINS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481581001149",
    },
    {
        "school": "CROSS PLAINS H S",
        "district": "CROSS PLAINS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481581001150",
    },
    {
        "school": "EULA H S",
        "district": "EULA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481869001749",
    },
    {
        "school": "EULA J H",
        "district": "EULA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481869006852",
    },
    {
        "school": "EULA EL",
        "district": "EULA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481869021014",
    },
    {
        "school": "ANSON H S",
        "district": "ANSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480840000208",
    },
    {
        "school": "ANSON MIDDLE",
        "district": "ANSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480840000209",
    },
    {
        "school": "ANSON EL",
        "district": "ANSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480840000210",
    },
    {
        "school": "HAMLIN COLLEGIATE EL",
        "district": "HAMLIN COLLEGIATE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482226002234",
    },
    {
        "school": "HAMLIN COLLEGIATE H S",
        "district": "HAMLIN COLLEGIATE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482226002235",
    },
    {
        "school": "HAWLEY EL",
        "district": "HAWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482280002310",
    },
    {
        "school": "HAWLEY H S",
        "district": "HAWLEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482280002311",
    },
    {
        "school": "HAWLEY MIDDLE",
        "district": "HAWLEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482280007980",
    },
    {
        "school": "LUEDERS-AVOCA H S",
        "district": "LUEDERS-AVOCA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482853003223",
    },
    {
        "school": "LUEDERS-AVOCA EL/J H",
        "district": "LUEDERS-AVOCA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482853003224",
    },
    {
        "school": "OLIVER EL",
        "district": "STAMFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484140004735",
    },
    {
        "school": "STAMFORD H S",
        "district": "STAMFORD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484140004737",
    },
    {
        "school": "CLYDE EL",
        "district": "CLYDE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481445000934",
    },
    {
        "school": "CLYDE H S",
        "district": "CLYDE CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481445000935",
    },
    {
        "school": "CLYDE J H",
        "district": "CLYDE CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481445000936",
    },
    {
        "school": "CLYDE INT",
        "district": "CLYDE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481445005929",
    },
    {
        "school": "ABILENE H S",
        "district": "ABILENE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000010",
    },
    {
        "school": "AUSTIN EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000012",
    },
    {
        "school": "BONHAM EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000013",
    },
    {
        "school": "BOWIE EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000014",
    },
    {
        "school": "COOPER H S",
        "district": "ABILENE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000016",
    },
    {
        "school": "DYESS EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000018",
    },
    {
        "school": "JACKSON EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000022",
    },
    {
        "school": "JOHNSTON EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000024",
    },
    {
        "school": "LEE EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000026",
    },
    {
        "school": "MADISON MIDDLE",
        "district": "ABILENE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000030",
    },
    {
        "school": "MANN MIDDLE",
        "district": "ABILENE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000031",
    },
    {
        "school": "REAGAN EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000033",
    },
    {
        "school": "TAYLOR EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744000035",
    },
    {
        "school": "CLACK MIDDLE",
        "district": "ABILENE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744002231",
    },
    {
        "school": "WARD EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744002238",
    },
    {
        "school": "THOMAS EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744002241",
    },
    {
        "school": "ORTIZ EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744002354",
    },
    {
        "school": "BASSETTI EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744002371",
    },
    {
        "school": "WOODSON CENTER FOR EXCELLENCE",
        "district": "ABILENE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480744007123",
    },
    {
        "school": "DAEP",
        "district": "ABILENE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480744007449",
    },
    {
        "school": "TAYLOR COUNTY LEARNING CENTER",
        "district": "ABILENE ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480744009062",
    },
    {
        "school": "BUFFALO GAP EL",
        "district": "JIM NED CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482478002770",
    },
    {
        "school": "JIM NED H S",
        "district": "JIM NED CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482478002771",
    },
    {
        "school": "LAWN EL",
        "district": "JIM NED CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482478002772",
    },
    {
        "school": "JIM NED MIDDLE",
        "district": "JIM NED CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482478007734",
    },
    {
        "school": "MERKEL EL",
        "district": "MERKEL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483034003395",
    },
    {
        "school": "MERKEL H S",
        "district": "MERKEL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483034003396",
    },
    {
        "school": "MERKEL MIDDLE",
        "district": "MERKEL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483034003397",
    },
    {
        "school": "TRENT INDEPENDENT SCHOOL DISTRICT",
        "district": "TRENT ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484311004900",
    },
    {
        "school": "WYLIE WEST EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484650005292",
    },
    {
        "school": "WYLIE H S",
        "district": "WYLIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484650005293",
    },
    {
        "school": "WYLIE WEST J H",
        "district": "WYLIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484650005826",
    },
    {
        "school": "WYLIE WEST INT",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484650006926",
    },
    {
        "school": "LA GLORIA EL",
        "district": "LA GLORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482607002931",
    },
    {
        "school": "ADAMS MIDDLE",
        "district": "ALICE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480780000091",
    },
    {
        "school": "ALICE H S",
        "district": "ALICE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480780000092",
    },
    {
        "school": "DUBOSE INT",
        "district": "ALICE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480780000093",
    },
    {
        "school": "HILLCREST EL",
        "district": "ALICE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480780000095",
    },
    {
        "school": "MEMORIAL INT",
        "district": "ALICE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480780000096",
    },
    {
        "school": "NOONAN EL",
        "district": "ALICE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480780000098",
    },
    {
        "school": "SAENZ EL",
        "district": "ALICE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480780000099",
    },
    {
        "school": "SALAZAR EL",
        "district": "ALICE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480780000100",
    },
    {
        "school": "SCHALLERT EL",
        "district": "ALICE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480780000101",
    },
    {
        "school": "BEN BOLT-PALITO BLANCO H S",
        "district": "BEN BOLT-PALITO BLANCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480987000461",
    },
    {
        "school": "BEN BOLT-PALITO BLANCO EL",
        "district": "BEN BOLT-PALITO BLANCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480987000462",
    },
    {
        "school": "ORANGE GROVE PRI",
        "district": "ORANGE GROVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483372003762",
    },
    {
        "school": "ORANGE GROVE H S",
        "district": "ORANGE GROVE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483372003763",
    },
    {
        "school": "ORANGE GROVE J H",
        "district": "ORANGE GROVE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483372003764",
    },
    {
        "school": "PREMONT ERNEST H SINGLETON EARLY COLLEGE ACADEMY",
        "district": "PREMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483576004049",
    },
    {
        "school": "PREMONT COLLEGIATE H S",
        "district": "PREMONT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483576004050",
    },
    {
        "school": "LORENZO DE ZAVALA MIDDLE",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813010995",
    },
    {
        "school": "JOHNNY N ALLEN-6TH GRADE CAMPUS",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813010996",
    },
    {
        "school": "BUSHLAND H S",
        "district": "BUSHLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483557010997",
    },
    {
        "school": "GREENWAYS INT",
        "district": "CANYON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281009476",
    },
    {
        "school": "CANYON INT",
        "district": "CANYON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281010998",
    },
    {
        "school": "CLAUDE SCHOOLS",
        "district": "CLAUDE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481425000900",
    },
    {
        "school": "GRANDVIEW-HOPKINS EL",
        "district": "GRANDVIEW-HOPKINS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482156002172",
    },
    {
        "school": "GROOM SCHOOL",
        "district": "GROOM ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482184002205",
    },
    {
        "school": "PANHANDLE EL",
        "district": "PANHANDLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483423003804",
    },
    {
        "school": "PANHANDLE H S",
        "district": "PANHANDLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483423003805",
    },
    {
        "school": "PANHANDLE J H",
        "district": "PANHANDLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483423003806",
    },
    {
        "school": "WHITE DEER EL",
        "district": "WHITE DEER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484545005170",
    },
    {
        "school": "WHITE DEER H S",
        "district": "WHITE DEER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484545005171",
    },
    {
        "school": "AUSTIN MIDDLE",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000143",
    },
    {
        "school": "AVONDALE EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000144",
    },
    {
        "school": "BELMAR EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000145",
    },
    {
        "school": "BIVINS EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000146",
    },
    {
        "school": "BOWIE MIDDLE",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000148",
    },
    {
        "school": "EASTRIDGE EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000153",
    },
    {
        "school": "EMERSON EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000154",
    },
    {
        "school": "FOREST HILL EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000156",
    },
    {
        "school": "GLENWOOD EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000157",
    },
    {
        "school": "HAMLET EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000158",
    },
    {
        "school": "HOUSTON MIDDLE",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000159",
    },
    {
        "school": "HUMPHREY'S HIGHLAND EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000160",
    },
    {
        "school": "LAWNDALE EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000163",
    },
    {
        "school": "PARK HILLS EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000164",
    },
    {
        "school": "MANN MIDDLE",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000165",
    },
    {
        "school": "MESA VERDE EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000166",
    },
    {
        "school": "NORTH HEIGHTS ALTER",
        "district": "AMARILLO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480813000167",
    },
    {
        "school": "OAK DALE EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000168",
    },
    {
        "school": "OLSEN PARK EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000169",
    },
    {
        "school": "PALO DURO H S",
        "district": "AMARILLO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000170",
    },
    {
        "school": "PLEASANT VALLEY EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000172",
    },
    {
        "school": "ROGERS EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000175",
    },
    {
        "school": "SAN JACINTO EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000176",
    },
    {
        "school": "SANBORN EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000177",
    },
    {
        "school": "SUNRISE EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000180",
    },
    {
        "school": "TASCOSA H S",
        "district": "AMARILLO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000181",
    },
    {
        "school": "TRAVIS MIDDLE",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000182",
    },
    {
        "school": "WHITTIER EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000184",
    },
    {
        "school": "WILLS EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000185",
    },
    {
        "school": "WOLFLIN EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000186",
    },
    {
        "school": "AMARILLO AREA CTR FOR ADVANCED LRN",
        "district": "AMARILLO ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813007086",
    },
    {
        "school": "CARVER EARLY CHILDHOOD ACADEMY",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813008349",
    },
    {
        "school": "WOODLANDS EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813008350",
    },
    {
        "school": "HOMEBOUND",
        "district": "AMARILLO ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813009010",
    },
    {
        "school": "CARVER EL ACADEMY",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813021049",
    },
    {
        "school": "HIGHLAND PARK H S",
        "district": "HIGHLAND PARK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483556006160",
    },
    {
        "school": "HIGHLAND PARK EL",
        "district": "HIGHLAND PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483556006161",
    },
    {
        "school": "HIGHLAND PARK MIDDLE",
        "district": "HIGHLAND PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483556008898",
    },
    {
        "school": "BUSHLAND EL",
        "district": "BUSHLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483557005577",
    },
    {
        "school": "BUSHLAND MIDDLE",
        "district": "BUSHLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483557007057",
    },
    {
        "school": "RIVER ROAD H S",
        "district": "RIVER ROAD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483726004190",
    },
    {
        "school": "ROLLING HILLS EL",
        "district": "RIVER ROAD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483726004191",
    },
    {
        "school": "AMARILLO H S",
        "district": "AMARILLO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000142",
    },
    {
        "school": "BONHAM MIDDLE",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000147",
    },
    {
        "school": "CAPROCK H S",
        "district": "AMARILLO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000149",
    },
    {
        "school": "CORONADO EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000151",
    },
    {
        "school": "CROCKETT MIDDLE",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000152",
    },
    {
        "school": "FANNIN MIDDLE",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000155",
    },
    {
        "school": "LAMAR EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000161",
    },
    {
        "school": "LANDERGIN EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000162",
    },
    {
        "school": "PARAMOUNT TERRACE EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000171",
    },
    {
        "school": "PUCKETT EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000173",
    },
    {
        "school": "RIDGECREST EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000174",
    },
    {
        "school": "SOUTH GEORGIA EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000178",
    },
    {
        "school": "SOUTH LAWN EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000179",
    },
    {
        "school": "WESTERN PLATEAU EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813000183",
    },
    {
        "school": "SLEEPY HOLLOW EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813005641",
    },
    {
        "school": "WINDSOR EL",
        "district": "AMARILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813005642",
    },
    {
        "school": "CANYON H S",
        "district": "CANYON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281000774",
    },
    {
        "school": "CANYON J H",
        "district": "CANYON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281000775",
    },
    {
        "school": "GENE HOWE EL",
        "district": "CANYON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281000776",
    },
    {
        "school": "SUNDOWN LANE EL",
        "district": "CANYON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281000779",
    },
    {
        "school": "YOUTH CTR OF HIGH PLAINS",
        "district": "CANYON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481281005172",
    },
    {
        "school": "LAKEVIEW EL",
        "district": "CANYON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281006371",
    },
    {
        "school": "ARDEN ROAD EL",
        "district": "CANYON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281006372",
    },
    {
        "school": "RANDALL H S",
        "district": "CANYON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281006521",
    },
    {
        "school": "WESTOVER PARK J H",
        "district": "CANYON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281007088",
    },
    {
        "school": "CRESTVIEW EL",
        "district": "CANYON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281007090",
    },
    {
        "school": "REEVES-HINGER EL",
        "district": "CANYON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281007091",
    },
    {
        "school": "ANDREWS H S",
        "district": "ANDREWS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480828000194",
    },
    {
        "school": "ANDREWS MIDDLE",
        "district": "ANDREWS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480828000195",
    },
    {
        "school": "DEVONIAN EL",
        "district": "ANDREWS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480828000196",
    },
    {
        "school": "UNDERWOOD EL",
        "district": "ANDREWS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480828000199",
    },
    {
        "school": "CLEARFORK EL",
        "district": "ANDREWS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480828005844",
    },
    {
        "school": "ANDREWS EDUCATION CENTER",
        "district": "ANDREWS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480828007502",
    },
    {
        "school": "CHANDLER INT",
        "district": "BROWNSBORO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481164009292",
    },
    {
        "school": "LAPOYNOR J H",
        "district": "LAPOYNOR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482622009542",
    },
    {
        "school": "GATEWAY",
        "district": "MALAKOFF ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482878011281",
    },
    {
        "school": "TOOL EL",
        "district": "MALAKOFF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482878011405",
    },
    {
        "school": "ATHENS H S",
        "district": "ATHENS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480887000277",
    },
    {
        "school": "ATHENS MIDDLE",
        "district": "ATHENS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480887000278",
    },
    {
        "school": "BEL AIR EL",
        "district": "ATHENS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480887000279",
    },
    {
        "school": "SOUTH ATHENS EL",
        "district": "ATHENS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480887000281",
    },
    {
        "school": "CENTRAL ATHENS",
        "district": "ATHENS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480887000282",
    },
    {
        "school": "BROWNSBORO EL",
        "district": "BROWNSBORO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481164000638",
    },
    {
        "school": "BROWNSBORO H S",
        "district": "BROWNSBORO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481164000639",
    },
    {
        "school": "CHANDLER EL",
        "district": "BROWNSBORO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481164000640",
    },
    {
        "school": "BROWNSBORO J H",
        "district": "BROWNSBORO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481164005414",
    },
    {
        "school": "BROWNSBORO INT",
        "district": "BROWNSBORO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481164006516",
    },
    {
        "school": "CROSS ROADS EL",
        "district": "CROSS ROADS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481584001151",
    },
    {
        "school": "CROSS ROADS H S",
        "district": "CROSS ROADS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481584005434",
    },
    {
        "school": "CROSS ROADS J H",
        "district": "CROSS ROADS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481584006387",
    },
    {
        "school": "EUSTACE PRI",
        "district": "EUSTACE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481872001750",
    },
    {
        "school": "EUSTACE H S",
        "district": "EUSTACE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481872001751",
    },
    {
        "school": "EUSTACE MIDDLE",
        "district": "EUSTACE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481872006406",
    },
    {
        "school": "EUSTACE INT",
        "district": "EUSTACE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481872007344",
    },
    {
        "school": "LAPOYNOR EL",
        "district": "LAPOYNOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482622002958",
    },
    {
        "school": "LAPOYNOR H S",
        "district": "LAPOYNOR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482622002959",
    },
    {
        "school": "MALAKOFF EL",
        "district": "MALAKOFF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482878003257",
    },
    {
        "school": "MALAKOFF H S",
        "district": "MALAKOFF ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482878003258",
    },
    {
        "school": "MALAKOFF ALTERNATIVE PROGRAM (MAP)",
        "district": "MALAKOFF ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482878007959",
    },
    {
        "school": "MALAKOFF MIDDLE",
        "district": "MALAKOFF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482878021339",
    },
    {
        "school": "MURCHISON EL",
        "district": "MURCHISON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483201003555",
    },
    {
        "school": "TRINIDAD SCHOOL",
        "district": "TRINIDAD ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484317004904",
    },
    {
        "school": "OLYMPIA HILLS",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007111445",
    },
    {
        "school": "RAY EL",
        "district": "HUTTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482410011444",
    },
    {
        "school": "GRANDVIEW HILLS EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703011434",
    },
    {
        "school": "RIVER PLACE EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703011528",
    },
    {
        "school": "OAK MEADOWS EL",
        "district": "MANOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889011390",
    },
    {
        "school": "PRESIDENTIAL MEADOWS EL",
        "district": "MANOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889011409",
    },
    {
        "school": "DECKER MIDDLE",
        "district": "MANOR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889011453",
    },
    {
        "school": "MANOR NEW TECHNOLOGY HIGH",
        "district": "MANOR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889011568",
    },
    {
        "school": "CEDAR CREEK INT",
        "district": "BASTROP ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957009484",
    },
    {
        "school": "BLUEBONNET EL",
        "district": "BASTROP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957010390",
    },
    {
        "school": "LOST PINES EL",
        "district": "BASTROP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957010391",
    },
    {
        "school": "BASTROP COUNTY JUVENILE BOOT CAMP",
        "district": "ELGIN ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481836010392",
    },
    {
        "school": "BASTROP COUNTY JUVENILE BOOT CAMP",
        "district": "SMITHVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484055010394",
    },
    {
        "school": "BLUEBONNET EL",
        "district": "LOCKHART ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482787010471",
    },
    {
        "school": "TRINITY CHARTER SCHOOL",
        "district": "TRINITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480025910529",
    },
    {
        "school": "TRINITY CHARTER SCHOOL",
        "district": "TRINITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480025910532",
    },
    {
        "school": "TOBIAS EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001009290",
    },
    {
        "school": "LEHMAN H S",
        "district": "HAYS CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001009624",
    },
    {
        "school": "ARMANDO CHAPA MIDDLE",
        "district": "HAYS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001010804",
    },
    {
        "school": "D J RED SIMON MIDDLE",
        "district": "HAYS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001010805",
    },
    {
        "school": "LAURA B NEGLEY EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001010806",
    },
    {
        "school": "SCIENCE HALL EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001010807",
    },
    {
        "school": "BLANCO VISTA EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001010808",
    },
    {
        "school": "CAMINO REAL EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001010809",
    },
    {
        "school": "CARPENTER HILL EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001011534",
    },
    {
        "school": "WILLIAMSON COUNTY JUVENILE DETENTION CENTER",
        "district": "GRANGER ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482159011093",
    },
    {
        "school": "PATHWAYS 3H CAMPUS",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007109407",
    },
    {
        "school": "TNC CAMPUS (TEXAS NEUROREHABILITATION CENTER)",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007109408",
    },
    {
        "school": "METHODIST CHILDREN'S HOME",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007109513",
    },
    {
        "school": "DEPELCHIN-RICHMOND",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007111351",
    },
    {
        "school": "LAUREL RIDGE",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007111352",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - AUSTIN",
        "district": "HARMONY SCIENCE ACADEMY (AUSTIN)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024109409",
    },
    {
        "school": "UNIVERSITY OF TEXAS EL CHARTER SCHOOL",
        "district": "UNIVERSITY OF TEXAS ELEMENTARY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480025109530",
    },
    {
        "school": "TEXAS SCHOOL FOR THE BLIND",
        "district": "TEXAS SCH FOR THE BLIND & VISUALLY IMPAIRED",
        "level": "Other",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "480025209536",
    },
    {
        "school": "TEXAS SCHOOL FOR THE DEAF",
        "district": "TEXAS SCH FOR THE DEAF",
        "level": "Other",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "480025309537",
    },
    {
        "school": "KIPP AUSTIN COLLEGE PREP",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026411055",
    },
    {
        "school": "AUSTIN DISCOVERY SCH",
        "district": "AUSTIN DISCOVERY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026511056",
    },
    {
        "school": "INTERNATIONAL H S",
        "district": "AUSTIN ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894011057",
    },
    {
        "school": "GORZYCKI MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011059",
    },
    {
        "school": "SOUTHEAST MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011060",
    },
    {
        "school": "CLAYTON EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011061",
    },
    {
        "school": "BLAZIER EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011062",
    },
    {
        "school": "GUERRERO THOMPSON",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011063",
    },
    {
        "school": "BALDWIN EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011064",
    },
    {
        "school": "PADRON EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011065",
    },
    {
        "school": "OVERTON EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011066",
    },
    {
        "school": "PEREZ EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011067",
    },
    {
        "school": "DEL VALLE EL",
        "district": "DEL VALLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662009413",
    },
    {
        "school": "JOHN P OJEDA MIDDLE",
        "district": "DEL VALLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662009527",
    },
    {
        "school": "TRAVIS CO J J A E P",
        "district": "EANES ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481776011068",
    },
    {
        "school": "NEIDIG EL",
        "district": "ELGIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481836010393",
    },
    {
        "school": "LAKE POINTE EL",
        "district": "LAKE TRAVIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482647009414",
    },
    {
        "school": "SERENE HILLS EL",
        "district": "LAKE TRAVIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482647011479",
    },
    {
        "school": "WILHELMINA DELCO EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483009411",
    },
    {
        "school": "CALDWELL EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483009412",
    },
    {
        "school": "HENDRICKSON H S",
        "district": "PFLUGERVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483009531",
    },
    {
        "school": "ROWE LANE EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483011357",
    },
    {
        "school": "WIELAND EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483011514",
    },
    {
        "school": "WILLIAMSON CO JUVENILE DETENTION CENTER",
        "district": "FLORENCE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481932009566",
    },
    {
        "school": "JO ANN FORD EL",
        "district": "GEORGETOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060011092",
    },
    {
        "school": "NADINE JOHNSON EL",
        "district": "HUTTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482410009478",
    },
    {
        "school": "WILLIAMSON COUNTY CORE/JJAEP",
        "district": "HUTTO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482410011094",
    },
    {
        "school": "WILLIAMSON COUNTY JUVENILE DETENTION CENTER",
        "district": "HUTTO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482410011095",
    },
    {
        "school": "WILLIAMSON CO J J A E P",
        "district": "JARRELL ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482460009477",
    },
    {
        "school": "VISTA RIDGE H S",
        "district": "LEANDER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703009436",
    },
    {
        "school": "NEW HOPE H S",
        "district": "LEANDER ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482703009437",
    },
    {
        "school": "WILLIAMSON COUNTY DETENTION CENTER",
        "district": "LEANDER ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482703009438",
    },
    {
        "school": "ARTIE L HENRY MIDDLE",
        "district": "LEANDER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703009439",
    },
    {
        "school": "LAURA WELCH BUSH EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703009440",
    },
    {
        "school": "PATRICIA KNOWLES EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703009656",
    },
    {
        "school": "CANYON RIDGE MIDDLE",
        "district": "LEANDER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703011110",
    },
    {
        "school": "DEER CREEK EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703011111",
    },
    {
        "school": "PLEASANT HILL EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703011112",
    },
    {
        "school": "RUTLEDGE EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703011113",
    },
    {
        "school": "TRAVIS CO J J A E P",
        "district": "LEANDER ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482703011516",
    },
    {
        "school": "WILLIAMSON COUNTY CORE/JJAEP",
        "district": "LIBERTY HILL ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482742009428",
    },
    {
        "school": "WILLIAMSON COUNTY JUVENILE DETENTION CENTER",
        "district": "LIBERTY HILL ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482742009475",
    },
    {
        "school": "WILLIAMSON COUNTY JUV DETENTION CENTER",
        "district": "ROUND ROCK ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483808009429",
    },
    {
        "school": "UNION HILL EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808009431",
    },
    {
        "school": "EL DAEP",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483808009461",
    },
    {
        "school": "CEDAR RIDGE H S",
        "district": "ROUND ROCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808011097",
    },
    {
        "school": "NEW MIDDLE AT MCNEIL",
        "district": "ROUND ROCK ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808011098",
    },
    {
        "school": "NEW MIDDLE #9 AT GULF WAY",
        "district": "ROUND ROCK ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808011099",
    },
    {
        "school": "JAMES GARLAND WALSH MIDDLE",
        "district": "ROUND ROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808011100",
    },
    {
        "school": "JOE LEE JOHNSON EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808011101",
    },
    {
        "school": "TERAVISTA EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808011102",
    },
    {
        "school": "NEW EL AT RYANS CROSSING",
        "district": "ROUND ROCK ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808011103",
    },
    {
        "school": "PATSY SOMMER EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808011104",
    },
    {
        "school": "CHANDLER OAKS EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808011105",
    },
    {
        "school": "NEYSA CALLISON EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808011106",
    },
    {
        "school": "LINDA HERRINGTON EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808011107",
    },
    {
        "school": "WILLIAMSON COUNTY JUVENILE DETENTION CENTER",
        "district": "TAYLOR ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484228009432",
    },
    {
        "school": "WILLIAMSON COUNTY CORE/JJAEP",
        "district": "THRALL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484266009433",
    },
    {
        "school": "WILLIAMSON COUNTY JUVENILE DETENTION",
        "district": "THRALL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484266009434",
    },
    {
        "school": "THRALL MIDDLE",
        "district": "THRALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484266009435",
    },
    {
        "school": "LOTT DETENTION CENTER",
        "district": "JARRELL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482460011096",
    },
    {
        "school": "EMILE EL",
        "district": "BASTROP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957000408",
    },
    {
        "school": "BASTROP H S",
        "district": "BASTROP ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957000409",
    },
    {
        "school": "BASTROP MIDDLE",
        "district": "BASTROP ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957000410",
    },
    {
        "school": "MINA EL",
        "district": "BASTROP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957000411",
    },
    {
        "school": "CEDAR CREEK EL",
        "district": "BASTROP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957002476",
    },
    {
        "school": "BASTROP INT",
        "district": "BASTROP ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957005709",
    },
    {
        "school": "CEDAR CREEK MIDDLE",
        "district": "BASTROP ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957008692",
    },
    {
        "school": "RED ROCK EL",
        "district": "BASTROP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957008693",
    },
    {
        "school": "GENESIS H S",
        "district": "BASTROP ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480957021082",
    },
    {
        "school": "BOOKER T WASHINGTON EL",
        "district": "ELGIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481836001727",
    },
    {
        "school": "ELGIN MIDDLE",
        "district": "ELGIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481836001729",
    },
    {
        "school": "ELGIN EL",
        "district": "ELGIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481836001730",
    },
    {
        "school": "PHOENIX H S",
        "district": "ELGIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481836008426",
    },
    {
        "school": "MCDADE EL",
        "district": "MCDADE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482976003351",
    },
    {
        "school": "BROWN PRI",
        "district": "SMITHVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484055004588",
    },
    {
        "school": "SMITHVILLE EL",
        "district": "SMITHVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484055004589",
    },
    {
        "school": "SMITHVILLE H S",
        "district": "SMITHVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484055004590",
    },
    {
        "school": "SMITHVILLE J H",
        "district": "SMITHVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484055004591",
    },
    {
        "school": "LOCKHART H S",
        "district": "LOCKHART ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482787003123",
    },
    {
        "school": "NAVARRO EL",
        "district": "LOCKHART ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482787003124",
    },
    {
        "school": "GEORGE W CARVER EARLY EDUCATION CENTER",
        "district": "LOCKHART ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482787003126",
    },
    {
        "school": "CLEAR FORK EL",
        "district": "LOCKHART ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482787003127",
    },
    {
        "school": "PLUM CREEK EL",
        "district": "LOCKHART ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482787006293",
    },
    {
        "school": "LOCKHART J H",
        "district": "LOCKHART ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482787008716",
    },
    {
        "school": "LOCKHART PRIDE H S",
        "district": "LOCKHART ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482787021148",
    },
    {
        "school": "LEONARD SHANKLIN EL",
        "district": "LULING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482859003238",
    },
    {
        "school": "LULING H S",
        "district": "LULING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482859003239",
    },
    {
        "school": "GILBERT GERDES J H",
        "district": "LULING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482859006141",
    },
    {
        "school": "PRAIRIE LEA SCHOOL",
        "district": "PRAIRIE LEA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483570004042",
    },
    {
        "school": "DRIPPING SPRINGS EL",
        "district": "DRIPPING SPRINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000801507",
    },
    {
        "school": "DRIPPING SPRINGS H S",
        "district": "DRIPPING SPRINGS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000801508",
    },
    {
        "school": "DRIPPING SPRINGS MIDDLE",
        "district": "DRIPPING SPRINGS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000806094",
    },
    {
        "school": "WALNUT SPRINGS EL",
        "district": "DRIPPING SPRINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000806989",
    },
    {
        "school": "JACOB'S WELL EL",
        "district": "WIMBERLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000905246",
    },
    {
        "school": "WIMBERLEY H S",
        "district": "WIMBERLEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000906198",
    },
    {
        "school": "SCUDDER PRI",
        "district": "WIMBERLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000906499",
    },
    {
        "school": "DANFORTH J H",
        "district": "WIMBERLEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000907342",
    },
    {
        "school": "JACK C HAYS H S",
        "district": "HAYS CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001005244",
    },
    {
        "school": "KYLE EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001005245",
    },
    {
        "school": "R C BARTON MIDDLE",
        "district": "HAYS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001006199",
    },
    {
        "school": "TOM GREEN EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001006346",
    },
    {
        "school": "ALTER IMPACT CTR",
        "district": "HAYS CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001006990",
    },
    {
        "school": "BUDA EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001007343",
    },
    {
        "school": "LIVE OAK ACADEMY",
        "district": "HAYS CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001008835",
    },
    {
        "school": "ERIC DAHLSTROM MIDDLE",
        "district": "HAYS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001008836",
    },
    {
        "school": "LAURA B WALLACE MIDDLE",
        "district": "HAYS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001008837",
    },
    {
        "school": "ELM GROVE EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001008838",
    },
    {
        "school": "SUSIE FUENTES EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001008839",
    },
    {
        "school": "HEMPHILL EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001008840",
    },
    {
        "school": "KATHERINE ANNE PORTER SCHOOL",
        "district": "KATHERINE ANNE PORTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480013208279",
    },
    {
        "school": "TEXAS PREPARATORY SCHOOL",
        "district": "TEXAS PREPARATORY SCHOOL",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480019408645",
    },
    {
        "school": "BOWIE EL",
        "district": "SAN MARCOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483897004448",
    },
    {
        "school": "CROCKETT EL",
        "district": "SAN MARCOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483897004449",
    },
    {
        "school": "GOODNIGHT MIDDLE",
        "district": "SAN MARCOS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483897004450",
    },
    {
        "school": "HERNANDEZ EL",
        "district": "SAN MARCOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483897004451",
    },
    {
        "school": "SAN MARCOS H S",
        "district": "SAN MARCOS CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483897004452",
    },
    {
        "school": "TRAVIS EL",
        "district": "SAN MARCOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483897004453",
    },
    {
        "school": "DEZAVALA EL",
        "district": "SAN MARCOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483897006322",
    },
    {
        "school": "WAYSIDE EDEN PARK ACADEMY",
        "district": "WAYSIDE SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480004408055",
    },
    {
        "school": "NYOS CHARTER SCHOOL",
        "district": "NYOS CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480005808056",
    },
    {
        "school": "NYOS - MAGNOLIA MCCULLOUGH CAMPUS",
        "district": "NYOS CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480005809070",
    },
    {
        "school": "CHAPARRAL STAR ACADEMY",
        "district": "CHAPARRAL STAR ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006408059",
    },
    {
        "school": "TEXAS EMPOWERMENT ACADEMY",
        "district": "TEXAS EMPOWERMENT ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006608057",
    },
    {
        "school": "SETTLEMENT HOME",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007108383",
    },
    {
        "school": "PATHFINDER CAMP",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007108932",
    },
    {
        "school": "GEORGE M KOZMETSKY SCHOOL",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007109072",
    },
    {
        "school": "CEDARS INTERNATIONAL ACADEMY",
        "district": "CEDARS INTERNATIONAL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023209075",
    },
    {
        "school": "ALLISON EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000291",
    },
    {
        "school": "ANDERSON H S",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000292",
    },
    {
        "school": "ANDREWS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000293",
    },
    {
        "school": "AUSTIN H S",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000294",
    },
    {
        "school": "BARRINGTON EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000296",
    },
    {
        "school": "BARTON HILLS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000297",
    },
    {
        "school": "BECKER EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000298",
    },
    {
        "school": "BEDICHEK MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000299",
    },
    {
        "school": "BLACKSHEAR EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000300",
    },
    {
        "school": "BLANTON EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000301",
    },
    {
        "school": "BRENTWOOD EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000302",
    },
    {
        "school": "BROOKE EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000303",
    },
    {
        "school": "BROWN EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000304",
    },
    {
        "school": "BRYKER WOODS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000305",
    },
    {
        "school": "BURNET MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000306",
    },
    {
        "school": "CAMPBELL EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000307",
    },
    {
        "school": "CASIS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000308",
    },
    {
        "school": "COOK EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000309",
    },
    {
        "school": "CROCKETT ECHS",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000310",
    },
    {
        "school": "CUNNINGHAM EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000311",
    },
    {
        "school": "DAWSON EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000312",
    },
    {
        "school": "DOBIE MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000313",
    },
    {
        "school": "DOSS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000314",
    },
    {
        "school": "LIVELY MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000315",
    },
    {
        "school": "GOVALLE EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000316",
    },
    {
        "school": "GRAHAM EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000317",
    },
    {
        "school": "GULLETT EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000318",
    },
    {
        "school": "HARRIS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000319",
    },
    {
        "school": "HIGHLAND PARK EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000320",
    },
    {
        "school": "HILL EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000321",
    },
    {
        "school": "HOUSTON EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000322",
    },
    {
        "school": "JOSLIN EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000325",
    },
    {
        "school": "LAMAR M S",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000326",
    },
    {
        "school": "NAVARRO EARLY COLLEGE H S",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000327",
    },
    {
        "school": "LEE EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000328",
    },
    {
        "school": "LINDER EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000329",
    },
    {
        "school": "MAPLEWOOD EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000330",
    },
    {
        "school": "MARTIN MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000331",
    },
    {
        "school": "MATHEWS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000332",
    },
    {
        "school": "MCCALLUM H S",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000333",
    },
    {
        "school": "MENCHACA EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000334",
    },
    {
        "school": "METZ EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000335",
    },
    {
        "school": "MURCHISON MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000336",
    },
    {
        "school": "NORMAN EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000337",
    },
    {
        "school": "O HENRY MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000338",
    },
    {
        "school": "OAK HILL EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000339",
    },
    {
        "school": "OAK SPRINGS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000340",
    },
    {
        "school": "ODOM EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000341",
    },
    {
        "school": "ORTEGA EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000342",
    },
    {
        "school": "PEASE EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000344",
    },
    {
        "school": "PECAN SPRINGS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000345",
    },
    {
        "school": "PILLOW EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000346",
    },
    {
        "school": "PLEASANT HILL EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000347",
    },
    {
        "school": "NORTHEAST EARLY COLLEGE H S",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000350",
    },
    {
        "school": "REILLY EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000351",
    },
    {
        "school": "RIDGETOP EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000352",
    },
    {
        "school": "SANCHEZ EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000355",
    },
    {
        "school": "SIMS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000356",
    },
    {
        "school": "ST ELMO EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000357",
    },
    {
        "school": "SUMMITT EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000358",
    },
    {
        "school": "SUNSET VALLEY EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000359",
    },
    {
        "school": "TRAVIS EARLY COLLEGE H S",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000360",
    },
    {
        "school": "TRAVIS HTS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000361",
    },
    {
        "school": "WALNUT CREEK EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000362",
    },
    {
        "school": "WILLIAMS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000364",
    },
    {
        "school": "WINN EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000365",
    },
    {
        "school": "WOOLDRIDGE EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000366",
    },
    {
        "school": "WOOTEN EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000367",
    },
    {
        "school": "ZAVALA EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000368",
    },
    {
        "school": "ZILKER EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894000369",
    },
    {
        "school": "WEBB M S",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894002468",
    },
    {
        "school": "JORDAN EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894002470",
    },
    {
        "school": "KIKER EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894002776",
    },
    {
        "school": "ANITA FERRALES COY FACILITY",
        "district": "AUSTIN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894005394",
    },
    {
        "school": "ROSEDALE",
        "district": "AUSTIN ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894005396",
    },
    {
        "school": "LANGFORD EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894005398",
    },
    {
        "school": "BAILEY MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894005486",
    },
    {
        "school": "AUSTIN ST HOSPITAL",
        "district": "AUSTIN ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894005646",
    },
    {
        "school": "PATTON EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894006070",
    },
    {
        "school": "KEALING M S",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894006207",
    },
    {
        "school": "COVINGTON MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894006208",
    },
    {
        "school": "MENDEZ MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894006209",
    },
    {
        "school": "BOONE EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894006210",
    },
    {
        "school": "PALM EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894006211",
    },
    {
        "school": "KOCUREK EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894006212",
    },
    {
        "school": "WIDEN EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894006213",
    },
    {
        "school": "DAEP- EL",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894006356",
    },
    {
        "school": "BOWIE H S",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894006508",
    },
    {
        "school": "GALINDO EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894006509",
    },
    {
        "school": "LEADERSHIP ACADEMY",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894007137",
    },
    {
        "school": "TRAVIS COUNTY J J A E P",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894007741",
    },
    {
        "school": "GARZA INDEPENDENCE H S",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894008060",
    },
    {
        "school": "HART EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894008061",
    },
    {
        "school": "MILLS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894008062",
    },
    {
        "school": "PHOENIX ACADEMY",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894008389",
    },
    {
        "school": "SMALL MIDDLE",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894008390",
    },
    {
        "school": "CASEY EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894008391",
    },
    {
        "school": "RODRIGUEZ EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894008392",
    },
    {
        "school": "BARANOFF EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894008393",
    },
    {
        "school": "AKINS H S",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894008937",
    },
    {
        "school": "PAREDES M S",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894008938",
    },
    {
        "school": "MCBEE EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894008939",
    },
    {
        "school": "COWAN EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894008940",
    },
    {
        "school": "ALTERNATIVE LEARNING CENTER",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894009076",
    },
    {
        "school": "TRAVIS COUNTY JUVENILE DETENTION CENTER",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894009077",
    },
    {
        "school": "PICKLE EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894009078",
    },
    {
        "school": "DEL VALLE H S",
        "district": "DEL VALLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662001424",
    },
    {
        "school": "DEL VALLE MIDDLE",
        "district": "DEL VALLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662001425",
    },
    {
        "school": "POPHAM EL",
        "district": "DEL VALLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662001426",
    },
    {
        "school": "SMITH EL",
        "district": "DEL VALLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662001427",
    },
    {
        "school": "HILLCREST EL",
        "district": "DEL VALLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662005695",
    },
    {
        "school": "BATY EL",
        "district": "DEL VALLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662006091",
    },
    {
        "school": "HORNSBY-DUNLAP EL",
        "district": "DEL VALLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662006534",
    },
    {
        "school": "TRAVIS CO J J A E P",
        "district": "DEL VALLE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481662007743",
    },
    {
        "school": "DEL VALLE OPPORTUNITY CTR",
        "district": "DEL VALLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481662021529",
    },
    {
        "school": "CEDAR CREEK EL",
        "district": "EANES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481776001546",
    },
    {
        "school": "EANES EL",
        "district": "EANES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481776001547",
    },
    {
        "school": "HILL COUNTRY MIDDLE",
        "district": "EANES ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481776001548",
    },
    {
        "school": "WESTLAKE H S",
        "district": "EANES ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481776001549",
    },
    {
        "school": "VALLEY VIEW EL",
        "district": "EANES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481776005699",
    },
    {
        "school": "FOREST TRAIL EL",
        "district": "EANES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481776005979",
    },
    {
        "school": "WEST RIDGE MIDDLE",
        "district": "EANES ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481776006398",
    },
    {
        "school": "BRIDGE POINT EL",
        "district": "EANES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481776007742",
    },
    {
        "school": "WESTLAKE ALTER",
        "district": "EANES ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481776009079",
    },
    {
        "school": "BARTON CREEK EL",
        "district": "EANES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481776021527",
    },
    {
        "school": "ELGIN H S",
        "district": "ELGIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481836001728",
    },
    {
        "school": "LAGO VISTA EL",
        "district": "LAGO VISTA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482640002972",
    },
    {
        "school": "LAGO VISTA H S",
        "district": "LAGO VISTA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482640002973",
    },
    {
        "school": "LAGO VISTA MIDDLE",
        "district": "LAGO VISTA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482640007469",
    },
    {
        "school": "LAKEWAY EL",
        "district": "LAKE TRAVIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482647002520",
    },
    {
        "school": "LAKE TRAVIS EL",
        "district": "LAKE TRAVIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482647005762",
    },
    {
        "school": "LAKE TRAVIS H S",
        "district": "LAKE TRAVIS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482647005763",
    },
    {
        "school": "LAKE TRAVIS MIDDLE",
        "district": "LAKE TRAVIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482647006010",
    },
    {
        "school": "BEE CAVE EL",
        "district": "LAKE TRAVIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482647008395",
    },
    {
        "school": "HUDSON BEND MIDDLE",
        "district": "LAKE TRAVIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482647008945",
    },
    {
        "school": "TRAVIS CO J J A E P",
        "district": "LAKE TRAVIS ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482647009081",
    },
    {
        "school": "STEINER RANCH EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703007498",
    },
    {
        "school": "MANOR H S",
        "district": "MANOR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889003263",
    },
    {
        "school": "MANOR MIDDLE",
        "district": "MANOR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889003264",
    },
    {
        "school": "BLUEBONNET TRAIL EL",
        "district": "MANOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889005491",
    },
    {
        "school": "MANOR EL",
        "district": "MANOR ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889006581",
    },
    {
        "school": "MANOR EXCEL ACADEMY",
        "district": "MANOR ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482889007141",
    },
    {
        "school": "DECKER EL",
        "district": "MANOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889008394",
    },
    {
        "school": "TRAVIS CO J J A E P",
        "district": "MANOR ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482889008944",
    },
    {
        "school": "PFLUGERVILLE EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483003904",
    },
    {
        "school": "PFLUGERVILLE H S",
        "district": "PFLUGERVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483003905",
    },
    {
        "school": "PFLUGERVILLE MIDDLE",
        "district": "PFLUGERVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483003906",
    },
    {
        "school": "RIVER OAKS EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483005489",
    },
    {
        "school": "PARMER LANE EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483005794",
    },
    {
        "school": "TIMMERMAN EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483006158",
    },
    {
        "school": "NORTHWEST EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483006310",
    },
    {
        "school": "DESSAU EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483006463",
    },
    {
        "school": "WESTVIEW MIDDLE",
        "district": "PFLUGERVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483006596",
    },
    {
        "school": "WINDERMERE EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483006895",
    },
    {
        "school": "PARK CREST MIDDLE",
        "district": "PFLUGERVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483007138",
    },
    {
        "school": "BROOKHOLLOW EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483007140",
    },
    {
        "school": "JOHN B CONNALLY H S",
        "district": "PFLUGERVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483007467",
    },
    {
        "school": "SPRINGHILL EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483007468",
    },
    {
        "school": "COPPERFIELD EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483008065",
    },
    {
        "school": "TRAVIS CO J J A E P",
        "district": "PFLUGERVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483483008941",
    },
    {
        "school": "DESSAU MIDDLE",
        "district": "PFLUGERVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483008942",
    },
    {
        "school": "MURCHISON EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483008943",
    },
    {
        "school": "JOLLYVILLE EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808002306",
    },
    {
        "school": "KATHY CARAWAY EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808004252",
    },
    {
        "school": "SPICEWOOD EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808004257",
    },
    {
        "school": "CANYON VISTA MIDDLE",
        "district": "ROUND ROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808006034",
    },
    {
        "school": "WELLS BRANCH EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808006166",
    },
    {
        "school": "LAUREL MOUNTAIN EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808006167",
    },
    {
        "school": "MCNEIL H S",
        "district": "ROUND ROCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808006469",
    },
    {
        "school": "CANYON CREEK EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808008087",
    },
    {
        "school": "ANNUNCIATION MATERNITY HOME",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007109074",
    },
    {
        "school": "COUPLAND EL",
        "district": "COUPLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481542001119",
    },
    {
        "school": "FLORENCE EL",
        "district": "FLORENCE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481932001790",
    },
    {
        "school": "FLORENCE H S",
        "district": "FLORENCE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481932001791",
    },
    {
        "school": "WILLIAMSON COUNTY JJAEP",
        "district": "FLORENCE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481932009098",
    },
    {
        "school": "FLORENCE MIDDLE",
        "district": "FLORENCE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481932021552",
    },
    {
        "school": "WILLIAMSON CO JUVENILE DETENTION CENTER",
        "district": "GEORGETOWN ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482060001018",
    },
    {
        "school": "GEORGETOWN H S",
        "district": "GEORGETOWN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060002068",
    },
    {
        "school": "CARVER EL",
        "district": "GEORGETOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060002069",
    },
    {
        "school": "JAMES TIPPIT MIDDLE",
        "district": "GEORGETOWN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060002070",
    },
    {
        "school": "ANNIE PURL EL",
        "district": "GEORGETOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060002072",
    },
    {
        "school": "FROST EL",
        "district": "GEORGETOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060006263",
    },
    {
        "school": "GEORGETOWN ALTER PROG",
        "district": "GEORGETOWN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482060007097",
    },
    {
        "school": "DOUGLAS BENOLD MIDDLE",
        "district": "GEORGETOWN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060007487",
    },
    {
        "school": "PAT COOPER EL",
        "district": "GEORGETOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060007488",
    },
    {
        "school": "DELL PICKETT EL",
        "district": "GEORGETOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060007489",
    },
    {
        "school": "RAYE MCCOY EL",
        "district": "GEORGETOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060007490",
    },
    {
        "school": "WILLIAMSON CO J J A E P",
        "district": "GEORGETOWN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482060007491",
    },
    {
        "school": "EAST VIEW H S",
        "district": "GEORGETOWN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060008083",
    },
    {
        "school": "VILLAGE EL",
        "district": "GEORGETOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060008084",
    },
    {
        "school": "CHARLES A FORBES MIDDLE",
        "district": "GEORGETOWN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060009099",
    },
    {
        "school": "CHIP RICHARTE H S",
        "district": "GEORGETOWN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482060021554",
    },
    {
        "school": "GRANGER SCHOOL",
        "district": "GRANGER ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482159002173",
    },
    {
        "school": "WILLIAMSON COUNTY CORE/JJAEP",
        "district": "GRANGER ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482159008955",
    },
    {
        "school": "HUTTO EL",
        "district": "HUTTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482410002685",
    },
    {
        "school": "HUTTO H S",
        "district": "HUTTO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482410002686",
    },
    {
        "school": "HUTTO MIDDLE",
        "district": "HUTTO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482410008411",
    },
    {
        "school": "JARRELL EL",
        "district": "JARRELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482460002755",
    },
    {
        "school": "JARRELL H S",
        "district": "JARRELL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482460002756",
    },
    {
        "school": "JARRELL MIDDLE",
        "district": "JARRELL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482460007492",
    },
    {
        "school": "ADA MAE FAUBION EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703003041",
    },
    {
        "school": "LEANDER H S",
        "district": "LEANDER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703003042",
    },
    {
        "school": "CEDAR PARK MIDDLE",
        "district": "LEANDER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703003043",
    },
    {
        "school": "WHITESTONE EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703003044",
    },
    {
        "school": "CYPRESS EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703005587",
    },
    {
        "school": "BLOCK HOUSE CREEK EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703006289",
    },
    {
        "school": "C C MASON EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703007099",
    },
    {
        "school": "LEANDER MIDDLE",
        "district": "LEANDER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703007496",
    },
    {
        "school": "LOIS F GIDDENS EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703007497",
    },
    {
        "school": "WILLIAMSON CO ACADEMY",
        "district": "LEANDER ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482703007758",
    },
    {
        "school": "CEDAR PARK H S",
        "district": "LEANDER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703008089",
    },
    {
        "school": "PAULINE NAUMANN EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703008090",
    },
    {
        "school": "BAGDAD EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703008416",
    },
    {
        "school": "RUNNING BRUSHY MIDDLE",
        "district": "LEANDER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703008959",
    },
    {
        "school": "CHARLOTTE COX EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703009105",
    },
    {
        "school": "LIBERTY HILL EL",
        "district": "LIBERTY HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482742003084",
    },
    {
        "school": "LIBERTY HILL H S",
        "district": "LIBERTY HILL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482742003085",
    },
    {
        "school": "LIBERTY HILL J H",
        "district": "LIBERTY HILL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482742005772",
    },
    {
        "school": "LIBERTY HILL INT",
        "district": "LIBERTY HILL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482742008957",
    },
    {
        "school": "GATTIS EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808001326",
    },
    {
        "school": "FERN BLUFF EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808001355",
    },
    {
        "school": "ANDERSON MILL EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808004247",
    },
    {
        "school": "CLAUDE BERKMAN EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808004248",
    },
    {
        "school": "DEEPWOOD EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808004249",
    },
    {
        "school": "FOREST NORTH EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808004250",
    },
    {
        "school": "NOEL GRISHAM MIDDLE",
        "district": "ROUND ROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808004251",
    },
    {
        "school": "ROUND ROCK H S",
        "district": "ROUND ROCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808004254",
    },
    {
        "school": "C D FULKES MIDDLE",
        "district": "ROUND ROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808004255",
    },
    {
        "school": "XENIA VOIGT EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808004258",
    },
    {
        "school": "VIC ROBERTSON EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808005588",
    },
    {
        "school": "CEDAR VALLEY MIDDLE",
        "district": "ROUND ROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808005611",
    },
    {
        "school": "BRUSHY CREEK EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808005802",
    },
    {
        "school": "CHISHOLM TRAIL MIDDLE",
        "district": "ROUND ROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808005803",
    },
    {
        "school": "PURPLE SAGE EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808005804",
    },
    {
        "school": "WESTWOOD H S",
        "district": "ROUND ROCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808005805",
    },
    {
        "school": "POND SPRINGS EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808006314",
    },
    {
        "school": "BLUEBONNET EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808006315",
    },
    {
        "school": "DOUBLE FILE TRAIL EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808006316",
    },
    {
        "school": "LIVE OAK EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808006470",
    },
    {
        "school": "ROUND ROCK OPPORT CTR DAEP",
        "district": "ROUND ROCK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483808006605",
    },
    {
        "school": "DEERPARK MIDDLE",
        "district": "ROUND ROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808006606",
    },
    {
        "school": "OLD TOWN EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808006608",
    },
    {
        "school": "HOPEWELL MIDDLE",
        "district": "ROUND ROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808007494",
    },
    {
        "school": "FOREST CREEK EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808007495",
    },
    {
        "school": "GREAT OAKS EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808007756",
    },
    {
        "school": "WILLIAMSON COUNTY CORE/JJAEP",
        "district": "ROUND ROCK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483808008086",
    },
    {
        "school": "STONY POINT H S",
        "district": "ROUND ROCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808008412",
    },
    {
        "school": "CALDWELL HEIGHTS EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808008413",
    },
    {
        "school": "SUCCESS H S",
        "district": "ROUND ROCK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483808008958",
    },
    {
        "school": "GOALS",
        "district": "ROUND ROCK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483808009100",
    },
    {
        "school": "RIDGEVIEW MIDDLE",
        "district": "ROUND ROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808009101",
    },
    {
        "school": "BLACKLAND PRAIRIE EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808009102",
    },
    {
        "school": "CACTUS RANCH EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808009103",
    },
    {
        "school": "TAYLOR H S",
        "district": "TAYLOR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484228004808",
    },
    {
        "school": "TAYLOR MIDDLE",
        "district": "TAYLOR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484228004809",
    },
    {
        "school": "MAIN STREET INT",
        "district": "TAYLOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484228006048",
    },
    {
        "school": "WILLIAMSON COUNTY CORE/JJAEP",
        "district": "TAYLOR ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484228007757",
    },
    {
        "school": "NAOMI PASEMANN EL",
        "district": "TAYLOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484228008088",
    },
    {
        "school": "THRALL EL",
        "district": "THRALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484266004871",
    },
    {
        "school": "THRALL H S",
        "district": "THRALL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484266004872",
    },
    {
        "school": "BAY CITY H S",
        "district": "BAY CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480963000412",
    },
    {
        "school": "BAY CITY J H",
        "district": "BAY CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480963000413",
    },
    {
        "school": "CHERRY EL",
        "district": "BAY CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480963000414",
    },
    {
        "school": "TENIE HOLMES EL",
        "district": "BAY CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480963000415",
    },
    {
        "school": "ROBERTS EL",
        "district": "BAY CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480963000418",
    },
    {
        "school": "MATAGORDA SCHOOL",
        "district": "MATAGORDA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482937003310",
    },
    {
        "school": "CENTRAL EL",
        "district": "PALACIOS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483402003780",
    },
    {
        "school": "EAST SIDE INT",
        "district": "PALACIOS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483402003781",
    },
    {
        "school": "PALACIOS H S",
        "district": "PALACIOS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483402003782",
    },
    {
        "school": "PALACIOS J H",
        "district": "PALACIOS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483402003783",
    },
    {
        "school": "BLESSING EL",
        "district": "TIDEHAVEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484281004881",
    },
    {
        "school": "MARKHAM EL",
        "district": "TIDEHAVEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484281004882",
    },
    {
        "school": "TIDEHAVEN H S",
        "district": "TIDEHAVEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484281004883",
    },
    {
        "school": "TIDEHAVEN INT",
        "district": "TIDEHAVEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484281004884",
    },
    {
        "school": "VAN VLECK EL",
        "district": "VAN VLECK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484395004987",
    },
    {
        "school": "VAN VLECK H S",
        "district": "VAN VLECK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484395004988",
    },
    {
        "school": "O H HERMAN MIDDLE",
        "district": "VAN VLECK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484395004989",
    },
    {
        "school": "E RUDD INT",
        "district": "VAN VLECK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484395006340",
    },
    {
        "school": "HARDIN CO ALTERNATIVE AEP",
        "district": "WEST HARDIN COUNTY CISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484500009255",
    },
    {
        "school": "JEFFERSON CO J J A E P",
        "district": "SABINE PASS ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483849010854",
    },
    {
        "school": "STILWELL TECH CTR/CATE",
        "district": "PORT ARTHUR ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483540009314",
    },
    {
        "school": "MEMORIAL H S",
        "district": "PORT ARTHUR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540009317",
    },
    {
        "school": "LUMBERTON H S",
        "district": "LUMBERTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481353000848",
    },
    {
        "school": "LUMBERTON MIDDLE",
        "district": "LUMBERTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481353000849",
    },
    {
        "school": "LUMBERTON PRI",
        "district": "LUMBERTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481353000850",
    },
    {
        "school": "LUMBERTON EARLY CHILDHOOD SCH",
        "district": "LUMBERTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481353005421",
    },
    {
        "school": "LUMBERTON INT",
        "district": "LUMBERTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481353006967",
    },
    {
        "school": "HARDIN CO ALTER ED",
        "district": "LUMBERTON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481353008582",
    },
    {
        "school": "HARDIN-JEFFERSON H S",
        "district": "HARDIN-JEFFERSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482241002248",
    },
    {
        "school": "SOUR LAKE EL",
        "district": "HARDIN-JEFFERSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482241002250",
    },
    {
        "school": "HARDIN CO J J A E P",
        "district": "HARDIN-JEFFERSON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482241008581",
    },
    {
        "school": "KOUNTZE EL",
        "district": "KOUNTZE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482592002918",
    },
    {
        "school": "KOUNTZE H S",
        "district": "KOUNTZE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482592002919",
    },
    {
        "school": "KOUNTZE MIDDLE",
        "district": "KOUNTZE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482592002921",
    },
    {
        "school": "HARDIN CO ALTER ED",
        "district": "KOUNTZE ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482592008226",
    },
    {
        "school": "SILSBEE H S",
        "district": "SILSBEE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484023004562",
    },
    {
        "school": "EDWARDS-JOHNSON MEMORIAL MIDDLE",
        "district": "SILSBEE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484023004563",
    },
    {
        "school": "HARDIN CO ALTER ED",
        "district": "SILSBEE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484023008227",
    },
    {
        "school": "WEST HARDIN EL",
        "district": "WEST HARDIN COUNTY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484500005126",
    },
    {
        "school": "WEST HARDIN H S",
        "district": "WEST HARDIN COUNTY CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484500005127",
    },
    {
        "school": "TEKOA ACADEMY OF ACCELERATED STUDIES",
        "district": "TEKOA ACADEMY OF ACCELERATED STUDIES STEM SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480013908309",
    },
    {
        "school": "EHRHART SCHOOL",
        "district": "EHRHART SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480022108673",
    },
    {
        "school": "AMELIA EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967004631",
    },
    {
        "school": "CALDWOOD EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967004634",
    },
    {
        "school": "CURTIS EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967004635",
    },
    {
        "school": "SMITH MIDDLE",
        "district": "BEAUMONT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967004639",
    },
    {
        "school": "M L KING MIDDLE",
        "district": "BEAUMONT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967004641",
    },
    {
        "school": "FLETCHER EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967004642",
    },
    {
        "school": "WEST BROOK SR H S",
        "district": "BEAUMONT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967005951",
    },
    {
        "school": "MARSHALL MIDDLE",
        "district": "BEAUMONT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967005953",
    },
    {
        "school": "ODOM MIDDLE",
        "district": "BEAUMONT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967005954",
    },
    {
        "school": "GUESS EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967005958",
    },
    {
        "school": "REGINA HOWELL EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967005961",
    },
    {
        "school": "SOUTH PARK MIDDLE",
        "district": "BEAUMONT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967006219",
    },
    {
        "school": "PATHWAYS LEARNING CTR",
        "district": "BEAUMONT ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480967006510",
    },
    {
        "school": "HOMER DR EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967006824",
    },
    {
        "school": "JEFFERSON CO YOUTH ACAD",
        "district": "BEAUMONT ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480967007364",
    },
    {
        "school": "PIETZSCH/MAC ARTHUR EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967007365",
    },
    {
        "school": "PAUL A BROWN ALTERNATIVE CENTER",
        "district": "BEAUMONT ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480967007976",
    },
    {
        "school": "DISHMAN EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967007977",
    },
    {
        "school": "O C TAYLOR CTR",
        "district": "BEAUMONT ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480967008676",
    },
    {
        "school": "HAMSHIRE-FANNETT EL",
        "district": "HAMSHIRE-FANNETT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482232002237",
    },
    {
        "school": "HAMSHIRE-FANNETT H S",
        "district": "HAMSHIRE-FANNETT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482232002239",
    },
    {
        "school": "HAMSHIRE-FANNETT MIDDLE",
        "district": "HAMSHIRE-FANNETT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482232002240",
    },
    {
        "school": "JEFFERSON CO J J A E P",
        "district": "HAMSHIRE-FANNETT ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482232008311",
    },
    {
        "school": "HAMSHIRE-FANNETT INT",
        "district": "HAMSHIRE-FANNETT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482232021382",
    },
    {
        "school": "CHINA EL",
        "district": "HARDIN-JEFFERSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482241002247",
    },
    {
        "school": "HENDERSON MIDDLE",
        "district": "HARDIN-JEFFERSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482241002249",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "NEDERLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483228003576",
    },
    {
        "school": "HELENA PARK EL",
        "district": "NEDERLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483228003577",
    },
    {
        "school": "HIGHLAND PARK EL",
        "district": "NEDERLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483228003578",
    },
    {
        "school": "HILLCREST EL",
        "district": "NEDERLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483228003579",
    },
    {
        "school": "LANGHAM EL",
        "district": "NEDERLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483228003580",
    },
    {
        "school": "NEDERLAND H S",
        "district": "NEDERLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483228003581",
    },
    {
        "school": "WILSON MIDDLE",
        "district": "NEDERLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483228003582",
    },
    {
        "school": "JEFFERSON CO YOUTH ACAD",
        "district": "NEDERLAND ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483228007662",
    },
    {
        "school": "ALTERNATIVE EDUCATION SCHOOL",
        "district": "NEDERLAND ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483228008674",
    },
    {
        "school": "DEQUEEN EL",
        "district": "PORT ARTHUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540003999",
    },
    {
        "school": "PORT ACRES EL",
        "district": "PORT ARTHUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540004000",
    },
    {
        "school": "JEFFERSON MIDDLE",
        "district": "PORT ARTHUR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540004001",
    },
    {
        "school": "HOUSTON EL",
        "district": "PORT ARTHUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540004003",
    },
    {
        "school": "LAKEVIEW EL",
        "district": "PORT ARTHUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540004007",
    },
    {
        "school": "TRAVIS EL",
        "district": "PORT ARTHUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540004011",
    },
    {
        "school": "TYRRELL EL",
        "district": "PORT ARTHUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540004012",
    },
    {
        "school": "WHEATLEY SCHOOL OF EARLY CHILDHOOD PROGRAMS",
        "district": "PORT ARTHUR ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540004014",
    },
    {
        "school": "LINCOLN MIDDLE",
        "district": "PORT ARTHUR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540004015",
    },
    {
        "school": "JEFFERSON CO YOUTH ACAD",
        "district": "PORT ARTHUR ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483540007663",
    },
    {
        "school": "PORT ARTHUR ALTERNATIVE CENTER",
        "district": "PORT ARTHUR ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483540008675",
    },
    {
        "school": "GROVES MIDDLE",
        "district": "PORT NECHES-GROVES ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483543004016",
    },
    {
        "school": "GROVES EL",
        "district": "PORT NECHES-GROVES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483543004017",
    },
    {
        "school": "PORT NECHES EL",
        "district": "PORT NECHES-GROVES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483543004018",
    },
    {
        "school": "PORT NECHES MIDDLE",
        "district": "PORT NECHES-GROVES ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483543004019",
    },
    {
        "school": "PORT NECHES-GROVES H S",
        "district": "PORT NECHES-GROVES ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483543004020",
    },
    {
        "school": "RIDGEWOOD EL",
        "district": "PORT NECHES-GROVES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483543004021",
    },
    {
        "school": "TAFT EL",
        "district": "PORT NECHES-GROVES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483543004022",
    },
    {
        "school": "VAN BUREN EL",
        "district": "PORT NECHES-GROVES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483543004023",
    },
    {
        "school": "WOODCREST EL",
        "district": "PORT NECHES-GROVES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483543004024",
    },
    {
        "school": "ALTER SCH",
        "district": "PORT NECHES-GROVES ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483543007363",
    },
    {
        "school": "JEFFERSON CO J J A E P",
        "district": "PORT NECHES-GROVES ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483543008310",
    },
    {
        "school": "SABINE PASS SCHOOL",
        "district": "SABINE PASS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483849004285",
    },
    {
        "school": "BRIDGE CITY H S",
        "district": "BRIDGE CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481131000607",
    },
    {
        "school": "BRIDGE CITY MIDDLE",
        "district": "BRIDGE CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481131000608",
    },
    {
        "school": "BRIDGE CITY EL",
        "district": "BRIDGE CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481131000610",
    },
    {
        "school": "BRIDGE CITY INT",
        "district": "BRIDGE CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481131007418",
    },
    {
        "school": "LIT CYPR-MRCEVILLE H S",
        "district": "LITTLE CYPRESS-MAURICEVILLE CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482769003105",
    },
    {
        "school": "LITTLE CYPRESS EL",
        "district": "LITTLE CYPRESS-MAURICEVILLE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482769003106",
    },
    {
        "school": "LITTLE CYPRESS INT",
        "district": "LITTLE CYPRESS-MAURICEVILLE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482769003107",
    },
    {
        "school": "LITTLE CYPRESS J H",
        "district": "LITTLE CYPRESS-MAURICEVILLE CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482769003108",
    },
    {
        "school": "MAURICEVILLE EL",
        "district": "LITTLE CYPRESS-MAURICEVILLE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482769003109",
    },
    {
        "school": "MAURICEVILLE MIDDLE",
        "district": "LITTLE CYPRESS-MAURICEVILLE CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482769005886",
    },
    {
        "school": "ORANGEFIELD EL",
        "district": "ORANGEFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483378003766",
    },
    {
        "school": "ORANGEFIELD H S",
        "district": "ORANGEFIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483378003767",
    },
    {
        "school": "ORANGEFIELD J H",
        "district": "ORANGEFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483378003768",
    },
    {
        "school": "OAK FOREST EL",
        "district": "VIDOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484416005022",
    },
    {
        "school": "PINE FOREST EL",
        "district": "VIDOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484416005023",
    },
    {
        "school": "VIDOR EL",
        "district": "VIDOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484416005024",
    },
    {
        "school": "VIDOR H S",
        "district": "VIDOR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484416005025",
    },
    {
        "school": "VIDOR J H",
        "district": "VIDOR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484416005026",
    },
    {
        "school": "VIDOR MIDDLE",
        "district": "VIDOR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484416005932",
    },
    {
        "school": "AIM CENTER H S",
        "district": "VIDOR ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484416007054",
    },
    {
        "school": "WEST ORANGE-STARK EL",
        "district": "WEST ORANGE-COVE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484509005140",
    },
    {
        "school": "WEST ORANGE-STARK MIDDLE",
        "district": "WEST ORANGE-COVE CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484509005142",
    },
    {
        "school": "WEST ORANGE-STARK H S",
        "district": "WEST ORANGE-COVE CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484509005143",
    },
    {
        "school": "M B NORTH E C LRN CTR",
        "district": "WEST ORANGE-COVE CISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484509007053",
    },
    {
        "school": "ST MARY'S ACADEMY CHARTER SCHOOL",
        "district": "ST MARY'S ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017708427",
    },
    {
        "school": "FADDEN-MCKEOWN-CHAMBLISS EL",
        "district": "BEEVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480972000438",
    },
    {
        "school": "R A HALL EL",
        "district": "BEEVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480972000439",
    },
    {
        "school": "MORENO J H",
        "district": "BEEVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480972000441",
    },
    {
        "school": "A C JONES H S",
        "district": "BEEVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480972000442",
    },
    {
        "school": "HAMPTON-MORENO-DUGAT EARLY CHILDHOOD CENTER",
        "district": "BEEVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480972000444",
    },
    {
        "school": "PAWNEE EL / J H",
        "district": "PAWNEE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483441003859",
    },
    {
        "school": "PETTUS EL",
        "district": "PETTUS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483477003898",
    },
    {
        "school": "PETTUS SECONDARY",
        "district": "PETTUS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483477003899",
    },
    {
        "school": "SKIDMORE-TYNAN EL",
        "district": "SKIDMORE-TYNAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484041004575",
    },
    {
        "school": "SKIDMORE-TYNAN H S",
        "district": "SKIDMORE-TYNAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484041004576",
    },
    {
        "school": "SKIDMORE-TYNAN J H",
        "district": "SKIDMORE-TYNAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484041004577",
    },
    {
        "school": "GOLIAD EL",
        "district": "BIG SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481020000473",
    },
    {
        "school": "BIG SPRING H S",
        "district": "BIG SPRING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481020000474",
    },
    {
        "school": "KENTWOOD EL",
        "district": "BIG SPRING ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481020000477",
    },
    {
        "school": "MARCY EL",
        "district": "BIG SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481020000479",
    },
    {
        "school": "MOSS EL",
        "district": "BIG SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481020000480",
    },
    {
        "school": "WASHINGTON EL",
        "district": "BIG SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481020000482",
    },
    {
        "school": "BIG SPRING J H",
        "district": "BIG SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481020008303",
    },
    {
        "school": "BIG SPRING AEP",
        "district": "BIG SPRING ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481020008667",
    },
    {
        "school": "COAHOMA EL",
        "district": "COAHOMA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481449000937",
    },
    {
        "school": "COAHOMA H S",
        "district": "COAHOMA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481449000938",
    },
    {
        "school": "COAHOMA J H",
        "district": "COAHOMA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481449000939",
    },
    {
        "school": "FORSAN EL",
        "district": "FORSAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481962001812",
    },
    {
        "school": "FORSAN H S",
        "district": "FORSAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481962001813",
    },
    {
        "school": "BORGER H S",
        "district": "BORGER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481089000553",
    },
    {
        "school": "BORGER MIDDLE",
        "district": "BORGER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481089000554",
    },
    {
        "school": "PAUL BELTON EL",
        "district": "BORGER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481089000555",
    },
    {
        "school": "CROCKETT EL",
        "district": "BORGER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481089000556",
    },
    {
        "school": "GATEWAY EL",
        "district": "BORGER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481089005662",
    },
    {
        "school": "SANFORD-FRITCH EL",
        "district": "SANFORD-FRITCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483915004464",
    },
    {
        "school": "SANFORD-FRITCH J H",
        "district": "SANFORD-FRITCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483915004465",
    },
    {
        "school": "SANFORD-FRITCH H S",
        "district": "SANFORD-FRITCH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483915004466",
    },
    {
        "school": "SPRING CREEK SCHOOL",
        "district": "SPRING CREEK ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484113004707",
    },
    {
        "school": "WEST TEXAS H S",
        "district": "PLEMONS-STINNETT-PHILLIPS CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484158004751",
    },
    {
        "school": "WEST TEXAS MIDDLE",
        "district": "PLEMONS-STINNETT-PHILLIPS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484158006486",
    },
    {
        "school": "WEST TEXAS EL",
        "district": "PLEMONS-STINNETT-PHILLIPS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484158021373",
    },
    {
        "school": "ALTON EL",
        "district": "BRENHAM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481128000602",
    },
    {
        "school": "BRENHAM EL",
        "district": "BRENHAM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481128000603",
    },
    {
        "school": "BRENHAM H S",
        "district": "BRENHAM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481128000604",
    },
    {
        "school": "BRENHAM MIDDLE",
        "district": "BRENHAM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481128000605",
    },
    {
        "school": "KRAUSE EL",
        "district": "BRENHAM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481128000606",
    },
    {
        "school": "BRENHAM J H",
        "district": "BRENHAM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481128007747",
    },
    {
        "school": "BURTON EL",
        "district": "BURTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481224000725",
    },
    {
        "school": "BURTON H S",
        "district": "BURTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481224000726",
    },
    {
        "school": "DORA ROMERO EL",
        "district": "LOS FRESNOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829011382",
    },
    {
        "school": "RANCHO VERDE EL",
        "district": "LOS FRESNOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829011425",
    },
    {
        "school": "ADULT ED",
        "district": "BROWNSVILLE ISD",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481168009152",
    },
    {
        "school": "GARCIA MIDDLE",
        "district": "BROWNSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168009153",
    },
    {
        "school": "STILLMAN MIDDLE",
        "district": "BROWNSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168010472",
    },
    {
        "school": "ORTIZ EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168010473",
    },
    {
        "school": "CAMERON CO JUVENILE DETENTION CTR",
        "district": "BROWNSVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481168010474",
    },
    {
        "school": "BROWNSVILLE LEARNING ACADEMY",
        "district": "BROWNSVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481168011159",
    },
    {
        "school": "NEW PATHWAYS CENTER",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482253009154",
    },
    {
        "school": "EDNA TAMAYO HOUSE",
        "district": "HARLINGEN CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482253009155",
    },
    {
        "school": "MOISES VELA MIDDLE",
        "district": "HARLINGEN CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253010475",
    },
    {
        "school": "DR HESIQUIO RODRIGUEZ EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253010476",
    },
    {
        "school": "EARLY COLLEGE H S",
        "district": "HARLINGEN CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253011541",
    },
    {
        "school": "NOEMI DOMINGUEZ EL",
        "district": "LA FERIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482604009545",
    },
    {
        "school": "CAMERON CO J J A E P",
        "district": "LOS FRESNOS CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482829009454",
    },
    {
        "school": "LIBERTY MEMORIAL MIDDLE",
        "district": "LOS FRESNOS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829010477",
    },
    {
        "school": "OLMITO EL",
        "district": "LOS FRESNOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829010478",
    },
    {
        "school": "CAMERON CO J J A E P",
        "district": "POINT ISABEL ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483525010479",
    },
    {
        "school": "SANTA MARIA DAEP",
        "district": "SANTA MARIA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483933009156",
    },
    {
        "school": "VELA MIDDLE",
        "district": "BROWNSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000426",
    },
    {
        "school": "YTURRIA EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000427",
    },
    {
        "school": "HANNA EARLY COLLEGE H S",
        "district": "BROWNSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000641",
    },
    {
        "school": "PORTER EARLY COLLEGE H S",
        "district": "BROWNSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000642",
    },
    {
        "school": "PACE EARLY COLLEGE H S",
        "district": "BROWNSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000643",
    },
    {
        "school": "CANALES EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000644",
    },
    {
        "school": "CROMACK EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000647",
    },
    {
        "school": "DEL CASTILLO EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000649",
    },
    {
        "school": "EGLY EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000650",
    },
    {
        "school": "EL JARDIN EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000651",
    },
    {
        "school": "FAULK MIDDLE",
        "district": "BROWNSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000652",
    },
    {
        "school": "GARDEN PARK EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000653",
    },
    {
        "school": "GARZA EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000654",
    },
    {
        "school": "CASTANEDA EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000655",
    },
    {
        "school": "PALM GROVE EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000659",
    },
    {
        "school": "PEREZ EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000660",
    },
    {
        "school": "PUTEGNAT EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000661",
    },
    {
        "school": "MARTIN EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000662",
    },
    {
        "school": "RUSSELL EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000665",
    },
    {
        "school": "SHARP EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000666",
    },
    {
        "school": "SKINNER EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000667",
    },
    {
        "school": "STELL MIDDLE",
        "district": "BROWNSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000668",
    },
    {
        "school": "VILLA NUEVA EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168000670",
    },
    {
        "school": "LOPEZ EARLY COLLEGE H S",
        "district": "BROWNSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168003324",
    },
    {
        "school": "BESTEIRO MIDDLE",
        "district": "BROWNSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168003325",
    },
    {
        "school": "OLIVEIRA MIDDLE",
        "district": "BROWNSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168005415",
    },
    {
        "school": "VERMILLION ROAD EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168005416",
    },
    {
        "school": "LINCOLN PARK SCH",
        "district": "BROWNSVILLE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481168005663",
    },
    {
        "school": "BURNS EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168005849",
    },
    {
        "school": "GONZALEZ EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168006224",
    },
    {
        "school": "MORNINGSIDE EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168006225",
    },
    {
        "school": "PERKINS MIDDLE",
        "district": "BROWNSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168006369",
    },
    {
        "school": "RIVERA EARLY COLLEGE H S",
        "district": "BROWNSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168006517",
    },
    {
        "school": "SOUTHMOST EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168006518",
    },
    {
        "school": "AIKEN EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168007200",
    },
    {
        "school": "CAMERON CO J J A E P",
        "district": "BROWNSVILLE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481168007541",
    },
    {
        "school": "LUCIO MIDDLE",
        "district": "BROWNSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168007542",
    },
    {
        "school": "HUDSON EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168007821",
    },
    {
        "school": "BENAVIDES EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168008137",
    },
    {
        "school": "BROWNSVILLE ACADEMIC CENTER",
        "district": "BROWNSVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481168008461",
    },
    {
        "school": "CHAMPION EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168008463",
    },
    {
        "school": "PAREDES EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168008464",
    },
    {
        "school": "GALLEGOS EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168008465",
    },
    {
        "school": "AUSTIN EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002276",
    },
    {
        "school": "BEN MILAM EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002277",
    },
    {
        "school": "BONHAM EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002278",
    },
    {
        "school": "BOWIE EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002279",
    },
    {
        "school": "COAKLEY MIDDLE",
        "district": "HARLINGEN CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002280",
    },
    {
        "school": "CROCKETT EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002281",
    },
    {
        "school": "DISHMAN EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002282",
    },
    {
        "school": "MEMORIAL MIDDLE",
        "district": "HARLINGEN CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002283",
    },
    {
        "school": "HARLINGEN H S",
        "district": "HARLINGEN CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002284",
    },
    {
        "school": "HOUSTON EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002285",
    },
    {
        "school": "JEFFERSON EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002286",
    },
    {
        "school": "LAMAR EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002287",
    },
    {
        "school": "STUART PLACE EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002288",
    },
    {
        "school": "TRAVIS EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002289",
    },
    {
        "school": "VERNON MIDDLE",
        "district": "HARLINGEN CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002290",
    },
    {
        "school": "WILSON EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002291",
    },
    {
        "school": "ZAVALA EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253002292",
    },
    {
        "school": "TREASURE HILLS EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253005487",
    },
    {
        "school": "LONG EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253006115",
    },
    {
        "school": "HARLINGEN H S - SOUTH",
        "district": "HARLINGEN CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253006267",
    },
    {
        "school": "SECONDARY ALTER CTR",
        "district": "HARLINGEN CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482253006940",
    },
    {
        "school": "GUTIERREZ MIDDLE",
        "district": "HARLINGEN CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253007544",
    },
    {
        "school": "CAMERON CO J J A E P",
        "district": "HARLINGEN CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482253008717",
    },
    {
        "school": "KEYS ACAD",
        "district": "HARLINGEN CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482253021152",
    },
    {
        "school": "W B GREEN J H",
        "district": "LA FERIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482604002926",
    },
    {
        "school": "LA FERIA H S",
        "district": "LA FERIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482604002927",
    },
    {
        "school": "C E VAIL EL",
        "district": "LA FERIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482604002929",
    },
    {
        "school": "SAM HOUSTON EL",
        "district": "LA FERIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482604002930",
    },
    {
        "school": "LA FERIA ACADEMY",
        "district": "LA FERIA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482604006941",
    },
    {
        "school": "CAMERON COUNTY JJAEP",
        "district": "LA FERIA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482604008718",
    },
    {
        "school": "RESACA MIDDLE",
        "district": "LOS FRESNOS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829000428",
    },
    {
        "school": "LAS YESCAS EL",
        "district": "LOS FRESNOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829003161",
    },
    {
        "school": "LOS FRESNOS EL",
        "district": "LOS FRESNOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829003162",
    },
    {
        "school": "LOS FRESNOS H S",
        "district": "LOS FRESNOS CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829003163",
    },
    {
        "school": "LOS CUATES MIDDLE",
        "district": "LOS FRESNOS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829003164",
    },
    {
        "school": "VILLAREAL EL",
        "district": "LOS FRESNOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829003165",
    },
    {
        "school": "LOPEZ-RIGGINS EL",
        "district": "LOS FRESNOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829006140",
    },
    {
        "school": "PALMER-LAAKSO EL",
        "district": "LOS FRESNOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829007201",
    },
    {
        "school": "LAURELES EL",
        "district": "LOS FRESNOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482829008720",
    },
    {
        "school": "DERRY EL",
        "district": "POINT ISABEL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483525003987",
    },
    {
        "school": "GARRIGA EL",
        "district": "POINT ISABEL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483525003988",
    },
    {
        "school": "PORT ISABEL H S",
        "district": "POINT ISABEL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483525003989",
    },
    {
        "school": "PORT ISABEL J H",
        "district": "POINT ISABEL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483525003990",
    },
    {
        "school": "SOUTH TEXAS ISD MEDICAL PROFESSIONS",
        "district": "SOUTH TEXAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483715005908",
    },
    {
        "school": "CAMERON CO J J A E P",
        "district": "SOUTH TEXAS ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483715008468",
    },
    {
        "school": "RIO HONDO EL",
        "district": "RIO HONDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483717004183",
    },
    {
        "school": "RIO HONDO H S",
        "district": "RIO HONDO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483717004184",
    },
    {
        "school": "RIO HONDO MIDDLE",
        "district": "RIO HONDO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483717004185",
    },
    {
        "school": "RIO HONDO INT",
        "district": "RIO HONDO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483717007202",
    },
    {
        "school": "CAMERON CO J J A E P",
        "district": "RIO HONDO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483717008466",
    },
    {
        "school": "FRED BOOTH",
        "district": "SAN BENITO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879004416",
    },
    {
        "school": "CASH EL",
        "district": "SAN BENITO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879004418",
    },
    {
        "school": "DOWNS FINE ARTS ACADEMY",
        "district": "SAN BENITO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879004419",
    },
    {
        "school": "LA ENCANTADA EL",
        "district": "SAN BENITO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879004420",
    },
    {
        "school": "BERTA CABAZA MIDDLE",
        "district": "SAN BENITO CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879004423",
    },
    {
        "school": "RANGERVILLE EL",
        "district": "SAN BENITO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879004424",
    },
    {
        "school": "ROBERTS EL",
        "district": "SAN BENITO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879004425",
    },
    {
        "school": "SAN BENITO H S",
        "district": "SAN BENITO CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879004426",
    },
    {
        "school": "SULLIVAN ENVIRONMENTAL SCIENCE ACADEMY",
        "district": "SAN BENITO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879004427",
    },
    {
        "school": "LA PALOMA EL",
        "district": "SAN BENITO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879005919",
    },
    {
        "school": "HESTER JUVENILE DETENT",
        "district": "SAN BENITO CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483879006942",
    },
    {
        "school": "POSITIVE REDIRECTION CTR",
        "district": "SAN BENITO CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483879007547",
    },
    {
        "school": "RAUL GARZA JR STEAM ACADEMY",
        "district": "SAN BENITO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879007824",
    },
    {
        "school": "AMADOR R RODRIGUEZ JUVENILE BOOT CAMP",
        "district": "SAN BENITO CISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483879008139",
    },
    {
        "school": "CAMERON CO J J A E P",
        "district": "SAN BENITO CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483879008467",
    },
    {
        "school": "SAN BENITO VETERANS MEMORIAL ACADEMY",
        "district": "SAN BENITO CISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879008722",
    },
    {
        "school": "MILLER JORDAN MIDDLE",
        "district": "SAN BENITO CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879021156",
    },
    {
        "school": "TONY GONZALEZ EL",
        "district": "SANTA MARIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483933004478",
    },
    {
        "school": "SANTA MARIA H S",
        "district": "SANTA MARIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483933021157",
    },
    {
        "school": "ELMA E BARRERA EL",
        "district": "SANTA ROSA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483936004479",
    },
    {
        "school": "SANTA ROSA H S",
        "district": "SANTA ROSA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483936004480",
    },
    {
        "school": "JO NELSON MIDDLE",
        "district": "SANTA ROSA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483936006324",
    },
    {
        "school": "SOUTH TEXAS ISD SCIENCE ACADEMY",
        "district": "SOUTH TEXAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483715000429",
    },
    {
        "school": "SOUTH TEXAS ISD WORLD SCHOLARS",
        "district": "SOUTH TEXAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483715004181",
    },
    {
        "school": "SOUTH TEXAS ISD HEALTH PROFESSIONS",
        "district": "SOUTH TEXAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483715006033",
    },
    {
        "school": "HIDALGO CO J J A E P",
        "district": "SOUTH TEXAS ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483715008141",
    },
    {
        "school": "BROWNWOOD ACCELERATED H S",
        "district": "BROWNWOOD ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481170011156",
    },
    {
        "school": "J B STEPHENS EL",
        "district": "BANGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480939000397",
    },
    {
        "school": "BANGS H S",
        "district": "BANGS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480939000398",
    },
    {
        "school": "BANGS MIDDLE",
        "district": "BANGS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480939005402",
    },
    {
        "school": "BLANKET SCHOOL",
        "district": "BLANKET ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481038005661",
    },
    {
        "school": "BROOKESMITH SCHOOL",
        "district": "BROOKESMITH ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481155000627",
    },
    {
        "school": "BROWNWOOD H S",
        "district": "BROWNWOOD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481170000672",
    },
    {
        "school": "BROWNWOOD MIDDLE",
        "district": "BROWNWOOD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481170000673",
    },
    {
        "school": "COGGIN INT",
        "district": "BROWNWOOD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481170000674",
    },
    {
        "school": "NORTHWEST EL",
        "district": "BROWNWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481170000675",
    },
    {
        "school": "WOODLAND HEIGHTS EL",
        "district": "BROWNWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481170000677",
    },
    {
        "school": "EAST EL",
        "district": "BROWNWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481170005965",
    },
    {
        "school": "EARLY EL",
        "district": "EARLY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481779001550",
    },
    {
        "school": "EARLY H S",
        "district": "EARLY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481779001551",
    },
    {
        "school": "EARLY PRI",
        "district": "EARLY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481779003240",
    },
    {
        "school": "EARLY MIDDLE",
        "district": "EARLY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481779005700",
    },
    {
        "school": "MAY EL",
        "district": "MAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482952003318",
    },
    {
        "school": "MAY H S",
        "district": "MAY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482952003319",
    },
    {
        "school": "ZEPHYR SCHOOL",
        "district": "ZEPHYR ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484677005356",
    },
    {
        "school": "COLLEGE STATION JJAEP",
        "district": "COLLEGE STATION ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480735010464",
    },
    {
        "school": "FOREST RIDGE",
        "district": "COLLEGE STATION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735010465",
    },
    {
        "school": "BRAZOS COUNTY JJAEP",
        "district": "BRYAN ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481179009145",
    },
    {
        "school": "BRYAN COLLEGIATE H S",
        "district": "BRYAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179011507",
    },
    {
        "school": "BRAZOS SCHOOL FOR INQUIRY AND CREATIVITY TIDWELL",
        "district": "BRAZOS SCHOOL FOR INQUIRY & CREATIVITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480008610461",
    },
    {
        "school": "CALDWELL EL",
        "district": "CALDWELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481246000738",
    },
    {
        "school": "CALDWELL H S",
        "district": "CALDWELL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481246000739",
    },
    {
        "school": "CALDWELL MIDDLE",
        "district": "CALDWELL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481246000740",
    },
    {
        "school": "CALDWELL DAEP",
        "district": "CALDWELL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481246008460",
    },
    {
        "school": "CALDWELL INT",
        "district": "CALDWELL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481246021143",
    },
    {
        "school": "SNOOK SECONDARY",
        "district": "SNOOK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484062004595",
    },
    {
        "school": "SNOOK EL",
        "district": "SNOOK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484062008132",
    },
    {
        "school": "SOMERVILLE EL",
        "district": "SOMERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484077004625",
    },
    {
        "school": "SOMERVILLE H S",
        "district": "SOMERVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484077004626",
    },
    {
        "school": "BREMOND EL",
        "district": "BREMOND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481125000600",
    },
    {
        "school": "BREMOND H S",
        "district": "BREMOND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481125000601",
    },
    {
        "school": "BREMOND MIDDLE",
        "district": "BREMOND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481125006827",
    },
    {
        "school": "CALVERT SCHOOL",
        "district": "CALVERT ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481254000756",
    },
    {
        "school": "FRANKLIN H S",
        "district": "FRANKLIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481974001936",
    },
    {
        "school": "ROLAND REYNOLDS EL",
        "district": "FRANKLIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481974001937",
    },
    {
        "school": "FRANKLIN MIDDLE",
        "district": "FRANKLIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481974021468",
    },
    {
        "school": "HEARNE H S",
        "district": "HEARNE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482283002313",
    },
    {
        "school": "HEARNE J H",
        "district": "HEARNE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482283002314",
    },
    {
        "school": "MUMFORD EL",
        "district": "MUMFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483195003551",
    },
    {
        "school": "MUMFORD H S",
        "district": "MUMFORD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483195008899",
    },
    {
        "school": "BRAZOS SCHOOL FOR INQUIRY AND CREATIVITY BRYAN/COL",
        "district": "BRAZOS SCHOOL FOR INQUIRY & CREATIVITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480008608128",
    },
    {
        "school": "A & M CONS H S",
        "district": "COLLEGE STATION ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735000001",
    },
    {
        "school": "COLLEGE HILLS EL",
        "district": "COLLEGE STATION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735000002",
    },
    {
        "school": "COLLEGE STATION MIDDLE",
        "district": "COLLEGE STATION ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735000003",
    },
    {
        "school": "SOUTH KNOLL EL",
        "district": "COLLEGE STATION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735000004",
    },
    {
        "school": "SOUTHWOOD VALLEY EL",
        "district": "COLLEGE STATION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735005839",
    },
    {
        "school": "ROCK PRAIRIE EL",
        "district": "COLLEGE STATION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735006636",
    },
    {
        "school": "PEBBLE CREEK EL",
        "district": "COLLEGE STATION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735007192",
    },
    {
        "school": "OAKWOOD INT",
        "district": "COLLEGE STATION ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735008129",
    },
    {
        "school": "CYPRESS GROVE INT",
        "district": "COLLEGE STATION ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735008130",
    },
    {
        "school": "A & M CONSOLIDATED MIDDLE",
        "district": "COLLEGE STATION ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735008712",
    },
    {
        "school": "BONHAM EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179000680",
    },
    {
        "school": "TRAVIS B BRYAN H S",
        "district": "BRYAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179000682",
    },
    {
        "school": "CROCKETT EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179000684",
    },
    {
        "school": "HENDERSON EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179000686",
    },
    {
        "school": "JOHNSON EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179000687",
    },
    {
        "school": "SUL ROSS EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179000692",
    },
    {
        "school": "ALTON BOWEN EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179005875",
    },
    {
        "school": "SAM HOUSTON EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179006226",
    },
    {
        "school": "NAVARRO EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179006519",
    },
    {
        "school": "JANE LONG",
        "district": "BRYAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179006657",
    },
    {
        "school": "SAM RAYBURN",
        "district": "BRYAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179006658",
    },
    {
        "school": "FANNIN EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179006830",
    },
    {
        "school": "NEAL EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179007533",
    },
    {
        "school": "DISCIPLINARY ALTERNATIVE EDUCATIONAL PROGAM (DAEP)",
        "district": "BRYAN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481179007816",
    },
    {
        "school": "MITCHELL EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179008131",
    },
    {
        "school": "BRAZOS CO JUVENILE DETENTION CENTER",
        "district": "BRYAN ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481179008456",
    },
    {
        "school": "MARY BRANCH EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179021013",
    },
    {
        "school": "STEPHEN F AUSTIN",
        "district": "BRYAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179021133",
    },
    {
        "school": "KEMP-CARVER EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179021134",
    },
    {
        "school": "ANSON JONES EL",
        "district": "BRYAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481179021135",
    },
    {
        "school": "CORPUS CHRISTI MONTESSORI SCHOOL",
        "district": "CORPUS CHRISTI MONTESSORI SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027911317",
    },
    {
        "school": "SEASHORE MIDDLE ACAD",
        "district": "SEASHORE CHARTER SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480028911399",
    },
    {
        "school": "ARANSAS PASS JJAEP",
        "district": "ARANSAS PASS ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480858009519",
    },
    {
        "school": "BANQUETE DAEP",
        "district": "BANQUETE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480941010993",
    },
    {
        "school": "FAYE WEBB EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527010991",
    },
    {
        "school": "NUECES CO J J A E P",
        "district": "PORT ARANSAS ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483537010992",
    },
    {
        "school": "NUECES CO J J A E P",
        "district": "ROBSTOWN ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483744009361",
    },
    {
        "school": "SINTON EL",
        "district": "SINTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484035009525",
    },
    {
        "school": "FULTON LEARNING CENTER",
        "district": "ARANSAS COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480855000219",
    },
    {
        "school": "LIVE OAK LEARNING CENTER",
        "district": "ARANSAS COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480855000220",
    },
    {
        "school": "ROCKPORT-FULTON H S",
        "district": "ARANSAS COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480855000222",
    },
    {
        "school": "ROCKPORT-FULTON MIDDLE",
        "district": "ARANSAS COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480855000223",
    },
    {
        "school": "DR M L GARZA-GONZALEZ CHARTER SCHOOL",
        "district": "DR M L GARZA-GONZALEZ CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480002507411",
    },
    {
        "school": "AGUA DULCE EL",
        "district": "AGUA DULCE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480753000043",
    },
    {
        "school": "AGUA DULCE H S",
        "district": "AGUA DULCE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480753000044",
    },
    {
        "school": "BANQUETE EL",
        "district": "BANQUETE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480941000399",
    },
    {
        "school": "BANQUETE H S",
        "district": "BANQUETE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480941000400",
    },
    {
        "school": "BANQUETE J H",
        "district": "BANQUETE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480941000401",
    },
    {
        "school": "BISHOP H S",
        "district": "BISHOP CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481026000507",
    },
    {
        "school": "LILLION E LUEHRS J H",
        "district": "BISHOP CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481026000508",
    },
    {
        "school": "BISHOP EL",
        "district": "BISHOP CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481026000509",
    },
    {
        "school": "PETRONILA EL",
        "district": "BISHOP CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481026000510",
    },
    {
        "school": "BISHOP PRI",
        "district": "BISHOP CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481026007413",
    },
    {
        "school": "NUECES CO J J A E P",
        "district": "BISHOP CISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481026008007",
    },
    {
        "school": "CALALLEN H S",
        "district": "CALALLEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481242000734",
    },
    {
        "school": "CALALLEN MIDDLE",
        "district": "CALALLEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481242000735",
    },
    {
        "school": "MAGEE EL",
        "district": "CALALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481242000737",
    },
    {
        "school": "CALALLEN EAST EL",
        "district": "CALALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481242005852",
    },
    {
        "school": "CALALLEN WOOD RIVER EL",
        "district": "CALALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481242006229",
    },
    {
        "school": "NUECES CO J J A E P",
        "district": "CALALLEN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481242009003",
    },
    {
        "school": "MARY GRETT SCHOOL",
        "district": "CORPUS CHRISTI ISD",
        "level": "High",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "481527001037",
    },
    {
        "school": "ALLEN EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001038",
    },
    {
        "school": "BAKER MIDDLE",
        "district": "CORPUS CHRISTI ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001040",
    },
    {
        "school": "BROWNE MIDDLE",
        "district": "CORPUS CHRISTI ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001041",
    },
    {
        "school": "CARROLL H S",
        "district": "CORPUS CHRISTI ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001043",
    },
    {
        "school": "MARY HELEN BERLANGA EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001044",
    },
    {
        "school": "HICKS EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001046",
    },
    {
        "school": "WYNN SEALE METROPOLITAN SCHOOL OF DESIGN",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001047",
    },
    {
        "school": "CROCKETT EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001049",
    },
    {
        "school": "CUNNINGHAM MIDDLE AT SOUTH PARK",
        "district": "CORPUS CHRISTI ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001052",
    },
    {
        "school": "DRISCOLL MIDDLE",
        "district": "CORPUS CHRISTI ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001053",
    },
    {
        "school": "EVANS SES",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001054",
    },
    {
        "school": "FANNIN EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001055",
    },
    {
        "school": "GARCIA EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001058",
    },
    {
        "school": "GIBSON EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001059",
    },
    {
        "school": "HAAS MIDDLE",
        "district": "CORPUS CHRISTI ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001060",
    },
    {
        "school": "HAMLIN MIDDLE",
        "district": "CORPUS CHRISTI ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001061",
    },
    {
        "school": "HOUSTON EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001063",
    },
    {
        "school": "KING H S",
        "district": "CORPUS CHRISTI ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001064",
    },
    {
        "school": "KOSTORYZ EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001065",
    },
    {
        "school": "LOS ENCINOS SES",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001068",
    },
    {
        "school": "SHAW SES",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001069",
    },
    {
        "school": "MARTIN MIDDLE",
        "district": "CORPUS CHRISTI ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001070",
    },
    {
        "school": "MEADOWBROOK EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001071",
    },
    {
        "school": "MENGER EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001072",
    },
    {
        "school": "ROY MILLER H S AND METRO SCHOOL OF DESIGN",
        "district": "CORPUS CHRISTI ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001073",
    },
    {
        "school": "MONTCLAIR EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001074",
    },
    {
        "school": "MOODY H S",
        "district": "CORPUS CHRISTI ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001075",
    },
    {
        "school": "OAK PARK SPECIAL EMPHASIS SCHOOL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001077",
    },
    {
        "school": "RAY H S",
        "district": "CORPUS CHRISTI ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001080",
    },
    {
        "school": "SANDERS EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001082",
    },
    {
        "school": "SCHANEN ESTATES EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001084",
    },
    {
        "school": "SMITH EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001087",
    },
    {
        "school": "TRAVIS EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001090",
    },
    {
        "school": "CALK-WILSON EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001091",
    },
    {
        "school": "WINDSOR PARK G/T",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001092",
    },
    {
        "school": "WOODLAWN EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001093",
    },
    {
        "school": "YEAGER EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001095",
    },
    {
        "school": "ZAVALA EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001096",
    },
    {
        "school": "BARNES EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527001837",
    },
    {
        "school": "CLUB ESTATES",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527005433",
    },
    {
        "school": "STUDENT SUPPORT CENTER",
        "district": "CORPUS CHRISTI ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481527005681",
    },
    {
        "school": "COLES H S AND EDUCATIONAL CENTER",
        "district": "CORPUS CHRISTI ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481527006082",
    },
    {
        "school": "KAFFIE MIDDLE",
        "district": "CORPUS CHRISTI ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527006528",
    },
    {
        "school": "MOORE EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527006529",
    },
    {
        "school": "EARLY CHILDHOOD DEVELOPMENT CTR",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527007415",
    },
    {
        "school": "DAWSON EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527007706",
    },
    {
        "school": "NUECES CO J J A E P",
        "district": "CORPUS CHRISTI ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481527008346",
    },
    {
        "school": "MIRELES EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527008888",
    },
    {
        "school": "GALVAN EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527021047",
    },
    {
        "school": "JONES EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527021048",
    },
    {
        "school": "DRISCOLL EL & MIDDLE",
        "district": "DRISCOLL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481755008889",
    },
    {
        "school": "FLOUR BLUFF EL",
        "district": "FLOUR BLUFF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481938001796",
    },
    {
        "school": "FLOUR BLUFF H S",
        "district": "FLOUR BLUFF ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481938001797",
    },
    {
        "school": "FLOUR BLUFF J H",
        "district": "FLOUR BLUFF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481938001799",
    },
    {
        "school": "FLOUR BLUFF PRI",
        "district": "FLOUR BLUFF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481938001800",
    },
    {
        "school": "FLOUR BLUFF INT",
        "district": "FLOUR BLUFF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481938006252",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "FLOUR BLUFF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481938007417",
    },
    {
        "school": "NUECES CO J J A E P",
        "district": "FLOUR BLUFF ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481938008010",
    },
    {
        "school": "LONDON EL",
        "district": "LONDON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482799003135",
    },
    {
        "school": "OLSEN EL",
        "district": "PORT ARANSAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483537003995",
    },
    {
        "school": "PORT ARANSAS H S",
        "district": "PORT ARANSAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483537003996",
    },
    {
        "school": "BRUNDRETT MIDDLE",
        "district": "PORT ARANSAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483537005798",
    },
    {
        "school": "SAN PEDRO EL",
        "district": "ROBSTOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483744004201",
    },
    {
        "school": "LOTSPEICH EL",
        "district": "ROBSTOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483744004202",
    },
    {
        "school": "ROBSTOWN EARLY COLLEGE H S",
        "district": "ROBSTOWN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483744004204",
    },
    {
        "school": "ROBERT DRISCOLL JR EL",
        "district": "ROBSTOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483744004205",
    },
    {
        "school": "SEALE J H",
        "district": "ROBSTOWN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483744004207",
    },
    {
        "school": "SOLOMON P ORTIZ INT",
        "district": "ROBSTOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483744006603",
    },
    {
        "school": "TULOSO-MIDWAY H S",
        "district": "TULOSO-MIDWAY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484335004923",
    },
    {
        "school": "TULOSO-MIDWAY MIDDLE",
        "district": "TULOSO-MIDWAY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484335004924",
    },
    {
        "school": "TULOSO-MIDWAY ACADEMIC CAREER CENTER",
        "district": "TULOSO-MIDWAY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484335005136",
    },
    {
        "school": "TULOSO-MIDWAY INT",
        "district": "TULOSO-MIDWAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484335006052",
    },
    {
        "school": "TULOSO-MIDWAY PRI",
        "district": "TULOSO-MIDWAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484335006490",
    },
    {
        "school": "NUECES CO J J A E P",
        "district": "TULOSO-MIDWAY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484335009004",
    },
    {
        "school": "KENNEDY EL",
        "district": "WEST OSO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484512005145",
    },
    {
        "school": "WEST OSO H S",
        "district": "WEST OSO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484512005147",
    },
    {
        "school": "WEST OSO J H",
        "district": "WEST OSO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484512005148",
    },
    {
        "school": "WEST OSO EL",
        "district": "WEST OSO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484512008890",
    },
    {
        "school": "WEST OSO ISD JJAEP",
        "district": "WEST OSO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484512009005",
    },
    {
        "school": "ARANSAS PASS H S",
        "district": "ARANSAS PASS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480858000224",
    },
    {
        "school": "A C BLUNT MIDDLE",
        "district": "ARANSAS PASS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480858000225",
    },
    {
        "school": "H T FAULK EL",
        "district": "ARANSAS PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480858000226",
    },
    {
        "school": "CHARLIE MARSHALL EL",
        "district": "ARANSAS PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480858007710",
    },
    {
        "school": "AUSTIN EL",
        "district": "GREGORY-PORTLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482178002196",
    },
    {
        "school": "CLARK EL",
        "district": "GREGORY-PORTLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482178002197",
    },
    {
        "school": "EAST CLIFF EL",
        "district": "GREGORY-PORTLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482178002198",
    },
    {
        "school": "GREGORY-PORTLAND H S",
        "district": "GREGORY-PORTLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482178002199",
    },
    {
        "school": "GREGORY-PORTLAND MIDDLE",
        "district": "GREGORY-PORTLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482178002200",
    },
    {
        "school": "ANDREWS EL",
        "district": "GREGORY-PORTLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482178005485",
    },
    {
        "school": "INGLESIDE PRI",
        "district": "INGLESIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482418002696",
    },
    {
        "school": "INGLESIDE H S",
        "district": "INGLESIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482418002697",
    },
    {
        "school": "LEON TAYLOR J H",
        "district": "INGLESIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482418005508",
    },
    {
        "school": "BLASCHKE/SHELDON EL",
        "district": "INGLESIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482418005509",
    },
    {
        "school": "GILBERT J MIRCOVICH EL",
        "district": "INGLESIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482418008015",
    },
    {
        "school": "MATHIS EL",
        "district": "MATHIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482940003311",
    },
    {
        "school": "MATHIS H S",
        "district": "MATHIS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482940003312",
    },
    {
        "school": "MATHIS INT",
        "district": "MATHIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482940003313",
    },
    {
        "school": "MATHIS MIDDLE",
        "district": "MATHIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482940003314",
    },
    {
        "school": "ODEM INT",
        "district": "ODEM-EDROY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483336003743",
    },
    {
        "school": "ODEM H S",
        "district": "ODEM-EDROY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483336003744",
    },
    {
        "school": "ODEM J H",
        "district": "ODEM-EDROY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483336003745",
    },
    {
        "school": "WELDER EL",
        "district": "SINTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484035004570",
    },
    {
        "school": "SINTON H S",
        "district": "SINTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484035004571",
    },
    {
        "school": "E MERLE SMITH MIDDLE",
        "district": "SINTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484035004572",
    },
    {
        "school": "JUVENILE DETENTION CTR",
        "district": "SINTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484035007062",
    },
    {
        "school": "WOODROE PETTY EL",
        "district": "TAFT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484206004789",
    },
    {
        "school": "TAFT H S",
        "district": "TAFT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484206004791",
    },
    {
        "school": "TAFT J H",
        "district": "TAFT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484206004792",
    },
    {
        "school": "DAWSON DAEP",
        "district": "DAWSON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481638010984",
    },
    {
        "school": "NAVARRO COUNTY AEP/ABC",
        "district": "FROST ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482004010985",
    },
    {
        "school": "BLOOMING GROVE EL",
        "district": "BLOOMING GROVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481047000524",
    },
    {
        "school": "BLOOMING GROVE H S",
        "district": "BLOOMING GROVE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481047000525",
    },
    {
        "school": "BLOOMING GROVE JH",
        "district": "BLOOMING GROVE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481047007080",
    },
    {
        "school": "BOWIE EL",
        "district": "CORSICANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481533001100",
    },
    {
        "school": "CORSICANA MIDDLE",
        "district": "CORSICANA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481533001101",
    },
    {
        "school": "CORSICANA H IGH SCHOOL",
        "district": "CORSICANA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481533001102",
    },
    {
        "school": "COLLINS INT",
        "district": "CORSICANA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481533001104",
    },
    {
        "school": "FANNIN EL",
        "district": "CORSICANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481533001105",
    },
    {
        "school": "CARROLL EL",
        "district": "CORSICANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481533001108",
    },
    {
        "school": "JOSE ANTONIO NAVARRO EL",
        "district": "CORSICANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481533008341",
    },
    {
        "school": "DAWSON EL",
        "district": "DAWSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481638001396",
    },
    {
        "school": "DAWSON H S",
        "district": "DAWSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481638001397",
    },
    {
        "school": "FROST EL",
        "district": "FROST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482004001958",
    },
    {
        "school": "FROST H S",
        "district": "FROST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482004001959",
    },
    {
        "school": "KERENS SCHOOL",
        "district": "KERENS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482553002842",
    },
    {
        "school": "MILDRED EL",
        "district": "MILDRED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483072003468",
    },
    {
        "school": "MILDRED H S",
        "district": "MILDRED ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483072003469",
    },
    {
        "school": "RICE EL",
        "district": "RICE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483696004114",
    },
    {
        "school": "RICE H S",
        "district": "RICE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483696008005",
    },
    {
        "school": "CORINTH CLASSICAL UPPER SCHOOL",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480016311536",
    },
    {
        "school": "COPPELL CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480016311553",
    },
    {
        "school": "CARROLL EL",
        "district": "FRISCO ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001011403",
    },
    {
        "school": "MOONEYHAM EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001011563",
    },
    {
        "school": "INDEPENDENCE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730011467",
    },
    {
        "school": "HERMAN LAWSON EARLY CHILDHOOD SCHOOL",
        "district": "MCKINNEY ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985011424",
    },
    {
        "school": "KAY GRANGER EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318011530",
    },
    {
        "school": "SHARON SHANNON EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765011490",
    },
    {
        "school": "CELIA HAYS EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765011499",
    },
    {
        "school": "MISS MAY VERNON EL",
        "district": "ROYSE CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483822011545",
    },
    {
        "school": "DON WHITT EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653011373",
    },
    {
        "school": "JAMES AND MARGIE MARION EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789009490",
    },
    {
        "school": "ERECKSON MIDDLE",
        "district": "ALLEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789010488",
    },
    {
        "school": "DR E T BOON EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789010489",
    },
    {
        "school": "CARLENA CHANDLER EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789010490",
    },
    {
        "school": "SPECIAL PROG CTR/J J A E P",
        "district": "ANNA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480834010492",
    },
    {
        "school": "SUE EVELYN RATTAN EL",
        "district": "ANNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480834011456",
    },
    {
        "school": "JOHN R ROACH",
        "district": "BLUE RIDGE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481059010522",
    },
    {
        "school": "COLLIN CO J J A E P",
        "district": "CELINA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481329009159",
    },
    {
        "school": "BRAVES ACADEMY",
        "district": "COMMUNITY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481485010523",
    },
    {
        "school": "PLANO SPECIAL PROGRAMS CENTER",
        "district": "COMMUNITY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481485010524",
    },
    {
        "school": "COLLIN CO J J A E P",
        "district": "FARMERSVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481908009486",
    },
    {
        "school": "CENTENNIAL H S",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001009160",
    },
    {
        "school": "WESTER MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001009162",
    },
    {
        "school": "SPEARS EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001009163",
    },
    {
        "school": "GUNSTREAM EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001009165",
    },
    {
        "school": "RIDDLE EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001009642",
    },
    {
        "school": "COLLIN CO J J A E P",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482001010493",
    },
    {
        "school": "WAKELAND H S",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001010494",
    },
    {
        "school": "GRIFFIN MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001010495",
    },
    {
        "school": "ROACH MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001010496",
    },
    {
        "school": "ISBELL EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001010497",
    },
    {
        "school": "PINK EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001010498",
    },
    {
        "school": "BLEDSOE EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001010499",
    },
    {
        "school": "ASHLEY EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001010500",
    },
    {
        "school": "FOWLER MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001011484",
    },
    {
        "school": "LOVEJOY H S",
        "district": "LOVEJOY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482838010525",
    },
    {
        "school": "WILLOW SPRINGS MIDDLE",
        "district": "LOVEJOY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482838010526",
    },
    {
        "school": "LOVEJOY DAEP",
        "district": "LOVEJOY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482838010527",
    },
    {
        "school": "SPECIAL PROG CTR/JJAEP",
        "district": "LOVEJOY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482838010528",
    },
    {
        "school": "JOSE DE JESUS AND MARIA LUISA VEGA EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985009166",
    },
    {
        "school": "DEAN AND MILDRED BENNETT EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985009167",
    },
    {
        "school": "MCKINNEY BOYD H S",
        "district": "MCKINNEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985010501",
    },
    {
        "school": "LEONARD EVANS JR MIDDLE",
        "district": "MCKINNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985010502",
    },
    {
        "school": "GARY AND BOBBYE JACK MINSHEW EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985010503",
    },
    {
        "school": "J B WILMETH EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985010504",
    },
    {
        "school": "COLLIN CO J J A E P",
        "district": "MELISSA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483012009644",
    },
    {
        "school": "MELISSA H S",
        "district": "MELISSA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483012010505",
    },
    {
        "school": "PLANO JJAEP",
        "district": "PLANO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510009168",
    },
    {
        "school": "ANDREWS EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510009169",
    },
    {
        "school": "BOGGESS EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510009170",
    },
    {
        "school": "HICKEY EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510009171",
    },
    {
        "school": "BEATY EARLY CHILDHOOD SCHOOL",
        "district": "PLANO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510009172",
    },
    {
        "school": "PEARSON EARLY CHILDHOOD",
        "district": "PLANO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510009173",
    },
    {
        "school": "PLANO FAMILY LITERACY",
        "district": "PLANO ISD",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510009175",
    },
    {
        "school": "MURPHY MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510009639",
    },
    {
        "school": "ALLAN K & CAROLYN H BIRD EDUCATION CENTER",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510009654",
    },
    {
        "school": "ADULT BASIC ED",
        "district": "PLANO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510010506",
    },
    {
        "school": "NIGHT SCH",
        "district": "PLANO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510010507",
    },
    {
        "school": "MCCALL EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510010508",
    },
    {
        "school": "MARTHA HUNT EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510010509",
    },
    {
        "school": "HOSPITAL/HOMEBOUND",
        "district": "PLANO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510010510",
    },
    {
        "school": "HEAD START",
        "district": "PLANO ISD",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510010511",
    },
    {
        "school": "PRINCETON SPECIAL PROGRAMS CENTER",
        "district": "PRINCETON ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483585009641",
    },
    {
        "school": "GODWIN EL",
        "district": "PRINCETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483585010512",
    },
    {
        "school": "PRINCETON DAEP",
        "district": "PRINCETON ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483585010513",
    },
    {
        "school": "COLLIN CO J J A E P",
        "district": "PROSPER ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483600010515",
    },
    {
        "school": "JUDY RUCKER EL",
        "district": "PROSPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600010517",
    },
    {
        "school": "R V GROVES EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653009176",
    },
    {
        "school": "FRANK MCMILLAN J H",
        "district": "WYLIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653009651",
    },
    {
        "school": "DAVIS INT",
        "district": "WYLIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653010518",
    },
    {
        "school": "CHERI COX EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653010519",
    },
    {
        "school": "TIBBALS EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653010520",
    },
    {
        "school": "RITA SMITH EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653010521",
    },
    {
        "school": "WYLIE EAST H S",
        "district": "WYLIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653011511",
    },
    {
        "school": "TEXANS CAN ACADEMY - CARROLLTON-FARMERS BRANCH",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001609532",
    },
    {
        "school": "TEXANS CAN ACADEMY - PLEASANT GROVE",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001610548",
    },
    {
        "school": "UPLIFT EDUCATIION-NORTH HILLS PREP PRI",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003011476",
    },
    {
        "school": "LIFE SCHOOL RED OAK",
        "district": "LIFE SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480005509533",
    },
    {
        "school": "NOVA ACADEMY",
        "district": "NOVA ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007210549",
    },
    {
        "school": "GENESIS CAMPUS PRE-K THRU 5",
        "district": "A W BROWN LEADERSHIP ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480009510550",
    },
    {
        "school": "GATEWAY CHARTER ACADEMY - MIDDLE - H S",
        "district": "GATEWAY CHARTER ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480018411485",
    },
    {
        "school": "EVOLUTION ACADEMY CHARTER SCHOOL",
        "district": "EVOLUTION ACADEMY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480023609188",
    },
    {
        "school": "GOLDEN RULE CHARTER SCHOOL",
        "district": "GOLDEN RULE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023709189",
    },
    {
        "school": "ST ANTHONY ACADEMY",
        "district": "ST ANTHONY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024809521",
    },
    {
        "school": "EAST GRAND PREPARATORY ACADEMY",
        "district": "CITYSCAPE SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480028811555",
    },
    {
        "school": "RANCHVIEW H S",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305009190",
    },
    {
        "school": "BLAIR EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305009191",
    },
    {
        "school": "LA VILLITA MIDDLE",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305010554",
    },
    {
        "school": "FREEMAN EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305010555",
    },
    {
        "school": "LA VILLITA EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305010556",
    },
    {
        "school": "LAKERIDGE EL",
        "district": "CEDAR HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323009193",
    },
    {
        "school": "ELEMENTARY' DISCIPLINARY ALTERNATIVE EDUCATION PRG",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481623009196",
    },
    {
        "school": "EMMETT J CONRAD H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010560",
    },
    {
        "school": "IRMA RANGEL YOUNG WOMEN'S LEADERSHIP SCHOOL",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010561",
    },
    {
        "school": "HAROLD WENDELL LANG SR MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010562",
    },
    {
        "school": "HECTOR P GARCIA MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010563",
    },
    {
        "school": "FRANCISCO MEDRANO MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010564",
    },
    {
        "school": "JUVENILE JUSTICE AEP",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481623010565",
    },
    {
        "school": "LARRY G SMITH EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010566",
    },
    {
        "school": "C A TATUM JR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010567",
    },
    {
        "school": "JIMMIE TYLER BRASHEAR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010568",
    },
    {
        "school": "JACK LOWE SR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010569",
    },
    {
        "school": "HENRY B GONZALEZ PERSONALIZED LEARNING ACADEMY",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010570",
    },
    {
        "school": "ARTURO SALAZAR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010571",
    },
    {
        "school": "FRANK GUZICK EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010572",
    },
    {
        "school": "LEONIDES GONZALEZ CIGARROA MD EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010573",
    },
    {
        "school": "JERRY R JUNKINS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010574",
    },
    {
        "school": "HIGHLAND MEADOWS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010575",
    },
    {
        "school": "LEE A MCSHAN JR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010576",
    },
    {
        "school": "CELESTINO MAURICIO SOTO JR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010577",
    },
    {
        "school": "FELIX G BOTELLO EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010578",
    },
    {
        "school": "ROY P BENAVIDEZ EL",
        "district": "DALLAS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623010579",
    },
    {
        "school": "WOODRIDGE EL",
        "district": "DESOTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686009467",
    },
    {
        "school": "CURTISTENE S MCCOWAN MIDDLE (ISTEAM)",
        "district": "DESOTO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686011474",
    },
    {
        "school": "CJ & ANNE HYMAN EL",
        "district": "DUNCANVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764009197",
    },
    {
        "school": "JAMES R BILHARTZ JR EL",
        "district": "DUNCANVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764009501",
    },
    {
        "school": "G W KENNEMER MIDDLE",
        "district": "DUNCANVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764010588",
    },
    {
        "school": "SACHSE H S",
        "district": "GARLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034009198",
    },
    {
        "school": "JOHN W ARMSTRONG EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034009200",
    },
    {
        "school": "NITA PEARSON EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034010589",
    },
    {
        "school": "CISNEROS PRE-K CTR",
        "district": "GARLAND ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034010590",
    },
    {
        "school": "PARSONS PRE-K CTR",
        "district": "GARLAND ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034010591",
    },
    {
        "school": "GLEN COUCH EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034011198",
    },
    {
        "school": "GEORGE WASHINGTON CARVER EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034011475",
    },
    {
        "school": "LIBERTY GROVE EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034011551",
    },
    {
        "school": "RONALD W REAGAN MIDDLE",
        "district": "GRAND PRAIRIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142010592",
    },
    {
        "school": "JUAN N SEGUIN EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142010593",
    },
    {
        "school": "THURGOOD MARSHALL LEADERSHIP ACADEMY",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142010594",
    },
    {
        "school": "MIKE MOSELEY EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142011433",
    },
    {
        "school": "HIGHLAND PARK ALTER ED CTR",
        "district": "HIGHLAND PARK ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482325010595",
    },
    {
        "school": "P A S S LEARNING CTR",
        "district": "HIGHLAND PARK ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482325010596",
    },
    {
        "school": "LORENZO DE ZAVALA MIDDLE",
        "district": "IRVING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442009202",
    },
    {
        "school": "JACKIE MAE TOWNSELL EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442009618",
    },
    {
        "school": "LADY BIRD JOHNSON MIDDLE",
        "district": "IRVING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442010598",
    },
    {
        "school": "JOHN W AND MARGIE STIPES EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442010599",
    },
    {
        "school": "JD HALL LEARNING CENTER",
        "district": "LANCASTER ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482667009204",
    },
    {
        "school": "GENTRY EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039009574",
    },
    {
        "school": "MACKEY EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039010601",
    },
    {
        "school": "AUDELIA CREEK EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702009605",
    },
    {
        "school": "CAROLYN G BUKHAIR EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702010603",
    },
    {
        "school": "THURGOOD MARSHALL EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702011202",
    },
    {
        "school": "NORTH TEXAS COLLEGIATE ACADEMY-NORTH CAMPUS",
        "district": "NORTH TEXAS COLLEGIATE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480018711443",
    },
    {
        "school": "NORTH TEXAS COLLEGIATE ACADEMY-SOUTH CAMPUS",
        "district": "NORTH TEXAS COLLEGIATE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480018711537",
    },
    {
        "school": "WINFREE ACADEMY CHARTER SCHOOL DALLAS",
        "district": "WINFREE ACADEMY CHARTER SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020211380",
    },
    {
        "school": "DENTON CO J J A E P",
        "district": "AUBREY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480891010621",
    },
    {
        "school": "BESSIE COLEMAN MIDDLE",
        "district": "CEDAR HILL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323010559",
    },
    {
        "school": "CROWNOVER MIDDLE",
        "district": "DENTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674009206",
    },
    {
        "school": "EP RAYZOR EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674009207",
    },
    {
        "school": "PECAN CREEK EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674009592",
    },
    {
        "school": "GUYER H S",
        "district": "DENTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674010607",
    },
    {
        "school": "NAVO MIDDLE",
        "district": "DENTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674010608",
    },
    {
        "school": "PROVIDENCE EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674010609",
    },
    {
        "school": "HAWK EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674010610",
    },
    {
        "school": "SAVANNAH EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674010611",
    },
    {
        "school": "REGIONAL DAY SCH DEAF",
        "district": "DENTON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481674010612",
    },
    {
        "school": "COMMUNITY ED",
        "district": "DENTON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481674010613",
    },
    {
        "school": "NELSON EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674011447",
    },
    {
        "school": "PALOMA CREEK EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674011517",
    },
    {
        "school": "PIONEER HERITAGE MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001009161",
    },
    {
        "school": "SPARKS EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001009164",
    },
    {
        "school": "BOALS EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001009636",
    },
    {
        "school": "ROBERTSON EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001011470",
    },
    {
        "school": "DENTON CO J J A E P",
        "district": "KRUM ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482598009212",
    },
    {
        "school": "SHADY SHORES EL",
        "district": "LAKE DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482643010624",
    },
    {
        "school": "CLAYTON DOWNING MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730009208",
    },
    {
        "school": "MARSHALL DURHAM MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730009209",
    },
    {
        "school": "LIBERTY EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730009210",
    },
    {
        "school": "CASTLE HILLS EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730009211",
    },
    {
        "school": "MARJORY VICKERY EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730009593",
    },
    {
        "school": "ROCKBROOK EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730009594",
    },
    {
        "school": "LEGENDS PROPERTY",
        "district": "LEWISVILLE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730010614",
    },
    {
        "school": "SHADOW RIDGE MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730010615",
    },
    {
        "school": "TOM HICKS EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730010616",
    },
    {
        "school": "CHAPEL HILL EL",
        "district": "LEWISVILLE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730010617",
    },
    {
        "school": "COYOTE RIDGE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730010618",
    },
    {
        "school": "LILLIE J JACKSON EARLY CHILDHOOD CENTER",
        "district": "LEWISVILLE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730010619",
    },
    {
        "school": "CESAR CHAVEZ EL",
        "district": "LITTLE ELM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482772009214",
    },
    {
        "school": "HACKBERRY EL",
        "district": "LITTLE ELM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482772009600",
    },
    {
        "school": "LAKEVIEW EL",
        "district": "LITTLE ELM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482772010626",
    },
    {
        "school": "OAK POINT EL",
        "district": "LITTLE ELM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482772011461",
    },
    {
        "school": "SONNY & ALLEGRA NANCE EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318011207",
    },
    {
        "school": "J LYNDAL HUGHES EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318011208",
    },
    {
        "school": "DENTON CO J J A E P",
        "district": "PILOT POINT ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483492010620",
    },
    {
        "school": "PONDER J H",
        "district": "PONDER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483531011205",
    },
    {
        "school": "DENTON CO J J A E P",
        "district": "SANGER ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483918010623",
    },
    {
        "school": "LIFE SCHOOL LANCASTER",
        "district": "LIFE SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480005511533",
    },
    {
        "school": "DORIE MILLER INT",
        "district": "ENNIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481854009218",
    },
    {
        "school": "DAVID S CROCKETT EARLY CHILDHOOD CENTER",
        "district": "ENNIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481854009219",
    },
    {
        "school": "LUCY MAE MCDONALD EL",
        "district": "FERRIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481917009220",
    },
    {
        "school": "WALNUT GROVE MIDDLE",
        "district": "MIDLOTHIAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060010630",
    },
    {
        "school": "J A VITOVSKY EL",
        "district": "MIDLOTHIAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060010631",
    },
    {
        "school": "LARUE MILLER EL",
        "district": "MIDLOTHIAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060011529",
    },
    {
        "school": "ROBBIE E HOWARD J H",
        "district": "WAXAHACHIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473011375",
    },
    {
        "school": "MARGARET L FELTY EL",
        "district": "WAXAHACHIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473011560",
    },
    {
        "school": "BOLES MIDDLE",
        "district": "BOLES ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481074009311",
    },
    {
        "school": "GRANDVIEW ISD JJAEP",
        "district": "GRANDVIEW ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482154010858",
    },
    {
        "school": "KEENE JJAEP",
        "district": "KEENE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482523010860",
    },
    {
        "school": "JUVENILE JUSTICE ALTERNATIVE",
        "district": "ALVARADO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001110855",
    },
    {
        "school": "RICHARD BRANSOM EL",
        "district": "BURLESON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218009319",
    },
    {
        "school": "JOHNSON COUNTY JJAEP",
        "district": "BURLESON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481218010856",
    },
    {
        "school": "ANN BROCK EL AT OAK GROVE",
        "district": "BURLESON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218011448",
    },
    {
        "school": "JUDY HAJEK EL",
        "district": "BURLESON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218011540",
    },
    {
        "school": "COOKE EL",
        "district": "CLEBURNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481431009563",
    },
    {
        "school": "GODLEY JJAEP",
        "district": "GODLEY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482096010863",
    },
    {
        "school": "GRANDVIEW EL",
        "district": "GRANDVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482154009320",
    },
    {
        "school": "JOHNSON COUNTY J J A E P",
        "district": "JOSHUA ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482493009562",
    },
    {
        "school": "CADDO GROVE EL",
        "district": "JOSHUA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482493010859",
    },
    {
        "school": "JUVENILE JUSTICE ALTERNATIVE ED PROGRAM/VENUS",
        "district": "VENUS ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484401010861",
    },
    {
        "school": "HENDERSON EL",
        "district": "FORNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956009557",
    },
    {
        "school": "NORTH FORNEY H S",
        "district": "FORNEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956010867",
    },
    {
        "school": "BROWN MIDDLE",
        "district": "FORNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956010868",
    },
    {
        "school": "BLACKBURN EL",
        "district": "FORNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956010869",
    },
    {
        "school": "CROSBY EL",
        "district": "FORNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956010870",
    },
    {
        "school": "NELL HILL RHEA INT",
        "district": "FORNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956011501",
    },
    {
        "school": "MARGARET TAYLOR SMITH INT",
        "district": "FORNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956011554",
    },
    {
        "school": "GARY W CAMPBELL H S",
        "district": "KAUFMAN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482520009321",
    },
    {
        "school": "HELEN EDWARD EARLY CHILDHOOD CENTER",
        "district": "KAUFMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482520009572",
    },
    {
        "school": "KEMP ALTERNATIVE",
        "district": "KEMP ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482532010871",
    },
    {
        "school": "MCANALLY INT",
        "district": "ALEDO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480778009500",
    },
    {
        "school": "BROCK J H",
        "district": "BROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481146009535",
    },
    {
        "school": "POOLVILLE J H",
        "district": "POOLVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483534009363",
    },
    {
        "school": "SEGUIN EL",
        "district": "WEATHERFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484480009364",
    },
    {
        "school": "IKARD EL",
        "district": "WEATHERFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484480009365",
    },
    {
        "school": "DORRIS A JONES EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765009368",
    },
    {
        "school": "GRACE HARTMAN EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765009369",
    },
    {
        "school": "ROCKWALL-HEATH H S",
        "district": "ROCKWALL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765011000",
    },
    {
        "school": "OUIDA SPRINGER",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765011001",
    },
    {
        "school": "ANITA SCOTT EL",
        "district": "ROYSE CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483822009370",
    },
    {
        "school": "W R (BILL) FORT EL",
        "district": "ROYSE CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483822011002",
    },
    {
        "school": "WINFREE ACADEMY CHARTER SCHOOL - GRAND PRAIRIE",
        "district": "WINFREE ACADEMY CHARTER SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020209187",
    },
    {
        "school": "WESTLAKE ACADEMY",
        "district": "WESTLAKE ACADEMY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480025409511",
    },
    {
        "school": "EAST FORT WORTH MONTESSORI ACADEMY",
        "district": "EAST FORT WORTH MONTESSORI ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480025509603",
    },
    {
        "school": "TEXAS SCHOOL OF THE ARTS",
        "district": "TEXAS SCHOOL OF THE ARTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480028711567",
    },
    {
        "school": "SEGUIN H S",
        "district": "ARLINGTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870009374",
    },
    {
        "school": "ANDERSON EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870011013",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "AZLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480920009389",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "BIRDVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481023009375",
    },
    {
        "school": "WALKER CREEK EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023011015",
    },
    {
        "school": "TARRANT COUNTY J J A E P",
        "district": "BURLESON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481218010857",
    },
    {
        "school": "CARROLL H S",
        "district": "CARROLL ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481302009392",
    },
    {
        "school": "GEORGE DAWSON MIDDLE",
        "district": "CARROLL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481302009393",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "CARROLL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481302011035",
    },
    {
        "school": "DALLAS PARK EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591009387",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "CROWLEY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481591011029",
    },
    {
        "school": "J A HARGRAVE EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591011030",
    },
    {
        "school": "SIDNEY H POYNTER",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591011343",
    },
    {
        "school": "REMINGTON POINT EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770009509",
    },
    {
        "school": "SAGINAW H S",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770011031",
    },
    {
        "school": "WELDON HAFLEY DEVELOPMENT CTR",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770011032",
    },
    {
        "school": "CREEKVIEW MIDDLE",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770011033",
    },
    {
        "school": "CHISHOLM RIDGE",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770011034",
    },
    {
        "school": "TARRANT COUNTY JJAEP SCHOOL",
        "district": "EVERMAN ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481881009376",
    },
    {
        "school": "DAN POWELL INT",
        "district": "EVERMAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481881011329",
    },
    {
        "school": "CLIFFORD DAVIS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970009377",
    },
    {
        "school": "CESAR CHAVEZ PRI",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970009378",
    },
    {
        "school": "MG ELLIS",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970009379",
    },
    {
        "school": "BONNIE BRAE",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970009620",
    },
    {
        "school": "SPED PRIVATE/HOMEBOUND",
        "district": "FORT WORTH ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970009625",
    },
    {
        "school": "ADULT ED",
        "district": "FORT WORTH ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970011016",
    },
    {
        "school": "SEMINARY HILLS PARK EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970011017",
    },
    {
        "school": "DOLORES HUERTA EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970011018",
    },
    {
        "school": "BUINGER CTE ACADEMY",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482406009390",
    },
    {
        "school": "RIVER TRAILS EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406009391",
    },
    {
        "school": "CENTRAL H S",
        "district": "KELLER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526009380",
    },
    {
        "school": "BLUEBONNET EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526009381",
    },
    {
        "school": "FREEDOM EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526009382",
    },
    {
        "school": "BETTE PEROT EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526011019",
    },
    {
        "school": "WOODLAND SPRINGS EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526011020",
    },
    {
        "school": "LIBERTY EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526011021",
    },
    {
        "school": "EAGLE RIDGE EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526011459",
    },
    {
        "school": "KENNEDALE ALTER ED PROG",
        "district": "KENNEDALE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482550009388",
    },
    {
        "school": "TARRANT CO JUVENILE JUSTICE CTR",
        "district": "LAKE WORTH ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482649009385",
    },
    {
        "school": "MARINE CREEK EL",
        "district": "LAKE WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482649009386",
    },
    {
        "school": "MANSFIELD H S",
        "district": "MANSFIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892009383",
    },
    {
        "school": "BROOKS WESTER MIDDLE",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892009384",
    },
    {
        "school": "THELMA JONES EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892009480",
    },
    {
        "school": "ROBERTA TIPPS EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892009590",
    },
    {
        "school": "ERMA NASH EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892009660",
    },
    {
        "school": "MANSFIELD TIMBERVIEW H S",
        "district": "MANSFIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011022",
    },
    {
        "school": "DANNY JONES MIDDLE",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011023",
    },
    {
        "school": "ELIZABETH SMITH EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011024",
    },
    {
        "school": "MARTHA REID EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011025",
    },
    {
        "school": "MARY JO SHEPPARD EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011026",
    },
    {
        "school": "JANET BROCKETT EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011027",
    },
    {
        "school": "DELLA ICENHOWER INT",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011028",
    },
    {
        "school": "ANNETTE PERRY EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011398",
    },
    {
        "school": "MANSFIELD LAKE RIDGE H S",
        "district": "MANSFIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011441",
    },
    {
        "school": "JUDY MILLER EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011478",
    },
    {
        "school": "ASA E LOW JR INT",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011532",
    },
    {
        "school": "WHITE SETTLEMENT DISCIPLINARY CAMPUS",
        "district": "WHITE SETTLEMENT ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484554009508",
    },
    {
        "school": "COOPER EL",
        "district": "COOPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481515001021",
    },
    {
        "school": "COOPER H S",
        "district": "COOPER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481515001022",
    },
    {
        "school": "COOPER J H",
        "district": "COOPER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481515001023",
    },
    {
        "school": "FANNINDEL EL",
        "district": "FANNINDEL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481905001775",
    },
    {
        "school": "FANNINDEL H S",
        "district": "FANNINDEL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481905001776",
    },
    {
        "school": "ALVORD EL",
        "district": "ALVORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480810000140",
    },
    {
        "school": "ALVORD H S",
        "district": "ALVORD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480810000141",
    },
    {
        "school": "ALVORD MIDDLE",
        "district": "ALVORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480810006205",
    },
    {
        "school": "BOYD EL",
        "district": "BOYD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481101000568",
    },
    {
        "school": "BOYD H S",
        "district": "BOYD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481101000569",
    },
    {
        "school": "BOYD MIDDLE",
        "district": "BOYD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481101005412",
    },
    {
        "school": "BOYD INT",
        "district": "BOYD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481101006514",
    },
    {
        "school": "BRIDGEPORT EL",
        "district": "BRIDGEPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481134000611",
    },
    {
        "school": "BRIDGEPORT H S",
        "district": "BRIDGEPORT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481134000612",
    },
    {
        "school": "BRIDGEPORT MIDDLE",
        "district": "BRIDGEPORT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481134000613",
    },
    {
        "school": "BRIDGEPORT INT",
        "district": "BRIDGEPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481134005614",
    },
    {
        "school": "CHICO EL",
        "district": "CHICO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481380000869",
    },
    {
        "school": "CHICO H S",
        "district": "CHICO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481380000870",
    },
    {
        "school": "CHICO MIDDLE",
        "district": "CHICO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481380005971",
    },
    {
        "school": "RANN EL",
        "district": "DECATUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481650001406",
    },
    {
        "school": "DECATUR H S",
        "district": "DECATUR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481650001407",
    },
    {
        "school": "MCCARROLL MIDDLE",
        "district": "DECATUR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481650001408",
    },
    {
        "school": "CARSON EL",
        "district": "DECATUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481650008962",
    },
    {
        "school": "PARADISE EL",
        "district": "PARADISE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483426003807",
    },
    {
        "school": "PARADISE H S",
        "district": "PARADISE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483426003808",
    },
    {
        "school": "PARADISE MIDDLE",
        "district": "PARADISE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483426006770",
    },
    {
        "school": "PARADISE INT",
        "district": "PARADISE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483426008419",
    },
    {
        "school": "SLIDELL SCHOOLS",
        "district": "SLIDELL ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484047004583",
    },
    {
        "school": "ALLEN H S",
        "district": "ALLEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789000117",
    },
    {
        "school": "ALTON BOYD EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789000119",
    },
    {
        "school": "D L ROUNTREE EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789000120",
    },
    {
        "school": "W E PETE FORD MIDDLE",
        "district": "ALLEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789005842",
    },
    {
        "school": "GENE M REED EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789005843",
    },
    {
        "school": "WALTER & LOIS CURTIS MIDDLE",
        "district": "ALLEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789006072",
    },
    {
        "school": "ALVIS C STORY EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789006351",
    },
    {
        "school": "MAX O VAUGHAN EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789006641",
    },
    {
        "school": "FLOSSIE FLOYD GREEN EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789006950",
    },
    {
        "school": "COLLIN CO J J A E P",
        "district": "ALLEN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480789007551",
    },
    {
        "school": "FRANCES E NORTON EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789007552",
    },
    {
        "school": "GEORGE J ANDERSON EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789007553",
    },
    {
        "school": "LOWERY FRESHMAN CENTER",
        "district": "ALLEN ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789008146",
    },
    {
        "school": "PAT DILLARD SPECIAL ACHIEVEMENT CENTER",
        "district": "ALLEN ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480789008481",
    },
    {
        "school": "BOLIN EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789008725",
    },
    {
        "school": "KERR EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789008726",
    },
    {
        "school": "JOE K BRYANT EL",
        "district": "ANNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480834000206",
    },
    {
        "school": "ANNA H S",
        "district": "ANNA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480834000207",
    },
    {
        "school": "ANNA MIDDLE",
        "district": "ANNA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480834006502",
    },
    {
        "school": "BLUE RIDGE MIDDLE",
        "district": "BLUE RIDGE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481059000435",
    },
    {
        "school": "BLUE RIDGE EL",
        "district": "BLUE RIDGE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481059000530",
    },
    {
        "school": "BLUE RIDGE H S",
        "district": "BLUE RIDGE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481059000531",
    },
    {
        "school": "CELINA H S",
        "district": "CELINA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481329000830",
    },
    {
        "school": "CELINA J H",
        "district": "CELINA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481329000831",
    },
    {
        "school": "CELINA EL",
        "district": "CELINA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481329006375",
    },
    {
        "school": "MCCLENDON EL",
        "district": "COMMUNITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481485000986",
    },
    {
        "school": "COMMUNITY H S",
        "district": "COMMUNITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481485000987",
    },
    {
        "school": "LELAND E EDGE MIDDLE",
        "district": "COMMUNITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481485005856",
    },
    {
        "school": "COLLIN CO J J A E P",
        "district": "COMMUNITY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481485008496",
    },
    {
        "school": "FARMERSVILLE H S",
        "district": "FARMERSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481908001777",
    },
    {
        "school": "FARMERSVILLE J H",
        "district": "FARMERSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481908001778",
    },
    {
        "school": "TATUM EL",
        "district": "FARMERSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481908001779",
    },
    {
        "school": "FARMERSVILLE INT",
        "district": "FARMERSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481908008728",
    },
    {
        "school": "FRISCO H S",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001001956",
    },
    {
        "school": "STALEY MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001001957",
    },
    {
        "school": "ROGERS EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001006410",
    },
    {
        "school": "CURTSINGER EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001006951",
    },
    {
        "school": "SMITH EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001007554",
    },
    {
        "school": "ANDERSON EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001008147",
    },
    {
        "school": "CHRISTIE EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001008148",
    },
    {
        "school": "STUDENT OPPORTUNITY CENTER",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482001008482",
    },
    {
        "school": "BRIGHT ACAD",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001008484",
    },
    {
        "school": "BORCHARDT EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001008485",
    },
    {
        "school": "CLARK MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001008729",
    },
    {
        "school": "SHAWNEE TRAIL EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001008730",
    },
    {
        "school": "CARRIE L LOVEJOY EL",
        "district": "LOVEJOY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482838003168",
    },
    {
        "school": "JOE V HART EL",
        "district": "LOVEJOY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482838008740",
    },
    {
        "school": "BURKS EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985003356",
    },
    {
        "school": "FINCH EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985003358",
    },
    {
        "school": "MCKINNEY H S",
        "district": "MCKINNEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985003360",
    },
    {
        "school": "FAUBION MIDDLE",
        "district": "MCKINNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985003361",
    },
    {
        "school": "WEBB EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985003362",
    },
    {
        "school": "GLEN OAKS EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985003482",
    },
    {
        "school": "CALDWELL EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985006300",
    },
    {
        "school": "SLAUGHTER EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985006953",
    },
    {
        "school": "REUBEN JOHNSON EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985007555",
    },
    {
        "school": "J J A E P",
        "district": "MCKINNEY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482985007556",
    },
    {
        "school": "C T EDDINS EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985007833",
    },
    {
        "school": "SERENITY HIGH",
        "district": "MCKINNEY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482985008149",
    },
    {
        "school": "COUNTY RESIDENTIAL CENTER",
        "district": "MCKINNEY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482985008486",
    },
    {
        "school": "ARTHUR H MCNEIL EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985008487",
    },
    {
        "school": "ALBERT & IOLA LEE DAVIS MALVERN EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985008488",
    },
    {
        "school": "MCKINNEY NORTH H S",
        "district": "MCKINNEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985008731",
    },
    {
        "school": "SCOTT MORGAN JOHNSON MIDDLE",
        "district": "MCKINNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985008732",
    },
    {
        "school": "ROY LEE WALKER EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985008733",
    },
    {
        "school": "EARL & LOTTIE WOLFORD EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985008734",
    },
    {
        "school": "VALLEY CREEK EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985021181",
    },
    {
        "school": "MELISSA MIDDLE",
        "district": "MELISSA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483012003379",
    },
    {
        "school": "HARRY MCKILLOP EL",
        "district": "MELISSA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483012006143",
    },
    {
        "school": "MITCHELL EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510000434",
    },
    {
        "school": "ROBINSON MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003534",
    },
    {
        "school": "BETHANY EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003542",
    },
    {
        "school": "ALDRIDGE EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003954",
    },
    {
        "school": "ARMSTRONG MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003955",
    },
    {
        "school": "BOWMAN MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003957",
    },
    {
        "school": "CARPENTER MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003958",
    },
    {
        "school": "CHRISTIE EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003959",
    },
    {
        "school": "DAVIS EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003960",
    },
    {
        "school": "FORMAN EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003961",
    },
    {
        "school": "HAGGARD MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003962",
    },
    {
        "school": "HARRINGTON EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003963",
    },
    {
        "school": "HUGHSTON EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003964",
    },
    {
        "school": "JACKSON EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003965",
    },
    {
        "school": "MEADOWS EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003966",
    },
    {
        "school": "MEMORIAL EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003967",
    },
    {
        "school": "MENDENHALL EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003968",
    },
    {
        "school": "PLANO SR H S",
        "district": "PLANO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003969",
    },
    {
        "school": "SAIGLING EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003970",
    },
    {
        "school": "SHEPARD EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003971",
    },
    {
        "school": "SIGLER EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003972",
    },
    {
        "school": "THOMAS EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003973",
    },
    {
        "school": "VINES H S",
        "district": "PLANO ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003974",
    },
    {
        "school": "WEATHERFORD EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003975",
    },
    {
        "school": "WELLS EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003976",
    },
    {
        "school": "WILLIAMS H S",
        "district": "PLANO ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003977",
    },
    {
        "school": "WILSON MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510003978",
    },
    {
        "school": "CLARK H S",
        "district": "PLANO ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510005571",
    },
    {
        "school": "DOOLEY EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510005572",
    },
    {
        "school": "SCHIMELPFENIG MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510005573",
    },
    {
        "school": "PLANO EAST SR H S",
        "district": "PLANO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510005796",
    },
    {
        "school": "SHEPTON H S",
        "district": "PLANO ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510006028",
    },
    {
        "school": "HUFFMAN EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510006029",
    },
    {
        "school": "CARLISLE EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510006030",
    },
    {
        "school": "HENDRICK MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510006464",
    },
    {
        "school": "MATHEWS EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510006465",
    },
    {
        "school": "BRINKER EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510006600",
    },
    {
        "school": "RENNER MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510006897",
    },
    {
        "school": "GULLEDGE EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510006954",
    },
    {
        "school": "MILLER EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510006956",
    },
    {
        "school": "JASPER H S",
        "district": "PLANO ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510007221",
    },
    {
        "school": "BARKSDALE EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510007222",
    },
    {
        "school": "SKAGGS EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510007223",
    },
    {
        "school": "HAUN EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510007557",
    },
    {
        "school": "FRANKFORD MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510007834",
    },
    {
        "school": "BEVERLY EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510007835",
    },
    {
        "school": "HIGHTOWER EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510007836",
    },
    {
        "school": "PLANO WEST SENIOR H S",
        "district": "PLANO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510008150",
    },
    {
        "school": "C M RICE MIDDLE",
        "district": "PLANO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510008151",
    },
    {
        "school": "CENTENNIAL EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510008152",
    },
    {
        "school": "E-SCHOOL",
        "district": "PLANO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510008489",
    },
    {
        "school": "REGIONAL DAY SCH FOR DEAF",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510008492",
    },
    {
        "school": "ITINERANT SP ED",
        "district": "PLANO ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510008493",
    },
    {
        "school": "STINSON EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510008735",
    },
    {
        "school": "WYATT EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510008736",
    },
    {
        "school": "LARRY D GUINN SPECIAL PROGRAMS CENTER",
        "district": "PLANO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510008737",
    },
    {
        "school": "DAFFRON EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510021016",
    },
    {
        "school": "HEDGCOXE EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510021017",
    },
    {
        "school": "RASOR EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510021183",
    },
    {
        "school": "LACY EL",
        "district": "PRINCETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483585004058",
    },
    {
        "school": "PRINCETON H S",
        "district": "PRINCETON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483585004059",
    },
    {
        "school": "CLARK MIDDLE",
        "district": "PRINCETON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483585004060",
    },
    {
        "school": "COLLIN CO J J A E P",
        "district": "PRINCETON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483585008494",
    },
    {
        "school": "R STEVE FOLSOM EL",
        "district": "PROSPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600004063",
    },
    {
        "school": "PROSPER H S",
        "district": "PROSPER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600004064",
    },
    {
        "school": "LORENE ROGERS MIDDLE",
        "district": "PROSPER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600021184",
    },
    {
        "school": "DAVIS EL",
        "district": "ROYSE CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483822004267",
    },
    {
        "school": "OUIDA BALEY MIDDLE",
        "district": "ROYSE CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483822006471",
    },
    {
        "school": "R F HARTMAN EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653005294",
    },
    {
        "school": "WYLIE H S",
        "district": "WYLIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653005295",
    },
    {
        "school": "GRADY BURNETT J H",
        "district": "WYLIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653005296",
    },
    {
        "school": "T F BIRMINGHAM EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653006195",
    },
    {
        "school": "P M AKIN EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653006634",
    },
    {
        "school": "AB HARRISON INT",
        "district": "WYLIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653007224",
    },
    {
        "school": "COLLIN CO J J A E P",
        "district": "WYLIE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484653007837",
    },
    {
        "school": "DODD EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653008154",
    },
    {
        "school": "TEXANS CAN ACADEMY - DALLAS NORTH",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001607239",
    },
    {
        "school": "TEXANS CAN ACADEMY - OAK CLIFF",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001607847",
    },
    {
        "school": "PEGASUS CHARTER H S",
        "district": "PEGASUS SCHOOL OF LIBERAL ARTS AND SCIENCES",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480002907561",
    },
    {
        "school": "UPLIFT EDUCATION-NORTH HILLS PREP MIDDLE",
        "district": "UPLIFT EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003007562",
    },
    {
        "school": "ADVANTAGE ACADEMY",
        "district": "ADVANTAGE ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480004108501",
    },
    {
        "school": "LIFE SCHOOL OAK CLIFF",
        "district": "LIFE SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480005507849",
    },
    {
        "school": "UNIVERSAL ACADEMY",
        "district": "UNIVERSAL ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007007850",
    },
    {
        "school": "LUMIN LINDSLEY PARK COMMUNITY SCHOOL",
        "district": "LUMIN EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480008908160",
    },
    {
        "school": "ACADEMY OF DALLAS",
        "district": "ACADEMY OF DALLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480009008161",
    },
    {
        "school": "TRINITY BASIN PREPARATORY",
        "district": "TRINITY BASIN PREPARATORY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480009208163",
    },
    {
        "school": "DALLAS COUNTY JUVENILE JUSTICE",
        "district": "ACADEMY FOR ACADEMIC EXCELLENCE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480009308164",
    },
    {
        "school": "QUEST CAMPUS KINDER THRU 8",
        "district": "A W BROWN LEADERSHIP ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480009508166",
    },
    {
        "school": "GATEWAY CHARTER ACADEMY",
        "district": "GATEWAY CHARTER ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480018408507",
    },
    {
        "school": "EDUCATION CENTER INTERNATIONAL ACADEMY 1",
        "district": "EDUCATION CENTER INTERNATIONAL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480018608509",
    },
    {
        "school": "NOVA ACADEMY CEDAR HILL",
        "district": "NOVA ACADEMY SOUTHEAST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020108755",
    },
    {
        "school": "WINFREE ACADEMY CHARTER SCHOOL (RICHARDSON)",
        "district": "WINFREE ACADEMY CHARTER SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020208505",
    },
    {
        "school": "WINFREE ACADEMY CHARTER SCHOOL (IRVING)",
        "district": "WINFREE ACADEMY CHARTER SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020208756",
    },
    {
        "school": "A+ ACADEMY EL",
        "district": "A+ ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020308758",
    },
    {
        "school": "INSPIRED VISION ACADEMY SECONDARY",
        "district": "INSPIRED VISION ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020408506",
    },
    {
        "school": "INSPIRED VISION ACADEMY EL",
        "district": "INSPIRED VISION ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020408759",
    },
    {
        "school": "CARROLLTON EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000793",
    },
    {
        "school": "CENTRAL EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000794",
    },
    {
        "school": "COUNTRY PLACE EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000795",
    },
    {
        "school": "FARMERS BRANCH EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000797",
    },
    {
        "school": "FIELD MIDDLE",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000798",
    },
    {
        "school": "GOOD EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000799",
    },
    {
        "school": "BLANTON EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000800",
    },
    {
        "school": "MCCOY EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000801",
    },
    {
        "school": "SMITH H S",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000803",
    },
    {
        "school": "PERRY MIDDLE",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000804",
    },
    {
        "school": "STARK EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000805",
    },
    {
        "school": "TURNER H S",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000806",
    },
    {
        "school": "GRIMES EDUCATION CENTER",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481305005671",
    },
    {
        "school": "LAS COLINAS EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305006231",
    },
    {
        "school": "SALAZAR DISTRICT ALTERNATIVE EDUCATION PROGRAM",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481305007241",
    },
    {
        "school": "BUSH MIDDLE",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305007242",
    },
    {
        "school": "LANDRY EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305007243",
    },
    {
        "school": "DALLAS COUNTY JJAEP CFB CAMPUS",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481305007563",
    },
    {
        "school": "POLK MIDDLE",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305007564",
    },
    {
        "school": "RIVERCHASE ELE",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305008760",
    },
    {
        "school": "BRAY EL",
        "district": "CEDAR HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323000822",
    },
    {
        "school": "CEDAR HILL H S",
        "district": "CEDAR HILL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323000823",
    },
    {
        "school": "W S PERMENTER MIDDLE",
        "district": "CEDAR HILL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323000825",
    },
    {
        "school": "PLUMMER EL",
        "district": "CEDAR HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323000826",
    },
    {
        "school": "HIGH POINTE EL",
        "district": "CEDAR HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323006232",
    },
    {
        "school": "HIGHLANDS EL",
        "district": "CEDAR HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323006374",
    },
    {
        "school": "JJAEP",
        "district": "CEDAR HILL ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481323008182",
    },
    {
        "school": "WATERFORD OAKS EL",
        "district": "CEDAR HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323021203",
    },
    {
        "school": "WILSON EL",
        "district": "COPPELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521000585",
    },
    {
        "school": "PINKERTON EL",
        "district": "COPPELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521001027",
    },
    {
        "school": "COPPELL H S",
        "district": "COPPELL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521001028",
    },
    {
        "school": "COPPELL MIDDLE EAST",
        "district": "COPPELL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521003702",
    },
    {
        "school": "LAKESIDE EL",
        "district": "COPPELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521003710",
    },
    {
        "school": "AUSTIN EL",
        "district": "COPPELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521006380",
    },
    {
        "school": "COPPELL MIDDLE WEST",
        "district": "COPPELL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521006936",
    },
    {
        "school": "TOWN CENTER EL",
        "district": "COPPELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521006937",
    },
    {
        "school": "COTTONWOOD CREEK EL",
        "district": "COPPELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521007262",
    },
    {
        "school": "VALLEY RANCH EL",
        "district": "COPPELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521007263",
    },
    {
        "school": "COPPELL MIDDLE NORTH",
        "district": "COPPELL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521007862",
    },
    {
        "school": "DENTON CREEK EL",
        "district": "COPPELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521007863",
    },
    {
        "school": "VICTORY PLACE AT COPPELL",
        "district": "COPPELL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481521008527",
    },
    {
        "school": "DALLAS COUNTY JJAEP",
        "district": "COPPELL ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481521008766",
    },
    {
        "school": "MOCKINGBIRD EL",
        "district": "COPPELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521021215",
    },
    {
        "school": "HARRY STONE MONTESSORI ACADEMY",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623000465",
    },
    {
        "school": "NEW TECH H S AT B F DARRELL H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001204",
    },
    {
        "school": "BRYAN ADAMS H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001205",
    },
    {
        "school": "W H ADAMSON H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001206",
    },
    {
        "school": "BIRDIE ALEXANDER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001207",
    },
    {
        "school": "GABE P ALLEN CHARTER SCHOOL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001208",
    },
    {
        "school": "ARCADIA PARK EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001209",
    },
    {
        "school": "WILLIAM HAWLEY ATWELL LAW ACADEMY",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001211",
    },
    {
        "school": "BAYLES EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001212",
    },
    {
        "school": "W A BLAIR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001213",
    },
    {
        "school": "ANNIE WEBB BLANTON EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001214",
    },
    {
        "school": "JAMES BOWIE EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001215",
    },
    {
        "school": "T W BROWNE MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001217",
    },
    {
        "school": "JOHN NEELY BRYAN EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001218",
    },
    {
        "school": "HARRELL BUDD EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001221",
    },
    {
        "school": "RUFUS C BURLESON EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001222",
    },
    {
        "school": "DAVID G BURNET EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001223",
    },
    {
        "school": "W W BUSHMAN EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001224",
    },
    {
        "school": "SCHOOL OF BUSINESS AND MANAGEMENT",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001225",
    },
    {
        "school": "F P CAILLET EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001226",
    },
    {
        "school": "JOHN W CARPENTER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001227",
    },
    {
        "school": "C F CARR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001228",
    },
    {
        "school": "DAVID W CARTER H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001229",
    },
    {
        "school": "EDWARD H CARY MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001231",
    },
    {
        "school": "CASA VIEW EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001232",
    },
    {
        "school": "CENTRAL EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001233",
    },
    {
        "school": "CLARA OLIVER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001235",
    },
    {
        "school": "CLINTON P RUSSELL EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001236",
    },
    {
        "school": "NANCY J COCHRAN EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001237",
    },
    {
        "school": "MARTIN LUTHER KING JR LEARNING CENTER",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001238",
    },
    {
        "school": "E B COMSTOCK MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001239",
    },
    {
        "school": "S S CONNER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001240",
    },
    {
        "school": "LEILA P COWART EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001241",
    },
    {
        "school": "BOOKER T WASHINGTON SPVA MAGNET",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001242",
    },
    {
        "school": "IGNACIO ZARAGOZA EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001243",
    },
    {
        "school": "BARBARA JORDAN EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001246",
    },
    {
        "school": "L O DONALD EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001249",
    },
    {
        "school": "JULIUS DORSEY EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001250",
    },
    {
        "school": "YOUNG MEN'S LEADERSHIP ACADEMY AT FRED F FLORENCE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001257",
    },
    {
        "school": "STEPHEN C FOSTER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001258",
    },
    {
        "school": "W H GASTON MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001261",
    },
    {
        "school": "GEORGE PEABODY EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001262",
    },
    {
        "school": "GEORGE W TRUETT EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001263",
    },
    {
        "school": "CHARLES A GILL EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001264",
    },
    {
        "school": "TOM C GOOCH EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001265",
    },
    {
        "school": "W E GREINER EXPLORATORY ARTS ACADEMY",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001266",
    },
    {
        "school": "LENORE KIRK HALL EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001268",
    },
    {
        "school": "NATHANIEL HAWTHORNE EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001272",
    },
    {
        "school": "SCHOOL OF HEALTH PROFESSIONS",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001273",
    },
    {
        "school": "MARGARET B HENDERSON EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001274",
    },
    {
        "school": "VICTOR H HEXTER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001275",
    },
    {
        "school": "ROBERT T HILL MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001276",
    },
    {
        "school": "HILLCREST H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001277",
    },
    {
        "school": "JAMES S HOGG EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001278",
    },
    {
        "school": "OLIVER WENDELL HOLMES HUMANITIES/COMMUNICATIONS",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001279",
    },
    {
        "school": "PIEDMONT GLOBAL ACADEMY",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001280",
    },
    {
        "school": "LIDA HOOE EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001281",
    },
    {
        "school": "L L HOTCHKISS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001282",
    },
    {
        "school": "PERSONALIZED LEARNING PREPARATORY AT SAM HOUSTON",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001283",
    },
    {
        "school": "JOHN IRELAND EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001285",
    },
    {
        "school": "JOHN Q ADAMS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001287",
    },
    {
        "school": "THOMAS JEFFERSON H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001289",
    },
    {
        "school": "CEDAR CREST EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001290",
    },
    {
        "school": "ANSON JONES EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001291",
    },
    {
        "school": "EDWIN J KIEST EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001294",
    },
    {
        "school": "JUSTIN F KIMBALL H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001295",
    },
    {
        "school": "KLEBERG EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001296",
    },
    {
        "school": "OBADIAH KNIGHT EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001297",
    },
    {
        "school": "RICHARD LAGOW EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001299",
    },
    {
        "school": "LAKEWOOD EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001300",
    },
    {
        "school": "SIDNEY LANIER EXPRESSIVE ARTS VANGUARD",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001301",
    },
    {
        "school": "GENEVA HEIGHTS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001302",
    },
    {
        "school": "UMPHREY LEE EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001303",
    },
    {
        "school": "LINCOLN HUMANITIES/COMMUNICATIONS MAGNET HIGH SCH",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001304",
    },
    {
        "school": "WILLIAM LIPSCOMB EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001305",
    },
    {
        "school": "H I HOLLAND EL AT LISBON",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001306",
    },
    {
        "school": "J L LONG MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001307",
    },
    {
        "school": "B H MACON EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001310",
    },
    {
        "school": "JAMES MADISON H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001311",
    },
    {
        "school": "MAPLE LAWN EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001312",
    },
    {
        "school": "HERBERT MARCUS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001313",
    },
    {
        "school": "BEN MILAM EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001318",
    },
    {
        "school": "WILLIAM B MILLER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001319",
    },
    {
        "school": "NANCY MOSELEY EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001320",
    },
    {
        "school": "MOUNT AUBURN STEAM ACADEMY",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001321",
    },
    {
        "school": "NORTH DALLAS H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001324",
    },
    {
        "school": "PAUL L DUNBAR LEARNING CENTER",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001325",
    },
    {
        "school": "ELISHA M PEASE EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001327",
    },
    {
        "school": "JOHN F PEELER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001328",
    },
    {
        "school": "JOHN J PERSHING EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001329",
    },
    {
        "school": "L G PINKSTON H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001331",
    },
    {
        "school": "K B POLK CENTER FOR ACADEMICALLY TALENTED & GIFTED",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001332",
    },
    {
        "school": "PRESTON HOLLOW EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001333",
    },
    {
        "school": "JOHN H REAGAN EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001335",
    },
    {
        "school": "MARTHA TURNER REILLY EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001336",
    },
    {
        "school": "REINHARDT EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001337",
    },
    {
        "school": "JOSEPH J RHOADS LEARNING CENTER",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001338",
    },
    {
        "school": "CHARLES RICE LEARNING CENTER",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001339",
    },
    {
        "school": "ORAN M ROBERTS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001340",
    },
    {
        "school": "TRINITY HEIGHTS GIFTED AND TALENTED SCHOOL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001341",
    },
    {
        "school": "DAN D ROGERS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001342",
    },
    {
        "school": "FRANKLIN D ROOSEVELT H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001343",
    },
    {
        "school": "ROSEMONT LOWER - CHRIS V SEMOS BUILDING",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001344",
    },
    {
        "school": "EDNA ROWE EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001345",
    },
    {
        "school": "JOHN W RUNYON EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001346",
    },
    {
        "school": "THOMAS J RUSK MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001347",
    },
    {
        "school": "SAN JACINTO EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001349",
    },
    {
        "school": "ALEX SANGER PREPARATORY SCHOOL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001350",
    },
    {
        "school": "SEAGOVILLE EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001351",
    },
    {
        "school": "SEAGOVILLE H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001352",
    },
    {
        "school": "SEAGOVILLE MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001353",
    },
    {
        "school": "ASCHER SILBERSTEIN EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001356",
    },
    {
        "school": "SKYLINE H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001357",
    },
    {
        "school": "SOUTH OAK CLIFF H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001358",
    },
    {
        "school": "ALEX W SPENCE TALENTED/GIFTED ACADEMY",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001359",
    },
    {
        "school": "H GRADY SPRUCE H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001360",
    },
    {
        "school": "LESLIE A STEMMONS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001361",
    },
    {
        "school": "STEVENS PARK EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001362",
    },
    {
        "school": "L V STOCKARD MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001363",
    },
    {
        "school": "MOCKINGBIRD EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001365",
    },
    {
        "school": "BOUDE STOREY MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001366",
    },
    {
        "school": "SUNSET H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001367",
    },
    {
        "school": "T G TERRY EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001368",
    },
    {
        "school": "THOMAS C MARSH MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001369",
    },
    {
        "school": "THOMAS L MARSALIS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001370",
    },
    {
        "school": "R L THORNTON EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001371",
    },
    {
        "school": "EDWARD TITCHE EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001372",
    },
    {
        "school": "WILLIAM B TRAVIS VANGUARD ACAD OF ACADEMICALLY TAG",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001374",
    },
    {
        "school": "ADELLE TURNER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001375",
    },
    {
        "school": "MARK TWAIN LEADERSHIP VANGUARD",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001376",
    },
    {
        "school": "URBAN PARK EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001378",
    },
    {
        "school": "W W SAMUELL H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001379",
    },
    {
        "school": "WALNUT HILL EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001380",
    },
    {
        "school": "DANIEL WEBSTER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001381",
    },
    {
        "school": "MARTIN WEISS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001382",
    },
    {
        "school": "W T WHITE H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001383",
    },
    {
        "school": "WILLIAM M ANDERSON EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001384",
    },
    {
        "school": "CHAPEL HILL PREPARATORY-A PERSONALIZED LRNING SCH",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001385",
    },
    {
        "school": "WOODROW WILSON H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001387",
    },
    {
        "school": "WINNETKA EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001388",
    },
    {
        "school": "WHITNEY M YOUNG JR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623001390",
    },
    {
        "school": "SCHOOL OF SCIENCE AND ENGINEERING",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623003641",
    },
    {
        "school": "ROSIE SORRELLS EDUCATION AND SOCIAL SERVICES H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623005441",
    },
    {
        "school": "J N ERVIN EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623005442",
    },
    {
        "school": "JUDGE BAREFOOT SANDERS LAW MAGNET",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623005444",
    },
    {
        "school": "LORENZO DE ZAVALA EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623005446",
    },
    {
        "school": "DALLAS ENVIRONMENTAL SCIENCE ACADEMY",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623005690",
    },
    {
        "school": "SARAH ZUMWALT MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623005864",
    },
    {
        "school": "SCHOOL FOR THE TALENTED AND GIFTED",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623005865",
    },
    {
        "school": "BENJAMIN FRANKLIN INTERNATIONAL EXPLORATORY ACAD",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623006088",
    },
    {
        "school": "HENRY W LONGFELLOW CAREER EXPLORATION ACADEMY",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623006089",
    },
    {
        "school": "J P STARKS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623006242",
    },
    {
        "school": "HOSPITAL/HOMEBOUND",
        "district": "DALLAS ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481623006391",
    },
    {
        "school": "NATHAN ADAMS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623006392",
    },
    {
        "school": "RONALD E MCNAIR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623006393",
    },
    {
        "school": "DR WRIGHT L LASSITER JR EARLY COLLEGE H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623006532",
    },
    {
        "school": "ARTHUR KRAMER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623006681",
    },
    {
        "school": "FREDERICK DOUGLASS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623006682",
    },
    {
        "school": "BARBARA M MANNS H S DAEP",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481623006930",
    },
    {
        "school": "GEORGE B DEALEY MONTESSORI ACADEMY",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623006932",
    },
    {
        "school": "EVERETTE LEE DEGOLYER EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623006933",
    },
    {
        "school": "MAYA ANGELOU H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481623006965",
    },
    {
        "school": "BARBARA M MANNS MIDDLE DAEP",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481623007244",
    },
    {
        "school": "JULIAN T SALDIVAR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007249",
    },
    {
        "school": "MARIA MORENO EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007250",
    },
    {
        "school": "PLEASANT GROVE EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007251",
    },
    {
        "school": "MARY MCLEOD BETHUNE EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007252",
    },
    {
        "school": "GILBERT CUELLAR SR EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007253",
    },
    {
        "school": "THOMAS TOLBERT EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007254",
    },
    {
        "school": "MOISES E MOLINA H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007565",
    },
    {
        "school": "RAUL QUINTANILLA SR MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007566",
    },
    {
        "school": "EDUARDO MATA MONTESSORI SCHOOL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007569",
    },
    {
        "school": "LOUISE WOLFF KAHN EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007570",
    },
    {
        "school": "ANNE FRANK EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007571",
    },
    {
        "school": "CESAR CHAVEZ LEARNING CENTER",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007572",
    },
    {
        "school": "JILL STONE EL AT VICKERY MEADOW",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623007855",
    },
    {
        "school": "ESPERANZA MEDRANO EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623008184",
    },
    {
        "school": "CALLIER CENTER PRE-SCHOOL DEAF (0-5)",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "481623008518",
    },
    {
        "school": "HARRY C WITHERS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623021021",
    },
    {
        "school": "ELADIO R MARTINEZ LEARNING CENTER",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623021022",
    },
    {
        "school": "DESOTO H S & ISTEAM3D",
        "district": "DESOTO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686001459",
    },
    {
        "school": "DESOTO EAST MIDDLE (ISTEAM)",
        "district": "DESOTO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686001461",
    },
    {
        "school": "RUBY YOUNG EL",
        "district": "DESOTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686001463",
    },
    {
        "school": "THE MEADOWS EL",
        "district": "DESOTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686006243",
    },
    {
        "school": "DESOTO WEST MIDDLE (ISTEAM)",
        "district": "DESOTO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686006396",
    },
    {
        "school": "COCKRELL HILL EL",
        "district": "DESOTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686006397",
    },
    {
        "school": "FRANK D MOATES EL",
        "district": "DESOTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686006535",
    },
    {
        "school": "DALLAS COUNTY JJAEP DESOTO CAMPUS",
        "district": "DESOTO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481686007857",
    },
    {
        "school": "GRACE R BRANDENBURG INT",
        "district": "DUNCANVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764000478",
    },
    {
        "school": "CHARLES ACTON EL",
        "district": "DUNCANVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764001521",
    },
    {
        "school": "S GUS ALEXANDER JR EL",
        "district": "DUNCANVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764001522",
    },
    {
        "school": "CENTRAL EL",
        "district": "DUNCANVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764001523",
    },
    {
        "school": "DUNCANVILLE H S",
        "district": "DUNCANVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764001524",
    },
    {
        "school": "FAIRMEADOWS EL",
        "district": "DUNCANVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764001525",
    },
    {
        "school": "WILLIAM LEE HASTINGS EL",
        "district": "DUNCANVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764001526",
    },
    {
        "school": "MERRIFIELD EL",
        "district": "DUNCANVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764001527",
    },
    {
        "school": "J HERMAN REED MIDDLE",
        "district": "DUNCANVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764001528",
    },
    {
        "school": "CLINT Q SMITH EL",
        "district": "DUNCANVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764001529",
    },
    {
        "school": "WILLIAM H BYRD MIDDLE",
        "district": "DUNCANVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764001530",
    },
    {
        "school": "MARY E SMITHEY PACE H S",
        "district": "DUNCANVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481764003679",
    },
    {
        "school": "H BOB DANIEL SR INT",
        "district": "DUNCANVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764006536",
    },
    {
        "school": "GLENN C HARDIN INT",
        "district": "DUNCANVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481764006537",
    },
    {
        "school": "P A S S LEARNING CTR",
        "district": "DUNCANVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481764007255",
    },
    {
        "school": "SUMMIT LEARNING CENTER",
        "district": "DUNCANVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481764008519",
    },
    {
        "school": "B G HUDSON MIDDLE",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034000511",
    },
    {
        "school": "GARLAND AEC",
        "district": "GARLAND ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482034000518",
    },
    {
        "school": "ROBERT B SEWELL EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034000519",
    },
    {
        "school": "AUSTIN ACAD FOR EXCELL",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002008",
    },
    {
        "school": "BEAVER TECHNOLOGY CENTER",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002009",
    },
    {
        "school": "BRADFIELD EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002010",
    },
    {
        "school": "CLASSICAL CENTER AT BRANDENBURG MIDDLE",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002011",
    },
    {
        "school": "BULLOCK EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002012",
    },
    {
        "school": "BUSSEY MIDDLE",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002013",
    },
    {
        "school": "CALDWELL EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002014",
    },
    {
        "school": "CENTERVILLE EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002015",
    },
    {
        "school": "CLUB HILL EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002016",
    },
    {
        "school": "PATHFINDER ACHIEVEMENT CENTER",
        "district": "GARLAND ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482034002017",
    },
    {
        "school": "COOPER EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002018",
    },
    {
        "school": "COYLE MIDDLE",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002019",
    },
    {
        "school": "DAUGHERTY EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002020",
    },
    {
        "school": "DAVIS EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002021",
    },
    {
        "school": "ETHRIDGE EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002022",
    },
    {
        "school": "FREEMAN EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002023",
    },
    {
        "school": "GARLAND H S",
        "district": "GARLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002024",
    },
    {
        "school": "GOLDEN MEADOWS EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002025",
    },
    {
        "school": "HANDLEY EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002026",
    },
    {
        "school": "HEATHER GLEN EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002027",
    },
    {
        "school": "HICKMAN EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002028",
    },
    {
        "school": "HILLSIDE ACAD FOR EXCEL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002029",
    },
    {
        "school": "SAM HOUSTON MIDDLE",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002030",
    },
    {
        "school": "JACKSON TECHNOLOGY CENTER",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002031",
    },
    {
        "school": "KIMBERLIN ACAD FOR EXCEL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002032",
    },
    {
        "school": "LAKEVIEW CENTENNIAL H S",
        "district": "GARLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002033",
    },
    {
        "school": "MONTCLAIR EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002035",
    },
    {
        "school": "N GARLAND H S",
        "district": "GARLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002036",
    },
    {
        "school": "NORTHLAKE EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002037",
    },
    {
        "school": "O'BANION MIDDLE",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002038",
    },
    {
        "school": "PARK CREST EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002039",
    },
    {
        "school": "ROACH EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002040",
    },
    {
        "school": "S GARLAND H S",
        "district": "GARLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002042",
    },
    {
        "school": "SELLERS MIDDLE",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002043",
    },
    {
        "school": "SHOREHAVEN EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002044",
    },
    {
        "school": "SOUTHGATE EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002045",
    },
    {
        "school": "TOLER EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002046",
    },
    {
        "school": "CLASSICAL CENTER AT VIAL EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002047",
    },
    {
        "school": "WALNUT GLEN ACAD FOR EXCEL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002048",
    },
    {
        "school": "WATSON TECHNOLOGY CENTER",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002050",
    },
    {
        "school": "WEAVER EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002051",
    },
    {
        "school": "WEBB MIDDLE",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002052",
    },
    {
        "school": "WILLIAMS EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034002053",
    },
    {
        "school": "MEMORIAL PATHWAY ACADEMY H S",
        "district": "GARLAND ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482034005726",
    },
    {
        "school": "ROWLETT EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034005727",
    },
    {
        "school": "SPRING CREEK EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034005728",
    },
    {
        "school": "LUNA EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034005992",
    },
    {
        "school": "BACK EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034005993",
    },
    {
        "school": "LYLES MIDDLE",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034006415",
    },
    {
        "school": "SHUGART EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034006416",
    },
    {
        "school": "NAAMAN FOREST H S",
        "district": "GARLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034006552",
    },
    {
        "school": "HERFURTH EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034006553",
    },
    {
        "school": "ABBETT EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034006706",
    },
    {
        "school": "KATHERINE STEPHENS EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034006935",
    },
    {
        "school": "ROWLETT H S",
        "district": "GARLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034007256",
    },
    {
        "school": "NORMA DORSEY EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034007257",
    },
    {
        "school": "P A S S LEARNING CTR",
        "district": "GARLAND ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482034007574",
    },
    {
        "school": "VERNON SCHRADE MIDDLE",
        "district": "GARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034007858",
    },
    {
        "school": "STEADHAM EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034008185",
    },
    {
        "school": "INFANT CENTER",
        "district": "GARLAND ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034008520",
    },
    {
        "school": "KEELEY EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034021208",
    },
    {
        "school": "DIGITAL ARTS & TECHNOLOGY ACADEMY AT ADAMS MIDDLE",
        "district": "GRAND PRAIRIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002143",
    },
    {
        "school": "STEPHEN F AUSTIN ENVIRONMENTAL SCIENCE ACADEMY",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002144",
    },
    {
        "school": "JAMES BOWIE FINE ARTS ACADEMY",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002146",
    },
    {
        "school": "DAVID DANIELS EL ACADEMY OF SCIENCE & MATH",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002148",
    },
    {
        "school": "DWIGHT D EISENHOWER EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002149",
    },
    {
        "school": "FLORENCE HILL EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002151",
    },
    {
        "school": "GRAND PRAIRIE H S",
        "district": "GRAND PRAIRIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002152",
    },
    {
        "school": "ANDREW JACKSON MIDDLE",
        "district": "GRAND PRAIRIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002153",
    },
    {
        "school": "ELLEN OCHOA STEM ACADEMY AT BEN MILIAM EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002158",
    },
    {
        "school": "SAM RAYBURN EL STEAM ACADEMY",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002160",
    },
    {
        "school": "SOUTH GRAND PRAIRIE H S",
        "district": "GRAND PRAIRIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002162",
    },
    {
        "school": "LORENZO DE ZAVALA ENVIRONMENTAL SCIENCE ACADEMY",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142002164",
    },
    {
        "school": "HARRY S TRUMAN MIDDLE",
        "district": "GRAND PRAIRIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142005482",
    },
    {
        "school": "SUZANNA DICKINSON EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142005734",
    },
    {
        "school": "GARNER FINE ARTS ACADEMY",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142006420",
    },
    {
        "school": "LYNDON B JOHNSON DAEP",
        "district": "GRAND PRAIRIE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482142006970",
    },
    {
        "school": "P A S S LEARNING CTR",
        "district": "GRAND PRAIRIE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482142007575",
    },
    {
        "school": "GLOBAL LEADERSHIP ACADEMY AT BARBARA BUSH EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142007576",
    },
    {
        "school": "COLIN POWELL EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142007577",
    },
    {
        "school": "HECTOR P GARCIA EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142008186",
    },
    {
        "school": "SALLYE R MOORE COLLEGE & CAREER PREPARATORY",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142008522",
    },
    {
        "school": "ERVIN C WHITT EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142008523",
    },
    {
        "school": "ARMSTRONG EL",
        "district": "HIGHLAND PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482325002355",
    },
    {
        "school": "BRADFIELD EL",
        "district": "HIGHLAND PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482325002356",
    },
    {
        "school": "HIGHLAND PARK H S",
        "district": "HIGHLAND PARK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482325002357",
    },
    {
        "school": "HYER EL",
        "district": "HIGHLAND PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482325002358",
    },
    {
        "school": "HIGHLAND PARK MIDDLE",
        "district": "HIGHLAND PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482325002359",
    },
    {
        "school": "UNIVERSITY PARK ELEMENTARY",
        "district": "HIGHLAND PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482325002360",
    },
    {
        "school": "MCCULLOCH INTERMEDIATE SCHOOL",
        "district": "HIGHLAND PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482325006971",
    },
    {
        "school": "BARTON EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002715",
    },
    {
        "school": "BOWIE MIDDLE",
        "district": "IRVING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002716",
    },
    {
        "school": "BRANDENBURG EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002717",
    },
    {
        "school": "BRITAIN EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002718",
    },
    {
        "school": "CROCKETT MIDDLE",
        "district": "IRVING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002719",
    },
    {
        "school": "ELLIOTT EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002720",
    },
    {
        "school": "FARINE EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002721",
    },
    {
        "school": "GOOD EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002722",
    },
    {
        "school": "HALEY J EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002723",
    },
    {
        "school": "HALEY T EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002724",
    },
    {
        "school": "HANES EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002725",
    },
    {
        "school": "IRVING H S",
        "district": "IRVING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002726",
    },
    {
        "school": "SCHULZE EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002727",
    },
    {
        "school": "JOHNSTON EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002728",
    },
    {
        "school": "KEYES EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002729",
    },
    {
        "school": "LAMAR MIDDLE",
        "district": "IRVING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002730",
    },
    {
        "school": "LEE EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002731",
    },
    {
        "school": "LIVELY EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002732",
    },
    {
        "school": "MACARTHUR H S",
        "district": "IRVING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002733",
    },
    {
        "school": "NIMITZ H S",
        "district": "IRVING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002734",
    },
    {
        "school": "BROWN EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002735",
    },
    {
        "school": "HOUSTON MIDDLE",
        "district": "IRVING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002736",
    },
    {
        "school": "AUSTIN MIDDLE",
        "district": "IRVING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002737",
    },
    {
        "school": "TOWNLEY EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002738",
    },
    {
        "school": "TRAVIS MIDDLE",
        "district": "IRVING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442002739",
    },
    {
        "school": "BARBARA CARDWELL CAREER PREPARATORY CENTER",
        "district": "IRVING ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482442006275",
    },
    {
        "school": "DAVIS EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442006869",
    },
    {
        "school": "STUDENT REASSIGNMENT CTR",
        "district": "IRVING ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482442007259",
    },
    {
        "school": "GILBERT F M EL",
        "district": "IRVING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442007260",
    },
    {
        "school": "DALLAS CO SCHOOL FOR ACCELERATED LRNG",
        "district": "IRVING ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482442008187",
    },
    {
        "school": "CLIFTON EARLY CHILDHOOD",
        "district": "IRVING ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442008188",
    },
    {
        "school": "PIERCE EARLY CHILDHOOD",
        "district": "IRVING ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442008189",
    },
    {
        "school": "KINKEADE EARLY CHILDHOOD",
        "district": "IRVING ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442008190",
    },
    {
        "school": "JACK E SINGLEY ACADEMY",
        "district": "IRVING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482442008525",
    },
    {
        "school": "HOUSTON EL",
        "district": "LANCASTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482667003002",
    },
    {
        "school": "LANCASTER H S",
        "district": "LANCASTER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482667003003",
    },
    {
        "school": "LANCASTER MIDDLE",
        "district": "LANCASTER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482667003004",
    },
    {
        "school": "PLEASANT RUN EL",
        "district": "LANCASTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482667003005",
    },
    {
        "school": "WEST MAIN EL",
        "district": "LANCASTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482667003006",
    },
    {
        "school": "ROSA PARKS/MILLBROOK EL",
        "district": "LANCASTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482667006288",
    },
    {
        "school": "ROLLING HILLS EL",
        "district": "LANCASTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482667006743",
    },
    {
        "school": "L ISD J J A E P",
        "district": "LANCASTER ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482667008191",
    },
    {
        "school": "MOSS EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039000567",
    },
    {
        "school": "AGNEW MIDDLE",
        "district": "MESQUITE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003401",
    },
    {
        "school": "BLACK EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003402",
    },
    {
        "school": "FLORENCE EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003403",
    },
    {
        "school": "FLOYD EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003404",
    },
    {
        "school": "GALLOWAY EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003405",
    },
    {
        "school": "HODGES EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003406",
    },
    {
        "school": "HANBY EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003407",
    },
    {
        "school": "LAWRENCE EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003408",
    },
    {
        "school": "MCDONALD MIDDLE",
        "district": "MESQUITE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003409",
    },
    {
        "school": "MCWHORTER EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003410",
    },
    {
        "school": "MESQUITE H S",
        "district": "MESQUITE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003411",
    },
    {
        "school": "MOTLEY EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003412",
    },
    {
        "school": "NORTH MESQUITE H S",
        "district": "MESQUITE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003413",
    },
    {
        "school": "RANGE EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003414",
    },
    {
        "school": "RUGEL EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003415",
    },
    {
        "school": "RUTHERFORD EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003416",
    },
    {
        "school": "SEABOURN EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003417",
    },
    {
        "school": "SHANDS EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003418",
    },
    {
        "school": "TISINGER EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003419",
    },
    {
        "school": "TOSCH EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003420",
    },
    {
        "school": "VANSTON MIDDLE",
        "district": "MESQUITE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003421",
    },
    {
        "school": "WEST MESQUITE H S",
        "district": "MESQUITE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003422",
    },
    {
        "school": "WILKINSON MIDDLE",
        "district": "MESQUITE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003423",
    },
    {
        "school": "KIMBROUGH MIDDLE",
        "district": "MESQUITE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039003695",
    },
    {
        "school": "MCKENZIE EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039005551",
    },
    {
        "school": "PORTER EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039005552",
    },
    {
        "school": "BEASLEY EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039005778",
    },
    {
        "school": "PRICE EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039005779",
    },
    {
        "school": "SHAW EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039005898",
    },
    {
        "school": "KIMBALL EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039006144",
    },
    {
        "school": "POTEET H S",
        "district": "MESQUITE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039006301",
    },
    {
        "school": "NEW MIDDLE",
        "district": "MESQUITE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039006449",
    },
    {
        "school": "PIRRUNG EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039006450",
    },
    {
        "school": "CANNADAY EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039006583",
    },
    {
        "school": "AUSTIN EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039006755",
    },
    {
        "school": "THOMPSON EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039006972",
    },
    {
        "school": "PASS LEARNING CTR",
        "district": "MESQUITE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483039007578",
    },
    {
        "school": "BERRY MIDDLE",
        "district": "MESQUITE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039007579",
    },
    {
        "school": "SMITH EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039007860",
    },
    {
        "school": "GRAY EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039008192",
    },
    {
        "school": "HORN H S",
        "district": "MESQUITE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039008764",
    },
    {
        "school": "APOLLO J H",
        "district": "RICHARDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004122",
    },
    {
        "school": "ARAPAHO CLASSICAL MAGNET",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004123",
    },
    {
        "school": "BERKNER H S",
        "district": "RICHARDSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004124",
    },
    {
        "school": "BIG SPRINGS EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004125",
    },
    {
        "school": "BOWIE EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004126",
    },
    {
        "school": "BRENTFIELD EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004127",
    },
    {
        "school": "CANYON CREEK EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004128",
    },
    {
        "school": "DARTMOUTH EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004129",
    },
    {
        "school": "DOBIE PRE-KINDERGARTEN SCHOOL",
        "district": "RICHARDSON ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004130",
    },
    {
        "school": "DOVER EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004131",
    },
    {
        "school": "FOREST MEADOW J H",
        "district": "RICHARDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004132",
    },
    {
        "school": "FORESTRIDGE EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004133",
    },
    {
        "school": "GREENWOOD HILLS EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004134",
    },
    {
        "school": "HAMILTON PARK PACESETTER MAGNET",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004135",
    },
    {
        "school": "JESS HARBEN EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004136",
    },
    {
        "school": "LAKE HIGHLANDS EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004137",
    },
    {
        "school": "LAKE HIGHLANDS H S",
        "district": "RICHARDSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004138",
    },
    {
        "school": "LAKE HIGHLANDS J H",
        "district": "RICHARDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004139",
    },
    {
        "school": "LIBERTY J H",
        "district": "RICHARDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004140",
    },
    {
        "school": "MOHAWK EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004141",
    },
    {
        "school": "MOSS HAVEN EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004142",
    },
    {
        "school": "NORTHLAKE EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004143",
    },
    {
        "school": "NORTHRICH EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004144",
    },
    {
        "school": "NORTHWOOD HILLS EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004145",
    },
    {
        "school": "O HENRY EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004147",
    },
    {
        "school": "PEARCE H S",
        "district": "RICHARDSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004148",
    },
    {
        "school": "PRAIRIE CREEK EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004149",
    },
    {
        "school": "PRESTONWOOD EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004150",
    },
    {
        "school": "RICHARDSON H S",
        "district": "RICHARDSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004151",
    },
    {
        "school": "RICHARDSON HEIGHTS EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004152",
    },
    {
        "school": "RICHARDSON NORTH J H",
        "district": "RICHARDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004154",
    },
    {
        "school": "RICHARDSON TERRACE EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004155",
    },
    {
        "school": "RICHARDSON WEST J H",
        "district": "RICHARDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004156",
    },
    {
        "school": "RICHLAND EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004157",
    },
    {
        "school": "SKYVIEW EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004158",
    },
    {
        "school": "SPRING CREEK EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004159",
    },
    {
        "school": "SPRING VALLEY EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004160",
    },
    {
        "school": "SPRINGRIDGE EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004161",
    },
    {
        "school": "STULTS ROAD EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004162",
    },
    {
        "school": "MARK TWAIN EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004163",
    },
    {
        "school": "WALLACE EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004164",
    },
    {
        "school": "WESTWOOD MATH SCIENCE LEADERSHIP MAGNET",
        "district": "RICHARDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004165",
    },
    {
        "school": "WHITE ROCK EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004166",
    },
    {
        "school": "YALE EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702004167",
    },
    {
        "school": "AIKIN EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702005581",
    },
    {
        "school": "CHRISTA MCAULIFFE LEARNING CENTER",
        "district": "RICHARDSON ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483702005582",
    },
    {
        "school": "MERRIMAN PARK EL",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702005584",
    },
    {
        "school": "PARKHILL J H",
        "district": "RICHARDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702005585",
    },
    {
        "school": "RISD ACAD",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702006899",
    },
    {
        "school": "MATH/SCIENCE/TECH MAGNET",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702006975",
    },
    {
        "school": "P A S S LEARNING CTR",
        "district": "RICHARDSON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483702007580",
    },
    {
        "school": "FOREST LANE ACADEMY",
        "district": "RICHARDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702008193",
    },
    {
        "school": "SUNNYVALE EL",
        "district": "SUNNYVALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484188004775",
    },
    {
        "school": "UNIVERSAL ACADEMY - COPPELL",
        "district": "UNIVERSAL ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007008503",
    },
    {
        "school": "WINFREE ACADEMY CHARTER SCHOOL (LEWISVILLE)",
        "district": "WINFREE ACADEMY CHARTER SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020208757",
    },
    {
        "school": "HILLTOP EL",
        "district": "ARGYLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480867000230",
    },
    {
        "school": "ARGYLE MIDDLE",
        "district": "ARGYLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480867008200",
    },
    {
        "school": "ARGYLE H S",
        "district": "ARGYLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480867008769",
    },
    {
        "school": "HL BROCKETT",
        "district": "AUBREY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480891000287",
    },
    {
        "school": "AUBREY H S",
        "district": "AUBREY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480891000288",
    },
    {
        "school": "AUBREY MIDDLE",
        "district": "AUBREY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480891007267",
    },
    {
        "school": "MCKAMY EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000463",
    },
    {
        "school": "DAVIS EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000796",
    },
    {
        "school": "THOMPSON EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305000809",
    },
    {
        "school": "LONG MIDDLE",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305005670",
    },
    {
        "school": "RAINWATER EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305005740",
    },
    {
        "school": "HUIE SPECIAL EDUC CTR",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481305005854",
    },
    {
        "school": "FURNEAUX EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305005968",
    },
    {
        "school": "ROSEMEADE EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305005969",
    },
    {
        "school": "BLALACK MIDDLE",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305006230",
    },
    {
        "school": "KENT EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305006663",
    },
    {
        "school": "CREEKVIEW H S",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305007852",
    },
    {
        "school": "DENTON COUNTY JJAEP CFB CAMPUS",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481305008510",
    },
    {
        "school": "MCWHORTER EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305008511",
    },
    {
        "school": "SHEFFIELD EL",
        "district": "CARROLLTON-FARMERS BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481305021019",
    },
    {
        "school": "DENTON H S",
        "district": "DENTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674000657",
    },
    {
        "school": "BORMAN EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674001445",
    },
    {
        "school": "CALHOUN MIDDLE",
        "district": "DENTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674001446",
    },
    {
        "school": "GINNINGS EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674001449",
    },
    {
        "school": "ALICE MOORE ALEXANDER",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674001451",
    },
    {
        "school": "NEWTON RAYZOR EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674001452",
    },
    {
        "school": "STRICKLAND MIDDLE",
        "district": "DENTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674001453",
    },
    {
        "school": "WILSON EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674001454",
    },
    {
        "school": "JOE DALE SPARKS CAMPUS",
        "district": "DENTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481674003735",
    },
    {
        "school": "HOUSTON EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674005696",
    },
    {
        "school": "EVERS PARK EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674006092",
    },
    {
        "school": "HODGE EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674006394",
    },
    {
        "school": "MCNAIR EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674006395",
    },
    {
        "school": "RIVERA EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674006939",
    },
    {
        "school": "RYAN H S",
        "district": "DENTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674006976",
    },
    {
        "school": "LESTER DAVIS",
        "district": "DENTON ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481674007265",
    },
    {
        "school": "DENTON CO J J A E P",
        "district": "DENTON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481674007581",
    },
    {
        "school": "MCMATH MIDDLE",
        "district": "DENTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674007864",
    },
    {
        "school": "RYAN EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674008530",
    },
    {
        "school": "THE ANN WINDLE SCHOOL FOR YOUNG CHILDREN",
        "district": "DENTON ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674008531",
    },
    {
        "school": "FRED MOORE H S",
        "district": "DENTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481674021219",
    },
    {
        "school": "FISHER EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001008483",
    },
    {
        "school": "DYER EL",
        "district": "KRUM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482598002924",
    },
    {
        "school": "KRUM H S",
        "district": "KRUM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482598002925",
    },
    {
        "school": "KRUM MIDDLE",
        "district": "KRUM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482598005760",
    },
    {
        "school": "BLANCHE DODD EL",
        "district": "KRUM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482598006736",
    },
    {
        "school": "LAKE DALLAS EL",
        "district": "LAKE DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482643002974",
    },
    {
        "school": "LAKE DALLAS H S",
        "district": "LAKE DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482643002975",
    },
    {
        "school": "LAKE DALLAS MIDDLE",
        "district": "LAKE DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482643002976",
    },
    {
        "school": "DENTON CO J J A E P",
        "district": "LAKE DALLAS ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482643008201",
    },
    {
        "school": "CORINTH EL",
        "district": "LAKE DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482643021224",
    },
    {
        "school": "GARDEN RIDGE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730000658",
    },
    {
        "school": "CAMEY EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730003064",
    },
    {
        "school": "CENTRAL EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730003065",
    },
    {
        "school": "DEGAN EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730003067",
    },
    {
        "school": "HEDRICK MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730003070",
    },
    {
        "school": "LAKELAND EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730003071",
    },
    {
        "school": "LEWISVILLE H S",
        "district": "LEWISVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730003072",
    },
    {
        "school": "TIMBER CREEK EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730003074",
    },
    {
        "school": "FORESTWOOD MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730003746",
    },
    {
        "school": "MORNINGSIDE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730003752",
    },
    {
        "school": "HERITAGE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730003753",
    },
    {
        "school": "PETERS COLONY EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730005536",
    },
    {
        "school": "GRIFFIN MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730005768",
    },
    {
        "school": "HIGHLAND VILLAGE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730005769",
    },
    {
        "school": "MARCUS H S",
        "district": "LEWISVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730005770",
    },
    {
        "school": "STEWARTS CREEK EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730005771",
    },
    {
        "school": "FLOWER MOUND EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006137",
    },
    {
        "school": "INDIAN CREEK EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006138",
    },
    {
        "school": "THE COLONY H S",
        "district": "LEWISVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006291",
    },
    {
        "school": "LAMAR MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006440",
    },
    {
        "school": "MCAULIFFE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006441",
    },
    {
        "school": "B B OWEN EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006442",
    },
    {
        "school": "LEARNING CTR",
        "district": "LEWISVILLE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482730006744",
    },
    {
        "school": "LAKEVIEW MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006745",
    },
    {
        "school": "DONALD EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006746",
    },
    {
        "school": "HEBRON VALLEY EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006747",
    },
    {
        "school": "CREEKSIDE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006880",
    },
    {
        "school": "BRIARHILL MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006977",
    },
    {
        "school": "DELAY MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006978",
    },
    {
        "school": "PARKWAY EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006980",
    },
    {
        "school": "POLSER EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006981",
    },
    {
        "school": "PRAIRIE TRAIL ELEMENTARY",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730006982",
    },
    {
        "school": "VALLEY RIDGE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730007266",
    },
    {
        "school": "HUFFINES MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730007583",
    },
    {
        "school": "MCKAMY MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730007584",
    },
    {
        "school": "FOREST VISTA EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730007585",
    },
    {
        "school": "DENTON CO J J A E P",
        "district": "LEWISVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482730007865",
    },
    {
        "school": "BRIDLEWOOD EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730007866",
    },
    {
        "school": "WELLINGTON EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730007867",
    },
    {
        "school": "HEBRON H S",
        "district": "LEWISVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730008195",
    },
    {
        "school": "FLOWER MOUND H S",
        "district": "LEWISVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730008196",
    },
    {
        "school": "SOUTHRIDGE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730008197",
    },
    {
        "school": "HOMESTEAD EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730008198",
    },
    {
        "school": "DALE JACKSON CAREER CTR",
        "district": "LEWISVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482730008532",
    },
    {
        "school": "CREEK VALLEY MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730008533",
    },
    {
        "school": "BLUEBONNET EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730008767",
    },
    {
        "school": "ETHRIDGE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730021023",
    },
    {
        "school": "LITTLE ELM H S",
        "district": "LITTLE ELM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482772003111",
    },
    {
        "school": "LAKESIDE MIDDLE",
        "district": "LITTLE ELM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482772006443",
    },
    {
        "school": "DENTON CO J J A E P",
        "district": "LITTLE ELM ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482772008202",
    },
    {
        "school": "D H BRENT EL",
        "district": "LITTLE ELM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482772008770",
    },
    {
        "school": "JUSTIN EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318003730",
    },
    {
        "school": "NORTHWEST H S",
        "district": "NORTHWEST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318003732",
    },
    {
        "school": "DENTON CREEK",
        "district": "NORTHWEST ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483318003773",
    },
    {
        "school": "LAKEVIEW EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318005904",
    },
    {
        "school": "ROANOKE EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318006156",
    },
    {
        "school": "MEDLIN MIDDLE",
        "district": "NORTHWEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318007872",
    },
    {
        "school": "GENE PIKE MIDDLE",
        "district": "NORTHWEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318007873",
    },
    {
        "school": "SAMUEL BECK EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318007875",
    },
    {
        "school": "W R HATFIELD EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318007876",
    },
    {
        "school": "DENTON CO J J A E P",
        "district": "NORTHWEST ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483318008535",
    },
    {
        "school": "PILOT POINT EL",
        "district": "PILOT POINT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483492003928",
    },
    {
        "school": "PILOT POINT H S",
        "district": "PILOT POINT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483492003929",
    },
    {
        "school": "PILOT POINT SELZ MIDDLE",
        "district": "PILOT POINT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483492003930",
    },
    {
        "school": "PILOT POINT INT",
        "district": "PILOT POINT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483492008199",
    },
    {
        "school": "PONDER EL",
        "district": "PONDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483531003991",
    },
    {
        "school": "PONDER H S",
        "district": "PONDER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483531003992",
    },
    {
        "school": "DENTON CO J J A E P",
        "district": "PONDER ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483531008534",
    },
    {
        "school": "CLEAR CREEK INT",
        "district": "SANGER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483918004467",
    },
    {
        "school": "SANGER H S",
        "district": "SANGER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483918004468",
    },
    {
        "school": "SANGER MIDDLE",
        "district": "SANGER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483918004469",
    },
    {
        "school": "CHISHOLM TRAIL EL",
        "district": "SANGER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483918006472",
    },
    {
        "school": "LINDA TUTT H S",
        "district": "SANGER ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483918007869",
    },
    {
        "school": "AVALON SCHOOL",
        "district": "AVALON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480903000374",
    },
    {
        "school": "AUSTIN EL",
        "district": "ENNIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481854001736",
    },
    {
        "school": "ENNIS H S",
        "district": "ENNIS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481854001737",
    },
    {
        "school": "HOUSTON EL",
        "district": "ENNIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481854001738",
    },
    {
        "school": "ENNIS J H",
        "district": "ENNIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481854001739",
    },
    {
        "school": "TRAVIS EL",
        "district": "ENNIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481854001740",
    },
    {
        "school": "BOWIE EL",
        "district": "ENNIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481854006405",
    },
    {
        "school": "JACK LUMMUS INT",
        "district": "ENNIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481854007588",
    },
    {
        "school": "HAZEL INGRAM EL",
        "district": "FERRIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481917001785",
    },
    {
        "school": "FERRIS H S",
        "district": "FERRIS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481917001786",
    },
    {
        "school": "FERRIS J H",
        "district": "FERRIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481917001787",
    },
    {
        "school": "FERRIS INT",
        "district": "FERRIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481917006696",
    },
    {
        "school": "ITALY H S",
        "district": "ITALY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482445002740",
    },
    {
        "school": "STAFFORD EL",
        "district": "ITALY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482445002741",
    },
    {
        "school": "LORENE SMITH KIRKPATRICK EL",
        "district": "MAYPEARL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482958003322",
    },
    {
        "school": "MAYPEARL H S",
        "district": "MAYPEARL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482958003323",
    },
    {
        "school": "MAYPEARL MIDDLE",
        "district": "MAYPEARL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482958006884",
    },
    {
        "school": "MIDLOTHIAN H S",
        "district": "MIDLOTHIAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060003458",
    },
    {
        "school": "FRANK SEALE MIDDLE",
        "district": "MIDLOTHIAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060006303",
    },
    {
        "school": "IRVIN EL",
        "district": "MIDLOTHIAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060006304",
    },
    {
        "school": "T E BAXTER EL",
        "district": "MIDLOTHIAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060006586",
    },
    {
        "school": "LONGBRANCH EL",
        "district": "MIDLOTHIAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060007589",
    },
    {
        "school": "MT PEAK EL",
        "district": "MIDLOTHIAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060007590",
    },
    {
        "school": "MILFORD SCHOOL",
        "district": "MILFORD ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483078003473",
    },
    {
        "school": "PALMER EL",
        "district": "PALMER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483411003793",
    },
    {
        "school": "PALMER H S",
        "district": "PALMER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483411003794",
    },
    {
        "school": "PALMER MIDDLE",
        "district": "PALMER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483411006595",
    },
    {
        "school": "EASTRIDGE EL",
        "district": "RED OAK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483666003774",
    },
    {
        "school": "RED OAK EL",
        "district": "RED OAK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483666004105",
    },
    {
        "school": "RED OAK H S",
        "district": "RED OAK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483666004106",
    },
    {
        "school": "RED OAK MIDDLE",
        "district": "RED OAK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483666004107",
    },
    {
        "school": "SHIELDS EL",
        "district": "RED OAK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483666005800",
    },
    {
        "school": "WOODEN EL",
        "district": "RED OAK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483666006164",
    },
    {
        "school": "NORTHSIDE EL",
        "district": "WAXAHACHIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473005092",
    },
    {
        "school": "EDDIE FINLEY SR J H",
        "district": "WAXAHACHIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473005093",
    },
    {
        "school": "WAXAHACHIE H S",
        "district": "WAXAHACHIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473005095",
    },
    {
        "school": "DUNAWAY EL",
        "district": "WAXAHACHIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473006494",
    },
    {
        "school": "SHACKELFORD EL",
        "district": "WAXAHACHIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473006624",
    },
    {
        "school": "WAXAHACHIE H S OF CHOICE",
        "district": "WAXAHACHIE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484473006943",
    },
    {
        "school": "WEDGEWORTH EL",
        "district": "WAXAHACHIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473008206",
    },
    {
        "school": "LAKEVIEW EL",
        "district": "MABANK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482868007374",
    },
    {
        "school": "BLAND EL",
        "district": "BLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481035000516",
    },
    {
        "school": "BLAND H S",
        "district": "BLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481035000517",
    },
    {
        "school": "BLAND MIDDLE",
        "district": "BLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481035007661",
    },
    {
        "school": "BOLES EL",
        "district": "BOLES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481074000539",
    },
    {
        "school": "BOLES H S",
        "district": "BOLES ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481074000540",
    },
    {
        "school": "FRANCES AND JEANNETTE LEE EL",
        "district": "CADDO MILLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481239000731",
    },
    {
        "school": "CADDO MILLS H S",
        "district": "CADDO MILLS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481239000732",
    },
    {
        "school": "CADDO MILLS MIDDLE",
        "district": "CADDO MILLS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481239005665",
    },
    {
        "school": "CAMPBELL EL",
        "district": "CAMPBELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481266000763",
    },
    {
        "school": "CAMPBELL H S",
        "district": "CAMPBELL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481266000764",
    },
    {
        "school": "CELESTE EL",
        "district": "CELESTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481326000827",
    },
    {
        "school": "CELESTE H S",
        "district": "CELESTE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481326000828",
    },
    {
        "school": "CELESTE J H",
        "district": "CELESTE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481326006522",
    },
    {
        "school": "COMMERCE H S",
        "district": "COMMERCE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481482000981",
    },
    {
        "school": "COMMERCE MIDDLE",
        "district": "COMMERCE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481482000982",
    },
    {
        "school": "COMMERCE EL",
        "district": "COMMERCE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481482000983",
    },
    {
        "school": "ALBERT C WILLIAMS EL",
        "district": "COMMERCE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481482005676",
    },
    {
        "school": "BOWIE EL",
        "district": "GREENVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482172002186",
    },
    {
        "school": "CARVER EL",
        "district": "GREENVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482172002187",
    },
    {
        "school": "CROCKETT EL",
        "district": "GREENVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482172002188",
    },
    {
        "school": "GREENVILLE H S",
        "district": "GREENVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482172002189",
    },
    {
        "school": "LAMAR EL",
        "district": "GREENVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482172002192",
    },
    {
        "school": "TRAVIS EL",
        "district": "GREENVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482172002193",
    },
    {
        "school": "GREENVILLE MIDDLE",
        "district": "GREENVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482172006421",
    },
    {
        "school": "NEW HORIZONS LEARNING CENTER",
        "district": "GREENVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482172006859",
    },
    {
        "school": "GREENVILLE ALTERNATIVE EDUCATIONAL PROGRAM",
        "district": "GREENVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482172007361",
    },
    {
        "school": "L P WATERS EARLY CHILDHOOD CENTER",
        "district": "GREENVILLE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482172007974",
    },
    {
        "school": "LONE OAK EL",
        "district": "LONE OAK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482802003136",
    },
    {
        "school": "LONE OAK H S",
        "district": "LONE OAK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482802003137",
    },
    {
        "school": "LONE OAK MIDDLE",
        "district": "LONE OAK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482802006294",
    },
    {
        "school": "A E BUTLER INT",
        "district": "QUINLAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483624004074",
    },
    {
        "school": "WH FORD H S",
        "district": "QUINLAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483624004075",
    },
    {
        "school": "C B THOMPSON MIDDLE",
        "district": "QUINLAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483624004076",
    },
    {
        "school": "D C CANNON EL",
        "district": "QUINLAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483624005907",
    },
    {
        "school": "WOLFE CITY EL",
        "district": "WOLFE CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484635005279",
    },
    {
        "school": "WOLFE CITY H S",
        "district": "WOLFE CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484635005280",
    },
    {
        "school": "WOLFE CITY MIDDLE",
        "district": "WOLFE CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484635005622",
    },
    {
        "school": "W A MARTIN EL",
        "district": "CRANDALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481551001122",
    },
    {
        "school": "CRANDALL H S",
        "district": "CRANDALL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481551001123",
    },
    {
        "school": "CRANDALL MIDDLE",
        "district": "CRANDALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481551001124",
    },
    {
        "school": "NOLA KATHRYN WILSON EL",
        "district": "CRANDALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481551007052",
    },
    {
        "school": "CRANDALL COMPASS ACADEMY",
        "district": "CRANDALL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481551007370",
    },
    {
        "school": "JOHNSON EL",
        "district": "FORNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956001809",
    },
    {
        "school": "FORNEY H S",
        "district": "FORNEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956001810",
    },
    {
        "school": "WARREN MIDDLE",
        "district": "FORNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956001811",
    },
    {
        "school": "KATHRYN WOLFE CRISWELL EL",
        "district": "FORNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956006253",
    },
    {
        "school": "FORNEY LEARNING ACADEMY",
        "district": "FORNEY ISD",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481956008683",
    },
    {
        "school": "L E CLAYBON EL",
        "district": "FORNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481956008684",
    },
    {
        "school": "KAUFMAN H S",
        "district": "KAUFMAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482520002816",
    },
    {
        "school": "NORMAN J H",
        "district": "KAUFMAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482520002817",
    },
    {
        "school": "KEMP PRI",
        "district": "KEMP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482532002825",
    },
    {
        "school": "KEMP H S",
        "district": "KEMP ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482532002826",
    },
    {
        "school": "KEMP J H",
        "district": "KEMP ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482532002827",
    },
    {
        "school": "KEMP INT",
        "district": "KEMP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482532006572",
    },
    {
        "school": "MABANK H S",
        "district": "MABANK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482868003248",
    },
    {
        "school": "MABANK J H",
        "district": "MABANK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482868003249",
    },
    {
        "school": "CENTRAL EL",
        "district": "MABANK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482868007372",
    },
    {
        "school": "SOUTHSIDE EL",
        "district": "MABANK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482868007373",
    },
    {
        "school": "SCURRY-ROSSER EL",
        "district": "SCURRY-ROSSER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483957004496",
    },
    {
        "school": "SCURRY-ROSSER H S",
        "district": "SCURRY-ROSSER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483957004497",
    },
    {
        "school": "SCURRY-ROSSER MIDDLE",
        "district": "SCURRY-ROSSER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483957006174",
    },
    {
        "school": "W H BURNETT EL",
        "district": "TERRELL ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484245004840",
    },
    {
        "school": "TERRELL H S",
        "district": "TERRELL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484245004841",
    },
    {
        "school": "HERMAN FURLOUGH JR MIDDLE",
        "district": "TERRELL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484245004843",
    },
    {
        "school": "TISD CHILD & ADOLESCENT SCHOOL",
        "district": "TERRELL ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484245005604",
    },
    {
        "school": "HOWARD DOBBS EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765004220",
    },
    {
        "school": "ROCKWALL H S",
        "district": "ROCKWALL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765004221",
    },
    {
        "school": "AMANDA ROCHELL EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765004222",
    },
    {
        "school": "VIRGINIA REINHARDT EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765006165",
    },
    {
        "school": "DORIS CULLINS-LAKE POINTE EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765006604",
    },
    {
        "school": "ROCKWALL QUEST ACADEMY",
        "district": "ROCKWALL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483765007060",
    },
    {
        "school": "J W WILLIAMS MIDDLE",
        "district": "ROCKWALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765007095",
    },
    {
        "school": "NEBBIE WILLIAMS EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765007422",
    },
    {
        "school": "MAURINE CAIN MIDDLE",
        "district": "ROCKWALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765008353",
    },
    {
        "school": "DOROTHY SMITH PULLEN EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765008354",
    },
    {
        "school": "ROYSE CITY H S",
        "district": "ROYSE CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483822004268",
    },
    {
        "school": "JEAN MASSIEU ACADEMY",
        "district": "JEAN MASSIEU ACADEMY",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480009808169",
    },
    {
        "school": "HASLET EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318003729",
    },
    {
        "school": "SEVEN HILLS EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318006593",
    },
    {
        "school": "CHISHOLM TRAIL MIDDLE",
        "district": "NORTHWEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318007874",
    },
    {
        "school": "PRAIRIE VIEW EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318007877",
    },
    {
        "school": "REMYNSE EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870009034",
    },
    {
        "school": "ALVARADO H S",
        "district": "ALVARADO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001100128",
    },
    {
        "school": "ALVARADO J H",
        "district": "ALVARADO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001100129",
    },
    {
        "school": "ALVARADO EL-SOUTH",
        "district": "ALVARADO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001100130",
    },
    {
        "school": "LILLIAN EL",
        "district": "ALVARADO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001103090",
    },
    {
        "school": "ALVARADO EL-NORTH",
        "district": "ALVARADO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001106201",
    },
    {
        "school": "ALVARADO INT",
        "district": "ALVARADO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001107367",
    },
    {
        "school": "BURLESON H S",
        "district": "BURLESON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218000715",
    },
    {
        "school": "FRAZIER EL",
        "district": "BURLESON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218000716",
    },
    {
        "school": "MOUND EL",
        "district": "BURLESON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218000717",
    },
    {
        "school": "NORWOOD EL",
        "district": "BURLESON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218000719",
    },
    {
        "school": "HUGHES MIDDLE",
        "district": "BURLESON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218000720",
    },
    {
        "school": "CROSSROADS H S",
        "district": "BURLESON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481218007978",
    },
    {
        "school": "WILLIAM STRIBLING EL",
        "district": "BURLESON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218007979",
    },
    {
        "school": "NICK KERR MIDDLE",
        "district": "BURLESON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218008855",
    },
    {
        "school": "ACADEMY AT NOLA DUNN",
        "district": "BURLESON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218008856",
    },
    {
        "school": "ADAMS EL",
        "district": "CLEBURNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481431000916",
    },
    {
        "school": "CLEBURNE H S",
        "district": "CLEBURNE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481431000917",
    },
    {
        "school": "LOWELL SMITH JR MIDDLE",
        "district": "CLEBURNE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481431000918",
    },
    {
        "school": "COLEMAN EL",
        "district": "CLEBURNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481431000919",
    },
    {
        "school": "MARTI EL",
        "district": "CLEBURNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481431000920",
    },
    {
        "school": "AD WHEAT MIDDLE",
        "district": "CLEBURNE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481431000921",
    },
    {
        "school": "IRVING EL",
        "district": "CLEBURNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481431000922",
    },
    {
        "school": "TEAM SCH",
        "district": "CLEBURNE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481431001614",
    },
    {
        "school": "GERARD EL",
        "district": "CLEBURNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481431006079",
    },
    {
        "school": "J J A E P",
        "district": "CLEBURNE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481431008680",
    },
    {
        "school": "GODLEY EL",
        "district": "GODLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482096002089",
    },
    {
        "school": "GODLEY H S",
        "district": "GODLEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482096002090",
    },
    {
        "school": "GODLEY MIDDLE",
        "district": "GODLEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482096006111",
    },
    {
        "school": "GODLEY INT",
        "district": "GODLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482096008858",
    },
    {
        "school": "GRANDVIEW H S",
        "district": "GRANDVIEW ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482154002171",
    },
    {
        "school": "GRANDVIEW J H",
        "district": "GRANDVIEW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482154005735",
    },
    {
        "school": "H D STAPLES EL",
        "district": "JOSHUA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482493002780",
    },
    {
        "school": "JOSHUA H S",
        "district": "JOSHUA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482493002781",
    },
    {
        "school": "R C LOFLIN MIDDLE",
        "district": "JOSHUA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482493002782",
    },
    {
        "school": "A G ELDER EL",
        "district": "JOSHUA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482493006126",
    },
    {
        "school": "NEW HORIZON H S",
        "district": "JOSHUA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482493007013",
    },
    {
        "school": "PLUM CREEK EL",
        "district": "JOSHUA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482493007666",
    },
    {
        "school": "NORTH JOSHUA EL",
        "district": "JOSHUA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482493008857",
    },
    {
        "school": "KEENE EL",
        "district": "KEENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482523002819",
    },
    {
        "school": "KEENE H S",
        "district": "KEENE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482523006726",
    },
    {
        "school": "KEENE J H",
        "district": "KEENE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482523006727",
    },
    {
        "school": "ALTER LEARNING CTR",
        "district": "KEENE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482523007014",
    },
    {
        "school": "RIO VISTA EL",
        "district": "RIO VISTA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483720004186",
    },
    {
        "school": "RIO VISTA H S",
        "district": "RIO VISTA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483720004187",
    },
    {
        "school": "RIO VISTA MIDDLE",
        "district": "RIO VISTA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483720006468",
    },
    {
        "school": "RIO VISTA ISD JJAEP",
        "district": "RIO VISTA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483720008681",
    },
    {
        "school": "VENUS EL",
        "district": "VENUS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484401004992",
    },
    {
        "school": "VENUS H S",
        "district": "VENUS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484401004993",
    },
    {
        "school": "VENUS PRI",
        "district": "VENUS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484401008313",
    },
    {
        "school": "VANDAGRIFF EL",
        "district": "ALEDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480778000088",
    },
    {
        "school": "ALEDO H S",
        "district": "ALEDO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480778000089",
    },
    {
        "school": "ALEDO MIDDLE",
        "district": "ALEDO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480778000090",
    },
    {
        "school": "CODER EL",
        "district": "ALEDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480778006501",
    },
    {
        "school": "STUARD EL",
        "district": "ALEDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480778008897",
    },
    {
        "school": "SILVER CREEK EL",
        "district": "AZLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480920006359",
    },
    {
        "school": "CROSS TIMBERS EL",
        "district": "AZLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480920008042",
    },
    {
        "school": "BROCK H S",
        "district": "BROCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481146000621",
    },
    {
        "school": "BROCK INT",
        "district": "BROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481146001871",
    },
    {
        "school": "GARNER EL",
        "district": "GARNER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482037002054",
    },
    {
        "school": "MILLSAP EL",
        "district": "MILLSAP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483087003476",
    },
    {
        "school": "MILLSAP H S",
        "district": "MILLSAP ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483087003477",
    },
    {
        "school": "MILLSAP MIDDLE",
        "district": "MILLSAP ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483087009008",
    },
    {
        "school": "PEASTER H S",
        "district": "PEASTER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483450003873",
    },
    {
        "school": "PEASTER MIDDLE",
        "district": "PEASTER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483450007082",
    },
    {
        "school": "PEASTER EL",
        "district": "PEASTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483450007083",
    },
    {
        "school": "POOLVILLE H S",
        "district": "POOLVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483534003994",
    },
    {
        "school": "POOLVILLE EL",
        "district": "POOLVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483534008011",
    },
    {
        "school": "SPRINGTOWN H S",
        "district": "SPRINGTOWN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484128004729",
    },
    {
        "school": "SPRINGTOWN MIDDLE",
        "district": "SPRINGTOWN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484128004730",
    },
    {
        "school": "SPRINGTOWN EL",
        "district": "SPRINGTOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484128006333",
    },
    {
        "school": "SPRINGTOWN RENO EL",
        "district": "SPRINGTOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484128008892",
    },
    {
        "school": "SPRINGTOWN INT",
        "district": "SPRINGTOWN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484128008893",
    },
    {
        "school": "CROCKETT EL",
        "district": "WEATHERFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484480005097",
    },
    {
        "school": "WRIGHT EL",
        "district": "WEATHERFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484480005098",
    },
    {
        "school": "WEATHERFORD H S",
        "district": "WEATHERFORD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484480005100",
    },
    {
        "school": "HALL MIDDLE",
        "district": "WEATHERFORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484480005101",
    },
    {
        "school": "CURTIS EL",
        "district": "WEATHERFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484480006495",
    },
    {
        "school": "AUSTIN EL",
        "district": "WEATHERFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484480006625",
    },
    {
        "school": "MARTIN EL",
        "district": "WEATHERFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484480007420",
    },
    {
        "school": "TISON MIDDLE",
        "district": "WEATHERFORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484480007708",
    },
    {
        "school": "TREETOPS SCHOOL INTERNATIONAL",
        "district": "TREETOPS SCHOOL INTERNATIONAL",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006808023",
    },
    {
        "school": "ARLINGTON CLASSICS ACADEMY - ARKANSAS CAMPUS",
        "district": "ARLINGTON CLASSICS ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480015808363",
    },
    {
        "school": "FORT WORTH ACADEMY OF FINE ARTS",
        "district": "FORT WORTH ACADEMY OF FINE ARTS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023109030",
    },
    {
        "school": "AMOS EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000231",
    },
    {
        "school": "ARLINGTON H S",
        "district": "ARLINGTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000232",
    },
    {
        "school": "ATHERTON EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000233",
    },
    {
        "school": "BAILEY J H",
        "district": "ARLINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000234",
    },
    {
        "school": "BERRY EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000235",
    },
    {
        "school": "BLANTON EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000236",
    },
    {
        "school": "BUTLER EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000238",
    },
    {
        "school": "CARTER J H",
        "district": "ARLINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000239",
    },
    {
        "school": "CROW LEADERSHIP ACADEMY",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000240",
    },
    {
        "school": "DITTO EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000241",
    },
    {
        "school": "DUFF EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000242",
    },
    {
        "school": "DUNN EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000243",
    },
    {
        "school": "FOSTER EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000245",
    },
    {
        "school": "GOODMAN EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000246",
    },
    {
        "school": "GUNN J H",
        "district": "ARLINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000247",
    },
    {
        "school": "HILL EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000248",
    },
    {
        "school": "SAM HOUSTON H S",
        "district": "ARLINGTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000249",
    },
    {
        "school": "JOHNS EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000251",
    },
    {
        "school": "KEY EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000252",
    },
    {
        "school": "LAMAR H S",
        "district": "ARLINGTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000253",
    },
    {
        "school": "MORTON EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000255",
    },
    {
        "school": "NICHOLS J H",
        "district": "ARLINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000256",
    },
    {
        "school": "POPE EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000257",
    },
    {
        "school": "RANKIN EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000258",
    },
    {
        "school": "ROARK EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000259",
    },
    {
        "school": "SHACKELFORD J H",
        "district": "ARLINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000261",
    },
    {
        "school": "SHORT EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000262",
    },
    {
        "school": "SOUTH DAVIS EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000263",
    },
    {
        "school": "SPEER EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000264",
    },
    {
        "school": "SWIFT EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000265",
    },
    {
        "school": "THORNTON EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870000266",
    },
    {
        "school": "WILLIAMS EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870002041",
    },
    {
        "school": "LITTLE EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870002049",
    },
    {
        "school": "BARNETT J H",
        "district": "ARLINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870005335",
    },
    {
        "school": "BRYANT EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870005343",
    },
    {
        "school": "WEBB EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870005364",
    },
    {
        "school": "SHERROD EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870005390",
    },
    {
        "school": "WOOD EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870005391",
    },
    {
        "school": "YOUNG J H",
        "district": "ARLINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870005392",
    },
    {
        "school": "MARTIN H S",
        "district": "ARLINGTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870005643",
    },
    {
        "school": "MILLER EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870005644",
    },
    {
        "school": "TURNING POINT SECONDARY SCHOOL",
        "district": "ARLINGTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480870005792",
    },
    {
        "school": "COREY FINE ARTS / DUAL LANGUAGE ACADEMY",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870005845",
    },
    {
        "school": "WORKMAN J H",
        "district": "ARLINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870005846",
    },
    {
        "school": "FITZGERALD EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870006066",
    },
    {
        "school": "BOLES J H",
        "district": "ARLINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870006352",
    },
    {
        "school": "STARRETT EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870006353",
    },
    {
        "school": "KOOKEN ED CTR",
        "district": "ARLINGTON ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870006506",
    },
    {
        "school": "BEBENSEE EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870006507",
    },
    {
        "school": "ELLIS EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870006821",
    },
    {
        "school": "VENTURE ALTER H S",
        "district": "ARLINGTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480870007066",
    },
    {
        "school": "NEWCOMER CENTER",
        "district": "ARLINGTON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480870007110",
    },
    {
        "school": "ASHWORTH EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870007433",
    },
    {
        "school": "CROUCH EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870007434",
    },
    {
        "school": "OUSLEY J H",
        "district": "ARLINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870007721",
    },
    {
        "school": "LARSON EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870007722",
    },
    {
        "school": "WEST EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870007723",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "ARLINGTON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480870008024",
    },
    {
        "school": "HALE EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870008025",
    },
    {
        "school": "PEARCY STEM ACADEMY",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870008909",
    },
    {
        "school": "BURGIN EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870008910",
    },
    {
        "school": "KNOX EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870009032",
    },
    {
        "school": "BECKHAM EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870009033",
    },
    {
        "school": "FARRELL EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870021051",
    },
    {
        "school": "MOORE EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870021052",
    },
    {
        "school": "BOWIE H S",
        "district": "ARLINGTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870021493",
    },
    {
        "school": "AZLE EL",
        "district": "AZLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480920000381",
    },
    {
        "school": "AZLE H S",
        "district": "AZLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480920000382",
    },
    {
        "school": "AZLE J H SOUTH",
        "district": "AZLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480920000383",
    },
    {
        "school": "EAGLE HEIGHTS EL",
        "district": "AZLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480920000384",
    },
    {
        "school": "WALNUT CREEK EL",
        "district": "AZLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480920000385",
    },
    {
        "school": "LIBERTY EL",
        "district": "AZLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480920005401",
    },
    {
        "school": "W E HOOVER EL",
        "district": "AZLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480920005445",
    },
    {
        "school": "SANTO FORTE J H",
        "district": "AZLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480920008374",
    },
    {
        "school": "ALLIENE MULLENDORE EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000483",
    },
    {
        "school": "BIRDVILLE EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000484",
    },
    {
        "school": "DAVID E SMITH EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000485",
    },
    {
        "school": "ACADEMY AT CARRIE F THOMAS",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000486",
    },
    {
        "school": "JACK C BINION EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000487",
    },
    {
        "school": "GRACE E HARDEMAN EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000488",
    },
    {
        "school": "HALTOM H S",
        "district": "BIRDVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000489",
    },
    {
        "school": "HALTOM MIDDLE",
        "district": "BIRDVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000490",
    },
    {
        "school": "HOLIDAY HEIGHTS EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000491",
    },
    {
        "school": "NORTH OAKS MIDDLE",
        "district": "BIRDVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000492",
    },
    {
        "school": "NORTH RICHLAND MIDDLE",
        "district": "BIRDVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000493",
    },
    {
        "school": "RICHLAND EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000494",
    },
    {
        "school": "RICHLAND H S",
        "district": "BIRDVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000495",
    },
    {
        "school": "RICHLAND MIDDLE",
        "district": "BIRDVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000496",
    },
    {
        "school": "SMITHFIELD EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000497",
    },
    {
        "school": "SMITHFIELD MIDDLE",
        "district": "BIRDVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000498",
    },
    {
        "school": "SNOW HEIGHTS EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000499",
    },
    {
        "school": "MAJOR CHENEY EL AT SOUTH BIRDVILLE",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000500",
    },
    {
        "school": "O H STOWE EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000501",
    },
    {
        "school": "W A PORTER EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000502",
    },
    {
        "school": "W T FRANCISCO EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000503",
    },
    {
        "school": "WATAUGA EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000504",
    },
    {
        "school": "WATAUGA MIDDLE",
        "district": "BIRDVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000505",
    },
    {
        "school": "WEST BIRDVILLE EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023000506",
    },
    {
        "school": "GREEN VALLEY EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023002102",
    },
    {
        "school": "FOSTER VILLAGE EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023005410",
    },
    {
        "school": "HOMEBOUND",
        "district": "BIRDVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481023006364",
    },
    {
        "school": "NORTH RIDGE EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023006513",
    },
    {
        "school": "NORTH RIDGE MIDDLE",
        "district": "BIRDVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023006653",
    },
    {
        "school": "BIRDVILLE H S",
        "district": "BIRDVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023008368",
    },
    {
        "school": "JOHN D SPICER EL",
        "district": "BIRDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023021496",
    },
    {
        "school": "JACK TAYLOR EL",
        "district": "BURLESON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218006227",
    },
    {
        "school": "JACK D JOHNSON EL",
        "district": "CARROLL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481302000790",
    },
    {
        "school": "CARROLL SENIOR H S",
        "district": "CARROLL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481302000791",
    },
    {
        "school": "CARROLL EL",
        "district": "CARROLL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481302006373",
    },
    {
        "school": "WALNUT GROVE EL",
        "district": "CARROLL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481302007122",
    },
    {
        "school": "DON T DURHAM INT",
        "district": "CARROLL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481302007448",
    },
    {
        "school": "ROBERT H ROCKENBAUGH EL",
        "district": "CARROLL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481302007733",
    },
    {
        "school": "CARROLL MIDDLE",
        "district": "CARROLL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481302008923",
    },
    {
        "school": "OLD UNION EL",
        "district": "CARROLL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481302009060",
    },
    {
        "school": "EUBANKS INT",
        "district": "CARROLL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481302009061",
    },
    {
        "school": "A V CATO EL",
        "district": "CASTLEBERRY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481317000815",
    },
    {
        "school": "CASTLEBERRY EL",
        "district": "CASTLEBERRY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481317000816",
    },
    {
        "school": "CASTLEBERRY H S",
        "district": "CASTLEBERRY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481317000817",
    },
    {
        "school": "MARSH MIDDLE",
        "district": "CASTLEBERRY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481317000818",
    },
    {
        "school": "JOY JAMES EL",
        "district": "CASTLEBERRY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481317000819",
    },
    {
        "school": "REACH H S",
        "district": "CASTLEBERRY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481317007121",
    },
    {
        "school": "T R U C E LEARNING CTR",
        "district": "CASTLEBERRY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481317007446",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "CASTLEBERRY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481317008044",
    },
    {
        "school": "BESS RACE EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591001154",
    },
    {
        "school": "CROWLEY H S",
        "district": "CROWLEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591001155",
    },
    {
        "school": "DEER CREEK EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591001156",
    },
    {
        "school": "H F STEVENS MIDDLE",
        "district": "CROWLEY ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591001157",
    },
    {
        "school": "SYCAMORE EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591001158",
    },
    {
        "school": "CROWLEY MIDDLE",
        "district": "CROWLEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591005440",
    },
    {
        "school": "MEADOWCREEK EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591006234",
    },
    {
        "school": "JACKIE CARDEN EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591006669",
    },
    {
        "school": "PARKWAY EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591007073",
    },
    {
        "school": "OAKMONT EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591007444",
    },
    {
        "school": "NORTH CROWLEY H S",
        "district": "CROWLEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591008040",
    },
    {
        "school": "CROWLEY ALTERNATIVE SCHOOL",
        "district": "CROWLEY ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481591009055",
    },
    {
        "school": "BOSWELL H S",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770001531",
    },
    {
        "school": "EAGLE MOUNTAIN EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770001532",
    },
    {
        "school": "L A GILILLAND EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770001533",
    },
    {
        "school": "SAGINAW EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770001534",
    },
    {
        "school": "WAYSIDE MIDDLE",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770001535",
    },
    {
        "school": "ELMER C WATSON H S",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481770005450",
    },
    {
        "school": "BRYSON EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770006095",
    },
    {
        "school": "ELKINS EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770006538",
    },
    {
        "school": "ALTER DISCIPLINE CAMPUS",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481770007447",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481770007731",
    },
    {
        "school": "HIGHLAND MIDDLE",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770008045",
    },
    {
        "school": "HIGH COUNTRY EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770009059",
    },
    {
        "school": "BISHOP EL",
        "district": "EVERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481881001756",
    },
    {
        "school": "EVERMAN H S",
        "district": "EVERMAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481881001757",
    },
    {
        "school": "CHARLES BAXTER J H",
        "district": "EVERMAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481881001758",
    },
    {
        "school": "HOMMEL EL",
        "district": "EVERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481881001759",
    },
    {
        "school": "E RAY EL",
        "district": "EVERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481881001760",
    },
    {
        "school": "SOUDER EL",
        "district": "EVERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481881001761",
    },
    {
        "school": "ARLINGTON HEIGHTS H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001830",
    },
    {
        "school": "BENBROOK EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001831",
    },
    {
        "school": "BOULEVARD HEIGHTS",
        "district": "FORT WORTH ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970001832",
    },
    {
        "school": "RIVERSIDE APPLIED LRN CTR",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001833",
    },
    {
        "school": "BURTON HILL EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001834",
    },
    {
        "school": "MIDDLE LVL LRN CTR",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970001835",
    },
    {
        "school": "CARTER PARK EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001838",
    },
    {
        "school": "CARTER-RIVERSIDE H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001839",
    },
    {
        "school": "MANUEL JARA EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001841",
    },
    {
        "school": "GEORGE CLARKE EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001842",
    },
    {
        "school": "LILY B CLAYTON EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001843",
    },
    {
        "school": "COMO EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001844",
    },
    {
        "school": "COMO MONTESSORI",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001845",
    },
    {
        "school": "DAGGETT EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001846",
    },
    {
        "school": "DAGGETT MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001847",
    },
    {
        "school": "DE ZAVALA EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001848",
    },
    {
        "school": "RUFINO MENDOZA SR EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001849",
    },
    {
        "school": "DIAMOND HILL EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001850",
    },
    {
        "school": "DIAMOND HILL-JARVIS H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001851",
    },
    {
        "school": "S S DILLOW EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001852",
    },
    {
        "school": "DUNBAR H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001853",
    },
    {
        "school": "J MARTIN JACQUET MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001854",
    },
    {
        "school": "EAST HANDLEY EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001855",
    },
    {
        "school": "EASTERN HILLS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001856",
    },
    {
        "school": "EASTERN HILLS H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001857",
    },
    {
        "school": "CHRISTENE C MOSS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001858",
    },
    {
        "school": "ELDER MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001859",
    },
    {
        "school": "HARLEAN BEAL EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001860",
    },
    {
        "school": "FOREST OAK MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001861",
    },
    {
        "school": "GLEN PARK EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001862",
    },
    {
        "school": "GLENCREST 6TH GRADE SCH",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001863",
    },
    {
        "school": "W M GREEN EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001864",
    },
    {
        "school": "GREENBRIAR EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001865",
    },
    {
        "school": "VAN ZANDT-GUINN EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001866",
    },
    {
        "school": "HANDLEY MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001867",
    },
    {
        "school": "HELBING EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001868",
    },
    {
        "school": "HUBBARD EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001869",
    },
    {
        "school": "JAMES MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001870",
    },
    {
        "school": "KIRKPATRICK EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001872",
    },
    {
        "school": "LEONARD MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001874",
    },
    {
        "school": "MAUDE I LOGAN EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001875",
    },
    {
        "school": "LUELLA MERRETT EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001876",
    },
    {
        "school": "ATWOOD MCDONALD EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001878",
    },
    {
        "school": "MCLEAN MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001879",
    },
    {
        "school": "MEACHAM MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001881",
    },
    {
        "school": "MEADOWBROOK EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001882",
    },
    {
        "school": "MEADOWBROOK MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001883",
    },
    {
        "school": "MITCHELL BOULEVARD EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001884",
    },
    {
        "school": "MONNIG MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001885",
    },
    {
        "school": "MOORE M H EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001887",
    },
    {
        "school": "MORNINGSIDE EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001888",
    },
    {
        "school": "MORNINGSIDE MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001889",
    },
    {
        "school": "CHARLES NASH EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001890",
    },
    {
        "school": "NATHA HOWELL EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001891",
    },
    {
        "school": "NORTH HI MOUNT EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001892",
    },
    {
        "school": "NORTH SIDE H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001893",
    },
    {
        "school": "O D WYATT H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001894",
    },
    {
        "school": "OAKHURST EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001895",
    },
    {
        "school": "OAKLAWN EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001896",
    },
    {
        "school": "PASCHAL H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001897",
    },
    {
        "school": "A M PATE EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001898",
    },
    {
        "school": "CARROLL PEAK EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001899",
    },
    {
        "school": "M L PHILLIPS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001900",
    },
    {
        "school": "POLYTECHNIC H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001901",
    },
    {
        "school": "RIDGLEA HILLS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001902",
    },
    {
        "school": "RIVERSIDE MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001903",
    },
    {
        "school": "ROSEMONT MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001904",
    },
    {
        "school": "SAM ROSEN EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001905",
    },
    {
        "school": "SAGAMORE HILL EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001907",
    },
    {
        "school": "DAVID K SELLARS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001908",
    },
    {
        "school": "BRUCE SHULKEY EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001909",
    },
    {
        "school": "RICHARD J WILSON EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001910",
    },
    {
        "school": "SOUTH HI MOUNT EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001911",
    },
    {
        "school": "SOUTH HILLS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001912",
    },
    {
        "school": "SOUTHWEST H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001913",
    },
    {
        "school": "SPRINGDALE EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001914",
    },
    {
        "school": "J T STEVENS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001915",
    },
    {
        "school": "STRIPLING MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001916",
    },
    {
        "school": "SUNRISE - MCMILLAN EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001917",
    },
    {
        "school": "TANGLEWOOD EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001918",
    },
    {
        "school": "TRIMBLE TECHNICAL H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001920",
    },
    {
        "school": "W J TURNER EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001921",
    },
    {
        "school": "VERSIA WILLIAMS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001922",
    },
    {
        "school": "MAUDRIE WALTON EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001924",
    },
    {
        "school": "WASHINGTON HEIGHTS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001925",
    },
    {
        "school": "WAVERLY PARK EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001926",
    },
    {
        "school": "WEDGWOOD MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001927",
    },
    {
        "school": "WESTCLIFF EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001929",
    },
    {
        "school": "WESTCREEK EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001930",
    },
    {
        "school": "WESTERN HILLS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001931",
    },
    {
        "school": "WESTERN HILLS H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001932",
    },
    {
        "school": "WORTH HEIGHTS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970001934",
    },
    {
        "school": "ALICE CARLSON APPLIED LRN CTR",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970002185",
    },
    {
        "school": "WEDGWOOD 6TH GR SCH",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970005379",
    },
    {
        "school": "APPLIED LEARNING ACAD",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970005388",
    },
    {
        "school": "INT'L NEWCOMER ACAD",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970005395",
    },
    {
        "school": "DETENT CTR",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970005469",
    },
    {
        "school": "METRO OPPORTUNITY",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970005472",
    },
    {
        "school": "JO KELLY SP ED",
        "district": "FORT WORTH ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970005717",
    },
    {
        "school": "WEST HANDLEY EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970005799",
    },
    {
        "school": "WILLOUGHBY HOUSE",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970006257",
    },
    {
        "school": "KIRKPATRICK MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970006547",
    },
    {
        "school": "BILL J ELLIOTT EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970006549",
    },
    {
        "school": "WESTPARK EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970006550",
    },
    {
        "school": "T A SIMS EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970006700",
    },
    {
        "school": "EDWARD BRISCOE EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970006701",
    },
    {
        "school": "SUCCESS H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970007112",
    },
    {
        "school": "ASSESSMENT CTR",
        "district": "FORT WORTH ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970007724",
    },
    {
        "school": "INSIGHTS LEARNING CENTER",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970007725",
    },
    {
        "school": "SOUTH HILLS H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970008026",
    },
    {
        "school": "ROSEMONT 6TH GRADE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970008369",
    },
    {
        "school": "TARRANT YOUTH RECOVERY",
        "district": "FORT WORTH ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970008371",
    },
    {
        "school": "MCLEAN 6TH GRADE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970008912",
    },
    {
        "school": "LOWERY ROAD",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970008913",
    },
    {
        "school": "ALICE D CONTRERAS",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970008914",
    },
    {
        "school": "WESTERN HILLS PRI",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970008915",
    },
    {
        "school": "JUVENILE JUSTICE ALTERNATIVE ED PROGRAM",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970009035",
    },
    {
        "school": "FW RGNL PROGRAM FOR DEAF",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970009036",
    },
    {
        "school": "DAGGETT MONTESSORI",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970009037",
    },
    {
        "school": "DISTRICT WIDE EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970009046",
    },
    {
        "school": "TRANSITION CTR",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970021053",
    },
    {
        "school": "MCRAE EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970021055",
    },
    {
        "school": "CHILDREN'S MEDICAL CTR",
        "district": "FORT WORTH ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970021056",
    },
    {
        "school": "WOMEN'S HAVEN",
        "district": "FORT WORTH ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970021057",
    },
    {
        "school": "BRIDGE ASSOC",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481970021058",
    },
    {
        "school": "WOODWAY EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970021060",
    },
    {
        "school": "COLLEYVILLE EL",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166002180",
    },
    {
        "school": "COLLEYVILLE MIDDLE",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166002181",
    },
    {
        "school": "DOVE EL",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166002182",
    },
    {
        "school": "GRAPEVINE H S",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166002183",
    },
    {
        "school": "BRANSFORD EL",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166005405",
    },
    {
        "school": "TIMBERLINE EL",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166005484",
    },
    {
        "school": "CANNON EL",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166005736",
    },
    {
        "school": "GRAPEVINE MIDDLE",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166005737",
    },
    {
        "school": "TAYLOR EL",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166006266",
    },
    {
        "school": "BEAR CREEK EL",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166006556",
    },
    {
        "school": "HERITAGE MIDDLE",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166006858",
    },
    {
        "school": "GRAPEVINE EL",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166007070",
    },
    {
        "school": "THE BRIDGES ACAD ALTER",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482166007116",
    },
    {
        "school": "SILVER LAKE EL",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166007117",
    },
    {
        "school": "GLENHOPE EL",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166007118",
    },
    {
        "school": "COLLEYVILLE HERITAGE H S",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166007439",
    },
    {
        "school": "CROSS TIMBERS MIDDLE",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166007440",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482166008034",
    },
    {
        "school": "HERITAGE EL",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166021500",
    },
    {
        "school": "BEDFORD HEIGHTS EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002661",
    },
    {
        "school": "BEDFORD J H",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002662",
    },
    {
        "school": "BELL H S",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002663",
    },
    {
        "school": "BELL MANOR EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002664",
    },
    {
        "school": "BELLAIRE EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002665",
    },
    {
        "school": "CENTRAL J H",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002667",
    },
    {
        "school": "DONNA PARK",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002668",
    },
    {
        "school": "EULESS J H",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002669",
    },
    {
        "school": "HARRISON LANE EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002670",
    },
    {
        "school": "HARWOOD J H",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002671",
    },
    {
        "school": "HURST HILLS EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002672",
    },
    {
        "school": "HURST J H",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002673",
    },
    {
        "school": "LAKEWOOD EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002674",
    },
    {
        "school": "MIDWAY PARK EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002675",
    },
    {
        "school": "NORTH EULESS EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002676",
    },
    {
        "school": "OAKWOOD TERRACE EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002677",
    },
    {
        "school": "SHADY OAKS EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002678",
    },
    {
        "school": "SHADY BROOK EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002679",
    },
    {
        "school": "SOUTH EULESS EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002680",
    },
    {
        "school": "STONEGATE EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002681",
    },
    {
        "school": "TRINITY H S",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002682",
    },
    {
        "school": "WEST HURST EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002683",
    },
    {
        "school": "WILSHIRE EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406002684",
    },
    {
        "school": "TRANSITION PROGRAM",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482406005507",
    },
    {
        "school": "SPRING GARDEN EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406005878",
    },
    {
        "school": "KEYS H S",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482406006568",
    },
    {
        "school": "MEADOW CREEK EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406006868",
    },
    {
        "school": "ALTER ED PROG",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482406007730",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482406008043",
    },
    {
        "school": "HOMEBOUND",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482406009058",
    },
    {
        "school": "FLORENCE EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526002820",
    },
    {
        "school": "KELLER-HARVEL EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526002821",
    },
    {
        "school": "KELLER H S",
        "district": "KELLER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526002822",
    },
    {
        "school": "KELLER MIDDLE",
        "district": "KELLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526002823",
    },
    {
        "school": "PARKVIEW EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526005519",
    },
    {
        "school": "BEAR CREEK INT",
        "district": "KELLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526006002",
    },
    {
        "school": "WHITLEY ROAD EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526006003",
    },
    {
        "school": "HERITAGE EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526006432",
    },
    {
        "school": "FOSSIL HILL MIDDLE",
        "district": "KELLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526006571",
    },
    {
        "school": "CHISHOLM TRAIL INT",
        "district": "KELLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526006871",
    },
    {
        "school": "KELLER LEARNING CENTER",
        "district": "KELLER ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482526007071",
    },
    {
        "school": "PARK GLEN EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526007072",
    },
    {
        "school": "FOSSIL RIDGE H S",
        "district": "KELLER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526007119",
    },
    {
        "school": "WILLIS LANE EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526007727",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "KELLER ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482526008035",
    },
    {
        "school": "NORTH RIVERSIDE EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526008036",
    },
    {
        "school": "HILLWOOD MIDDLE",
        "district": "KELLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526008917",
    },
    {
        "school": "HIDDEN LAKES EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526008918",
    },
    {
        "school": "LONE STAR EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526008919",
    },
    {
        "school": "PARKWOOD HILL INT",
        "district": "KELLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526008920",
    },
    {
        "school": "INDIAN SPRINGS MIDDLE",
        "district": "KELLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526009047",
    },
    {
        "school": "SHADY GROVE EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526021502",
    },
    {
        "school": "JAMES A ARTHUR INT",
        "district": "KENNEDALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482550002838",
    },
    {
        "school": "KENNEDALE H S",
        "district": "KENNEDALE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482550002839",
    },
    {
        "school": "KENNEDALE J H",
        "district": "KENNEDALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482550002840",
    },
    {
        "school": "JAMES F DELANEY EL",
        "district": "KENNEDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482550006280",
    },
    {
        "school": "R F PATTERSON EL",
        "district": "KENNEDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482550007445",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "KENNEDALE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482550009056",
    },
    {
        "school": "EFFIE MORRIS EL",
        "district": "LAKE WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482649002977",
    },
    {
        "school": "LAKE WORTH H S",
        "district": "LAKE WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482649002978",
    },
    {
        "school": "TADPOLE LRN CTR",
        "district": "LAKE WORTH ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482649009054",
    },
    {
        "school": "ROGENE WORLEY MIDDLE",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892003267",
    },
    {
        "school": "ALICE PONDER EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892003269",
    },
    {
        "school": "TARVER-RENDON EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892003270",
    },
    {
        "school": "THE PHOENIX ACADEMY",
        "district": "MANSFIELD ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482892005407",
    },
    {
        "school": "T A HOWARD MIDDLE",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892005411",
    },
    {
        "school": "J L BOREN EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892005545",
    },
    {
        "school": "CHARLOTTE ANDERSON EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892006297",
    },
    {
        "school": "GLENN HARMON EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892006582",
    },
    {
        "school": "MARY ORR INT",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892007441",
    },
    {
        "school": "CROSS TIMBERS INT",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892007442",
    },
    {
        "school": "D P MORRIS EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892008037",
    },
    {
        "school": "WILLIE BROWN EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892008038",
    },
    {
        "school": "MANSFIELD SUMMIT H S",
        "district": "MANSFIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892009049",
    },
    {
        "school": "KENNETH DAVIS EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892009050",
    },
    {
        "school": "IMOGENE GIDEON EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892009051",
    },
    {
        "school": "DONNA SHEPARD INT",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892009052",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "MANSFIELD ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482892009053",
    },
    {
        "school": "BREWER H S",
        "district": "WHITE SETTLEMENT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484554005175",
    },
    {
        "school": "BREWER MIDDLE",
        "district": "WHITE SETTLEMENT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484554005176",
    },
    {
        "school": "LIBERTY EL",
        "district": "WHITE SETTLEMENT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484554005177",
    },
    {
        "school": "NORTH EL",
        "district": "WHITE SETTLEMENT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484554005178",
    },
    {
        "school": "WEST EL",
        "district": "WHITE SETTLEMENT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484554005179",
    },
    {
        "school": "BLUE HAZE EL",
        "district": "WHITE SETTLEMENT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484554006628",
    },
    {
        "school": "TARRANT CO J J A E P",
        "district": "WHITE SETTLEMENT ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484554008046",
    },
    {
        "school": "TANNAHILL INT",
        "district": "WHITE SETTLEMENT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484554008047",
    },
    {
        "school": "DEL RIO MIDDLE 8TH GRADE CAMPUS",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890009518",
    },
    {
        "school": "JUVENILE DETENTION CENTER",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483890011069",
    },
    {
        "school": "COMSTOCK SCHOOL",
        "district": "COMSTOCK ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481492000991",
    },
    {
        "school": "DEL RIO H S",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890004435",
    },
    {
        "school": "GARFIELD EL",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890004438",
    },
    {
        "school": "LAMAR EL",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890004439",
    },
    {
        "school": "SAN FELIPE MEMORIAL MIDDLE",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890004440",
    },
    {
        "school": "NORTH HEIGHTS EL",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890004441",
    },
    {
        "school": "IRENE C CARDWELL EL",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890004445",
    },
    {
        "school": "DR FERMIN CALDERON EL",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890005542",
    },
    {
        "school": "BUENA VISTA EL",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890005808",
    },
    {
        "school": "RUBEN CHAVIRA EL",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890006172",
    },
    {
        "school": "DR LONNIE GREEN JR EL",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890008397",
    },
    {
        "school": "CACTUS EL",
        "district": "DUMAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481761001514",
    },
    {
        "school": "DUMAS H S",
        "district": "DUMAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481761001515",
    },
    {
        "school": "DUMAS J H",
        "district": "DUMAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481761001516",
    },
    {
        "school": "GREEN ACRES EL",
        "district": "DUMAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481761001517",
    },
    {
        "school": "HILLCREST EL",
        "district": "DUMAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481761001518",
    },
    {
        "school": "MORNINGSIDE EL",
        "district": "DUMAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481761001519",
    },
    {
        "school": "SUNSET EL",
        "district": "DUMAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481761001520",
    },
    {
        "school": "SUNRAY EL",
        "district": "SUNRAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484191004776",
    },
    {
        "school": "SUNRAY H S",
        "district": "SUNRAY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484191004777",
    },
    {
        "school": "SUNRAY MIDDLE",
        "district": "SUNRAY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484191008885",
    },
    {
        "school": "LIBERTY EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773009338",
    },
    {
        "school": "BENAVIDES HEIGHTS EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773001537",
    },
    {
        "school": "EAGLE PASS H S",
        "district": "EAGLE PASS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773001538",
    },
    {
        "school": "EAGLE PASS J H",
        "district": "EAGLE PASS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773001539",
    },
    {
        "school": "NELLIE MAE GLASS EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773001540",
    },
    {
        "school": "DENA KELSO GRAVES EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773001541",
    },
    {
        "school": "ROBERT E LEE EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773001542",
    },
    {
        "school": "MAUDE MAE KIRCHNER EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773001543",
    },
    {
        "school": "SAN LUIS EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773001544",
    },
    {
        "school": "LANGUAGE DEVELOPMENT CENTER",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773005037",
    },
    {
        "school": "ROSITA VALLEY EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773005038",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773005456",
    },
    {
        "school": "SECO MINES EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773005698",
    },
    {
        "school": "RAY H DARR EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773006096",
    },
    {
        "school": "MEMORIAL J H",
        "district": "EAGLE PASS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773006245",
    },
    {
        "school": "DAEP",
        "district": "EAGLE PASS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481773007032",
    },
    {
        "school": "C C WINN H S",
        "district": "EAGLE PASS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773007986",
    },
    {
        "school": "SAM HOUSTON EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773007987",
    },
    {
        "school": "ROSITA VALLEY LITERACY ACADEMY",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773007988",
    },
    {
        "school": "PETE GALLEGO EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773008329",
    },
    {
        "school": "HENRY B GONZALEZ EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773008330",
    },
    {
        "school": "KENNEDY EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773008868",
    },
    {
        "school": "BOLING H S",
        "district": "BOLING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481078000541",
    },
    {
        "school": "IAGO J H",
        "district": "BOLING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481078000542",
    },
    {
        "school": "NEWGULF EL",
        "district": "BOLING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481078000543",
    },
    {
        "school": "EAST BERNARD EL",
        "district": "EAST BERNARD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481783001552",
    },
    {
        "school": "EAST BERNARD H S",
        "district": "EAST BERNARD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481783001553",
    },
    {
        "school": "EAST BERNARD J H",
        "district": "EAST BERNARD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481783005457",
    },
    {
        "school": "EL CAMPO H S",
        "district": "EL CAMPO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481828001654",
    },
    {
        "school": "EL CAMPO MIDDLE",
        "district": "EL CAMPO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481828001655",
    },
    {
        "school": "HUTCHINS EL",
        "district": "EL CAMPO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481828001656",
    },
    {
        "school": "NORTHSIDE EL",
        "district": "EL CAMPO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481828001657",
    },
    {
        "school": "MYATT EL",
        "district": "EL CAMPO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481828006250",
    },
    {
        "school": "LOUISE H S",
        "district": "LOUISE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482835003167",
    },
    {
        "school": "LOUISE EL",
        "district": "LOUISE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482835021546",
    },
    {
        "school": "C G SIVELLS EL",
        "district": "WHARTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484538005163",
    },
    {
        "school": "WHARTON H S",
        "district": "WHARTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484538005165",
    },
    {
        "school": "OPTIONS H S",
        "district": "SOCORRO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484071011496",
    },
    {
        "school": "EL PASO ACADEMY WEST",
        "district": "EL PASO ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020510632",
    },
    {
        "school": "LA FE PREPARATORY SCHOOL",
        "district": "LA FE PREPARATORY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480028611410",
    },
    {
        "school": "RAYMOND TELLAS ACADEMY - JJAEP",
        "district": "ANTHONY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480843010655",
    },
    {
        "school": "RAYMOND TELLAS ACADEMY - DAEP",
        "district": "ANTHONY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480843010656",
    },
    {
        "school": "GONZALO AND SOFIA GARCIA EL",
        "district": "CANUTILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481278010657",
    },
    {
        "school": "HORIZON H S",
        "district": "CLINT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443009224",
    },
    {
        "school": "CLINT ISD JJAEP",
        "district": "CLINT ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481443010633",
    },
    {
        "school": "HORIZON MIDDLE",
        "district": "CLINT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443010634",
    },
    {
        "school": "CARROLL T WELCH EL",
        "district": "CLINT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443011214",
    },
    {
        "school": "RICARDO ESTRADA MIDDLE",
        "district": "CLINT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443011488",
    },
    {
        "school": "BARRON EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830009230",
    },
    {
        "school": "HS-3 NW H S",
        "district": "EL PASO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010635",
    },
    {
        "school": "HS-5 NE H S",
        "district": "EL PASO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010636",
    },
    {
        "school": "BROWN MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010638",
    },
    {
        "school": "MS-5 NW MIDDLE",
        "district": "EL PASO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010639",
    },
    {
        "school": "TIPPIN EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010640",
    },
    {
        "school": "H R MOYE EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010641",
    },
    {
        "school": "E-10 NW EL",
        "district": "EL PASO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010642",
    },
    {
        "school": "ABOUT FACE PROGRAM EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481830010643",
    },
    {
        "school": "E-2 CENTRAL NE EL DON'T USE",
        "district": "EL PASO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010644",
    },
    {
        "school": "E-11 CENTRAL NW EL",
        "district": "EL PASO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010645",
    },
    {
        "school": "WILLIAM C HERRERA EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010646",
    },
    {
        "school": "COLIN L POWELL EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010647",
    },
    {
        "school": "E-14 MODULAR WESTSIDE EL",
        "district": "EL PASO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010648",
    },
    {
        "school": "MARGUERITE J LUNDY EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010649",
    },
    {
        "school": "TOM LEA JR EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830010650",
    },
    {
        "school": "FABENS JJAEP",
        "district": "FABENS ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481890010651",
    },
    {
        "school": "SAN ELIZARIO JJAEP",
        "district": "SAN ELIZARIO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483885010652",
    },
    {
        "school": "LOMA VERDE",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071009233",
    },
    {
        "school": "BILL SYBERT SCHOOL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071009234",
    },
    {
        "school": "EL DORADO H S",
        "district": "SOCORRO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071009547",
    },
    {
        "school": "DESERT WIND EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071009548",
    },
    {
        "school": "PASO DEL NORTE SCHOOL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071009549",
    },
    {
        "school": "JJAEP",
        "district": "SOCORRO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484071010659",
    },
    {
        "school": "JOHN DRUGAN SCHOOL",
        "district": "SOCORRO ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071010660",
    },
    {
        "school": "HURSHEL ANTWINE SCHOOL",
        "district": "SOCORRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071010661",
    },
    {
        "school": "DR SUE A SHOOK SCHOOL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071010662",
    },
    {
        "school": "SGT ROBERTO ITUARTE",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071010663",
    },
    {
        "school": "EASTLAKE H S",
        "district": "SOCORRO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071011391",
    },
    {
        "school": "CHESTER E JORDAN",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071011477",
    },
    {
        "school": "TORNILLO INT",
        "district": "TORNILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484299009546",
    },
    {
        "school": "TORNILLO DAEP",
        "district": "TORNILLO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484299010658",
    },
    {
        "school": "ADULT/COMMUNITY LRN CTR",
        "district": "YSLETA ISD",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484668009231",
    },
    {
        "school": "CONSTANCE HULBERT EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668009449",
    },
    {
        "school": "NORTH STAR EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668009450",
    },
    {
        "school": "HOWARD BURNHAM EL",
        "district": "BURNHAM WOOD CHARTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003707880",
    },
    {
        "school": "TRIUMPH PUBLIC HIGH SCHOOLS-EL PASO WEST",
        "district": "TRIUMPH PUBLIC HIGH SCHOOLS-EL PASO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480010608207",
    },
    {
        "school": "EL PASO ACADEMY",
        "district": "EL PASO ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020508773",
    },
    {
        "school": "ANTHONY H S",
        "district": "ANTHONY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480843000212",
    },
    {
        "school": "ANTHONY EL",
        "district": "ANTHONY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480843006503",
    },
    {
        "school": "ANTHONY MIDDLE",
        "district": "ANTHONY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480843008550",
    },
    {
        "school": "CANUTILLO H S",
        "district": "CANUTILLO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481278000772",
    },
    {
        "school": "CANUTILLO MIDDLE",
        "district": "CANUTILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481278000773",
    },
    {
        "school": "JOSE H DAMIAN EL",
        "district": "CANUTILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481278000874",
    },
    {
        "school": "CANUTILLO EL",
        "district": "CANUTILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481278006370",
    },
    {
        "school": "DEANNA DAVENPORT EL",
        "district": "CANUTILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481278006833",
    },
    {
        "school": "BILL CHILDRESS EL",
        "district": "CANUTILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481278007274",
    },
    {
        "school": "EAST MONTANA MIDDLE",
        "district": "CLINT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443000755",
    },
    {
        "school": "CLINT H S",
        "district": "CLINT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443000932",
    },
    {
        "school": "WM DAVID SURRATT EL",
        "district": "CLINT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443000933",
    },
    {
        "school": "CLINT J H SCHOOL",
        "district": "CLINT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443005427",
    },
    {
        "school": "RED SANDS EL",
        "district": "CLINT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443006080",
    },
    {
        "school": "DESERT HILLS EL",
        "district": "CLINT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443006525",
    },
    {
        "school": "MOUNTAIN VIEW H S",
        "district": "CLINT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443006667",
    },
    {
        "school": "FRANK MACIAS EL",
        "district": "CLINT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443008775",
    },
    {
        "school": "ANDRESS H S",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001661",
    },
    {
        "school": "AOY EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001662",
    },
    {
        "school": "AUSTIN H S",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001663",
    },
    {
        "school": "BLISS EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001666",
    },
    {
        "school": "BONHAM EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001667",
    },
    {
        "school": "BOWIE H S",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001668",
    },
    {
        "school": "BURGES H S",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001669",
    },
    {
        "school": "CHARLES MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001672",
    },
    {
        "school": "MOREHEAD MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001673",
    },
    {
        "school": "CIELO VISTA EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001674",
    },
    {
        "school": "CLARDY EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001675",
    },
    {
        "school": "COLDWELL EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001676",
    },
    {
        "school": "COOLEY EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001677",
    },
    {
        "school": "CORONADO H S",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001678",
    },
    {
        "school": "CROCKETT EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001679",
    },
    {
        "school": "CROSBY EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001680",
    },
    {
        "school": "DOUGLASS EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001681",
    },
    {
        "school": "DOWELL EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001682",
    },
    {
        "school": "EL PASO H S",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001683",
    },
    {
        "school": "FANNIN EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001685",
    },
    {
        "school": "GUILLEN MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001686",
    },
    {
        "school": "HART EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001687",
    },
    {
        "school": "HAWKINS EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001688",
    },
    {
        "school": "HENDERSON MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001689",
    },
    {
        "school": "HILLSIDE EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001691",
    },
    {
        "school": "HUGHEY EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001693",
    },
    {
        "school": "IRVIN H S",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001694",
    },
    {
        "school": "JEFFERSON H S",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001695",
    },
    {
        "school": "JOHNSON EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001696",
    },
    {
        "school": "LAMAR EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001697",
    },
    {
        "school": "LOGAN EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001700",
    },
    {
        "school": "MACARTHUR EL-INT",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001701",
    },
    {
        "school": "MESITA EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001703",
    },
    {
        "school": "MILAM EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001704",
    },
    {
        "school": "MAGOFFIN MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001705",
    },
    {
        "school": "NEWMAN EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001706",
    },
    {
        "school": "PARK EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001707",
    },
    {
        "school": "PUTNAM EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001708",
    },
    {
        "school": "RIVERA EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001709",
    },
    {
        "school": "ROBERTS EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001710",
    },
    {
        "school": "ROSS MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001712",
    },
    {
        "school": "RUSK EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001713",
    },
    {
        "school": "STANTON EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001715",
    },
    {
        "school": "TRAVIS EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001717",
    },
    {
        "school": "WESTERN HILLS EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001720",
    },
    {
        "school": "ZACH WHITE EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001721",
    },
    {
        "school": "ZAVALA EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830001722",
    },
    {
        "school": "GUERRERO EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830002421",
    },
    {
        "school": "FRANKLIN H S",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830003786",
    },
    {
        "school": "SILVA HEALTH MAGNET",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830003791",
    },
    {
        "school": "DELTA ACADEMY",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481830003812",
    },
    {
        "school": "GREEN EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830003860",
    },
    {
        "school": "COLLEGE CAREER TECHNOLOGY ACADEMY (CCTA)",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481830005464",
    },
    {
        "school": "BASSETT MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830005706",
    },
    {
        "school": "POLK EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830005707",
    },
    {
        "school": "MITZI BOND EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830005708",
    },
    {
        "school": "TERRACE HILLS MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830005711",
    },
    {
        "school": "HORNEDO MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830005741",
    },
    {
        "school": "LINCOLN MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830005869",
    },
    {
        "school": "CANYON HILLS MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830005982",
    },
    {
        "school": "COLLINS EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830005983",
    },
    {
        "school": "CLENDENIN EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830005984",
    },
    {
        "school": "LEE EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830005985",
    },
    {
        "school": "WIGGS MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830006251",
    },
    {
        "school": "WHITAKER EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830006403",
    },
    {
        "school": "BRADLEY EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830006404",
    },
    {
        "school": "TELLES ACADEMY",
        "district": "EL PASO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481830006945",
    },
    {
        "school": "KOHLBERG EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830007591",
    },
    {
        "school": "ARMENDARIZ MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830007881",
    },
    {
        "school": "RICHARDSON MIDDLE",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830007882",
    },
    {
        "school": "MORENO EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830008209",
    },
    {
        "school": "CAREER & TECH ED CTR",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830008545",
    },
    {
        "school": "CHAPIN H S",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830008776",
    },
    {
        "school": "NIXON EL",
        "district": "EL PASO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830021236",
    },
    {
        "school": "FABENS MIDDLE",
        "district": "FABENS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481890001765",
    },
    {
        "school": "JOHANNA ODONNELL INT",
        "district": "FABENS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481890001766",
    },
    {
        "school": "FABENS H S",
        "district": "FABENS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481890001768",
    },
    {
        "school": "L G ALARCON EL",
        "district": "SAN ELIZARIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483885004432",
    },
    {
        "school": "SAN ELIZARIO H S",
        "district": "SAN ELIZARIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483885004433",
    },
    {
        "school": "ANN M GARCIA-ENRIQUEZ MIDDLE",
        "district": "SAN ELIZARIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483885006171",
    },
    {
        "school": "LORENZO LOYA PRI",
        "district": "SAN ELIZARIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483885006907",
    },
    {
        "school": "JOSEFA L SAMBRANO EL",
        "district": "SAN ELIZARIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483885006948",
    },
    {
        "school": "ALFONSO BORREGO SR EL",
        "district": "SAN ELIZARIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483885008547",
    },
    {
        "school": "CAPT WALTER E CLARKE MIDDLE",
        "district": "SOCORRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071003998",
    },
    {
        "school": "SIERRA VISTA EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071004010",
    },
    {
        "school": "SOCORRO H S",
        "district": "SOCORRO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071004619",
    },
    {
        "school": "H D HILLEY EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071005593",
    },
    {
        "school": "CAMPESTRE EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071005812",
    },
    {
        "school": "HORIZON HEIGHTS EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071005922",
    },
    {
        "school": "HUECO EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071005923",
    },
    {
        "school": "VISTA DEL SOL EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071005924",
    },
    {
        "school": "MYRTLE COOPER EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071006326",
    },
    {
        "school": "ROBERT R ROJAS EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071006480",
    },
    {
        "school": "O'SHEA KELEHER EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071006481",
    },
    {
        "school": "ESCONTRIAS EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071006483",
    },
    {
        "school": "MONTWOOD H S",
        "district": "SOCORRO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071006914",
    },
    {
        "school": "AMERICAS H S",
        "district": "SOCORRO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071007276",
    },
    {
        "school": "ESCONTRIAS EARLY CHILD CTR",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071007277",
    },
    {
        "school": "MONTWOOD MIDDLE",
        "district": "SOCORRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071007597",
    },
    {
        "school": "ELFIDA CHAVEZ EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071007598",
    },
    {
        "school": "SUN RIDGE MIDDLE",
        "district": "SOCORRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071008551",
    },
    {
        "school": "KEYS EL",
        "district": "SOCORRO ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484071008552",
    },
    {
        "school": "LUJAN-CHAVEZ EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071008553",
    },
    {
        "school": "COL JOHN O ENSOR MIDDLE",
        "district": "SOCORRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071008777",
    },
    {
        "school": "JANE A HAMBRIC SCHOOL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071008778",
    },
    {
        "school": "ERNESTO SERNA SCHOOL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071008779",
    },
    {
        "school": "SOCORRO MIDDLE",
        "district": "SOCORRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071021025",
    },
    {
        "school": "SALVADOR SANCHEZ MIDDLE",
        "district": "SOCORRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071021026",
    },
    {
        "school": "WILLIAM D SLIDER MIDDLE",
        "district": "SOCORRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071021237",
    },
    {
        "school": "BENITO MARTINEZ EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071021238",
    },
    {
        "school": "TORNILLO EL",
        "district": "TORNILLO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484299000877",
    },
    {
        "school": "TORNILLO H S",
        "district": "TORNILLO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484299004898",
    },
    {
        "school": "TORNILLO JH",
        "district": "TORNILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484299007275",
    },
    {
        "school": "CESAR CHAVEZ ACADEMY",
        "district": "YSLETA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484668003897",
    },
    {
        "school": "ASCARATE EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005306",
    },
    {
        "school": "BEL AIR H S",
        "district": "YSLETA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005307",
    },
    {
        "school": "CAPISTRANO EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005310",
    },
    {
        "school": "CEDAR GROVE EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005311",
    },
    {
        "school": "DEL NORTE HEIGHTS EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005312",
    },
    {
        "school": "DOLPHIN TERRACE EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005313",
    },
    {
        "school": "EAST POINT EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005314",
    },
    {
        "school": "EASTWOOD H S",
        "district": "YSLETA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005315",
    },
    {
        "school": "EASTWOOD HEIGHTS EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005316",
    },
    {
        "school": "EASTWOOD MIDDLE",
        "district": "YSLETA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005317",
    },
    {
        "school": "EASTWOOD KNOLLS",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005318",
    },
    {
        "school": "EDGEMERE EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005319",
    },
    {
        "school": "GLEN COVE EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005320",
    },
    {
        "school": "HACIENDA HEIGHTS EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005321",
    },
    {
        "school": "J M HANKS H S",
        "district": "YSLETA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005323",
    },
    {
        "school": "LE BARRON PARK EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005324",
    },
    {
        "school": "LOMA TERRACE EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005325",
    },
    {
        "school": "MARIAN MANOR EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005326",
    },
    {
        "school": "MESA VISTA EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005327",
    },
    {
        "school": "NORTH LOOP EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005328",
    },
    {
        "school": "PARKLAND EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005329",
    },
    {
        "school": "PARKLAND H S",
        "district": "YSLETA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005330",
    },
    {
        "school": "PARKLAND MIDDLE",
        "district": "YSLETA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005331",
    },
    {
        "school": "PASODALE EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005332",
    },
    {
        "school": "PRESA EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005333",
    },
    {
        "school": "RAMONA EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005334",
    },
    {
        "school": "RIVERSIDE H S",
        "district": "YSLETA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005337",
    },
    {
        "school": "RIVERSIDE MIDDLE",
        "district": "YSLETA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005338",
    },
    {
        "school": "SAGELAND EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005339",
    },
    {
        "school": "SCOTSDALE EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005340",
    },
    {
        "school": "SOUTH LOOP EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005341",
    },
    {
        "school": "VISTA HILLS EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005345",
    },
    {
        "school": "YSLETA EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005346",
    },
    {
        "school": "YSLETA H S",
        "district": "YSLETA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005347",
    },
    {
        "school": "YSLETA MIDDLE",
        "district": "YSLETA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005348",
    },
    {
        "school": "PEBBLE HILLS EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005624",
    },
    {
        "school": "TIERRA DEL SOL EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005625",
    },
    {
        "school": "DESERT VIEW MIDDLE",
        "district": "YSLETA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005827",
    },
    {
        "school": "TEJAS SCHOOL OF CHOICE",
        "district": "YSLETA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484668005938",
    },
    {
        "school": "LANCASTER EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668005939",
    },
    {
        "school": "DEL VALLE H S",
        "district": "YSLETA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668006496",
    },
    {
        "school": "INDIAN RIDGE MIDDLE",
        "district": "YSLETA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668006808",
    },
    {
        "school": "MISSION VALLEY EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668006810",
    },
    {
        "school": "YSLETA PK CENTER",
        "district": "YSLETA ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668006927",
    },
    {
        "school": "ALICIA R CHACON",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484668006994",
    },
    {
        "school": "CESAR CHAVEZ ACADEMY JJAEP",
        "district": "YSLETA ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484668007594",
    },
    {
        "school": "RIO BRAVO MIDDLE",
        "district": "YSLETA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668007596",
    },
    {
        "school": "PLATO ACADEMY",
        "district": "YSLETA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484668008548",
    },
    {
        "school": "ROBBIN E L WASHINGTON EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668008549",
    },
    {
        "school": "DESERTAIRE EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668021024",
    },
    {
        "school": "VALLEY VIEW MIDDLE",
        "district": "VALLEY VIEW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484386009554",
    },
    {
        "school": "CALLISBURG EL",
        "district": "CALLISBURG ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481251000753",
    },
    {
        "school": "CALLISBURG H S",
        "district": "CALLISBURG ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481251000754",
    },
    {
        "school": "ERA SCHOOL",
        "district": "ERA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481860001744",
    },
    {
        "school": "EDISON EL",
        "district": "GAINESVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482022001973",
    },
    {
        "school": "GAINESVILLE H S",
        "district": "GAINESVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482022001975",
    },
    {
        "school": "GAINESVILLE J H",
        "district": "GAINESVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482022001976",
    },
    {
        "school": "ROBERT E LEE INT",
        "district": "GAINESVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482022001977",
    },
    {
        "school": "W E CHALMERS EL",
        "district": "GAINESVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482022008744",
    },
    {
        "school": "LINDSAY EL",
        "district": "LINDSAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482757003099",
    },
    {
        "school": "LINDSAY H S",
        "district": "LINDSAY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482757003100",
    },
    {
        "school": "MUENSTER EL",
        "district": "MUENSTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483186003544",
    },
    {
        "school": "MUENSTER H S",
        "district": "MUENSTER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483186003545",
    },
    {
        "school": "SIVELLS BEND EL",
        "district": "SIVELLS BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484038004574",
    },
    {
        "school": "VALLEY VIEW H S",
        "district": "VALLEY VIEW ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484386004980",
    },
    {
        "school": "VALLEY VIEW EL",
        "district": "VALLEY VIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484386007231",
    },
    {
        "school": "WALNUT BEND EL",
        "district": "WALNUT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484449005079",
    },
    {
        "school": "BRAZOS RIVER CHARTER SCHOOL",
        "district": "BRAZOS RIVER CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480021408907",
    },
    {
        "school": "GLEN ROSE INT",
        "district": "GLEN ROSE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482085001933",
    },
    {
        "school": "GLEN ROSE EL",
        "district": "GLEN ROSE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482085002087",
    },
    {
        "school": "GLEN ROSE H S",
        "district": "GLEN ROSE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482085002088",
    },
    {
        "school": "GLEN ROSE J H SCHOOL",
        "district": "GLEN ROSE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482085005478",
    },
    {
        "school": "LIPAN H S",
        "district": "LIPAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482763003104",
    },
    {
        "school": "LIPAN EL",
        "district": "LIPAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482763007359",
    },
    {
        "school": "ACTON EL",
        "district": "GRANBURY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482139002139",
    },
    {
        "school": "GRANBURY H S",
        "district": "GRANBURY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482139002141",
    },
    {
        "school": "GRANBURY MIDDLE",
        "district": "GRANBURY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482139002142",
    },
    {
        "school": "ACTON MIDDLE",
        "district": "GRANBURY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482139004811",
    },
    {
        "school": "EMMA ROBERSON EL",
        "district": "GRANBURY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482139006112",
    },
    {
        "school": "NETTIE BACCUS EL",
        "district": "GRANBURY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482139006419",
    },
    {
        "school": "OAK WOODS SCHOOL",
        "district": "GRANBURY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482139006856",
    },
    {
        "school": "STARS ACCELERATED H S",
        "district": "GRANBURY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482139007006",
    },
    {
        "school": "MAMBRINO SCHOOL",
        "district": "GRANBURY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482139007659",
    },
    {
        "school": "JOHN AND LYNN BRAWNER INT",
        "district": "GRANBURY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482139008665",
    },
    {
        "school": "TOLAR H S",
        "district": "TOLAR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484290004889",
    },
    {
        "school": "TOLAR EL",
        "district": "TOLAR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484290007047",
    },
    {
        "school": "AIKMAN EL",
        "district": "HEREFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482301002333",
    },
    {
        "school": "BLUEBONNET EL",
        "district": "HEREFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482301002334",
    },
    {
        "school": "HEREFORD H S",
        "district": "HEREFORD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482301002335",
    },
    {
        "school": "HEREFORD J H",
        "district": "HEREFORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482301002336",
    },
    {
        "school": "NORTHWEST EL",
        "district": "HEREFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482301002337",
    },
    {
        "school": "WEST CENTRAL EL",
        "district": "HEREFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482301002341",
    },
    {
        "school": "WALCOTT EL",
        "district": "WALCOTT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484437005066",
    },
    {
        "school": "ALTERNATIVE SCHOOL",
        "district": "BARBERS HILL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480945011547",
    },
    {
        "school": "CLEAR HORIZONS EARLY COLLEGE H S",
        "district": "CLEAR CREEK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428011416",
    },
    {
        "school": "SMITH MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011392",
    },
    {
        "school": "GOOSE CREEK MEMORIAL",
        "district": "GOOSE CREEK CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115011473",
    },
    {
        "school": "VICTORIA WALKER EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115011481",
    },
    {
        "school": "CLARK EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115011562",
    },
    {
        "school": "ROSS STERLING MIDDLE",
        "district": "HUMBLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391011531",
    },
    {
        "school": "NEW J H",
        "district": "PEARLAND ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444011379",
    },
    {
        "school": "BARBARA COCKRELL EL",
        "district": "PEARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444011483",
    },
    {
        "school": "SPICER ALTER ED CTR",
        "district": "BELLVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480981009108",
    },
    {
        "school": "MANVEL H S",
        "district": "ALVIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809010456",
    },
    {
        "school": "ASSETS",
        "district": "ALVIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809010458",
    },
    {
        "school": "MARY BURKS MAREK EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809010459",
    },
    {
        "school": "NOLAN RYAN J H",
        "district": "ALVIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809011504",
    },
    {
        "school": "LAURA INGALLS WILDER",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809011538",
    },
    {
        "school": "FAIRVIEW J H",
        "district": "ALVIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809011558",
    },
    {
        "school": "ANGLETON J H SCHOOL",
        "district": "ANGLETON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480831009139",
    },
    {
        "school": "BARROW EL",
        "district": "COLUMBIA-BRAZORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481467009140",
    },
    {
        "school": "BRAZORIA CO J J A E P",
        "district": "DAMON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481626010460",
    },
    {
        "school": "PACE CENTER",
        "district": "PEARLAND ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483444009141",
    },
    {
        "school": "PEARLAND J H SOUTH",
        "district": "PEARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444009142",
    },
    {
        "school": "SILVERCREST EL",
        "district": "PEARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444009143",
    },
    {
        "school": "ROGERS MIDDLE",
        "district": "PEARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444009494",
    },
    {
        "school": "GLENDA DAWSON H S",
        "district": "PEARLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444011446",
    },
    {
        "school": "ALEXANDER MIDDLE",
        "district": "PEARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444011469",
    },
    {
        "school": "MAGNOLIA EL",
        "district": "PEARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444011561",
    },
    {
        "school": "BROWNSVILLE RAUL YZAGUIRRE STEM SCHOLARS PREP",
        "district": "RAUL YZAGUIRRE SCHOOLS FOR SUCCESS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480002209256",
    },
    {
        "school": "YES PREP - SOUTHWEST",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020910714",
    },
    {
        "school": "THURGOOD MARSHALL H S",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965009241",
    },
    {
        "school": "BARBARA JORDAN EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965009242",
    },
    {
        "school": "WILLIAM B TRAVIS H S",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965010669",
    },
    {
        "school": "BILLY BAINES MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965010671",
    },
    {
        "school": "SCANLAN OAKS EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965010672",
    },
    {
        "school": "MARY AUSTIN HOLLEY EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965010673",
    },
    {
        "school": "DR LYNN ARMSTRONG EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965010674",
    },
    {
        "school": "ODESSA KILPATRICK EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517009614",
    },
    {
        "school": "FORT BEND CO ALTER",
        "district": "KATY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482517010762",
    },
    {
        "school": "GRIFFIN EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517010768",
    },
    {
        "school": "URSULA STEPHENS EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517010769",
    },
    {
        "school": "WOODCREEK EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517010770",
    },
    {
        "school": "IRMA DRU HUTCHISON EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658010666",
    },
    {
        "school": "WILLIAM VELASQUEZ",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658010667",
    },
    {
        "school": "FORT BEND CO ALTER",
        "district": "NEEDVILLE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483231010668",
    },
    {
        "school": "STAFFORD ADJUSTMENT CENTER",
        "district": "STAFFORD MSD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484135009243",
    },
    {
        "school": "FORT BEND CO ALTER",
        "district": "STAFFORD MSD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484135009571",
    },
    {
        "school": "G W ROBINSON",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428010682",
    },
    {
        "school": "AMBASSADORS PREPARATORY ACADEMY",
        "district": "AMBASSADORS PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480028411566",
    },
    {
        "school": "VICTORY LAKES INT",
        "district": "CLEAR CREEK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428009247",
    },
    {
        "school": "ARLYNE & ALAN WEBER EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428009249",
    },
    {
        "school": "CLEAR PATH ALTERNATIVE SCHOOL",
        "district": "CLEAR CREEK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481428009498",
    },
    {
        "school": "WESTBROOK INT",
        "district": "CLEAR CREEK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428010681",
    },
    {
        "school": "DARWIN L GILMORE EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428010683",
    },
    {
        "school": "JOHN AND SHAMARION BARBER MIDDLE",
        "district": "DICKINSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707010678",
    },
    {
        "school": "SAN LEON EL",
        "district": "DICKINSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707011449",
    },
    {
        "school": "WOODROW WILSON DAEP",
        "district": "TEXAS CITY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484251009544",
    },
    {
        "school": "SER-NINOS CHARTER MIDDLE",
        "district": "SER-NINOS CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001811526",
    },
    {
        "school": "TWO DIMENSIONS/VICKERY",
        "district": "TWO DIMENSIONS PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006909652",
    },
    {
        "school": "TWO DIMENSIONS AT CORSICANA",
        "district": "TWO DIMENSIONS PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006909665",
    },
    {
        "school": "THE VARNETT SCHOOL - NORTHEAST",
        "district": "THE VARNETT PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007309645",
    },
    {
        "school": "THE VARNETT SCHOOL - EAST",
        "district": "THE VARNETT PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007309646",
    },
    {
        "school": "CALVIN NELMS MIDDLE",
        "district": "CALVIN NELMS CHARTER SCHOOLS",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480012409258",
    },
    {
        "school": "YOUNG LEARNERS",
        "district": "SOUTHWEST SCHOOL",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480012510713",
    },
    {
        "school": "DISCOVERY MIDDLE",
        "district": "SOUTHWEST SCHOOL",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480012511234",
    },
    {
        "school": "SOUTHWEST SCHOOLS BISSONNET EL CAMPUS",
        "district": "SOUTHWEST SCHOOL",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480012511235",
    },
    {
        "school": "TEXAS SERENITY ACADEMY",
        "district": "TEXAS SERENITY ACADEMY",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480015111306",
    },
    {
        "school": "ACCELERATED INTERDISCIPLINARY ACAD",
        "district": "ACCELERATED INTERMEDIATE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480019210716",
    },
    {
        "school": "YES PREP - NORTH CENTRAL",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020909503",
    },
    {
        "school": "RIPLEY HOUSE CHARTER SCHOOL",
        "district": "PROMISE COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024009263",
    },
    {
        "school": "NCI CHARTER SCHOOL WITHOUT WALLS",
        "district": "PROMISE COMMUNITY SCHOOL",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024010718",
    },
    {
        "school": "HIGHPOINT SCHOOL NORTH",
        "district": "HARRIS COUNTY DEPT OF ED",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480026110703",
    },
    {
        "school": "HIGHPOINT SCHOOL EAST",
        "district": "HARRIS COUNTY DEPT OF ED",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480026110704",
    },
    {
        "school": "ACADEMIC BEHAVIOR SCHOOL EAST",
        "district": "HARRIS COUNTY DEPT OF ED",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480026110705",
    },
    {
        "school": "ACADEMIC BEHAVIOR SCHOOL WEST",
        "district": "HARRIS COUNTY DEPT OF ED",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480026110706",
    },
    {
        "school": "MEYERPARK EL",
        "district": "MEYERPARK ELEMENTARY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026210719",
    },
    {
        "school": "DRAW ACADEMY",
        "district": "DRAW ACADEMY",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480026310720",
    },
    {
        "school": "HARMONY SCIENCE ACAD (WACO)",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029211466",
    },
    {
        "school": "BUSSEY EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771009528",
    },
    {
        "school": "HOUSTON ACADEMY",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771009550",
    },
    {
        "school": "KUJAWA EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771009556",
    },
    {
        "school": "PLUMMER MIDDLE",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771010721",
    },
    {
        "school": "HIGHPOINT",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480771010723",
    },
    {
        "school": "SPENCE EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771010724",
    },
    {
        "school": "BUDEWIG INT",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783009517",
    },
    {
        "school": "HORN EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783011251",
    },
    {
        "school": "HARVEY S BROWN EL",
        "district": "CHANNELVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481359010726",
    },
    {
        "school": "FALCON PASS EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428009248",
    },
    {
        "school": "WILKINSON EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500011506",
    },
    {
        "school": "HIGHPOINT SCHOOL EAST (CROSBY)",
        "district": "CROSBY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481575010727",
    },
    {
        "school": "HC JJAEP - EXCEL ACADEMY",
        "district": "CROSBY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481575011498",
    },
    {
        "school": "CYPRESS RIDGE H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611009266",
    },
    {
        "school": "SAMPSON EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611009267",
    },
    {
        "school": "BIRKES EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611009619",
    },
    {
        "school": "ROBISON EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611009629",
    },
    {
        "school": "TIPPS EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611009630",
    },
    {
        "school": "KAHLA MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611010728",
    },
    {
        "school": "SPILLANE MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611010729",
    },
    {
        "school": "DURYEA EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611010730",
    },
    {
        "school": "KEITH EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611010731",
    },
    {
        "school": "LEE EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611010732",
    },
    {
        "school": "DANISH EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611010733",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "DEER PARK ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653011508",
    },
    {
        "school": "NORMANDY CROSSING EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025009631",
    },
    {
        "school": "DR SHIRLEY J WILLIAMSON EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025010736",
    },
    {
        "school": "HIGH POINT SCHOOL",
        "district": "GOOSE CREEK CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482115010738",
    },
    {
        "school": "EXCEL ACADEMY (MURWORTH)",
        "district": "GOOSE CREEK CISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482115010740",
    },
    {
        "school": "WEST BRIAR MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364009271",
    },
    {
        "school": "ROBINSON EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364009272",
    },
    {
        "school": "CARNEGIE VANGUARD H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364009273",
    },
    {
        "school": "PIN OAK MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364009274",
    },
    {
        "school": "ORTIZ MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364009275",
    },
    {
        "school": "SEGUIN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364009278",
    },
    {
        "school": "KETELSEN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364009279",
    },
    {
        "school": "CHALLENGE EARLY COLLEGE H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364009609",
    },
    {
        "school": "LIBERTY H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482364010741",
    },
    {
        "school": "ENERGIZED FOR EXCELLENCE ACADEMY ECC",
        "district": "HOUSTON ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364010742",
    },
    {
        "school": "FARIAS EARLY CHILDHOOD CENTER",
        "district": "HOUSTON ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364010743",
    },
    {
        "school": "SCHOOL AT ST GEORGE PLACE",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364010744",
    },
    {
        "school": "MISTRAL CENTER FOR EARLY CHILDHOOD",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364010745",
    },
    {
        "school": "KING EARLY CHILDHOOD CTR",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364010746",
    },
    {
        "school": "LAURENZO EARLY CHILDHOOD CTR",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364010747",
    },
    {
        "school": "COOK JR EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364010748",
    },
    {
        "school": "MORENO EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364010749",
    },
    {
        "school": "NEFF EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364010750",
    },
    {
        "school": "HINES-CALDWELL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364010751",
    },
    {
        "school": "RAY DAILY EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364010752",
    },
    {
        "school": "EXCEL ACADEMY",
        "district": "HUFFMAN ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482382010800",
    },
    {
        "school": "EARLY LEARNING WING",
        "district": "HUMBLE ISD",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482391009280",
    },
    {
        "school": "ATASCOCITA H S",
        "district": "HUMBLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391010753",
    },
    {
        "school": "SUMMERWOOD EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391010755",
    },
    {
        "school": "EAGLE SPRINGS EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391010756",
    },
    {
        "school": "PARK LAKES EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391010757",
    },
    {
        "school": "RIVER PINES EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391010758",
    },
    {
        "school": "MORTON RANCH J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517009613",
    },
    {
        "school": "MORTON RANCH H S",
        "district": "KATY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517010759",
    },
    {
        "school": "SEVEN LAKES H S",
        "district": "KATY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517010760",
    },
    {
        "school": "BECKENDORFF J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517010763",
    },
    {
        "school": "ROBERTA WRIGHT RYLANDER EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517010764",
    },
    {
        "school": "JOELLA EXLEY EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517010765",
    },
    {
        "school": "JACK & SHARON RHOADS EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517010766",
    },
    {
        "school": "FRANZ EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517010767",
    },
    {
        "school": "SCHINDEWOLF INT",
        "district": "KLEIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574009281",
    },
    {
        "school": "KOHRVILLE EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574009282",
    },
    {
        "school": "KREINHOP EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574010771",
    },
    {
        "school": "MCDOUGLE EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574010772",
    },
    {
        "school": "METZLER EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574010773",
    },
    {
        "school": "KRIMMEL INTERMED",
        "district": "KLEIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574011417",
    },
    {
        "school": "FRANK EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574011542",
    },
    {
        "school": "HERITAGE EL",
        "district": "LA PORTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482619011426",
    },
    {
        "school": "PASADENA MEMORIAL H S",
        "district": "PASADENA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432009283",
    },
    {
        "school": "DE ZAVALA MIDDLE SCHOOL",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432009284",
    },
    {
        "school": "THE SUMMIT (HIGH SCHOOL)",
        "district": "PASADENA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483432010775",
    },
    {
        "school": "COMMUNITY SCHOOL",
        "district": "PASADENA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483432010776",
    },
    {
        "school": "THE SUMMIT (INTERMEDIATE)",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483432010777",
    },
    {
        "school": "MORRIS MIDDLE",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432010778",
    },
    {
        "school": "LAURA WELCH BUSH EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432010779",
    },
    {
        "school": "SOUTH BELT EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432010780",
    },
    {
        "school": "CARTER LOMAX MIDDLE",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432010781",
    },
    {
        "school": "MELILLO MIDDLE",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432010782",
    },
    {
        "school": "EARNESTEEN MILSTEAD MIDDLE",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432010783",
    },
    {
        "school": "RICK SCHNEIDER MIDDLE",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432010784",
    },
    {
        "school": "BOBBY SHAW MIDDLE",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432010785",
    },
    {
        "school": "STEPHANIE CRAVENS EARLY CHILDHOOD",
        "district": "SHELDON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483999009288",
    },
    {
        "school": "SHELDON JJAEP",
        "district": "SHELDON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483999010795",
    },
    {
        "school": "KASE ACADEMY",
        "district": "SHELDON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483999010797",
    },
    {
        "school": "SHELDON EL",
        "district": "SHELDON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483999010799",
    },
    {
        "school": "HIGH POINT EAST",
        "district": "SHELDON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483999011278",
    },
    {
        "school": "THE WILDCAT WAY SCHOOL",
        "district": "SPRING BRANCH ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110009285",
    },
    {
        "school": "DISCIPLINE ALTERNATIVE EDUCATION PROGRAM",
        "district": "SPRING BRANCH ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484110010793",
    },
    {
        "school": "SCIENCE CTR",
        "district": "SPRING BRANCH ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484110010794",
    },
    {
        "school": "STELLE CLAUGHTON MIDDLE",
        "district": "SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122009575",
    },
    {
        "school": "BAMMEL MIDDLE",
        "district": "SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122009633",
    },
    {
        "school": "SALYERS EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122009662",
    },
    {
        "school": "CLARK INT",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122009663",
    },
    {
        "school": "ANDY DEKANEY H S",
        "district": "SPRING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122010786",
    },
    {
        "school": "RICKEY C BAILEY MIDDLE",
        "district": "SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122010787",
    },
    {
        "school": "CHET BURCHETT EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122010788",
    },
    {
        "school": "MILTON COOPER EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122010789",
    },
    {
        "school": "GINGER MCNABB EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122010790",
    },
    {
        "school": "NORTHGATE EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122010791",
    },
    {
        "school": "DONNA LEWIS EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122010792",
    },
    {
        "school": "TOMBALL J J A E P CAMPUS",
        "district": "TOMBALL ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484296009286",
    },
    {
        "school": "TOMBALL ALTERNATIVE EDUCATION CENTER",
        "district": "TOMBALL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484296009287",
    },
    {
        "school": "WILLOW WOOD J H",
        "district": "TOMBALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296009516",
    },
    {
        "school": "NORTHPOINTE INT",
        "district": "TOMBALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296009522",
    },
    {
        "school": "ROSEHILL EL",
        "district": "TOMBALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296009523",
    },
    {
        "school": "DEVERS JH",
        "district": "DEVERS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481692010885",
    },
    {
        "school": "KIMMIE M BROWN EL",
        "district": "DAYTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481641010884",
    },
    {
        "school": "TOUGH EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500009352",
    },
    {
        "school": "D A E P",
        "district": "CONROE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481500009504",
    },
    {
        "school": "COLLEGE PARK H S",
        "district": "CONROE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500010964",
    },
    {
        "school": "CRYAR INTERMEDIATE",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500010965",
    },
    {
        "school": "DERETCHIN EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500010966",
    },
    {
        "school": "REAVES EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500010967",
    },
    {
        "school": "BROADWAY EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500011489",
    },
    {
        "school": "PROJECT RESTORE",
        "district": "MAGNOLIA ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482874009354",
    },
    {
        "school": "NICHOLS SAWMILL EL",
        "district": "MAGNOLIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874009357",
    },
    {
        "school": "TOM R ELLISOR EL",
        "district": "MAGNOLIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874010969",
    },
    {
        "school": "STEWART CREEK EL",
        "district": "MONTGOMERY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483126009353",
    },
    {
        "school": "PROJECT RESTORE",
        "district": "NEW CANEY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483240009358",
    },
    {
        "school": "VALLEY RANCH EL",
        "district": "NEW CANEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240010972",
    },
    {
        "school": "SORTERS MILL EL",
        "district": "NEW CANEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240011455",
    },
    {
        "school": "ROBERT P BRABHAM MIDDLE",
        "district": "WILLIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484590010968",
    },
    {
        "school": "ROYAL EL",
        "district": "ROYAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483819009418",
    },
    {
        "school": "ROYAL EARLY CHILDHOOD CENTER",
        "district": "ROYAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483819009587",
    },
    {
        "school": "FIELDS STORE EL",
        "district": "WALLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484443009417",
    },
    {
        "school": "BELLVILLE H S",
        "district": "BELLVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480981000449",
    },
    {
        "school": "BELLVILLE J H",
        "district": "BELLVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480981000450",
    },
    {
        "school": "O'BRYANT PRI",
        "district": "BELLVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480981000451",
    },
    {
        "school": "WEST END EL",
        "district": "BELLVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480981000453",
    },
    {
        "school": "O'BRYANT INT",
        "district": "BELLVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480981005847",
    },
    {
        "school": "SELMAN EL",
        "district": "SEALY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483963004501",
    },
    {
        "school": "SEALY H S",
        "district": "SEALY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483963004502",
    },
    {
        "school": "SEALY J H",
        "district": "SEALY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483963004503",
    },
    {
        "school": "COLDSPRING-OAKHURST H S",
        "district": "COLDSPRING-OAKHURST CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481452000940",
    },
    {
        "school": "LINCOLN J H",
        "district": "COLDSPRING-OAKHURST CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481452000941",
    },
    {
        "school": "STREET EL",
        "district": "COLDSPRING-OAKHURST CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481452000942",
    },
    {
        "school": "COLDSPRING INT",
        "district": "COLDSPRING-OAKHURST CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481452006233",
    },
    {
        "school": "SHEPHERD PRI",
        "district": "SHEPHERD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484002004540",
    },
    {
        "school": "SHEPHERD H S",
        "district": "SHEPHERD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484002004541",
    },
    {
        "school": "SHEPHERD MIDDLE",
        "district": "SHEPHERD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484002004542",
    },
    {
        "school": "SHEPHERD INT",
        "district": "SHEPHERD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484002008013",
    },
    {
        "school": "ALVIN EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809000131",
    },
    {
        "school": "ALVIN H S",
        "district": "ALVIN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809000132",
    },
    {
        "school": "ALVIN J H",
        "district": "ALVIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809000133",
    },
    {
        "school": "ALVIN PRI",
        "district": "ALVIN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809000134",
    },
    {
        "school": "BILL HASSE EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809000135",
    },
    {
        "school": "E C MASON EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809000136",
    },
    {
        "school": "RODEO PALMS J H",
        "district": "ALVIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809000137",
    },
    {
        "school": "MARK TWAIN EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809000138",
    },
    {
        "school": "R L STEVENSON PRI",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809000139",
    },
    {
        "school": "MELBA PASSMORE EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809003080",
    },
    {
        "school": "G W HARBY J H",
        "district": "ALVIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809005386",
    },
    {
        "school": "WALT DISNEY EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809005387",
    },
    {
        "school": "HOOD-CASE EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809007527",
    },
    {
        "school": "DON JETER EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809008452",
    },
    {
        "school": "BRAZORIA CO J J A E P",
        "district": "ALVIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480809008709",
    },
    {
        "school": "ANGLETON H S",
        "district": "ANGLETON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480831000200",
    },
    {
        "school": "NORTHSIDE EL",
        "district": "ANGLETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480831000203",
    },
    {
        "school": "SOUTHSIDE EL",
        "district": "ANGLETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480831000204",
    },
    {
        "school": "WESTSIDE EL",
        "district": "ANGLETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480831000205",
    },
    {
        "school": "RANCHO ISABELLA EL",
        "district": "ANGLETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480831005945",
    },
    {
        "school": "STUDENT ALTERNATIVE CTR",
        "district": "ANGLETON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480831006642",
    },
    {
        "school": "BRAZORIA CO JUVENILE DETENTION",
        "district": "ANGLETON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480831007814",
    },
    {
        "school": "FRONTIER EL",
        "district": "ANGLETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480831021127",
    },
    {
        "school": "S F AUSTIN EL",
        "district": "BRAZOSPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000579",
    },
    {
        "school": "A P BEUTEL EL",
        "district": "BRAZOSPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000580",
    },
    {
        "school": "BESS BRANNEN EL",
        "district": "BRAZOSPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000581",
    },
    {
        "school": "BRAZOSPORT H S",
        "district": "BRAZOSPORT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000582",
    },
    {
        "school": "BRAZOSWOOD H S",
        "district": "BRAZOSPORT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000584",
    },
    {
        "school": "CLUTE INT",
        "district": "BRAZOSPORT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000586",
    },
    {
        "school": "FREEPORT EL",
        "district": "BRAZOSPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000587",
    },
    {
        "school": "FREEPORT INT",
        "district": "BRAZOSPORT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000588",
    },
    {
        "school": "LAKE JACKSON INT",
        "district": "BRAZOSPORT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000589",
    },
    {
        "school": "ELISABET NEY EL",
        "district": "BRAZOSPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000591",
    },
    {
        "school": "T W OGG EL",
        "district": "BRAZOSPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000592",
    },
    {
        "school": "O M ROBERTS EL",
        "district": "BRAZOSPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000593",
    },
    {
        "school": "VELASCO EL",
        "district": "BRAZOSPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119000594",
    },
    {
        "school": "GLADYS POLK EL",
        "district": "BRAZOSPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119005413",
    },
    {
        "school": "GRIFFITH EL",
        "district": "BRAZOSPORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119006826",
    },
    {
        "school": "O'HARA LANIER MIDDLE",
        "district": "BRAZOSPORT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119006929",
    },
    {
        "school": "LIGHTHOUSE LEARNING CENTER - DAEP",
        "district": "BRAZOSPORT ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481119007528",
    },
    {
        "school": "LIGHTHOUSE LEARNING CENTER - JJAEP",
        "district": "BRAZOSPORT ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481119008710",
    },
    {
        "school": "BRAZOS SUCCESS ACADEMY",
        "district": "BRAZOSPORT ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481119008711",
    },
    {
        "school": "COLUMBIA H S",
        "district": "COLUMBIA-BRAZORIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481467000958",
    },
    {
        "school": "WEST COLUMBIA EL",
        "district": "COLUMBIA-BRAZORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481467000960",
    },
    {
        "school": "WEST BRAZOS J H",
        "district": "COLUMBIA-BRAZORIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481467000961",
    },
    {
        "school": "WILD PEACH EL",
        "district": "COLUMBIA-BRAZORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481467005428",
    },
    {
        "school": "BRAZORIA CO J J A E P",
        "district": "COLUMBIA-BRAZORIA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481467007530",
    },
    {
        "school": "DAMON EL",
        "district": "DAMON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481626001391",
    },
    {
        "school": "DANBURY EL",
        "district": "DANBURY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481629001392",
    },
    {
        "school": "DANBURY H S",
        "district": "DANBURY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481629001393",
    },
    {
        "school": "DANBURY MIDDLE",
        "district": "DANBURY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481629005691",
    },
    {
        "school": "BRAZORIA CO J J A E P",
        "district": "DANBURY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481629008454",
    },
    {
        "school": "PEARLAND J H WEST",
        "district": "PEARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444003096",
    },
    {
        "school": "CHALLENGER EL",
        "district": "PEARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444003114",
    },
    {
        "school": "RUSTIC OAK EL",
        "district": "PEARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444003116",
    },
    {
        "school": "E A LAWHON EL",
        "district": "PEARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444003861",
    },
    {
        "school": "C J HARRIS EL",
        "district": "PEARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444003862",
    },
    {
        "school": "PEARLAND H S",
        "district": "PEARLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444003863",
    },
    {
        "school": "PEARLAND J H EAST",
        "district": "PEARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444003864",
    },
    {
        "school": "SHADYCREST EL",
        "district": "PEARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444003865",
    },
    {
        "school": "H C CARLESTON EL",
        "district": "PEARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444005570",
    },
    {
        "school": "SAM JAMISON MIDDLE",
        "district": "PEARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444005791",
    },
    {
        "school": "BRAZORIA CO J J A E P",
        "district": "PEARLAND ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483444007531",
    },
    {
        "school": "LEON H SABLATURA MIDDLE",
        "district": "PEARLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444007532",
    },
    {
        "school": "SILVERLAKE EL",
        "district": "PEARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444007815",
    },
    {
        "school": "SWEENY H S",
        "district": "SWEENY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484197004778",
    },
    {
        "school": "SWEENY J H",
        "district": "SWEENY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484197004780",
    },
    {
        "school": "SWEENY EL",
        "district": "SWEENY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484197005928",
    },
    {
        "school": "BRAZORIA CO J J A E P",
        "district": "SWEENY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484197008455",
    },
    {
        "school": "ODYSSEY ACADEMY - GALVESTON",
        "district": "ODYSSEY ACADEMY INC",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480010808213",
    },
    {
        "school": "CLEAR CREEK H S",
        "district": "CLEAR CREEK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000903",
    },
    {
        "school": "LEAGUE CITY EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000907",
    },
    {
        "school": "JAMES H ROSS EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000910",
    },
    {
        "school": "LAVACE STEWART EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000912",
    },
    {
        "school": "CREEKSIDE INT",
        "district": "CLEAR CREEK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428001103",
    },
    {
        "school": "WALTER HALL EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428005425",
    },
    {
        "school": "LEAGUE CITY INT",
        "district": "CLEAR CREEK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428005674",
    },
    {
        "school": "CLEAR VIEW H S",
        "district": "CLEAR CREEK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481428006666",
    },
    {
        "school": "BROOKSIDE INT",
        "district": "CLEAR CREEK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428007004",
    },
    {
        "school": "I W AND ELEANOR HYDE EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428007005",
    },
    {
        "school": "ART AND PAT GOFORTH EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428008573",
    },
    {
        "school": "HENRY BAUERSCHLAG EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428008574",
    },
    {
        "school": "GALVESTON CO JJAEP",
        "district": "CLEAR CREEK ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481428008790",
    },
    {
        "school": "HARRIS CO JJAEP",
        "district": "CLEAR CREEK ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481428008791",
    },
    {
        "school": "LLOYD R FERGUSON EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428021028",
    },
    {
        "school": "DICKINSON H S",
        "district": "DICKINSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707001477",
    },
    {
        "school": "DUNBAR MIDDLE",
        "district": "DICKINSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707001479",
    },
    {
        "school": "KENNETH E LITTLE EL",
        "district": "DICKINSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707001480",
    },
    {
        "school": "R D MCADAMS J H",
        "district": "DICKINSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707001481",
    },
    {
        "school": "JAKE SILBERNAGEL EL",
        "district": "DICKINSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707005455",
    },
    {
        "school": "HUGHES ROAD EL",
        "district": "DICKINSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707006093",
    },
    {
        "school": "TRANSFORMING LIVES COOPERATIVE (TLC)",
        "district": "DICKINSON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481707007289",
    },
    {
        "school": "GALVESTON CO DETENTION CTR",
        "district": "DICKINSON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481707007290",
    },
    {
        "school": "GALVESTON CO J J A E P",
        "district": "DICKINSON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481707007889",
    },
    {
        "school": "BAY COLONY EL",
        "district": "DICKINSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707008569",
    },
    {
        "school": "FRIENDSWOOD H S",
        "district": "FRIENDSWOOD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481995001948",
    },
    {
        "school": "FRIENDSWOOD J H",
        "district": "FRIENDSWOOD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481995001949",
    },
    {
        "school": "C W CLINE EL",
        "district": "FRIENDSWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481995001950",
    },
    {
        "school": "WESTWOOD EL",
        "district": "FRIENDSWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481995001951",
    },
    {
        "school": "ZUE S BALES INT",
        "district": "FRIENDSWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481995006958",
    },
    {
        "school": "GALVESTON CO J J A E P",
        "district": "FRIENDSWOOD ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481995007613",
    },
    {
        "school": "WINDSONG INT",
        "district": "FRIENDSWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481995008216",
    },
    {
        "school": "BALL H S",
        "district": "GALVESTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482028001996",
    },
    {
        "school": "CRENSHAW EL AND MIDDLE",
        "district": "GALVESTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482028001997",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "GALVESTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482028001999",
    },
    {
        "school": "MORGAN EL MAGNET SCHOOL",
        "district": "GALVESTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482028002001",
    },
    {
        "school": "PARKER EL",
        "district": "GALVESTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482028002002",
    },
    {
        "school": "OPPE EL",
        "district": "GALVESTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482028006412",
    },
    {
        "school": "AUSTIN MIDDLE",
        "district": "GALVESTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482028007001",
    },
    {
        "school": "GALVESTON CO J J A E P",
        "district": "GALVESTON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482028007890",
    },
    {
        "school": "HIGH ISLAND SCHOOL",
        "district": "HIGH ISLAND ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482316002351",
    },
    {
        "school": "CROSBY MIDDLE",
        "district": "HITCHCOCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482331002366",
    },
    {
        "school": "HITCHCOCK H S",
        "district": "HITCHCOCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482331002367",
    },
    {
        "school": "STEWART EL",
        "district": "HITCHCOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482331002369",
    },
    {
        "school": "GALVESTON CO J J A E P",
        "district": "HITCHCOCK ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482331007893",
    },
    {
        "school": "HITCHCOCK HEADSTART",
        "district": "HITCHCOCK ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482331008572",
    },
    {
        "school": "SANTA FE H S",
        "district": "SANTA FE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483927004473",
    },
    {
        "school": "SANTA FE J H",
        "district": "SANTA FE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483927004475",
    },
    {
        "school": "ROY J WOLLAM EL",
        "district": "SANTA FE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483927006323",
    },
    {
        "school": "GALVESTON CO J J A E P",
        "district": "SANTA FE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483927007612",
    },
    {
        "school": "DAN J KUBACAK EL",
        "district": "SANTA FE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483927008789",
    },
    {
        "school": "BLOCKER MIDDLE",
        "district": "TEXAS CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251004858",
    },
    {
        "school": "HEIGHTS EL",
        "district": "TEXAS CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251004861",
    },
    {
        "school": "KOHFELDT EL",
        "district": "TEXAS CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251004862",
    },
    {
        "school": "MANUAL GUAJARDO JR EL",
        "district": "TEXAS CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251004863",
    },
    {
        "school": "ROOSEVELT-WILSON EL",
        "district": "TEXAS CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251004864",
    },
    {
        "school": "TEXAS CITY H S",
        "district": "TEXAS CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251004865",
    },
    {
        "school": "FRY INT",
        "district": "TEXAS CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251006177",
    },
    {
        "school": "TEXAS CITY J J A E P",
        "district": "TEXAS CITY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484251007611",
    },
    {
        "school": "ARMAND BAYOU EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000901",
    },
    {
        "school": "BAY EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000902",
    },
    {
        "school": "CLEAR LAKE CITY EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000904",
    },
    {
        "school": "CLEAR LAKE INT",
        "district": "CLEAR CREEK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000905",
    },
    {
        "school": "CLEAR LAKE H S",
        "district": "CLEAR CREEK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000906",
    },
    {
        "school": "MARGARET S MCWHIRTER EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000908",
    },
    {
        "school": "P H GREENE EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000909",
    },
    {
        "school": "SEABROOK INT",
        "district": "CLEAR CREEK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000911",
    },
    {
        "school": "G H WHITCOMB EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000914",
    },
    {
        "school": "ED H WHITE EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428000915",
    },
    {
        "school": "SPACE CENTER INT",
        "district": "CLEAR CREEK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428001083",
    },
    {
        "school": "BROOKWOOD EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428001107",
    },
    {
        "school": "WEDGEWOOD EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428004066",
    },
    {
        "school": "C D LANDOLT EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428005424",
    },
    {
        "school": "CLEAR BROOK H S",
        "district": "CLEAR CREEK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428006523",
    },
    {
        "school": "JOHN F WARD EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428006835",
    },
    {
        "school": "BRAZOS H S",
        "district": "BRAZOS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484447005075",
    },
    {
        "school": "BRAZOS MIDDLE",
        "district": "BRAZOS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484447005076",
    },
    {
        "school": "ANAHUAC EL",
        "district": "ANAHUAC ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480819000189",
    },
    {
        "school": "ANAHUAC H S",
        "district": "ANAHUAC ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480819000190",
    },
    {
        "school": "ANAHUAC MIDDLE",
        "district": "ANAHUAC ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480819000191",
    },
    {
        "school": "BARBERS HILL H S",
        "district": "BARBERS HILL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480945000403",
    },
    {
        "school": "EAST CHAMBERS EL",
        "district": "EAST CHAMBERS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481788001560",
    },
    {
        "school": "EAST CHAMBERS H S",
        "district": "EAST CHAMBERS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481788001561",
    },
    {
        "school": "EAST CHAMBERS J H",
        "district": "EAST CHAMBERS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481788001562",
    },
    {
        "school": "LAWRENCE E ELKINS H S",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965000894",
    },
    {
        "school": "WALKER STATION EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965000985",
    },
    {
        "school": "BLUE RIDGE EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001815",
    },
    {
        "school": "BRIARGATE EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001816",
    },
    {
        "school": "DULLES EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001817",
    },
    {
        "school": "DULLES H S",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001818",
    },
    {
        "school": "E A JONES EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001819",
    },
    {
        "school": "LAKEVIEW EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001820",
    },
    {
        "school": "LANTERN LANE EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001821",
    },
    {
        "school": "MEADOWS EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001822",
    },
    {
        "school": "MISSOURI CITY MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001823",
    },
    {
        "school": "QUAIL VALLEY EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001824",
    },
    {
        "school": "RIDGEMONT EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001826",
    },
    {
        "school": "SUGAR LAND MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001827",
    },
    {
        "school": "TOWNEWEST EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965001828",
    },
    {
        "school": "RIDGEGATE EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965005467",
    },
    {
        "school": "WILLOWRIDGE H S",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965005468",
    },
    {
        "school": "COLONY BEND EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965005714",
    },
    {
        "school": "MISSION BEND EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965005715",
    },
    {
        "school": "CLEMENTS H S",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965005870",
    },
    {
        "school": "DULLES MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965005871",
    },
    {
        "school": "SUGAR MILL EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965005987",
    },
    {
        "school": "SETTLERS WAY EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965005988",
    },
    {
        "school": "FIRST COLONY MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965006105",
    },
    {
        "school": "PALMER EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965006106",
    },
    {
        "school": "HUNTERS GLEN EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965006107",
    },
    {
        "school": "HIGHLANDS EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965006255",
    },
    {
        "school": "MISSION GLEN EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965006256",
    },
    {
        "school": "KEMPNER H S",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965006540",
    },
    {
        "school": "PECAN GROVE EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965006541",
    },
    {
        "school": "AUSTIN PARKWAY EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965006699",
    },
    {
        "school": "BARRINGTON PLACE EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965006853",
    },
    {
        "school": "LEXINGTON CREEK EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965006955",
    },
    {
        "school": "STEPHEN F AUSTIN H S",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965007000",
    },
    {
        "school": "QUAIL VALLEY MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965007281",
    },
    {
        "school": "CHRISTA MCAULIFFE MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965007282",
    },
    {
        "school": "HODGES BEND MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965007283",
    },
    {
        "school": "LAKE OLYMPIA MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965007284",
    },
    {
        "school": "MACARIO GARCIA MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965007285",
    },
    {
        "school": "WALTER MOSES BURTON EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965007286",
    },
    {
        "school": "FORT BEND CO ALTER",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481965007605",
    },
    {
        "school": "COMMONWEALTH EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965007606",
    },
    {
        "school": "BRAZOS BEND EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965007607",
    },
    {
        "school": "HIGHTOWER H S",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965007885",
    },
    {
        "school": "SIENNA CROSSING EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965007886",
    },
    {
        "school": "OYSTER CREEK EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965008212",
    },
    {
        "school": "GEORGE BUSH H S",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965008562",
    },
    {
        "school": "SARTARTIA MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965008564",
    },
    {
        "school": "FORT SETTLEMENT MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965008565",
    },
    {
        "school": "RITA DRABEK EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965008566",
    },
    {
        "school": "LULA BELLE GOODMAN EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965008786",
    },
    {
        "school": "COLONY MEADOWS EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965021246",
    },
    {
        "school": "MISSION WEST EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965021247",
    },
    {
        "school": "KATY H S",
        "district": "KATY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517002809",
    },
    {
        "school": "EDNA MAE FIELDER EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517004621",
    },
    {
        "school": "RODGER & ELLEN BECK J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517007335",
    },
    {
        "school": "CINCO RANCH H S",
        "district": "KATY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517008271",
    },
    {
        "school": "CINCO RANCH J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517008626",
    },
    {
        "school": "HARRIS CO SCH FOR ACCELERATED LRN",
        "district": "KATY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482517008823",
    },
    {
        "school": "JAMES E WILLIAMS EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517008825",
    },
    {
        "school": "SUE CREECH EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517008826",
    },
    {
        "school": "BEASLEY EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658002983",
    },
    {
        "school": "BOWIE EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658002984",
    },
    {
        "school": "JANE LONG EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658002987",
    },
    {
        "school": "LAMAR CONS H S",
        "district": "LAMAR CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658002988",
    },
    {
        "school": "LAMAR J H",
        "district": "LAMAR CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658002989",
    },
    {
        "school": "SMITH EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658002991",
    },
    {
        "school": "TRAVIS EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658002992",
    },
    {
        "school": "SUSANNA DICKINSON EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658004034",
    },
    {
        "school": "GEORGE J H",
        "district": "LAMAR CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658005531",
    },
    {
        "school": "HUGGINS EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658005532",
    },
    {
        "school": "TAYLOR RAY EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658005533",
    },
    {
        "school": "B F TERRY H S",
        "district": "LAMAR CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658005534",
    },
    {
        "school": "MANFORD WILLIAMS EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658006132",
    },
    {
        "school": "MEYER EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658006133",
    },
    {
        "school": "ALTERNATIVE LEARNING CENTER",
        "district": "LAMAR CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482658006739",
    },
    {
        "school": "STEPHEN F AUSTIN EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658006878",
    },
    {
        "school": "FORT BEND CO ALTER",
        "district": "LAMAR CISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482658006999",
    },
    {
        "school": "T L PINK EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658007601",
    },
    {
        "school": "JUAN SEGUIN EARLY CHILDHOOD CENTER",
        "district": "LAMAR CISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658007602",
    },
    {
        "school": "JACKSON EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658007603",
    },
    {
        "school": "FOSTER H S",
        "district": "LAMAR CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658008559",
    },
    {
        "school": "BRISCOE J H",
        "district": "LAMAR CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658008561",
    },
    {
        "school": "BESS CAMPBELL EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658008782",
    },
    {
        "school": "FROST EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658008783",
    },
    {
        "school": "JUVENILE DETENT CTR",
        "district": "LAMAR CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482658021244",
    },
    {
        "school": "NEEDVILLE EL",
        "district": "NEEDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483231003583",
    },
    {
        "school": "NEEDVILLE H S",
        "district": "NEEDVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483231003584",
    },
    {
        "school": "NEEDVILLE MIDDLE",
        "district": "NEEDVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483231005780",
    },
    {
        "school": "NEEDVILLE J H",
        "district": "NEEDVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483231008784",
    },
    {
        "school": "C E KING MIDDLE",
        "district": "SHELDON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483999004535",
    },
    {
        "school": "STAFFORD EL",
        "district": "STAFFORD MSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484135001039",
    },
    {
        "school": "STAFFORD PRI",
        "district": "STAFFORD MSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484135005716",
    },
    {
        "school": "STAFFORD H S",
        "district": "STAFFORD MSD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484135005925",
    },
    {
        "school": "STAFFORD MIDDLE",
        "district": "STAFFORD MSD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484135005926",
    },
    {
        "school": "STAFFORD INT",
        "district": "STAFFORD MSD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484135008787",
    },
    {
        "school": "BRAZOS EL",
        "district": "BRAZOS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484447005077",
    },
    {
        "school": "SER-NINOS CHARTER EL",
        "district": "SER-NINOS CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001807302",
    },
    {
        "school": "ARISTOI CLASSICAL ACADEMY",
        "district": "ARISTOI CLASSICAL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001907303",
    },
    {
        "school": "GEORGE I SANCHEZ CHARTER",
        "district": "GEORGE I SANCHEZ CHARTER",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480002007304",
    },
    {
        "school": "HOUSTON T-STEM AND EARLY COLLEGE H S",
        "district": "RAUL YZAGUIRRE SCHOOLS FOR SUCCESS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480002207905",
    },
    {
        "school": "UNIV OF HOUSTON CHARTER SCH-TECH",
        "district": "UNIVERSITY OF HOUSTON CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003107619",
    },
    {
        "school": "ACADEMY OF ACCELERATED LEARNING",
        "district": "ACADEMY OF ACCELERATED LEARNING INC",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480003208585",
    },
    {
        "school": "ALIEF MONTESSORI COMMUNITY SCHOOL",
        "district": "ALIEF MONTESSORI COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003507914",
    },
    {
        "school": "HARRIS COUNTY JUVENILE DETENTION CENTER",
        "district": "EXCEL ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480004907909",
    },
    {
        "school": "HARRIS COUNTY YOUTH VILLAGE",
        "district": "EXCEL ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480004908231",
    },
    {
        "school": "LEADERSHIP ACADEMY",
        "district": "EXCEL ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480004908233",
    },
    {
        "school": "TWO DIMENSIONS PREPARATORY ACADEMY",
        "district": "TWO DIMENSIONS PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006907916",
    },
    {
        "school": "VARNETT CHARTER SCHOOL",
        "district": "THE VARNETT PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007307913",
    },
    {
        "school": "AMIGOS POR VIDA-FRIENDS FOR LIFE CHARTER SCHOOL",
        "district": "AMIGOS POR VIDA-FRIENDS FOR LIFE PUB CHTR SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480011308237",
    },
    {
        "school": "HOUSTON HEIGHTS CHARTER SCHOOL",
        "district": "HOUSTON HEIGHTS HIGH SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480011508239",
    },
    {
        "school": "HOUSTON GATEWAY ACADEMY",
        "district": "HOUSTON GATEWAY ACADEMY INC",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480011808242",
    },
    {
        "school": "CALVIN NELMS H S",
        "district": "CALVIN NELMS CHARTER SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480012408248",
    },
    {
        "school": "EMPOWERMENT H S",
        "district": "SOUTHWEST SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480012508249",
    },
    {
        "school": "PHOENIX SCHOOL AT SOUTHWEST SCHOOLS",
        "district": "SOUTHWEST SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480012508252",
    },
    {
        "school": "COMQUEST ACADEMY",
        "district": "COMQUEST ACADEMY",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480012708255",
    },
    {
        "school": "BEATRICE MAYES INSTITUTE CHARTER SCHOOL",
        "district": "BEATRICE MAYES INSTITUTE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480019008590",
    },
    {
        "school": "ACCELERATED INT CHARTER SCHOOL",
        "district": "ACCELERATED INTERMEDIATE ACADEMY",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480019208593",
    },
    {
        "school": "YES PREP - SOUTHEAST",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020908803",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY-HOUSTON",
        "district": "HARMONY SCIENCE ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021008804",
    },
    {
        "school": "CARVER H S FOR APPLIED TECH/ENGINEERING/ARTS",
        "district": "ALDINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000056",
    },
    {
        "school": "ALDINE H S",
        "district": "ALDINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000057",
    },
    {
        "school": "ALDINE MIDDLE",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000058",
    },
    {
        "school": "ANDERSON ACADEMY",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000059",
    },
    {
        "school": "CARMICHAEL EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000061",
    },
    {
        "school": "CARROLL EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000062",
    },
    {
        "school": "NIMITZ H S",
        "district": "ALDINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000063",
    },
    {
        "school": "ODOM EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000064",
    },
    {
        "school": "EISENHOWER H S",
        "district": "ALDINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000066",
    },
    {
        "school": "ERMEL EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000067",
    },
    {
        "school": "THOMPSON EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000068",
    },
    {
        "school": "FRANCIS EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000069",
    },
    {
        "school": "HAMBRICK MIDDLE",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000070",
    },
    {
        "school": "GOODMAN EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000071",
    },
    {
        "school": "HOFFMAN MIDDLE",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000072",
    },
    {
        "school": "SMITH EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000073",
    },
    {
        "school": "JOHNSON EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000074",
    },
    {
        "school": "LANE SCHOOL",
        "district": "ALDINE ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "480771000075",
    },
    {
        "school": "MACARTHUR H S",
        "district": "ALDINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000076",
    },
    {
        "school": "WORSHAM EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000079",
    },
    {
        "school": "OLESON EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000080",
    },
    {
        "school": "ORANGE GROVE EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000081",
    },
    {
        "school": "RAYMOND EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000082",
    },
    {
        "school": "SAMMONS EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000083",
    },
    {
        "school": "SHOTWELL MIDDLE",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000084",
    },
    {
        "school": "STEPHENS EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000085",
    },
    {
        "school": "STOVALL MIDDLE",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000086",
    },
    {
        "school": "TEAGUE MIDDLE",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771000087",
    },
    {
        "school": "CONLEY EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771005634",
    },
    {
        "school": "GRANTHAM ACADEMY",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771005942",
    },
    {
        "school": "DUNN EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771006204",
    },
    {
        "school": "GRAY EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771006638",
    },
    {
        "school": "BLACK EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771006639",
    },
    {
        "school": "STOVALL ACADEMY",
        "district": "ALDINE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771006816",
    },
    {
        "school": "REECE ACADEMY",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771007307",
    },
    {
        "school": "ALDINE J J A E P",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480771007620",
    },
    {
        "school": "HINOJOSA EC/PK/K",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771007621",
    },
    {
        "school": "ALDINE NINTH GRADE",
        "district": "ALDINE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771007917",
    },
    {
        "school": "EISENHOWER NINTH GRADE",
        "district": "ALDINE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771007918",
    },
    {
        "school": "CARTER ACADEMY",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771007919",
    },
    {
        "school": "KEEBLE EC/PK/K",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771007920",
    },
    {
        "school": "DE SANTIAGO EC/PK/K",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771007921",
    },
    {
        "school": "MACARTHUR NINTH GRADE",
        "district": "ALDINE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771008258",
    },
    {
        "school": "NIMITZ NINTH GRADE",
        "district": "ALDINE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771008259",
    },
    {
        "school": "HARRIS EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771008260",
    },
    {
        "school": "VINES EC/PK/K",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771008261",
    },
    {
        "school": "CALVERT EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771021292",
    },
    {
        "school": "MARTIN EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000102",
    },
    {
        "school": "ELSIK H S",
        "district": "ALIEF ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000103",
    },
    {
        "school": "HASTINGS H S",
        "district": "ALIEF ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000104",
    },
    {
        "school": "ALIEF MIDDLE",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000105",
    },
    {
        "school": "BOONE EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000106",
    },
    {
        "school": "CHANCELLOR EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000107",
    },
    {
        "school": "KILLOUGH MIDDLE",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000108",
    },
    {
        "school": "SMITH EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000109",
    },
    {
        "school": "OLLE MIDDLE",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000110",
    },
    {
        "school": "LIESTMAN EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000111",
    },
    {
        "school": "KENNEDY EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000112",
    },
    {
        "school": "CHAMBERS EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000113",
    },
    {
        "school": "MAHANAY EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000114",
    },
    {
        "school": "YOUENS EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783000115",
    },
    {
        "school": "O'DONNELL MIDDLE",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783001143",
    },
    {
        "school": "OUTLEY EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783004182",
    },
    {
        "school": "PETROSKY EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783005385",
    },
    {
        "school": "HEFLIN EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783005637",
    },
    {
        "school": "HOLUB MIDDLE",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783005639",
    },
    {
        "school": "OWENS INT",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783005756",
    },
    {
        "school": "ALBRIGHT MIDDLE",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783005840",
    },
    {
        "school": "CUMMINGS EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783005841",
    },
    {
        "school": "REES EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783005943",
    },
    {
        "school": "ALEXANDER EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783005944",
    },
    {
        "school": "HEARNE EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783006349",
    },
    {
        "school": "ADMIN SERVICES",
        "district": "ALIEF ISD",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480783006350",
    },
    {
        "school": "LANDIS EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783006640",
    },
    {
        "school": "SNEED EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783006817",
    },
    {
        "school": "KLENTZMAN INT",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783007016",
    },
    {
        "school": "HICKS EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783007308",
    },
    {
        "school": "YOUNGBLOOD INT",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783007309",
    },
    {
        "school": "BUSH EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783007622",
    },
    {
        "school": "COLLINS EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783008266",
    },
    {
        "school": "MATA INT",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783008267",
    },
    {
        "school": "TAYLOR H S",
        "district": "ALIEF ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783008598",
    },
    {
        "school": "ALIEF LEARNING CTR (6-12)",
        "district": "ALIEF ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480783008599",
    },
    {
        "school": "ALIEF ISD J J A E P",
        "district": "ALIEF ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480783008805",
    },
    {
        "school": "MILLER INT",
        "district": "ALIEF ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783008806",
    },
    {
        "school": "BEST EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783021293",
    },
    {
        "school": "CHANNELVIEW H S",
        "district": "CHANNELVIEW ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481359000851",
    },
    {
        "school": "VIOLA COBB EL",
        "district": "CHANNELVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481359000852",
    },
    {
        "school": "ALICE JOHNSON J H",
        "district": "CHANNELVIEW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481359000853",
    },
    {
        "school": "DE ZAVALA EL",
        "district": "CHANNELVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481359000854",
    },
    {
        "school": "SCHOCHLER EL",
        "district": "CHANNELVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481359000855",
    },
    {
        "school": "ENDEAVOR HS-JOE FRANK CAMPBELL LEARNING CENTER",
        "district": "CHANNELVIEW ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481359001144",
    },
    {
        "school": "MCMULLAN EL",
        "district": "CHANNELVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481359005422",
    },
    {
        "school": "CRENSHAW EL",
        "district": "CHANNELVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481359006077",
    },
    {
        "school": "B H HAMBLEN EL",
        "district": "CHANNELVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481359007310",
    },
    {
        "school": "JJAEP DISCIPLINARY SCHOOL",
        "district": "CHANNELVIEW ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481359008600",
    },
    {
        "school": "NEWPORT EL",
        "district": "CROSBY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481575001141",
    },
    {
        "school": "CROSBY H S",
        "district": "CROSBY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481575001142",
    },
    {
        "school": "CROSBY MIDDLE",
        "district": "CROSBY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481575005682",
    },
    {
        "school": "BARRETT EL",
        "district": "CROSBY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481575005683",
    },
    {
        "school": "DREW EL",
        "district": "CROSBY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481575005684",
    },
    {
        "school": "CROSBY KINDERGARTEN CENTER",
        "district": "CROSBY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481575006842",
    },
    {
        "school": "CYPRESS FALLS H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001148",
    },
    {
        "school": "ARNOLD MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001177",
    },
    {
        "school": "ADAM EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001178",
    },
    {
        "school": "BANE EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001179",
    },
    {
        "school": "BLEYL MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001180",
    },
    {
        "school": "CAMPBELL MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001181",
    },
    {
        "school": "CY-FAIR H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001182",
    },
    {
        "school": "CYPRESS CREEK H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001183",
    },
    {
        "school": "DEAN MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001184",
    },
    {
        "school": "HOLBROOK EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001185",
    },
    {
        "school": "JERSEY VILLAGE H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001186",
    },
    {
        "school": "LAMKIN EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001187",
    },
    {
        "school": "LIEDER EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001188",
    },
    {
        "school": "MATZKE EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001189",
    },
    {
        "school": "MILLSAP EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001190",
    },
    {
        "school": "POST EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001191",
    },
    {
        "school": "HANCOCK EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001192",
    },
    {
        "school": "YEAGER EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001193",
    },
    {
        "school": "HAMILTON MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001219",
    },
    {
        "school": "COPELAND EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001247",
    },
    {
        "school": "WILLBERN EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001248",
    },
    {
        "school": "SHERIDAN EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611001253",
    },
    {
        "school": "THORNTON MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611004206",
    },
    {
        "school": "FRANCONE EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611005436",
    },
    {
        "school": "HORNE EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611005437",
    },
    {
        "school": "MOORE EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611005438",
    },
    {
        "school": "FRAZIER EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611005685",
    },
    {
        "school": "LOWERY EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611005686",
    },
    {
        "school": "WATKINS MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611005687",
    },
    {
        "school": "OWENS EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611005861",
    },
    {
        "school": "WILSON EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611005862",
    },
    {
        "school": "LANGHAM CREEK H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611005973",
    },
    {
        "school": "LABAY MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611006084",
    },
    {
        "school": "EMMOTT EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611006085",
    },
    {
        "school": "HOLMSLEY EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611006086",
    },
    {
        "school": "COOK MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611006235",
    },
    {
        "school": "JOWELL EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611006236",
    },
    {
        "school": "FIEST EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611006671",
    },
    {
        "school": "TRUITT MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611006843",
    },
    {
        "school": "CYPRESS SPRINGS H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611007623",
    },
    {
        "school": "CYPRESS-FAIRBANKS J J A E P",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481611007624",
    },
    {
        "school": "ALTERNATIVE LEARNING CTR-EAST",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481611008601",
    },
    {
        "school": "ARAGON MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611008602",
    },
    {
        "school": "GOODSON MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611008603",
    },
    {
        "school": "KIRK EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611008807",
    },
    {
        "school": "FARNEY EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611008808",
    },
    {
        "school": "GLEASON EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611008809",
    },
    {
        "school": "WALKER EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611008810",
    },
    {
        "school": "BANG EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611021033",
    },
    {
        "school": "HAMILTON EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611021034",
    },
    {
        "school": "METCALF EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611021297",
    },
    {
        "school": "HAIRGROVE EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611021298",
    },
    {
        "school": "REED EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611021299",
    },
    {
        "school": "BONNETTE J H",
        "district": "DEER PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653001410",
    },
    {
        "school": "CARPENTER EL",
        "district": "DEER PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653001411",
    },
    {
        "school": "DEEPWATER EL",
        "district": "DEER PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653001412",
    },
    {
        "school": "DEEPWATER J H",
        "district": "DEER PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653001413",
    },
    {
        "school": "DEER PARK EL",
        "district": "DEER PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653001414",
    },
    {
        "school": "DEER PARK H S",
        "district": "DEER PARK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653001415",
    },
    {
        "school": "DEER PARK J H",
        "district": "DEER PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653001416",
    },
    {
        "school": "JP DABBS EL",
        "district": "DEER PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653001417",
    },
    {
        "school": "PARKWOOD EL",
        "district": "DEER PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653001419",
    },
    {
        "school": "SAN JACINTO EL",
        "district": "DEER PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653001420",
    },
    {
        "school": "FAIRMONT EL",
        "district": "DEER PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653006845",
    },
    {
        "school": "HARRIS CO J J A E P",
        "district": "DEER PARK ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481653007311",
    },
    {
        "school": "CIMARRON EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001980",
    },
    {
        "school": "CLOVERLEAF EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001981",
    },
    {
        "school": "GALENA PARK EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001982",
    },
    {
        "school": "GALENA PARK H S",
        "district": "GALENA PARK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001983",
    },
    {
        "school": "GALENA PARK MIDDLE",
        "district": "GALENA PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001984",
    },
    {
        "school": "GREEN VALLEY EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001985",
    },
    {
        "school": "JACINTO CITY EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001986",
    },
    {
        "school": "MACARTHUR EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001987",
    },
    {
        "school": "NORTH SHORE EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001988",
    },
    {
        "school": "NORTH SHORE SENIOR HIGH",
        "district": "GALENA PARK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001989",
    },
    {
        "school": "NORTH SHORE MIDDLE",
        "district": "GALENA PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001990",
    },
    {
        "school": "PYBURN EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001991",
    },
    {
        "school": "WOODLAND ACRES EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001992",
    },
    {
        "school": "WOODLAND ACRES MIDDLE",
        "district": "GALENA PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025001993",
    },
    {
        "school": "TICE EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025005477",
    },
    {
        "school": "CUNNINGHAM MIDDLE",
        "district": "GALENA PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025005724",
    },
    {
        "school": "HIGHPOINT SCHOOL EAST (DAEP)",
        "district": "GALENA PARK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482025006973",
    },
    {
        "school": "JAMES B HAVARD EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025007926",
    },
    {
        "school": "JUVENILE JUSTICE AEP",
        "district": "GALENA PARK ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482025008813",
    },
    {
        "school": "COBB 6TH GRADE CAMPUS",
        "district": "GALENA PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025008814",
    },
    {
        "school": "PURPLE SAGE EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025021304",
    },
    {
        "school": "DE ZAVALA EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115001260",
    },
    {
        "school": "ALAMO EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002105",
    },
    {
        "school": "ASHBEL SMITH EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002106",
    },
    {
        "school": "BAYTOWN J H",
        "district": "GOOSE CREEK CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002107",
    },
    {
        "school": "CARVER EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002108",
    },
    {
        "school": "CEDAR BAYOU J H",
        "district": "GOOSE CREEK CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002109",
    },
    {
        "school": "HARLEM EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002111",
    },
    {
        "school": "HIGHLANDS EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002112",
    },
    {
        "school": "HIGHLANDS J H",
        "district": "GOOSE CREEK CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002113",
    },
    {
        "school": "HORACE MANN J H",
        "district": "GOOSE CREEK CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002114",
    },
    {
        "school": "JAMES BOWIE EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002115",
    },
    {
        "school": "LAMAR EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002116",
    },
    {
        "school": "LEE H S",
        "district": "GOOSE CREEK CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002117",
    },
    {
        "school": "SAN JACINTO EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002120",
    },
    {
        "school": "STEPHEN F AUSTIN EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002121",
    },
    {
        "school": "STERLING H S",
        "district": "GOOSE CREEK CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002122",
    },
    {
        "school": "TRAVIS EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115002123",
    },
    {
        "school": "HOPPER PRI",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115005479",
    },
    {
        "school": "CROCKETT EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115005731",
    },
    {
        "school": "GENTRY J H",
        "district": "GOOSE CREEK CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115005732",
    },
    {
        "school": "PETER E HYLAND CENTER",
        "district": "GOOSE CREEK CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482115006974",
    },
    {
        "school": "POINT ALTERNATIVE CENTER",
        "district": "GOOSE CREEK CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482115008605",
    },
    {
        "school": "TANGLEWOOD MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364001271",
    },
    {
        "school": "BUSH EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364001308",
    },
    {
        "school": "GARCIA EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364001316",
    },
    {
        "school": "HERRERA EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364001322",
    },
    {
        "school": "CRESPO EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364001348",
    },
    {
        "school": "GALLEGOS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364001373",
    },
    {
        "school": "BENAVIDEZ EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364001389",
    },
    {
        "school": "MARTINEZ R EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364001432",
    },
    {
        "school": "ALCOTT EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002385",
    },
    {
        "school": "ALMEDA EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002387",
    },
    {
        "school": "ANDERSON EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002388",
    },
    {
        "school": "ASHFORD EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002389",
    },
    {
        "school": "ASKEW EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002390",
    },
    {
        "school": "ATHERTON EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002391",
    },
    {
        "school": "ATTUCKS MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002392",
    },
    {
        "school": "AUSTIN H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002393",
    },
    {
        "school": "BARRICK EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002394",
    },
    {
        "school": "BASTIAN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002395",
    },
    {
        "school": "BELL EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002396",
    },
    {
        "school": "BELLAIRE H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002397",
    },
    {
        "school": "BENBROOK EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002398",
    },
    {
        "school": "BERRY EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002399",
    },
    {
        "school": "BLACK MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002400",
    },
    {
        "school": "BLACKSHEAR EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002401",
    },
    {
        "school": "BONHAM EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002402",
    },
    {
        "school": "BONNER EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002403",
    },
    {
        "school": "RODERICK R PAIGE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002404",
    },
    {
        "school": "BRAEBURN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002405",
    },
    {
        "school": "BRIARGROVE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002406",
    },
    {
        "school": "BRISCOE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002407",
    },
    {
        "school": "BROOKLINE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002409",
    },
    {
        "school": "BROWNING EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002410",
    },
    {
        "school": "BRUCE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002411",
    },
    {
        "school": "BURBANK EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002412",
    },
    {
        "school": "BURBANK MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002413",
    },
    {
        "school": "BURNET EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002414",
    },
    {
        "school": "BURRUS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002415",
    },
    {
        "school": "WOODSON SCHOOL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002417",
    },
    {
        "school": "CODWELL EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002420",
    },
    {
        "school": "CONDIT EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002423",
    },
    {
        "school": "COOP EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002428",
    },
    {
        "school": "CORNELIUS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002429",
    },
    {
        "school": "CROCKETT EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002431",
    },
    {
        "school": "CULLEN MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002432",
    },
    {
        "school": "CUNNINGHAM EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002433",
    },
    {
        "school": "NORTHSIDE H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002434",
    },
    {
        "school": "DEADY MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002435",
    },
    {
        "school": "DE CHAUMES EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002436",
    },
    {
        "school": "DE ZAVALA EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002437",
    },
    {
        "school": "DOGAN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002439",
    },
    {
        "school": "LAWSON MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002442",
    },
    {
        "school": "DURHAM EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002444",
    },
    {
        "school": "DURKEE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002445",
    },
    {
        "school": "EDISON MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002447",
    },
    {
        "school": "ELIOT EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002449",
    },
    {
        "school": "ELROD EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002450",
    },
    {
        "school": "EMERSON EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002451",
    },
    {
        "school": "FIELD EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002453",
    },
    {
        "school": "FLEMING MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002454",
    },
    {
        "school": "FOERSTER EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002455",
    },
    {
        "school": "FONDREN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002456",
    },
    {
        "school": "FONDREN MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002457",
    },
    {
        "school": "FONVILLE MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002458",
    },
    {
        "school": "FOSTER EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002459",
    },
    {
        "school": "FRANKLIN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002460",
    },
    {
        "school": "FROST EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002461",
    },
    {
        "school": "FURR H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002462",
    },
    {
        "school": "GARDEN OAKS MONTESSORI",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002463",
    },
    {
        "school": "GARDEN VILLAS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002464",
    },
    {
        "school": "GOLFCREST EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002466",
    },
    {
        "school": "GREGG EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002469",
    },
    {
        "school": "GRISSOM EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002472",
    },
    {
        "school": "HAMILTON MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002474",
    },
    {
        "school": "HARRIS J R EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002478",
    },
    {
        "school": "HARRIS R P EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002479",
    },
    {
        "school": "HARTMAN MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002480",
    },
    {
        "school": "HARTSFIELD EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002481",
    },
    {
        "school": "HARVARD EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002482",
    },
    {
        "school": "DEBAKEY H S FOR HEALTH PROF",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002483",
    },
    {
        "school": "HELMS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002484",
    },
    {
        "school": "HENDERSON J EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002485",
    },
    {
        "school": "HENDERSON N EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002486",
    },
    {
        "school": "HENRY MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002487",
    },
    {
        "school": "HEROD EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002488",
    },
    {
        "school": "HIGHLAND HTS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002489",
    },
    {
        "school": "HOBBY EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002490",
    },
    {
        "school": "HOGG MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002491",
    },
    {
        "school": "HORN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002494",
    },
    {
        "school": "MCGOWEN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002495",
    },
    {
        "school": "ISAACS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002497",
    },
    {
        "school": "NAVARRO MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002498",
    },
    {
        "school": "JANOWSKI EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002499",
    },
    {
        "school": "JEFFERSON EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002500",
    },
    {
        "school": "MEYERLAND MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002501",
    },
    {
        "school": "JONES FUTURES ACADEMY",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002503",
    },
    {
        "school": "KASHMERE GARDENS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002505",
    },
    {
        "school": "KASHMERE H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002506",
    },
    {
        "school": "KELSO EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002507",
    },
    {
        "school": "KENNEDY EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002508",
    },
    {
        "school": "KEY MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002509",
    },
    {
        "school": "KOLTER EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002510",
    },
    {
        "school": "LAMAR H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002512",
    },
    {
        "school": "LANIER MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002514",
    },
    {
        "school": "LANTRIP EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002515",
    },
    {
        "school": "LAW EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002516",
    },
    {
        "school": "WISDOM H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002518",
    },
    {
        "school": "LEWIS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002519",
    },
    {
        "school": "LOCKHART EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002521",
    },
    {
        "school": "LONG ACADEMY",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002522",
    },
    {
        "school": "LONGFELLOW EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002523",
    },
    {
        "school": "LOOSCAN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002524",
    },
    {
        "school": "LOVE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002525",
    },
    {
        "school": "LOVETT EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002526",
    },
    {
        "school": "MACGREGOR EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002528",
    },
    {
        "school": "MADING EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002529",
    },
    {
        "school": "MADISON H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002530",
    },
    {
        "school": "MARSHALL MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002531",
    },
    {
        "school": "MCREYNOLDS MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002533",
    },
    {
        "school": "MEMORIAL EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002534",
    },
    {
        "school": "MILBY H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002536",
    },
    {
        "school": "MITCHELL EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002537",
    },
    {
        "school": "MONTGOMERY EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002539",
    },
    {
        "school": "NEFF ECC",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002541",
    },
    {
        "school": "NORTHLINE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002543",
    },
    {
        "school": "OAK FOREST EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002544",
    },
    {
        "school": "OATES EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002545",
    },
    {
        "school": "OSBORNE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002547",
    },
    {
        "school": "PARK PLACE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002548",
    },
    {
        "school": "PARKER EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002549",
    },
    {
        "school": "PATTERSON EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002550",
    },
    {
        "school": "PECK EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002551",
    },
    {
        "school": "KINDER H S FOR PERFORMING AND VISUAL ARTS",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002552",
    },
    {
        "school": "PERSHING MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002553",
    },
    {
        "school": "PETERSEN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002554",
    },
    {
        "school": "PILGRIM ACADEMY",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002555",
    },
    {
        "school": "PINEY POINT EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002556",
    },
    {
        "school": "PLEASANTVILLE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002558",
    },
    {
        "school": "POE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002559",
    },
    {
        "school": "PORT HOUSTON EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002560",
    },
    {
        "school": "PUGH EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002561",
    },
    {
        "school": "HEIGHTS H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002562",
    },
    {
        "school": "RED EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002563",
    },
    {
        "school": "REYNOLDS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002564",
    },
    {
        "school": "MCNAMARA EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002566",
    },
    {
        "school": "RIVER OAKS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002567",
    },
    {
        "school": "ROBERTS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002568",
    },
    {
        "school": "ROOSEVELT EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002571",
    },
    {
        "school": "ROSS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002572",
    },
    {
        "school": "RUCKER EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002573",
    },
    {
        "school": "BAYLOR COLLEGE OF MEDICINE BIOTECH ACADEMY AT RUSK",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002574",
    },
    {
        "school": "SCARBOROUGH EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002579",
    },
    {
        "school": "SCARBOROUGH H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002580",
    },
    {
        "school": "SCROGGINS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002582",
    },
    {
        "school": "SHARPSTOWN H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002583",
    },
    {
        "school": "SHARPSTOWN INTERNATIONAL SCHOOL",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002584",
    },
    {
        "school": "SHEARN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002585",
    },
    {
        "school": "SHERMAN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002586",
    },
    {
        "school": "SINCLAIR EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002587",
    },
    {
        "school": "SMITH EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002589",
    },
    {
        "school": "THOMPSON EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002590",
    },
    {
        "school": "SOUTHMAYD EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002591",
    },
    {
        "school": "STERLING H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002592",
    },
    {
        "school": "STEVENS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002593",
    },
    {
        "school": "YOUNG EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002595",
    },
    {
        "school": "SUTTON EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002596",
    },
    {
        "school": "THOMAS MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002598",
    },
    {
        "school": "TRAVIS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002599",
    },
    {
        "school": "TWAIN EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002601",
    },
    {
        "school": "WAINWRIGHT EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002602",
    },
    {
        "school": "WALNUT BEND EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002603",
    },
    {
        "school": "WALTRIP H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002604",
    },
    {
        "school": "WASHINGTON B T H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002605",
    },
    {
        "school": "WESLEY EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002607",
    },
    {
        "school": "WEST UNIVERSITY EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002608",
    },
    {
        "school": "WESTBURY H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002609",
    },
    {
        "school": "WHARTON K-8 DUAL LANGUAGE ACADEMY",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002610",
    },
    {
        "school": "WHEATLEY H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002611",
    },
    {
        "school": "WHIDBY EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002612",
    },
    {
        "school": "WHITE E EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002613",
    },
    {
        "school": "WHITTIER EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002614",
    },
    {
        "school": "WILLIAMS MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002615",
    },
    {
        "school": "WILSON MONTESSORI",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002616",
    },
    {
        "school": "WINDSOR VILLAGE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002617",
    },
    {
        "school": "WORTHING H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002619",
    },
    {
        "school": "YATES H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364002620",
    },
    {
        "school": "STEVENSON MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364004586",
    },
    {
        "school": "LYONS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364004587",
    },
    {
        "school": "CARRILLO EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364004598",
    },
    {
        "school": "HOLLAND MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364005494",
    },
    {
        "school": "GREGORY-LINCOLN ED CTR",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364005495",
    },
    {
        "school": "REVERE MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364005496",
    },
    {
        "school": "CLIFTON MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364005497",
    },
    {
        "school": "TIJERINA EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364005500",
    },
    {
        "school": "WELCH MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364005501",
    },
    {
        "school": "H S FOR LAW AND JUSTICE",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364005745",
    },
    {
        "school": "CAGE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364005999",
    },
    {
        "school": "SANCHEZ EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364006119",
    },
    {
        "school": "COMMUNITY SERVICES-SEC",
        "district": "HOUSTON ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482364006270",
    },
    {
        "school": "T H ROGERS SCHOOL",
        "district": "HOUSTON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364006272",
    },
    {
        "school": "DAVILA EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364006864",
    },
    {
        "school": "SUGAR GROVE ACADEMY",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364006983",
    },
    {
        "school": "MARTINEZ C EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364006985",
    },
    {
        "school": "SOAR CTR",
        "district": "HOUSTON ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "482364007018",
    },
    {
        "school": "HALPIN EARLY CHILDHOOD CTR",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364007321",
    },
    {
        "school": "SHADOWBRIAR EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364007322",
    },
    {
        "school": "VALLEY WEST EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364007324",
    },
    {
        "school": "EASTWOOD ACADEMY",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364007928",
    },
    {
        "school": "HARRIS CO J J A E P",
        "district": "HOUSTON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482364007934",
    },
    {
        "school": "BELLFORT EARLY CHILDHOOD CENTER",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364007940",
    },
    {
        "school": "ENERGIZED FOR EXCELLENCE ACADEMY EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364007943",
    },
    {
        "school": "YOUNG SCHOLARS ACADEMY FOR EXCELLENCE",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364007949",
    },
    {
        "school": "LAS AMERICAS",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482364008608",
    },
    {
        "school": "ENERGIZED FOR EXCELLENCE ACADEMY INC MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364008610",
    },
    {
        "school": "BRIARMEADOW CHARTER",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364008611",
    },
    {
        "school": "GROSS EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364008612",
    },
    {
        "school": "RODRIGUEZ EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364008613",
    },
    {
        "school": "TINSLEY EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364008614",
    },
    {
        "school": "R D S P D",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "482364008618",
    },
    {
        "school": "YOUNG LEARNERS",
        "district": "HOUSTON ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364008622",
    },
    {
        "school": "CHAVEZ H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364008815",
    },
    {
        "school": "WESTSIDE H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364008816",
    },
    {
        "school": "MILNE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364021036",
    },
    {
        "school": "HARGRAVE H S",
        "district": "HUFFMAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482382002633",
    },
    {
        "school": "HUFFMAN MIDDLE",
        "district": "HUFFMAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482382002635",
    },
    {
        "school": "BEAR BRANCH EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391002642",
    },
    {
        "school": "ELM GROVE EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391002643",
    },
    {
        "school": "FOSTER EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391002644",
    },
    {
        "school": "HUMBLE EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391002645",
    },
    {
        "school": "HUMBLE H S",
        "district": "HUMBLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391002646",
    },
    {
        "school": "HUMBLE MIDDLE",
        "district": "HUMBLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391002647",
    },
    {
        "school": "KINGWOOD MIDDLE",
        "district": "HUMBLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391002648",
    },
    {
        "school": "LAKELAND EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391002649",
    },
    {
        "school": "NORTH BELT EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391002650",
    },
    {
        "school": "WOODLAND HILLS EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391002651",
    },
    {
        "school": "SHADOW FOREST EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391004620",
    },
    {
        "school": "KINGWOOD H S",
        "district": "HUMBLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391005502",
    },
    {
        "school": "OAKS EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391005503",
    },
    {
        "school": "CREEKWOOD MIDDLE",
        "district": "HUMBLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391005746",
    },
    {
        "school": "GREENTREE EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391005747",
    },
    {
        "school": "TIMBERS EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391005748",
    },
    {
        "school": "ATASCOCITA MIDDLE",
        "district": "HUMBLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391005877",
    },
    {
        "school": "PINEFOREST EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391006123",
    },
    {
        "school": "DEERWOOD EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391006124",
    },
    {
        "school": "WILLOW CREEK EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391006567",
    },
    {
        "school": "HIDDEN HOLLOW EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391006866",
    },
    {
        "school": "JACK M FIELDS SR EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391007029",
    },
    {
        "school": "TIMBERWOOD MIDDLE",
        "district": "HUMBLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391007950",
    },
    {
        "school": "MAPLEBROOK EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391008624",
    },
    {
        "school": "RIVERWOOD MIDDLE",
        "district": "HUMBLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391021310",
    },
    {
        "school": "WHISPERING PINES EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391021311",
    },
    {
        "school": "MAURICE L WOLFE EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517002806",
    },
    {
        "school": "BEAR CREEK EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517002807",
    },
    {
        "school": "KATY EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517002808",
    },
    {
        "school": "KATY J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517002810",
    },
    {
        "school": "MEMORIAL PARKWAY EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517002811",
    },
    {
        "school": "WEST MEMORIAL EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517002812",
    },
    {
        "school": "WEST MEMORIAL J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517002813",
    },
    {
        "school": "ZELMA HUTSELL EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517002814",
    },
    {
        "school": "CIMARRON EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517005515",
    },
    {
        "school": "OPPORT AWARENESS CTR",
        "district": "KATY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482517005516",
    },
    {
        "school": "MAYDE CREEK J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517005517",
    },
    {
        "school": "TAYLOR H S",
        "district": "KATY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517005518",
    },
    {
        "school": "MEMORIAL PARKWAY J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517005750",
    },
    {
        "school": "NOTTINGHAM COUNTRY EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517005751",
    },
    {
        "school": "SUNDOWN EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517005752",
    },
    {
        "school": "DIANE WINBORN EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517005753",
    },
    {
        "school": "MAYDE CREEK EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517005879",
    },
    {
        "school": "MAYDE CREEK H S",
        "district": "KATY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517006001",
    },
    {
        "school": "HAZEL S PATTISON EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517006724",
    },
    {
        "school": "LORAINE T GOLBOW EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517006725",
    },
    {
        "school": "JEANETTE HAYES EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517007336",
    },
    {
        "school": "MCROBERTS EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517007641",
    },
    {
        "school": "ROOSEVELT ALEXANDER EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517007951",
    },
    {
        "school": "ARTHUR MILLER CAREER CENTER",
        "district": "KATY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482517008625",
    },
    {
        "school": "ROBERT KING EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517008627",
    },
    {
        "school": "JEAN & BETTY SCHMALZ EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517008628",
    },
    {
        "school": "PROJECT TYKE",
        "district": "KATY ISD",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "482517008629",
    },
    {
        "school": "GARLAND MCMEANS J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517008824",
    },
    {
        "school": "T H MCDONALD J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517021314",
    },
    {
        "school": "KLENK EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574001442",
    },
    {
        "school": "BENFER EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002896",
    },
    {
        "school": "BRILL EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002897",
    },
    {
        "school": "EPPS ISLAND EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002898",
    },
    {
        "school": "GREENWOOD FOREST EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002899",
    },
    {
        "school": "HAUDE EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002900",
    },
    {
        "school": "HILDEBRANDT INT",
        "district": "KLEIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002901",
    },
    {
        "school": "KAISER EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002902",
    },
    {
        "school": "KLEIN H S",
        "district": "KLEIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002903",
    },
    {
        "school": "NORTHAMPTON EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002904",
    },
    {
        "school": "STRACK INT",
        "district": "KLEIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002905",
    },
    {
        "school": "THEISS EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002906",
    },
    {
        "school": "WUNDERLICH INT",
        "district": "KLEIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574002907",
    },
    {
        "school": "EILAND EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574004647",
    },
    {
        "school": "EHRHARDT EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574005521",
    },
    {
        "school": "KLEIN FOREST H S",
        "district": "KLEIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574005522",
    },
    {
        "school": "NITSCH EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574005523",
    },
    {
        "school": "LEMM EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574005524",
    },
    {
        "school": "KLEB INT",
        "district": "KLEIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574005758",
    },
    {
        "school": "KLEIN OAK H S",
        "district": "KLEIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574005759",
    },
    {
        "school": "KRAHN EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574005880",
    },
    {
        "school": "KLEIN INT",
        "district": "KLEIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574006005",
    },
    {
        "school": "DOERRE INT",
        "district": "KLEIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574006006",
    },
    {
        "school": "ROTH EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574006007",
    },
    {
        "school": "KUEHNLE EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574006735",
    },
    {
        "school": "SCHULTZ EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574006986",
    },
    {
        "school": "HARRIS CO JJAEP",
        "district": "KLEIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482574007642",
    },
    {
        "school": "HASSLER EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574008272",
    },
    {
        "school": "KLEIN COLLINS H S",
        "district": "KLEIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574008631",
    },
    {
        "school": "KLEIN ANNEX",
        "district": "KLEIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482574008632",
    },
    {
        "school": "KLEIN SEMS",
        "district": "KLEIN ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482574008633",
    },
    {
        "school": "MITTELSTADT EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574021317",
    },
    {
        "school": "THE ACADEMY OF VIOLA DEWALT H S",
        "district": "LA PORTE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482619001443",
    },
    {
        "school": "LOMAX J H",
        "district": "LA PORTE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482619002950",
    },
    {
        "school": "COLLEGE PARK EL",
        "district": "LA PORTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482619002951",
    },
    {
        "school": "LOMAX EL",
        "district": "LA PORTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482619002952",
    },
    {
        "school": "BAYSHORE EL",
        "district": "LA PORTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482619002954",
    },
    {
        "school": "LA PORTE J H",
        "district": "LA PORTE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482619002955",
    },
    {
        "school": "JAMES H BAKER SIXTH GRADE CAMPUS",
        "district": "LA PORTE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482619002956",
    },
    {
        "school": "LEO A RIZZUTO EL",
        "district": "LA PORTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482619002957",
    },
    {
        "school": "JENNIE REID EL",
        "district": "LA PORTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482619006286",
    },
    {
        "school": "LA PORTE EL",
        "district": "LA PORTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482619006876",
    },
    {
        "school": "JJAEP DISCIPLINARY SCHOOL",
        "district": "LA PORTE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482619008827",
    },
    {
        "school": "LA PORTE H S",
        "district": "LA PORTE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482619021038",
    },
    {
        "school": "TURNER EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432001444",
    },
    {
        "school": "MORALES ELEMENTARY",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432001447",
    },
    {
        "school": "MATTHYS EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432001466",
    },
    {
        "school": "ATKINSON EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003817",
    },
    {
        "school": "BAILEY EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003818",
    },
    {
        "school": "BEVERLY HILLS INT",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003819",
    },
    {
        "school": "BURNETT ELEMENTARY",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003820",
    },
    {
        "school": "DOBIE H S",
        "district": "PASADENA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003821",
    },
    {
        "school": "FISHER ELEMENTARY",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003822",
    },
    {
        "school": "FRAZIER EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003823",
    },
    {
        "school": "FREEMAN EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003824",
    },
    {
        "school": "GARDENS EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003825",
    },
    {
        "school": "GARFIELD EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003826",
    },
    {
        "school": "GENOA EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003827",
    },
    {
        "school": "GOLDEN ACRES EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003828",
    },
    {
        "school": "JACKSON INT",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003829",
    },
    {
        "school": "JENSEN EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003830",
    },
    {
        "school": "JESSUP EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003831",
    },
    {
        "school": "KRUSE EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003832",
    },
    {
        "school": "MAE SMYTHE EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003833",
    },
    {
        "school": "MCMASTERS EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003834",
    },
    {
        "school": "MEADOR ELEMENTARY",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003835",
    },
    {
        "school": "MILLER INT",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003836",
    },
    {
        "school": "PARK VIEW INT",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003837",
    },
    {
        "school": "PARKS EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003838",
    },
    {
        "school": "PASADENA HIGH SCHOOL",
        "district": "PASADENA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003839",
    },
    {
        "school": "PEARL HALL EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003840",
    },
    {
        "school": "POMEROY EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003841",
    },
    {
        "school": "QUEENS INT",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003842",
    },
    {
        "school": "SAM RAYBURN H S",
        "district": "PASADENA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003843",
    },
    {
        "school": "RED BLUFF EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003844",
    },
    {
        "school": "RICHEY EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003845",
    },
    {
        "school": "SAN JACINTO INT",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003846",
    },
    {
        "school": "L F SMITH ELEMENTARY",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003847",
    },
    {
        "school": "SOUTH HOUSTON EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003848",
    },
    {
        "school": "SOUTH HOUSTON HIGH SCHOOL",
        "district": "PASADENA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003849",
    },
    {
        "school": "SOUTH HOUSTON INT",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003850",
    },
    {
        "school": "SOUTH SHAVER EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003851",
    },
    {
        "school": "SOUTHMORE INT",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003852",
    },
    {
        "school": "STUCHBERY EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003853",
    },
    {
        "school": "TEAGUE EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003854",
    },
    {
        "school": "THOMPSON INT",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003855",
    },
    {
        "school": "WILLIAMS ELEMENTARY",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432003856",
    },
    {
        "school": "BONDY INT",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432004691",
    },
    {
        "school": "MOORE EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432005568",
    },
    {
        "school": "YOUNG EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432005569",
    },
    {
        "school": "SPARKS ELEMENTARY",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432005905",
    },
    {
        "school": "GUIDANCE CENTER",
        "district": "PASADENA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483432008635",
    },
    {
        "school": "EXCEL ACADEMY (JJAEP)",
        "district": "PASADENA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483432008828",
    },
    {
        "school": "C E KING H S",
        "district": "SHELDON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483999004534",
    },
    {
        "school": "ROYALWOOD EL",
        "district": "SHELDON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483999004537",
    },
    {
        "school": "L E MONAHAN EL",
        "district": "SHELDON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483999005811",
    },
    {
        "school": "BUNKER HILL EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004671",
    },
    {
        "school": "EDGEWOOD EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004672",
    },
    {
        "school": "FROSTWOOD EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004673",
    },
    {
        "school": "HOLLIBROOK EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004674",
    },
    {
        "school": "HOUSMAN EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004675",
    },
    {
        "school": "HUNTERS CREEK EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004676",
    },
    {
        "school": "LANDRUM MIDDLE",
        "district": "SPRING BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004677",
    },
    {
        "school": "MEADOW WOOD EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004678",
    },
    {
        "school": "MEMORIAL DRIVE EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004679",
    },
    {
        "school": "MEMORIAL H S",
        "district": "SPRING BRANCH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004680",
    },
    {
        "school": "MEMORIAL MIDDLE",
        "district": "SPRING BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004681",
    },
    {
        "school": "NORTHBROOK H S",
        "district": "SPRING BRANCH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004682",
    },
    {
        "school": "NOTTINGHAM EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004684",
    },
    {
        "school": "PINE SHADOWS EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004685",
    },
    {
        "school": "RIDGECREST EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004686",
    },
    {
        "school": "RUMMEL CREEK EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004687",
    },
    {
        "school": "SHADOW OAKS EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004688",
    },
    {
        "school": "SHERWOOD EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004689",
    },
    {
        "school": "SPRING BRANCH EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004690",
    },
    {
        "school": "SPRING BRANCH MIDDLE",
        "district": "SPRING BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004692",
    },
    {
        "school": "SPRING FOREST MIDDLE",
        "district": "SPRING BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004693",
    },
    {
        "school": "SPRING OAKS MIDDLE",
        "district": "SPRING BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004694",
    },
    {
        "school": "SPRING SHADOW EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004695",
    },
    {
        "school": "SPRING WOODS H S",
        "district": "SPRING BRANCH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004696",
    },
    {
        "school": "SPRING WOODS MIDDLE",
        "district": "SPRING BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004697",
    },
    {
        "school": "STRATFORD H S",
        "district": "SPRING BRANCH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004698",
    },
    {
        "school": "TERRACE EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004699",
    },
    {
        "school": "THORNWOOD EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004700",
    },
    {
        "school": "VALLEY OAKS EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004701",
    },
    {
        "school": "CEDAR BROOK EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004702",
    },
    {
        "school": "WESTWOOD EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004704",
    },
    {
        "school": "WILCHESTER EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004705",
    },
    {
        "school": "WOODVIEW EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110004706",
    },
    {
        "school": "BENDWOOD SCHOOL",
        "district": "SPRING BRANCH ISD",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "484110006043",
    },
    {
        "school": "TREASURE FOREST EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110007338",
    },
    {
        "school": "BUFFALO CREEK EL",
        "district": "SPRING BRANCH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110007647",
    },
    {
        "school": "CORNERSTONE ACADEMY",
        "district": "SPRING BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110007955",
    },
    {
        "school": "HAROLD D GUTHRIE CENTER FOR EXCELLENCE",
        "district": "SPRING BRANCH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484110008637",
    },
    {
        "school": "SPRING BRANCH ED CTR",
        "district": "SPRING BRANCH ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110008638",
    },
    {
        "school": "THE PANDA PATH SCHOOL",
        "district": "SPRING BRANCH ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110008639",
    },
    {
        "school": "THE LION LANE SCHOOL",
        "district": "SPRING BRANCH ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110008640",
    },
    {
        "school": "THE BEAR BLVD SCHOOL",
        "district": "SPRING BRANCH ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110008641",
    },
    {
        "school": "THE TIGER TRAIL SCHOOL",
        "district": "SPRING BRANCH ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110008642",
    },
    {
        "school": "HARRIS CO J J A E P",
        "district": "SPRING BRANCH ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484110008830",
    },
    {
        "school": "WESTCHESTER ACADEMY FOR INTERNATIONAL STUDIES",
        "district": "SPRING BRANCH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110008831",
    },
    {
        "school": "NORTHBROOK MIDDLE",
        "district": "SPRING BRANCH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110021325",
    },
    {
        "school": "BAMMEL EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122004710",
    },
    {
        "school": "EDWIN M WELLS MIDDLE",
        "district": "SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122004712",
    },
    {
        "school": "JOHN WINSHIP EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122004713",
    },
    {
        "school": "MEYER EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122004714",
    },
    {
        "school": "MILDRED JENKINS EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122004715",
    },
    {
        "school": "PAT REYNOLDS EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122004716",
    },
    {
        "school": "PEARL M HIRSCH EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122004717",
    },
    {
        "school": "PONDEROSA EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122004718",
    },
    {
        "school": "SPRING H S",
        "district": "SPRING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122004720",
    },
    {
        "school": "WESTFIELD H S",
        "district": "SPRING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122004721",
    },
    {
        "school": "ANDERSON EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122005601",
    },
    {
        "school": "JOAN LINK EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122005816",
    },
    {
        "school": "TWIN CREEKS MIDDLE",
        "district": "SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122006044",
    },
    {
        "school": "BENEKE EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122006329",
    },
    {
        "school": "SMITH EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122006330",
    },
    {
        "school": "DELORAS E THOMPSON EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122007337",
    },
    {
        "school": "SCHOOL FOR ACCELERATED LRN",
        "district": "SPRING ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484122007952",
    },
    {
        "school": "HERITAGE EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122008829",
    },
    {
        "school": "TOMBALL J H",
        "district": "TOMBALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296004703",
    },
    {
        "school": "TOMBALL H S",
        "district": "TOMBALL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296004894",
    },
    {
        "school": "LAKEWOOD EL",
        "district": "TOMBALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296005818",
    },
    {
        "school": "WILLOW CREEK EL",
        "district": "TOMBALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296007956",
    },
    {
        "school": "TOMBALL EL",
        "district": "TOMBALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296007957",
    },
    {
        "school": "TOMBALL INT",
        "district": "TOMBALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296021327",
    },
    {
        "school": "I T HOLLEMAN EL",
        "district": "WALLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484443005072",
    },
    {
        "school": "WALLER H S",
        "district": "WALLER ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484443005073",
    },
    {
        "school": "ROBERTS ROAD EL",
        "district": "WALLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484443006184",
    },
    {
        "school": "CLEVELAND H S",
        "district": "CLEVELAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481437000925",
    },
    {
        "school": "CLEVELAND MIDDLE",
        "district": "CLEVELAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481437000926",
    },
    {
        "school": "NORTHSIDE EL",
        "district": "CLEVELAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481437000928",
    },
    {
        "school": "SOUTHSIDE EL",
        "district": "CLEVELAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481437000929",
    },
    {
        "school": "DISCIPLINARY ALTERNATIVE EDUCATION PROGRAM",
        "district": "CLEVELAND ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481437007381",
    },
    {
        "school": "EASTSIDE EL",
        "district": "CLEVELAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481437007675",
    },
    {
        "school": "AUSTIN EL",
        "district": "DAYTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481641001400",
    },
    {
        "school": "COLBERT EL",
        "district": "DAYTON ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481641001401",
    },
    {
        "school": "DAYTON H S",
        "district": "DAYTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481641001402",
    },
    {
        "school": "WILSON J H",
        "district": "DAYTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481641001403",
    },
    {
        "school": "RICHTER EL",
        "district": "DAYTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481641005692",
    },
    {
        "school": "DEVERS EL",
        "district": "DEVERS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481692001467",
    },
    {
        "school": "HARDIN EL",
        "district": "HARDIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482238002244",
    },
    {
        "school": "HARDIN H S",
        "district": "HARDIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482238002245",
    },
    {
        "school": "HARDIN J H",
        "district": "HARDIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482238002246",
    },
    {
        "school": "HULL-DAISETTA EL",
        "district": "HULL-DAISETTA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482388002639",
    },
    {
        "school": "HULL-DAISETTA H S",
        "district": "HULL-DAISETTA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482388002640",
    },
    {
        "school": "HULL-DAISETTA J H",
        "district": "HULL-DAISETTA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482388002641",
    },
    {
        "school": "LIBERTY H S",
        "district": "LIBERTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482745003087",
    },
    {
        "school": "LIBERTY MIDDLE",
        "district": "LIBERTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482745003088",
    },
    {
        "school": "SAN JACINTO EL",
        "district": "LIBERTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482745003089",
    },
    {
        "school": "LIBERTY EL",
        "district": "LIBERTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482745005773",
    },
    {
        "school": "TARKINGTON PRI",
        "district": "TARKINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484221004801",
    },
    {
        "school": "TARKINGTON H S",
        "district": "TARKINGTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484221004802",
    },
    {
        "school": "TARKINGTON MIDDLE",
        "district": "TARKINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484221004803",
    },
    {
        "school": "TARKINGTON INT",
        "district": "TARKINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484221006918",
    },
    {
        "school": "FORD EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500000997",
    },
    {
        "school": "ANDERSON EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500000998",
    },
    {
        "school": "ARMSTRONG EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500000999",
    },
    {
        "school": "AUSTIN EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001000",
    },
    {
        "school": "RICE EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001001",
    },
    {
        "school": "CONROE H S",
        "district": "CONROE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001002",
    },
    {
        "school": "HAUKE ALTER ED",
        "district": "CONROE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481500001004",
    },
    {
        "school": "HOUSTON EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001005",
    },
    {
        "school": "LAMAR EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001006",
    },
    {
        "school": "THE WOODLANDS H S",
        "district": "CONROE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001007",
    },
    {
        "school": "MILAM EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001008",
    },
    {
        "school": "KNOX J H",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001009",
    },
    {
        "school": "OAK RIDGE EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001010",
    },
    {
        "school": "RUNYAN EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001012",
    },
    {
        "school": "HAILEY EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001013",
    },
    {
        "school": "PEET J H",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001015",
    },
    {
        "school": "WILKERSON INT",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001017",
    },
    {
        "school": "GALATAS EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500001763",
    },
    {
        "school": "GLEN LOCH EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500005430",
    },
    {
        "school": "SAN JACINTO EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500005431",
    },
    {
        "school": "OAK RIDGE H S",
        "district": "CONROE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500005679",
    },
    {
        "school": "RIDE EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500005858",
    },
    {
        "school": "YORK J H",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500006081",
    },
    {
        "school": "COLLINS INT",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500006839",
    },
    {
        "school": "POWELL EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500007046",
    },
    {
        "school": "MOORHEAD J H",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500007076",
    },
    {
        "school": "CANEY CREEK H S",
        "district": "CONROE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500007401",
    },
    {
        "school": "MITCHELL INT",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500007403",
    },
    {
        "school": "BUSH EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500007404",
    },
    {
        "school": "BUCKALEW EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500007997",
    },
    {
        "school": "JUVENILE DETENTION CTR",
        "district": "CONROE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481500007998",
    },
    {
        "school": "WASHINGTON J H",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500008879",
    },
    {
        "school": "MCCULLOUGH J H",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500008880",
    },
    {
        "school": "TRAVIS INT",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500008881",
    },
    {
        "school": "GRANGERLAND INT",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500008990",
    },
    {
        "school": "VOGEL INT",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500008991",
    },
    {
        "school": "CREIGHTON EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500008992",
    },
    {
        "school": "HOUSER EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500008993",
    },
    {
        "school": "DAVID EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500021045",
    },
    {
        "school": "GIESINGER EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500021046",
    },
    {
        "school": "MAGNOLIA EL",
        "district": "MAGNOLIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874003253",
    },
    {
        "school": "MAGNOLIA H S",
        "district": "MAGNOLIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874003254",
    },
    {
        "school": "J L LYON EL",
        "district": "MAGNOLIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874003255",
    },
    {
        "school": "MAGNOLIA J H",
        "district": "MAGNOLIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874003256",
    },
    {
        "school": "BEAR BRANCH EL",
        "district": "MAGNOLIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874005895",
    },
    {
        "school": "WILLIE E WILLIAMS EL",
        "district": "MAGNOLIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874007078",
    },
    {
        "school": "BEAR BRANCH J H",
        "district": "MAGNOLIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874007406",
    },
    {
        "school": "CEDRIC C SMITH",
        "district": "MAGNOLIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874008884",
    },
    {
        "school": "ALTERNATIVE EDUCATION PROGRAM",
        "district": "MAGNOLIA ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482874008995",
    },
    {
        "school": "ALPHA",
        "district": "MAGNOLIA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482874008996",
    },
    {
        "school": "MONTGOMERY EL",
        "district": "MONTGOMERY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483126003512",
    },
    {
        "school": "MONTGOMERY H S",
        "district": "MONTGOMERY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483126003513",
    },
    {
        "school": "MONTGOMERY J H",
        "district": "MONTGOMERY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483126003514",
    },
    {
        "school": "LINCOLN EL",
        "district": "MONTGOMERY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483126007999",
    },
    {
        "school": "MONTGOMERY CO J J A E P",
        "district": "MONTGOMERY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483126008882",
    },
    {
        "school": "NEW CANEY EL",
        "district": "NEW CANEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240003595",
    },
    {
        "school": "NEW CANEY H S",
        "district": "NEW CANEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240003596",
    },
    {
        "school": "WHITE OAK MIDDLE",
        "district": "NEW CANEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240003597",
    },
    {
        "school": "PORTER EL",
        "district": "NEW CANEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240003599",
    },
    {
        "school": "THE LEARNING CTR",
        "district": "NEW CANEY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483240007079",
    },
    {
        "school": "ROBERT CRIPPEN EL",
        "district": "NEW CANEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240007407",
    },
    {
        "school": "KEEFER CROSSING MIDDLE",
        "district": "NEW CANEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240008997",
    },
    {
        "school": "KINGS MANOR EL",
        "district": "NEW CANEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240008999",
    },
    {
        "school": "SPLENDORA J H",
        "district": "SPLENDORA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484107004667",
    },
    {
        "school": "PEACH CREEK EL",
        "district": "SPLENDORA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484107004668",
    },
    {
        "school": "SPLENDORA H S",
        "district": "SPLENDORA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484107004669",
    },
    {
        "school": "GREENLEAF EL",
        "district": "SPLENDORA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484107006328",
    },
    {
        "school": "JUVENILE JUSTICE ALTERNATIVE EDUCATION PROGRAM",
        "district": "SPLENDORA ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484107008002",
    },
    {
        "school": "DUEITT MIDDLE",
        "district": "SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122005602",
    },
    {
        "school": "DECKER PRAIRIE EL",
        "district": "TOMBALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296004893",
    },
    {
        "school": "PARMLEY EL",
        "district": "WILLIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484590005226",
    },
    {
        "school": "WILLIS H S",
        "district": "WILLIS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484590005228",
    },
    {
        "school": "LYNN LUCAS MIDDLE",
        "district": "WILLIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484590005933",
    },
    {
        "school": "C C HARDY EL",
        "district": "WILLIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484590005934",
    },
    {
        "school": "TURNER EL",
        "district": "WILLIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484590006631",
    },
    {
        "school": "EDWARD B CANNAN EL",
        "district": "WILLIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484590008340",
    },
    {
        "school": "JJAEP",
        "district": "WILLIS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484590008883",
    },
    {
        "school": "STUBBLEFIELD ALTERNATIVE ACADEMY",
        "district": "WILLIS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484590008994",
    },
    {
        "school": "HEMPSTEAD EL",
        "district": "HEMPSTEAD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482292002320",
    },
    {
        "school": "HEMPSTEAD H S",
        "district": "HEMPSTEAD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482292002321",
    },
    {
        "school": "HEMPSTEAD MIDDLE",
        "district": "HEMPSTEAD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482292002322",
    },
    {
        "school": "ROYAL H S",
        "district": "ROYAL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483819004264",
    },
    {
        "school": "ROYAL J H",
        "district": "ROYAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483819004265",
    },
    {
        "school": "WALLER J H",
        "district": "WALLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484443005074",
    },
    {
        "school": "H T JONES EL",
        "district": "WALLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484443008076",
    },
    {
        "school": "WALLER J J A E P",
        "district": "WALLER ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484443008402",
    },
    {
        "school": "NEW WAVERLY INT",
        "district": "NEW WAVERLY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483264011079",
    },
    {
        "school": "THOMAS BUZBEE VOCATIONAL SCHOOL",
        "district": "RAVEN SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480004808075",
    },
    {
        "school": "SAMUEL HOUSTON EL",
        "district": "HUNTSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482403002656",
    },
    {
        "school": "GIBBS PRE-K CENTER",
        "district": "HUNTSVILLE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482403002657",
    },
    {
        "school": "HUNTSVILLE H S",
        "district": "HUNTSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482403002658",
    },
    {
        "school": "HUNTSVILLE INT",
        "district": "HUNTSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482403002659",
    },
    {
        "school": "STEWART EL",
        "district": "HUNTSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482403002660",
    },
    {
        "school": "MANCE PARK MIDDLE",
        "district": "HUNTSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482403005504",
    },
    {
        "school": "SCOTT JOHNSON EL",
        "district": "HUNTSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482403005505",
    },
    {
        "school": "HUNTSVILLE EL",
        "district": "HUNTSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482403006867",
    },
    {
        "school": "NEW WAVERLY H S",
        "district": "NEW WAVERLY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483264003609",
    },
    {
        "school": "NEW WAVERLY EL",
        "district": "NEW WAVERLY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483264003610",
    },
    {
        "school": "NEW WAVERLY J H",
        "district": "NEW WAVERLY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483264006589",
    },
    {
        "school": "RUSK INT",
        "district": "RUSK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483836009506",
    },
    {
        "school": "ALTO EL",
        "district": "ALTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480798000126",
    },
    {
        "school": "ALTO H S",
        "district": "ALTO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480798000127",
    },
    {
        "school": "ALTO MIDDLE",
        "district": "ALTO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480798007548",
    },
    {
        "school": "EAST SIDE EL",
        "district": "JACKSONVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482459002748",
    },
    {
        "school": "JACKSONVILLE H S",
        "district": "JACKSONVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482459002750",
    },
    {
        "school": "JACKSONVILLE MIDDLE",
        "district": "JACKSONVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482459002752",
    },
    {
        "school": "WEST SIDE EL",
        "district": "JACKSONVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482459002753",
    },
    {
        "school": "JOE WRIGHT EL",
        "district": "JACKSONVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482459002754",
    },
    {
        "school": "FRED DOUGLASS",
        "district": "JACKSONVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482459006000",
    },
    {
        "school": "COMPASS CENTER",
        "district": "JACKSONVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482459007213",
    },
    {
        "school": "NICHOLS INT",
        "district": "JACKSONVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482459008474",
    },
    {
        "school": "NEW SUMMERFIELD SCHOOL",
        "district": "NEW SUMMERFIELD ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483261003608",
    },
    {
        "school": "RUSK EL",
        "district": "RUSK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483836004273",
    },
    {
        "school": "RUSK H S",
        "district": "RUSK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483836004274",
    },
    {
        "school": "RUSK J H",
        "district": "RUSK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483836004275",
    },
    {
        "school": "GW BRADFORD PRI",
        "district": "RUSK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483836005807",
    },
    {
        "school": "WELLS EL",
        "district": "WELLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484494005115",
    },
    {
        "school": "WELLS H S",
        "district": "WELLS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484494005116",
    },
    {
        "school": "FRED H TALLY EL",
        "district": "KERRVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482559009323",
    },
    {
        "school": "CENTER POINT EL",
        "district": "CENTER POINT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481335000836",
    },
    {
        "school": "CENTER POINT H S",
        "district": "CENTER POINT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481335000837",
    },
    {
        "school": "CENTER POINT MIDDLE",
        "district": "CENTER POINT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481335007375",
    },
    {
        "school": "DIVIDE EL",
        "district": "DIVIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481719001490",
    },
    {
        "school": "HUNT SCHOOL",
        "district": "HUNT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482397002652",
    },
    {
        "school": "INGRAM EL",
        "district": "INGRAM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482421002699",
    },
    {
        "school": "INGRAM TOM MOORE H S",
        "district": "INGRAM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482421005510",
    },
    {
        "school": "B T WILSON SIXTH GRADE SCHOOL",
        "district": "KERRVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482559001629",
    },
    {
        "school": "DANIELS EL",
        "district": "KERRVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482559002848",
    },
    {
        "school": "PETERSON MIDDLE",
        "district": "KERRVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482559002850",
    },
    {
        "school": "STARKEY EL",
        "district": "KERRVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482559002851",
    },
    {
        "school": "NIMITZ EL",
        "district": "KERRVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482559002852",
    },
    {
        "school": "TIVY H S",
        "district": "KERRVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482559002853",
    },
    {
        "school": "HILL COUNTRY H S",
        "district": "KERRVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482559004892",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "KERRVILLE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482559007376",
    },
    {
        "school": "KERRVILLE DISCIPLINARY ALTERNATIVE SCHOOL",
        "district": "KERRVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482559008963",
    },
    {
        "school": "TARVER EL",
        "district": "BELTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986011412",
    },
    {
        "school": "BELL COUNTY ALTERNATIVE SCHOOL",
        "district": "ACADEMY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480747009111",
    },
    {
        "school": "ACADEMY JJAEP",
        "district": "ACADEMY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480747010395",
    },
    {
        "school": "WILLIAMSON CO J J A E P",
        "district": "BARTLETT ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480954009112",
    },
    {
        "school": "BELL CO JJAEP",
        "district": "BARTLETT ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480954010396",
    },
    {
        "school": "LAKE BELTON MIDDLE",
        "district": "BELTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986010398",
    },
    {
        "school": "BELL COUNTY JJAEP",
        "district": "HOLLAND ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482337010400",
    },
    {
        "school": "BELL COUNTY DAEP",
        "district": "HOLLAND ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482337010401",
    },
    {
        "school": "KILLEEN ISD CAREER CENTER",
        "district": "KILLEEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566009113",
    },
    {
        "school": "LIVE OAK RIDGE MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566009115",
    },
    {
        "school": "EL ALTER LEARNING CENTER",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482566009455",
    },
    {
        "school": "IRA CROSS JR EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566009456",
    },
    {
        "school": "IDUMA EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566009457",
    },
    {
        "school": "UNION GROVE MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566010402",
    },
    {
        "school": "AUDIE MURPHY MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566010403",
    },
    {
        "school": "OVETA CULP HOBBY EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566010404",
    },
    {
        "school": "TIMBER RIDGE EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566010405",
    },
    {
        "school": "SAEGERT EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566010407",
    },
    {
        "school": "SKIPCHA EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566010408",
    },
    {
        "school": "BELL COUNTY JJAEP",
        "district": "ROGERS ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483771010409",
    },
    {
        "school": "BELL CO JJAEP",
        "district": "SALADO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483858010410",
    },
    {
        "school": "BELL COUNTY DAEP",
        "district": "SALADO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483858010411",
    },
    {
        "school": "SCOTT & WHITE HOSPITAL",
        "district": "TEMPLE ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484233009458",
    },
    {
        "school": "TROY J J A E P",
        "district": "TROY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484326009459",
    },
    {
        "school": "LAMPASAS H S",
        "district": "LAMPASAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482664002998",
    },
    {
        "school": "LAMPASAS MIDDLE",
        "district": "LAMPASAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482664002999",
    },
    {
        "school": "KLINE WHITIS EL",
        "district": "LAMPASAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482664003000",
    },
    {
        "school": "HANNA SPRINGS EL",
        "district": "LAMPASAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482664007378",
    },
    {
        "school": "LOMETA SCHOOL",
        "district": "LOMETA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482796003134",
    },
    {
        "school": "RICHARD MILBURN ALTER H S (KILLEEN)",
        "district": "RICHARD MILBURN ALTER HIGH SCHOOL (KILLEEN)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007508097",
    },
    {
        "school": "TEMPLE CHARTER ACADEMY",
        "district": "PRIORITY CHARTER SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007608098",
    },
    {
        "school": "ACADEMY INT",
        "district": "ACADEMY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480747000039",
    },
    {
        "school": "ACADEMY H S",
        "district": "ACADEMY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480747000040",
    },
    {
        "school": "ACADEMY J H",
        "district": "ACADEMY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480747006348",
    },
    {
        "school": "BARTLETT SCHOOLS",
        "district": "BARTLETT ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480954000406",
    },
    {
        "school": "BELTON H S",
        "district": "BELTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986000454",
    },
    {
        "school": "LEON HEIGHTS EL",
        "district": "BELTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986000457",
    },
    {
        "school": "MILLER HEIGHTS EL",
        "district": "BELTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986000458",
    },
    {
        "school": "SOUTHWEST EL",
        "district": "BELTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986000459",
    },
    {
        "school": "LAKEWOOD EL",
        "district": "BELTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986006221",
    },
    {
        "school": "SPARTA EL",
        "district": "BELTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986006511",
    },
    {
        "school": "BELTON NEW TECH H S AT WASKOW",
        "district": "BELTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986008099",
    },
    {
        "school": "BELL CO J J A E P",
        "district": "BELTON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480986008100",
    },
    {
        "school": "JOE M PIRTLE EL",
        "district": "BELTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986008101",
    },
    {
        "school": "HOLLAND EL",
        "district": "HOLLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482337002372",
    },
    {
        "school": "HOLLAND H S",
        "district": "HOLLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482337002373",
    },
    {
        "school": "HOLLAND MIDDLE",
        "district": "HOLLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482337002844",
    },
    {
        "school": "GATEWAY MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482566000118",
    },
    {
        "school": "ADVENTHEALTH SCHOOL",
        "district": "KILLEEN ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482566002861",
    },
    {
        "school": "BELLAIRE EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002862",
    },
    {
        "school": "CLIFTON PARK EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002864",
    },
    {
        "school": "C E ELLISON H S",
        "district": "KILLEEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002866",
    },
    {
        "school": "HARKER HEIGHTS EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002869",
    },
    {
        "school": "KILLEEN H S",
        "district": "KILLEEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002871",
    },
    {
        "school": "MANOR MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002872",
    },
    {
        "school": "MEADOWS EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002874",
    },
    {
        "school": "NOLAN MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002875",
    },
    {
        "school": "NOLANVILLE EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002876",
    },
    {
        "school": "PEEBLES EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002877",
    },
    {
        "school": "PERSHING PARK EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002878",
    },
    {
        "school": "RANCIER MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002879",
    },
    {
        "school": "SUGAR LOAF EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002881",
    },
    {
        "school": "WEST WARD EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002882",
    },
    {
        "school": "CEDAR VALLEY EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002912",
    },
    {
        "school": "BROOKHAVEN EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002913",
    },
    {
        "school": "PALO ALTO MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566005918",
    },
    {
        "school": "GATEWAY H S",
        "district": "KILLEEN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482566006281",
    },
    {
        "school": "HAY BRANCH EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566006282",
    },
    {
        "school": "WILLOW SPRINGS EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566006283",
    },
    {
        "school": "EASTERN HILLS MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566006433",
    },
    {
        "school": "MOUNTAIN VIEW EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566006574",
    },
    {
        "school": "REECES CREEK EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566006733",
    },
    {
        "school": "KILLEEN JJAEP",
        "district": "KILLEEN ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482566007783",
    },
    {
        "school": "LIBERTY HILL MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566007784",
    },
    {
        "school": "TRIMMIER EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566007785",
    },
    {
        "school": "MONTAGUE VILLAGE EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566007786",
    },
    {
        "school": "MAXDALE EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566008428",
    },
    {
        "school": "HARKER HEIGHTS H S",
        "district": "KILLEEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566008695",
    },
    {
        "school": "ROBERT M SHOEMAKER H S",
        "district": "KILLEEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566008696",
    },
    {
        "school": "PATHWAYS ACADEMIC CAMPUS",
        "district": "KILLEEN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482566021001",
    },
    {
        "school": "CLEAR CREEK EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566021004",
    },
    {
        "school": "ROGERS EL",
        "district": "ROGERS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483771004224",
    },
    {
        "school": "ROGERS H S",
        "district": "ROGERS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483771004225",
    },
    {
        "school": "ROGERS MIDDLE",
        "district": "ROGERS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483771021090",
    },
    {
        "school": "SALADO H S",
        "district": "SALADO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483858004288",
    },
    {
        "school": "MERIDITH-DUNBAR EARLY CHILDHOOD ACADEMY",
        "district": "TEMPLE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233004815",
    },
    {
        "school": "BONHAM MIDDLE",
        "district": "TEMPLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233004816",
    },
    {
        "school": "CATER EL",
        "district": "TEMPLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233004817",
    },
    {
        "school": "JEFFERSON EL",
        "district": "TEMPLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233004821",
    },
    {
        "school": "LAMAR MIDDLE",
        "district": "TEMPLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233004822",
    },
    {
        "school": "SCOTT EL",
        "district": "TEMPLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233004826",
    },
    {
        "school": "TEMPLE H S",
        "district": "TEMPLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233004827",
    },
    {
        "school": "THORNTON EL",
        "district": "TEMPLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233004828",
    },
    {
        "school": "TRAVIS SCIENCE ACADEMY",
        "district": "TEMPLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233004829",
    },
    {
        "school": "WESTERN HILLS EL",
        "district": "TEMPLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233004831",
    },
    {
        "school": "RAYE-ALLEN EL",
        "district": "TEMPLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233007787",
    },
    {
        "school": "KENNEDY-POWELL EL",
        "district": "TEMPLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233007788",
    },
    {
        "school": "HECTOR P GARCIA EL",
        "district": "TEMPLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484233007789",
    },
    {
        "school": "WHEATLEY ALTERNATIVE EDUCATION CENTER",
        "district": "TEMPLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484233008430",
    },
    {
        "school": "BELL CO J J A E P",
        "district": "TEMPLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484233008697",
    },
    {
        "school": "TROY EL",
        "district": "TROY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484326004912",
    },
    {
        "school": "TROY H S",
        "district": "TROY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484326004913",
    },
    {
        "school": "RAYMOND MAYS MIDDLE",
        "district": "TROY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484326006179",
    },
    {
        "school": "EDNA BIGHAM MAYS EL",
        "district": "TROY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484326008431",
    },
    {
        "school": "C R CLEMENTS/HOLLIE PARSONS EL",
        "district": "COPPERAS COVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481524001029",
    },
    {
        "school": "COPPERAS COVE H S",
        "district": "COPPERAS COVE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481524001030",
    },
    {
        "school": "FAIRVIEW/MISS JEWELL EL",
        "district": "COPPERAS COVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481524001031",
    },
    {
        "school": "HETTIE HALSTEAD EL",
        "district": "COPPERAS COVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481524001032",
    },
    {
        "school": "COPPERAS COVE J H",
        "district": "COPPERAS COVE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481524001033",
    },
    {
        "school": "MAE STEVENS EARLY LEARNING ACADEMY",
        "district": "COPPERAS COVE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481524001034",
    },
    {
        "school": "MARTIN WALKER EL",
        "district": "COPPERAS COVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481524001035",
    },
    {
        "school": "J L WILLIAMS/LOVETT LEDGER EL",
        "district": "COPPERAS COVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481524006840",
    },
    {
        "school": "CROSSROADS H S",
        "district": "COPPERAS COVE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481524007233",
    },
    {
        "school": "S C LEE J H",
        "district": "COPPERAS COVE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481524007234",
    },
    {
        "school": "EVANT EL",
        "district": "EVANT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481878001754",
    },
    {
        "school": "EVANT H S",
        "district": "EVANT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481878001755",
    },
    {
        "school": "GATESVILLE EL",
        "district": "GATESVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482050002059",
    },
    {
        "school": "GATESVILLE H S",
        "district": "GATESVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482050002060",
    },
    {
        "school": "GATESVILLE J H",
        "district": "GATESVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482050002061",
    },
    {
        "school": "GATESVILLE PRI",
        "district": "GATESVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482050002062",
    },
    {
        "school": "GATESVILLE INT",
        "district": "GATESVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482050007232",
    },
    {
        "school": "CLARKE EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566002863",
    },
    {
        "school": "DUNCAN EL",
        "district": "KILLEEN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566005757",
    },
    {
        "school": "OGLESBY SCHOOL",
        "district": "OGLESBY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483342003751",
    },
    {
        "school": "JONESBORO SCHOOL",
        "district": "JONESBORO ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482490002779",
    },
    {
        "school": "SARITA EL",
        "district": "KENEDY COUNTY WIDE CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482541002831",
    },
    {
        "school": "HOMEBOUND",
        "district": "KINGSVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482568001658",
    },
    {
        "school": "GILLETT INT",
        "district": "KINGSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482568002884",
    },
    {
        "school": "HARREL EL",
        "district": "KINGSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482568002885",
    },
    {
        "school": "HARVEY EL",
        "district": "KINGSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482568002886",
    },
    {
        "school": "H M KING H S",
        "district": "KINGSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482568002887",
    },
    {
        "school": "KLEBERG EL",
        "district": "KINGSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482568002888",
    },
    {
        "school": "MEMORIAL MIDDLE",
        "district": "KINGSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482568002891",
    },
    {
        "school": "PEREZ EL",
        "district": "KINGSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482568002892",
    },
    {
        "school": "RICARDO EL",
        "district": "RICARDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483693004113",
    },
    {
        "school": "RICARDO MIDDLE",
        "district": "RICARDO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483693007059",
    },
    {
        "school": "KAUFER H S",
        "district": "RIVIERA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483732004193",
    },
    {
        "school": "NANNY EL",
        "district": "RIVIERA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483732004194",
    },
    {
        "school": "SANTA GERTRUDIS SCHOOL",
        "district": "SANTA GERTRUDIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483930004477",
    },
    {
        "school": "SANTA GERTRUDIS ACADEMY H S",
        "district": "SANTA GERTRUDIS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483930007019",
    },
    {
        "school": "DAWSON SCHOOL",
        "district": "DAWSON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481635001399",
    },
    {
        "school": "KLONDIKE ISD",
        "district": "KLONDIKE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482579002909",
    },
    {
        "school": "LAMESA SCHOOLS",
        "district": "LAMESA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482661002993",
    },
    {
        "school": "SANDS CISD",
        "district": "SANDS CISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483912004462",
    },
    {
        "school": "ANTONIO GONZALEZ MIDDLE",
        "district": "UNITED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365009420",
    },
    {
        "school": "CHARLES BORCHERS EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365009421",
    },
    {
        "school": "LAMAR BRUNI VERGARA MIDDLE",
        "district": "UNITED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365011082",
    },
    {
        "school": "BONNIE L GARCIA EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365011083",
    },
    {
        "school": "RODOLFO C CENTENO EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365011084",
    },
    {
        "school": "DR MALAKOFF EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365011085",
    },
    {
        "school": "BARBARA FASKEN EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365011086",
    },
    {
        "school": "RADCLIFFE & SUE KILLAM EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365011087",
    },
    {
        "school": "TRIUMPH PUBLIC HIGH SCHOOLS-LAREDO NORTH",
        "district": "TRIUMPH PUBLIC HIGH SCHOOLS-LAREDO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480017408403",
    },
    {
        "school": "BRUNI EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003010",
    },
    {
        "school": "DON JOSE GALLEGO",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003011",
    },
    {
        "school": "CHRISTEN MIDDLE",
        "district": "LAREDO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003012",
    },
    {
        "school": "D D HACHAR EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003013",
    },
    {
        "school": "DAICHES EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003014",
    },
    {
        "school": "FARIAS EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003015",
    },
    {
        "school": "H B ZACHRY EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003016",
    },
    {
        "school": "HEIGHTS EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003018",
    },
    {
        "school": "J C MARTIN JR EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003019",
    },
    {
        "school": "LAMAR MIDDLE",
        "district": "LAREDO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003020",
    },
    {
        "school": "LEYENDECKER EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003021",
    },
    {
        "school": "MACDONELL EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003022",
    },
    {
        "school": "MARTIN H S",
        "district": "LAREDO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003023",
    },
    {
        "school": "MILTON EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003024",
    },
    {
        "school": "NIXON H S",
        "district": "LAREDO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003025",
    },
    {
        "school": "PIERCE EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003026",
    },
    {
        "school": "RYAN EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003027",
    },
    {
        "school": "SANTA MARIA EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003029",
    },
    {
        "school": "SANTO NINO EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003030",
    },
    {
        "school": "TARVER EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679003031",
    },
    {
        "school": "J KAWAS EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679005765",
    },
    {
        "school": "DOVALINA EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679005882",
    },
    {
        "school": "DR LEO CIGARROA H S",
        "district": "LAREDO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679005883",
    },
    {
        "school": "JOAQUIN CIGARROA MIDDLE",
        "district": "LAREDO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679005884",
    },
    {
        "school": "MEMORIAL MIDDLE",
        "district": "LAREDO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679005885",
    },
    {
        "school": "LIGARDE EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679006578",
    },
    {
        "school": "F S LARA ACADEMY",
        "district": "LAREDO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482679007475",
    },
    {
        "school": "WEBB COUNTY J J A E P",
        "district": "LAREDO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482679007748",
    },
    {
        "school": "T SANCHEZ EL / H OCHOA EL",
        "district": "LAREDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482679009089",
    },
    {
        "school": "RUIZ EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365000036",
    },
    {
        "school": "AMPARO GUTIERREZ EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365002775",
    },
    {
        "school": "CLARK EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365004958",
    },
    {
        "school": "NYE EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365004960",
    },
    {
        "school": "SALINAS EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365004961",
    },
    {
        "school": "UNITED H S",
        "district": "UNITED ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365004962",
    },
    {
        "school": "MATIAS DE LLANO EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365005589",
    },
    {
        "school": "KAZEN EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365005590",
    },
    {
        "school": "JUAREZ/LINCOLN EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365005596",
    },
    {
        "school": "NEWMAN EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365005608",
    },
    {
        "school": "TRAUTMANN EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365005822",
    },
    {
        "school": "UNITED MIDDLE",
        "district": "UNITED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365006337",
    },
    {
        "school": "SIGIFREDO PEREZ EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365006339",
    },
    {
        "school": "FINLEY EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365006492",
    },
    {
        "school": "UNITED SOUTH H S",
        "district": "UNITED ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365006922",
    },
    {
        "school": "JOHN B ALEXANDER H S",
        "district": "UNITED ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365007094",
    },
    {
        "school": "PRADA EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365007096",
    },
    {
        "school": "SALVADOR GARCIA MIDDLE",
        "district": "UNITED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365007145",
    },
    {
        "school": "GEORGE WASHINGTON MIDDLE",
        "district": "UNITED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365007146",
    },
    {
        "school": "CLARK MIDDLE",
        "district": "UNITED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365007147",
    },
    {
        "school": "KENNEDY ZAPATA EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365007150",
    },
    {
        "school": "COL SANTOS BENAVIDES EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365007151",
    },
    {
        "school": "JUVENILLE JUSTICE ALTERNATIVE PROGRAM",
        "district": "UNITED ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484365007476",
    },
    {
        "school": "LOS OBISPOS MIDDLE",
        "district": "UNITED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365007477",
    },
    {
        "school": "TRAUTMANN MIDDLE",
        "district": "UNITED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365007478",
    },
    {
        "school": "FRANKLIN D ROOSEVELT EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365007479",
    },
    {
        "school": "UNITED STEP ACADEMY",
        "district": "UNITED ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484365008405",
    },
    {
        "school": "JUDITH ZAFFIRINI EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365008406",
    },
    {
        "school": "HENRY CUELLAR EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365008407",
    },
    {
        "school": "JULIA BIRD JONES MULLER EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365008408",
    },
    {
        "school": "JOHN W ARNDT EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365008409",
    },
    {
        "school": "LYNDON B JOHNSON",
        "district": "UNITED ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365009091",
    },
    {
        "school": "UNITED SOUTH MIDDLE",
        "district": "UNITED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365021066",
    },
    {
        "school": "BRUNI H S",
        "district": "WEBB CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484481005103",
    },
    {
        "school": "OILTON EL",
        "district": "WEBB CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484481005104",
    },
    {
        "school": "BRUNI MIDDLE",
        "district": "WEBB CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484481005613",
    },
    {
        "school": "WEBB D A E P",
        "district": "WEBB CISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484481008953",
    },
    {
        "school": "ANTON P E P",
        "district": "ANTON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480846008299",
    },
    {
        "school": "ANTON SCHOOL",
        "district": "ANTON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480846000214",
    },
    {
        "school": "LEVELLAND H S",
        "district": "LEVELLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482724003057",
    },
    {
        "school": "LEVELLAND MIDDLE",
        "district": "LEVELLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482724003058",
    },
    {
        "school": "LEVELLAND INT",
        "district": "LEVELLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482724003059",
    },
    {
        "school": "SOUTH EL",
        "district": "LEVELLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482724003060",
    },
    {
        "school": "LEVELLAND ACADEMIC BEGINNINGS CENTER",
        "district": "LEVELLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482724003061",
    },
    {
        "school": "ROPES SCHOOL",
        "district": "ROPES ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483783004235",
    },
    {
        "school": "SMYER SCHOOLS",
        "district": "SMYER ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484059004593",
    },
    {
        "school": "SUNDOWN EL",
        "district": "SUNDOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484185004772",
    },
    {
        "school": "SUNDOWN H S",
        "district": "SUNDOWN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484185004773",
    },
    {
        "school": "SUNDOWN J H",
        "district": "SUNDOWN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484185004774",
    },
    {
        "school": "PEP ALTER SCHOOL",
        "district": "SUNDOWN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484185008300",
    },
    {
        "school": "WHITHARRAL SCHOOL",
        "district": "WHITHARRAL ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484569005193",
    },
    {
        "school": "PINE TREE DAEP",
        "district": "PINE TREE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483498010696",
    },
    {
        "school": "CARLISLE SCHOOL",
        "district": "CARLISLE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481287000783",
    },
    {
        "school": "HENDERSON H S",
        "district": "HENDERSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482297002325",
    },
    {
        "school": "HENDERSON MIDDLE",
        "district": "HENDERSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482297002326",
    },
    {
        "school": "MONNIE MEYER WYLIE PRI",
        "district": "HENDERSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482297002327",
    },
    {
        "school": "NORTHSIDE EL",
        "district": "HENDERSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482297002329",
    },
    {
        "school": "LANEVILLE SCHOOL",
        "district": "LANEVILLE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482670006577",
    },
    {
        "school": "LEVERETTS CHAPEL H S",
        "district": "LEVERETTS CHAPEL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482727003063",
    },
    {
        "school": "LEVERETTS CHAPEL EL",
        "district": "LEVERETTS CHAPEL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482727007423",
    },
    {
        "school": "LEVERETTS CHAPEL J H",
        "district": "LEVERETTS CHAPEL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482727009016",
    },
    {
        "school": "MT ENTERPRISE EL",
        "district": "MOUNT ENTERPRISE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483165003530",
    },
    {
        "school": "MT ENTERPRISE H S",
        "district": "MOUNT ENTERPRISE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483165003531",
    },
    {
        "school": "OVERTON EL",
        "district": "OVERTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483387003771",
    },
    {
        "school": "OVERTON H S",
        "district": "OVERTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483387003772",
    },
    {
        "school": "TATUM EL",
        "district": "TATUM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484224004804",
    },
    {
        "school": "TATUM H S",
        "district": "TATUM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484224004805",
    },
    {
        "school": "TATUM MIDDLE",
        "district": "TATUM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484224006046",
    },
    {
        "school": "TATUM PRI",
        "district": "TATUM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484224006047",
    },
    {
        "school": "WEST RUSK INT",
        "district": "WEST RUSK COUNTY CONSOLIDATED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484515005150",
    },
    {
        "school": "WEST RUSK H S",
        "district": "WEST RUSK COUNTY CONSOLIDATED ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484515005151",
    },
    {
        "school": "WEST RUSK MIDDLE",
        "district": "WEST RUSK COUNTY CONSOLIDATED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484515005152",
    },
    {
        "school": "DAN CHADWICK CAMPUS",
        "district": "EAST TEXAS CHARTER SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480010908220",
    },
    {
        "school": "GLADEWATER PRI",
        "district": "GLADEWATER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482076002082",
    },
    {
        "school": "GLADEWATER MIDDLE",
        "district": "GLADEWATER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482076002084",
    },
    {
        "school": "WELDON EL",
        "district": "GLADEWATER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482076005994",
    },
    {
        "school": "KILGORE H S",
        "district": "KILGORE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482562002858",
    },
    {
        "school": "KILGORE PRI",
        "district": "KILGORE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482562002859",
    },
    {
        "school": "KILGORE MIDDLE",
        "district": "KILGORE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482562002860",
    },
    {
        "school": "ELDER COOP ALTER SCHOOL",
        "district": "KILGORE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482562007009",
    },
    {
        "school": "KILGORE INT",
        "district": "KILGORE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482562007010",
    },
    {
        "school": "JUVENILE DETENT CTR",
        "district": "LONGVIEW ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482811001116",
    },
    {
        "school": "FOREST PARK MAGNET SCHOOL",
        "district": "LONGVIEW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811003139",
    },
    {
        "school": "FOSTER MIDDLE",
        "district": "LONGVIEW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811003140",
    },
    {
        "school": "HUDSON EL",
        "district": "LONGVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811003142",
    },
    {
        "school": "LONGVIEW H S",
        "district": "LONGVIEW ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811003146",
    },
    {
        "school": "PINE TREE H S",
        "district": "PINE TREE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483498003932",
    },
    {
        "school": "PINE TREE J H",
        "district": "PINE TREE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483498003934",
    },
    {
        "school": "PINE TREE PRI",
        "district": "PINE TREE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483498003936",
    },
    {
        "school": "PINE TREE MIDDLE",
        "district": "PINE TREE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483498006027",
    },
    {
        "school": "SABINE EL",
        "district": "SABINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483846004281",
    },
    {
        "school": "SABINE H S",
        "district": "SABINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483846004282",
    },
    {
        "school": "SABINE MIDDLE",
        "district": "SABINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483846004283",
    },
    {
        "school": "SPRING HILL INT",
        "district": "SPRING HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484119004708",
    },
    {
        "school": "SPRING HILL H S",
        "district": "SPRING HILL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484119004709",
    },
    {
        "school": "SPRING HILL J H",
        "district": "SPRING HILL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484119005814",
    },
    {
        "school": "SPRING HILL PRI",
        "district": "SPRING HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484119008795",
    },
    {
        "school": "WHITE OAK H S",
        "district": "WHITE OAK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484548005173",
    },
    {
        "school": "WHITE OAK MIDDLE",
        "district": "WHITE OAK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484548005174",
    },
    {
        "school": "WHITE OAK PRI",
        "district": "WHITE OAK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484548006055",
    },
    {
        "school": "WHITE OAK INT",
        "district": "WHITE OAK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484548006056",
    },
    {
        "school": "CHANDLER EL",
        "district": "KILGORE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482562002854",
    },
    {
        "school": "BIG SANDY EL",
        "district": "BIG SANDY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481014000469",
    },
    {
        "school": "BIG SANDY H S",
        "district": "BIG SANDY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481014000470",
    },
    {
        "school": "BIG SANDY J H",
        "district": "BIG SANDY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481014007089",
    },
    {
        "school": "GILMER EL",
        "district": "GILMER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482070002077",
    },
    {
        "school": "GILMER H S",
        "district": "GILMER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482070002078",
    },
    {
        "school": "BRUCE J H",
        "district": "GILMER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482070002080",
    },
    {
        "school": "GILMER INT",
        "district": "GILMER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482070006264",
    },
    {
        "school": "GLADEWATER H S",
        "district": "GLADEWATER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482076002083",
    },
    {
        "school": "HARMONY EL",
        "district": "HARMONY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482256002293",
    },
    {
        "school": "HARMONY H S",
        "district": "HARMONY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482256002294",
    },
    {
        "school": "HARMONY J H",
        "district": "HARMONY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482256006116",
    },
    {
        "school": "HARMONY INTERMEDIATE SCHOOL",
        "district": "HARMONY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482256009082",
    },
    {
        "school": "NEW DIANA H S",
        "district": "NEW DIANA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483246003603",
    },
    {
        "school": "NEW DIANA MIDDLE",
        "district": "NEW DIANA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483246006021",
    },
    {
        "school": "ORE CITY EL",
        "district": "ORE CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483384003769",
    },
    {
        "school": "ORE CITY H S",
        "district": "ORE CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483384003770",
    },
    {
        "school": "ORE CITY MIDDLE",
        "district": "ORE CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483384006024",
    },
    {
        "school": "UNION GROVE EL",
        "district": "UNION GROVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484353004952",
    },
    {
        "school": "UNION GROVE H S",
        "district": "UNION GROVE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484353004953",
    },
    {
        "school": "UNION GROVE J H",
        "district": "UNION GROVE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484353009083",
    },
    {
        "school": "SHARON A RICHARDSON EL",
        "district": "UNION HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484356004954",
    },
    {
        "school": "UNION HILL H S",
        "district": "UNION HILL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484356004955",
    },
    {
        "school": "LUBBOCK-COOPER NORTH EL",
        "district": "LUBBOCK-COOPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481518009330",
    },
    {
        "school": "LUBBOCK CO J J A E P",
        "district": "FRENSHIP ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481983009331",
    },
    {
        "school": "TERRA VISTA MIDDLE",
        "district": "FRENSHIP ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983010945",
    },
    {
        "school": "WILLOW BEND EL",
        "district": "FRENSHIP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983010946",
    },
    {
        "school": "OFF CAMPUS DAEP",
        "district": "IDALOU ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482412009335",
    },
    {
        "school": "LUBBOCK CO J J A E P",
        "district": "IDALOU ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482412010948",
    },
    {
        "school": "CORONADO H S",
        "district": "LUBBOCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010889",
    },
    {
        "school": "ESTACADO H S",
        "district": "LUBBOCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010890",
    },
    {
        "school": "LUBBOCK H S",
        "district": "LUBBOCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010891",
    },
    {
        "school": "MONTEREY H S",
        "district": "LUBBOCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010892",
    },
    {
        "school": "ATKINS MIDDLE",
        "district": "LUBBOCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010894",
    },
    {
        "school": "CAVAZOS MIDDLE",
        "district": "LUBBOCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010895",
    },
    {
        "school": "DUNBAR COLLEGE PREPARATORY ACADEMY",
        "district": "LUBBOCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010896",
    },
    {
        "school": "EVANS MIDDLE",
        "district": "LUBBOCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010897",
    },
    {
        "school": "HUTCHINSON MIDDLE",
        "district": "LUBBOCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010898",
    },
    {
        "school": "IRONS MIDDLE",
        "district": "LUBBOCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010899",
    },
    {
        "school": "MACKENZIE MIDDLE",
        "district": "LUBBOCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010900",
    },
    {
        "school": "SLATON MIDDLE",
        "district": "LUBBOCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010901",
    },
    {
        "school": "SMYLIE WILSON MIDDLE",
        "district": "LUBBOCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010902",
    },
    {
        "school": "BAYLESS EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010906",
    },
    {
        "school": "BEAN EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010907",
    },
    {
        "school": "BROWN EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010910",
    },
    {
        "school": "DUPRE EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010911",
    },
    {
        "school": "GUADALUPE EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010912",
    },
    {
        "school": "HARDWICK EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010913",
    },
    {
        "school": "HARWELL EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010914",
    },
    {
        "school": "HODGES EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010916",
    },
    {
        "school": "HONEY EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010917",
    },
    {
        "school": "JACKSON EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010919",
    },
    {
        "school": "MCWHORTER EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010920",
    },
    {
        "school": "MAEDGEN EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010921",
    },
    {
        "school": "OVERTON EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010925",
    },
    {
        "school": "PARSONS EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010927",
    },
    {
        "school": "RAMIREZ EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010928",
    },
    {
        "school": "RUSH EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010929",
    },
    {
        "school": "SMITH EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010930",
    },
    {
        "school": "STEWART EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010931",
    },
    {
        "school": "WATERS EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010934",
    },
    {
        "school": "WESTER EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010935",
    },
    {
        "school": "WHEELOCK EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010937",
    },
    {
        "school": "WHITESIDE EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010938",
    },
    {
        "school": "WILLIAMS EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010939",
    },
    {
        "school": "WILSON EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010940",
    },
    {
        "school": "WOLFFARTH EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010941",
    },
    {
        "school": "WRIGHT EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850010942",
    },
    {
        "school": "LUBBOCK CO J J A E P",
        "district": "NEW DEAL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483243010943",
    },
    {
        "school": "NEW DEAL DAEP",
        "district": "NEW DEAL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483243010944",
    },
    {
        "school": "LUBBOCK CO YOUTH CTR",
        "district": "ROOSEVELT ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483780009332",
    },
    {
        "school": "DAEP",
        "district": "SHALLOWATER ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483987009334",
    },
    {
        "school": "LUBBOCK CO YOUTH CTR",
        "district": "SHALLOWATER ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483987010947",
    },
    {
        "school": "CROSBYTON EL",
        "district": "CROSBYTON CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000101145",
    },
    {
        "school": "CROSBYTON SECONDARY",
        "district": "CROSBYTON CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000101146",
    },
    {
        "school": "SP ED CO-OP",
        "district": "CROSBYTON CISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480000103621",
    },
    {
        "school": "LORENZO ISD",
        "district": "LORENZO ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482823003160",
    },
    {
        "school": "RALLS EL",
        "district": "RALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483639004083",
    },
    {
        "school": "RALLS H S",
        "district": "RALLS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483639004084",
    },
    {
        "school": "RECOVERY EDUCATION CAMPUS",
        "district": "RALLS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483639006825",
    },
    {
        "school": "RALLS MIDDLE",
        "district": "RALLS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483639006928",
    },
    {
        "school": "RISE ACADEMY",
        "district": "RISE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480014108325",
    },
    {
        "school": "TRIUMPH PUBLIC HIGH SCHOOLS-LUBBOCK",
        "district": "TRIUMPH PUBLIC HIGH SCHOOLS-LUBBOCK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480014208326",
    },
    {
        "school": "LUBBOCK-COOPER H S",
        "district": "LUBBOCK-COOPER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481518001024",
    },
    {
        "school": "LUBBOCK-COOPER MIDDLE",
        "district": "LUBBOCK-COOPER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481518001025",
    },
    {
        "school": "LUBBOCK-COOPER SOUTH EL",
        "district": "LUBBOCK-COOPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481518001026",
    },
    {
        "school": "L C Y C",
        "district": "LUBBOCK-COOPER ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481518008972",
    },
    {
        "school": "FRENSHIP H S",
        "district": "FRENSHIP ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983001945",
    },
    {
        "school": "FRENSHIP MIDDLE",
        "district": "FRENSHIP ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983001946",
    },
    {
        "school": "NORTH RIDGE EL",
        "district": "FRENSHIP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983005720",
    },
    {
        "school": "CRESTVIEW EL",
        "district": "FRENSHIP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983006703",
    },
    {
        "school": "WESTWIND EL",
        "district": "FRENSHIP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983007068",
    },
    {
        "school": "IDALOU EL",
        "district": "IDALOU ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482412002687",
    },
    {
        "school": "IDALOU H S",
        "district": "IDALOU ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482412002688",
    },
    {
        "school": "IDALOU MIDDLE",
        "district": "IDALOU ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482412002689",
    },
    {
        "school": "PRIORITY INTERVENTION ACADEMY",
        "district": "LUBBOCK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482850003208",
    },
    {
        "school": "HOMEBOUND",
        "district": "LUBBOCK ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850005539",
    },
    {
        "school": "MATTHEWS LEARNING CENTER",
        "district": "LUBBOCK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482850007030",
    },
    {
        "school": "LUBBOCK CO J J A E P",
        "district": "LUBBOCK ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482850007677",
    },
    {
        "school": "LUBBOCK CO JUVENILE JUSTICE CTR",
        "district": "LUBBOCK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482850008328",
    },
    {
        "school": "NEW DEAL EL",
        "district": "NEW DEAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483243003600",
    },
    {
        "school": "NEW DEAL H S",
        "district": "NEW DEAL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483243003601",
    },
    {
        "school": "NEW DEAL MIDDLE",
        "district": "NEW DEAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483243006458",
    },
    {
        "school": "ROOSEVELT EL",
        "district": "ROOSEVELT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483780004232",
    },
    {
        "school": "ROOSEVELT H S",
        "district": "ROOSEVELT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483780004233",
    },
    {
        "school": "ROOSEVELT J H",
        "district": "ROOSEVELT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483780007388",
    },
    {
        "school": "SHALLOWATER EL",
        "district": "SHALLOWATER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483987004522",
    },
    {
        "school": "SHALLOWATER H S",
        "district": "SHALLOWATER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483987004523",
    },
    {
        "school": "SHALLOWATER MIDDLE",
        "district": "SHALLOWATER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483987004524",
    },
    {
        "school": "SHALLOWATER INT",
        "district": "SHALLOWATER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483987006788",
    },
    {
        "school": "STEPHEN F AUSTIN PRI",
        "district": "SLATON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484044004578",
    },
    {
        "school": "SLATON H S",
        "district": "SLATON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484044004579",
    },
    {
        "school": "SLATON J H",
        "district": "SLATON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484044004580",
    },
    {
        "school": "CATHELENE THOMAS EL",
        "district": "SLATON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484044004581",
    },
    {
        "school": "LUBBOCK CO J J A E P",
        "district": "SLATON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484044008866",
    },
    {
        "school": "STUBBLEFIELD LRN CTR",
        "district": "ZAVALLA ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484674009579",
    },
    {
        "school": "PINEYWOODS COMMUNITY ACADEMY H S",
        "district": "PINEYWOODS COMMUNITY ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007408093",
    },
    {
        "school": "CENTRAL H S",
        "district": "CENTRAL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481350000846",
    },
    {
        "school": "CENTRAL J H",
        "district": "CENTRAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481350000847",
    },
    {
        "school": "CENTRAL EL",
        "district": "CENTRAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481350005619",
    },
    {
        "school": "STUBBLEFIELD LRN CTR",
        "district": "CENTRAL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481350007164",
    },
    {
        "school": "H G TEMPLE EL",
        "district": "DIBOLL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481704001474",
    },
    {
        "school": "DIBOLL H S",
        "district": "DIBOLL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481704001475",
    },
    {
        "school": "DIBOLL J H",
        "district": "DIBOLL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481704001476",
    },
    {
        "school": "DIBOLL PRI",
        "district": "DIBOLL ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481704006683",
    },
    {
        "school": "STUBBLEFIELD LRN CTR",
        "district": "DIBOLL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481704007503",
    },
    {
        "school": "HUDSON H S",
        "district": "HUDSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482379002631",
    },
    {
        "school": "HUDSON MIDDLE",
        "district": "HUDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482379002632",
    },
    {
        "school": "W H BONNER EL",
        "district": "HUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482379006865",
    },
    {
        "school": "STUBBLEFIELD LRN CTR",
        "district": "HUDSON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482379007162",
    },
    {
        "school": "W F PEAVY PRI",
        "district": "HUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482379008687",
    },
    {
        "school": "PRIDE ALTER SCH",
        "district": "HUNTINGTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482400001969",
    },
    {
        "school": "HUNTINGTON EL",
        "district": "HUNTINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482400002653",
    },
    {
        "school": "HUNTINGTON H S",
        "district": "HUNTINGTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482400002654",
    },
    {
        "school": "HUNTINGTON MIDDLE",
        "district": "HUNTINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482400002655",
    },
    {
        "school": "HUNTINGTON INT",
        "district": "HUNTINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482400006715",
    },
    {
        "school": "JUVENILE DETENT CTR",
        "district": "LUFKIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482855000536",
    },
    {
        "school": "STUBBLEFIELD LRN CTR",
        "district": "LUFKIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482855007163",
    },
    {
        "school": "LUFKIN H S",
        "district": "LUFKIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007762",
    },
    {
        "school": "LUFKIN MIDDLE",
        "district": "LUFKIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007763",
    },
    {
        "school": "ANDERSON EL",
        "district": "LUFKIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007764",
    },
    {
        "school": "BRANDON EL",
        "district": "LUFKIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007765",
    },
    {
        "school": "BROOKHOLLOW EL",
        "district": "LUFKIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007766",
    },
    {
        "school": "COSTON EL",
        "district": "LUFKIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007767",
    },
    {
        "school": "DUNBAR PRI",
        "district": "LUFKIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007768",
    },
    {
        "school": "GARRETT PRI",
        "district": "LUFKIN ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007769",
    },
    {
        "school": "HACKNEY PRI",
        "district": "LUFKIN ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007770",
    },
    {
        "school": "HERTY PRI",
        "district": "LUFKIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007771",
    },
    {
        "school": "KURTH PRI",
        "district": "LUFKIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007772",
    },
    {
        "school": "SLACK EL",
        "district": "LUFKIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007773",
    },
    {
        "school": "TROUT PRI",
        "district": "LUFKIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855007774",
    },
    {
        "school": "SPECIAL SERVICES",
        "district": "LUFKIN ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482855007776",
    },
    {
        "school": "ALTER SCH",
        "district": "LUFKIN ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482855008420",
    },
    {
        "school": "ZAVALLA EL",
        "district": "ZAVALLA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484674005353",
    },
    {
        "school": "ZAVALLA H S",
        "district": "ZAVALLA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484674005354",
    },
    {
        "school": "HALLSVILLE DAEP",
        "district": "HALLSVILLE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482217009289",
    },
    {
        "school": "ELYSIAN FIELDS EL",
        "district": "ELYSIAN FIELDS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481848001733",
    },
    {
        "school": "ELYSIAN FIELDS H S",
        "district": "ELYSIAN FIELDS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481848001734",
    },
    {
        "school": "ELYSIAN FIELDS MIDDLE",
        "district": "ELYSIAN FIELDS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481848001735",
    },
    {
        "school": "HALLSVILLE PRI",
        "district": "HALLSVILLE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482217002226",
    },
    {
        "school": "HALLSVILLE H S",
        "district": "HALLSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482217002227",
    },
    {
        "school": "HALLSVILLE J H",
        "district": "HALLSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482217002229",
    },
    {
        "school": "HALLSVILLE INT",
        "district": "HALLSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482217002230",
    },
    {
        "school": "HALLSVILLE EAST EL",
        "district": "HALLSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482217008278",
    },
    {
        "school": "HARLETON EL",
        "district": "HARLETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482250002273",
    },
    {
        "school": "HARLETON H S",
        "district": "HARLETON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482250002274",
    },
    {
        "school": "HARLETON J H",
        "district": "HARLETON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482250002275",
    },
    {
        "school": "GEORGE WASHINGTON CARVER EL",
        "district": "KARNACK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482511002799",
    },
    {
        "school": "CROCKETT EL",
        "district": "MARSHALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482916003286",
    },
    {
        "school": "MARSHALL H S",
        "district": "MARSHALL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482916003292",
    },
    {
        "school": "MARSHALL J H",
        "district": "MARSHALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482916003293",
    },
    {
        "school": "PRICE T YOUNG EL",
        "district": "MARSHALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482916003294",
    },
    {
        "school": "SAM HOUSTON EL",
        "district": "MARSHALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482916003298",
    },
    {
        "school": "WM B TRAVIS EL",
        "district": "MARSHALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482916003299",
    },
    {
        "school": "MARSHALL ECH CTR",
        "district": "MARSHALL ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482916006750",
    },
    {
        "school": "WASKOM EL",
        "district": "WASKOM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484467005086",
    },
    {
        "school": "WASKOM H S",
        "district": "WASKOM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484467005087",
    },
    {
        "school": "WASKOM MIDDLE",
        "district": "WASKOM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484467005088",
    },
    {
        "school": "EXCELL PROGRAM",
        "district": "WASKOM ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484467007340",
    },
    {
        "school": "HORIZON MONTESSORI II",
        "district": "HORIZON MONTESSORI PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006511509",
    },
    {
        "school": "FRANCISCO BARRIENTES MIDDLE",
        "district": "EDINBURG CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818011432",
    },
    {
        "school": "JUAN DE DIOS SALINAS MIDDLE",
        "district": "LA JOYA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613011374",
    },
    {
        "school": "DR MARIA PALMIRA MENDIOLA EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613011440",
    },
    {
        "school": "EVANGELINA GARZA EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613011458",
    },
    {
        "school": "SGT LEONEL TREVINO EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486011397",
    },
    {
        "school": "CARMEN ANAYA EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486011406",
    },
    {
        "school": "PSJA SOUTHWEST EARLY COLLEGE H S",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486011513",
    },
    {
        "school": "KENNEDY MIDDLE",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486011569",
    },
    {
        "school": "HORIZON MONTESSORI",
        "district": "HORIZON MONTESSORI PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006510814",
    },
    {
        "school": "IDEA COLLEGE PREP",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021111282",
    },
    {
        "school": "LE NOIR EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739009295",
    },
    {
        "school": "DANIEL SINGLETERRY SR",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739009540",
    },
    {
        "school": "DONNA ALTERNATIVE EDUCATION PROGRAM",
        "district": "DONNA ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481739009541",
    },
    {
        "school": "DORA M SAUCEDA MIDDLE",
        "district": "DONNA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739010816",
    },
    {
        "school": "ELOY GARZA SALAZAR EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739010817",
    },
    {
        "school": "JULIAN S ADAME",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739011524",
    },
    {
        "school": "HIDALGO CO J J A E P",
        "district": "EDCOUCH-ELSA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481806009296",
    },
    {
        "school": "CARMEN V AVILA EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818009538",
    },
    {
        "school": "ANNE L MAGEE EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818009558",
    },
    {
        "school": "DR THOMAS ESPARZA EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818009567",
    },
    {
        "school": "HIDALGO J J A E P",
        "district": "HIDALGO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482310010818",
    },
    {
        "school": "HIDALGO PARK EL",
        "district": "HIDALGO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482310010819",
    },
    {
        "school": "J J A E P",
        "district": "LA JOYA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482613009304",
    },
    {
        "school": "LA JOYA PALMVIEW H S",
        "district": "LA JOYA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613009305",
    },
    {
        "school": "SAM FORDYCE EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613009306",
    },
    {
        "school": "IRENE M GARCIA MIDDLE",
        "district": "LA JOYA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613009577",
    },
    {
        "school": "HOPE ACADEMY",
        "district": "LA JOYA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482613009585",
    },
    {
        "school": "EMILIANO ZAPATA EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613009623",
    },
    {
        "school": "JIMMY CARTER EARLY COLLEGE H S",
        "district": "LA JOYA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613010825",
    },
    {
        "school": "DR JAVIER SAENZ MIDDLE",
        "district": "LA JOYA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613010826",
    },
    {
        "school": "JUAN SEGUIN EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613010828",
    },
    {
        "school": "ENRIQUE KIKI CAMARENA EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613010829",
    },
    {
        "school": "DR AMERICO PAREDES EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613010830",
    },
    {
        "school": "WILLIAM J CLINTON EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613010831",
    },
    {
        "school": "CORINA PENA EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613010832",
    },
    {
        "school": "LA VILLA J J A E P H S",
        "district": "LA VILLA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482634010833",
    },
    {
        "school": "LUCILE HENDRICKS EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967011407",
    },
    {
        "school": "DR PABLO PEREZ",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967011450",
    },
    {
        "school": "BLANCA E SANCHEZ",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967011472",
    },
    {
        "school": "MICHAEL E FOSSUM MIDDLE",
        "district": "MCALLEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967011515",
    },
    {
        "school": "RUBEN HINOJOSA EL",
        "district": "MERCEDES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483025009298",
    },
    {
        "school": "SGT WILLIAM G HARRELL MIDDLE",
        "district": "MERCEDES ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483025010820",
    },
    {
        "school": "HURLA M MIDKIFF EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104009483",
    },
    {
        "school": "RAQUEL CAVAZOS EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104009485",
    },
    {
        "school": "ALTON MEMORIAL J H",
        "district": "MISSION CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104009505",
    },
    {
        "school": "HIDALGO CO J J A E P",
        "district": "MISSION CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483104009510",
    },
    {
        "school": "HILDA C ESCOBAR/ALICIA C RIOS EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104011386",
    },
    {
        "school": "RAFAEL A CANTU J H",
        "district": "MISSION CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104011388",
    },
    {
        "school": "HIDALGO CO J J A E P",
        "district": "MONTE ALTO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483123010834",
    },
    {
        "school": "DR WILLIAM LONG EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486009299",
    },
    {
        "school": "VIDA N CLOVER EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486009300",
    },
    {
        "school": "AUGUSTO GUERRA EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486009301",
    },
    {
        "school": "GRACIELA GARCIA EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486009302",
    },
    {
        "school": "HIDALGO CO J J A E P",
        "district": "PROGRESO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483591010821",
    },
    {
        "school": "RUBEN HINOJOSA EL",
        "district": "SHARYLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993009591",
    },
    {
        "school": "HIDALGO COUNTY J J A E P",
        "district": "SHARYLAND ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483993009598",
    },
    {
        "school": "SHARYLAND NORTH J H",
        "district": "SHARYLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993010823",
    },
    {
        "school": "LLOYD & DOLLY BENTSEN EL",
        "district": "SHARYLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993010824",
    },
    {
        "school": "DONNA WERNECKE EL",
        "district": "SHARYLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993011430",
    },
    {
        "school": "HARRY SHIMOTSU EL",
        "district": "SHARYLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993011522",
    },
    {
        "school": "WILBUR E LUCAS EL",
        "district": "VALLEY VIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484380009308",
    },
    {
        "school": "VALLEY VIEW J J A E P",
        "district": "VALLEY VIEW ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484380010836",
    },
    {
        "school": "BEATRIZ G GARZA MIDDLE",
        "district": "WESLACO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496009307",
    },
    {
        "school": "HORTON DISCIPLINARY ALTERNATIVE EDUCATION PROGRAM",
        "district": "WESLACO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484496009634",
    },
    {
        "school": "VANGUARD REMBRANDT",
        "district": "VANGUARD ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480019508649",
    },
    {
        "school": "A M OCHOA EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739001496",
    },
    {
        "school": "DONNA H S",
        "district": "DONNA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739001497",
    },
    {
        "school": "RUNN EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739001501",
    },
    {
        "school": "C STAINKE EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739001502",
    },
    {
        "school": "J W CACERES EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739006244",
    },
    {
        "school": "GUZMAN EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739006847",
    },
    {
        "school": "CAPT D SALINAS II EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739007038",
    },
    {
        "school": "T PRICE EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739007347",
    },
    {
        "school": "HIDALGO CO J J A E P",
        "district": "DONNA ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481739007961",
    },
    {
        "school": "PATRICIA S GARZA EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739008283",
    },
    {
        "school": "MARIA ALICIA P MUNOZ EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739008284",
    },
    {
        "school": "VETERANS MIDDLE",
        "district": "DONNA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739008842",
    },
    {
        "school": "M RIVAS EL",
        "district": "DONNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739021341",
    },
    {
        "school": "SANTIAGO GARCIA EL",
        "district": "EDCOUCH-ELSA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481806001601",
    },
    {
        "school": "EDCOUCH-ELSA H S",
        "district": "EDCOUCH-ELSA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481806001602",
    },
    {
        "school": "KENNEDY EL",
        "district": "EDCOUCH-ELSA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481806001603",
    },
    {
        "school": "CARLOS TRUAN J H",
        "district": "EDCOUCH-ELSA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481806005980",
    },
    {
        "school": "RUBEN C RODRIGUEZ EL",
        "district": "EDCOUCH-ELSA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481806006098",
    },
    {
        "school": "L B J EL",
        "district": "EDCOUCH-ELSA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481806006690",
    },
    {
        "school": "JORGE R GUTIERREZ EARLY CHILDHOOD CENTER",
        "district": "EDCOUCH-ELSA ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481806008651",
    },
    {
        "school": "ESCANDON EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818001500",
    },
    {
        "school": "AUSTIN ELEM",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818001635",
    },
    {
        "school": "BREWSTER EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818001636",
    },
    {
        "school": "EDINBURG H S",
        "district": "EDINBURG CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818001637",
    },
    {
        "school": "FREDDY GONZALEZ EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818001640",
    },
    {
        "school": "HARGILL EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818001641",
    },
    {
        "school": "JEFFERSON ELEM",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818001643",
    },
    {
        "school": "LEE EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818001645",
    },
    {
        "school": "TRAVIS EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818001648",
    },
    {
        "school": "L B JOHNSON EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818005462",
    },
    {
        "school": "SOUTH MIDDLE",
        "district": "EDINBURG CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818006102",
    },
    {
        "school": "DE LA VINA ELEM",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818006103",
    },
    {
        "school": "SAN CARLOS EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818006249",
    },
    {
        "school": "JUVENILE DETENTION CTR",
        "district": "EDINBURG CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481818006693",
    },
    {
        "school": "ZAVALA EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818006695",
    },
    {
        "school": "CANTERBURY EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818006850",
    },
    {
        "school": "MEMORIAL MIDDLE",
        "district": "EDINBURG CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818007350",
    },
    {
        "school": "TRUMAN EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818007351",
    },
    {
        "school": "EISENHOWER EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818007352",
    },
    {
        "school": "JOHN F KENNEDY EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818007353",
    },
    {
        "school": "CANO-GONZALEZ EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818007354",
    },
    {
        "school": "CAVAZOS EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818007355",
    },
    {
        "school": "J J A E P",
        "district": "EDINBURG CISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481818007651",
    },
    {
        "school": "LINCOLN EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818007962",
    },
    {
        "school": "B L GARZA MIDDLE",
        "district": "EDINBURG CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818008285",
    },
    {
        "school": "BETTS EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818008286",
    },
    {
        "school": "TREVINO EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818008287",
    },
    {
        "school": "GUERRA EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818008288",
    },
    {
        "school": "VILLARREAL EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818008289",
    },
    {
        "school": "EDINBURG ALTERNATIVE EDUCATION ACADEMY",
        "district": "EDINBURG CISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481818008652",
    },
    {
        "school": "ECONOMEDES H S",
        "district": "EDINBURG CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818008843",
    },
    {
        "school": "MONTE CRISTO EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818021040",
    },
    {
        "school": "EDINBURG NORTH H S",
        "district": "EDINBURG CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818021343",
    },
    {
        "school": "HIDALGO EL",
        "district": "HIDALGO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482310002346",
    },
    {
        "school": "HIDALGO EARLY COLLEGE H S",
        "district": "HIDALGO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482310002347",
    },
    {
        "school": "DIAZ J H",
        "district": "HIDALGO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482310005488",
    },
    {
        "school": "JC KELLY EL",
        "district": "HIDALGO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482310005743",
    },
    {
        "school": "DR ALEJO SALINAS JR EL",
        "district": "HIDALGO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482310008290",
    },
    {
        "school": "JOHN F KENNEDY EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613002935",
    },
    {
        "school": "LA JOYA H S",
        "district": "LA JOYA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613002936",
    },
    {
        "school": "LORENZO DE ZAVALA MIDDLE",
        "district": "LA JOYA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613002938",
    },
    {
        "school": "ELODIA R CHAPA EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613004779",
    },
    {
        "school": "JOSE DE ESCANDON EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613004781",
    },
    {
        "school": "GUILLERMO FLORES EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613005528",
    },
    {
        "school": "ROSENDO BENAVIDES EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613005881",
    },
    {
        "school": "LEO J LEO EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613006008",
    },
    {
        "school": "ELIGIO KIKA DE LA GARZA EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613006284",
    },
    {
        "school": "CESAR CHAVEZ MIDDLE",
        "district": "LA JOYA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613006737",
    },
    {
        "school": "E B REYNA EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613006875",
    },
    {
        "school": "JUAREZ-LINCOLN H S",
        "district": "LA JOYA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613007045",
    },
    {
        "school": "DIAZ-VILLARREAL EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613007356",
    },
    {
        "school": "NARCISO CAVAZOS",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613007655",
    },
    {
        "school": "TABASCO EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613007656",
    },
    {
        "school": "PATRICIO PEREZ EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613007967",
    },
    {
        "school": "ANN RICHARDS MIDDLE",
        "district": "LA JOYA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613008294",
    },
    {
        "school": "HENRY B GONZALEZ EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613008295",
    },
    {
        "school": "LLOYD M BENTSEN EL",
        "district": "LA JOYA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613008658",
    },
    {
        "school": "JOSE BERNABE MUNOZ EL",
        "district": "LA VILLA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482634002969",
    },
    {
        "school": "LA VILLA EARLY COLLEGE H S",
        "district": "LA VILLA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482634006130",
    },
    {
        "school": "LA VILLA MIDDLE",
        "district": "LA VILLA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482634021358",
    },
    {
        "school": "ALVAREZ EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967003326",
    },
    {
        "school": "BONHAM EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967003329",
    },
    {
        "school": "BROWN MIDDLE",
        "district": "MCALLEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967003331",
    },
    {
        "school": "FIELDS EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967003334",
    },
    {
        "school": "HOUSTON EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967003335",
    },
    {
        "school": "JACKSON EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967003336",
    },
    {
        "school": "MCALLEN H S",
        "district": "MCALLEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967003339",
    },
    {
        "school": "MILAM EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967003340",
    },
    {
        "school": "SEGUIN EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967003341",
    },
    {
        "school": "TRAVIS MIDDLE",
        "district": "MCALLEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967003343",
    },
    {
        "school": "WILSON EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967003344",
    },
    {
        "school": "ESCANDON EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967005547",
    },
    {
        "school": "MEMORIAL H S",
        "district": "MCALLEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967005548",
    },
    {
        "school": "ROOSEVELT EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967005549",
    },
    {
        "school": "RAYBURN EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967005550",
    },
    {
        "school": "GARZA EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967005897",
    },
    {
        "school": "MORRIS MIDDLE",
        "district": "MCALLEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967006142",
    },
    {
        "school": "MCAULIFFE EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967006298",
    },
    {
        "school": "INSTR/GUID CENTER",
        "district": "MCALLEN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482967006752",
    },
    {
        "school": "SOUTHWEST KEY PROGRAM",
        "district": "MCALLEN ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482967007652",
    },
    {
        "school": "CASTANEDA EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967008654",
    },
    {
        "school": "CATHEY MIDDLE",
        "district": "MCALLEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967008845",
    },
    {
        "school": "ROWE H S",
        "district": "MCALLEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967021345",
    },
    {
        "school": "LAMAR ACADEMY",
        "district": "MCALLEN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482967021346",
    },
    {
        "school": "DE LEON MIDDLE",
        "district": "MCALLEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967021347",
    },
    {
        "school": "GONZALEZ EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967021348",
    },
    {
        "school": "MERCEDES H S",
        "district": "MERCEDES ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483025003388",
    },
    {
        "school": "SGT MANUEL CHACON MIDDLE",
        "district": "MERCEDES ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483025003389",
    },
    {
        "school": "TAYLOR EL",
        "district": "MERCEDES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483025003390",
    },
    {
        "school": "TRAVIS EL",
        "district": "MERCEDES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483025003391",
    },
    {
        "school": "MERCEDES ACADEMIC ACADEMY",
        "district": "MERCEDES ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483025006996",
    },
    {
        "school": "JJAEP-SOUTHWEST KEY PROGRAM",
        "district": "MERCEDES ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483025008655",
    },
    {
        "school": "MERCEDES DAEP",
        "district": "MERCEDES ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483025008846",
    },
    {
        "school": "CARL C WAITZ EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104001509",
    },
    {
        "school": "ALTON EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104003492",
    },
    {
        "school": "BRYAN EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104003493",
    },
    {
        "school": "CASTRO EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104003494",
    },
    {
        "school": "MARCELL EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104003495",
    },
    {
        "school": "MISSION H S",
        "district": "MISSION CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104003496",
    },
    {
        "school": "MISSION J H",
        "district": "MISSION CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104003497",
    },
    {
        "school": "PEARSON EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104003498",
    },
    {
        "school": "CANTU EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104005901",
    },
    {
        "school": "LEAL EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104006017",
    },
    {
        "school": "MIMS EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104006146",
    },
    {
        "school": "OLLIE O'GRADY EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104006456",
    },
    {
        "school": "WHITE J H",
        "district": "MISSION CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104006760",
    },
    {
        "school": "VETERANS MEMORIAL H S",
        "district": "MISSION CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104006997",
    },
    {
        "school": "SALINAS EL",
        "district": "MISSION CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104007963",
    },
    {
        "school": "ROOSEVELT ALTERNATIVE SCHOOL",
        "district": "MISSION CISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483104008657",
    },
    {
        "school": "MONTE ALTO EL",
        "district": "MONTE ALTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483123003511",
    },
    {
        "school": "JOSE BORREGO MIDDLE",
        "district": "MONTE ALTO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483123007357",
    },
    {
        "school": "AUSTIN MIDDLE",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486003908",
    },
    {
        "school": "JOHN MCKEEVER EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486003909",
    },
    {
        "school": "JOHN DOEDYNS EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486003914",
    },
    {
        "school": "HENRY FORD EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486003915",
    },
    {
        "school": "GERALDINE PALMER EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486003917",
    },
    {
        "school": "LYNDON B JOHNSON MIDDLE",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486003919",
    },
    {
        "school": "PSJA EARLY COLLEGE H S",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486003921",
    },
    {
        "school": "RAUL LONGORIA EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486003922",
    },
    {
        "school": "ALFRED SORENSEN EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486003923",
    },
    {
        "school": "AIDA C ESCOBAR EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486003924",
    },
    {
        "school": "ZEFERINO FARIAS EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486003925",
    },
    {
        "school": "ARNOLDO CANTU SR EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486004738",
    },
    {
        "school": "DANIEL RAMIREZ EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486005795",
    },
    {
        "school": "AMANDA GARZA-PENA EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486006159",
    },
    {
        "school": "ALAMO MIDDLE",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486006597",
    },
    {
        "school": "KELLY-PHARR EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486006598",
    },
    {
        "school": "EDITH & ETHEL CARMAN EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486006599",
    },
    {
        "school": "PSJA NORTH EARLY COLLEGE H S",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486006896",
    },
    {
        "school": "SANTOS LIVAS EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486006998",
    },
    {
        "school": "ELVIS J BALLEW H S",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483486007041",
    },
    {
        "school": "PSJA MEMORIAL EARLY COLLEGE H S",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486007653",
    },
    {
        "school": "STUDENT ALTER PROG",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483486007964",
    },
    {
        "school": "DRS REED - MOCK EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486007965",
    },
    {
        "school": "CESAR CHAVEZ EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486008293",
    },
    {
        "school": "R YZAGUIRRE MIDDLE",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486008847",
    },
    {
        "school": "PSJA SONIA M SOTOMAYOR H S",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483486021041",
    },
    {
        "school": "LIBERTY MIDDLE",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486021042",
    },
    {
        "school": "PROGRESO H S",
        "district": "PROGRESO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483591006032",
    },
    {
        "school": "DOROTHY THOMPSON MIDDLE",
        "district": "PROGRESO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483591006163",
    },
    {
        "school": "PROGRESO EARLY CHILDHOOD",
        "district": "PROGRESO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483591021352",
    },
    {
        "school": "JOHN H SHARY EL",
        "district": "SHARYLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993004528",
    },
    {
        "school": "SHARYLAND H S",
        "district": "SHARYLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993004529",
    },
    {
        "school": "B L GRAY J H",
        "district": "SHARYLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993004530",
    },
    {
        "school": "OLIVERO GARZA SR EL",
        "district": "SHARYLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993006039",
    },
    {
        "school": "JESSIE L JENSEN EL",
        "district": "SHARYLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993007043",
    },
    {
        "school": "ROMULO D MARTINEZ EL",
        "district": "SHARYLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993008850",
    },
    {
        "school": "VALLEY VIEW EARLY COLLEGE CAMPUS",
        "district": "VALLEY VIEW ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484380006181",
    },
    {
        "school": "VALLEY VIEW EL",
        "district": "VALLEY VIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484380006795",
    },
    {
        "school": "VALLEY VIEW NORTH EL",
        "district": "VALLEY VIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484380007969",
    },
    {
        "school": "VALLEY VIEW H S",
        "district": "VALLEY VIEW ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484380021360",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "WESLACO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496001568",
    },
    {
        "school": "SOUTH PALM GARDENS H S",
        "district": "WESLACO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484496004795",
    },
    {
        "school": "F D ROOSEVELT EL",
        "district": "WESLACO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496005119",
    },
    {
        "school": "SAM HOUSTON EL",
        "district": "WESLACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496005122",
    },
    {
        "school": "RAUL A GONZALEZ JR EL",
        "district": "WESLACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496005124",
    },
    {
        "school": "WESLACO H S",
        "district": "WESLACO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496005125",
    },
    {
        "school": "DR R E MARGO EL",
        "district": "WESLACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496006054",
    },
    {
        "school": "RODOLFO RUDY SILVA JR EL",
        "district": "WESLACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496006186",
    },
    {
        "school": "AIRPORT EL",
        "district": "WESLACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496006626",
    },
    {
        "school": "MEMORIAL EL",
        "district": "WESLACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496006627",
    },
    {
        "school": "A N RICO EL",
        "district": "WESLACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496007002",
    },
    {
        "school": "CLECKLER/HEALD EL",
        "district": "WESLACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496007003",
    },
    {
        "school": "HIDALGO CO J J A E P",
        "district": "WESLACO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484496007968",
    },
    {
        "school": "HIDALGO COUNTY BOOT CAMP",
        "district": "WESLACO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484496008660",
    },
    {
        "school": "WESLACO EAST H S",
        "district": "WESLACO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496008851",
    },
    {
        "school": "MARY HOGE MIDDLE",
        "district": "WESLACO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496008852",
    },
    {
        "school": "ARMANDO CUELLAR MIDDLE",
        "district": "WESLACO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496021356",
    },
    {
        "school": "NORTH BRIDGE EL",
        "district": "WESLACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496021357",
    },
    {
        "school": "MIDLAND ACADEMY CHARTER SCHOOL",
        "district": "MIDLAND ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480014808336",
    },
    {
        "school": "GREENWOOD H S",
        "district": "GREENWOOD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482175002195",
    },
    {
        "school": "GREENWOOD EL",
        "district": "GREENWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482175006558",
    },
    {
        "school": "JAMES R BROOKS MIDDLE",
        "district": "GREENWOOD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482175007697",
    },
    {
        "school": "ALAMO J H",
        "district": "MIDLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003430",
    },
    {
        "school": "LEE FRESHMAN H S",
        "district": "MIDLAND ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003431",
    },
    {
        "school": "BONHAM EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003432",
    },
    {
        "school": "BURNET EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003434",
    },
    {
        "school": "DE ZAVALA EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003436",
    },
    {
        "school": "MIDLAND FRESHMAN H S",
        "district": "MIDLAND ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003437",
    },
    {
        "school": "EMERSON EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003438",
    },
    {
        "school": "FANNIN EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003439",
    },
    {
        "school": "GODDARD J H",
        "district": "MIDLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003440",
    },
    {
        "school": "HENDERSON EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003441",
    },
    {
        "school": "SAM HOUSTON COLLEGIATE PREPARATORY EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003442",
    },
    {
        "school": "JONES EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003443",
    },
    {
        "school": "LAMAR EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003444",
    },
    {
        "school": "LEE H S",
        "district": "MIDLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003445",
    },
    {
        "school": "LONG EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003446",
    },
    {
        "school": "MIDLAND H S",
        "district": "MIDLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003447",
    },
    {
        "school": "MILAM EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003448",
    },
    {
        "school": "RUSK EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003450",
    },
    {
        "school": "SAN JACINTO J H",
        "district": "MIDLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003451",
    },
    {
        "school": "SOUTH EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003452",
    },
    {
        "school": "TRAVIS EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057003453",
    },
    {
        "school": "ABELL J H",
        "district": "MIDLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057005118",
    },
    {
        "school": "GREATHOUSE EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057005121",
    },
    {
        "school": "PARKER EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057005899",
    },
    {
        "school": "SANTA RITA EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057005900",
    },
    {
        "school": "SCHARBAUER EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057006145",
    },
    {
        "school": "VIOLA M COLEMAN H S",
        "district": "MIDLAND ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483057006756",
    },
    {
        "school": "BUSH EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057006757",
    },
    {
        "school": "CARVER CENTER",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057008987",
    },
    {
        "school": "WASHINGTON STEM ACADEMY",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057008988",
    },
    {
        "school": "PEASE COMMUNICATIONS/TECHNOLOGY ACADEMY",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057008989",
    },
    {
        "school": "GORDON SCHOOL",
        "district": "GORDON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482118002125",
    },
    {
        "school": "GRAFORD SCHOOL",
        "district": "GRAFORD ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482133002133",
    },
    {
        "school": "MINERAL WELLS H S",
        "district": "MINERAL WELLS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483095003487",
    },
    {
        "school": "MINERAL WELLS J H",
        "district": "MINERAL WELLS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483095003488",
    },
    {
        "school": "MINERAL WELLS EL",
        "district": "MINERAL WELLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483095003489",
    },
    {
        "school": "MINERAL WELLS ACADEMY",
        "district": "MINERAL WELLS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483095008348",
    },
    {
        "school": "PALO PINTO EL",
        "district": "PALO PINTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483414003795",
    },
    {
        "school": "SANTO EL",
        "district": "SANTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483939004481",
    },
    {
        "school": "SANTO H S",
        "district": "SANTO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483939004482",
    },
    {
        "school": "STRAWN SCHOOL",
        "district": "STRAWN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484170004759",
    },
    {
        "school": "MOUNT PLEASANT DAEP",
        "district": "MOUNT PLEASANT ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483176009399",
    },
    {
        "school": "CHAPEL HILL EL",
        "district": "CHAPEL HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481368000861",
    },
    {
        "school": "CHAPEL HILL H S",
        "district": "CHAPEL HILL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481368007126",
    },
    {
        "school": "CHAPEL HILL J H",
        "district": "CHAPEL HILL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481368007452",
    },
    {
        "school": "HARTS BLUFF EL",
        "district": "HARTS BLUFF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482271002303",
    },
    {
        "school": "E C BRICE EL",
        "district": "MOUNT PLEASANT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483176003532",
    },
    {
        "school": "FRANCES CORPREW EL",
        "district": "MOUNT PLEASANT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483176003533",
    },
    {
        "school": "MOUNT PLEASANT H S",
        "district": "MOUNT PLEASANT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483176003535",
    },
    {
        "school": "ANNIE SIMS EL",
        "district": "MOUNT PLEASANT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483176003536",
    },
    {
        "school": "VIVIAN FOWLER EL",
        "district": "MOUNT PLEASANT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483176003537",
    },
    {
        "school": "MOUNT PLEASANT J H",
        "district": "MOUNT PLEASANT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483176003538",
    },
    {
        "school": "P E WALLACE MIDDLE",
        "district": "MOUNT PLEASANT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483176007736",
    },
    {
        "school": "NACOGDOCHES CO ALTER ED COOP",
        "district": "CHIRENO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481398010973",
    },
    {
        "school": "MIKE MOSES MIDDLE",
        "district": "NACOGDOCHES ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483209010974",
    },
    {
        "school": "MCMICHAEL MIDDLE",
        "district": "NACOGDOCHES ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483209010975",
    },
    {
        "school": "THOMAS J RUSK EL",
        "district": "NACOGDOCHES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483209010976",
    },
    {
        "school": "CENTRAL HEIGHTS H S",
        "district": "CENTRAL HEIGHTS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481344000844",
    },
    {
        "school": "CENTRAL HEIGHTS EL",
        "district": "CENTRAL HEIGHTS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481344007049",
    },
    {
        "school": "CHIRENO EL",
        "district": "CHIRENO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481398000883",
    },
    {
        "school": "CHIRENO H S",
        "district": "CHIRENO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481398000884",
    },
    {
        "school": "CUSHING SCHOOL",
        "district": "CUSHING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481608001176",
    },
    {
        "school": "CUSHING EL",
        "district": "CUSHING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481608007701",
    },
    {
        "school": "DOUGLASS SCHOOL",
        "district": "DOUGLASS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481746001506",
    },
    {
        "school": "ETOILE EL",
        "district": "ETOILE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481866001747",
    },
    {
        "school": "GARRISON EL",
        "district": "GARRISON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482040002055",
    },
    {
        "school": "GARRISON H S",
        "district": "GARRISON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482040002056",
    },
    {
        "school": "GARRISON MIDDLE",
        "district": "GARRISON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482040007702",
    },
    {
        "school": "MARTINSVILLE SCHOOL",
        "district": "MARTINSVILLE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482925003305",
    },
    {
        "school": "EMELINE CARPENTER EL",
        "district": "NACOGDOCHES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483209003557",
    },
    {
        "school": "FREDONIA EL",
        "district": "NACOGDOCHES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483209003558",
    },
    {
        "school": "BROOKS-QUINN-JONES EL",
        "district": "NACOGDOCHES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483209003559",
    },
    {
        "school": "NETTIE MARSHALL ACADEMY OF DUAL LANGUAGE",
        "district": "NACOGDOCHES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483209003560",
    },
    {
        "school": "NACOGDOCHES H S",
        "district": "NACOGDOCHES ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483209003561",
    },
    {
        "school": "RAGUET EL",
        "district": "NACOGDOCHES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483209003562",
    },
    {
        "school": "NACOGDOCHES CO ALTER ED COOP",
        "district": "NACOGDOCHES ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483209009000",
    },
    {
        "school": "WODEN EL",
        "district": "WODEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484632005277",
    },
    {
        "school": "WODEN H S",
        "district": "WODEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484632005278",
    },
    {
        "school": "WODEN J H",
        "district": "WODEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484632006342",
    },
    {
        "school": "CARVER EARLY EE-KG",
        "district": "ECTOR COUNTY ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800000714",
    },
    {
        "school": "GALE POND ALAMO EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001566",
    },
    {
        "school": "AUSTIN MONTESSORI MAGNET",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001567",
    },
    {
        "school": "BONHAM MIDDLE",
        "district": "ECTOR COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001569",
    },
    {
        "school": "BOWIE MIDDLE",
        "district": "ECTOR COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001570",
    },
    {
        "school": "BURLESON EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001571",
    },
    {
        "school": "BURNET EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001572",
    },
    {
        "school": "CAMERON DUAL LANGUAGE MAGNET",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001573",
    },
    {
        "school": "CROCKETT MIDDLE",
        "district": "ECTOR COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001574",
    },
    {
        "school": "DOWLING EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001575",
    },
    {
        "school": "GOLIAD EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001579",
    },
    {
        "school": "GONZALES EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001580",
    },
    {
        "school": "EL MAGNET AT HAYS",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001581",
    },
    {
        "school": "WILSON & YOUNG MEDAL OF HONOR MIDDLE",
        "district": "ECTOR COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001582",
    },
    {
        "school": "IRELAND EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001583",
    },
    {
        "school": "LAMAR EARLY EE-KG",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001584",
    },
    {
        "school": "EL MAGNET AT MILAM EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001585",
    },
    {
        "school": "NIMITZ MIDDLE",
        "district": "ECTOR COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001586",
    },
    {
        "school": "ODESSA H S",
        "district": "ECTOR COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001587",
    },
    {
        "school": "PEASE EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001588",
    },
    {
        "school": "PERMIAN H S",
        "district": "ECTOR COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001589",
    },
    {
        "school": "EL MAGNET AT REAGAN EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001590",
    },
    {
        "school": "ROSS EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001591",
    },
    {
        "school": "SAM HOUSTON EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001593",
    },
    {
        "school": "SAN JACINTO EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001594",
    },
    {
        "school": "EL MAGNET AT TRAVIS",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001595",
    },
    {
        "school": "ALTER ED CTR",
        "district": "ECTOR COUNTY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481800001596",
    },
    {
        "school": "EL MAGNET AT ZAVALA",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800001597",
    },
    {
        "school": "NOEL EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800005458",
    },
    {
        "school": "BLANTON EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800005702",
    },
    {
        "school": "ECTOR COLLEGE PREP SUCCESS ACADEMY",
        "district": "ECTOR COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800005704",
    },
    {
        "school": "MURRY FLY EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800005705",
    },
    {
        "school": "EL MAGNET AT BLACKSHEAR",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800005866",
    },
    {
        "school": "L B JOHNSON EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800006687",
    },
    {
        "school": "BARBARA JORDAN EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800006688",
    },
    {
        "school": "LAURO CAVAZOS EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800006689",
    },
    {
        "school": "REG DAY SCHOOL FOR DEAF",
        "district": "ECTOR COUNTY ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800008538",
    },
    {
        "school": "ELKHART DAEP",
        "district": "ELKHART ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481839010386",
    },
    {
        "school": "CAYUGA EL",
        "district": "CAYUGA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481320000820",
    },
    {
        "school": "CAYUGA H S",
        "district": "CAYUGA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481320000821",
    },
    {
        "school": "CAYUGA MIDDLE",
        "district": "CAYUGA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481320005623",
    },
    {
        "school": "ELKHART EL",
        "district": "ELKHART ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481839001731",
    },
    {
        "school": "ELKHART H S",
        "district": "ELKHART ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481839001732",
    },
    {
        "school": "ELKHART MIDDLE",
        "district": "ELKHART ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481839007161",
    },
    {
        "school": "FRANKSTON MIDDLE",
        "district": "FRANKSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481977000019",
    },
    {
        "school": "FRANKSTON H S",
        "district": "FRANKSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481977001939",
    },
    {
        "school": "FRANKSTON EL",
        "district": "FRANKSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481977006702",
    },
    {
        "school": "NECHES EL",
        "district": "NECHES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483225003574",
    },
    {
        "school": "NECHES H S",
        "district": "NECHES ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483225003575",
    },
    {
        "school": "PALESTINE J H",
        "district": "PALESTINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483405003784",
    },
    {
        "school": "NORTHSIDE PRI",
        "district": "PALESTINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483405003787",
    },
    {
        "school": "PALESTINE H S",
        "district": "PALESTINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483405003788",
    },
    {
        "school": "SOUTHSIDE EL",
        "district": "PALESTINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483405003790",
    },
    {
        "school": "STORY INT",
        "district": "PALESTINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483405005566",
    },
    {
        "school": "SLOCUM H S",
        "district": "SLOCUM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484050004585",
    },
    {
        "school": "SLOCUM PK - 8",
        "district": "SLOCUM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484050005640",
    },
    {
        "school": "WESTWOOD EL",
        "district": "WESTWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484329004914",
    },
    {
        "school": "WESTWOOD H S",
        "district": "WESTWOOD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484329004915",
    },
    {
        "school": "WESTWOOD J H",
        "district": "WESTWOOD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484329004916",
    },
    {
        "school": "WESTWOOD PRI",
        "district": "WESTWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484329005606",
    },
    {
        "school": "LEFORS SCHOOL",
        "district": "LEFORS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482709003047",
    },
    {
        "school": "MCLEAN SCHOOL",
        "district": "MCLEAN ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482988003364",
    },
    {
        "school": "AUSTIN EL",
        "district": "PAMPA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483417003796",
    },
    {
        "school": "LAMAR EL",
        "district": "PAMPA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483417003798",
    },
    {
        "school": "PAMPA H S",
        "district": "PAMPA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483417003800",
    },
    {
        "school": "PAMPA J H",
        "district": "PAMPA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483417003801",
    },
    {
        "school": "TRAVIS EL",
        "district": "PAMPA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483417003802",
    },
    {
        "school": "WILSON EL",
        "district": "PAMPA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483417003803",
    },
    {
        "school": "MIAMI SCHOOL",
        "district": "MIAMI ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483048003429",
    },
    {
        "school": "PRAIRILAND J H",
        "district": "PRAIRILAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483574010875",
    },
    {
        "school": "CHISUM EL",
        "district": "CHISUM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001201430",
    },
    {
        "school": "CHISUM H S",
        "district": "CHISUM ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001201431",
    },
    {
        "school": "CHISUM MIDDLE",
        "district": "CHISUM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001204908",
    },
    {
        "school": "AARON PARKER EL",
        "district": "NORTH LAMAR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483301003665",
    },
    {
        "school": "CECIL EVERETT EL",
        "district": "NORTH LAMAR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483301003666",
    },
    {
        "school": "NORTH LAMAR H S",
        "district": "NORTH LAMAR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483301003667",
    },
    {
        "school": "FRANK STONE MIDDLE",
        "district": "NORTH LAMAR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483301003668",
    },
    {
        "school": "W L HIGGINS EL",
        "district": "NORTH LAMAR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483301006768",
    },
    {
        "school": "BAILEY INT",
        "district": "NORTH LAMAR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483301007671",
    },
    {
        "school": "LAMAR DELTA ALTER",
        "district": "NORTH LAMAR ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483301008965",
    },
    {
        "school": "GIVENS EARLY CHILDHOOD CENTER",
        "district": "PARIS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483429003813",
    },
    {
        "school": "JUSTISS EL",
        "district": "PARIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483429003814",
    },
    {
        "school": "PARIS H S",
        "district": "PARIS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483429003815",
    },
    {
        "school": "PARIS J H",
        "district": "PARIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483429003816",
    },
    {
        "school": "AIKIN EL",
        "district": "PARIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483429005567",
    },
    {
        "school": "LAMAR COUNTY HEAD START",
        "district": "PARIS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483429008317",
    },
    {
        "school": "BLOSSOM EL",
        "district": "PRAIRILAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483574004045",
    },
    {
        "school": "DEPORT EL",
        "district": "PRAIRILAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483574004047",
    },
    {
        "school": "PRAIRILAND H S",
        "district": "PRAIRILAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483574004048",
    },
    {
        "school": "BALMORHEA SCHOOL",
        "district": "BALMORHEA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480933000392",
    },
    {
        "school": "AUSTIN EL",
        "district": "PECOS-BARSTOW-TOYAH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483455003874",
    },
    {
        "school": "CROCKETT MIDDLE",
        "district": "PECOS-BARSTOW-TOYAH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483455003877",
    },
    {
        "school": "HAYNES EL",
        "district": "PECOS-BARSTOW-TOYAH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483455003878",
    },
    {
        "school": "PECOS H S",
        "district": "PECOS-BARSTOW-TOYAH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483455003881",
    },
    {
        "school": "PECOS KIND",
        "district": "PECOS-BARSTOW-TOYAH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483455003882",
    },
    {
        "school": "ABERNATHY DAEP",
        "district": "ABERNATHY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480741009626",
    },
    {
        "school": "PETERSBURG DAEP",
        "district": "PETERSBURG ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483468010702",
    },
    {
        "school": "ABERNATHY EL",
        "district": "ABERNATHY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480741000007",
    },
    {
        "school": "ABERNATHY H S",
        "district": "ABERNATHY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480741000008",
    },
    {
        "school": "ABERNATHY MIDDLE",
        "district": "ABERNATHY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480741000009",
    },
    {
        "school": "COTTON CENTER SCHOOL",
        "district": "COTTON CENTER ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481536001112",
    },
    {
        "school": "AKIN EL",
        "district": "HALE CENTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482205002218",
    },
    {
        "school": "HALE CENTER H S",
        "district": "HALE CENTER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482205002219",
    },
    {
        "school": "CARR MIDDLE",
        "district": "HALE CENTER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482205006709",
    },
    {
        "school": "HALE CO J J A E P",
        "district": "HALE CENTER ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482205008580",
    },
    {
        "school": "PETERSBURG SCHOOL",
        "district": "PETERSBURG ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483468003893",
    },
    {
        "school": "COLLEGE HILL EL",
        "district": "PLAINVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483507003945",
    },
    {
        "school": "EDGEMERE EL",
        "district": "PLAINVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483507003947",
    },
    {
        "school": "HIGHLAND EL",
        "district": "PLAINVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483507003949",
    },
    {
        "school": "HILLCREST EL",
        "district": "PLAINVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483507003950",
    },
    {
        "school": "THUNDERBIRD EL",
        "district": "PLAINVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483507003953",
    },
    {
        "school": "LA MESA EL",
        "district": "PLAINVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483507006775",
    },
    {
        "school": "HALE COUNTY JJAEP",
        "district": "PLAINVIEW ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483507008224",
    },
    {
        "school": "PLAINVIEW H S",
        "district": "PLAINVIEW ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483507021279",
    },
    {
        "school": "LASARA EL",
        "district": "LASARA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482685003033",
    },
    {
        "school": "LYFORD H S",
        "district": "LYFORD CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482862003241",
    },
    {
        "school": "LYFORD MIDDLE",
        "district": "LYFORD CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482862003242",
    },
    {
        "school": "LYFORD EL",
        "district": "LYFORD CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482862006296",
    },
    {
        "school": "MYRA GREEN MIDDLE",
        "district": "RAYMONDVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483654004095",
    },
    {
        "school": "PITTMAN EL",
        "district": "RAYMONDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483654004097",
    },
    {
        "school": "RAYMONDVILLE H S",
        "district": "RAYMONDVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483654004098",
    },
    {
        "school": "SMITH EL",
        "district": "RAYMONDVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483654004099",
    },
    {
        "school": "SAN PERLITA H S",
        "district": "SAN PERLITA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483900007484",
    },
    {
        "school": "SAN PERLITA MIDDLE",
        "district": "SAN PERLITA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483900007485",
    },
    {
        "school": "SAN PERLITA EL",
        "district": "SAN PERLITA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483900007486",
    },
    {
        "school": "RAMIRO BARRERA MIDDLE",
        "district": "ROMA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483774011381",
    },
    {
        "school": "ROEL A & CELIA R SAENZ EL",
        "district": "ROMA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483774011414",
    },
    {
        "school": "DR MARIO E RAMIREZ EL",
        "district": "RIO GRANDE CITY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714011012",
    },
    {
        "school": "GRULLA MIDDLE",
        "district": "RIO GRANDE CITY CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714004172",
    },
    {
        "school": "GRULLA EL",
        "district": "RIO GRANDE CITY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714004173",
    },
    {
        "school": "LA UNION EL",
        "district": "RIO GRANDE CITY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714004174",
    },
    {
        "school": "ALBERTO AND CELIA BARRERA EL",
        "district": "RIO GRANDE CITY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714004175",
    },
    {
        "school": "RINGGOLD MIDDLE",
        "district": "RIO GRANDE CITY CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714004177",
    },
    {
        "school": "RINGGOLD EL",
        "district": "RIO GRANDE CITY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714004178",
    },
    {
        "school": "RIO GRANDE CITY H S",
        "district": "RIO GRANDE CITY CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714004179",
    },
    {
        "school": "ROQUE GUERRA JR EL",
        "district": "RIO GRANDE CITY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714004180",
    },
    {
        "school": "JOHN & OLIVE HINOJOSA EL",
        "district": "RIO GRANDE CITY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714006900",
    },
    {
        "school": "ALTO BONITO EL",
        "district": "RIO GRANDE CITY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714008361",
    },
    {
        "school": "GENERAL RICARDO SANCHEZ EL",
        "district": "RIO GRANDE CITY CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714009026",
    },
    {
        "school": "ROMA H S",
        "district": "ROMA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483774004228",
    },
    {
        "school": "ROMA MIDDLE",
        "district": "ROMA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483774004230",
    },
    {
        "school": "FLORENCE J SCOTT EL",
        "district": "ROMA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483774004231",
    },
    {
        "school": "RT BARRERA EL",
        "district": "ROMA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483774005782",
    },
    {
        "school": "EMMA VERA EL",
        "district": "ROMA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483774005788",
    },
    {
        "school": "INSTRUCTIONAL & GUIDANCE CENTER",
        "district": "ROMA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483774007108",
    },
    {
        "school": "SAN ISIDRO H S",
        "district": "SAN ISIDRO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483891004447",
    },
    {
        "school": "SAN ISIDRO EL",
        "district": "SAN ISIDRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483891008022",
    },
    {
        "school": "WATER VALLEY / VERIBEST SPECIAL PROGRAMS",
        "district": "WATER VALLEY ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484471011437",
    },
    {
        "school": "FAIRVIEW DAEP",
        "district": "CHRISTOVAL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481401009474",
    },
    {
        "school": "VERIBEST PPCD",
        "district": "CHRISTOVAL ISD",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481401009479",
    },
    {
        "school": "FAIRVIEW VT",
        "district": "CHRISTOVAL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481401011040",
    },
    {
        "school": "LAMAR EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870011044",
    },
    {
        "school": "FAIRVIEW ACCELERATED",
        "district": "VERIBEST ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484404011050",
    },
    {
        "school": "VERIBEST DAEP",
        "district": "VERIBEST ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484404011051",
    },
    {
        "school": "VERIBEST PPCD",
        "district": "WALL ISD",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484441009402",
    },
    {
        "school": "IRION EL",
        "district": "IRION COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483036003399",
    },
    {
        "school": "IRION H S",
        "district": "IRION COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483036003400",
    },
    {
        "school": "CHRISTOVAL EL",
        "district": "CHRISTOVAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481401000885",
    },
    {
        "school": "CHRISTOVAL H S",
        "district": "CHRISTOVAL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481401000886",
    },
    {
        "school": "WALL SP PROG (FLC/BAC)",
        "district": "CHRISTOVAL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481401007453",
    },
    {
        "school": "FAIRVIEW SPECIAL PROGRAMS",
        "district": "CHRISTOVAL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481401007454",
    },
    {
        "school": "FAIRVIEW ACCELERATED",
        "district": "CHRISTOVAL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481401008049",
    },
    {
        "school": "GRAPE CREEK INT",
        "district": "GRAPE CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482160002175",
    },
    {
        "school": "GRAPE CREEK MIDDLE",
        "district": "GRAPE CREEK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482160007132",
    },
    {
        "school": "GRAPE CREEK H S",
        "district": "GRAPE CREEK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482160007458",
    },
    {
        "school": "FAIRVIEW ACCELERATED",
        "district": "GRAPE CREEK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482160007459",
    },
    {
        "school": "FAIRVIEW DAEP",
        "district": "GRAPE CREEK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482160008930",
    },
    {
        "school": "ALTA LOMA EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004296",
    },
    {
        "school": "AUSTIN EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004297",
    },
    {
        "school": "BELAIRE EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004298",
    },
    {
        "school": "BOWIE EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004300",
    },
    {
        "school": "BRADFORD EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004301",
    },
    {
        "school": "CENTRAL H S",
        "district": "SAN ANGELO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004302",
    },
    {
        "school": "CROCKETT EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004303",
    },
    {
        "school": "FANNIN EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004306",
    },
    {
        "school": "FT CONCHO EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004307",
    },
    {
        "school": "GLENMORE EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004308",
    },
    {
        "school": "GLENN MIDDLE",
        "district": "SAN ANGELO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004309",
    },
    {
        "school": "GOLIAD EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004310",
    },
    {
        "school": "HOLIMAN EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004311",
    },
    {
        "school": "LAKE VIEW H S",
        "district": "SAN ANGELO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004312",
    },
    {
        "school": "LEE MIDDLE",
        "district": "SAN ANGELO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004313",
    },
    {
        "school": "MCGILL EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004315",
    },
    {
        "school": "REAGAN EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004316",
    },
    {
        "school": "SAN JACINTO EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004319",
    },
    {
        "school": "SANTA RITA EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870004320",
    },
    {
        "school": "CARVER ALTER LRN CTR",
        "district": "SAN ANGELO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483870005460",
    },
    {
        "school": "BONHAM EL",
        "district": "SAN ANGELO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870006317",
    },
    {
        "school": "LINCOLN MIDDLE",
        "district": "SAN ANGELO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483870008926",
    },
    {
        "school": "VERIBEST EL",
        "district": "VERIBEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484404004994",
    },
    {
        "school": "VERIBEST H S",
        "district": "VERIBEST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484404007463",
    },
    {
        "school": "WALL EL",
        "district": "WALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484441005068",
    },
    {
        "school": "WALL H S",
        "district": "WALL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484441005069",
    },
    {
        "school": "WALL MIDDLE",
        "district": "WALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484441006924",
    },
    {
        "school": "FAIRVIEW ACCELERATED DAEP",
        "district": "WALL ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484441009066",
    },
    {
        "school": "WATER VALLEY EL",
        "district": "WATER VALLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484471005089",
    },
    {
        "school": "WATER VALLEY H S",
        "district": "WATER VALLEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484471005090",
    },
    {
        "school": "FAIRVIEW SPECIAL PROGRAMS",
        "district": "WATER VALLEY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484471008051",
    },
    {
        "school": "SAN ANGELO STATE SCHOOL",
        "district": "WATER VALLEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484471008379",
    },
    {
        "school": "WALL SPECIAL PROGRAMS",
        "district": "WATER VALLEY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484471008928",
    },
    {
        "school": "BRANDEIS H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312011431",
    },
    {
        "school": "AUE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312011468",
    },
    {
        "school": "SAVANNAH HEIGHTS INT",
        "district": "SOMERSET ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484074011520",
    },
    {
        "school": "DISTRICT REASSIGNMENT & OPPORTUNITY CENTER",
        "district": "CHARLOTTE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481371010388",
    },
    {
        "school": "JJAEP",
        "district": "LYTLE ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482865010389",
    },
    {
        "school": "POTEET INT",
        "district": "POTEET ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483552009649",
    },
    {
        "school": "CESAR E CHAVEZ ACADEMY",
        "district": "POR VIDA ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480000409460",
    },
    {
        "school": "RUTH JONES MCCLENDON MIDDLE",
        "district": "GEORGE GERVIN ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001410415",
    },
    {
        "school": "JHW INSPIRE ACADEMY - HAYS COUNTY",
        "district": "INSPIRE ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480005309121",
    },
    {
        "school": "FRANK L MADLA ACCELERATED COLLEGIATE ACADEMY",
        "district": "NEW FRONTIERS PUBLIC SCHOOLS INC",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480006111122",
    },
    {
        "school": "DR PAUL S SAENZ J H",
        "district": "SCHOOL OF EXCELLENCE IN EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006210418",
    },
    {
        "school": "DR DAVID C WALKER EL",
        "district": "SCHOOL OF EXCELLENCE IN EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006211404",
    },
    {
        "school": "SOUTHWEST PREPARATORY SCHOOL-NORTHWEST",
        "district": "SOUTHWEST PREPARATORY SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480006309118",
    },
    {
        "school": "NEW DIRECTIONS",
        "district": "SOUTHWEST PREPARATORY SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480006310419",
    },
    {
        "school": "JUBILEE HIGHLAND HILLS",
        "district": "JUBILEE ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017909543",
    },
    {
        "school": "LIGHTHOUSE CHARTER SCHOOL",
        "district": "LIGHTHOUSE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024609569",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY",
        "district": "SCHOOL OF SCIENCE AND TECHNOLOGY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480025810423",
    },
    {
        "school": "MH SPECHT EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473009178",
    },
    {
        "school": "HIGHLAND FOREST EL",
        "district": "EAST CENTRAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785009132",
    },
    {
        "school": "LEGACY MIDDLE",
        "district": "EAST CENTRAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785010434",
    },
    {
        "school": "BEXAR CO J J A E P",
        "district": "EDGEWOOD ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481815009124",
    },
    {
        "school": "FENLEY TRANSITIONAL H S",
        "district": "HARLANDALE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482247009122",
    },
    {
        "school": "FENLEY TRANSITIONAL MIDDLE",
        "district": "HARLANDALE ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482247009123",
    },
    {
        "school": "TEJEDA JUNIOR ACADEMY",
        "district": "HARLANDALE ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482247010424",
    },
    {
        "school": "MARY LOU HARTMAN",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499009452",
    },
    {
        "school": "KAREN WAGNER H S",
        "district": "JUDSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499010445",
    },
    {
        "school": "HENRY METZGER MIDDLE",
        "district": "JUDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499010446",
    },
    {
        "school": "RICARDO SALINAS EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499010447",
    },
    {
        "school": "POTRANCO EL",
        "district": "MEDINA VALLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483006010960",
    },
    {
        "school": "ROYAL RIDGE EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294009130",
    },
    {
        "school": "ROAN FOREST EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294009131",
    },
    {
        "school": "CANYON RIDGE EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294010430",
    },
    {
        "school": "STEUBING RANCH EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294010431",
    },
    {
        "school": "BULVERDE CREEK",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294010432",
    },
    {
        "school": "WILDERNESS OAK EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294010433",
    },
    {
        "school": "ALTERNATIVE EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483294011135",
    },
    {
        "school": "WARREN H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312009134",
    },
    {
        "school": "RHODES EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312009135",
    },
    {
        "school": "NICHOLS EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312009136",
    },
    {
        "school": "NISD INTERVENTION",
        "district": "NORTHSIDE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312009137",
    },
    {
        "school": "WARD EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312009469",
    },
    {
        "school": "BLATTMAN EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312009470",
    },
    {
        "school": "BEARD EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312009471",
    },
    {
        "school": "RAWLINSON MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312009472",
    },
    {
        "school": "STEVENS H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312010437",
    },
    {
        "school": "LUNA MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312010438",
    },
    {
        "school": "MURNIN EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312010439",
    },
    {
        "school": "OTT EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312010440",
    },
    {
        "school": "HATCHETT EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312010441",
    },
    {
        "school": "MEAD EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312010442",
    },
    {
        "school": "KRUEGER EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312010443",
    },
    {
        "school": "DAEP AT HOLMGREEN",
        "district": "NORTHSIDE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312011136",
    },
    {
        "school": "JEFFERSON MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312011549",
    },
    {
        "school": "DRIGGERS EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312011559",
    },
    {
        "school": "BREWER ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483873009126",
    },
    {
        "school": "M L KING ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873010425",
    },
    {
        "school": "MISSION ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873010427",
    },
    {
        "school": "TRAVIS EARLY COLLEGE H S",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873011436",
    },
    {
        "school": "ROY BENAVIDEZ EL",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068009128",
    },
    {
        "school": "ROBERT C ZAMORA MIDDLE",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068010429",
    },
    {
        "school": "S/SGT MICHAEL P BARRERA VETERANS EL",
        "district": "SOMERSET ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484074009129",
    },
    {
        "school": "FREEDOM EL",
        "district": "SOUTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484092009451",
    },
    {
        "school": "JULIAN C GALLARDO EL",
        "district": "SOUTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484092010449",
    },
    {
        "school": "SPICEWOOD PARK EL",
        "district": "SOUTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095011523",
    },
    {
        "school": "HOFFMANN LANE EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473009179",
    },
    {
        "school": "REBECCA CREEK EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473009180",
    },
    {
        "school": "CANYON LAKE H S",
        "district": "COMAL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473010533",
    },
    {
        "school": "FREIHEIT EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473011442",
    },
    {
        "school": "TIMBERWOOD PARK EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473011460",
    },
    {
        "school": "DISCIPLINE ALTERNATIVE EDUCATION PLACEMENT",
        "district": "NEW BRAUNFELS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483237009177",
    },
    {
        "school": "NORMA KRUEGER EL/BERT KARRER CAMPUS",
        "district": "MARION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482910009632",
    },
    {
        "school": "GREEN VALLEY EL",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948009604",
    },
    {
        "school": "NORMA J PASCHAL EL",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948009627",
    },
    {
        "school": "BYRON P STEELE II H S",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948010700",
    },
    {
        "school": "ELAINE S SCHLATHER INT",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948011539",
    },
    {
        "school": "JOHN A SIPPEL EL",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948011556",
    },
    {
        "school": "JUVENILE DETENTION CENTER",
        "district": "SEGUIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483969009251",
    },
    {
        "school": "TRIUMPH PUBLIC HIGH SCHOOLS-MCALLEN",
        "district": "TRIUMPH PUBLIC HIGH SCHOOLS-RIO GRANDE VALLEY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480013309294",
    },
    {
        "school": "CASTROVILLE EL",
        "district": "MEDINA VALLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483006010958",
    },
    {
        "school": "LACOSTE EL",
        "district": "MEDINA VALLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483006010959",
    },
    {
        "school": "CORPUS CHRISTI COLLEGE PREP H S",
        "district": "POR VIDA ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480000409116",
    },
    {
        "school": "WILSON CO JJAEP",
        "district": "LA VERNIA ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482631009442",
    },
    {
        "school": "FLORESVILLE ALTERNATIVE CENTER",
        "district": "POTH ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483555009444",
    },
    {
        "school": "WILSON CO JJAEP",
        "district": "STOCKDALE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484161011115",
    },
    {
        "school": "CHARLOTTE EL",
        "district": "CHARLOTTE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481371000862",
    },
    {
        "school": "CHARLOTTE H S",
        "district": "CHARLOTTE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481371000863",
    },
    {
        "school": "CHARLOTTE MIDDLE",
        "district": "CHARLOTTE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481371000864",
    },
    {
        "school": "ATASCOSA CO ALTER",
        "district": "CHARLOTTE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481371008689",
    },
    {
        "school": "JOURDANTON EL",
        "district": "JOURDANTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482496002784",
    },
    {
        "school": "JOURDANTON H S",
        "district": "JOURDANTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482496002785",
    },
    {
        "school": "JOURDANTON J H",
        "district": "JOURDANTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482496005511",
    },
    {
        "school": "ATASCOSA COUNTY JUVENILE JUSTICE CENTER",
        "district": "JOURDANTON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482496007778",
    },
    {
        "school": "THE LARRY BROWN SCHOOL",
        "district": "JOURDANTON ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482496008421",
    },
    {
        "school": "LYTLE EL",
        "district": "LYTLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482865003245",
    },
    {
        "school": "LYTLE H S",
        "district": "LYTLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482865003246",
    },
    {
        "school": "LYTLE J H",
        "district": "LYTLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482865005544",
    },
    {
        "school": "LYTLE DAEP",
        "district": "LYTLE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482865008422",
    },
    {
        "school": "LYTLE PRIMARY SCHOOL",
        "district": "LYTLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482865008424",
    },
    {
        "school": "PLEASANTON EL",
        "district": "PLEASANTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483519003983",
    },
    {
        "school": "PLEASANTON H S",
        "district": "PLEASANTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483519003984",
    },
    {
        "school": "PLEASANTON J H",
        "district": "PLEASANTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483519003985",
    },
    {
        "school": "ATASCOSA CO ALTER",
        "district": "PLEASANTON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483519007506",
    },
    {
        "school": "PLEASANTON PRI",
        "district": "PLEASANTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483519007507",
    },
    {
        "school": "POTEET EL",
        "district": "POTEET ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483552004028",
    },
    {
        "school": "POTEET H S",
        "district": "POTEET ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483552004029",
    },
    {
        "school": "POTEET J H",
        "district": "POTEET ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483552004030",
    },
    {
        "school": "ATASCOSA CO JUVENILE UNIT",
        "district": "POTEET ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483552008425",
    },
    {
        "school": "ALKEK EL",
        "district": "BANDERA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480936000394",
    },
    {
        "school": "BANDERA H S",
        "district": "BANDERA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480936000395",
    },
    {
        "school": "BANDERA MIDDLE",
        "district": "BANDERA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480936000396",
    },
    {
        "school": "HILL COUNTRY EL",
        "district": "BANDERA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480936005863",
    },
    {
        "school": "MEDINA SCHOOL",
        "district": "MEDINA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483003003372",
    },
    {
        "school": "COMFORT EL",
        "district": "COMFORT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481479000978",
    },
    {
        "school": "COMFORT H S",
        "district": "COMFORT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481479000979",
    },
    {
        "school": "COMFORT MIDDLE",
        "district": "COMFORT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481479004860",
    },
    {
        "school": "D'HANIS SCHOOL",
        "district": "D'HANIS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481614001195",
    },
    {
        "school": "JOHN J CIAVARRA EL",
        "district": "DEVINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481695001468",
    },
    {
        "school": "DEVINE H S",
        "district": "DEVINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481695001469",
    },
    {
        "school": "DEVINE MIDDLE",
        "district": "DEVINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481695001470",
    },
    {
        "school": "DEVINE INTERMEDIATE SCHOOL",
        "district": "DEVINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481695006846",
    },
    {
        "school": "HONDO H S",
        "district": "HONDO ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482343002376",
    },
    {
        "school": "MCDOWELL MIDDLE",
        "district": "HONDO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482343002377",
    },
    {
        "school": "MEYER EL",
        "district": "HONDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482343002378",
    },
    {
        "school": "NEWELL E WOOLLS INT",
        "district": "HONDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482343008875",
    },
    {
        "school": "MEDINA VALLEY H S",
        "district": "MEDINA VALLEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483006003373",
    },
    {
        "school": "MEDINA VALLEY MIDDLE",
        "district": "MEDINA VALLEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483006008876",
    },
    {
        "school": "NATALIA EL",
        "district": "NATALIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483213003564",
    },
    {
        "school": "NATALIA H S",
        "district": "NATALIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483213003565",
    },
    {
        "school": "NATALIA J H",
        "district": "NATALIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483213003566",
    },
    {
        "school": "NATALIA EARLY CHILD CTR",
        "district": "NATALIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483213005102",
    },
    {
        "school": "TRIUMPH PUBLIC HISH SCHOOLS-MERCEDES",
        "district": "TRIUMPH PUBLIC HIGH SCHOOLS-RIO GRANDE VALLEY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480013308280",
    },
    {
        "school": "ATASCOSA CO ALTER",
        "district": "SOMERSET ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484074008445",
    },
    {
        "school": "POR VIDA ACADEMY CHARTER H S",
        "district": "POR VIDA ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480000407173",
    },
    {
        "school": "GEORGE GERVIN ACADEMY",
        "district": "GEORGE GERVIN ACADEMY",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001407174",
    },
    {
        "school": "JHW INSPIRE ACADEMY - AFTON OAKS",
        "district": "INSPIRE ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480005307796",
    },
    {
        "school": "POSITIVE SOLUTIONS CHARTER",
        "district": "POSITIVE SOLUTIONS CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480005907798",
    },
    {
        "school": "DR HARMON W KELLEY EL",
        "district": "SCHOOL OF EXCELLENCE IN EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006207794",
    },
    {
        "school": "SOUTHWEST PREPARATORY SCHOOL",
        "district": "SOUTHWEST PREPARATORY SCHOOL",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480006307795",
    },
    {
        "school": "SOUTHWEST PREPARATORY SOUTHEAST CAMPUS",
        "district": "SOUTHWEST PREPARATORY SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480006308433",
    },
    {
        "school": "BEXAR COUNTY ACADEMY",
        "district": "BEXAR COUNTY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007708105",
    },
    {
        "school": "HERITAGE ACADEMY OF WINDCREST",
        "district": "HERITAGE ACADEMY",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480008008108",
    },
    {
        "school": "HERITAGE ACADEMY",
        "district": "HERITAGE ACADEMY",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480008008109",
    },
    {
        "school": "JUBILEE SAN ANTONIO",
        "district": "JUBILEE ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017908438",
    },
    {
        "school": "ALAMO HEIGHTS H S",
        "district": "ALAMO HEIGHTS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480759000045",
    },
    {
        "school": "ALAMO HEIGHTS J H",
        "district": "ALAMO HEIGHTS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480759000046",
    },
    {
        "school": "CAMBRIDGE EL",
        "district": "ALAMO HEIGHTS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480759000047",
    },
    {
        "school": "HOWARD EL",
        "district": "ALAMO HEIGHTS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480759000048",
    },
    {
        "school": "WOODRIDGE EL",
        "district": "ALAMO HEIGHTS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480759000050",
    },
    {
        "school": "BEXAR CO J J A E P",
        "district": "ALAMO HEIGHTS ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480759007509",
    },
    {
        "school": "FAIR OAKS RANCH EL",
        "district": "BOERNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071007055",
    },
    {
        "school": "EAST CENTRAL H S",
        "district": "EAST CENTRAL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785001554",
    },
    {
        "school": "HARMONY EL",
        "district": "EAST CENTRAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785001555",
    },
    {
        "school": "PECAN VALLEY EL",
        "district": "EAST CENTRAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785001558",
    },
    {
        "school": "SINCLAIR EL",
        "district": "EAST CENTRAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785005701",
    },
    {
        "school": "BEXAR CO J J A E P",
        "district": "EAST CENTRAL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481785007183",
    },
    {
        "school": "BEXAR COUNTY LRN CTR",
        "district": "EAST CENTRAL ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481785007517",
    },
    {
        "school": "EAST CENTRAL HERITAGE MIDDLE",
        "district": "EAST CENTRAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785007518",
    },
    {
        "school": "EAST CENTRAL CHOICE PROGAM",
        "district": "EAST CENTRAL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481785008449",
    },
    {
        "school": "ALONSO S PERALES EL",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001606",
    },
    {
        "school": "BRENTWOOD MIDDLE",
        "district": "EDGEWOOD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001607",
    },
    {
        "school": "ROY CISNEROS EL",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001610",
    },
    {
        "school": "E T WRENN MIDDLE",
        "district": "EDGEWOOD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001612",
    },
    {
        "school": "GARDENDALE EL",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001617",
    },
    {
        "school": "GUS GARCIA MIDDLE",
        "district": "EDGEWOOD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001619",
    },
    {
        "school": "H B GONZALEZ EL",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001620",
    },
    {
        "school": "L B JOHNSON EL",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001623",
    },
    {
        "school": "JOHN F KENNEDY H S",
        "district": "EDGEWOOD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001624",
    },
    {
        "school": "LAS PALMAS EL",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001625",
    },
    {
        "school": "LOMA PARK EL",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001627",
    },
    {
        "school": "MEMORIAL H S",
        "district": "EDGEWOOD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001628",
    },
    {
        "school": "STAFFORD EL",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001630",
    },
    {
        "school": "WINSTON EL",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815001632",
    },
    {
        "school": "ROOSEVELT EL",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815006099",
    },
    {
        "school": "ALTERNATIVE CENTER",
        "district": "EDGEWOOD ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481815008442",
    },
    {
        "school": "ROBERT G COLE MIDDLE/HIGH SCHOOL",
        "district": "FT SAM HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482016001965",
    },
    {
        "school": "FT SAM HOUSTON EL",
        "district": "FT SAM HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482016001966",
    },
    {
        "school": "A LEAL JR MIDDLE",
        "district": "HARLANDALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002251",
    },
    {
        "school": "BELLAIRE EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002252",
    },
    {
        "school": "CARROLL BELL EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002253",
    },
    {
        "school": "COLLIER EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002254",
    },
    {
        "school": "COLUMBIA HEIGHTS EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002255",
    },
    {
        "school": "E H GILBERT EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002256",
    },
    {
        "school": "STONEWALL/FLANDERS EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002257",
    },
    {
        "school": "GILLETTE EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002258",
    },
    {
        "school": "H W SCHULZE EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002259",
    },
    {
        "school": "HARLANDALE H S",
        "district": "HARLANDALE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002260",
    },
    {
        "school": "HARLANDALE MIDDLE",
        "district": "HARLANDALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002261",
    },
    {
        "school": "KINGSBOROUGH MIDDLE",
        "district": "HARLANDALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002262",
    },
    {
        "school": "MCCOLLUM H S",
        "district": "HARLANDALE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002263",
    },
    {
        "school": "MORRILL EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002264",
    },
    {
        "school": "RAYBURN EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002265",
    },
    {
        "school": "JEWEL C WIETZEL CENTER",
        "district": "HARLANDALE ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "482247002267",
    },
    {
        "school": "TERRELL WELLS MIDDLE",
        "district": "HARLANDALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002269",
    },
    {
        "school": "V M ADAMS EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002270",
    },
    {
        "school": "VESTAL EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002271",
    },
    {
        "school": "WRIGHT EL",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247002272",
    },
    {
        "school": "FRANK M TEJEDA ACADEMY",
        "district": "HARLANDALE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482247005946",
    },
    {
        "school": "HAC DAEP H S",
        "district": "HARLANDALE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482247006559",
    },
    {
        "school": "BEXAR CO J J A E P",
        "district": "HARLANDALE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482247007175",
    },
    {
        "school": "HAC DAEP MIDDLE",
        "district": "HARLANDALE ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482247007799",
    },
    {
        "school": "COLLIER DAEP",
        "district": "HARLANDALE ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482247008440",
    },
    {
        "school": "HARLANDALE ALTERNATIVE CENTER BOOT H S",
        "district": "HARLANDALE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482247008702",
    },
    {
        "school": "HARLANDALE ALTERNATIVE CENTER BOOT MIDDLE",
        "district": "HARLANDALE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482247008703",
    },
    {
        "school": "CONVERSE EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499002786",
    },
    {
        "school": "CORONADO VILLAGE EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499002787",
    },
    {
        "school": "CRESTVIEW EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499002788",
    },
    {
        "school": "JUDSON H S",
        "district": "JUDSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499002789",
    },
    {
        "school": "HOPKINS EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499002790",
    },
    {
        "school": "KIRBY MIDDLE",
        "district": "JUDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499002791",
    },
    {
        "school": "KITTY HAWK MIDDLE",
        "district": "JUDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499002792",
    },
    {
        "school": "ED FRANZ EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499002793",
    },
    {
        "school": "PARK VILLAGE EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499002794",
    },
    {
        "school": "OLYMPIA EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499005512",
    },
    {
        "school": "WOODLAKE EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499005514",
    },
    {
        "school": "ELOLF EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499005819",
    },
    {
        "school": "JUDSON LEARNING ACAD",
        "district": "JUDSON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482499006128",
    },
    {
        "school": "SPRING MEADOWS EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499006276",
    },
    {
        "school": "MILLER POINT EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499006429",
    },
    {
        "school": "CANDLEWOOD EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499006723",
    },
    {
        "school": "JUDSON CARE ACADEMY",
        "district": "JUDSON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482499007187",
    },
    {
        "school": "BEXAR CO J J A E P",
        "district": "JUDSON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482499007188",
    },
    {
        "school": "WOODLAKE HILLS MIDDLE",
        "district": "JUDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499007189",
    },
    {
        "school": "WILLIAM PASCHALL EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499008451",
    },
    {
        "school": "LACKLAND EL",
        "district": "LACKLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482637002970",
    },
    {
        "school": "VIRGINIA ALLRED STACEY JR/SR H S",
        "district": "LACKLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482637006877",
    },
    {
        "school": "DRISCOLL MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294000290",
    },
    {
        "school": "SERNA EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294000295",
    },
    {
        "school": "CAMELOT EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003627",
    },
    {
        "school": "CASTLE HILLS EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003628",
    },
    {
        "school": "CHURCHILL H S",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003630",
    },
    {
        "school": "CLEAR SPRING EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003631",
    },
    {
        "school": "COKER EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003632",
    },
    {
        "school": "COLONIAL HILLS EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003633",
    },
    {
        "school": "DELLVIEW EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003634",
    },
    {
        "school": "EAST TERRELL HILLS EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003635",
    },
    {
        "school": "EISENHOWER MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003636",
    },
    {
        "school": "EL DORADO EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003637",
    },
    {
        "school": "GARNER MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003638",
    },
    {
        "school": "HARMONY HILLS EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003639",
    },
    {
        "school": "HIDDEN FOREST EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003640",
    },
    {
        "school": "JACKSON MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003642",
    },
    {
        "school": "KRUEGER MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003643",
    },
    {
        "school": "LARKSPUR EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003644",
    },
    {
        "school": "LEGACY OF EDUCATIONAL EXCELLENCE H S",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003645",
    },
    {
        "school": "MACARTHUR H S",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003646",
    },
    {
        "school": "MADISON H S",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003647",
    },
    {
        "school": "MONTGOMERY EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003648",
    },
    {
        "school": "NIMITZ MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003649",
    },
    {
        "school": "NORTHWOOD EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003650",
    },
    {
        "school": "OAK GROVE EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003651",
    },
    {
        "school": "OLMOS EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003652",
    },
    {
        "school": "REGENCY PLACE EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003653",
    },
    {
        "school": "RIDGEVIEW EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003654",
    },
    {
        "school": "ROOSEVELT H S",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003655",
    },
    {
        "school": "WALZEM EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003657",
    },
    {
        "school": "WHITE MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003659",
    },
    {
        "school": "WILSHIRE EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003660",
    },
    {
        "school": "WINDCREST EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003661",
    },
    {
        "school": "WOODSTONE EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294003662",
    },
    {
        "school": "STAHL EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294005559",
    },
    {
        "school": "THOUSAND OAKS EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294005561",
    },
    {
        "school": "WOOD MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294005562",
    },
    {
        "school": "BRADLEY MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294005783",
    },
    {
        "school": "NORTHERN HILLS EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294005784",
    },
    {
        "school": "ALTER H S",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483294006035",
    },
    {
        "school": "JACKSON-KELLER EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294006590",
    },
    {
        "school": "REDLAND OAKS EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294006766",
    },
    {
        "school": "ENCINO PARK EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294006767",
    },
    {
        "school": "ALTER MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483294006889",
    },
    {
        "school": "NORTH EAST J J A E P",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483294007181",
    },
    {
        "school": "STONE OAK EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294007182",
    },
    {
        "school": "INTERNATIONAL SCHOOL OF AMERICA",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294007513",
    },
    {
        "school": "LONGS CREEK EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294007515",
    },
    {
        "school": "HUEBNER EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294007516",
    },
    {
        "school": "BUSH MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294007801",
    },
    {
        "school": "REAGAN H S",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294008116",
    },
    {
        "school": "TEJEDA MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294008447",
    },
    {
        "school": "WETMORE EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294008448",
    },
    {
        "school": "HARDY OAK EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294008705",
    },
    {
        "school": "FOX RUN EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294021007",
    },
    {
        "school": "ACADEMY OF CREATIVE ED",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483294021107",
    },
    {
        "school": "OAK MEADOW EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294021108",
    },
    {
        "school": "EVERS EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312000353",
    },
    {
        "school": "MCDERMOTT EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312000354",
    },
    {
        "school": "REDDIX CENTER",
        "district": "NORTHSIDE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312002944",
    },
    {
        "school": "JORDAN MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312002953",
    },
    {
        "school": "PUPIL PERSONNEL CAMPUS",
        "district": "NORTHSIDE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312003032",
    },
    {
        "school": "ADAMS HILL EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003687",
    },
    {
        "school": "JONES MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003688",
    },
    {
        "school": "CABLE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003689",
    },
    {
        "school": "CARLOS COON EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003690",
    },
    {
        "school": "STEVENSON MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003692",
    },
    {
        "school": "COLONIES NORTH EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003693",
    },
    {
        "school": "PEASE MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003694",
    },
    {
        "school": "VILLARREAL EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003696",
    },
    {
        "school": "GLENN EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003697",
    },
    {
        "school": "GLENOAKS EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003698",
    },
    {
        "school": "ESPARZA EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003699",
    },
    {
        "school": "HELOTES EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003700",
    },
    {
        "school": "HOLMES H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003701",
    },
    {
        "school": "HULL EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003704",
    },
    {
        "school": "PASSMORE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003705",
    },
    {
        "school": "JAY H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003706",
    },
    {
        "school": "ALLEN EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003707",
    },
    {
        "school": "LEON VALLEY EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003708",
    },
    {
        "school": "LOCKE HILL EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003709",
    },
    {
        "school": "MARSHALL H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003711",
    },
    {
        "school": "MEADOW VILLAGE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003712",
    },
    {
        "school": "BOONE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003713",
    },
    {
        "school": "NEFF MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003714",
    },
    {
        "school": "HOLMGREEN CENTER",
        "district": "NORTHSIDE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312003715",
    },
    {
        "school": "OAK HILLS TERRACE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003716",
    },
    {
        "school": "RAYBURN MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003717",
    },
    {
        "school": "HOWSMAN EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003718",
    },
    {
        "school": "ROSS MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003719",
    },
    {
        "school": "GLASS EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003720",
    },
    {
        "school": "POWELL EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003721",
    },
    {
        "school": "CLARK H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003722",
    },
    {
        "school": "VALLEY HI EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003723",
    },
    {
        "school": "WESTWOOD TERRACE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003725",
    },
    {
        "school": "HOBBY MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312003726",
    },
    {
        "school": "LINTON EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312005563",
    },
    {
        "school": "HOMEBOUND",
        "district": "NORTHSIDE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312005564",
    },
    {
        "school": "TIMBERWILDE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312005565",
    },
    {
        "school": "BRAUN STATION EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312005785",
    },
    {
        "school": "RUDDER MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312005786",
    },
    {
        "school": "CODY EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312005787",
    },
    {
        "school": "NORTHWEST CROSSING EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312005789",
    },
    {
        "school": "HEALTH CAREERS H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312006023",
    },
    {
        "school": "TAFT H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312006148",
    },
    {
        "school": "ALTERNATIVE H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312006149",
    },
    {
        "school": "ZACHRY MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312006150",
    },
    {
        "school": "KNOWLTON EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312006151",
    },
    {
        "school": "SCOBEE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312006460",
    },
    {
        "school": "GALM EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312006461",
    },
    {
        "school": "ELROD EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312006592",
    },
    {
        "school": "THORNTON EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312006769",
    },
    {
        "school": "BRAUCHLE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312006891",
    },
    {
        "school": "NISD BEXAR COUNTY JJA",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312007184",
    },
    {
        "school": "ALTERNATIVE MIDDLE SOUTH",
        "district": "NORTHSIDE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312007185",
    },
    {
        "school": "ALTERNATIVE MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312007521",
    },
    {
        "school": "MAY EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312007522",
    },
    {
        "school": "MYERS EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312007523",
    },
    {
        "school": "STEUBING EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312007524",
    },
    {
        "school": "O'CONNOR H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312007808",
    },
    {
        "school": "CONNALLY MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312007809",
    },
    {
        "school": "CARSON EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312007811",
    },
    {
        "school": "MICHAEL EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312008119",
    },
    {
        "school": "LEWIS EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312008450",
    },
    {
        "school": "BURKE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312008707",
    },
    {
        "school": "RABA EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312008708",
    },
    {
        "school": "FERNANDEZ EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312021008",
    },
    {
        "school": "CHAVEZ EXCEL ACADEMY",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312021113",
    },
    {
        "school": "STINSON MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312021114",
    },
    {
        "school": "LEON SPRINGS EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312021115",
    },
    {
        "school": "RANDOLPH EL",
        "district": "RANDOLPH FIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483645004087",
    },
    {
        "school": "RANDOLPH H S",
        "district": "RANDOLPH FIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483645004088",
    },
    {
        "school": "RANDOLPH MIDDLE",
        "district": "RANDOLPH FIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483645006778",
    },
    {
        "school": "CHILDREN'S SHELTER OF SA",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483873000289",
    },
    {
        "school": "CHRISTUS SANTA ROSA",
        "district": "SAN ANTONIO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483873002915",
    },
    {
        "school": "AGNES COTTON ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004322",
    },
    {
        "school": "ARNOLD EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004323",
    },
    {
        "school": "BASKIN EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004324",
    },
    {
        "school": "BEACON HILL ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004325",
    },
    {
        "school": "BONHAM ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004326",
    },
    {
        "school": "BOWDEN ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004327",
    },
    {
        "school": "BRISCOE EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004329",
    },
    {
        "school": "BURBANK H S",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004330",
    },
    {
        "school": "CAMERON EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004331",
    },
    {
        "school": "CHARLES C BALL ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004333",
    },
    {
        "school": "CHARLES GRAEBNER EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004334",
    },
    {
        "school": "COLLINS GARDEN EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004335",
    },
    {
        "school": "DAVID CROCKETT ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004339",
    },
    {
        "school": "DAVIS MIDDLE",
        "district": "SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004341",
    },
    {
        "school": "DE ZAVALA EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004342",
    },
    {
        "school": "DORIE MILLER EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004343",
    },
    {
        "school": "DOUGLASS ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004344",
    },
    {
        "school": "EDISON H S",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004345",
    },
    {
        "school": "ELOISE JAPHET ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004346",
    },
    {
        "school": "FENWICK ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004348",
    },
    {
        "school": "FOSTER ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004349",
    },
    {
        "school": "FOX TECHNICAL H S",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004350",
    },
    {
        "school": "FRANKLIN EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004352",
    },
    {
        "school": "GATES EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004353",
    },
    {
        "school": "GEORGE E KELLY EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004354",
    },
    {
        "school": "HARRIS MIDDLE",
        "district": "SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004355",
    },
    {
        "school": "HAWTHORNE PK-8 ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004356",
    },
    {
        "school": "HERFF ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004357",
    },
    {
        "school": "HIGHLAND HILLS EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004358",
    },
    {
        "school": "HIGHLAND PARK EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004359",
    },
    {
        "school": "HIGHLANDS H S",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004360",
    },
    {
        "school": "HILLCREST EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004361",
    },
    {
        "school": "HIRSCH EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004362",
    },
    {
        "school": "HOUSTON H S",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004363",
    },
    {
        "school": "HUPPERTZ EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004364",
    },
    {
        "school": "J T BRACKENRIDGE EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004366",
    },
    {
        "school": "JEFFERSON H S",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004368",
    },
    {
        "school": "LAMAR EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004369",
    },
    {
        "school": "LANIER H S",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004370",
    },
    {
        "school": "LONGFELLOW MIDDLE",
        "district": "SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004371",
    },
    {
        "school": "LOWELL MIDDLE",
        "district": "SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004372",
    },
    {
        "school": "MADISON EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004373",
    },
    {
        "school": "MARGIL ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004375",
    },
    {
        "school": "MAVERICK EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004376",
    },
    {
        "school": "MURIEL FORBES ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004377",
    },
    {
        "school": "NEAL EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004378",
    },
    {
        "school": "OGDEN ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004380",
    },
    {
        "school": "P F STEWART EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004381",
    },
    {
        "school": "PERSHING EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004383",
    },
    {
        "school": "POE MIDDLE",
        "district": "SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004385",
    },
    {
        "school": "RHODES MIDDLE",
        "district": "SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004386",
    },
    {
        "school": "RIVERSIDE PARK ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004388",
    },
    {
        "school": "ROBERT B GREEN ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004389",
    },
    {
        "school": "ROGERS ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004391",
    },
    {
        "school": "ROGERS MIDDLE",
        "district": "SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004392",
    },
    {
        "school": "DAVID BARKLEY/FRANCISCO RUIZ EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004393",
    },
    {
        "school": "SARAH S KING EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004394",
    },
    {
        "school": "SCHENCK EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004395",
    },
    {
        "school": "SMITH EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004397",
    },
    {
        "school": "STORM EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004400",
    },
    {
        "school": "TAFOLLA MIDDLE",
        "district": "SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004401",
    },
    {
        "school": "WASHINGTON EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004406",
    },
    {
        "school": "BRACKENRIDGE H S",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004407",
    },
    {
        "school": "WHITTIER MIDDLE",
        "district": "SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004408",
    },
    {
        "school": "WILSON EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004409",
    },
    {
        "school": "WOODLAWN ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004411",
    },
    {
        "school": "WOODLAWN HILLS EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873004412",
    },
    {
        "school": "HEALY-MURPHY",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483873005911",
    },
    {
        "school": "SEIDEL LEARNING CENTER",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483873005916",
    },
    {
        "school": "ESTRADA ACHIEVEMENT CTR",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483873006611",
    },
    {
        "school": "JT BRACKENRIDGE DAEP",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483873006612",
    },
    {
        "school": "JJAEP",
        "district": "SAN ANTONIO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483873007177",
    },
    {
        "school": "HEALY MURPHY PK",
        "district": "SAN ANTONIO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873008443",
    },
    {
        "school": "JUVENILE DETENT CTR",
        "district": "SAN ANTONIO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483873021101",
    },
    {
        "school": "ROSE GARDEN EL",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948004486",
    },
    {
        "school": "ALAN B SHEPARD MIDDLE",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068004605",
    },
    {
        "school": "DWIGHT MIDDLE",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068004608",
    },
    {
        "school": "FIVE PALMS EL",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068004609",
    },
    {
        "school": "HUTCHINS EL",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068004610",
    },
    {
        "school": "KINDRED EL",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068004611",
    },
    {
        "school": "NEIL ARMSTRONG EL",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068004612",
    },
    {
        "school": "PALO ALTO EL",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068004613",
    },
    {
        "school": "PRICE EL",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068004614",
    },
    {
        "school": "FRANK MADLA EL",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068004615",
    },
    {
        "school": "SOUTH SAN ANTONIO H S",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068004617",
    },
    {
        "school": "MIGUEL CARRILLO JR EL",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068005989",
    },
    {
        "school": "ALTERNATIVE SCHOOL",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484068006790",
    },
    {
        "school": "BEXAR CO J J A E P",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484068007178",
    },
    {
        "school": "SOMERSET EL",
        "district": "SOMERSET ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484074004622",
    },
    {
        "school": "SOMERSET H S",
        "district": "SOMERSET ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484074004623",
    },
    {
        "school": "SOMERSET J H",
        "district": "SOMERSET ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484074004624",
    },
    {
        "school": "SOMERSET EARLY CHILDHOOD EL",
        "district": "SOMERSET ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484074008115",
    },
    {
        "school": "SOUTHSIDE H S",
        "district": "SOUTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484092004652",
    },
    {
        "school": "JULIUS L MATTHEY MIDDLE",
        "district": "SOUTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484092004653",
    },
    {
        "school": "W M PEARCE PRI",
        "district": "SOUTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484092004654",
    },
    {
        "school": "LOSOYA MIDDLE",
        "district": "SOUTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484092006484",
    },
    {
        "school": "SOUTHSIDE ALTER CTR",
        "district": "SOUTHSIDE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484092007190",
    },
    {
        "school": "BEXAR CO J J A E P",
        "district": "SOUTHSIDE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484092007813",
    },
    {
        "school": "HERITAGE EL",
        "district": "SOUTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484092008120",
    },
    {
        "school": "SOUTHWEST EL",
        "district": "SOUTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095004655",
    },
    {
        "school": "SUN VALLEY EL",
        "district": "SOUTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095004656",
    },
    {
        "school": "BOB HOPE EL",
        "district": "SOUTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095004657",
    },
    {
        "school": "SOUTHWEST H S",
        "district": "SOUTHWEST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095004658",
    },
    {
        "school": "INDIAN CREEK EL",
        "district": "SOUTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095004659",
    },
    {
        "school": "RONALD E MCNAIR MIDDLE",
        "district": "SOUTHWEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095004660",
    },
    {
        "school": "SKY HARBOUR EL",
        "district": "SOUTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095005598",
    },
    {
        "school": "SHARON CHRISTA MCAULIFFE MIDDLE",
        "district": "SOUTHWEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095006042",
    },
    {
        "school": "HIDDEN COVE EL",
        "district": "SOUTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095006327",
    },
    {
        "school": "BIG COUNTRY EL",
        "district": "SOUTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095006485",
    },
    {
        "school": "BEXAR CO J J A E P",
        "district": "SOUTHWEST ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484095007519",
    },
    {
        "school": "ELM CREEK EL",
        "district": "SOUTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095007520",
    },
    {
        "school": "KRIEWALD RD EL",
        "district": "SOUTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095007807",
    },
    {
        "school": "FRANCIS R SCOBEE MIDDLE",
        "district": "SOUTHWEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095008118",
    },
    {
        "school": "RAHE BULVERDE EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473000965",
    },
    {
        "school": "SMITHSON VALLEY MIDDLE",
        "district": "COMAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473000966",
    },
    {
        "school": "CANYON H S",
        "district": "COMAL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473000967",
    },
    {
        "school": "CANYON MIDDLE",
        "district": "COMAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473000968",
    },
    {
        "school": "GARDEN RIDGE EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473000969",
    },
    {
        "school": "GOODWIN FRAZIER EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473000970",
    },
    {
        "school": "STARTZVILLE EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473000972",
    },
    {
        "school": "SMITHSON VALLEY H S",
        "district": "COMAL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473000974",
    },
    {
        "school": "COMAL ACADEMY",
        "district": "COMAL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481473006957",
    },
    {
        "school": "ARLON R SEAY EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473007227",
    },
    {
        "school": "SPRING BRANCH MIDDLE",
        "district": "COMAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473007559",
    },
    {
        "school": "BILL BROWN EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473021192",
    },
    {
        "school": "CARL SCHURZ EL",
        "district": "NEW BRAUNFELS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237003589",
    },
    {
        "school": "LONE STAR EARLY CHILDHOOD CENTER",
        "district": "NEW BRAUNFELS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237003590",
    },
    {
        "school": "NEW BRAUNFELS H S",
        "district": "NEW BRAUNFELS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237003591",
    },
    {
        "school": "NEW BRAUNFELS MIDDLE",
        "district": "NEW BRAUNFELS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237003592",
    },
    {
        "school": "SEELE EL",
        "district": "NEW BRAUNFELS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237003593",
    },
    {
        "school": "LAMAR EL",
        "district": "NEW BRAUNFELS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237003594",
    },
    {
        "school": "COUNTY LINE EL",
        "district": "NEW BRAUNFELS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237006147",
    },
    {
        "school": "WALNUT SPRINGS EL",
        "district": "NEW BRAUNFELS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237006762",
    },
    {
        "school": "THE NBISD LEARNING CENTER",
        "district": "NEW BRAUNFELS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483237007840",
    },
    {
        "school": "MEMORIAL EL",
        "district": "NEW BRAUNFELS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237007841",
    },
    {
        "school": "OAKRUN MIDDLE",
        "district": "NEW BRAUNFELS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237021191",
    },
    {
        "school": "MARION H S",
        "district": "MARION ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482910003280",
    },
    {
        "school": "MARION MIDDLE",
        "district": "MARION ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482910003281",
    },
    {
        "school": "NORMA KRUEGER EL",
        "district": "MARION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482910003282",
    },
    {
        "school": "NAVARRO EL",
        "district": "NAVARRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483216003567",
    },
    {
        "school": "NAVARRO H S",
        "district": "NAVARRO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483216003568",
    },
    {
        "school": "NAVARRO J H",
        "district": "NAVARRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483216007296",
    },
    {
        "school": "RAY D CORBETT J H",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948004487",
    },
    {
        "school": "SAMUEL CLEMENS H S",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948004488",
    },
    {
        "school": "SCHERTZ EL",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948004489",
    },
    {
        "school": "WIEDERSTEIN EL",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948004490",
    },
    {
        "school": "LAURA INGALLS WILDER INT",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948007616",
    },
    {
        "school": "DOBIE J H",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948007898",
    },
    {
        "school": "BARBARA JORDAN INT",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948007899",
    },
    {
        "school": "WATTS EL",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948008223",
    },
    {
        "school": "DISCIPLINE ALTERNATIVE SCHOOL AT SAEGERT",
        "district": "SEGUIN ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483969004070",
    },
    {
        "school": "BALL EARLY CHILDHOOD CENTER",
        "district": "SEGUIN ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483969004506",
    },
    {
        "school": "JEFFERSON AVE EL",
        "district": "SEGUIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483969004508",
    },
    {
        "school": "MCQUEENEY EL",
        "district": "SEGUIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483969004509",
    },
    {
        "school": "SEGUIN H S",
        "district": "SEGUIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483969004512",
    },
    {
        "school": "ORALIA R RODRIGUEZ EL",
        "district": "SEGUIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483969006473",
    },
    {
        "school": "PATLAN EL",
        "district": "SEGUIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483969006474",
    },
    {
        "school": "KOENNECKE EL",
        "district": "SEGUIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483969006475",
    },
    {
        "school": "MERCER & BLUMBERG LRN CTR",
        "district": "SEGUIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483969006964",
    },
    {
        "school": "JIM BARNES MIDDLE",
        "district": "SEGUIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483969021271",
    },
    {
        "school": "BRIESEMEISTER MIDDLE",
        "district": "SEGUIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483969021272",
    },
    {
        "school": "WEINERT EL",
        "district": "SEGUIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483969021274",
    },
    {
        "school": "VOGEL EL",
        "district": "SEGUIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483969021275",
    },
    {
        "school": "BOERNE H S",
        "district": "BOERNE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071000535",
    },
    {
        "school": "BOERNE MIDDLE NORTH",
        "district": "BOERNE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071000537",
    },
    {
        "school": "CURINGTON EL",
        "district": "BOERNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071000538",
    },
    {
        "school": "FABRA EL",
        "district": "BOERNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071006367",
    },
    {
        "school": "BOERNE ALTER SCH",
        "district": "BOERNE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481071008686",
    },
    {
        "school": "BOERNE MIDDLE SOUTH",
        "district": "BOERNE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071008859",
    },
    {
        "school": "KENDALL EL",
        "district": "BOERNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071008860",
    },
    {
        "school": "FLORESVILLE H S",
        "district": "FLORESVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481935001792",
    },
    {
        "school": "FLORESVILLE MIDDLE",
        "district": "FLORESVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481935001794",
    },
    {
        "school": "FLORESVILLE ALTER CTR",
        "district": "FLORESVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481935007499",
    },
    {
        "school": "WILSON CO J J A E P",
        "district": "FLORESVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481935008091",
    },
    {
        "school": "LA VERNIA H S",
        "district": "LA VERNIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482631002968",
    },
    {
        "school": "LA VERNIA J H",
        "district": "LA VERNIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482631006287",
    },
    {
        "school": "FLORESVILLE ALTERNATIVE EDUCATION CENTER",
        "district": "LA VERNIA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482631007500",
    },
    {
        "school": "LA VERNIA PRI",
        "district": "LA VERNIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482631009107",
    },
    {
        "school": "POTH EL",
        "district": "POTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483555004031",
    },
    {
        "school": "POTH H S",
        "district": "POTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483555004032",
    },
    {
        "school": "POTH J H",
        "district": "POTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483555004033",
    },
    {
        "school": "WILSON CO J J A E P",
        "district": "POTH ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483555008960",
    },
    {
        "school": "STOCKDALE EL",
        "district": "STOCKDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484161004752",
    },
    {
        "school": "STOCKDALE H S",
        "district": "STOCKDALE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484161004753",
    },
    {
        "school": "STOCKDALE J H",
        "district": "STOCKDALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484161004754",
    },
    {
        "school": "ALTERNATIVE SCHOOL",
        "district": "STOCKDALE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484161008092",
    },
    {
        "school": "GRAYSON CO J J A E P",
        "district": "HOWE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482367010686",
    },
    {
        "school": "AEP CAMPUS",
        "district": "HOWE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482367010687",
    },
    {
        "school": "HAYES PRIMARY SCHOOL",
        "district": "WHITESBORO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484563009615",
    },
    {
        "school": "GRAYSON CO J J A E P",
        "district": "WHITESBORO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484563010690",
    },
    {
        "school": "BELLS EL",
        "district": "BELLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480978000447",
    },
    {
        "school": "BELLS H S",
        "district": "BELLS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480978000448",
    },
    {
        "school": "PRITCHARD J H",
        "district": "BELLS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480978006363",
    },
    {
        "school": "COLLINSVILLE H S",
        "district": "COLLINSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481458000948",
    },
    {
        "school": "DENISON H S",
        "district": "DENISON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481671001433",
    },
    {
        "school": "HOUSTON EL",
        "district": "DENISON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481671001435",
    },
    {
        "school": "HENRY SCOTT MIDDLE",
        "district": "DENISON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481671001436",
    },
    {
        "school": "HYDE PARK EL",
        "district": "DENISON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481671001437",
    },
    {
        "school": "LAMAR EL",
        "district": "DENISON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481671001438",
    },
    {
        "school": "MAYES EL",
        "district": "DENISON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481671001440",
    },
    {
        "school": "TERRELL EL",
        "district": "DENISON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481671005453",
    },
    {
        "school": "PATHWAYS H S",
        "district": "DENISON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481671007294",
    },
    {
        "school": "GUNTER EL",
        "district": "GUNTER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482196002212",
    },
    {
        "school": "GUNTER H S",
        "district": "GUNTER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482196002213",
    },
    {
        "school": "GUNTER MIDDLE",
        "district": "GUNTER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482196006962",
    },
    {
        "school": "GRAYSON COUNTY SPECIAL EDUCATION SSA",
        "district": "GUNTER ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482196008577",
    },
    {
        "school": "SUMMIT HILL EL",
        "district": "HOWE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482367002621",
    },
    {
        "school": "HOWE H S",
        "district": "HOWE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482367002622",
    },
    {
        "school": "HOWE MIDDLE",
        "district": "HOWE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482367002623",
    },
    {
        "school": "POTTSBORO EL",
        "district": "POTTSBORO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483558004035",
    },
    {
        "school": "POTTSBORO H S",
        "district": "POTTSBORO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483558004036",
    },
    {
        "school": "POTTSBORO MIDDLE",
        "district": "POTTSBORO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483558008576",
    },
    {
        "school": "S AND S CONS EL",
        "district": "S AND S CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483840004277",
    },
    {
        "school": "S AND S CONS H S",
        "district": "S AND S CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483840004278",
    },
    {
        "school": "S AND S CONS MIDDLE",
        "district": "S AND S CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483840006169",
    },
    {
        "school": "CRUTCHFIELD EL",
        "district": "SHERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008004543",
    },
    {
        "school": "FRED DOUGLASS EARLY CHILDHOOD CENTER",
        "district": "SHERMAN ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008004545",
    },
    {
        "school": "FAIRVIEW EL",
        "district": "SHERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008004546",
    },
    {
        "school": "JEFFERSON EL",
        "district": "SHERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008004547",
    },
    {
        "school": "PINER MIDDLE",
        "district": "SHERMAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008004549",
    },
    {
        "school": "SHERMAN H S",
        "district": "SHERMAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008004550",
    },
    {
        "school": "WAKEFIELD EL",
        "district": "SHERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008004551",
    },
    {
        "school": "WASHINGTON EL",
        "district": "SHERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008004552",
    },
    {
        "school": "PERRIN LEARNING CTR",
        "district": "SHERMAN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484008006911",
    },
    {
        "school": "TRI CO JUVENILE DETENT",
        "district": "SHERMAN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484008006961",
    },
    {
        "school": "COOKE/FANNIN/GRAYSON CO JUVENILE POST AJUD FAC",
        "district": "SHERMAN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484008008794",
    },
    {
        "school": "DILLINGHAM INT",
        "district": "SHERMAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008021264",
    },
    {
        "school": "TIOGA SCHOOL",
        "district": "TIOGA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484287004887",
    },
    {
        "school": "TOM BEAN EL",
        "district": "TOM BEAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484293004890",
    },
    {
        "school": "TOM BEAN H S",
        "district": "TOM BEAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484293004891",
    },
    {
        "school": "TOM BEAN MIDDLE",
        "district": "TOM BEAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484293006622",
    },
    {
        "school": "JOHN AND NELDA PARTIN EL",
        "district": "VAN ALSTYNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484389004981",
    },
    {
        "school": "VAN ALSTYNE H S",
        "district": "VAN ALSTYNE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484389004982",
    },
    {
        "school": "VAN ALSTYNE J H",
        "district": "VAN ALSTYNE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484389004983",
    },
    {
        "school": "WHITESBORO INTERMEDIATE",
        "district": "WHITESBORO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484563005186",
    },
    {
        "school": "WHITESBORO H S",
        "district": "WHITESBORO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484563005187",
    },
    {
        "school": "WHITESBORO MIDDLE",
        "district": "WHITESBORO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484563005188",
    },
    {
        "school": "WHITEWRIGHT EL",
        "district": "WHITEWRIGHT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484567005189",
    },
    {
        "school": "WHITEWRIGHT H S",
        "district": "WHITEWRIGHT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484567005190",
    },
    {
        "school": "WHITEWRIGHT MIDDLE",
        "district": "WHITEWRIGHT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484567005191",
    },
    {
        "school": "HERMLEIGH SCHOOL",
        "district": "HERMLEIGH ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482304002343",
    },
    {
        "school": "IRA SCHOOL",
        "district": "IRA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482430002708",
    },
    {
        "school": "SNYDER H S",
        "district": "SNYDER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484065004601",
    },
    {
        "school": "SNYDER J H",
        "district": "SNYDER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484065004602",
    },
    {
        "school": "HUCKABAY DAEP",
        "district": "HUCKABAY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482376011487",
    },
    {
        "school": "PREMIER H S OF COMANCHE/EARLY",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708780",
    },
    {
        "school": "BLUFF DALE EL",
        "district": "BLUFF DALE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481062000532",
    },
    {
        "school": "DUBLIN EL",
        "district": "DUBLIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481758001511",
    },
    {
        "school": "DUBLIN H S",
        "district": "DUBLIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481758001512",
    },
    {
        "school": "DUBLIN INT",
        "district": "DUBLIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481758008211",
    },
    {
        "school": "HUCKABAY SCHOOL",
        "district": "HUCKABAY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482376002629",
    },
    {
        "school": "LINGLEVILLE SCHOOL",
        "district": "LINGLEVILLE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482760003102",
    },
    {
        "school": "MORGAN MILL EL",
        "district": "MORGAN MILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483141003521",
    },
    {
        "school": "CENTRAL EL",
        "district": "STEPHENVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484152004744",
    },
    {
        "school": "CHAMBERLIN EL",
        "district": "STEPHENVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484152004745",
    },
    {
        "school": "STEPHENVILLE H S",
        "district": "STEPHENVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484152004746",
    },
    {
        "school": "HENDERSON J H",
        "district": "STEPHENVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484152004747",
    },
    {
        "school": "GILBERT INT",
        "district": "STEPHENVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484152006045",
    },
    {
        "school": "HOOK EL",
        "district": "STEPHENVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484152008554",
    },
    {
        "school": "THREE WAY ISD",
        "district": "THREE WAY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484272004876",
    },
    {
        "school": "HUSTON ACADEMY",
        "district": "ERATH EXCELS ACADEMY INC",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480015908364",
    },
    {
        "school": "COMO-PICKTON SCHOOL",
        "district": "COMO-PICKTON CISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481488000989",
    },
    {
        "school": "CUMBY EL",
        "district": "CUMBY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481602001173",
    },
    {
        "school": "CUMBY H S",
        "district": "CUMBY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481602001174",
    },
    {
        "school": "MILLER GROVE SCHOOL",
        "district": "MILLER GROVE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483081003475",
    },
    {
        "school": "NORTH HOPKINS EL",
        "district": "NORTH HOPKINS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483297003663",
    },
    {
        "school": "NORTH HOPKINS H S",
        "district": "NORTH HOPKINS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483297003664",
    },
    {
        "school": "SALTILLO SCHOOL",
        "district": "SALTILLO ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483861004291",
    },
    {
        "school": "SULPHUR BLUFF ISD",
        "district": "SULPHUR BLUFF ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484179004763",
    },
    {
        "school": "BOWIE PRI",
        "district": "SULPHUR SPRINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484182004765",
    },
    {
        "school": "DOUGLASS ECLC",
        "district": "SULPHUR SPRINGS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484182004766",
    },
    {
        "school": "LAMAR PRI",
        "district": "SULPHUR SPRINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484182004768",
    },
    {
        "school": "SULPHUR SPRINGS H S",
        "district": "SULPHUR SPRINGS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484182004769",
    },
    {
        "school": "SULPHUR SPRINGS MIDDLE",
        "district": "SULPHUR SPRINGS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484182004770",
    },
    {
        "school": "TRAVIS PRI",
        "district": "SULPHUR SPRINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484182004771",
    },
    {
        "school": "BARBARA BUSH PRI",
        "district": "SULPHUR SPRINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484182007660",
    },
    {
        "school": "BLACKWELL SCHOOL",
        "district": "BLACKWELL CISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000500513",
    },
    {
        "school": "HIGHLAND SCHOOL",
        "district": "HIGHLAND ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482319002353",
    },
    {
        "school": "ROSCOE EL",
        "district": "ROSCOE COLLEGIATE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483786004237",
    },
    {
        "school": "ROSCOE COLLEGIATE H S",
        "district": "ROSCOE COLLEGIATE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483786004238",
    },
    {
        "school": "SOUTHEAST EARLY CHILDHOOD CENTER",
        "district": "SWEETWATER ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484203004783",
    },
    {
        "school": "EAST RIDGE EL",
        "district": "SWEETWATER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484203004784",
    },
    {
        "school": "SWEETWATER INT",
        "district": "SWEETWATER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484203004785",
    },
    {
        "school": "SWEETWATER MIDDLE",
        "district": "SWEETWATER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484203004786",
    },
    {
        "school": "SOUTHEAST EL",
        "district": "SWEETWATER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484203004787",
    },
    {
        "school": "SWEETWATER H S",
        "district": "SWEETWATER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484203004788",
    },
    {
        "school": "NEW BOSTON DAEP",
        "district": "NEW BOSTON ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483234011143",
    },
    {
        "school": "JAMES BOWIE MIDDLE",
        "district": "SIMMS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484032009495",
    },
    {
        "school": "MARTHA & JOSH MORRISS MATH & ENGINEERING EL",
        "district": "TEXARKANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248011422",
    },
    {
        "school": "DEKALB EL",
        "district": "DEKALB ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481657001421",
    },
    {
        "school": "DEKALB H S",
        "district": "DEKALB ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481657001422",
    },
    {
        "school": "DEKALB MIDDLE",
        "district": "DEKALB ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481657001423",
    },
    {
        "school": "HOOKS EL",
        "district": "HOOKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482349002381",
    },
    {
        "school": "HOOKS H S",
        "district": "HOOKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482349002382",
    },
    {
        "school": "HOOKS J H",
        "district": "HOOKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482349002383",
    },
    {
        "school": "HUBBARD ISD",
        "district": "HUBBARD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482370002624",
    },
    {
        "school": "LEARY EL",
        "district": "LEARY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482706003045",
    },
    {
        "school": "LIBERTY-EYLAU EARLY CHILDHOOD CENTER",
        "district": "LIBERTY-EYLAU ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482739003078",
    },
    {
        "school": "LIBERTY-EYLAU H S",
        "district": "LIBERTY-EYLAU ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482739003079",
    },
    {
        "school": "LIBERTY-EYLAU EL",
        "district": "LIBERTY-EYLAU ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482739003081",
    },
    {
        "school": "LIBERTY-EYLAU MIDDLE",
        "district": "LIBERTY-EYLAU ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482739003082",
    },
    {
        "school": "MALTA EL",
        "district": "MALTA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482883003261",
    },
    {
        "school": "MAUD SCHOOL",
        "district": "MAUD ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482946003317",
    },
    {
        "school": "CRESTVIEW EL",
        "district": "NEW BOSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483234003585",
    },
    {
        "school": "NEW BOSTON H S",
        "district": "NEW BOSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483234003586",
    },
    {
        "school": "NEW BOSTON MIDDLE",
        "district": "NEW BOSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483234003587",
    },
    {
        "school": "PLEASANT GROVE EL",
        "district": "PLEASANT GROVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483513003979",
    },
    {
        "school": "PLEASANT GROVE H S",
        "district": "PLEASANT GROVE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483513006031",
    },
    {
        "school": "PLEASANT GROVE MIDDLE",
        "district": "PLEASANT GROVE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483513006311",
    },
    {
        "school": "RED LICK EL",
        "district": "RED LICK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483663004103",
    },
    {
        "school": "RED LICK MIDDLE",
        "district": "RED LICK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483663007191",
    },
    {
        "school": "REDWATER EL",
        "district": "REDWATER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483675004108",
    },
    {
        "school": "REDWATER H S",
        "district": "REDWATER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483675004109",
    },
    {
        "school": "REDWATER J H",
        "district": "REDWATER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483675005801",
    },
    {
        "school": "REDWATER MIDDLE",
        "district": "REDWATER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483675008123",
    },
    {
        "school": "JAMES BOWIE EL",
        "district": "SIMMS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484032004566",
    },
    {
        "school": "JAMES BOWIE H S",
        "district": "SIMMS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484032004567",
    },
    {
        "school": "HIGHLAND PARK EL",
        "district": "TEXARKANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248004847",
    },
    {
        "school": "WESTLAWN EL",
        "district": "TEXARKANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248004848",
    },
    {
        "school": "NASH EL",
        "district": "TEXARKANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248004850",
    },
    {
        "school": "TEXAS MIDDLE",
        "district": "TEXARKANA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248004852",
    },
    {
        "school": "TEXAS H S",
        "district": "TEXARKANA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248004854",
    },
    {
        "school": "WAKE VILLAGE EL",
        "district": "TEXARKANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248004855",
    },
    {
        "school": "PAUL LAURENCE DUNBAR EARLY EDUCATION CENTER",
        "district": "TEXARKANA ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248006049",
    },
    {
        "school": "THERON JONES EARLY LITERACY CENTER",
        "district": "TEXARKANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248006335",
    },
    {
        "school": "SPRING LAKE PARK EL",
        "district": "TEXARKANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248006336",
    },
    {
        "school": "OPTIONS",
        "district": "TEXARKANA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484248008124",
    },
    {
        "school": "CUMBERLAND ACADEMY",
        "district": "CUMBERLAND ACADEMY",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480003408020",
    },
    {
        "school": "ARP EL",
        "district": "ARP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480873000269",
    },
    {
        "school": "ARP H S",
        "district": "ARP ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480873000270",
    },
    {
        "school": "ARP J H",
        "district": "ARP ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480873006068",
    },
    {
        "school": "BULLARD EL",
        "district": "BULLARD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481206000702",
    },
    {
        "school": "BULLARD H S",
        "district": "BULLARD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481206000703",
    },
    {
        "school": "BULLARD MIDDLE",
        "district": "BULLARD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481206005664",
    },
    {
        "school": "BULLARD INT",
        "district": "BULLARD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481206009020",
    },
    {
        "school": "WISE EL FINE ARTS MAGNET",
        "district": "CHAPEL HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481365000858",
    },
    {
        "school": "CHAPEL HILL H S",
        "district": "CHAPEL HILL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481365000859",
    },
    {
        "school": "W L KISSAM EL",
        "district": "CHAPEL HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481365005767",
    },
    {
        "school": "CHAPEL HILL MIDDLE",
        "district": "CHAPEL HILL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481365005970",
    },
    {
        "school": "JACKSON EL",
        "district": "CHAPEL HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481365006078",
    },
    {
        "school": "LINDALE H S",
        "district": "LINDALE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482751003091",
    },
    {
        "school": "VELMA PENNY EL",
        "district": "LINDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482751003092",
    },
    {
        "school": "LINDALE J H",
        "district": "LINDALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482751003093",
    },
    {
        "school": "COLLEGE STREET EL",
        "district": "LINDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482751003094",
    },
    {
        "school": "E J MOSS INT",
        "district": "LINDALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482751007104",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "LINDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482751009021",
    },
    {
        "school": "TROUP EL",
        "district": "TROUP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484323004909",
    },
    {
        "school": "TROUP H S",
        "district": "TROUP ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484323004910",
    },
    {
        "school": "TROUP MIDDLE",
        "district": "TROUP ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484323004911",
    },
    {
        "school": "BELL EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004927",
    },
    {
        "school": "BIRDWELL EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004928",
    },
    {
        "school": "BONNER EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004929",
    },
    {
        "school": "BOULTER MIDDLE",
        "district": "TYLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004930",
    },
    {
        "school": "CLARKSTON EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004931",
    },
    {
        "school": "DIXIE EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004932",
    },
    {
        "school": "DOUGLAS EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004934",
    },
    {
        "school": "CALDWELL ARTS ACADEMY",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004935",
    },
    {
        "school": "GRIFFIN EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004936",
    },
    {
        "school": "HOGG MIDDLE",
        "district": "TYLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004937",
    },
    {
        "school": "HUBBARD MIDDLE",
        "district": "TYLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004938",
    },
    {
        "school": "JOHN TYLER H S",
        "district": "TYLER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004939",
    },
    {
        "school": "JONES EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004940",
    },
    {
        "school": "ROBERT E LEE H S",
        "district": "TYLER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004941",
    },
    {
        "school": "MOORE MST MAGNET SCHOOL",
        "district": "TYLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004942",
    },
    {
        "school": "ORR EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004943",
    },
    {
        "school": "PEETE EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004944",
    },
    {
        "school": "RAMEY EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004945",
    },
    {
        "school": "RICE EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004946",
    },
    {
        "school": "T J AUSTIN EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004949",
    },
    {
        "school": "WOODS EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347004951",
    },
    {
        "school": "OWENS EL",
        "district": "TYLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347006180",
    },
    {
        "school": "WHITEHOUSE H S",
        "district": "WHITEHOUSE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484560005183",
    },
    {
        "school": "WHITEHOUSE J H",
        "district": "WHITEHOUSE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484560005185",
    },
    {
        "school": "WHITEHOUSE ISD - JJAEP",
        "district": "WHITEHOUSE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484560008021",
    },
    {
        "school": "WHITEHOUSE A E P",
        "district": "WHITEHOUSE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484560009023",
    },
    {
        "school": "WINONA EL",
        "district": "WINONA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484623005273",
    },
    {
        "school": "WINONA H S",
        "district": "WINONA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484623005274",
    },
    {
        "school": "WINONA MIDDLE",
        "district": "WINONA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484623005825",
    },
    {
        "school": "KNIPPA SCHOOL",
        "district": "KNIPPA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482580002911",
    },
    {
        "school": "SABINAL H S",
        "district": "SABINAL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483843004280",
    },
    {
        "school": "SABINAL EL",
        "district": "SABINAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483843006780",
    },
    {
        "school": "SABINAL MIDDLE",
        "district": "SABINAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483843007142",
    },
    {
        "school": "CLUSTER V SP ED",
        "district": "SABINAL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483843009084",
    },
    {
        "school": "UTOPIA SCHOOL",
        "district": "UTOPIA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484368004965",
    },
    {
        "school": "ANTHON EL",
        "district": "UVALDE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484372004966",
    },
    {
        "school": "DALTON EL",
        "district": "UVALDE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484372004969",
    },
    {
        "school": "ROBB EL",
        "district": "UVALDE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484372004970",
    },
    {
        "school": "UVALDE H S",
        "district": "UVALDE CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484372004971",
    },
    {
        "school": "MORALES J H",
        "district": "UVALDE CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484372021533",
    },
    {
        "school": "HARROLD SCHOOL",
        "district": "HARROLD ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482262002298",
    },
    {
        "school": "NORTHSIDE SCHOOL",
        "district": "NORTHSIDE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483309003728",
    },
    {
        "school": "SHIVE EL",
        "district": "VERNON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484411004997",
    },
    {
        "school": "VERNON H S",
        "district": "VERNON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484411004998",
    },
    {
        "school": "VERNON MIDDLE",
        "district": "VERNON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484411004999",
    },
    {
        "school": "T G MCCORD EL",
        "district": "VERNON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484411005823",
    },
    {
        "school": "NORTH TEXAS STATE HOSPITAL - AFP - VERNON",
        "district": "VERNON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484411006493",
    },
    {
        "school": "CALHOUN H S",
        "district": "CALHOUN COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481248000741",
    },
    {
        "school": "HARRISON/JEFFERSON/MADISON COMPLEX",
        "district": "CALHOUN COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481248000744",
    },
    {
        "school": "JACKSON/ROOSEVELT COMPLEX",
        "district": "CALHOUN COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481248000745",
    },
    {
        "school": "PORT O CONNOR EL",
        "district": "CALHOUN COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481248000749",
    },
    {
        "school": "SEADRIFT SCHOOL",
        "district": "CALHOUN COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481248000751",
    },
    {
        "school": "TRAVIS MIDDLE",
        "district": "CALHOUN COUNTY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481248000752",
    },
    {
        "school": "HOPE H S",
        "district": "CALHOUN COUNTY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481248007199",
    },
    {
        "school": "GOLIAD H S",
        "district": "GOLIAD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482103002096",
    },
    {
        "school": "GOLIAD MIDDLE",
        "district": "GOLIAD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482103002097",
    },
    {
        "school": "BLOOMINGTON EL",
        "district": "BLOOMINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481050000526",
    },
    {
        "school": "BLOOMINGTON H S",
        "district": "BLOOMINGTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481050000527",
    },
    {
        "school": "PLACEDO EL",
        "district": "BLOOMINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481050000529",
    },
    {
        "school": "BLOOMINGTON J H",
        "district": "BLOOMINGTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481050007744",
    },
    {
        "school": "NURSERY EL",
        "district": "NURSERY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483327003740",
    },
    {
        "school": "WILLIAM WOOD EL",
        "district": "VICTORIA ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415002698",
    },
    {
        "school": "ALOE EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005000",
    },
    {
        "school": "STROMAN MIDDLE",
        "district": "VICTORIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005001",
    },
    {
        "school": "DUDLEY EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005002",
    },
    {
        "school": "F W GROSS EL",
        "district": "VICTORIA ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005003",
    },
    {
        "school": "HOPKINS EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005006",
    },
    {
        "school": "HOWELL MIDDLE",
        "district": "VICTORIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005007",
    },
    {
        "school": "CRAIN EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005008",
    },
    {
        "school": "MISSION VALLEY EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005009",
    },
    {
        "school": "O'CONNOR EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005011",
    },
    {
        "school": "ROWLAND EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005013",
    },
    {
        "school": "SHIELDS EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005014",
    },
    {
        "school": "SMITH EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005015",
    },
    {
        "school": "VICKERS EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005018",
    },
    {
        "school": "PATTI WELDER MIDDLE",
        "district": "VICTORIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005020",
    },
    {
        "school": "LIBERTY CREDIT RECOVERY",
        "district": "VICTORIA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484415005579",
    },
    {
        "school": "MARTIN DE LEON EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415005609",
    },
    {
        "school": "LIBERTY DAEP",
        "district": "VICTORIA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484415007745",
    },
    {
        "school": "VICTORIA REGIONAL JUVENILE JUSTICE CENTER",
        "district": "VICTORIA ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484415008072",
    },
    {
        "school": "GUADALUPE EL",
        "district": "VICTORIA ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415008073",
    },
    {
        "school": "C O CHANDLER EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415009087",
    },
    {
        "school": "MARLIN ALTERNATIVE EDUCATION PROGRAM",
        "district": "RIESEL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483711010953",
    },
    {
        "school": "QUINN CAMPUS PUBLIC MIDDLE",
        "district": "RAPOPORT ACADEMY PUBLIC SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480004209586",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "BOSQUEVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481091010956",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "CHINA SPRING ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481396009348",
    },
    {
        "school": "BILL LOGUE JUVENILE DETENTION CENTER",
        "district": "CHINA SPRING ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481396010954",
    },
    {
        "school": "CONNALLY EL",
        "district": "CONNALLY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481497009349",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "CRAWFORD ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481560009340",
    },
    {
        "school": "MCLENNAN COUNTY CHALLENGE ACADEMY",
        "district": "HALLSBURG ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482214010957",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "LORENA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482820009581",
    },
    {
        "school": "LORENA PRI",
        "district": "LORENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482820010950",
    },
    {
        "school": "MART ACADEMIC ALERNATIVE PROGRAM",
        "district": "MART ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482919009343",
    },
    {
        "school": "MCLENNAN CO CHALLENGE ACADEMY",
        "district": "MOODY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483129010951",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "RIESEL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483711010952",
    },
    {
        "school": "BRAZOS H S",
        "district": "WACO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484428009344",
    },
    {
        "school": "CESAR CHAVEZ MIDDLE",
        "district": "WACO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428009345",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "WEST ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484504009346",
    },
    {
        "school": "WACO CHARTER SCHOOL",
        "district": "WACO CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480002407392",
    },
    {
        "school": "AUDRE AND BERNARD RAPOPORT ACADEMY",
        "district": "RAPOPORT ACADEMY PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480004207989",
    },
    {
        "school": "AXTELL EL",
        "district": "AXTELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480915000379",
    },
    {
        "school": "AXTELL H S",
        "district": "AXTELL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480915000380",
    },
    {
        "school": "WACO CTR FOR YOUTH",
        "district": "AXTELL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480915006358",
    },
    {
        "school": "AXTELL BRUCEVILLE-EDDY LEARNING CENTER",
        "district": "AXTELL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480915007687",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "AXTELL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480915008981",
    },
    {
        "school": "AXTELL MIDDLE SCHOOL",
        "district": "AXTELL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480915008982",
    },
    {
        "school": "BOSQUEVILLE H S",
        "district": "BOSQUEVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481091006073",
    },
    {
        "school": "BOSQUEVILLE EL",
        "district": "BOSQUEVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481091007693",
    },
    {
        "school": "BRUCEVILLE-EDDY EL",
        "district": "BRUCEVILLE-EDDY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481173000678",
    },
    {
        "school": "BRUCEVILLE-EDDY H S",
        "district": "BRUCEVILLE-EDDY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481173000679",
    },
    {
        "school": "BRUCEVILLE-EDDY J H",
        "district": "BRUCEVILLE-EDDY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481173007398",
    },
    {
        "school": "AXTELL/BRUCEVILLE-EDDY LEARNING CENTER",
        "district": "BRUCEVILLE-EDDY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481173007994",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "BRUCEVILLE-EDDY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481173008873",
    },
    {
        "school": "BRUCEVILLE-EDDY INT",
        "district": "BRUCEVILLE-EDDY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481173008983",
    },
    {
        "school": "CHINA SPRING EL",
        "district": "CHINA SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481396000880",
    },
    {
        "school": "CHINA SPRING H S",
        "district": "CHINA SPRING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481396000881",
    },
    {
        "school": "CHINA SPRING MIDDLE",
        "district": "CHINA SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481396005673",
    },
    {
        "school": "TURN AROUND GRADUATE",
        "district": "CHINA SPRING ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481396007995",
    },
    {
        "school": "DAEP",
        "district": "CHINA SPRING ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481396007996",
    },
    {
        "school": "CHINA SPRING INT",
        "district": "CHINA SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481396008874",
    },
    {
        "school": "CONNALLY HIGH SCHOOL",
        "district": "CONNALLY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481497000992",
    },
    {
        "school": "CONNALLY J H",
        "district": "CONNALLY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481497000993",
    },
    {
        "school": "CONNALLY PRI",
        "district": "CONNALLY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481497000994",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "CONNALLY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481497007692",
    },
    {
        "school": "CRAWFORD EL",
        "district": "CRAWFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481560001130",
    },
    {
        "school": "CRAWFORD H S",
        "district": "CRAWFORD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481560001131",
    },
    {
        "school": "GHOLSON SCHOOL",
        "district": "GHOLSON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482061002073",
    },
    {
        "school": "HALLSBURG SCHOOL",
        "district": "HALLSBURG ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482214002225",
    },
    {
        "school": "LA VEGA INT H P MILES CAMPUS",
        "district": "LA VEGA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482628002963",
    },
    {
        "school": "LA VEGA H S",
        "district": "LA VEGA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482628002965",
    },
    {
        "school": "LA VEGA J H GEORGE DIXON CAMPUS",
        "district": "LA VEGA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482628002966",
    },
    {
        "school": "LA VEGA PRI PHIL BANCALE CAMPUS",
        "district": "LA VEGA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482628006129",
    },
    {
        "school": "LA VEGA EL",
        "district": "LA VEGA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482628007035",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "LA VEGA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482628007395",
    },
    {
        "school": "LORENA EL",
        "district": "LORENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482820003157",
    },
    {
        "school": "LORENA HIGH",
        "district": "LORENA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482820003158",
    },
    {
        "school": "LORENA MIDDLE",
        "district": "LORENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482820006139",
    },
    {
        "school": "MART EL",
        "district": "MART ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482919003300",
    },
    {
        "school": "MART H S",
        "district": "MART ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482919003301",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "MART ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482919008978",
    },
    {
        "school": "ISBILL J H",
        "district": "MCGREGOR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482982003353",
    },
    {
        "school": "MCGREGOR H S",
        "district": "MCGREGOR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482982003354",
    },
    {
        "school": "MCGREGOR EL",
        "district": "MCGREGOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482982003355",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "MCGREGOR ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482982008979",
    },
    {
        "school": "WOODWAY EL",
        "district": "MIDWAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483064003462",
    },
    {
        "school": "MIDWAY H S",
        "district": "MIDWAY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483064003463",
    },
    {
        "school": "MIDWAY MIDDLE",
        "district": "MIDWAY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483064003464",
    },
    {
        "school": "SPEEGLEVILLE EL",
        "district": "MIDWAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483064005554",
    },
    {
        "school": "HEWITT EL",
        "district": "MIDWAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483064006452",
    },
    {
        "school": "SPRING VALLEY EL",
        "district": "MIDWAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483064006453",
    },
    {
        "school": "SOUTH BOSQUE EL",
        "district": "MIDWAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483064006886",
    },
    {
        "school": "WOODGATE INT",
        "district": "MIDWAY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483064007033",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "MIDWAY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483064007394",
    },
    {
        "school": "MOODY EL",
        "district": "MOODY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483129003515",
    },
    {
        "school": "MOODY H S",
        "district": "MOODY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483129003516",
    },
    {
        "school": "MOODY PRE-K",
        "district": "MOODY ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483129007037",
    },
    {
        "school": "MOODY MIDDLE",
        "district": "MOODY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483129021424",
    },
    {
        "school": "RIESEL SCHOOL",
        "district": "RIESEL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483711004171",
    },
    {
        "school": "FOSTER EL",
        "district": "RIESEL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483711008869",
    },
    {
        "school": "ROBINSON PRI",
        "district": "ROBINSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483741004197",
    },
    {
        "school": "ROBINSON H S",
        "district": "ROBINSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483741004198",
    },
    {
        "school": "ROBINSON J H",
        "district": "ROBINSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483741004199",
    },
    {
        "school": "ROBINSON EL",
        "district": "ROBINSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483741004200",
    },
    {
        "school": "ROBINSON INT",
        "district": "ROBINSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483741006901",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "ROBINSON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483741008985",
    },
    {
        "school": "ALTA VISTA EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005028",
    },
    {
        "school": "BELL'S HILL EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005030",
    },
    {
        "school": "CEDAR RIDGE EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005032",
    },
    {
        "school": "CRESTVIEW EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005033",
    },
    {
        "school": "DEAN HIGHLAND EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005034",
    },
    {
        "school": "LAKE AIR MONTESSORI SCHOOL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005035",
    },
    {
        "school": "J H HINES EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005039",
    },
    {
        "school": "KENDRICK EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005041",
    },
    {
        "school": "MOUNTAINVIEW EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005047",
    },
    {
        "school": "HILLCREST PDS MAGNET",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005048",
    },
    {
        "school": "PARKDALE EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005051",
    },
    {
        "school": "PROVIDENT HEIGHTS EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005052",
    },
    {
        "school": "WACO H S",
        "district": "WACO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005054",
    },
    {
        "school": "TENNYSON MIDDLE",
        "district": "WACO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005058",
    },
    {
        "school": "UNIVERSITY H S",
        "district": "WACO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428005059",
    },
    {
        "school": "G W CARVER MIDDLE",
        "district": "WACO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428006341",
    },
    {
        "school": "SOUTH WACO EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428006798",
    },
    {
        "school": "G L WILEY OPPORTUNITY CENTER",
        "district": "WACO ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484428007039",
    },
    {
        "school": "CHALLENGE ACADEMY",
        "district": "WACO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484428007397",
    },
    {
        "school": "BROOK AVENUE EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428008333",
    },
    {
        "school": "BILL LOGUE DETENTION CENTER",
        "district": "WACO ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484428008870",
    },
    {
        "school": "WEST AVENUE EL",
        "district": "WACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428008980",
    },
    {
        "school": "WEST BROOKHAVEN YOUTH RANCH SCHOOL",
        "district": "WEST ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484504001742",
    },
    {
        "school": "WEST EL",
        "district": "WEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484504005130",
    },
    {
        "school": "WEST H S",
        "district": "WEST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484504005131",
    },
    {
        "school": "WEST MIDDLE",
        "district": "WEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484504006187",
    },
    {
        "school": "WICHITA CO JJAEP",
        "district": "BURKBURNETT ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481212011089",
    },
    {
        "school": "WICHITA COUNTY J J A E P",
        "district": "CITY VIEW ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481413011091",
    },
    {
        "school": "IOWA PARK JJAEP",
        "district": "IOWA PARK CISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482426011090",
    },
    {
        "school": "WICHITA COUNTY JUVENILE JUSTICE AEP",
        "district": "WICHITA FALLS ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484578009422",
    },
    {
        "school": "BELLEVUE SCHOOL",
        "district": "BELLEVUE ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480975000446",
    },
    {
        "school": "HENRIETTA EL",
        "district": "HENRIETTA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482298002330",
    },
    {
        "school": "HENRIETTA H S",
        "district": "HENRIETTA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482298002331",
    },
    {
        "school": "HENRIETTA MIDDLE",
        "district": "HENRIETTA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482298002332",
    },
    {
        "school": "MIDWAY SCHOOL",
        "district": "MIDWAY ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483066003461",
    },
    {
        "school": "PETROLIA JUNIOR HIGH/HIGH SCHOOL",
        "district": "PETROLIA CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483471003896",
    },
    {
        "school": "PETROLIA EL",
        "district": "PETROLIA CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483471007214",
    },
    {
        "school": "ARCHER CITY EL",
        "district": "ARCHER CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480861000228",
    },
    {
        "school": "ARCHER CITY H S",
        "district": "ARCHER CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480861000229",
    },
    {
        "school": "HOLLIDAY EL",
        "district": "HOLLIDAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482340002374",
    },
    {
        "school": "HOLLIDAY H S",
        "district": "HOLLIDAY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482340002375",
    },
    {
        "school": "HOLLIDAY MIDDLE",
        "district": "HOLLIDAY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482340006118",
    },
    {
        "school": "WINDTHORST EL",
        "district": "WINDTHORST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484608005264",
    },
    {
        "school": "WINDTHORST H S",
        "district": "WINDTHORST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484608005265",
    },
    {
        "school": "BURKBURNETT H S",
        "district": "BURKBURNETT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481212000707",
    },
    {
        "school": "BURKBURNETT MIDDLE",
        "district": "BURKBURNETT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481212000708",
    },
    {
        "school": "OVERTON RAY EL",
        "district": "BURKBURNETT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481212000709",
    },
    {
        "school": "I C EVANS EL",
        "district": "BURKBURNETT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481212000710",
    },
    {
        "school": "JOHN G TOWER EL",
        "district": "BURKBURNETT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481212000711",
    },
    {
        "school": "GATEWAY STUDENT SUPPORT CTR",
        "district": "BURKBURNETT ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481212007480",
    },
    {
        "school": "CITY VIEW EL",
        "district": "CITY VIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481413000891",
    },
    {
        "school": "CITY VIEW JUNIOR/SENIOR HIGH",
        "district": "CITY VIEW ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481413008954",
    },
    {
        "school": "ELECTRA EL",
        "district": "ELECTRA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481833001723",
    },
    {
        "school": "ELECTRA JUNIOR/SENIOR HIGH",
        "district": "ELECTRA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481833001724",
    },
    {
        "school": "BRADFORD EL",
        "district": "IOWA PARK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482426002702",
    },
    {
        "school": "IOWA PARK H S",
        "district": "IOWA PARK CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482426002703",
    },
    {
        "school": "W F GEORGE MIDDLE",
        "district": "IOWA PARK CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482426002704",
    },
    {
        "school": "KIDWELL EL",
        "district": "IOWA PARK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482426002705",
    },
    {
        "school": "BURGESS EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005202",
    },
    {
        "school": "CROCKETT EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005203",
    },
    {
        "school": "CUNNINGHAM SCHOOL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005204",
    },
    {
        "school": "FAIN EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005205",
    },
    {
        "school": "FOWLER EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005207",
    },
    {
        "school": "FRANKLIN EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005208",
    },
    {
        "school": "HAYNES EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005209",
    },
    {
        "school": "HIRSCHI H S",
        "district": "WICHITA FALLS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005210",
    },
    {
        "school": "JEFFERSON EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005214",
    },
    {
        "school": "KIRBY MIDDLE",
        "district": "WICHITA FALLS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005215",
    },
    {
        "school": "LAMAR EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005216",
    },
    {
        "school": "MCNIEL MIDDLE",
        "district": "WICHITA FALLS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005218",
    },
    {
        "school": "MILAM EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005219",
    },
    {
        "school": "RIDER H S",
        "district": "WICHITA FALLS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005220",
    },
    {
        "school": "SHEPPARD AFB EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005221",
    },
    {
        "school": "BOOKER T WASHINGTON EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005222",
    },
    {
        "school": "WICHITA FALLS H S",
        "district": "WICHITA FALLS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578005223",
    },
    {
        "school": "WEST FOUNDATION EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578007482",
    },
    {
        "school": "BROOK VILLAGE EARLY CHILDHOOD",
        "district": "WICHITA FALLS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578008080",
    },
    {
        "school": "DENVER CTR",
        "district": "WICHITA FALLS ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484578009094",
    },
    {
        "school": "NORTHWEST HEAD START",
        "district": "WICHITA FALLS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578009095",
    },
    {
        "school": "Intech Collegiate High School",
        "district": "Intech Collegiate High School",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003901129",
    },
    {
        "school": "Spectrum Academy - NSL",
        "district": "Spectrum Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004201137",
    },
    {
        "school": "Syracuse Arts Academy - Antelope",
        "district": "Syracuse Arts Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004401145",
    },
    {
        "school": "Legacy Preparatory Academy",
        "district": "Legacy Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004501146",
    },
    {
        "school": "Parkside School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001114",
    },
    {
        "school": "Iron Springs School",
        "district": "Iron District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039001120",
    },
    {
        "school": "Three Peaks School",
        "district": "Iron District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039001121",
    },
    {
        "school": "Canyon View Middle",
        "district": "Iron District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039001122",
    },
    {
        "school": "Channing Hall",
        "district": "Channing Hall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004001130",
    },
    {
        "school": "Monticello Academy",
        "district": "Monticello Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004901150",
    },
    {
        "school": "Salt Lake School for the Performing Arts",
        "district": "Salt Lake School for the Performing Arts",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490005001151",
    },
    {
        "school": "Paradigm High School",
        "district": "Paradigm High School",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490005201153",
    },
    {
        "school": "Dual Immersion Academy",
        "district": "Dual Immersion Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490007301187",
    },
    {
        "school": "Gearld Wright School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036001115",
    },
    {
        "school": "Spring Lane School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036001116",
    },
    {
        "school": "Butterfield Canyon School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001123",
    },
    {
        "school": "Jordan Academy for Technology and Careers - North",
        "district": "Jordan District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "UT",
        "nces_id": "490042001186",
    },
    {
        "school": "Fox Hollow School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001111",
    },
    {
        "school": "Harvest School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001112",
    },
    {
        "school": "Ridgeline School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001113",
    },
    {
        "school": "Alpine Online School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001154",
    },
    {
        "school": "Renaissance Academy",
        "district": "Renaissance Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003801128",
    },
    {
        "school": "Lakeview Academy",
        "district": "Lakeview Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004301144",
    },
    {
        "school": "Noah Webster Academy",
        "district": "Noah Webster Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004801149",
    },
    {
        "school": "Mountainville Academy",
        "district": "Mountainville Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490005101152",
    },
    {
        "school": "C.S. Lewis Academy",
        "district": "C.S. Lewis Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490007401190",
    },
    {
        "school": "East Meadows School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001125",
    },
    {
        "school": "Foothills School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001126",
    },
    {
        "school": "Mapleton Junior High",
        "district": "Nebo District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001127",
    },
    {
        "school": "Orchard Hills School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001155",
    },
    {
        "school": "Old Mill School",
        "district": "Wasatch District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490111001162",
    },
    {
        "school": "George Washington Academy",
        "district": "George Washington Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004601147",
    },
    {
        "school": "Coral Canyon School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001132",
    },
    {
        "school": "Horizon School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001133",
    },
    {
        "school": "Hurricane Intermediate",
        "district": "Washington District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001134",
    },
    {
        "school": "Utah Online K8",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001161",
    },
    {
        "school": "Entheos Academy Kearns",
        "district": "Entheos Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004101136",
    },
    {
        "school": "Minersville School",
        "district": "Beaver District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006000912",
    },
    {
        "school": "Moab Charter School",
        "district": "Moab Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003501085",
    },
    {
        "school": "Big Water High",
        "district": "Kane District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490048000953",
    },
    {
        "school": "Garrison 7 & 8th",
        "district": "Millard District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490054000955",
    },
    {
        "school": "Lake Powell High School",
        "district": "Kane District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490048000954",
    },
    {
        "school": "Soldier Hollow Charter School",
        "district": "Soldier Hollow Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490001100587",
    },
    {
        "school": "Richfield Preschool",
        "district": "Sevier District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490093000495",
    },
    {
        "school": "Beaver High",
        "district": "Beaver District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006000036",
    },
    {
        "school": "Belknap School",
        "district": "Beaver District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006000037",
    },
    {
        "school": "Milford High",
        "district": "Beaver District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006000038",
    },
    {
        "school": "Milford School",
        "district": "Beaver District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006000039",
    },
    {
        "school": "Minersville School",
        "district": "Beaver District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006000040",
    },
    {
        "school": "Flaming Gorge School",
        "district": "Daggett District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018000100",
    },
    {
        "school": "Manila High",
        "district": "Daggett District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018000101",
    },
    {
        "school": "Manila School",
        "district": "Daggett District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018000102",
    },
    {
        "school": "Altamont High",
        "district": "Duchesne District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000158",
    },
    {
        "school": "Altamont School",
        "district": "Duchesne District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000159",
    },
    {
        "school": "Con Amore School",
        "district": "Duchesne District",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490024000160",
    },
    {
        "school": "Duchesne High",
        "district": "Duchesne District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000162",
    },
    {
        "school": "Duchesne School",
        "district": "Duchesne District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000163",
    },
    {
        "school": "East School",
        "district": "Duchesne District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000164",
    },
    {
        "school": "Myton School",
        "district": "Duchesne District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000165",
    },
    {
        "school": "Neola School",
        "district": "Duchesne District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000166",
    },
    {
        "school": "Roosevelt Jr High",
        "district": "Duchesne District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000167",
    },
    {
        "school": "Union High",
        "district": "Duchesne District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000171",
    },
    {
        "school": "Tabiona High",
        "district": "Duchesne District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000711",
    },
    {
        "school": "Kings Peak School",
        "district": "Duchesne District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000850",
    },
    {
        "school": "Book Cliff School",
        "district": "Emery District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490027000173",
    },
    {
        "school": "Canyon View Jr High",
        "district": "Emery District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490027000174",
    },
    {
        "school": "Castle Dale School",
        "district": "Emery District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490027000175",
    },
    {
        "school": "Cleveland School",
        "district": "Emery District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490027000176",
    },
    {
        "school": "Cottonwood School",
        "district": "Emery District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490027000177",
    },
    {
        "school": "Emery High",
        "district": "Emery District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490027000178",
    },
    {
        "school": "Green River High",
        "district": "Emery District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490027000179",
    },
    {
        "school": "Huntington School",
        "district": "Emery District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490027000180",
    },
    {
        "school": "Ferron School",
        "district": "Emery District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490027000181",
    },
    {
        "school": "San Rafael Middle School",
        "district": "Emery District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490027000182",
    },
    {
        "school": "Antimony School",
        "district": "Garfield District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490030000183",
    },
    {
        "school": "Bryce Valley High",
        "district": "Garfield District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490030000184",
    },
    {
        "school": "Bryce Valley School",
        "district": "Garfield District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490030000185",
    },
    {
        "school": "Escalante High",
        "district": "Garfield District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490030000186",
    },
    {
        "school": "Escalante School",
        "district": "Garfield District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490030000187",
    },
    {
        "school": "Panguitch High",
        "district": "Garfield District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490030000188",
    },
    {
        "school": "Panguitch School",
        "district": "Garfield District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490030000189",
    },
    {
        "school": "Panguitch Middle",
        "district": "Garfield District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490030000712",
    },
    {
        "school": "Boulder School",
        "district": "Garfield District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490030000825",
    },
    {
        "school": "Grand County High",
        "district": "Grand District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490033000191",
    },
    {
        "school": "Grand County Middle",
        "district": "Grand District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490033000192",
    },
    {
        "school": "Helen M. Knight School",
        "district": "Grand District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490033000893",
    },
    {
        "school": "Delta High",
        "district": "Millard District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490054000356",
    },
    {
        "school": "Delta Middle",
        "district": "Millard District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490054000357",
    },
    {
        "school": "Fillmore School",
        "district": "Millard District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490054000359",
    },
    {
        "school": "Garrison School",
        "district": "Millard District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490054000360",
    },
    {
        "school": "Millard High",
        "district": "Millard District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490054000361",
    },
    {
        "school": "Eskdale High",
        "district": "Millard District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490054000746",
    },
    {
        "school": "Fillmore Middle",
        "district": "Millard District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490054000798",
    },
    {
        "school": "Circleville School",
        "district": "Piute District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490078000448",
    },
    {
        "school": "Oscarson School",
        "district": "Piute District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490078000449",
    },
    {
        "school": "Piute High",
        "district": "Piute District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490078000450",
    },
    {
        "school": "North Rich School",
        "district": "Rich District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490084000470",
    },
    {
        "school": "Rich High",
        "district": "Rich District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490084000471",
    },
    {
        "school": "South Rich School",
        "district": "Rich District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490084000472",
    },
    {
        "school": "Rich Middle School",
        "district": "Rich District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490084000838",
    },
    {
        "school": "Navajo Mountain High",
        "district": "San Juan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090000491",
    },
    {
        "school": "Albert R. Lyman Middle",
        "district": "San Juan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090000526",
    },
    {
        "school": "Blanding School",
        "district": "San Juan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090000527",
    },
    {
        "school": "Bluff School",
        "district": "San Juan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090000528",
    },
    {
        "school": "La Sal School",
        "district": "San Juan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090000532",
    },
    {
        "school": "Montezuma Creek School",
        "district": "San Juan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090000534",
    },
    {
        "school": "Monticello High",
        "district": "San Juan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090000535",
    },
    {
        "school": "Monticello School",
        "district": "San Juan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090000536",
    },
    {
        "school": "San Juan High",
        "district": "San Juan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090000537",
    },
    {
        "school": "Whitehorse High",
        "district": "San Juan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090000667",
    },
    {
        "school": "Monument Valley High",
        "district": "San Juan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090000802",
    },
    {
        "school": "Fairview School",
        "district": "North Sanpete District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490066000408",
    },
    {
        "school": "Moroni School",
        "district": "North Sanpete District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490066000409",
    },
    {
        "school": "Mt. Pleasant School",
        "district": "North Sanpete District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490066000411",
    },
    {
        "school": "North Sanpete High",
        "district": "North Sanpete District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490066000412",
    },
    {
        "school": "North Sanpete Middle",
        "district": "North Sanpete District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490066000413",
    },
    {
        "school": "Spring City School",
        "district": "North Sanpete District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490066000414",
    },
    {
        "school": "Fountain Green School",
        "district": "North Sanpete District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490066000662",
    },
    {
        "school": "Ephraim Middle",
        "district": "South Sanpete District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490096000548",
    },
    {
        "school": "Ephraim School",
        "district": "South Sanpete District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490096000549",
    },
    {
        "school": "Gunnison Valley High",
        "district": "South Sanpete District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490096000550",
    },
    {
        "school": "Gunnison Valley School",
        "district": "South Sanpete District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490096000551",
    },
    {
        "school": "Manti High",
        "district": "South Sanpete District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490096000553",
    },
    {
        "school": "Manti School",
        "district": "South Sanpete District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490096000554",
    },
    {
        "school": "Gunnison Valley Middle",
        "district": "South Sanpete District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490096000668",
    },
    {
        "school": "Ashman School",
        "district": "Sevier District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490093000538",
    },
    {
        "school": "Koosharem School",
        "district": "Sevier District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490093000540",
    },
    {
        "school": "Monroe School",
        "district": "Sevier District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490093000541",
    },
    {
        "school": "North Sevier High",
        "district": "Sevier District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490093000542",
    },
    {
        "school": "Pahvant School",
        "district": "Sevier District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490093000543",
    },
    {
        "school": "Richfield High",
        "district": "Sevier District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490093000544",
    },
    {
        "school": "Salina School",
        "district": "Sevier District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490093000546",
    },
    {
        "school": "South Sevier High",
        "district": "Sevier District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490093000547",
    },
    {
        "school": "North Sevier Middle",
        "district": "Sevier District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490093000782",
    },
    {
        "school": "South Sevier Middle",
        "district": "Sevier District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490093000783",
    },
    {
        "school": "Red Hills Middle",
        "district": "Sevier District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490093000839",
    },
    {
        "school": "Cedar Ridge High",
        "district": "Sevier District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490093000900",
    },
    {
        "school": "Tabiona School",
        "district": "Duchesne District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024000170",
    },
    {
        "school": "Heber Valley School",
        "district": "Wasatch District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490111000499",
    },
    {
        "school": "Midway School",
        "district": "Wasatch District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490111000592",
    },
    {
        "school": "Wasatch High",
        "district": "Wasatch District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490111000594",
    },
    {
        "school": "Rocky Mountain Middle",
        "district": "Wasatch District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490111000738",
    },
    {
        "school": "J.R. Smith School",
        "district": "Wasatch District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490111000788",
    },
    {
        "school": "Hanksville School",
        "district": "Wayne District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490117000608",
    },
    {
        "school": "Loa School",
        "district": "Wayne District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490117000609",
    },
    {
        "school": "Wayne High",
        "district": "Wayne District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490117000610",
    },
    {
        "school": "Wayne Middle",
        "district": "Wayne District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490117000611",
    },
    {
        "school": "Kanab High",
        "district": "Kane District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490048000339",
    },
    {
        "school": "Kanab School",
        "district": "Kane District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490048000340",
    },
    {
        "school": "Valley High",
        "district": "Kane District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490048000341",
    },
    {
        "school": "Valley School",
        "district": "Kane District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490048000342",
    },
    {
        "school": "Kanab Middle",
        "district": "Kane District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490048000796",
    },
    {
        "school": "Big Water School",
        "district": "Kane District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490048000887",
    },
    {
        "school": "Lake Powell School",
        "district": "Kane District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490048000897",
    },
    {
        "school": "Grouse Creek Secondary",
        "district": "Box Elder District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000915",
    },
    {
        "school": "Park Valley Secondary",
        "district": "Box Elder District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000916",
    },
    {
        "school": "Century School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000042",
    },
    {
        "school": "Bear River High",
        "district": "Box Elder District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000043",
    },
    {
        "school": "Bear River Middle",
        "district": "Box Elder District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000044",
    },
    {
        "school": "Box Elder High",
        "district": "Box Elder District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000046",
    },
    {
        "school": "Box Elder Middle",
        "district": "Box Elder District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000047",
    },
    {
        "school": "Corinne Early Learning Center",
        "district": "Box Elder District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000050",
    },
    {
        "school": "Fielding School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000051",
    },
    {
        "school": "Foothill School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000052",
    },
    {
        "school": "Garland School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000053",
    },
    {
        "school": "Grouse Creek Elementary",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000054",
    },
    {
        "school": "Lake View School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000057",
    },
    {
        "school": "Mckinley School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000060",
    },
    {
        "school": "Mountain View School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000061",
    },
    {
        "school": "North Park School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000062",
    },
    {
        "school": "Park Valley Elementary",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000064",
    },
    {
        "school": "Three Mile Creek School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000065",
    },
    {
        "school": "Snowville School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000067",
    },
    {
        "school": "Willard School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000069",
    },
    {
        "school": "Discovery School",
        "district": "Box Elder District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000123",
    },
    {
        "school": "Harris Intermediate",
        "district": "Box Elder District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000239",
    },
    {
        "school": "Young Intermediate",
        "district": "Box Elder District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490009000367",
    },
    {
        "school": "Dale Young Community High",
        "district": "Box Elder District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490009000707",
    },
    {
        "school": "Success SUU",
        "district": "Success Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003701101",
    },
    {
        "school": "Cedar City High",
        "district": "Iron District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039000278",
    },
    {
        "school": "Cedar East School",
        "district": "Iron District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039000279",
    },
    {
        "school": "Cedar Middle",
        "district": "Iron District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039000280",
    },
    {
        "school": "Cedar North School",
        "district": "Iron District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039000281",
    },
    {
        "school": "Cedar South School",
        "district": "Iron District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039000282",
    },
    {
        "school": "Escalante Valley School",
        "district": "Iron District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039000283",
    },
    {
        "school": "Parowan High",
        "district": "Iron District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039000284",
    },
    {
        "school": "Parowan School",
        "district": "Iron District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039000285",
    },
    {
        "school": "Canyon View High",
        "district": "Iron District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039000473",
    },
    {
        "school": "Enoch School",
        "district": "Iron District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039000682",
    },
    {
        "school": "Fiddlers Canyon School",
        "district": "Iron District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039000794",
    },
    {
        "school": "Southwest Educational Academy",
        "district": "Iron District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490039000872",
    },
    {
        "school": "Edith Bowen Laboratory School",
        "district": "Edith Bowen Laboratory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490007001176",
    },
    {
        "school": "Thomas Edison - North",
        "district": "Thomas Edison",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490001500820",
    },
    {
        "school": "Fast Forward High",
        "district": "Fast Forward High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490001900906",
    },
    {
        "school": "Canyon School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012001064",
    },
    {
        "school": "Bridger School",
        "district": "Logan City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490051001063",
    },
    {
        "school": "Cache High",
        "district": "Cache District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490012000041",
    },
    {
        "school": "Lewiston School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000076",
    },
    {
        "school": "Lincoln School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000077",
    },
    {
        "school": "North Cache Middle School",
        "district": "Cache District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000078",
    },
    {
        "school": "North Park School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000079",
    },
    {
        "school": "White Pine School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000080",
    },
    {
        "school": "Providence School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000081",
    },
    {
        "school": "River Heights School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000082",
    },
    {
        "school": "Sky View High",
        "district": "Cache District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000083",
    },
    {
        "school": "South Cache Middle School",
        "district": "Cache District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000084",
    },
    {
        "school": "Summit School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000085",
    },
    {
        "school": "Wellsville School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000086",
    },
    {
        "school": "Greenville School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000139",
    },
    {
        "school": "Nibley School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000598",
    },
    {
        "school": "Millville School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000674",
    },
    {
        "school": "Mountain Crest High",
        "district": "Cache District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000792",
    },
    {
        "school": "Spring Creek Middle School",
        "district": "Cache District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000846",
    },
    {
        "school": "Sunrise School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012000882",
    },
    {
        "school": "Adams School",
        "district": "Logan City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490051000343",
    },
    {
        "school": "Ellis School",
        "district": "Logan City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490051000348",
    },
    {
        "school": "Hillcrest School",
        "district": "Logan City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490051000350",
    },
    {
        "school": "Logan High",
        "district": "Logan City District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490051000351",
    },
    {
        "school": "Mount Logan Middle",
        "district": "Logan City District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490051000352",
    },
    {
        "school": "Wilson School",
        "district": "Logan City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490051000354",
    },
    {
        "school": "Woodruff School",
        "district": "Logan City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490051000355",
    },
    {
        "school": "Wasatch Peak Academy",
        "district": "Wasatch Peak Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490002401107",
    },
    {
        "school": "No. UT. Acad. for Math Engineering & Science",
        "district": "No. UT. Acad. for Math Engineering & Science",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006300993",
    },
    {
        "school": "North Davis Preparatory Academy",
        "district": "North Davis Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006800998",
    },
    {
        "school": "Heritage School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000759",
    },
    {
        "school": "Star Transition",
        "district": "Davis District",
        "level": "High",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490021000761",
    },
    {
        "school": "Online School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000921",
    },
    {
        "school": "West Point Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000923",
    },
    {
        "school": "Sand Springs School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001098",
    },
    {
        "school": "Blind Region 2",
        "district": "Utah Schools for Deaf & Blind",
        "level": "Elementary",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490006901140",
    },
    {
        "school": "Central Region Deaf",
        "district": "Utah Schools for Deaf & Blind",
        "level": "Elementary",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490006901141",
    },
    {
        "school": "South Region Deaf",
        "district": "Utah Schools for Deaf & Blind",
        "level": "Elementary",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490006901143",
    },
    {
        "school": "Ogden Preparatory Academy",
        "district": "Ogden Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490005800989",
    },
    {
        "school": "Davinci Academy",
        "district": "Davinci Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006500995",
    },
    {
        "school": "North Region Blind",
        "district": "Utah Schools for Deaf & Blind",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490006901138",
    },
    {
        "school": "Kenneth Burdett School",
        "district": "Utah Schools for Deaf & Blind",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490006901139",
    },
    {
        "school": "Contracted Special Education",
        "district": "Ogden City District",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490072000977",
    },
    {
        "school": "Spec. Educ. ATC",
        "district": "Ogden City District",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490072000978",
    },
    {
        "school": "Freedom School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000781",
    },
    {
        "school": "Orion Jr High",
        "district": "Weber District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000967",
    },
    {
        "school": "Two Rivers High",
        "district": "Weber District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490120000972",
    },
    {
        "school": "West Haven School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120001108",
    },
    {
        "school": "Morgan High",
        "district": "Morgan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490057000363",
    },
    {
        "school": "Morgan Middle",
        "district": "Morgan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490057000364",
    },
    {
        "school": "Morgan School",
        "district": "Morgan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490057000365",
    },
    {
        "school": "Family Enrichment Center",
        "district": "Davis District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490021000727",
    },
    {
        "school": "Northridge High",
        "district": "Davis District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000045",
    },
    {
        "school": "Adelaide School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000103",
    },
    {
        "school": "Boulton School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000104",
    },
    {
        "school": "Bountiful High",
        "district": "Davis District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000105",
    },
    {
        "school": "Bountiful Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000106",
    },
    {
        "school": "Bountiful School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000107",
    },
    {
        "school": "H C Burton School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000108",
    },
    {
        "school": "Centerville Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000109",
    },
    {
        "school": "Centerville School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000110",
    },
    {
        "school": "Central Davis Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000111",
    },
    {
        "school": "Clearfield High",
        "district": "Davis District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000112",
    },
    {
        "school": "Clinton School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000113",
    },
    {
        "school": "Crestview School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000114",
    },
    {
        "school": "Davis High",
        "district": "Davis District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000115",
    },
    {
        "school": "Doxey School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000118",
    },
    {
        "school": "King School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000119",
    },
    {
        "school": "Farmington School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000120",
    },
    {
        "school": "Fremont School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000121",
    },
    {
        "school": "Hill Field School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000122",
    },
    {
        "school": "Holbrook School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000124",
    },
    {
        "school": "Taylor School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000125",
    },
    {
        "school": "Kaysville Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000126",
    },
    {
        "school": "Kaysville School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000127",
    },
    {
        "school": "Layton High",
        "district": "Davis District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000128",
    },
    {
        "school": "Layton School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000129",
    },
    {
        "school": "Muir School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000130",
    },
    {
        "school": "Lincoln School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000131",
    },
    {
        "school": "Meadowbrook School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000132",
    },
    {
        "school": "Millcreek Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000133",
    },
    {
        "school": "Eagle Bay School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000134",
    },
    {
        "school": "North Davis Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000135",
    },
    {
        "school": "North Layton Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000136",
    },
    {
        "school": "Oak Hills School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000137",
    },
    {
        "school": "Orchard School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000138",
    },
    {
        "school": "Woods Cross School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000140",
    },
    {
        "school": "South Clearfield School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000141",
    },
    {
        "school": "South Davis Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000142",
    },
    {
        "school": "South Weber School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000143",
    },
    {
        "school": "Sunset Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000145",
    },
    {
        "school": "Sunset School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000146",
    },
    {
        "school": "Syracuse School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000147",
    },
    {
        "school": "Tolman School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000148",
    },
    {
        "school": "Vae View School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000149",
    },
    {
        "school": "Valley View School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000150",
    },
    {
        "school": "Viewmont High",
        "district": "Davis District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000151",
    },
    {
        "school": "Wasatch School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000152",
    },
    {
        "school": "West Bountiful School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000154",
    },
    {
        "school": "West Point School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000155",
    },
    {
        "school": "Whitesides School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000156",
    },
    {
        "school": "Woods Cross High",
        "district": "Davis District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000157",
    },
    {
        "school": "Fairfield Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000169",
    },
    {
        "school": "Windridge School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000242",
    },
    {
        "school": "Mountain View School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000252",
    },
    {
        "school": "Renaissance Academy",
        "district": "Davis District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490021000306",
    },
    {
        "school": "Creekside School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000648",
    },
    {
        "school": "Bluff Ridge School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000649",
    },
    {
        "school": "Lakeside School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000650",
    },
    {
        "school": "Stewart School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000651",
    },
    {
        "school": "Cook School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000676",
    },
    {
        "school": "Morgan School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000677",
    },
    {
        "school": "East Layton School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000708",
    },
    {
        "school": "Holt School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000709",
    },
    {
        "school": "Knowlton School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000710",
    },
    {
        "school": "Columbia School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000748",
    },
    {
        "school": "Farmington Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000749",
    },
    {
        "school": "Mueller Park Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000750",
    },
    {
        "school": "Adams School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000793",
    },
    {
        "school": "Reading School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000810",
    },
    {
        "school": "Mountain High",
        "district": "Davis District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490021000823",
    },
    {
        "school": "Syracuse Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000848",
    },
    {
        "school": "Antelope School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000869",
    },
    {
        "school": "West Clinton School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021000870",
    },
    {
        "school": "Rocky Mountain Jr High",
        "district": "Weber District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000212",
    },
    {
        "school": "Fremont High",
        "district": "Weber District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000221",
    },
    {
        "school": "Majestic School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000573",
    },
    {
        "school": "Bates School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000612",
    },
    {
        "school": "Bonneville High",
        "district": "Weber District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000613",
    },
    {
        "school": "Green Acres School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000616",
    },
    {
        "school": "H Guy Child School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000617",
    },
    {
        "school": "Hooper School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000618",
    },
    {
        "school": "Kanesville School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000619",
    },
    {
        "school": "Lakeview School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000620",
    },
    {
        "school": "Lomond View School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000621",
    },
    {
        "school": "Municipal School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000624",
    },
    {
        "school": "North Ogden Jr High",
        "district": "Weber District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000625",
    },
    {
        "school": "North Ogden School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000626",
    },
    {
        "school": "North Park School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000627",
    },
    {
        "school": "Pioneer School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000630",
    },
    {
        "school": "Plain City School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000631",
    },
    {
        "school": "Riverdale School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000632",
    },
    {
        "school": "Roosevelt School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000633",
    },
    {
        "school": "Roy High",
        "district": "Weber District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000634",
    },
    {
        "school": "Roy Jr High",
        "district": "Weber District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000635",
    },
    {
        "school": "Roy School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000636",
    },
    {
        "school": "Sand Ridge Jr High",
        "district": "Weber District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000637",
    },
    {
        "school": "South Ogden Jr High",
        "district": "Weber District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000638",
    },
    {
        "school": "T.H. Bell Jr High",
        "district": "Weber District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000639",
    },
    {
        "school": "Uintah School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000640",
    },
    {
        "school": "Valley School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000641",
    },
    {
        "school": "Valley View School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000642",
    },
    {
        "school": "Wahlquist Jr High",
        "district": "Weber District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000643",
    },
    {
        "school": "Washington Terrace School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000644",
    },
    {
        "school": "Weber High",
        "district": "Weber District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000645",
    },
    {
        "school": "West Weber School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000646",
    },
    {
        "school": "Snowcrest Jr High",
        "district": "Weber District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000669",
    },
    {
        "school": "Country View School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000703",
    },
    {
        "school": "Farr West School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000817",
    },
    {
        "school": "Midland School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120000818",
    },
    {
        "school": "Pinnacle Canyon Academy",
        "district": "Pinnacle Canyon Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490000800629",
    },
    {
        "school": "Castle Valley Center",
        "district": "Carbon District",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490015000088",
    },
    {
        "school": "Carbon High",
        "district": "Carbon District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015000089",
    },
    {
        "school": "Helper Middle",
        "district": "Carbon District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015000092",
    },
    {
        "school": "Mont Harmon Middle",
        "district": "Carbon District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015000093",
    },
    {
        "school": "Sally Mauro School",
        "district": "Carbon District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015000097",
    },
    {
        "school": "Wellington School",
        "district": "Carbon District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015000098",
    },
    {
        "school": "Castle Heights School",
        "district": "Carbon District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015000809",
    },
    {
        "school": "Creekview School",
        "district": "Carbon District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015000821",
    },
    {
        "school": "Nebo View School",
        "district": "Juab District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490045000951",
    },
    {
        "school": "Juab Jr High",
        "district": "Juab District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490045000952",
    },
    {
        "school": "John Hancock Charter School",
        "district": "John Hancock Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490001400811",
    },
    {
        "school": "Timpanogos Academy",
        "district": "Timpanogos Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490001600830",
    },
    {
        "school": "Utah County Academy of Science",
        "district": "Utah County Academy of Science",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490002001106",
    },
    {
        "school": "Odyssey Charter School",
        "district": "Odyssey Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490002101092",
    },
    {
        "school": "Lincoln Academy",
        "district": "Lincoln Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490002201082",
    },
    {
        "school": "Deerfield School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000757",
    },
    {
        "school": "Pony Express School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000907",
    },
    {
        "school": "Freedom School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000908",
    },
    {
        "school": "Timberline Middle",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000909",
    },
    {
        "school": "Serv By Appt",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000911",
    },
    {
        "school": "Eagle Valley School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001071",
    },
    {
        "school": "Saratoga Shores School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001099",
    },
    {
        "school": "Willowcreek Middle",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001109",
    },
    {
        "school": "Reagan Academy",
        "district": "Reagan Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003201095",
    },
    {
        "school": "American Leadership Academy",
        "district": "American Leadership Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003301056",
    },
    {
        "school": "Karl G. Maeser Preparatory Academy",
        "district": "Karl G. Maeser Preparatory Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490005601175",
    },
    {
        "school": "Walden School of Liberal Arts",
        "district": "Walden School of Liberal Arts",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006100991",
    },
    {
        "school": "Freedom Preparatory Academy",
        "district": "Freedom Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006200992",
    },
    {
        "school": "Ranches Academy",
        "district": "Ranches Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006400994",
    },
    {
        "school": "Spring Lake School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000766",
    },
    {
        "school": "Hobble Creek School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000956",
    },
    {
        "school": "Riverview School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001156",
    },
    {
        "school": "Diamond Fork Junior High",
        "district": "Nebo District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001157",
    },
    {
        "school": "Mt. Nebo Junior High",
        "district": "Nebo District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001158",
    },
    {
        "school": "Maple Mountain High",
        "district": "Nebo District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001159",
    },
    {
        "school": "Salem Hills High",
        "district": "Nebo District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001160",
    },
    {
        "school": "Spring Creek School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000789",
    },
    {
        "school": "Provo Peaks School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081001074",
    },
    {
        "school": "Juab High",
        "district": "Juab District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490045000334",
    },
    {
        "school": "Red Cliff School",
        "district": "Juab District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490045000336",
    },
    {
        "school": "Mona School",
        "district": "Juab District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490045000795",
    },
    {
        "school": "Eureka School",
        "district": "Tintic District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490102000559",
    },
    {
        "school": "Tintic High",
        "district": "Tintic District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490102000560",
    },
    {
        "school": "West Desert School",
        "district": "Tintic District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490102000561",
    },
    {
        "school": "West Desert High School",
        "district": "Tintic District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490102000735",
    },
    {
        "school": "Oak Springs School",
        "district": "Provo District",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490081000468",
    },
    {
        "school": "Alpine School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000001",
    },
    {
        "school": "American Fork High",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000002",
    },
    {
        "school": "American Fork Jr High",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000003",
    },
    {
        "school": "Barratt School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000004",
    },
    {
        "school": "Bonneville School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000005",
    },
    {
        "school": "Cascade School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000006",
    },
    {
        "school": "Cedar Valley School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000007",
    },
    {
        "school": "Central School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000008",
    },
    {
        "school": "Cherry Hill School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000009",
    },
    {
        "school": "Forbes School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000010",
    },
    {
        "school": "Geneva School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000011",
    },
    {
        "school": "Greenwood School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000012",
    },
    {
        "school": "Grovecrest School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000013",
    },
    {
        "school": "Dan W. Peterson",
        "district": "Alpine District",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490003000014",
    },
    {
        "school": "Lakeridge Jr High",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000016",
    },
    {
        "school": "Lehi High",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000017",
    },
    {
        "school": "Lehi Jr High",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000018",
    },
    {
        "school": "Lehi School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000019",
    },
    {
        "school": "Lindon School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000020",
    },
    {
        "school": "Orem High",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000021",
    },
    {
        "school": "Orem Jr High",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000022",
    },
    {
        "school": "Orem School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000023",
    },
    {
        "school": "Pleasant Grove High",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000024",
    },
    {
        "school": "Pleasant Grove Jr High",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000025",
    },
    {
        "school": "Scera Park",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000026",
    },
    {
        "school": "Sego Lily School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000027",
    },
    {
        "school": "Sharon School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000028",
    },
    {
        "school": "Shelley School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000029",
    },
    {
        "school": "Valley View School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000031",
    },
    {
        "school": "Vineyard School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000032",
    },
    {
        "school": "Westmore School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000034",
    },
    {
        "school": "Windsor School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000035",
    },
    {
        "school": "Mountain Ridge Jr High",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000074",
    },
    {
        "school": "Oak Canyon Jr High",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000075",
    },
    {
        "school": "Legacy School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000228",
    },
    {
        "school": "Rocky Mountain School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000349",
    },
    {
        "school": "Timpanogos High",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000362",
    },
    {
        "school": "Summit High",
        "district": "Alpine District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490003000366",
    },
    {
        "school": "Cedar Ridge School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000440",
    },
    {
        "school": "Eaglecrest School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000444",
    },
    {
        "school": "Lone Peak High",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000445",
    },
    {
        "school": "Foothill School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000593",
    },
    {
        "school": "Northridge School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000647",
    },
    {
        "school": "Highland School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000672",
    },
    {
        "school": "Mount Mahogany School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000696",
    },
    {
        "school": "Snow Springs School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000699",
    },
    {
        "school": "Westfield School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000704",
    },
    {
        "school": "Mountain View High",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000706",
    },
    {
        "school": "Aspen School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000740",
    },
    {
        "school": "Manila School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000743",
    },
    {
        "school": "Meadow School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000744",
    },
    {
        "school": "Orchard School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000791",
    },
    {
        "school": "Canyon View Jr High",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000819",
    },
    {
        "school": "Suncrest School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003000844",
    },
    {
        "school": "Brockbank School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000379",
    },
    {
        "school": "Brookside School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000380",
    },
    {
        "school": "Goshen School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000383",
    },
    {
        "school": "Mapleton School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000386",
    },
    {
        "school": "Landmark High",
        "district": "Nebo District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490063000387",
    },
    {
        "school": "Park School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000388",
    },
    {
        "school": "Park View School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000389",
    },
    {
        "school": "Payson High",
        "district": "Nebo District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000390",
    },
    {
        "school": "Payson Jr High",
        "district": "Nebo District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000391",
    },
    {
        "school": "Rees School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000394",
    },
    {
        "school": "Sage Creek School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000395",
    },
    {
        "school": "Salem School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000396",
    },
    {
        "school": "Santaquin School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000397",
    },
    {
        "school": "Spanish Fork High",
        "district": "Nebo District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000399",
    },
    {
        "school": "Springville High",
        "district": "Nebo District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000402",
    },
    {
        "school": "Springville Jr High",
        "district": "Nebo District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000403",
    },
    {
        "school": "Taylor School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000405",
    },
    {
        "school": "Westside School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000406",
    },
    {
        "school": "Wilson School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000407",
    },
    {
        "school": "Mt. Loafer School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000431",
    },
    {
        "school": "Canyon School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000479",
    },
    {
        "school": "Spanish Fork Jr High",
        "district": "Nebo District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000482",
    },
    {
        "school": "Art City School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000660",
    },
    {
        "school": "Barnett School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000689",
    },
    {
        "school": "Larsen School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000690",
    },
    {
        "school": "Spanish Oaks School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063000747",
    },
    {
        "school": "Centennial Middle",
        "district": "Provo District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000438",
    },
    {
        "school": "Dixon Middle",
        "district": "Provo District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000452",
    },
    {
        "school": "Edgemont School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000453",
    },
    {
        "school": "Franklin School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000455",
    },
    {
        "school": "Provo High",
        "district": "Provo District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000459",
    },
    {
        "school": "Provost School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000461",
    },
    {
        "school": "Rock Canyon School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000462",
    },
    {
        "school": "Sunset View School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000463",
    },
    {
        "school": "Timpanogos School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000465",
    },
    {
        "school": "Timpview High",
        "district": "Provo District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000466",
    },
    {
        "school": "Wasatch School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000467",
    },
    {
        "school": "Amelia Earhart School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000584",
    },
    {
        "school": "Westridge School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000730",
    },
    {
        "school": "Canyon Crest School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081000799",
    },
    {
        "school": "Independence High",
        "district": "Provo District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490081000836",
    },
    {
        "school": "Slate Canyon",
        "district": "Provo District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490081000858",
    },
    {
        "school": "Provo Adult Education",
        "district": "Provo District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490081000860",
    },
    {
        "school": "Washington Preschool",
        "district": "Washington District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490114000778",
    },
    {
        "school": "Tuacahn High School for the Performing Arts",
        "district": "Tuacahn High School for the Performing Arts",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490001200673",
    },
    {
        "school": "Lava Ridge Intermediate",
        "district": "Washington District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000779",
    },
    {
        "school": "Post HS Self-Cont",
        "district": "Washington District",
        "level": "High",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490114000963",
    },
    {
        "school": "Arrowhead School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001057",
    },
    {
        "school": "Fossil Ridge Intermediate",
        "district": "Washington District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001076",
    },
    {
        "school": "Little Valley School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001083",
    },
    {
        "school": "Riverside School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001096",
    },
    {
        "school": "Snow Canyon Middle",
        "district": "Washington District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000063",
    },
    {
        "school": "Snow Canyon High",
        "district": "Washington District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000206",
    },
    {
        "school": "Bloomington Hills School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000347",
    },
    {
        "school": "Three Falls School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000433",
    },
    {
        "school": "Diamond Valley School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000500",
    },
    {
        "school": "Coral Cliffs School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000501",
    },
    {
        "school": "Red Mountain School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000570",
    },
    {
        "school": "Dixie High",
        "district": "Washington District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000597",
    },
    {
        "school": "Enterprise High",
        "district": "Washington District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000599",
    },
    {
        "school": "Enterprise School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000600",
    },
    {
        "school": "Hurricane High",
        "district": "Washington District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000601",
    },
    {
        "school": "Hurricane School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000602",
    },
    {
        "school": "Springdale School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000604",
    },
    {
        "school": "Legacy School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000605",
    },
    {
        "school": "Heritage School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000606",
    },
    {
        "school": "Washington School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000607",
    },
    {
        "school": "Santa Clara School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000701",
    },
    {
        "school": "Hurricane Middle",
        "district": "Washington District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000702",
    },
    {
        "school": "Sandstone School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000739",
    },
    {
        "school": "Dixie Middle",
        "district": "Washington District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000805",
    },
    {
        "school": "LaVerkin School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000806",
    },
    {
        "school": "Pine View High",
        "district": "Washington District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000807",
    },
    {
        "school": "Bloomington School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000841",
    },
    {
        "school": "Sunset School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000842",
    },
    {
        "school": "Panorama School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000866",
    },
    {
        "school": "Pine View Middle",
        "district": "Washington District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000880",
    },
    {
        "school": "Millcreek High",
        "district": "Washington District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490114000881",
    },
    {
        "school": "Paradise Canyon",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114000903",
    },
    {
        "school": "Canyon Rim Academy",
        "district": "Canyon Rim Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490007101178",
    },
    {
        "school": "Stansbury High",
        "district": "Tooele District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105001177",
    },
    {
        "school": "American Preparatory Academy - Draper #1",
        "district": "American Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490000500801",
    },
    {
        "school": "City Academy",
        "district": "City Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490000900742",
    },
    {
        "school": "Academy for Math Engineering & Science",
        "district": "Academy for Math Engineering & Science",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490001700904",
    },
    {
        "school": "Salt Lake Arts Academy",
        "district": "Salt Lake Arts Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490001800905",
    },
    {
        "school": "Beehive Science & Technology Academy",
        "district": "Beehive Science & Technology Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490002301060",
    },
    {
        "school": "North Star Academy",
        "district": "North Star Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490002501089",
    },
    {
        "school": "Navigator Pointe Academy",
        "district": "Navigator Pointe Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003401088",
    },
    {
        "school": "East Hollywood High",
        "district": "East Hollywood High",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003601072",
    },
    {
        "school": "Summit Academy - Draper Campus",
        "district": "Summit Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006600996",
    },
    {
        "school": "Itineris Early College High",
        "district": "Itineris Early College High",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006700997",
    },
    {
        "school": "Guadalupe School",
        "district": "Guadalupe School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490007201174",
    },
    {
        "school": "Scott M Matheson Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000763",
    },
    {
        "school": "Granite Technical Institute",
        "district": "Granite District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "UT",
        "nces_id": "490036001119",
    },
    {
        "school": "Foothills School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000949",
    },
    {
        "school": "Copper Canyon School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001067",
    },
    {
        "school": "Daybreak School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001069",
    },
    {
        "school": "Fort Herriman Middle",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001075",
    },
    {
        "school": "Oakcrest School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001090",
    },
    {
        "school": "Sunset Ridge Middle",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001103",
    },
    {
        "school": "Murray Adult Transition",
        "district": "Murray District",
        "level": "High",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490060000988",
    },
    {
        "school": "Escalante School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000787",
    },
    {
        "school": "Salt Lake Technology Center",
        "district": "Salt Lake District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "UT",
        "nces_id": "490087001170",
    },
    {
        "school": "Middle Canyon School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000774",
    },
    {
        "school": "Overlake School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000775",
    },
    {
        "school": "Willow School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000776",
    },
    {
        "school": "Copper Canyon School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105001068",
    },
    {
        "school": "Rose Springs School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105001097",
    },
    {
        "school": "Settlement Canyon School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105001179",
    },
    {
        "school": "North Summit High",
        "district": "North Summit District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490069000415",
    },
    {
        "school": "North Summit School",
        "district": "North Summit District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490069000416",
    },
    {
        "school": "North Summit Middle",
        "district": "North Summit District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490069000724",
    },
    {
        "school": "Jeremy Ranch School",
        "district": "Park City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490075000197",
    },
    {
        "school": "Park City High",
        "district": "Park City District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490075000447",
    },
    {
        "school": "Ecker Hill Middle",
        "district": "Park City District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490075000485",
    },
    {
        "school": "Parleys Park School",
        "district": "Park City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490075000726",
    },
    {
        "school": "Trailside School",
        "district": "Park City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490075000751",
    },
    {
        "school": "Treasure Mtn. Junior High School",
        "district": "Park City District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490075000773",
    },
    {
        "school": "Mcpolin School",
        "district": "Park City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490075000901",
    },
    {
        "school": "South Summit High",
        "district": "South Summit District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490099000557",
    },
    {
        "school": "South Summit School",
        "district": "South Summit District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490099000558",
    },
    {
        "school": "South Summit Middle",
        "district": "South Summit District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490099000733",
    },
    {
        "school": "Northlake School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000562",
    },
    {
        "school": "Grantsville High",
        "district": "Tooele District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000566",
    },
    {
        "school": "Grantsville School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000567",
    },
    {
        "school": "Ibapah School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000569",
    },
    {
        "school": "Tooele High",
        "district": "Tooele District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000574",
    },
    {
        "school": "Tooele Jr High",
        "district": "Tooele District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000575",
    },
    {
        "school": "Vernon School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000576",
    },
    {
        "school": "Wendover High",
        "district": "Tooele District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000577",
    },
    {
        "school": "Anna Smith School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000578",
    },
    {
        "school": "West School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000579",
    },
    {
        "school": "Stansbury Park School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000697",
    },
    {
        "school": "Blue Peak High",
        "district": "Tooele District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490105000698",
    },
    {
        "school": "Grantsville Jr High",
        "district": "Tooele District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105000784",
    },
    {
        "school": "Academy Park School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000196",
    },
    {
        "school": "Arcadia School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000198",
    },
    {
        "school": "Bennion School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000199",
    },
    {
        "school": "Bonneville Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000200",
    },
    {
        "school": "Carl Sandburg School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000203",
    },
    {
        "school": "Churchill Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000205",
    },
    {
        "school": "Cottonwood High",
        "district": "Granite District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000207",
    },
    {
        "school": "Cottonwood School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000208",
    },
    {
        "school": "Crestview School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000209",
    },
    {
        "school": "Cyprus High",
        "district": "Granite District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000210",
    },
    {
        "school": "David Gourley School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000211",
    },
    {
        "school": "Eastwood School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000214",
    },
    {
        "school": "Eisenhower Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000215",
    },
    {
        "school": "Evergreen Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000216",
    },
    {
        "school": "Granger High",
        "district": "Granite District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000218",
    },
    {
        "school": "Granger School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000219",
    },
    {
        "school": "Granite Connection High",
        "district": "Granite District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490036000220",
    },
    {
        "school": "Granite Park Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000223",
    },
    {
        "school": "Hartvigsen School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490036000224",
    },
    {
        "school": "Hillsdale School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000226",
    },
    {
        "school": "Howard R. Driggs School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000229",
    },
    {
        "school": "Jackling School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000230",
    },
    {
        "school": "James E. Moss School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000231",
    },
    {
        "school": "John C. Fremont School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000232",
    },
    {
        "school": "John F. Kennedy Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000233",
    },
    {
        "school": "Kearns High",
        "district": "Granite District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000234",
    },
    {
        "school": "Kearns Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000235",
    },
    {
        "school": "Lake Ridge School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000236",
    },
    {
        "school": "Lincoln School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000238",
    },
    {
        "school": "Magna School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000240",
    },
    {
        "school": "Mill Creek School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000243",
    },
    {
        "school": "Monroe School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000244",
    },
    {
        "school": "Morningside School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000245",
    },
    {
        "school": "Oakridge School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000246",
    },
    {
        "school": "Oakwood School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000247",
    },
    {
        "school": "Olympus High",
        "district": "Granite District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000248",
    },
    {
        "school": "Olympus Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000249",
    },
    {
        "school": "Oquirrh Hills School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000250",
    },
    {
        "school": "Philo T. Farnsworth School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000251",
    },
    {
        "school": "Pioneer School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000253",
    },
    {
        "school": "Plymouth School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000254",
    },
    {
        "school": "Redwood School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000255",
    },
    {
        "school": "Robert Frost School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000257",
    },
    {
        "school": "Rolling Meadows School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000258",
    },
    {
        "school": "Roosevelt School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000259",
    },
    {
        "school": "Rosecrest School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000260",
    },
    {
        "school": "Skyline High",
        "district": "Granite District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000261",
    },
    {
        "school": "South Kearns School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000262",
    },
    {
        "school": "Stansbury School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000263",
    },
    {
        "school": "Taylorsville School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000264",
    },
    {
        "school": "Twin Peaks School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000265",
    },
    {
        "school": "Upland Terrace School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000266",
    },
    {
        "school": "Valley Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000267",
    },
    {
        "school": "Vista School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000268",
    },
    {
        "school": "Wasatch Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000269",
    },
    {
        "school": "West Kearns School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000271",
    },
    {
        "school": "West Lake Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000272",
    },
    {
        "school": "Western Hills School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000273",
    },
    {
        "school": "Whittier School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000274",
    },
    {
        "school": "William Penn School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000275",
    },
    {
        "school": "Woodrow Wilson School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000276",
    },
    {
        "school": "Woodstock School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000277",
    },
    {
        "school": "Douglas T. Orchard School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000653",
    },
    {
        "school": "Harry S. Truman School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000656",
    },
    {
        "school": "Fox Hills School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000679",
    },
    {
        "school": "Calvin S. Smith School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000680",
    },
    {
        "school": "Bennion Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000715",
    },
    {
        "school": "Hunter School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000717",
    },
    {
        "school": "West Valley School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000728",
    },
    {
        "school": "Thomas W. Bacchus School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000755",
    },
    {
        "school": "Copper Hills School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000756",
    },
    {
        "school": "Taylorsville High",
        "district": "Granite District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000764",
    },
    {
        "school": "Hillside School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000812",
    },
    {
        "school": "Jim Bridger School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000826",
    },
    {
        "school": "Valley Crest School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000827",
    },
    {
        "school": "Westbrook School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000828",
    },
    {
        "school": "Hunter Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000829",
    },
    {
        "school": "Silver Hills School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000852",
    },
    {
        "school": "Beehive School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000853",
    },
    {
        "school": "Pleasant Green School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000854",
    },
    {
        "school": "Thomas Jefferson Jr High",
        "district": "Granite District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000871",
    },
    {
        "school": "Hunter High",
        "district": "Granite District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036000898",
    },
    {
        "school": "Elk Ridge Middle",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000195",
    },
    {
        "school": "Bingham High",
        "district": "Jordan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000289",
    },
    {
        "school": "Rivers Edge School",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490042000308",
    },
    {
        "school": "Majestic School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000310",
    },
    {
        "school": "Monte Vista School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000314",
    },
    {
        "school": "Riverton School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000320",
    },
    {
        "school": "South Jordan School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000322",
    },
    {
        "school": "South Valley School",
        "district": "Jordan District",
        "level": "High",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490042000323",
    },
    {
        "school": "Southland School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000324",
    },
    {
        "school": "Terra Linda School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000327",
    },
    {
        "school": "Valley High School",
        "district": "Jordan District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490042000329",
    },
    {
        "school": "West Jordan Middle",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000330",
    },
    {
        "school": "Westvale School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000331",
    },
    {
        "school": "Westland School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000332",
    },
    {
        "school": "Bluffdale School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000338",
    },
    {
        "school": "Copper Hills High",
        "district": "Jordan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000346",
    },
    {
        "school": "West Hills Middle",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000428",
    },
    {
        "school": "Elk Meadows School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000508",
    },
    {
        "school": "Jordan Hills School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000523",
    },
    {
        "school": "Rose Creek School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000530",
    },
    {
        "school": "South Hills Middle",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000531",
    },
    {
        "school": "Hayden Peak School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000655",
    },
    {
        "school": "Herriman School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000657",
    },
    {
        "school": "Riverton High",
        "district": "Jordan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000661",
    },
    {
        "school": "Oquirrh School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000684",
    },
    {
        "school": "Oquirrh Hills Middle",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000720",
    },
    {
        "school": "Riverside School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000721",
    },
    {
        "school": "Welby School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000722",
    },
    {
        "school": "West Jordan High",
        "district": "Jordan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000769",
    },
    {
        "school": "West Jordan School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000770",
    },
    {
        "school": "Columbia School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000813",
    },
    {
        "school": "Rosamond School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000814",
    },
    {
        "school": "Joel P. Jensen Middle",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000816",
    },
    {
        "school": "Heartland School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000873",
    },
    {
        "school": "Jordan Ridge School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000874",
    },
    {
        "school": "Mountain Shadows School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000886",
    },
    {
        "school": "South Jordan Middle",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042000896",
    },
    {
        "school": "Grant School",
        "district": "Murray District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490060000368",
    },
    {
        "school": "Hillcrest Jr High",
        "district": "Murray District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490060000369",
    },
    {
        "school": "Liberty School",
        "district": "Murray District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490060000370",
    },
    {
        "school": "Longview School",
        "district": "Murray District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490060000371",
    },
    {
        "school": "Mcmillan School",
        "district": "Murray District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490060000373",
    },
    {
        "school": "Murray High",
        "district": "Murray District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490060000374",
    },
    {
        "school": "Parkside School",
        "district": "Murray District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490060000375",
    },
    {
        "school": "Riverview Jr High",
        "district": "Murray District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490060000376",
    },
    {
        "school": "Viewmont School",
        "district": "Murray District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490060000377",
    },
    {
        "school": "Horizon School",
        "district": "Murray District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490060000771",
    },
    {
        "school": "Backman School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000474",
    },
    {
        "school": "Beacon Heights School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000475",
    },
    {
        "school": "Bonneville School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000476",
    },
    {
        "school": "Bryant Middle",
        "district": "Salt Lake District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000477",
    },
    {
        "school": "Children Behavior Therapy Unit",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490087000478",
    },
    {
        "school": "Clayton Middle",
        "district": "Salt Lake District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000480",
    },
    {
        "school": "Columbus Community Center",
        "district": "Salt Lake District",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490087000481",
    },
    {
        "school": "Dilworth School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000484",
    },
    {
        "school": "East High",
        "district": "Salt Lake District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000486",
    },
    {
        "school": "Edison School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000487",
    },
    {
        "school": "Emerson School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000488",
    },
    {
        "school": "Ensign School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000489",
    },
    {
        "school": "Franklin School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000490",
    },
    {
        "school": "Glendale Middle",
        "district": "Salt Lake District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000492",
    },
    {
        "school": "Mountain View School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000493",
    },
    {
        "school": "Hawthorne School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000494",
    },
    {
        "school": "Highland High",
        "district": "Salt Lake District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000496",
    },
    {
        "school": "Highland Park School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000497",
    },
    {
        "school": "Hillside Middle",
        "district": "Salt Lake District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000498",
    },
    {
        "school": "Indian Hills School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000502",
    },
    {
        "school": "Mary W. Jackson School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000503",
    },
    {
        "school": "Meadowlark School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000509",
    },
    {
        "school": "Newman School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000510",
    },
    {
        "school": "Nibley Park School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000511",
    },
    {
        "school": "Northwest Middle",
        "district": "Salt Lake District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000512",
    },
    {
        "school": "Parkview School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000514",
    },
    {
        "school": "Riley School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000515",
    },
    {
        "school": "Rose Park School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000516",
    },
    {
        "school": "Uintah School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000520",
    },
    {
        "school": "Wasatch School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000521",
    },
    {
        "school": "Washington School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000522",
    },
    {
        "school": "West High",
        "district": "Salt Lake District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000524",
    },
    {
        "school": "Whittier School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000525",
    },
    {
        "school": "M. Lynn Bennion School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000665",
    },
    {
        "school": "Liberty School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000666",
    },
    {
        "school": "North Star School",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087000695",
    },
    {
        "school": "Horizonte Instruction & Training Center",
        "district": "Salt Lake District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490087000732",
    },
    {
        "school": "Uintah River High",
        "district": "Uintah River High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490001300671",
    },
    {
        "school": "Ashley School",
        "district": "Uintah District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490108000580",
    },
    {
        "school": "Maeser School",
        "district": "Uintah District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490108000582",
    },
    {
        "school": "Naples School",
        "district": "Uintah District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490108000583",
    },
    {
        "school": "Uintah High",
        "district": "Uintah District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490108000585",
    },
    {
        "school": "Uintah Middle School",
        "district": "Uintah District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490108000588",
    },
    {
        "school": "Discovery School",
        "district": "Uintah District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490108000736",
    },
    {
        "school": "Vernal Middle",
        "district": "Uintah District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490108000786",
    },
    {
        "school": "Davis School",
        "district": "Uintah District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490108000803",
    },
    {
        "school": "Lapoint School",
        "district": "Uintah District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490108000804",
    },
    {
        "school": "HB WOODLAWN SECONDARY PRGM.",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510027002659",
    },
    {
        "school": "COSBY HIGH",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002661",
    },
    {
        "school": "EAGLE VIEW ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002496",
    },
    {
        "school": "ACHIEVEMENT INTEGRITY AND MATURITY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510126002674",
    },
    {
        "school": "MT. VISTA REG. GOV. SCH.",
        "district": "MOUNTAIN VISTA GOVERNOR'S SCH",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510010702697",
    },
    {
        "school": "EVENDALE ELEM",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147002501",
    },
    {
        "school": "KERSEY CREEK ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183002506",
    },
    {
        "school": "THE GEORGETOWN SCHOOL",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510183002691",
    },
    {
        "school": "MATOAKA ELEM",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402002656",
    },
    {
        "school": "WARHILL HIGH",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402002658",
    },
    {
        "school": "POTOMAC MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002584",
    },
    {
        "school": "ROSA PARKS ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002587",
    },
    {
        "school": "BUCKLAND MILLS ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002588",
    },
    {
        "school": "MASSANUTTEN GOV. SCH./INTEGRATED ENVIRON. SCI.",
        "district": "MASSANUTTEN GOVERNOR'S SCH",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510010902698",
    },
    {
        "school": "DONALD B. DIXON-LYLE R. SMITH MIDDLE",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002600",
    },
    {
        "school": "ANTHONY BURNS ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002601",
    },
    {
        "school": "SKYLINE HIGH",
        "district": "WARREN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510387002657",
    },
    {
        "school": "MAYFIELD INTERMEDIATE",
        "district": "MANASSAS CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510236002637",
    },
    {
        "school": "ALBERT HARRIS ELEM",
        "district": "MARTINSVILLE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510240002616",
    },
    {
        "school": "PATRICK HENRY ELEM",
        "district": "MARTINSVILLE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510240002617",
    },
    {
        "school": "GATEWOOD ACADEMY",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264002696",
    },
    {
        "school": "VICTORY ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300002625",
    },
    {
        "school": "CREEKSIDE ELEM",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371002630",
    },
    {
        "school": "NEW START - BASIC ALT. CTR.",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510189001908",
    },
    {
        "school": "NANDUA MIDDLE",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006002433",
    },
    {
        "school": "ARCADIA MIDDLE",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006002434",
    },
    {
        "school": "SOUTHSIDE L.I.N.K. PROJECT/BRUNSWICK CO",
        "district": "SOUTHSIDE L.I.N.K. PROJECT/BRUNSWICK CO",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510008902360",
    },
    {
        "school": "CARROLL/GALAX/JOY RANCH REG ALTERNATIVE ED",
        "district": "CARROLL-GALAX REG ALT ED PRGM/THE RAE CENTER",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510010002370",
    },
    {
        "school": "CARROLL COUNTY ED CENTER",
        "district": "CARROLL CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510069002489",
    },
    {
        "school": "SEALSTON ELEM",
        "district": "KING GEO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510210002445",
    },
    {
        "school": "ALTERNATIVE EDUCATION CENTER",
        "district": "MECKLENBURG CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510246002453",
    },
    {
        "school": "PROJECT RENEW/NORTHAMPTON CO",
        "district": "PROJECT RENEW/NORTHAMPTON CO",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510008302374",
    },
    {
        "school": "PIEDMONT ALTERNATIVE",
        "district": "PIEDMONT ALTERNATIVE SCHOOL",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510009602366",
    },
    {
        "school": "LOCUST GROVE MIDDLE",
        "district": "ORANGE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510282002340",
    },
    {
        "school": "NORTHERN NECK REGIONAL ALTERNATIVE ED",
        "district": "NORTHERN NECK REGIONAL ALTERNATIVE ED",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510009702367",
    },
    {
        "school": "PROJECT BRIDGE/RUSSELL CO",
        "district": "PROJECT BRIDGE/RUSSELL CO",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510009302363",
    },
    {
        "school": "LEBANON MIDDLE",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510342002461",
    },
    {
        "school": "REGIONAL LEARNING ACADEMY/WISE CO",
        "district": "REGIONAL LEARNING ACADEMY/WISE CO",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510010202372",
    },
    {
        "school": "WISE CO. ALTERNATIVE ED. CTR.",
        "district": "WISE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510408002342",
    },
    {
        "school": "REGIONAL ALTERNATIVE/WYTHE CO",
        "district": "REGIONAL ALTERNATIVE/WYTHE CO",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510009402364",
    },
    {
        "school": "JOSEPH P. KING JR. MIDDLE",
        "district": "FRANKLIN CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510141002431",
    },
    {
        "school": "CHINCOTEAGUE ELEM",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006000006",
    },
    {
        "school": "CHINCOTEAGUE HIGH",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006000007",
    },
    {
        "school": "KEGOTANK ELEM",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006000009",
    },
    {
        "school": "PUNGOTEAGUE ELEM",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006000012",
    },
    {
        "school": "TANGIER COMBINED",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "Other",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006000014",
    },
    {
        "school": "ACCAWMACKE ELEM",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006001737",
    },
    {
        "school": "METOMPKIN ELEM",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006001738",
    },
    {
        "school": "BADGER VOC ED CTR - NORTH",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510006001988",
    },
    {
        "school": "NANDUA HIGH",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006002003",
    },
    {
        "school": "BADGER VOC ED CTR - SOUTH",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510006002004",
    },
    {
        "school": "ARCADIA HIGH",
        "district": "ACCOMACK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006002028",
    },
    {
        "school": "ALLEGHANY HIGH",
        "district": "ALLEGHANY CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510015201883",
    },
    {
        "school": "CALLAGHAN ELEM",
        "district": "ALLEGHANY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510015201885",
    },
    {
        "school": "CLIFTON MIDDLE",
        "district": "ALLEGHANY CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510015201888",
    },
    {
        "school": "MT VIEW ELEM",
        "district": "ALLEGHANY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510015201938",
    },
    {
        "school": "BATH COUNTY HIGH",
        "district": "BATH CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510033000139",
    },
    {
        "school": "MILLBORO ELEM",
        "district": "BATH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510033000140",
    },
    {
        "school": "VALLEY ELEM",
        "district": "BATH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510033000141",
    },
    {
        "school": "JAMES S RUSSELL MIDDLE",
        "district": "BRUNSWICK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510048000182",
    },
    {
        "school": "BRUNSWICK HIGH",
        "district": "BRUNSWICK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510048000183",
    },
    {
        "school": "MEHERRIN POWELLTON ELEM",
        "district": "BRUNSWICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510048000184",
    },
    {
        "school": "RED OAK-STURGEON ELEM",
        "district": "BRUNSWICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510048000185",
    },
    {
        "school": "TOTARO ELEM",
        "district": "BRUNSWICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510048000188",
    },
    {
        "school": "BUCHANAN COUNTY TECHNOLOGY CAREER & HIGHER LEARNING CENTER",
        "district": "BUCHANAN CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510051000191",
    },
    {
        "school": "COUNCIL HIGH",
        "district": "BUCHANAN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510051000193",
    },
    {
        "school": "GRUNDY HIGH",
        "district": "BUCHANAN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510051000198",
    },
    {
        "school": "HURLEY HIGH",
        "district": "BUCHANAN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510051000200",
    },
    {
        "school": "COUNCIL ELEMENTARY/MIDDLE SCHOOL",
        "district": "BUCHANAN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510051001897",
    },
    {
        "school": "RIVERVIEW ELEMENTARY/MIDDLE",
        "district": "BUCHANAN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510051001945",
    },
    {
        "school": "TWIN VALLEY ELEMENTARY/MIDDLE",
        "district": "BUCHANAN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510051001946",
    },
    {
        "school": "TWIN VALLEY HIGH",
        "district": "BUCHANAN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510051001947",
    },
    {
        "school": "HURLEY ELEMENTARY/MIDDLE",
        "district": "BUCHANAN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510051002052",
    },
    {
        "school": "BUCKINGHAM CO. MIDDLE",
        "district": "BUCKINGHAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510054000209",
    },
    {
        "school": "BUCKINGHAM COUNTY HIGH",
        "district": "BUCKINGHAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510054000210",
    },
    {
        "school": "CARROLL COUNTY HIGH",
        "district": "CARROLL CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510069000242",
    },
    {
        "school": "FANCY GAP ELEM",
        "district": "CARROLL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510069000244",
    },
    {
        "school": "GLADESBORO ELEM",
        "district": "CARROLL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510069000245",
    },
    {
        "school": "GLADEVILLE ELEM",
        "district": "CARROLL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510069000246",
    },
    {
        "school": "HILLSVILLE ELEM",
        "district": "CARROLL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510069000247",
    },
    {
        "school": "OAKLAND ELEM",
        "district": "CARROLL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510069000253",
    },
    {
        "school": "ST PAUL",
        "district": "CARROLL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510069000254",
    },
    {
        "school": "CARROLL COUNTY MIDDLE",
        "district": "CARROLL CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510069000257",
    },
    {
        "school": "GOV. SCH. GLOBAL ECONOMICS/TECH.",
        "district": "GOV SCH GLOBAL ECONOMICS/TECH",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510002901505",
    },
    {
        "school": "BACON DISTRICT ELEM",
        "district": "CHARLOTTE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510075000262",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "CHARLOTTE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510075000264",
    },
    {
        "school": "PHENIX ELEM",
        "district": "CHARLOTTE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510075000267",
    },
    {
        "school": "RANDOLPH-HENRY HIGH",
        "district": "CHARLOTTE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510075000270",
    },
    {
        "school": "EUREKA ELEM",
        "district": "CHARLOTTE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510075002005",
    },
    {
        "school": "CLINTWOOD ELEM",
        "district": "DICKENSON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510114000401",
    },
    {
        "school": "ERVINTON ELEM",
        "district": "DICKENSON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510114000404",
    },
    {
        "school": "SANDLICK ELEM",
        "district": "DICKENSON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510114000408",
    },
    {
        "school": "CHESAPEAKE BAY GOV. SCH.",
        "district": "CHESAPEAKE BAY GOV SCH",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510003401934",
    },
    {
        "school": "ESSEX HIGH",
        "district": "ESSEX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510120000419",
    },
    {
        "school": "ESSEX INT.",
        "district": "ESSEX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510120000420",
    },
    {
        "school": "TAPPAHANNOCK ELEM",
        "district": "ESSEX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510120000421",
    },
    {
        "school": "CHECK ELEM",
        "district": "FLOYD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510135000617",
    },
    {
        "school": "FLOYD COUNTY HIGH",
        "district": "FLOYD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510135000618",
    },
    {
        "school": "FLOYD ELEM",
        "district": "FLOYD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510135000619",
    },
    {
        "school": "INDIAN VALLEY ELEM",
        "district": "FLOYD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510135000620",
    },
    {
        "school": "WILLIS ELEM",
        "district": "FLOYD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510135000621",
    },
    {
        "school": "FAIRVIEW ELEM",
        "district": "GRAYSON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510169000693",
    },
    {
        "school": "GRAYSON CO. HIGH CAREER & TECH. ED.",
        "district": "GRAYSON CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510169000695",
    },
    {
        "school": "INDEPENDENCE ELEM",
        "district": "GRAYSON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510169000696",
    },
    {
        "school": "GRAYSON COUNTY HIGH",
        "district": "GRAYSON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510169000697",
    },
    {
        "school": "INDEPENDENCE MIDDLE",
        "district": "GRAYSON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510169002189",
    },
    {
        "school": "BELFIELD ELEM",
        "district": "GREENSVILLE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510174000703",
    },
    {
        "school": "EDWARD W WYATT MIDDLE",
        "district": "GREENSVILLE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510174000707",
    },
    {
        "school": "GREENSVILLE ELEM",
        "district": "GREENSVILLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510174001827",
    },
    {
        "school": "CLAYS MILL ELEM",
        "district": "HALIFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510177000710",
    },
    {
        "school": "HALIFAX COUNTY MIDDLE",
        "district": "HALIFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510177000714",
    },
    {
        "school": "MEADVILLE ELEM",
        "district": "HALIFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510177000716",
    },
    {
        "school": "SCOTTSBURG ELEM",
        "district": "HALIFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510177000717",
    },
    {
        "school": "SYDNOR JENNINGS ELEM",
        "district": "HALIFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510177000720",
    },
    {
        "school": "HALIFAX COUNTY HIGH",
        "district": "HALIFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510177001848",
    },
    {
        "school": "HALIFAX COUNTY CAREER CTR.",
        "district": "HALIFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510177001907",
    },
    {
        "school": "HIGHLAND ELEM",
        "district": "HIGHLAND CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510195000861",
    },
    {
        "school": "HIGHLAND HIGH",
        "district": "HIGHLAND CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510195000862",
    },
    {
        "school": "LANCASTER HIGH",
        "district": "LANCASTER CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510216000887",
    },
    {
        "school": "LANCASTER MIDDLE",
        "district": "LANCASTER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510216000888",
    },
    {
        "school": "LANCASTER PRIMARY",
        "district": "LANCASTER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510216000889",
    },
    {
        "school": "DRYDEN ELEM",
        "district": "LEE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510219000890",
    },
    {
        "school": "ELK KNOB ELEM",
        "district": "LEE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510219000891",
    },
    {
        "school": "ELYDALE MIDDLE",
        "district": "LEE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510219000892",
    },
    {
        "school": "FLATWOODS ELEM",
        "district": "LEE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510219000894",
    },
    {
        "school": "JONESVILLE MIDDLE",
        "district": "LEE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510219000896",
    },
    {
        "school": "LEE COUNTY CAREER & TECH. CENTER",
        "district": "LEE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510219000898",
    },
    {
        "school": "PENNINGTON MIDDLE",
        "district": "LEE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510219000900",
    },
    {
        "school": "ROSE HILL ELEM",
        "district": "LEE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510219000901",
    },
    {
        "school": "ST. CHARLES ELEM",
        "district": "LEE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510219000902",
    },
    {
        "school": "THOMAS WALKER HIGH",
        "district": "LEE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510219000904",
    },
    {
        "school": "LEE HIGH",
        "district": "LEE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510219002152",
    },
    {
        "school": "CENTRAL HIGH",
        "district": "LUNENBURG CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510231000944",
    },
    {
        "school": "KENBRIDGE ELEM",
        "district": "LUNENBURG CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510231000946",
    },
    {
        "school": "LUNENBURG MIDDLE",
        "district": "LUNENBURG CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510231000947",
    },
    {
        "school": "VICTORIA ELEM",
        "district": "LUNENBURG CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510231000949",
    },
    {
        "school": "MADISON COUNTY HIGH",
        "district": "MADISON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510237000972",
    },
    {
        "school": "MADISON PRIMARY",
        "district": "MADISON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510237000973",
    },
    {
        "school": "WAVERLY YOWELL ELEM",
        "district": "MADISON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510237000974",
    },
    {
        "school": "WILLIAM H. WETSEL MIDDLE",
        "district": "MADISON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510237000975",
    },
    {
        "school": "BLUESTONE MIDDLE",
        "district": "MECKLENBURG CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510246000995",
    },
    {
        "school": "BLUESTONE  HIGH",
        "district": "MECKLENBURG CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510246000996",
    },
    {
        "school": "CHASE CITY ELEM",
        "district": "MECKLENBURG CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510246001002",
    },
    {
        "school": "CLARKSVILLE ELEM",
        "district": "MECKLENBURG CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510246001004",
    },
    {
        "school": "LACROSSE ELEM",
        "district": "MECKLENBURG CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510246001006",
    },
    {
        "school": "PARK VIEW MIDDLE",
        "district": "MECKLENBURG CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510246001007",
    },
    {
        "school": "PARK VIEW HIGH",
        "district": "MECKLENBURG CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510246001008",
    },
    {
        "school": "SOUTH HILL ELEM",
        "district": "MECKLENBURG CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510246001009",
    },
    {
        "school": "MIDDLESEX HIGH",
        "district": "MIDDLESEX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510249001012",
    },
    {
        "school": "ST. CLARE WALKER MIDDLE",
        "district": "MIDDLESEX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510249002195",
    },
    {
        "school": "MIDDLESEX ELEM",
        "district": "MIDDLESEX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510249002293",
    },
    {
        "school": "OCCOHANNOCK ELEM",
        "district": "NORTHAMPTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510271000554",
    },
    {
        "school": "KIPTOPEKE ELEM",
        "district": "NORTHAMPTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510271000555",
    },
    {
        "school": "NORTHAMPTON HIGH",
        "district": "NORTHAMPTON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510271001155",
    },
    {
        "school": "THE T.E.C.H. CENTER",
        "district": "NORTHAMPTON CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510271001161",
    },
    {
        "school": "NORTHUMBERLAND HIGH",
        "district": "NORTHUMBERLAND CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510273001159",
    },
    {
        "school": "NORTHUMBERLAND ELEM",
        "district": "NORTHUMBERLAND CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510273001392",
    },
    {
        "school": "NORTHUMBERLAND MIDDLE",
        "district": "NORTHUMBERLAND CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510273001941",
    },
    {
        "school": "NOTTOWAY INTERMEDIATE",
        "district": "NOTTOWAY CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510279001165",
    },
    {
        "school": "BLACKSTONE PRIMARY",
        "district": "NOTTOWAY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510279001166",
    },
    {
        "school": "CREWE PRIMARY",
        "district": "NOTTOWAY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510279001169",
    },
    {
        "school": "NOTTOWAY HIGH",
        "district": "NOTTOWAY CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510279001942",
    },
    {
        "school": "NOTTOWAY MIDDLE",
        "district": "NOTTOWAY CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510279001943",
    },
    {
        "school": "GORDON-BARBOUR ELEM",
        "district": "ORANGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510282001172",
    },
    {
        "school": "LIGHTFOOT ELEM",
        "district": "ORANGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510282001173",
    },
    {
        "school": "ORANGE CO. HIGH",
        "district": "ORANGE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510282001174",
    },
    {
        "school": "ORANGE ELEM",
        "district": "ORANGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510282001175",
    },
    {
        "school": "PROSPECT HEIGHTS MIDDLE",
        "district": "ORANGE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510282001176",
    },
    {
        "school": "UNIONVILLE ELEM",
        "district": "ORANGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510282001177",
    },
    {
        "school": "LOCUST GROVE ELEM",
        "district": "ORANGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510282002196",
    },
    {
        "school": "PAGE COUNTY TECHNICAL CTR.",
        "district": "PAGE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510285000578",
    },
    {
        "school": "LURAY ELEM",
        "district": "PAGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510285001179",
    },
    {
        "school": "LURAY HIGH",
        "district": "PAGE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510285001180",
    },
    {
        "school": "PAGE COUNTY HIGH",
        "district": "PAGE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510285001181",
    },
    {
        "school": "SHENANDOAH ELEM",
        "district": "PAGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510285001182",
    },
    {
        "school": "SPRINGFIELD ELEM",
        "district": "PAGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510285001183",
    },
    {
        "school": "STANLEY ELEM",
        "district": "PAGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510285001184",
    },
    {
        "school": "BLUE RIDGE ELEM",
        "district": "PATRICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510288001185",
    },
    {
        "school": "HARDIN REYNOLDS ELEM",
        "district": "PATRICK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510288001186",
    },
    {
        "school": "MEADOWS OF DAN ELEM",
        "district": "PATRICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510288001187",
    },
    {
        "school": "PATRICK COUNTY HIGH",
        "district": "PATRICK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510288001188",
    },
    {
        "school": "PATRICK SPRINGS ELEM",
        "district": "PATRICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510288001189",
    },
    {
        "school": "STUART ELEM",
        "district": "PATRICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510288001191",
    },
    {
        "school": "WOOLWINE ELEM",
        "district": "PATRICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510288001192",
    },
    {
        "school": "PRINCE EDWARD COUNTY HIGH",
        "district": "PRINCE EDWARD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510306001271",
    },
    {
        "school": "PRINCE EDWARD ELEM",
        "district": "PRINCE EDWARD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510306001272",
    },
    {
        "school": "PRINCE EDWARD MIDDLE",
        "district": "PRINCE EDWARD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510306002130",
    },
    {
        "school": "RAPPAHANNOCK CO. HIGH",
        "district": "RAPPAHANNOCK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510321001346",
    },
    {
        "school": "RAPPAHANNOCK COUNTY ELEM",
        "district": "RAPPAHANNOCK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510321001347",
    },
    {
        "school": "NORTHERN NECK TECHNICAL CENTER",
        "district": "NORTHERN NECK TECHNICAL CENTER",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510001202025",
    },
    {
        "school": "RAPPAHANNOCK HIGH",
        "district": "RICHMOND CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510327001409",
    },
    {
        "school": "RICHMOND COUNTY ELEM",
        "district": "RICHMOND CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510327001974",
    },
    {
        "school": "ROCKBRIDGE COUNTY HIGH",
        "district": "ROCKBRIDGE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510337000204",
    },
    {
        "school": "FAIRFIELD ELEM",
        "district": "ROCKBRIDGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510337001481",
    },
    {
        "school": "MOUNTAIN VIEW ELEM",
        "district": "ROCKBRIDGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510337001485",
    },
    {
        "school": "NATURAL BRIDGE ELEM",
        "district": "ROCKBRIDGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510337001486",
    },
    {
        "school": "BELFAST ELEM",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510342001512",
    },
    {
        "school": "CASTLEWOOD ELEM",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510342001513",
    },
    {
        "school": "CASTLEWOOD HIGH",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510342001514",
    },
    {
        "school": "COPPER CREEK ELEM",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510342001518",
    },
    {
        "school": "HONAKER ELEM",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510342001521",
    },
    {
        "school": "HONAKER HIGH",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510342001522",
    },
    {
        "school": "LEBANON PRIMARY",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510342001523",
    },
    {
        "school": "LEBANON ELEM",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510342001524",
    },
    {
        "school": "RUSSELL COUNTY VOC.",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510342001526",
    },
    {
        "school": "SWORDS CREEK ELEM",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510342001527",
    },
    {
        "school": "LEBANON HIGH",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510342002042",
    },
    {
        "school": "SIGNAL KNOB MIDDLE",
        "district": "SHENANDOAH CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510351000221",
    },
    {
        "school": "NORTH FORK MIDDLE",
        "district": "SHENANDOAH CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510351000581",
    },
    {
        "school": "PETER MUHLENBERG MIDDLE",
        "district": "SHENANDOAH CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510351000958",
    },
    {
        "school": "ASHBY LEE ELEM",
        "district": "SHENANDOAH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510351001542",
    },
    {
        "school": "CENTRAL HIGH",
        "district": "SHENANDOAH CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510351001543",
    },
    {
        "school": "SANDY HOOK ELEM",
        "district": "SHENANDOAH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510351001547",
    },
    {
        "school": "STONEWALL JACKSON HIGH",
        "district": "SHENANDOAH CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510351001548",
    },
    {
        "school": "STRASBURG HIGH",
        "district": "SHENANDOAH CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510351001549",
    },
    {
        "school": "TRIPLETT BUSINESS & TECH.",
        "district": "SHENANDOAH CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510351001552",
    },
    {
        "school": "W.W. ROBINSON ELEM",
        "district": "SHENANDOAH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510351001554",
    },
    {
        "school": "SOUTHWESTERN VA MENTAL HEALTH INSTITUTE",
        "district": "SW VA MENTAL HEALTH INSTITUTE",
        "level": "High",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510004702311",
    },
    {
        "school": "NORTHWOOD MIDDLE",
        "district": "SMYTH CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001411",
    },
    {
        "school": "CHILHOWIE MIDDLE",
        "district": "SMYTH CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001441",
    },
    {
        "school": "ATKINS ELEM",
        "district": "SMYTH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001556",
    },
    {
        "school": "CHILHOWIE ELEM",
        "district": "SMYTH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001557",
    },
    {
        "school": "CHILHOWIE HIGH",
        "district": "SMYTH CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001558",
    },
    {
        "school": "OAK POINT ELEM",
        "district": "SMYTH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001559",
    },
    {
        "school": "MARION MIDDLE",
        "district": "SMYTH CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001560",
    },
    {
        "school": "MARION ELEM",
        "district": "SMYTH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001561",
    },
    {
        "school": "MARION SENIOR HIGH",
        "district": "SMYTH CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001562",
    },
    {
        "school": "NORTHWOOD HIGH",
        "district": "SMYTH CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001563",
    },
    {
        "school": "RICH VALLEY ELEM",
        "district": "SMYTH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001564",
    },
    {
        "school": "SALTVILLE ELEM",
        "district": "SMYTH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352001566",
    },
    {
        "school": "SMYTH CO. CAREER & TECH. CTR.",
        "district": "SMYTH CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510352001567",
    },
    {
        "school": "CAPRON ELEM",
        "district": "SOUTHAMPTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510360001573",
    },
    {
        "school": "RIVERDALE ELEM",
        "district": "SOUTHAMPTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510360001577",
    },
    {
        "school": "SOUTHAMPTON HIGH",
        "district": "SOUTHAMPTON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510360001582",
    },
    {
        "school": "SOUTHAMPTON MIDDLE",
        "district": "SOUTHAMPTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510360001583",
    },
    {
        "school": "MEHERRIN ELEM",
        "district": "SOUTHAMPTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510360002312",
    },
    {
        "school": "NOTTOWAY ELEM",
        "district": "SOUTHAMPTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510360002313",
    },
    {
        "school": "COLONIAL BEACH ELEM",
        "district": "COLONIAL BEACH PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510093001956",
    },
    {
        "school": "COLONIAL BEACH HIGH",
        "district": "COLONIAL BEACH PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510093001957",
    },
    {
        "school": "MONTROSS MIDDLE",
        "district": "WESTMORELAND CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510398001764",
    },
    {
        "school": "COPLE ELEM",
        "district": "WESTMORELAND CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510398001765",
    },
    {
        "school": "WASHINGTON & LEE HIGH",
        "district": "WESTMORELAND CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510398001768",
    },
    {
        "school": "WASHINGTON DISTRICT ELEM",
        "district": "WESTMORELAND CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510398001769",
    },
    {
        "school": "EASTSIDE HIGH",
        "district": "WISE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510408001786",
    },
    {
        "school": "COEBURN MIDDLE",
        "district": "WISE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510408001787",
    },
    {
        "school": "COEBURN PRIMARY",
        "district": "WISE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510408001788",
    },
    {
        "school": "CENTRAL HIGH",
        "district": "WISE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510408001789",
    },
    {
        "school": "J.W. ADAMS COMBINED",
        "district": "WISE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510408001790",
    },
    {
        "school": "UNION HIGH",
        "district": "WISE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510408001792",
    },
    {
        "school": "UNION PRIMARY SCHOOL",
        "district": "WISE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510408001793",
    },
    {
        "school": "ST. PAUL ELEM",
        "district": "WISE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510408001794",
    },
    {
        "school": "WISE COUNTY CAREER-TECHNICAL CENTER",
        "district": "WISE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510408001796",
    },
    {
        "school": "L.F. ADDINGTON MIDDLE",
        "district": "WISE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510408001797",
    },
    {
        "school": "WISE PRIMARY",
        "district": "WISE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510408001798",
    },
    {
        "school": "UNION MIDDLE",
        "district": "WISE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510408002050",
    },
    {
        "school": "LAUREL ELEM",
        "district": "CARROLL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510069000250",
    },
    {
        "school": "JACKSON MEMORIAL ELEM",
        "district": "WYTHE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411001799",
    },
    {
        "school": "FORT CHISWELL HIGH",
        "district": "WYTHE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411001800",
    },
    {
        "school": "GEORGE WYTHE HIGH",
        "district": "WYTHE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411001801",
    },
    {
        "school": "MAX MEADOWS ELEM",
        "district": "WYTHE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411001803",
    },
    {
        "school": "RURAL RETREAT ELEM",
        "district": "WYTHE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411001804",
    },
    {
        "school": "RURAL RETREAT HIGH",
        "district": "WYTHE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411001805",
    },
    {
        "school": "SHEFFEY ELEM",
        "district": "WYTHE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411001807",
    },
    {
        "school": "SPEEDWELL ELEM",
        "district": "WYTHE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411001808",
    },
    {
        "school": "SPILLER ELEM",
        "district": "WYTHE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411001809",
    },
    {
        "school": "WYTHE COUNTY TECH CENTER",
        "district": "WYTHE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510411001810",
    },
    {
        "school": "FORT CHISWELL MIDDLE",
        "district": "WYTHE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411002327",
    },
    {
        "school": "RURAL RETREAT MIDDLE",
        "district": "WYTHE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411002328",
    },
    {
        "school": "SCOTT MEMORIAL MIDDLE",
        "district": "WYTHE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510411002329",
    },
    {
        "school": "ENDERLY HEIGHTS ELEM",
        "district": "BUENA VISTA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510056000215",
    },
    {
        "school": "FW KLING JR ELEM",
        "district": "BUENA VISTA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510056000216",
    },
    {
        "school": "PARRY MCCLUER HIGH",
        "district": "BUENA VISTA CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510056000217",
    },
    {
        "school": "PARRY MCCLUER MIDDLE",
        "district": "BUENA VISTA CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510056000218",
    },
    {
        "school": "JACKSON RIVER GOV. SCH.",
        "district": "JACKSON RIVER GOVERNOR'S SCHOOL",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006302563",
    },
    {
        "school": "SHARON ELEM",
        "district": "ALLEGHANY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510015201891",
    },
    {
        "school": "JACKSON RIVER TECH CTR",
        "district": "JACKSON RIVER TECH CTR",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510000402016",
    },
    {
        "school": "COVINGTON HIGH",
        "district": "COVINGTON CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510099000367",
    },
    {
        "school": "EDGEMONT PRIMARY",
        "district": "COVINGTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510099000368",
    },
    {
        "school": "JETER-WATSON INTERMEDIATE",
        "district": "COVINGTON CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510099000369",
    },
    {
        "school": "GREENSVILLE COUNTY HIGH",
        "district": "GREENSVILLE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510174000706",
    },
    {
        "school": "FRANKLIN HIGH",
        "district": "FRANKLIN CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510141000628",
    },
    {
        "school": "S.P. MORTON ELEM",
        "district": "FRANKLIN CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510141000631",
    },
    {
        "school": "COOP CTR FOR EXCEP CHILDREN",
        "district": "COOP CTRS FOR EXCEPTIONAL CHILDREN",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510001402086",
    },
    {
        "school": "GALAX HIGH",
        "district": "GALAX CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510156000301",
    },
    {
        "school": "GALAX MIDDLE",
        "district": "GALAX CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510156000356",
    },
    {
        "school": "GALAX ELEM",
        "district": "GALAX CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510156000665",
    },
    {
        "school": "HARRINGTON WADDELL ELEM",
        "district": "LEXINGTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510222000905",
    },
    {
        "school": "LYLBURN DOWNING MIDDLE",
        "district": "LEXINGTON CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510222000907",
    },
    {
        "school": "CENTRAL ELEM",
        "district": "ROCKBRIDGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510337001479",
    },
    {
        "school": "MAURY RIVER MIDDLE",
        "district": "ROCKBRIDGE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510337001871",
    },
    {
        "school": "J.I. BURTON HIGH",
        "district": "NORTON CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510276001162",
    },
    {
        "school": "NORTON ELEM",
        "district": "NORTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510276001163",
    },
    {
        "school": "A G RICHARDSON ELEM",
        "district": "CULPEPER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510105000374",
    },
    {
        "school": "CULPEPER COUNTY HIGH",
        "district": "CULPEPER CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510105000376",
    },
    {
        "school": "CULPEPER MIDDLE",
        "district": "CULPEPER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510105000377",
    },
    {
        "school": "FARMINGTON ELEM",
        "district": "CULPEPER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510105000378",
    },
    {
        "school": "PEARL SAMPLE ELEM",
        "district": "CULPEPER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510105000380",
    },
    {
        "school": "SYCAMORE PARK ELEM",
        "district": "CULPEPER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510105000382",
    },
    {
        "school": "EMERALD HILL ELEM",
        "district": "CULPEPER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510105001612",
    },
    {
        "school": "FLOYD T BINNS MIDDLE",
        "district": "CULPEPER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510105001958",
    },
    {
        "school": "GALBREATH-MARSHALL BLDG",
        "district": "CULPEPER CO PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510105001959",
    },
    {
        "school": "KING GEORGE ELEM",
        "district": "KING GEO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510210000881",
    },
    {
        "school": "KING GEORGE HIGH",
        "district": "KING GEO CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510210000882",
    },
    {
        "school": "KING GEORGE MIDDLE",
        "district": "KING GEO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510210000883",
    },
    {
        "school": "POTOMAC ELEM",
        "district": "KING GEO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510210000884",
    },
    {
        "school": "ALTERN ED PRGM/BEHAV DISORD YOUTH/MONTGOMERY",
        "district": "ALT ED PRGM/BEHAV DISORD YOUTH/MONTGOMERY",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510007802353",
    },
    {
        "school": "PULASKI ELEM",
        "district": "PULASKI CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510315002460",
    },
    {
        "school": "GILES COUNTY TECH. CENTER",
        "district": "GILES CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510159000668",
    },
    {
        "school": "GILES HIGH",
        "district": "GILES CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510159000669",
    },
    {
        "school": "MACY MCCLAUGHERTY COMBINED",
        "district": "GILES CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510159000671",
    },
    {
        "school": "NARROWS ELEM/MID.",
        "district": "GILES CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510159000672",
    },
    {
        "school": "NARROWS HIGH",
        "district": "GILES CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510159000673",
    },
    {
        "school": "EASTERN COMBINED",
        "district": "GILES CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510159001920",
    },
    {
        "school": "FALLING BRANCH ELEM",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252000178",
    },
    {
        "school": "KIPPS ELEM",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252000916",
    },
    {
        "school": "AUBURN HIGH",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001013",
    },
    {
        "school": "BELVIEW ELEM",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001014",
    },
    {
        "school": "BLACKSBURG HIGH",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001016",
    },
    {
        "school": "BLACKSBURG MIDDLE",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001017",
    },
    {
        "school": "CHRISTIANSBURG HIGH",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001019",
    },
    {
        "school": "CHRISTIANSBURG MIDDLE",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001020",
    },
    {
        "school": "CHRISTIANSBURG PRIMARY",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001021",
    },
    {
        "school": "GILBERT LINKOUS ELEM",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001023",
    },
    {
        "school": "HARDING AVENUE ELEM",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001024",
    },
    {
        "school": "MARGARET BEEKS ELEM",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001025",
    },
    {
        "school": "PRICES FORK ELEM",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001026",
    },
    {
        "school": "SHAWSVILLE MIDDLE",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001029",
    },
    {
        "school": "AUBURN ELEM",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001859",
    },
    {
        "school": "AUBURN MIDDLE",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252001916",
    },
    {
        "school": "CHRISTIANSBURG ELEM",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252002126",
    },
    {
        "school": "MONTGOMERY CENTRAL",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510252002155",
    },
    {
        "school": "EASTERN MONTGOMERY HIGH",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252002541",
    },
    {
        "school": "SOUTHWEST VIRGINIA GOV. SCH.",
        "district": "SOUTHWEST VIRGINIA GOV SCH",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510217402230",
    },
    {
        "school": "CRITZER ELEM",
        "district": "PULASKI CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510315001330",
    },
    {
        "school": "DUBLIN ELEM",
        "district": "PULASKI CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510315001332",
    },
    {
        "school": "DUBLIN MIDDLE",
        "district": "PULASKI CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510315001333",
    },
    {
        "school": "PULASKI COUNTY SR. HIGH",
        "district": "PULASKI CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510315001338",
    },
    {
        "school": "PULASKI MIDDLE",
        "district": "PULASKI CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510315001339",
    },
    {
        "school": "RIVERLAWN ELEM",
        "district": "PULASKI CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510315001340",
    },
    {
        "school": "SNOWVILLE ELEM",
        "district": "PULASKI CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510315001341",
    },
    {
        "school": "BELLE HETH ELEM",
        "district": "RADFORD CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510318001342",
    },
    {
        "school": "MCHARG ELEM",
        "district": "RADFORD CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510318001344",
    },
    {
        "school": "RADFORD HIGH",
        "district": "RADFORD CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510318001345",
    },
    {
        "school": "JOHN N. DALTON INT.",
        "district": "RADFORD CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510318001858",
    },
    {
        "school": "ABBS VALLEY-BOISSEVAIN ELEM",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001645",
    },
    {
        "school": "CEDAR BLUFF ELEM",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001648",
    },
    {
        "school": "DUDLEY PRIMARY",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001650",
    },
    {
        "school": "GRAHAM INTERMEDIATE",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001652",
    },
    {
        "school": "GRAHAM HIGH",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001653",
    },
    {
        "school": "GRAHAM MIDDLE",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001654",
    },
    {
        "school": "TAZEWELL INTERMEDIATE",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001657",
    },
    {
        "school": "RICHLANDS ELEM",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001660",
    },
    {
        "school": "RICHLANDS HIGH",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001661",
    },
    {
        "school": "RICHLANDS MIDDLE",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001662",
    },
    {
        "school": "TAZEWELL CO. CAREER & TECH. CTR.",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510381001666",
    },
    {
        "school": "TAZEWELL PRIMARY",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001667",
    },
    {
        "school": "TAZEWELL HIGH",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001668",
    },
    {
        "school": "TAZEWELL MIDDLE",
        "district": "TAZEWELL CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510381001669",
    },
    {
        "school": "CROSSROADS ALTERNATIVE/BRISTOL CITY",
        "district": "CROSSROADS ALTERNATIVE/BRISTOL CITY",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510008602357",
    },
    {
        "school": "A. LINWOOD HOLTON GOV. SCH.",
        "district": "A. LINWOOD HOLTON GOV SCH",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510003301933",
    },
    {
        "school": "ABINGDON ELEM",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001735",
    },
    {
        "school": "ABINGDON HIGH",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001736",
    },
    {
        "school": "E.B. STANLEY MIDDLE",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001739",
    },
    {
        "school": "GLADE SPRING MIDDLE",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001740",
    },
    {
        "school": "GREENDALE ELEM",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001741",
    },
    {
        "school": "HIGH POINT ELEM",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001744",
    },
    {
        "school": "HOLSTON HIGH",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001745",
    },
    {
        "school": "JOHN S. BATTLE HIGH",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001746",
    },
    {
        "school": "MEADOWVIEW ELEM",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001748",
    },
    {
        "school": "PATRICK HENRY HIGH",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001749",
    },
    {
        "school": "VALLEY INSTITUTE ELEM",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001750",
    },
    {
        "school": "WASHINGTON COUNTY CAREER & TECHNICAL EDUCATION CENTER",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510390001751",
    },
    {
        "school": "WALLACE MIDDLE",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001752",
    },
    {
        "school": "DAMASCUS MIDDLE",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001984",
    },
    {
        "school": "RHEA VALLEY ELEM",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001985",
    },
    {
        "school": "WATAUGA ELEM",
        "district": "WASHINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510390001986",
    },
    {
        "school": "HIGHLAND VIEW ELEM",
        "district": "BRISTOL CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510045000175",
    },
    {
        "school": "JOSEPH VAN PELT ELEM",
        "district": "BRISTOL CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510045000176",
    },
    {
        "school": "STONEWALL JACKSON ELEM",
        "district": "BRISTOL CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510045000177",
    },
    {
        "school": "VIRGINIA HIGH",
        "district": "BRISTOL CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510045000179",
    },
    {
        "school": "VIRGINIA MIDDLE",
        "district": "BRISTOL CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510045000180",
    },
    {
        "school": "WASHINGTON LEE ELEM",
        "district": "BRISTOL CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510045000181",
    },
    {
        "school": "DAY TREATMENT PROGRAM",
        "district": "BRISTOL CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510045001944",
    },
    {
        "school": "PROJECT RETURN/FLUVANNA CO",
        "district": "PROJECT RETURN/FLUVANNA CO",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510007702352",
    },
    {
        "school": "ALTERNATIVE EDUCATION CENTER",
        "district": "GREENE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510171002439",
    },
    {
        "school": "NELSON COUNTY HIGH",
        "district": "NELSON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510258001032",
    },
    {
        "school": "NELSON MIDDLE",
        "district": "NELSON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510258001033",
    },
    {
        "school": "TYE RIVER ELEM",
        "district": "NELSON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510258001160",
    },
    {
        "school": "ROCKFISH RIVER ELEM",
        "district": "NELSON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510258001917",
    },
    {
        "school": "CHARLOTTESVILLE-ALBEMARLE TECH",
        "district": "CHARLOTTESVILLE-ALBEMARLE TECH",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510000302015",
    },
    {
        "school": "PIEDMONT REG ED/IVY CREEK",
        "district": "PIEDMONT REGIONAL ED.",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510001802090",
    },
    {
        "school": "AGNOR-HURT ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000002",
    },
    {
        "school": "VIRGINIA L MURRAY ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000003",
    },
    {
        "school": "ALBEMARLE HIGH",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000015",
    },
    {
        "school": "BROADUS WOOD ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000017",
    },
    {
        "school": "BROWNSVILLE ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000018",
    },
    {
        "school": "CROZET ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000020",
    },
    {
        "school": "HOLLYMEAD ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000022",
    },
    {
        "school": "JACK JOUETT MIDDLE",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000023",
    },
    {
        "school": "JOSEPH T HENLEY MIDDLE",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000025",
    },
    {
        "school": "LESLIE H WALTON MIDDLE",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000026",
    },
    {
        "school": "MARY CARR GREER ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000027",
    },
    {
        "school": "MERIWETHER LEWIS ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000028",
    },
    {
        "school": "RED HILL ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000029",
    },
    {
        "school": "STONE ROBINSON ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000032",
    },
    {
        "school": "STONY POINT ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000033",
    },
    {
        "school": "WESTERN ALBEMARLE HIGH",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000035",
    },
    {
        "school": "WOODBROOK ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000036",
    },
    {
        "school": "MORTIMER Y SUTHERLAND MIDDLE",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000751",
    },
    {
        "school": "MONTICELLO HIGH",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009001747",
    },
    {
        "school": "SCOTTSVILLE ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009001882",
    },
    {
        "school": "BAKER-BUTLER ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009001937",
    },
    {
        "school": "PAUL H CALE ELEM",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009002173",
    },
    {
        "school": "BLUE RIDGE GOV. SCH.",
        "district": "BLUE RIDGE GOV SCHOOL",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006202562",
    },
    {
        "school": "FLUVANNA MIDDLE",
        "district": "FLUVANNA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510138000089",
    },
    {
        "school": "CARYSBROOK ELEM",
        "district": "FLUVANNA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510138000622",
    },
    {
        "school": "FLUVANNA COUNTY HIGH",
        "district": "FLUVANNA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510138000625",
    },
    {
        "school": "WILLIAM MONROE MIDDLE",
        "district": "GREENE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510171000106",
    },
    {
        "school": "NATHANAEL GREENE PRIMARY SCHOOL",
        "district": "GREENE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510171000700",
    },
    {
        "school": "WILLIAM MONROE HIGH",
        "district": "GREENE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510171000702",
    },
    {
        "school": "GREENE CO. TECHNICAL ED. CTR.",
        "district": "GREENE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510171001382",
    },
    {
        "school": "RUCKERSVILLE ELEM",
        "district": "GREENE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510171001802",
    },
    {
        "school": "NATHANAEL GREENE ELEM",
        "district": "GREENE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510171002190",
    },
    {
        "school": "CHARLOTTESVILLE HOSP. EP.",
        "district": "UNIVERSITY OF VA",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510004102324",
    },
    {
        "school": "JACKSON P BURLEY MIDDLE",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000024",
    },
    {
        "school": "MURRAY HIGH",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009000030",
    },
    {
        "school": "JOHNSON ELEM",
        "district": "CHARLOTTESVILLE CTY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510078000266",
    },
    {
        "school": "BUFORD MIDDLE",
        "district": "CHARLOTTESVILLE CTY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510078000271",
    },
    {
        "school": "BURNLEY-MORAN ELEM",
        "district": "CHARLOTTESVILLE CTY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510078000272",
    },
    {
        "school": "CHARLOTTESVILLE HIGH",
        "district": "CHARLOTTESVILLE CTY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510078000273",
    },
    {
        "school": "GREENBRIER ELEM",
        "district": "CHARLOTTESVILLE CTY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510078000275",
    },
    {
        "school": "JACKSON-VIA ELEM",
        "district": "CHARLOTTESVILLE CTY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510078000276",
    },
    {
        "school": "WALKER UPPER ELEM",
        "district": "CHARLOTTESVILLE CTY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510078000279",
    },
    {
        "school": "CLARK ELEM",
        "district": "CHARLOTTESVILLE CTY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510078002110",
    },
    {
        "school": "VENABLE ELEM",
        "district": "CHARLOTTESVILLE CTY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510078002143",
    },
    {
        "school": "CHARLOTTESVILLE ALTERNATIVE",
        "district": "CHARLOTTESVILLE CTY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510078002550",
    },
    {
        "school": "REGIONAL ALTERNATIVE/PITTSLVANIA CO",
        "district": "REGIONAL ALTERNATIVE/PITTSLVANIA CO",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510008002355",
    },
    {
        "school": "BROSVILLE ELEM",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294002454",
    },
    {
        "school": "ADULT & CAREER  EDUCATION CTR",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510111002467",
    },
    {
        "school": "TUNSTALL MIDDLE",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001206",
    },
    {
        "school": "CHATHAM MIDDLE",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001208",
    },
    {
        "school": "CHATHAM ELEM",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001209",
    },
    {
        "school": "CHATHAM HIGH",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001210",
    },
    {
        "school": "DAN RIVER MIDDLE",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001213",
    },
    {
        "school": "DAN RIVER HIGH",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001214",
    },
    {
        "school": "GRETNA ELEM",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001216",
    },
    {
        "school": "GRETNA MIDDLE",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001217",
    },
    {
        "school": "GRETNA HIGH",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001218",
    },
    {
        "school": "JOHN L. HURT ELEM",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001219",
    },
    {
        "school": "KENTUCK ELEM",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001220",
    },
    {
        "school": "MT. AIRY ELEM",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001221",
    },
    {
        "school": "SOUTHSIDE ELEM",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001224",
    },
    {
        "school": "STONY MILL ELEM",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001226",
    },
    {
        "school": "TUNSTALL HIGH",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001227",
    },
    {
        "school": "UNION HALL ELEM",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001228",
    },
    {
        "school": "TWIN SPRINGS ELEM",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510294001395",
    },
    {
        "school": "PITTSYLVANIA VOC.-TECH. CTR.",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510294001856",
    },
    {
        "school": "SCHOOLFIELD ELEM",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111000268",
    },
    {
        "school": "FOREST HILLS ELEM",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111000388",
    },
    {
        "school": "G.L.H. JOHNSON ELEM",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111000389",
    },
    {
        "school": "GEORGE WASHINGTON HIGH",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111000390",
    },
    {
        "school": "GROVE PARK PRESCHOOL",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111000391",
    },
    {
        "school": "O. TRENT BONNER MIDDLE",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111000394",
    },
    {
        "school": "PARK AVENUE ELEM",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111000395",
    },
    {
        "school": "WOODBERRY HILLS ELEM",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111000398",
    },
    {
        "school": "WESTWOOD MIDDLE",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111001233",
    },
    {
        "school": "GALILEO MAGNET HIGH",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111002261",
    },
    {
        "school": "SOUTH RIVER ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339000954",
    },
    {
        "school": "BROADWAY HIGH",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001492",
    },
    {
        "school": "ELKTON ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001494",
    },
    {
        "school": "ELKTON MIDDLE",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001495",
    },
    {
        "school": "FULKS RUN ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001496",
    },
    {
        "school": "J. FRANK HILLYARD MIDDLE",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001498",
    },
    {
        "school": "JOHN W. WAYLAND ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001499",
    },
    {
        "school": "LINVILLE-EDOM ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001501",
    },
    {
        "school": "MCGAHEYSVILLE ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001503",
    },
    {
        "school": "OTTOBINE ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001507",
    },
    {
        "school": "PLAINS ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001508",
    },
    {
        "school": "WILBUR S. PENCE MIDDLE",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001511",
    },
    {
        "school": "JOHN C. MYERS ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001869",
    },
    {
        "school": "SPOTSWOOD HIGH",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001872",
    },
    {
        "school": "MONTEVIDEO MIDDLE",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001975",
    },
    {
        "school": "LACEY SPRING ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339002163",
    },
    {
        "school": "TURNER ASHBY HIGH",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339002164",
    },
    {
        "school": "PEAK VIEW ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339002310",
    },
    {
        "school": "MOUNTAIN VIEW ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339002545",
    },
    {
        "school": "MASSANUTTEN TECH CTR",
        "district": "MASSANUTTEN TECH CTR",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510000602018",
    },
    {
        "school": "STONE SPRING ELEM",
        "district": "HARRISONBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510186000602",
    },
    {
        "school": "HARRISONBURG HIGH",
        "district": "HARRISONBURG CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510186000782",
    },
    {
        "school": "KEISTER ELEM",
        "district": "HARRISONBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510186000783",
    },
    {
        "school": "SPOTSWOOD ELEM",
        "district": "HARRISONBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510186000785",
    },
    {
        "school": "WATERMAN ELEM",
        "district": "HARRISONBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510186000787",
    },
    {
        "school": "THOMAS HARRISON MIDDLE",
        "district": "HARRISONBURG CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510186002150",
    },
    {
        "school": "PLEASANT VALLEY ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339001509",
    },
    {
        "school": "RENAISSANCE/SCOTT CO",
        "district": "RENAISSANCE/SCOTT CO",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510008402375",
    },
    {
        "school": "DUFFIELD-PATTONSVILLE PRIMARY",
        "district": "SCOTT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001528",
    },
    {
        "school": "DUNGANNON INTERMEDIATE",
        "district": "SCOTT CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001529",
    },
    {
        "school": "FORT BLACKMORE PRIMARY",
        "district": "SCOTT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001531",
    },
    {
        "school": "GATE CITY HIGH",
        "district": "SCOTT CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001532",
    },
    {
        "school": "HILTON ELEM",
        "district": "SCOTT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001533",
    },
    {
        "school": "NICKELSVILLE ELEM",
        "district": "SCOTT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001534",
    },
    {
        "school": "RYE COVE INTERMEDIATE",
        "district": "SCOTT CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001535",
    },
    {
        "school": "RYE COVE HIGH",
        "district": "SCOTT CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001536",
    },
    {
        "school": "SCOTT COUNTY CAREER AND TECHNICAL CENTER",
        "district": "SCOTT CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510348001537",
    },
    {
        "school": "SHOEMAKER ELEM",
        "district": "SCOTT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001538",
    },
    {
        "school": "TWIN SPRINGS HIGH",
        "district": "SCOTT CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001539",
    },
    {
        "school": "WEBER CITY ELEM",
        "district": "SCOTT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001540",
    },
    {
        "school": "YUMA ELEM",
        "district": "SCOTT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348001541",
    },
    {
        "school": "GATE CITY MIDDLE",
        "district": "SCOTT CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510348002132",
    },
    {
        "school": "CORNERSTONE LEARNING CENTER",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510060002332",
    },
    {
        "school": "LYNCHBURG CITY SECONDARY ALTERNATIVE",
        "district": "LYNCHBURG CITY SECONDARY ALTERNATIVE",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510007202347",
    },
    {
        "school": "APPOMATTOX COUNTY HIGH",
        "district": "APPOMATTOX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510024000076",
    },
    {
        "school": "APPOMATTOX ELEM",
        "district": "APPOMATTOX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510024000077",
    },
    {
        "school": "APPOMATTOX MIDDLE",
        "district": "APPOMATTOX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510024000078",
    },
    {
        "school": "APPOMATTOX PRIMARY",
        "district": "APPOMATTOX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510024000079",
    },
    {
        "school": "CENTRAL VA. TRAINING CTR.",
        "district": "CENT VA TRAIN CT",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510005001950",
    },
    {
        "school": "MADISON HEIGHTS ELEM",
        "district": "AMHERST CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510021000010",
    },
    {
        "school": "AMELON ELEM",
        "district": "AMHERST CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510021000064",
    },
    {
        "school": "AMHERST COUNTY HIGH",
        "district": "AMHERST CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510021000065",
    },
    {
        "school": "AMHERST MIDDLE",
        "district": "AMHERST CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510021000066",
    },
    {
        "school": "AMHERST ELEM",
        "district": "AMHERST CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510021000067",
    },
    {
        "school": "CENTRAL ELEM",
        "district": "AMHERST CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510021000068",
    },
    {
        "school": "ELON ELEM",
        "district": "AMHERST CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510021000069",
    },
    {
        "school": "MONELISON MIDDLE",
        "district": "AMHERST CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510021000072",
    },
    {
        "school": "TEMPERANCE ELEM",
        "district": "AMHERST CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510021000075",
    },
    {
        "school": "BIG ISLAND ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036000145",
    },
    {
        "school": "BOONSBORO ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036000147",
    },
    {
        "school": "HUDDLESTON ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036000149",
    },
    {
        "school": "LIBERTY HIGH",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036000151",
    },
    {
        "school": "MONETA ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036000152",
    },
    {
        "school": "MONTVALE ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036000153",
    },
    {
        "school": "OTTER RIVER ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036000155",
    },
    {
        "school": "STAUNTON RIVER HIGH",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036000156",
    },
    {
        "school": "STEWARTSVILLE ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036000157",
    },
    {
        "school": "STAUNTON RIVER MIDDLE",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036002029",
    },
    {
        "school": "NEW LONDON ACADEMY ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036002109",
    },
    {
        "school": "FOREST ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036002142",
    },
    {
        "school": "FOREST MIDDLE",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036002174",
    },
    {
        "school": "JEFFERSON FOREST HIGH",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036002175",
    },
    {
        "school": "THOMAS JEFFERSON ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036002525",
    },
    {
        "school": "GOODVIEW ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036002526",
    },
    {
        "school": "ALTAVISTA ELEM",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060000219",
    },
    {
        "school": "ALTAVISTA HIGH",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060000220",
    },
    {
        "school": "BROOKVILLE HIGH",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060000223",
    },
    {
        "school": "BROOKVILLE MIDDLE",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060000224",
    },
    {
        "school": "CAMPBELL CO TECH  CTR",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510060000225",
    },
    {
        "school": "CONCORD ELEM",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060000226",
    },
    {
        "school": "LEESVILLE ROAD ELEM",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060000230",
    },
    {
        "school": "RUSTBURG HIGH",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060000231",
    },
    {
        "school": "TOMAHAWK ELEM",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060000232",
    },
    {
        "school": "WILLIAM CAMPBELL HIGH",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060000233",
    },
    {
        "school": "YELLOW BRANCH ELEM",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060000234",
    },
    {
        "school": "RUSTBURG ELEM",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060002528",
    },
    {
        "school": "BEDFORD SCIENCE AND TECHNOLOGY CENTER",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510036000142",
    },
    {
        "school": "LIBERTY MIDDLE",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036000143",
    },
    {
        "school": "BEDFORD PRIMARY",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036000144",
    },
    {
        "school": "BEDFORD ELEM",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510036002141",
    },
    {
        "school": "LAUREL REGIONAL SPECIAL ED CTR",
        "district": "LAUREL REGIONAL",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510002401572",
    },
    {
        "school": "CENTRAL VIRGINIA GOV. SCH.",
        "district": "CENTRAL VIRGINIA GOV SCH FOR SCI/TECH",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510217302229",
    },
    {
        "school": "T.C. MILLER ELEM FOR INNOVAT.",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000603",
    },
    {
        "school": "BEDFORD HILLS ELEM",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000952",
    },
    {
        "school": "PAUL LAURENCE DUNBAR MID. FOR INNOV.",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000955",
    },
    {
        "school": "E.C. GLASS HIGH",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000956",
    },
    {
        "school": "HERITAGE ELEM",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000959",
    },
    {
        "school": "HERITAGE HIGH",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000960",
    },
    {
        "school": "LINKHORNE ELEM",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000961",
    },
    {
        "school": "LINKHORNE MIDDLE",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000962",
    },
    {
        "school": "PAUL MUNRO ELEM",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000963",
    },
    {
        "school": "PERRYMONT ELEM",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000964",
    },
    {
        "school": "ROBERT S. PAYNE ELEM",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000965",
    },
    {
        "school": "SANDUSKY ELEM",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000966",
    },
    {
        "school": "SANDUSKY MIDDLE",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000967",
    },
    {
        "school": "SHEFFIELD ELEM",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000968",
    },
    {
        "school": "WILLIAM M. BASS ELEM",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234000970",
    },
    {
        "school": "DEARINGTON ELEM/INNOVATION",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510234002205",
    },
    {
        "school": "CARL B. HUTCHERSON BUILDING",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510234002206",
    },
    {
        "school": "BREAKING BARRIERS ALTERNATIVE ED/HENRY CO",
        "district": "BREAKING BARRIERS ALTERNATIVE ED/HENRY CO",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510009902369",
    },
    {
        "school": "PIEDMONT GOV. SCH. FOR MATH./SCI./TECH.",
        "district": "PIEDMONT GOV SCH FOR MATH/SCI/TECH",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510010302345",
    },
    {
        "school": "MOUNT OLIVET ELEM",
        "district": "HENRY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192002443",
    },
    {
        "school": "CLEARVIEW EARLY CHILDHOOD CTR.",
        "district": "MARTINSVILLE CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510240002618",
    },
    {
        "school": "BASSETT HIGH",
        "district": "HENRY CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192000837",
    },
    {
        "school": "CAMPBELL COURT ELEM",
        "district": "HENRY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192000838",
    },
    {
        "school": "LAUREL PARK MIDDLE",
        "district": "HENRY CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192000840",
    },
    {
        "school": "FIELDALE-COLLINSVILLE MIDDLE",
        "district": "HENRY CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192000847",
    },
    {
        "school": "MEADOW VIEW ELEMENTARY",
        "district": "HENRY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192000848",
    },
    {
        "school": "RICH ACRES ELEM",
        "district": "HENRY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192000853",
    },
    {
        "school": "DREWRY MASON ELEM",
        "district": "HENRY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192000855",
    },
    {
        "school": "SANVILLE ELEM",
        "district": "HENRY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192000857",
    },
    {
        "school": "G.W. CARVER ELEM",
        "district": "HENRY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192000859",
    },
    {
        "school": "STANLEYTOWN ELEM",
        "district": "HENRY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192000860",
    },
    {
        "school": "MAGNA VISTA HIGH",
        "district": "HENRY CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192002125",
    },
    {
        "school": "MARTINSVILLE HIGH",
        "district": "MARTINSVILLE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510240000988",
    },
    {
        "school": "MARTINSVILLE MIDDLE",
        "district": "MARTINSVILLE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510240000989",
    },
    {
        "school": "BLUE RIDGE JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202378",
    },
    {
        "school": "ROANOKE VALLEY JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202396",
    },
    {
        "school": "CHESTERFIELD JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202380",
    },
    {
        "school": "FAIRFAX JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202383",
    },
    {
        "school": "HANOVER HIGH",
        "district": "HANOVER CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183002338",
    },
    {
        "school": "HENRICO JUVENILE DETENTION HOME - JAMES RIVER",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202386",
    },
    {
        "school": "RIVERS EDGE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002410",
    },
    {
        "school": "HUNGARY CREEK MIDDLE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002440",
    },
    {
        "school": "GREENWOOD ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002441",
    },
    {
        "school": "VA. RANDOLPH ED. CTR",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510189002442",
    },
    {
        "school": "MIDDLE PENINSULA JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202399",
    },
    {
        "school": "MIDDLE PENINSULA ACADEMIC CENTER",
        "district": "REGIONAL ALTERNATIVE ED/KING WILLIAM",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510009102361",
    },
    {
        "school": "COOL SPRING PRIMARY",
        "district": "KING WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510212002339",
    },
    {
        "school": "LOUDOUN CO. JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202388",
    },
    {
        "school": "NEW RIVER VALLEY JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202390",
    },
    {
        "school": "PROJECT RETURN/POWHATAN CO",
        "district": "PROJECT RETURN/POWHATAN CO",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510008102356",
    },
    {
        "school": "PIEDMONT REGIONAL JUVENILE DETENTION CENTER",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202393",
    },
    {
        "school": "CRATER JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202394",
    },
    {
        "school": "PRINCE WILLIAM JUV. DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202403",
    },
    {
        "school": "RAPPAHANNOCK JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202397",
    },
    {
        "school": "NORTHERN VIRGINIA JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202376",
    },
    {
        "school": "HIGHLANDS JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202377",
    },
    {
        "school": "TIDEWATER JUVENILE DETENTION HOME - CHESAPEAKE",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202379",
    },
    {
        "school": "W.W. MOORE JR. JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202382",
    },
    {
        "school": "NEW HOPE ACADEMY",
        "district": "HOPEWELL CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510198002421",
    },
    {
        "school": "LYNCHBURG JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202389",
    },
    {
        "school": "NEWPORT NEWS JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202391",
    },
    {
        "school": "NORFOLK JUVENILE DETENTION CENTER",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202392",
    },
    {
        "school": "PETERSBURG REGIONAL ALTERNATIVE",
        "district": "PETERSBURG REGIONAL ALTERNATIVE",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510007902354",
    },
    {
        "school": "RICHMOND JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202395",
    },
    {
        "school": "METRO RICHMOND ALTERNATIVE ED",
        "district": "METRO RICHMOND ALTERNATIVE ED",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510008702358",
    },
    {
        "school": "REAL SPECIAL ED. CTR.",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510324002424",
    },
    {
        "school": "THIRTEEN ACRES SPECIAL ED. CTR.",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510324002425",
    },
    {
        "school": "SHENANDOAH VALLEY JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202398",
    },
    {
        "school": "VIRGINIA BEACH JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202476",
    },
    {
        "school": "AMELIA-NOTTOWAY VOC CTR",
        "district": "AMELIA-NOTTOWAY VOC CTR",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510001302026",
    },
    {
        "school": "AMELIA COUNTY ELEM",
        "district": "AMELIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510018000062",
    },
    {
        "school": "AMELIA COUNTY MIDDLE",
        "district": "AMELIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510018000063",
    },
    {
        "school": "AMELIA COUNTY HIGH",
        "district": "AMELIA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510018001828",
    },
    {
        "school": "CAROLINE MIDDLE",
        "district": "CAROLINE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510066000051",
    },
    {
        "school": "BOWLING GREEN ELEM",
        "district": "CAROLINE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510066000237",
    },
    {
        "school": "CAROLINE HIGH",
        "district": "CAROLINE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510066000238",
    },
    {
        "school": "MADISON ELEM",
        "district": "CAROLINE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510066000241",
    },
    {
        "school": "CUMBERLAND HIGH",
        "district": "CUMBERLAND CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510108000057",
    },
    {
        "school": "CUMBERLAND MIDDLE",
        "district": "CUMBERLAND CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510108000058",
    },
    {
        "school": "CUMBERLAND ELEM",
        "district": "CUMBERLAND CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510108000383",
    },
    {
        "school": "HAMILTON HOLMES MIDDLE",
        "district": "KING WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510212000885",
    },
    {
        "school": "KING WILLIAM HIGH",
        "district": "KING WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510212000886",
    },
    {
        "school": "ACQUINTON ELEM",
        "district": "KING WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510212002151",
    },
    {
        "school": "WEST POINT ELEM",
        "district": "WEST POINT PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510395001762",
    },
    {
        "school": "WEST POINT MIDDLE/HIGH",
        "district": "WEST POINT PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510395001763",
    },
    {
        "school": "LOUISA COUNTY HIGH",
        "district": "LOUISA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510228000939",
    },
    {
        "school": "THOMAS JEFFERSON ELEM",
        "district": "LOUISA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510228000942",
    },
    {
        "school": "LOUISA COUNTY MIDDLE",
        "district": "LOUISA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510228001930",
    },
    {
        "school": "JOUETT ELEM",
        "district": "LOUISA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510228002036",
    },
    {
        "school": "TREVILIANS ELEM",
        "district": "LOUISA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510228002066",
    },
    {
        "school": "SUSSEX CENTRAL HIGH",
        "district": "SUSSEX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510378001643",
    },
    {
        "school": "CHARLES CITY CO HIGH",
        "district": "CHARLES CITY CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510072000258",
    },
    {
        "school": "CHARLES CITY CO ELEM",
        "district": "CHARLES CITY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510072000260",
    },
    {
        "school": "BAILEY BRIDGE MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000053",
    },
    {
        "school": "MANCHESTER HIGH",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000056",
    },
    {
        "school": "A M DAVIS ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000314",
    },
    {
        "school": "BELLWOOD ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000315",
    },
    {
        "school": "BENSLEY ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000316",
    },
    {
        "school": "BEULAH ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000317",
    },
    {
        "school": "BON AIR ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000318",
    },
    {
        "school": "C C WELLS ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000319",
    },
    {
        "school": "C E CURTIS ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000320",
    },
    {
        "school": "CARVER MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000321",
    },
    {
        "school": "CHESTERFIELD CAREER AND TECHNICAL CENTER AT COURTHOUSE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510084000323",
    },
    {
        "school": "CLOVER HILL HIGH",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000324",
    },
    {
        "school": "CRESTWOOD ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000325",
    },
    {
        "school": "ENON ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000326",
    },
    {
        "school": "ETTRICK ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000327",
    },
    {
        "school": "FALLING CREEK ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000328",
    },
    {
        "school": "FALLING CREEK MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000329",
    },
    {
        "school": "GRANGE HALL ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000330",
    },
    {
        "school": "GREENFIELD ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000331",
    },
    {
        "school": "HARROWGATE ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000332",
    },
    {
        "school": "HOPKINS ROAD ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000333",
    },
    {
        "school": "J A CHALKLEY ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000334",
    },
    {
        "school": "J B WATKINS ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000335",
    },
    {
        "school": "J G HENING ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000336",
    },
    {
        "school": "LLOYD C BIRD HIGH",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000337",
    },
    {
        "school": "MANCHESTER MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000338",
    },
    {
        "school": "MATOACA ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000339",
    },
    {
        "school": "MATOACA HIGH",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000340",
    },
    {
        "school": "MATOACA MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000341",
    },
    {
        "school": "MEADOWBROOK HIGH",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000342",
    },
    {
        "school": "MIDLOTHIAN MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000343",
    },
    {
        "school": "PROVIDENCE MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000344",
    },
    {
        "school": "REAMS ROAD ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000345",
    },
    {
        "school": "ROBIOUS ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000346",
    },
    {
        "school": "ROBIOUS MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000347",
    },
    {
        "school": "SALEM CHURCH ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000348",
    },
    {
        "school": "SALEM CHURCH MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000349",
    },
    {
        "school": "THOMAS DALE HIGH",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000350",
    },
    {
        "school": "ALBERTA SMITH ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000462",
    },
    {
        "school": "BETTIE WEAVER ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000762",
    },
    {
        "school": "JAMES RIVER HIGH",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084000766",
    },
    {
        "school": "MARGUERITE F CHRISTIAN ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084001086",
    },
    {
        "school": "CARVER COLLEGE AND CAREER ACADEMY",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510084001605",
    },
    {
        "school": "MONACAN HIGH",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084001833",
    },
    {
        "school": "SWIFT CREEK MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084001834",
    },
    {
        "school": "W W GORDON ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084001835",
    },
    {
        "school": "SPRING RUN ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084001903",
    },
    {
        "school": "O B GATES ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084001989",
    },
    {
        "school": "SWIFT CREEK ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084001990",
    },
    {
        "school": "MIDLOTHIAN HIGH",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002006",
    },
    {
        "school": "CLOVER HILL ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002055",
    },
    {
        "school": "PROVIDENCE ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002056",
    },
    {
        "school": "EVERGREEN ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002097",
    },
    {
        "school": "JACOBS ROAD ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002098",
    },
    {
        "school": "THELMA CRENSHAW ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002099",
    },
    {
        "school": "WOOLRIDGE ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002176",
    },
    {
        "school": "ECOFF ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002177",
    },
    {
        "school": "CENTRAL ST. HOSP. ED. PR.",
        "district": "CENTRAL ST HOSP",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510004501948",
    },
    {
        "school": "SOUTHSIDE VA TRAINING CTR",
        "district": "S.SIDE VA TRN CT",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510005202315",
    },
    {
        "school": "DINWIDDIE MIDDLE",
        "district": "DINWIDDIE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510117000409",
    },
    {
        "school": "DINWIDDIE HIGH",
        "district": "DINWIDDIE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510117000410",
    },
    {
        "school": "DINWIDDIE ELEM",
        "district": "DINWIDDIE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510117000411",
    },
    {
        "school": "MIDWAY ELEM",
        "district": "DINWIDDIE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510117000414",
    },
    {
        "school": "SUTHERLAND ELEM",
        "district": "DINWIDDIE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510117000416",
    },
    {
        "school": "SOUTHSIDE ELEM",
        "district": "DINWIDDIE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510117000417",
    },
    {
        "school": "SUNNYSIDE ELEM",
        "district": "DINWIDDIE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510117000418",
    },
    {
        "school": "BYRD ELEM",
        "district": "GOOCHLAND CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510165000683",
    },
    {
        "school": "GOOCHLAND ELEM",
        "district": "GOOCHLAND CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510165000685",
    },
    {
        "school": "GOOCHLAND HIGH",
        "district": "GOOCHLAND CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510165000686",
    },
    {
        "school": "GOOCHLAND MIDDLE",
        "district": "GOOCHLAND CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510165000687",
    },
    {
        "school": "RANDOLPH ELEM",
        "district": "GOOCHLAND CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510165000689",
    },
    {
        "school": "ATLEE HIGH",
        "district": "HANOVER CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000114",
    },
    {
        "school": "BATTLEFIELD PARK ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000764",
    },
    {
        "school": "BEAVERDAM ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000765",
    },
    {
        "school": "ELMONT ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000769",
    },
    {
        "school": "HENRY CLAY ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000770",
    },
    {
        "school": "JOHN M. GANDY ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000771",
    },
    {
        "school": "LEE DAVIS HIGH",
        "district": "HANOVER CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000772",
    },
    {
        "school": "LIBERTY MIDDLE",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000773",
    },
    {
        "school": "MECHANICSVILLE ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000774",
    },
    {
        "school": "PATRICK HENRY HIGH",
        "district": "HANOVER CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000776",
    },
    {
        "school": "PEARSON'S CORNER ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000777",
    },
    {
        "school": "RURAL POINT ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000779",
    },
    {
        "school": "STONEWALL JACKSON MIDDLE",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000780",
    },
    {
        "school": "WASHINGTON-HENRY ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183000781",
    },
    {
        "school": "COOL SPRING ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183001617",
    },
    {
        "school": "COLD HARBOR ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183001995",
    },
    {
        "school": "SOUTH ANNA ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183001996",
    },
    {
        "school": "CHICKAHOMINY MIDDLE",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183002191",
    },
    {
        "school": "OAK KNOLL MIDDLE",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183002277",
    },
    {
        "school": "POLE GREEN ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183002535",
    },
    {
        "school": "SHORT PUMP MIDDLE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000123",
    },
    {
        "school": "SHADY GROVE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000133",
    },
    {
        "school": "ADULT EDUCATION CENTER",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510189000537",
    },
    {
        "school": "BAKER ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000788",
    },
    {
        "school": "JOHNSON ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000789",
    },
    {
        "school": "BROOKLAND MIDDLE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000790",
    },
    {
        "school": "CHAMBERLAYNE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000792",
    },
    {
        "school": "CRESTVIEW ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000793",
    },
    {
        "school": "DONAHOE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000794",
    },
    {
        "school": "FREEMAN HIGH",
        "district": "HENRICO CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000795",
    },
    {
        "school": "DUMBARTON ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000796",
    },
    {
        "school": "HOLLADAY ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000797",
    },
    {
        "school": "FAIR OAKS ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000798",
    },
    {
        "school": "FAIRFIELD MIDDLE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000799",
    },
    {
        "school": "MOODY MIDDLE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000800",
    },
    {
        "school": "GLEN ALLEN ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000801",
    },
    {
        "school": "GLEN LEA ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000802",
    },
    {
        "school": "QUIOCCASIN MIDDLE SCHOOL",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000803",
    },
    {
        "school": "HENRICO HIGH",
        "district": "HENRICO CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000804",
    },
    {
        "school": "ACADEMY AT VIRGINIA RANDOLPH",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510189000805",
    },
    {
        "school": "HERMITAGE HIGH",
        "district": "HENRICO CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000806",
    },
    {
        "school": "ADVANCED CAREER EDUCATION CENTER AT HERMITAGE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510189000807",
    },
    {
        "school": "HIGHLAND SPRINGS ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000808",
    },
    {
        "school": "HIGHLAND SPRINGS HIGH",
        "district": "HENRICO CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000809",
    },
    {
        "school": "ADVANCED CAREER EDUCATION CENTER AT HIGHLAND SPRINGS",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510189000810",
    },
    {
        "school": "TUCKER HIGH",
        "district": "HENRICO CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000811",
    },
    {
        "school": "DAVIS ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000812",
    },
    {
        "school": "ADAMS ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000813",
    },
    {
        "school": "LABURNUM ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000814",
    },
    {
        "school": "LAKESIDE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000815",
    },
    {
        "school": "LONGDALE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000816",
    },
    {
        "school": "MAYBEURY ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000817",
    },
    {
        "school": "MONTROSE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000818",
    },
    {
        "school": "PEMBERTON ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000819",
    },
    {
        "school": "PINCHBECK ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000820",
    },
    {
        "school": "LONGAN ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000821",
    },
    {
        "school": "RATCLIFFE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000822",
    },
    {
        "school": "RIDGE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000823",
    },
    {
        "school": "CARVER ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000824",
    },
    {
        "school": "SANDSTON ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000825",
    },
    {
        "school": "SEVEN PINES ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000826",
    },
    {
        "school": "SHORT PUMP ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000827",
    },
    {
        "school": "SKIPWITH ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000828",
    },
    {
        "school": "THREE CHOPT ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000829",
    },
    {
        "school": "TREVVETT ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000830",
    },
    {
        "school": "TUCKAHOE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000831",
    },
    {
        "school": "TUCKAHOE MIDDLE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000832",
    },
    {
        "school": "VARINA ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000834",
    },
    {
        "school": "VARINA HIGH",
        "district": "HENRICO CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000835",
    },
    {
        "school": "ARTHUR ASHE JR. ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189000869",
    },
    {
        "school": "WARD ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189001128",
    },
    {
        "school": "SPRINGFIELD PARK ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189001384",
    },
    {
        "school": "L. DOUGLAS WILDER MIDDLE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189001622",
    },
    {
        "school": "NUCKOLS FARM ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189001624",
    },
    {
        "school": "ROLFE MIDDLE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189001850",
    },
    {
        "school": "GODWIN HIGH",
        "district": "HENRICO CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189001851",
    },
    {
        "school": "POCAHONTAS MIDDLE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189001911",
    },
    {
        "school": "ECHO LAKE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189001912",
    },
    {
        "school": "GAYTON ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002123",
    },
    {
        "school": "MEHFOUD ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002124",
    },
    {
        "school": "DEEP RUN HIGH",
        "district": "HENRICO CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002278",
    },
    {
        "school": "TWIN HICKORY ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002536",
    },
    {
        "school": "ARMSTRONG HIGH",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324002082",
    },
    {
        "school": "NEW KENT MIDDLE",
        "district": "NEW KENT CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510261001037",
    },
    {
        "school": "GEORGE W. WATKINS ELEM",
        "district": "NEW KENT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510261001038",
    },
    {
        "school": "NEW KENT ELEM",
        "district": "NEW KENT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510261001039",
    },
    {
        "school": "NEW KENT  HIGH",
        "district": "NEW KENT CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510261002156",
    },
    {
        "school": "POWHATAN HIGH",
        "district": "POWHATAN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510303001268",
    },
    {
        "school": "POWHATAN MIDDLE",
        "district": "POWHATAN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510303001269",
    },
    {
        "school": "POWHATAN VOC. CENTER",
        "district": "POWHATAN CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510303001270",
    },
    {
        "school": "POCAHONTAS ELEM",
        "district": "POWHATAN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510303001398",
    },
    {
        "school": "POWHATAN ELEM",
        "district": "POWHATAN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510303002105",
    },
    {
        "school": "ROWANTY VOCATIONAL TECH CTR",
        "district": "ROWANTY VOCATIONAL TECH CTR",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510001102024",
    },
    {
        "school": "DAVID A. HARRISON ELEM",
        "district": "PRINCE GEORGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510309001275",
    },
    {
        "school": "J.E.J. MOORE MIDDLE",
        "district": "PRINCE GEORGE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510309001276",
    },
    {
        "school": "L.L. BEAZLEY ELEM",
        "district": "PRINCE GEORGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510309001277",
    },
    {
        "school": "NORTH ELEM",
        "district": "PRINCE GEORGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510309001279",
    },
    {
        "school": "PRINCE GEORGE HIGH",
        "district": "PRINCE GEORGE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510309001280",
    },
    {
        "school": "SOUTH ELEM",
        "district": "PRINCE GEORGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510309001282",
    },
    {
        "school": "WILLIAM A. WALTON ELEM",
        "district": "PRINCE GEORGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510309001283",
    },
    {
        "school": "COLONIAL HEIGHTS HIGH",
        "district": "COLONIAL HEIGHTS CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510096000361",
    },
    {
        "school": "COLONIAL HEIGHTS MIDDLE",
        "district": "COLONIAL HEIGHTS CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510096000362",
    },
    {
        "school": "LAKEVIEW ELEM",
        "district": "COLONIAL HEIGHTS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510096000364",
    },
    {
        "school": "NORTH ELEM",
        "district": "COLONIAL HEIGHTS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510096000365",
    },
    {
        "school": "TUSSING ELEM",
        "district": "COLONIAL HEIGHTS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510096000366",
    },
    {
        "school": "HARRY E. JAMES ELEM",
        "district": "HOPEWELL CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510198000357",
    },
    {
        "school": "CARTER G. WOODSON MIDDLE",
        "district": "HOPEWELL CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510198000865",
    },
    {
        "school": "DUPONT ELEM",
        "district": "HOPEWELL CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510198000866",
    },
    {
        "school": "HOPEWELL HIGH",
        "district": "HOPEWELL CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510198000867",
    },
    {
        "school": "PATRICK COPELAND ELEM",
        "district": "HOPEWELL CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510198000870",
    },
    {
        "school": "WOODLAWN PRE-SCHOOL LRNG CTR.",
        "district": "HOPEWELL CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510198002279",
    },
    {
        "school": "APPOMATTOX REGIONAL GOV. SCH.",
        "district": "APPOMATTOX REGIONAL GOV SCH",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510003201932",
    },
    {
        "school": "PLEASANTS LANE ELEM",
        "district": "PETERSBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510291001196",
    },
    {
        "school": "PETERSBURG HIGH",
        "district": "PETERSBURG CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510291001198",
    },
    {
        "school": "LAKEMONT ELEMENTARY",
        "district": "PETERSBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510291001200",
    },
    {
        "school": "COOL SPRING ELEM",
        "district": "PETERSBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510291001202",
    },
    {
        "school": "WALNUT HILL ELEM",
        "district": "PETERSBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510291001203",
    },
    {
        "school": "WESTVIEW EARLY CHILDHOOD ED. CTR.",
        "district": "PETERSBURG CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510291001204",
    },
    {
        "school": "RICHMOND HOSPITAL EP.",
        "district": "MEDICAL COLLEGE OF VA",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510004002291",
    },
    {
        "school": "VIRGINIA TREATMENT CTR.",
        "district": "MCV/VA TREATMENT CTR",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510005502290",
    },
    {
        "school": "MAGGIE L. WALKER GOV. SCH.",
        "district": "MAGGIE L. WALKER GOV SCH",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510006102561",
    },
    {
        "school": "BARACK OBAMA ELEMENTARY",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324000381",
    },
    {
        "school": "ALBERT HILL MIDDLE",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001351",
    },
    {
        "school": "AMELIA STREET SP. ED.",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510324001352",
    },
    {
        "school": "BINFORD MIDDLE",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001356",
    },
    {
        "school": "BLACKWELL ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001357",
    },
    {
        "school": "CHIMBORAZO ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001359",
    },
    {
        "school": "E.S.H. GREENE ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001361",
    },
    {
        "school": "ELIZABETH D. REDD ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001363",
    },
    {
        "school": "FAIRFIELD COURT ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001365",
    },
    {
        "school": "SWANSBORO ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001367",
    },
    {
        "school": "G.H. REID ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001369",
    },
    {
        "school": "GEORGE MASON ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001370",
    },
    {
        "school": "GINTER PARK ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001372",
    },
    {
        "school": "OPEN HIGH",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001373",
    },
    {
        "school": "HENDERSON MIDDLE",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001374",
    },
    {
        "school": "J.L. FRANCIS ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001378",
    },
    {
        "school": "JOHN B. CARY ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001379",
    },
    {
        "school": "MARY MUNFORD ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001383",
    },
    {
        "school": "MARTIN LUTHER KING JR. MIDDLE",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001385",
    },
    {
        "school": "OAK GROVE/BELLEMEADE ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001387",
    },
    {
        "school": "OVERBY-SHEPPARD ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001389",
    },
    {
        "school": "RICHMOND TECHNICAL CENTER",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510324001396",
    },
    {
        "school": "SOUTHAMPTON ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001400",
    },
    {
        "school": "WESTOVER HILLS ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001404",
    },
    {
        "school": "WILLIAM FOX ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001406",
    },
    {
        "school": "WOODVILLE ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001407",
    },
    {
        "school": "BELLEVUE ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001860",
    },
    {
        "school": "BROAD ROCK ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001861",
    },
    {
        "school": "GEORGE W. CARVER ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001862",
    },
    {
        "school": "J.B. FISHER ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001863",
    },
    {
        "school": "MAYMONT PRE-K CENTER",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001865",
    },
    {
        "school": "LUCILLE M. BROWN MIDDLE",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001894",
    },
    {
        "school": "LINWOOD HOLTON ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001927",
    },
    {
        "school": "MILES JONES ELEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324001928",
    },
    {
        "school": "RICHMOND ACCELERATION PRGM.",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510324001929",
    },
    {
        "school": "THOMAS JEFFERSON HIGH",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324002070",
    },
    {
        "school": "RICHMOND COMMUNITY HIGH",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324002075",
    },
    {
        "school": "THOMAS C. BOUSHALL MIDDLE",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324002078",
    },
    {
        "school": "JOHN MARSHALL HIGH",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324002080",
    },
    {
        "school": "GEORGE WYTHE HIGH",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324002081",
    },
    {
        "school": "HUGUENOT HIGH",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324002083",
    },
    {
        "school": "FRANKLIN MILITARY ACADEMY",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324002214",
    },
    {
        "school": "PRE-SCHOOL DEV. CENTER",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510324002306",
    },
    {
        "school": "RICHMOND ALTERNATIVE",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510324002307",
    },
    {
        "school": "CENTRAL HIGH",
        "district": "KING AND QUEEN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510207000878",
    },
    {
        "school": "KING & QUEEN ELEM",
        "district": "KING AND QUEEN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510207000879",
    },
    {
        "school": "LAWSON-MARRIOTT ELEM",
        "district": "KING AND QUEEN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510207000880",
    },
    {
        "school": "REG ALTERNATIVE PLUS SELF PROJECT/ROANOKE CITY",
        "district": "REG ALTERNATIVE PLUS SELF PROJECT/ROANOKE CITY",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510007502350",
    },
    {
        "school": "NOEL C. TAYLOR ACADEMY AT OAKLAND",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510330002628",
    },
    {
        "school": "MCCLEARY ELEM",
        "district": "CRAIG CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510102000372",
    },
    {
        "school": "CRAIG COUNTY HIGH",
        "district": "CRAIG CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510102002111",
    },
    {
        "school": "BOONES MILL ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000632",
    },
    {
        "school": "BURNT CHIMNEY ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000633",
    },
    {
        "school": "CALLAWAY ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000634",
    },
    {
        "school": "DUDLEY ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000635",
    },
    {
        "school": "FERRUM ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000636",
    },
    {
        "school": "FRANKLIN COUNTY HIGH",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000637",
    },
    {
        "school": "GLADE HILL ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000639",
    },
    {
        "school": "HENRY ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000640",
    },
    {
        "school": "LEE M. WAID ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000641",
    },
    {
        "school": "ROCKY MOUNT ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000642",
    },
    {
        "school": "SNOW CREEK ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000643",
    },
    {
        "school": "SONTAG ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144000644",
    },
    {
        "school": "GEREAU CTR FOR APL TECH&CAREER EXPL",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144001614",
    },
    {
        "school": "BEN. FRANKLIN MIDDLE-EAST",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144002148",
    },
    {
        "school": "BEN. FRANKLIN MIDDLE-WEST",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144002187",
    },
    {
        "school": "CENTRAL ACADEMY MIDDLE",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510042000164",
    },
    {
        "school": "BOTETOURT TECH EDUC CTR",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510042000165",
    },
    {
        "school": "BRECKINRIDGE ELEM",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510042000166",
    },
    {
        "school": "BUCHANAN ELEM",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510042000167",
    },
    {
        "school": "CLOVERDALE ELEM",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510042000168",
    },
    {
        "school": "COLONIAL ELEM",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510042000169",
    },
    {
        "school": "EAGLE ROCK ELEM",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510042000170",
    },
    {
        "school": "JAMES RIVER HIGH",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510042000171",
    },
    {
        "school": "LORD BOTETOURT HIGH",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510042000172",
    },
    {
        "school": "TROUTVILLE ELEM",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510042000173",
    },
    {
        "school": "READ MOUNTAIN MIDDLE",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510042001354",
    },
    {
        "school": "GREENFIELD ELEM",
        "district": "BOTETOURT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510042002527",
    },
    {
        "school": "GLENVAR MIDDLE",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001408",
    },
    {
        "school": "BACK CREEK ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001442",
    },
    {
        "school": "BURLINGTON ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001444",
    },
    {
        "school": "CAVE SPRING ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001446",
    },
    {
        "school": "CAVE SPRING HIGH",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001447",
    },
    {
        "school": "CAVE SPRING MIDDLE",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001448",
    },
    {
        "school": "CLEARBROOK ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001449",
    },
    {
        "school": "HERMAN L. HORN ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001452",
    },
    {
        "school": "GLEN COVE ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001455",
    },
    {
        "school": "GLENVAR ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001456",
    },
    {
        "school": "GLENVAR HIGH",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001457",
    },
    {
        "school": "GREEN VALLEY ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001458",
    },
    {
        "school": "W.E. CUNDIFF ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001459",
    },
    {
        "school": "MASON'S COVE ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001461",
    },
    {
        "school": "MOUNTAIN VIEW ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001463",
    },
    {
        "school": "MT. PLEASANT ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001464",
    },
    {
        "school": "NORTHSIDE HIGH",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001465",
    },
    {
        "school": "NORTHSIDE MIDDLE",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001466",
    },
    {
        "school": "OAK GROVE ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001467",
    },
    {
        "school": "PENN FOREST ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001468",
    },
    {
        "school": "WILLIAM BYRD HIGH",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001476",
    },
    {
        "school": "WILLIAM BYRD MIDDLE",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001477",
    },
    {
        "school": "BONSACK ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001919",
    },
    {
        "school": "FORT LEWIS ELEM",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001998",
    },
    {
        "school": "HIDDEN VALLEY HIGH",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333002308",
    },
    {
        "school": "ROANOKE VALLEY GOV. SCH.",
        "district": "ROANOKE VALLEY GOV SCH",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510217602232",
    },
    {
        "school": "CRYSTAL SPRING ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330000385",
    },
    {
        "school": "VIRGINIA HEIGHTS ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330000667",
    },
    {
        "school": "MORNINGSIDE ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001045",
    },
    {
        "school": "WASENA ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001349",
    },
    {
        "school": "LUCY ADDISON AEROSPACE MAGNET MIDDLE",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001412",
    },
    {
        "school": "BRECKINRIDGE MIDDLE",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001413",
    },
    {
        "school": "FAIRVIEW ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001415",
    },
    {
        "school": "FALLON PARK ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001416",
    },
    {
        "school": "FISHBURN PARK ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001417",
    },
    {
        "school": "GARDEN CITY ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001419",
    },
    {
        "school": "GRANDIN COURT ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001420",
    },
    {
        "school": "ROUND HILL ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001422",
    },
    {
        "school": "HURT PARK ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001423",
    },
    {
        "school": "JAMES MADISON MIDDLE",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001424",
    },
    {
        "school": "LINCOLN TERRACE ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001425",
    },
    {
        "school": "MONTEREY ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001426",
    },
    {
        "school": "ROANOKE ACADEMY FOR MATH & SCIENCE ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001428",
    },
    {
        "school": "PATRICK HENRY HIGH",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001430",
    },
    {
        "school": "JOHN P. FISHWICK MIDDLE",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001434",
    },
    {
        "school": "WESTSIDE ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001437",
    },
    {
        "school": "WILLIAM FLEMING HIGH",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001438",
    },
    {
        "school": "WOODROW WILSON MIDDLE",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330001440",
    },
    {
        "school": "HIGHLAND PARK ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330002161",
    },
    {
        "school": "PRESTON PARK ELEM",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510330002217",
    },
    {
        "school": "HIDDEN VALLEY MIDDLE",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510333001460",
    },
    {
        "school": "BURTON CTR. FOR ARTS AND TECH.",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510333001469",
    },
    {
        "school": "SALEM HIGH",
        "district": "SALEM CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510346002043",
    },
    {
        "school": "G.W. CARVER ELEM",
        "district": "SALEM CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510346002044",
    },
    {
        "school": "ANDREW LEWIS MIDDLE",
        "district": "SALEM CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510346002045",
    },
    {
        "school": "WEST SALEM ELEM",
        "district": "SALEM CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510346002046",
    },
    {
        "school": "EAST SALEM ELEM",
        "district": "SALEM CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510346002047",
    },
    {
        "school": "SOUTH SALEM ELEM",
        "district": "SALEM CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510346002048",
    },
    {
        "school": "WILSON MIDDLE",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030002435",
    },
    {
        "school": "VALLEY CAREER & TECHNICAL CENTER",
        "district": "VALLEY VOCATIONAL TECH",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510000802020",
    },
    {
        "school": "SHENANDOAH VALLEY GOV. SCH.",
        "district": "SHENANDOAH VALLEY GOVERNORS SCHOOL",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510002801504",
    },
    {
        "school": "WOODROW WILSON REHAB CTR",
        "district": "WILSON WORKFORCE AND REHAB",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510005402326",
    },
    {
        "school": "BUFFALO GAP HIGH",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000117",
    },
    {
        "school": "CASSELL ELEM",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000118",
    },
    {
        "school": "CHURCHVILLE ELEM",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000119",
    },
    {
        "school": "CRAIGSVILLE ELEM",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000120",
    },
    {
        "school": "FT DEFIANCE HIGH",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000124",
    },
    {
        "school": "NORTH RIVER ELEM",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000127",
    },
    {
        "school": "RIVERHEADS ELEM",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000128",
    },
    {
        "school": "RIVERHEADS HIGH",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000129",
    },
    {
        "school": "STUARTS DRAFT MIDDLE",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000130",
    },
    {
        "school": "STUARTS DRAFT ELEM",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000131",
    },
    {
        "school": "STUARTS DRAFT HIGH",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000132",
    },
    {
        "school": "WILSON ELEM",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000137",
    },
    {
        "school": "WILSON MEMORIAL HIGH",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030000138",
    },
    {
        "school": "EDWARD G CLYMORE ELEM",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030001080",
    },
    {
        "school": "S GORDON STEWART MIDDLE",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030001830",
    },
    {
        "school": "GUY K STUMP ELEM",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030001901",
    },
    {
        "school": "BEVERLEY MANOR MIDDLE",
        "district": "AUGUSTA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510030002140",
    },
    {
        "school": "WESTERN ST. HOSP. ED. PR.",
        "district": "WESTERN ST HOSP",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510004802325",
    },
    {
        "school": "CCCA",
        "district": "COMMONWEALTH CTR FOR CHILDREN & ADOLESCENTS",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510007101949",
    },
    {
        "school": "BESSIE WELLER ELEM",
        "district": "STAUNTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510369001604",
    },
    {
        "school": "STAUNTON HIGH",
        "district": "STAUNTON CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510369001606",
    },
    {
        "school": "SHELBURNE MIDDLE",
        "district": "STAUNTON CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510369001607",
    },
    {
        "school": "THOMAS C. MCSWAIN ELEM",
        "district": "STAUNTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510369001608",
    },
    {
        "school": "A. R. WARE ELEM",
        "district": "STAUNTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510369001610",
    },
    {
        "school": "WILLIAM PERRY ELEM",
        "district": "WAYNESBORO CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510393001064",
    },
    {
        "school": "BERKELEY GLENN ELEM",
        "district": "WAYNESBORO CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510393001754",
    },
    {
        "school": "KATE COLLINS MIDDLE",
        "district": "WAYNESBORO CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510393001755",
    },
    {
        "school": "WAYNESBORO HIGH",
        "district": "WAYNESBORO CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510393001759",
    },
    {
        "school": "WENONAH ELEM",
        "district": "WAYNESBORO CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510393001760",
    },
    {
        "school": "WESTWOOD HILLS ELEM",
        "district": "WAYNESBORO CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510393001761",
    },
    {
        "school": "WESTSIDE ELEM",
        "district": "ISLE OF WIGHT CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510201002444",
    },
    {
        "school": "GRASSFIELD ELEM",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081002432",
    },
    {
        "school": "NEWPORT ACADEMY",
        "district": "NEW HORIZONS REGIONAL EDUC CTR-SPEC ED",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510001702639",
    },
    {
        "school": "ENTERPRISE ACADEMY/NEWPORT NEWS CITY",
        "district": "ENTERPRISE ACADEMY/NEWPORT NEWS CITY",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510007302348",
    },
    {
        "school": "ACHIEVABLE DREAM ACADEMY",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264002343",
    },
    {
        "school": "ACHIEVABLE DREAM MIDDLE/HIGH",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264002344",
    },
    {
        "school": "GENERAL STANFORD ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264002422",
    },
    {
        "school": "LEE HALL EARLY CHILDHOOD CENTER",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264002470",
    },
    {
        "school": "WATKINS EARLY CHILDHOOD CENTER",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264002471",
    },
    {
        "school": "TIDEWATER REGIONAL ALTERNATIVE ED PROJECT",
        "district": "TIDEWATER REGIONAL ALTERNATIVE ED PROJECT",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510007402349",
    },
    {
        "school": "BRIGHTON ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300002472",
    },
    {
        "school": "MOUNT HERMON PRESCHOOL CENTER",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300002474",
    },
    {
        "school": "KING'S FORK HIGH",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371002426",
    },
    {
        "school": "ADVANCED TECHNOLOGY CTR.",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510384002430",
    },
    {
        "school": "THREE OAKS ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002475",
    },
    {
        "school": "LUTHER P. JACKSON MIDDLE",
        "district": "SURRY CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510375001201",
    },
    {
        "school": "SURRY COUNTY HIGH",
        "district": "SURRY CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510375001635",
    },
    {
        "school": "SURRY ELEM",
        "district": "SURRY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510375002002",
    },
    {
        "school": "ABINGDON ELEM",
        "district": "GLOUCESTER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510162000677",
    },
    {
        "school": "ACHILLES ELEM",
        "district": "GLOUCESTER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510162000678",
    },
    {
        "school": "BOTETOURT ELEM",
        "district": "GLOUCESTER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510162000679",
    },
    {
        "school": "GLOUCESTER HIGH",
        "district": "GLOUCESTER CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510162000680",
    },
    {
        "school": "BETHEL ELEM",
        "district": "GLOUCESTER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510162001616",
    },
    {
        "school": "PETSWORTH ELEM",
        "district": "GLOUCESTER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510162002065",
    },
    {
        "school": "PEASLEY MIDDLE",
        "district": "GLOUCESTER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510162002188",
    },
    {
        "school": "CARROLLTON ELEM",
        "district": "ISLE OF WIGHT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510201000547",
    },
    {
        "school": "CARRSVILLE ELEM",
        "district": "ISLE OF WIGHT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510201000872",
    },
    {
        "school": "HARDY ELEM",
        "district": "ISLE OF WIGHT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510201000873",
    },
    {
        "school": "SMITHFIELD MIDDLE",
        "district": "ISLE OF WIGHT CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510201000874",
    },
    {
        "school": "SMITHFIELD HIGH",
        "district": "ISLE OF WIGHT CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510201000875",
    },
    {
        "school": "WINDSOR ELEM",
        "district": "ISLE OF WIGHT CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510201000876",
    },
    {
        "school": "WINDSOR HIGH",
        "district": "ISLE OF WIGHT CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510201000877",
    },
    {
        "school": "GEORGIE D. TYLER MIDDLE",
        "district": "ISLE OF WIGHT CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510201000906",
    },
    {
        "school": "EASTERN ST. HOSP. ED. PRG",
        "district": "EASTERN ST HOSP",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510004602262",
    },
    {
        "school": "TOANO MIDDLE",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402000446",
    },
    {
        "school": "JAMES RIVER ELEM",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402000705",
    },
    {
        "school": "JAMESTOWN HIGH",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402001665",
    },
    {
        "school": "LAFAYETTE HIGH",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402001773",
    },
    {
        "school": "NORGE ELEM",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402001775",
    },
    {
        "school": "LAUREL LANE ELEM",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402001776",
    },
    {
        "school": "CLARA BYRD BAKER ELEM",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402002170",
    },
    {
        "school": "D.J. MONTAGUE ELEM",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402002171",
    },
    {
        "school": "STONEHOUSE ELEM",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402002556",
    },
    {
        "school": "MATHEWS HIGH",
        "district": "MATHEWS CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510243000993",
    },
    {
        "school": "THOMAS HUNTER MIDDLE",
        "district": "MATHEWS CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510243000994",
    },
    {
        "school": "LEE-JACKSON ELEM",
        "district": "MATHEWS CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510243001388",
    },
    {
        "school": "GRAFTON HIGH",
        "district": "YORK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001443",
    },
    {
        "school": "GRAFTON MIDDLE",
        "district": "YORK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001445",
    },
    {
        "school": "BETHEL MANOR ELEM",
        "district": "YORK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001811",
    },
    {
        "school": "BRUTON HIGH",
        "district": "YORK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001812",
    },
    {
        "school": "DARE ELEM",
        "district": "YORK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001813",
    },
    {
        "school": "GRAFTON BETHEL ELEM",
        "district": "YORK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001814",
    },
    {
        "school": "MAGRUDER ELEM",
        "district": "YORK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001815",
    },
    {
        "school": "MT. VERNON ELEM",
        "district": "YORK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001816",
    },
    {
        "school": "QUEENS LAKE MIDDLE",
        "district": "YORK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001817",
    },
    {
        "school": "SEAFORD ELEM",
        "district": "YORK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001818",
    },
    {
        "school": "TABB ELEM",
        "district": "YORK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001819",
    },
    {
        "school": "TABB HIGH",
        "district": "YORK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001820",
    },
    {
        "school": "TABB MIDDLE",
        "district": "YORK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001821",
    },
    {
        "school": "WALLER MILL ELEM",
        "district": "YORK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001822",
    },
    {
        "school": "YORK HIGH",
        "district": "YORK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001823",
    },
    {
        "school": "YORKTOWN ELEM",
        "district": "YORK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001824",
    },
    {
        "school": "YORKTOWN MIDDLE",
        "district": "YORK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415001825",
    },
    {
        "school": "COVENTRY ELEM",
        "district": "YORK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415002172",
    },
    {
        "school": "YORK RIVER ACADEMY",
        "district": "YORK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510415002330",
    },
    {
        "school": "SOUTHEASTERN VA TR CTR EP",
        "district": "S.EAST VA TRN CT",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510005602314",
    },
    {
        "school": "B M WILLIAMS PRIMARY",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000280",
    },
    {
        "school": "BUTTS ROAD PRIMARY",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000281",
    },
    {
        "school": "CAMELOT ELEM",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000282",
    },
    {
        "school": "CHESAPEAKE CAREER CENTER",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510081000285",
    },
    {
        "school": "CRESTWOOD INTERMEDIATE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000286",
    },
    {
        "school": "CRESTWOOD MIDDLE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000287",
    },
    {
        "school": "DEEP CREEK ELEM",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000288",
    },
    {
        "school": "DEEP CREEK MIDDLE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000289",
    },
    {
        "school": "EDWIN W CHITTUM ELEM",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000291",
    },
    {
        "school": "G A TREAKLE ELEM",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000292",
    },
    {
        "school": "GEORGE W CARVER INT",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000293",
    },
    {
        "school": "GEORGETOWN PRIMARY",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000294",
    },
    {
        "school": "GREAT BRIDGE PRIMARY",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000295",
    },
    {
        "school": "GREAT BRIDGE MIDDLE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000296",
    },
    {
        "school": "HICKORY MIDDLE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000297",
    },
    {
        "school": "HICKORY ELEM",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000298",
    },
    {
        "school": "INDIAN RIVER HIGH",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000299",
    },
    {
        "school": "INDIAN RIVER MIDDLE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000300",
    },
    {
        "school": "NORFOLK HIGHLANDS PRIMARY",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000302",
    },
    {
        "school": "OSCAR F SMITH HIGH",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000303",
    },
    {
        "school": "THURGOOD MARSHALL ELEM",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000304",
    },
    {
        "school": "PORTLOCK PRIMARY",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000305",
    },
    {
        "school": "RENA B WRIGHT PRIMARY",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000306",
    },
    {
        "school": "SOUTHEASTERN ELEM",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000307",
    },
    {
        "school": "SOUTHWESTERN ELEM",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000308",
    },
    {
        "school": "SPARROW ROAD INTERMEDIATE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000309",
    },
    {
        "school": "OSCAR SMITH MIDDLE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000310",
    },
    {
        "school": "WESTERN BRANCH INT",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000311",
    },
    {
        "school": "WESTERN BRANCH HIGH",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000312",
    },
    {
        "school": "WESTERN BRANCH MIDDLE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000313",
    },
    {
        "school": "GREAT BRIDGE INT",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000456",
    },
    {
        "school": "BUTTS ROAD INT",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000457",
    },
    {
        "school": "GREENBRIER INT.",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081000459",
    },
    {
        "school": "HICKORY HIGH",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081001482",
    },
    {
        "school": "CEDAR ROAD ELEM",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081001483",
    },
    {
        "school": "HUGO A OWENS MIDDLE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081001672",
    },
    {
        "school": "DEEP CREEK HIGH",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081001832",
    },
    {
        "school": "TRUITT INTERMEDIATE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081001899",
    },
    {
        "school": "WESTERN BRANCH PRIMARY",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081001910",
    },
    {
        "school": "JOLLIFF MIDDLE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081001954",
    },
    {
        "school": "GREAT BRIDGE HIGH",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081002031",
    },
    {
        "school": "GREENBRIER PRIMARY",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081002054",
    },
    {
        "school": "CHESAPEAKE CENTER FOR STUDENT SUCCESS",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510081002222",
    },
    {
        "school": "DEEP CREEK CENTRAL ELEM",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081002223",
    },
    {
        "school": "GREENBRIER MIDDLE",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081002557",
    },
    {
        "school": "A.W.E. BASSETTE ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000725",
    },
    {
        "school": "ABERDEEN ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000726",
    },
    {
        "school": "ALFRED S. FORREST ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000727",
    },
    {
        "school": "ARMSTRONG ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000728",
    },
    {
        "school": "BARRON ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000729",
    },
    {
        "school": "BENJAMIN SYMS MIDDLE",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000730",
    },
    {
        "school": "BETHEL HIGH",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000731",
    },
    {
        "school": "BOOKER ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000732",
    },
    {
        "school": "C. ALTON LINDSAY MIDDLE",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000734",
    },
    {
        "school": "CAPTAIN JOHN SMITH ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000735",
    },
    {
        "school": "CHRISTOPHER C. KRAFT ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000737",
    },
    {
        "school": "FRANCIS ASBURY ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000739",
    },
    {
        "school": "HAMPTON HIGH",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000742",
    },
    {
        "school": "JANE H. BRYAN ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000743",
    },
    {
        "school": "CESAR TARRANT MIDDLE",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000744",
    },
    {
        "school": "JOHN B. CARY ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000745",
    },
    {
        "school": "JOHN TYLER ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000746",
    },
    {
        "school": "KECOUGHTAN HIGH",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000747",
    },
    {
        "school": "LUTHER W. MACHEN ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000748",
    },
    {
        "school": "PAUL BURBANK ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000750",
    },
    {
        "school": "PHILLIPS ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000754",
    },
    {
        "school": "PHOEBUS HIGH",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000755",
    },
    {
        "school": "MOTON EARLY CHILDHOOD CENTER",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000757",
    },
    {
        "school": "SAMUEL P. LANGLEY ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000758",
    },
    {
        "school": "THOMAS EATON MIDDLE",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000760",
    },
    {
        "school": "TUCKER-CAPPS ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000761",
    },
    {
        "school": "WILLIAM MASON COOPER ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180000763",
    },
    {
        "school": "FRANCIS W. JONES MAGNET MIDDLE",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180001890",
    },
    {
        "school": "NEW HORIZONS GOV. SCH.",
        "district": "NEW HORIZONS GOV SCHOOL",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510217702233",
    },
    {
        "school": "POINT OPTION ALTERNATIVE",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510264001238",
    },
    {
        "school": "WOODSIDE CAMPUS",
        "district": "NEW HORIZONS CAREER & TECH CTR",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510000902022",
    },
    {
        "school": "BUTLER FARM CAMPUS",
        "district": "NEW HORIZONS CAREER & TECH CTR",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510000902051",
    },
    {
        "school": "CENTER FOR AUTISM",
        "district": "NEW HORIZONS REGIONAL EDUC CTR-SPEC ED",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510001702089",
    },
    {
        "school": "KILN CREEK ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264000358",
    },
    {
        "school": "B.C. CHARLES ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001040",
    },
    {
        "school": "B.T. WASHINGTON MIDDLE",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001041",
    },
    {
        "school": "CARVER ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001043",
    },
    {
        "school": "DAVID A. DUTROW ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001044",
    },
    {
        "school": "DENBIGH HIGH",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001047",
    },
    {
        "school": "GEORGE J. MCINTOSH ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001049",
    },
    {
        "school": "HOMER L. HINES MIDDLE",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001050",
    },
    {
        "school": "HIDENWOOD ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001051",
    },
    {
        "school": "HILTON ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001052",
    },
    {
        "school": "HORACE H. EPES ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001054",
    },
    {
        "school": "HUNTINGTON MIDDLE",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001055",
    },
    {
        "school": "J.M. DOZIER MIDDLE",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001056",
    },
    {
        "school": "JOSEPH H. SAUNDERS ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001059",
    },
    {
        "school": "L.F. PALMER ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001060",
    },
    {
        "school": "LEE HALL ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001061",
    },
    {
        "school": "DISCOVERY STEM ACADEMY",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001062",
    },
    {
        "school": "MENCHVILLE HIGH",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001063",
    },
    {
        "school": "NEWSOME PARK ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001065",
    },
    {
        "school": "R.O. NELSON ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001068",
    },
    {
        "school": "RICHARD T. YATES ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001070",
    },
    {
        "school": "RICHNECK ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001071",
    },
    {
        "school": "RIVERSIDE ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001072",
    },
    {
        "school": "SEDGEFIELD ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001074",
    },
    {
        "school": "T. RYLAND SANFORD ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001075",
    },
    {
        "school": "WARWICK HIGH",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001076",
    },
    {
        "school": "WILLIS A. JENKINS ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001077",
    },
    {
        "school": "CRITTENDEN MIDDLE",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001237",
    },
    {
        "school": "HERITAGE HIGH",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001451",
    },
    {
        "school": "WOODSIDE HIGH",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001453",
    },
    {
        "school": "DEER PARK ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264001637",
    },
    {
        "school": "OLIVER C. GREENWOOD ELEM",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264002068",
    },
    {
        "school": "ETHEL M. GILDERSLEEVE MIDDLE",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264002208",
    },
    {
        "school": "DENBIGH EARLY CHILDHOOD CENTER",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264002296",
    },
    {
        "school": "MARY PASSAGE MIDDLE",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264002298",
    },
    {
        "school": "KINGS DAUGHTERS HOSP. EP.",
        "district": "KINGS DAUGHTERS",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510003802280",
    },
    {
        "school": "GOV. SCH. FOR THE ARTS",
        "district": "GOVERNOR'S SCHOOL FOR THE ARTS",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510217502231",
    },
    {
        "school": "AZALEA MIDDLE",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001078",
    },
    {
        "school": "BOOKER T. WASHINGTON HIGH",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001079",
    },
    {
        "school": "BAY VIEW ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001081",
    },
    {
        "school": "BLAIR MIDDLE",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001082",
    },
    {
        "school": "RICHARD BOWLING ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001083",
    },
    {
        "school": "CAMP ALLEN ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001084",
    },
    {
        "school": "SOUTHSIDE STEM ACADEMY AT CAMPOSTELLA",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001085",
    },
    {
        "school": "WILLARD MODEL ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001087",
    },
    {
        "school": "CHESTERFIELD ACADEMY ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001088",
    },
    {
        "school": "COLEMAN PLACE ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001089",
    },
    {
        "school": "CROSSROADS ELEMENTARY",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001090",
    },
    {
        "school": "BERKLEY/CAMPOSTELLA EARLY CHILDHOOD CENTER",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001092",
    },
    {
        "school": "EASTON PRESCHOOL",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001094",
    },
    {
        "school": "GHENT SCHOOL",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001096",
    },
    {
        "school": "GRANBY ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001097",
    },
    {
        "school": "GRANBY HIGH",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001098",
    },
    {
        "school": "INGLESIDE ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001100",
    },
    {
        "school": "JACOX ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001101",
    },
    {
        "school": "LAKE TAYLOR HIGH",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001104",
    },
    {
        "school": "LAKE TAYLOR",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001105",
    },
    {
        "school": "LARCHMONT ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001108",
    },
    {
        "school": "LARRYMORE ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001109",
    },
    {
        "school": "LINDENWOOD ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001112",
    },
    {
        "school": "LITTLE CREEK ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001113",
    },
    {
        "school": "MARY CALCOTT ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001116",
    },
    {
        "school": "MAURY HIGH",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001117",
    },
    {
        "school": "NORFOLK TECHNICAL CTR",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510267001119",
    },
    {
        "school": "NORTHSIDE MIDDLE",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001120",
    },
    {
        "school": "NORVIEW ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001121",
    },
    {
        "school": "NORVIEW HIGH",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001122",
    },
    {
        "school": "NORVIEW MIDDLE",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001123",
    },
    {
        "school": "OCEAN VIEW ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001125",
    },
    {
        "school": "OCEANAIR ELEMENTARY",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001126",
    },
    {
        "school": "RUFFNER MIDDLE",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001134",
    },
    {
        "school": "SEWELLS POINT ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001135",
    },
    {
        "school": "SHERWOOD FOREST ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001136",
    },
    {
        "school": "ST. HELENA ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001137",
    },
    {
        "school": "SUBURBAN PARK ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001140",
    },
    {
        "school": "TARRALLTON ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001141",
    },
    {
        "school": "TIDEWATER PARK ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001142",
    },
    {
        "school": "WALTER HERRON TAYLOR ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001144",
    },
    {
        "school": "WILLOUGHBY EARLY CHILDHOOD CENTER",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001146",
    },
    {
        "school": "P.B. YOUNG SR. ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267001147",
    },
    {
        "school": "MADISON ALTERNATIVE",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510267002128",
    },
    {
        "school": "TANNERS CREEK ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267002210",
    },
    {
        "school": "JAMES MONROE ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267002211",
    },
    {
        "school": "POQUOSON ELEM",
        "district": "POQUOSON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510298001230",
    },
    {
        "school": "POQUOSON HIGH",
        "district": "POQUOSON CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510298001231",
    },
    {
        "school": "POQUOSON MIDDLE",
        "district": "POQUOSON CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510298001232",
    },
    {
        "school": "POQUOSON PRIMARY",
        "district": "POQUOSON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510298002157",
    },
    {
        "school": "CHURCHLAND HIGH",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300000375",
    },
    {
        "school": "NEW DIRECTIONS CENTER",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510300001018",
    },
    {
        "school": "CRADOCK MIDDLE",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001234",
    },
    {
        "school": "CHURCHLAND ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001239",
    },
    {
        "school": "CHURCHLAND MIDDLE",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001241",
    },
    {
        "school": "CHURCHLAND PRIMARY & INTERMEDIATE",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001242",
    },
    {
        "school": "DOUGLASS PARK ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001245",
    },
    {
        "school": "HODGES MANOR ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001249",
    },
    {
        "school": "I.C. NORCOM HIGH",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001250",
    },
    {
        "school": "JAMES HURST ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001252",
    },
    {
        "school": "JOHN TYLER ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001253",
    },
    {
        "school": "LAKEVIEW ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001254",
    },
    {
        "school": "WOODROW WILSON HIGH",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001255",
    },
    {
        "school": "SIMONSDALE ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001257",
    },
    {
        "school": "PARK VIEW ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001258",
    },
    {
        "school": "WESTHAVEN ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001264",
    },
    {
        "school": "WM. E. WATERS MIDDLE",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300001265",
    },
    {
        "school": "CHURCHLAND ACADEMY ELEM",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300002069",
    },
    {
        "school": "CRADOCK TECHNICAL & CAREER CENTER",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510300002301",
    },
    {
        "school": "NORTHERN SHORES ELEM",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001475",
    },
    {
        "school": "BOOKER T. WASHINGTON ELEM",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001613",
    },
    {
        "school": "FLORENCE BOWSER ELEM",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001615",
    },
    {
        "school": "FOREST GLEN MIDDLE",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001619",
    },
    {
        "school": "JOHN F. KENNEDY MIDDLE",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001621",
    },
    {
        "school": "JOHN YEATES MIDDLE",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001623",
    },
    {
        "school": "OAKLAND ELEM",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001626",
    },
    {
        "school": "PIONEER ELEM",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001629",
    },
    {
        "school": "ELEPHANT'S FORK ELEM",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001876",
    },
    {
        "school": "KILBY SHORES ELEM",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001877",
    },
    {
        "school": "NANSEMOND PARKWAY ELEM",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001878",
    },
    {
        "school": "MACK BENN JR. ELEM",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371001895",
    },
    {
        "school": "NANSEMOND RIVER HIGH",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371002218",
    },
    {
        "school": "LAKELAND HIGH",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371002219",
    },
    {
        "school": "KING'S FORK MIDDLE",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371002321",
    },
    {
        "school": "TURLINGTON WOODS ALTERNATIVE",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510371002555",
    },
    {
        "school": "PRINCESS ANNE HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384000412",
    },
    {
        "school": "TALLWOOD HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384000434",
    },
    {
        "school": "LANDSTOWN MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384000436",
    },
    {
        "school": "STRAWBRIDGE ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384000443",
    },
    {
        "school": "LANDSTOWN ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384000674",
    },
    {
        "school": "CORPORATE LANDING ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384000675",
    },
    {
        "school": "ADULT LEARNING CTR.",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510384000684",
    },
    {
        "school": "OCEAN LAKES HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001046",
    },
    {
        "school": "LARKSPUR MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001057",
    },
    {
        "school": "OLD DONATION SCHOOL",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001353",
    },
    {
        "school": "CORPORATE LANDING MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001639",
    },
    {
        "school": "CHRISTOPHER FARMS ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001656",
    },
    {
        "school": "ALANTON ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001671",
    },
    {
        "school": "ARROWHEAD ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001673",
    },
    {
        "school": "BAYSIDE ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001674",
    },
    {
        "school": "BAYSIDE HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001675",
    },
    {
        "school": "BAYSIDE MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001676",
    },
    {
        "school": "BRANDON MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001677",
    },
    {
        "school": "BROOKWOOD ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001678",
    },
    {
        "school": "COLLEGE PARK ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001680",
    },
    {
        "school": "CREEDS ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001682",
    },
    {
        "school": "FAIRFIELD ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001683",
    },
    {
        "school": "FIRST COLONIAL HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001684",
    },
    {
        "school": "FLOYD KELLAM HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001685",
    },
    {
        "school": "GREAT NECK MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001686",
    },
    {
        "school": "GREEN RUN ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001687",
    },
    {
        "school": "HERMITAGE ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001688",
    },
    {
        "school": "HOLLAND ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001689",
    },
    {
        "school": "INDEPENDENCE MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001690",
    },
    {
        "school": "JOHN B. DEY ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001691",
    },
    {
        "school": "KEMPSVILLE ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001693",
    },
    {
        "school": "KEMPSVILLE HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001694",
    },
    {
        "school": "KEMPSVILLE MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001695",
    },
    {
        "school": "KEMPSVILLE MEADOWS ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001696",
    },
    {
        "school": "KING'S GRANT ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001697",
    },
    {
        "school": "KINGSTON ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001698",
    },
    {
        "school": "LINKHORN PARK ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001699",
    },
    {
        "school": "LUXFORD ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001700",
    },
    {
        "school": "LYNNHAVEN ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001701",
    },
    {
        "school": "LYNNHAVEN MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001702",
    },
    {
        "school": "MALIBU ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001703",
    },
    {
        "school": "NEWTOWN ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001704",
    },
    {
        "school": "NORTH LANDING ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001705",
    },
    {
        "school": "PEMBROKE ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001707",
    },
    {
        "school": "PEMBROKE MEADOWS ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001708",
    },
    {
        "school": "PLAZA MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001710",
    },
    {
        "school": "POINT O' VIEW ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001711",
    },
    {
        "school": "PRINCESS ANNE ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001712",
    },
    {
        "school": "PRINCESS ANNE MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001714",
    },
    {
        "school": "SEATACK ELEM AN ACHIEVABLE DREAM ACADEMY",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001715",
    },
    {
        "school": "SHELTON PARK ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001716",
    },
    {
        "school": "THALIA ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001717",
    },
    {
        "school": "THOROUGHGOOD ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001718",
    },
    {
        "school": "TRANTWOOD ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001719",
    },
    {
        "school": "VIRGINIA BEACH MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001721",
    },
    {
        "school": "TECHNICAL & CAREER ED. CTR.",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510384001722",
    },
    {
        "school": "W.T. COOKE ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001723",
    },
    {
        "school": "WHITE OAKS ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001724",
    },
    {
        "school": "WILLIAMS ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001725",
    },
    {
        "school": "WINDSOR OAKS ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001726",
    },
    {
        "school": "WINDSOR WOODS ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001727",
    },
    {
        "school": "WOODSTOCK ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001728",
    },
    {
        "school": "GREEN RUN HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001879",
    },
    {
        "school": "INDIAN LAKES ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001880",
    },
    {
        "school": "NEW CASTLE ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001931",
    },
    {
        "school": "PROVIDENCE ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001982",
    },
    {
        "school": "ROSEMONT ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384001983",
    },
    {
        "school": "CENTERVILLE ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002010",
    },
    {
        "school": "FRANK W. COX HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002049",
    },
    {
        "school": "BIRDNECK ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002085",
    },
    {
        "school": "PARKWAY ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002107",
    },
    {
        "school": "ROSEMONT FOREST ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002108",
    },
    {
        "school": "SALEM MIDDLE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002138",
    },
    {
        "school": "SALEM ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002139",
    },
    {
        "school": "SALEM HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002166",
    },
    {
        "school": "OCEAN LAKES ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002167",
    },
    {
        "school": "RED MILL ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002168",
    },
    {
        "school": "TALLWOOD ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002169",
    },
    {
        "school": "GLENWOOD ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002220",
    },
    {
        "school": "LANDSTOWN HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002323",
    },
    {
        "school": "BERKELEY MIDDLE",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402001770",
    },
    {
        "school": "MATTHEW WHALEY ELEM",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402001774",
    },
    {
        "school": "EUNICE KENNEDY SHRIVER PROGRAM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510027002331",
    },
    {
        "school": "CLAREMONT IMMERSION",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027002404",
    },
    {
        "school": "TRANSITION SUPPORT RESOURCE CENTER/FAIRFAX",
        "district": "TRANSITION SUPPORT RESOURCE CTR/FAIRFAX",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510007602351",
    },
    {
        "school": "COLVIN RUN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002333",
    },
    {
        "school": "ISLAND CREEK ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002334",
    },
    {
        "school": "LORTON STATION ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002335",
    },
    {
        "school": "POWELL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002336",
    },
    {
        "school": "DUNN LORING E C RESOURCE CTR",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002406",
    },
    {
        "school": "SOUTH COUNTY HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002436",
    },
    {
        "school": "THE REGIONAL COMMUNITY ALTERNATIVE ED CONTINUUM",
        "district": "THE REGIONAL COMMUNITY ALTERNATIVE ED CONTINUUM",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510008202373",
    },
    {
        "school": "AUBURN MIDDLE",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132002409",
    },
    {
        "school": "DOMINION HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Other",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002411",
    },
    {
        "school": "FRANCES HAZEL REID ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002412",
    },
    {
        "school": "COUNTRYSIDE ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002413",
    },
    {
        "school": "BELMONT RIDGE MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002414",
    },
    {
        "school": "MOUNTAIN VIEW ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002415",
    },
    {
        "school": "SMART'S MILL MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002446",
    },
    {
        "school": "FREEDOM HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002447",
    },
    {
        "school": "NEWTON-LEE ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002448",
    },
    {
        "school": "BELMONT STATION ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002449",
    },
    {
        "school": "MERCER MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002450",
    },
    {
        "school": "BRIAR WOODS HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002451",
    },
    {
        "school": "LEGACY ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002452",
    },
    {
        "school": "PINEBROOK ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002514",
    },
    {
        "school": "INDEPENDENCE NONTRADITIONAL SCHOOL - MIDDLE",
        "district": "INDEPENDENCE NONTRADITIONAL SCHOOL - MIDDLE",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510009202362",
    },
    {
        "school": "J.W. ALVEY ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002417",
    },
    {
        "school": "MARY WILLIAMS ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002455",
    },
    {
        "school": "SUELLA G. ELLIS ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002456",
    },
    {
        "school": "BATTLEFIELD HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002457",
    },
    {
        "school": "FREEDOM HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002458",
    },
    {
        "school": "INDEPENDENCE NONTRADITIONAL - HIGH SCHOOL",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510313002459",
    },
    {
        "school": "GLENKIRK ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002585",
    },
    {
        "school": "VICTORY ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002586",
    },
    {
        "school": "FREEDOM MIDDLE",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364002420",
    },
    {
        "school": "RIVERBEND HIGH",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364002462",
    },
    {
        "school": "REGIONAL ALTERNATIVE ED/STAFFORD CO",
        "district": "REGIONAL ALTERNATIVE ED/STAFFORD CO",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510008802359",
    },
    {
        "school": "MARGARET BRENT ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002463",
    },
    {
        "school": "MOUNTAIN VIEW HIGH",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002464",
    },
    {
        "school": "CONWAY ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002465",
    },
    {
        "school": "LAFAYETTE UPPER ELEM",
        "district": "FREDERICKSBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510151002468",
    },
    {
        "school": "WALKER-GRANT MIDDLE",
        "district": "FREDERICKSBURG CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510151002612",
    },
    {
        "school": "PENNINGTON",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002418",
    },
    {
        "school": "RANDOLPH ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000013",
    },
    {
        "school": "ABINGDON ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000081",
    },
    {
        "school": "ASHLAWN ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000082",
    },
    {
        "school": "BARCROFT ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000083",
    },
    {
        "school": "BARRETT ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000084",
    },
    {
        "school": "DR. CHARLES R. DREW ELEMENTARY",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000087",
    },
    {
        "school": "FRANCIS SCOTT KEY ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000090",
    },
    {
        "school": "GLEBE ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000092",
    },
    {
        "school": "CARLIN SPRINGS ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000093",
    },
    {
        "school": "ALICE WEST FLEET ELEMENTARY",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000094",
    },
    {
        "school": "JAMESTOWN ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000097",
    },
    {
        "school": "JEFFERSON MIDDLE",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000098",
    },
    {
        "school": "KENMORE MIDDLE",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000099",
    },
    {
        "school": "LONG BRANCH ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000100",
    },
    {
        "school": "MCKINLEY ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000101",
    },
    {
        "school": "NOTTINGHAM ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000102",
    },
    {
        "school": "OAKRIDGE ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000103",
    },
    {
        "school": "ARLINGTON TRADITIONAL",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000104",
    },
    {
        "school": "SWANSON MIDDLE",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000107",
    },
    {
        "school": "TAYLOR ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000108",
    },
    {
        "school": "TECH. ED. & CAREER CTR.",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510027000109",
    },
    {
        "school": "TUCKAHOE ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000110",
    },
    {
        "school": "WAKEFIELD HIGH",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000111",
    },
    {
        "school": "WASHINGTON LIBERTY HIGH",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000112",
    },
    {
        "school": "WILLIAMSBURG MIDDLE",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000113",
    },
    {
        "school": "YORKTOWN HIGH",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000115",
    },
    {
        "school": "GUNSTON MIDDLE",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027000752",
    },
    {
        "school": "ARLINGTON SCIENCE FOCUS",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027001067",
    },
    {
        "school": "HOFFMAN-BOSTON ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027001900",
    },
    {
        "school": "CAMPBELL ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027001940",
    },
    {
        "school": "BOYCE ELEM",
        "district": "CLARKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510087000352",
    },
    {
        "school": "JOHNSON-WILLIAMS MIDDLE",
        "district": "CLARKE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510087000353",
    },
    {
        "school": "D G COOLEY ELEM",
        "district": "CLARKE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510087000354",
    },
    {
        "school": "CLARKE COUNTY HIGH",
        "district": "CLARKE CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510087002100",
    },
    {
        "school": "NORTHERN VA. TR. CTR. E.P",
        "district": "N. VA. TRN CT",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510005102300",
    },
    {
        "school": "CHANTILLY HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000059",
    },
    {
        "school": "BELVEDERE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000061",
    },
    {
        "school": "BREN MAR PARK ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000073",
    },
    {
        "school": "STONE MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000086",
    },
    {
        "school": "WAPLES MILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000088",
    },
    {
        "school": "FAIRFAX COUNTY ADULT HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510126000422",
    },
    {
        "school": "ANNANDALE HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000423",
    },
    {
        "school": "ANNANDALE TERRACE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000424",
    },
    {
        "school": "BAILEYS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000426",
    },
    {
        "school": "BEECH TREE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000428",
    },
    {
        "school": "BELLE VIEW ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000429",
    },
    {
        "school": "BRADDOCK ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000431",
    },
    {
        "school": "BROOKFIELD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000433",
    },
    {
        "school": "BUCKNELL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000435",
    },
    {
        "school": "BUSH HILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000438",
    },
    {
        "school": "CAMELOT ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000439",
    },
    {
        "school": "CAMERON ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000440",
    },
    {
        "school": "CANTERBURY WOODS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000441",
    },
    {
        "school": "CARDINAL FOREST ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000442",
    },
    {
        "school": "CHESTERBROOK ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000448",
    },
    {
        "school": "CHURCHILL ROAD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000449",
    },
    {
        "school": "CLERMONT ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000450",
    },
    {
        "school": "COLUMBIA ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000452",
    },
    {
        "school": "COOPER MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000453",
    },
    {
        "school": "CRESTWOOD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000454",
    },
    {
        "school": "CUNNINGHAM PARK ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000455",
    },
    {
        "school": "DOGWOOD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000458",
    },
    {
        "school": "HUTCHISON ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000460",
    },
    {
        "school": "EDISON HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000461",
    },
    {
        "school": "FAIRFAX VILLA ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000464",
    },
    {
        "school": "FAIRHILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000466",
    },
    {
        "school": "FAIRVIEW ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000467",
    },
    {
        "school": "FALLS CHURCH HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000468",
    },
    {
        "school": "FLINT HILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000469",
    },
    {
        "school": "FLORIS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000470",
    },
    {
        "school": "FOREST EDGE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000471",
    },
    {
        "school": "FORESTDALE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000472",
    },
    {
        "school": "FORT HUNT ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000473",
    },
    {
        "school": "SANDBURG MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000474",
    },
    {
        "school": "WHITMAN MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000475",
    },
    {
        "school": "FRANCONIA ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000476",
    },
    {
        "school": "SHERMAN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000477",
    },
    {
        "school": "FREEDOM HILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000478",
    },
    {
        "school": "FROST MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000479",
    },
    {
        "school": "GARFIELD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000480",
    },
    {
        "school": "GLASGOW MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000481",
    },
    {
        "school": "GLEN FOREST ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000482",
    },
    {
        "school": "GRAHAM ROAD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000483",
    },
    {
        "school": "GREAT FALLS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000484",
    },
    {
        "school": "GREENBRIAR EAST ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000486",
    },
    {
        "school": "GREENBRIAR WEST ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000487",
    },
    {
        "school": "GROVETON ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000488",
    },
    {
        "school": "WEST POTOMAC HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000489",
    },
    {
        "school": "GUNSTON ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000490",
    },
    {
        "school": "HAYCOCK ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000491",
    },
    {
        "school": "HAYFIELD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000492",
    },
    {
        "school": "HAYFIELD SECONDARY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000493",
    },
    {
        "school": "HERNDON ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000494",
    },
    {
        "school": "HERNDON HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000495",
    },
    {
        "school": "HERNDON MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000496",
    },
    {
        "school": "BRYANT HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510126000497",
    },
    {
        "school": "HOLLIN MEADOWS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000499",
    },
    {
        "school": "HOLMES MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000500",
    },
    {
        "school": "HUNT VALLEY ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000501",
    },
    {
        "school": "HUNTERS WOODS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000502",
    },
    {
        "school": "HYBLA VALLEY ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000503",
    },
    {
        "school": "IRVING MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000504",
    },
    {
        "school": "JUSTICE HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000505",
    },
    {
        "school": "KEENE MILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000508",
    },
    {
        "school": "KENT GARDENS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000509",
    },
    {
        "school": "KEY CENTER",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510126000510",
    },
    {
        "school": "KEY MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000511",
    },
    {
        "school": "KILMER CENTER",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Other",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510126000512",
    },
    {
        "school": "KILMER MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000513",
    },
    {
        "school": "KINGS PARK ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000514",
    },
    {
        "school": "LAKE ANNE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000515",
    },
    {
        "school": "LAKE BRADDOCK SECONDARY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000516",
    },
    {
        "school": "LANGLEY HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000517",
    },
    {
        "school": "LAUREL RIDGE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000519",
    },
    {
        "school": "LEE HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000521",
    },
    {
        "school": "LEMON ROAD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000522",
    },
    {
        "school": "LITTLE RUN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000525",
    },
    {
        "school": "LONDON TOWNE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000526",
    },
    {
        "school": "LONGFELLOW MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000527",
    },
    {
        "school": "LOUISE ARCHER ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000529",
    },
    {
        "school": "JACKSON MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000530",
    },
    {
        "school": "LYNBROOK ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000531",
    },
    {
        "school": "MADISON HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000532",
    },
    {
        "school": "MANTUA ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000533",
    },
    {
        "school": "MARSHALL HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000535",
    },
    {
        "school": "MARSHALL ROAD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000536",
    },
    {
        "school": "MCLEAN HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000538",
    },
    {
        "school": "MOSBY WOODS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000539",
    },
    {
        "school": "MOUNT EAGLE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000540",
    },
    {
        "school": "MOUNT VERNON HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000542",
    },
    {
        "school": "MOUNT VERNON WOODS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000543",
    },
    {
        "school": "NAVY ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000544",
    },
    {
        "school": "NORTH SPRINGFIELD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000546",
    },
    {
        "school": "OAK VIEW ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000548",
    },
    {
        "school": "OAKTON ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000549",
    },
    {
        "school": "OAKTON HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000550",
    },
    {
        "school": "OLDE CREEK ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000551",
    },
    {
        "school": "ORANGE HUNT ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000552",
    },
    {
        "school": "PARKLAWN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000553",
    },
    {
        "school": "PINE SPRING ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000556",
    },
    {
        "school": "POE MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000557",
    },
    {
        "school": "QUANDER ROAD SCHOOL",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510126000558",
    },
    {
        "school": "RAVENSWORTH ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000559",
    },
    {
        "school": "RIVERSIDE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000560",
    },
    {
        "school": "ROBINSON SECONDARY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000561",
    },
    {
        "school": "ROLLING VALLEY ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000562",
    },
    {
        "school": "ROSE HILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000563",
    },
    {
        "school": "SHREVEWOOD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000564",
    },
    {
        "school": "SLEEPY HOLLOW ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000565",
    },
    {
        "school": "SOUTH LAKES HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000566",
    },
    {
        "school": "SPRING HILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000567",
    },
    {
        "school": "SPRINGFIELD ESTATES ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000568",
    },
    {
        "school": "STENWOOD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000569",
    },
    {
        "school": "STRATFORD LANDING ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000570",
    },
    {
        "school": "SUNRISE VALLEY ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000571",
    },
    {
        "school": "INTERAGENCY ALT. SEC. CTR",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510126000572",
    },
    {
        "school": "TERRASET ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000573",
    },
    {
        "school": "THOREAU MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000574",
    },
    {
        "school": "TIMBER LANE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000575",
    },
    {
        "school": "TWAIN MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000576",
    },
    {
        "school": "VIENNA ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000577",
    },
    {
        "school": "COMMUNITY BASED EDUCATION",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510126000579",
    },
    {
        "school": "WAKEFIELD FOREST ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000580",
    },
    {
        "school": "WASHINGTON MILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000582",
    },
    {
        "school": "WAYNEWOOD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000583",
    },
    {
        "school": "WEST SPRINGFIELD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000584",
    },
    {
        "school": "WEST SPRINGFIELD HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000585",
    },
    {
        "school": "WESTBRIAR ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000586",
    },
    {
        "school": "WESTGATE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000587",
    },
    {
        "school": "WESTLAWN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000588",
    },
    {
        "school": "WEYANOKE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000590",
    },
    {
        "school": "WOLFTRAP ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000594",
    },
    {
        "school": "WOODBURN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000597",
    },
    {
        "school": "WOODLAWN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000598",
    },
    {
        "school": "WOODLEY HILLS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000599",
    },
    {
        "school": "WOODSON HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000600",
    },
    {
        "school": "ALDRIN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000767",
    },
    {
        "school": "DEER PARK ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000768",
    },
    {
        "school": "CENTREVILLE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000775",
    },
    {
        "school": "LANE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001091",
    },
    {
        "school": "HALLEY ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001093",
    },
    {
        "school": "MOUNTAIN VIEW HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510126001099",
    },
    {
        "school": "ALC AT BRYANT",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510126001103",
    },
    {
        "school": "CARSON MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001756",
    },
    {
        "school": "FORT BELVOIR ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001767",
    },
    {
        "school": "CLEARVIEW ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001836",
    },
    {
        "school": "FORESTVILLE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001837",
    },
    {
        "school": "FOX MILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001838",
    },
    {
        "school": "HUGHES MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001839",
    },
    {
        "school": "KINGS GLEN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001840",
    },
    {
        "school": "ROCKY RUN MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001841",
    },
    {
        "school": "TERRA CENTRE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001842",
    },
    {
        "school": "WHITE OAKS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001843",
    },
    {
        "school": "BULL RUN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001904",
    },
    {
        "school": "CEDAR LANE SCHOOL",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510126001991",
    },
    {
        "school": "CHERRY RUN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001992",
    },
    {
        "school": "NEWINGTON FOREST ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001993",
    },
    {
        "school": "OAK HILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126001994",
    },
    {
        "school": "FRANKLIN MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002007",
    },
    {
        "school": "DAVIS CAREER CENTER",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510126002008",
    },
    {
        "school": "BURKE SCHOOL",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510126002032",
    },
    {
        "school": "PULLEY CAREER CENTER",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510126002033",
    },
    {
        "school": "THOMAS JEFFERSON HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002034",
    },
    {
        "school": "ARMSTRONG ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002058",
    },
    {
        "school": "UNION MILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002060",
    },
    {
        "school": "CUB RUN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002061",
    },
    {
        "school": "LEES CORNER ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002063",
    },
    {
        "school": "CENTREVILLE HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002114",
    },
    {
        "school": "SILVERBROOK ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002115",
    },
    {
        "school": "BONNIE BRAE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002116",
    },
    {
        "school": "DRANESVILLE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002117",
    },
    {
        "school": "CROSSFIELD ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002118",
    },
    {
        "school": "SANGSTER ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002119",
    },
    {
        "school": "SARATOGA ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002144",
    },
    {
        "school": "VIRGINIA RUN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002146",
    },
    {
        "school": "WILLOW SPRINGS ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002147",
    },
    {
        "school": "POPLAR TREE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002182",
    },
    {
        "school": "CENTRE RIDGE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002183",
    },
    {
        "school": "LIBERTY MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002271",
    },
    {
        "school": "MCNAIR ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002272",
    },
    {
        "school": "WESTFIELD HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002529",
    },
    {
        "school": "GEORGE MASON HIGH",
        "district": "FALLS CHURCH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510129000283",
    },
    {
        "school": "MARY ELLEN HENDERSON MIDDLE",
        "district": "FALLS CHURCH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510129000284",
    },
    {
        "school": "MT. DANIEL ELEMENTARY",
        "district": "FALLS CHURCH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510129002204",
    },
    {
        "school": "C.M. BRADLEY ELEM",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000604",
    },
    {
        "school": "CEDAR LEE MIDDLE",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000605",
    },
    {
        "school": "FAUQUIER HIGH",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000607",
    },
    {
        "school": "H.M. PEARSON ELEM",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000608",
    },
    {
        "school": "MARSHALL MIDDLE",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000609",
    },
    {
        "school": "CLAUDE THOMPSON ELEM",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000610",
    },
    {
        "school": "P.B. SMITH ELEM",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000611",
    },
    {
        "school": "MARGARET M. PIERCE ELEM",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000612",
    },
    {
        "school": "W.C. TAYLOR MIDDLE",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000614",
    },
    {
        "school": "W.G. COLEMAN ELEM",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000615",
    },
    {
        "school": "WARRENTON MIDDLE",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000616",
    },
    {
        "school": "LIBERTY HIGH",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132000854",
    },
    {
        "school": "MARY WALTER ELEM",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132001846",
    },
    {
        "school": "GRACE MILLER ELEM",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132002184",
    },
    {
        "school": "C. HUNTER RITCHIE ELEM",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132002185",
    },
    {
        "school": "ALTERNATIVE EDUCATION CTR.",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510132002186",
    },
    {
        "school": "JAMES G. BRUMFIELD ELEM",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132002533",
    },
    {
        "school": "ASHBURN ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000134",
    },
    {
        "school": "ALDIE ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000908",
    },
    {
        "school": "BANNEKER ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000911",
    },
    {
        "school": "BLUE RIDGE MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000912",
    },
    {
        "school": "BROAD RUN HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000913",
    },
    {
        "school": "CATOCTIN ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000914",
    },
    {
        "school": "EMERICK ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000917",
    },
    {
        "school": "GUILFORD ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000918",
    },
    {
        "school": "HAMILTON ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000919",
    },
    {
        "school": "J. LUPTON SIMPSON MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000921",
    },
    {
        "school": "LINCOLN ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000922",
    },
    {
        "school": "LOUDOUN COUNTY HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000923",
    },
    {
        "school": "LOUDOUN VALLEY HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000924",
    },
    {
        "school": "LOVETTSVILLE ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000925",
    },
    {
        "school": "LUCKETTS ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000926",
    },
    {
        "school": "PARK VIEW HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000928",
    },
    {
        "school": "ROLLING RIDGE ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000929",
    },
    {
        "school": "ROUND HILL ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000930",
    },
    {
        "school": "SENECA RIDGE MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000931",
    },
    {
        "school": "STERLING ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000932",
    },
    {
        "school": "STERLING MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000933",
    },
    {
        "school": "SUGARLAND ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000934",
    },
    {
        "school": "SULLY ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000935",
    },
    {
        "school": "WATERFORD ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225000936",
    },
    {
        "school": "FARMWELL STATION MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001131",
    },
    {
        "school": "BALL'S BLUFF ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001143",
    },
    {
        "school": "SANDERS CORNER ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001148",
    },
    {
        "school": "POTOWMACK ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001158",
    },
    {
        "school": "POTOMAC FALLS HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001627",
    },
    {
        "school": "DOMINION TRAIL ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001632",
    },
    {
        "school": "LOWES ISLAND ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001633",
    },
    {
        "school": "EVERGREEN MILL ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001845",
    },
    {
        "school": "LEESBURG ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001852",
    },
    {
        "school": "MEADOWLAND ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001853",
    },
    {
        "school": "HILLSIDE ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001855",
    },
    {
        "school": "HARPER PARK MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001913",
    },
    {
        "school": "HORIZON ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001914",
    },
    {
        "school": "CEDAR LANE ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225001915",
    },
    {
        "school": "ALGONKIAN ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002153",
    },
    {
        "school": "COOL SPRING ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002154",
    },
    {
        "school": "DOUGLASS SCHOOL",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510225002281",
    },
    {
        "school": "EAGLE RIDGE MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002282",
    },
    {
        "school": "FOREST GROVE ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002283",
    },
    {
        "school": "HERITAGE HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Other",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002285",
    },
    {
        "school": "HUTCHISON FARM ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002286",
    },
    {
        "school": "JOHN W. TOLBERT JR. ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002287",
    },
    {
        "school": "RIVER BEND MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002288",
    },
    {
        "school": "SELDENS LANDING ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002289",
    },
    {
        "school": "STONE BRIDGE HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002538",
    },
    {
        "school": "LITTLE RIVER ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002539",
    },
    {
        "school": "MILL RUN ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002540",
    },
    {
        "school": "N VIRGINIA REG SPEC ED PGM",
        "district": "N VIRGINIA REG SPEC ED PGM",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510002601576",
    },
    {
        "school": "C.D. HYLTON HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313000186",
    },
    {
        "school": "STUART M. BEVILLE MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313000190",
    },
    {
        "school": "MONTCLAIR ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313000192",
    },
    {
        "school": "THURGOOD MARSHALL ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313000938",
    },
    {
        "school": "MOUNTAIN VIEW ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001168",
    },
    {
        "school": "OLD BRIDGE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001170",
    },
    {
        "school": "BEL AIR ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001285",
    },
    {
        "school": "BELMONT ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001286",
    },
    {
        "school": "BRENTSVILLE DISTRICT HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001288",
    },
    {
        "school": "C.A. SINCLAIR ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001289",
    },
    {
        "school": "COLES ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001290",
    },
    {
        "school": "DALE CITY ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001291",
    },
    {
        "school": "DUMFRIES ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001292",
    },
    {
        "school": "E.H. MARSTELLER MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001293",
    },
    {
        "school": "ELIZABETH VAUGHAN ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001294",
    },
    {
        "school": "ENTERPRISE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001295",
    },
    {
        "school": "FEATHERSTONE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001296",
    },
    {
        "school": "FRED M. LYNN MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001297",
    },
    {
        "school": "GAR-FIELD HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001299",
    },
    {
        "school": "GEORGE G. TYLER ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001300",
    },
    {
        "school": "GRAHAM PARK MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001301",
    },
    {
        "school": "INDEPENDENCE NONTRADITIONAL CENTER",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510313001302",
    },
    {
        "school": "JOHN F. PATTIE SR. ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001303",
    },
    {
        "school": "KERRYDALE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001304",
    },
    {
        "school": "LOCH LOMOND ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001305",
    },
    {
        "school": "MARUMSCO HILLS ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001306",
    },
    {
        "school": "GEORGE M. HAMPTON MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001307",
    },
    {
        "school": "MINNIEVILLE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001308",
    },
    {
        "school": "NEABSCO ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001309",
    },
    {
        "school": "THE NOKESVILLE SCHOOL",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001311",
    },
    {
        "school": "OCCOQUAN ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001312",
    },
    {
        "school": "OSBOURN PARK HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001313",
    },
    {
        "school": "SIGNAL HILL ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001314",
    },
    {
        "school": "PARKSIDE MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001315",
    },
    {
        "school": "POTOMAC VIEW ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001316",
    },
    {
        "school": "R. DEAN KILBY ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001317",
    },
    {
        "school": "RIPPON MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001319",
    },
    {
        "school": "ROCKLEDGE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001320",
    },
    {
        "school": "STONEWALL JACKSON HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001321",
    },
    {
        "school": "STONEWALL MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001322",
    },
    {
        "school": "SUDLEY ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001323",
    },
    {
        "school": "TRIANGLE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001324",
    },
    {
        "school": "WEST GATE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001325",
    },
    {
        "school": "WOODBRIDGE MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001326",
    },
    {
        "school": "WOODBRIDGE HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001327",
    },
    {
        "school": "YORKSHIRE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001328",
    },
    {
        "school": "LEESYLVANIA ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001399",
    },
    {
        "school": "BENNETT ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001402",
    },
    {
        "school": "POTOMAC HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001857",
    },
    {
        "school": "SONNIE PENN ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001864",
    },
    {
        "school": "BRISTOW RUN ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001867",
    },
    {
        "school": "HERBERT J. SAUNDERS MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001951",
    },
    {
        "school": "MARTIN LUTHER KING JR. ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001952",
    },
    {
        "school": "WOODBINE PRE-SCHOOL CENTER",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001955",
    },
    {
        "school": "LAKE RIDGE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313001997",
    },
    {
        "school": "SPRINGWOODS ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002038",
    },
    {
        "school": "A. HENDERSON ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002039",
    },
    {
        "school": "LAKE RIDGE MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002158",
    },
    {
        "school": "SHARON C. MCAULIFFE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002159",
    },
    {
        "school": "WESTRIDGE ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002160",
    },
    {
        "school": "RIVER OAKS ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002198",
    },
    {
        "school": "ANTIETAM ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002199",
    },
    {
        "school": "GEORGE P. MULLEN ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002200",
    },
    {
        "school": "ASHLAND ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002302",
    },
    {
        "school": "BULL RUN MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002303",
    },
    {
        "school": "CEDAR POINT ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002304",
    },
    {
        "school": "SWANS CREEK ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002305",
    },
    {
        "school": "FOREST PARK HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002542",
    },
    {
        "school": "LOUISE A. BENTON MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002543",
    },
    {
        "school": "COMMONWEALTH GOV .SCH.",
        "district": "COMMONWEALTH GOVERNOR'S SCHOOL",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510003501936",
    },
    {
        "school": "SMITH STATION ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364000227",
    },
    {
        "school": "BROCK ROAD ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364000263",
    },
    {
        "school": "COURTHOUSE RD ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364000969",
    },
    {
        "school": "THORNBURG MIDDLE",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364000981",
    },
    {
        "school": "RIVERVIEW ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364000987",
    },
    {
        "school": "QUEST ALTERNATIVE EDUCATION PROGRAM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510364001190",
    },
    {
        "school": "BATTLEFIELD ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001584",
    },
    {
        "school": "BATTLEFIELD MIDDLE",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001585",
    },
    {
        "school": "BERKELEY ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001586",
    },
    {
        "school": "CHANCELLOR ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001587",
    },
    {
        "school": "POST OAK MIDDLE",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001588",
    },
    {
        "school": "LEE HILL ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001589",
    },
    {
        "school": "LIVINGSTON ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001590",
    },
    {
        "school": "ROBERT E. LEE ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001591",
    },
    {
        "school": "SPOTSWOOD ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001592",
    },
    {
        "school": "SPOTSYLVANIA HIGH",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001593",
    },
    {
        "school": "WILDERNESS ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001870",
    },
    {
        "school": "COURTLAND HIGH",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001873",
    },
    {
        "school": "SALEM ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001874",
    },
    {
        "school": "SPOTSYLVANIA CAREER AND TECH. CTR.",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510364001875",
    },
    {
        "school": "MASSAPONAX HIGH",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001881",
    },
    {
        "school": "NI RIVER MIDDLE",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001922",
    },
    {
        "school": "SPOTSYLVANIA MIDDLE",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364001999",
    },
    {
        "school": "COURTLAND ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364002133",
    },
    {
        "school": "CHANCELLOR HIGH",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364002134",
    },
    {
        "school": "CHANCELLOR MIDDLE",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364002165",
    },
    {
        "school": "HARRISON ROAD ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364002317",
    },
    {
        "school": "PARKSIDE ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364002318",
    },
    {
        "school": "HAMPTON OAKS ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366000265",
    },
    {
        "school": "BROOKE POINT HIGH",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366000591",
    },
    {
        "school": "H.H. POOLE MIDDLE",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001199",
    },
    {
        "school": "ANNE E. MONCURE ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001594",
    },
    {
        "school": "EDWARD E. DREW JR. MIDDLE",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001595",
    },
    {
        "school": "FALMOUTH ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001596",
    },
    {
        "school": "FERRY FARM ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001597",
    },
    {
        "school": "GRAFTON VILLAGE ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001598",
    },
    {
        "school": "HARTWOOD ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001599",
    },
    {
        "school": "STAFFORD ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001600",
    },
    {
        "school": "STAFFORD MIDDLE",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001601",
    },
    {
        "school": "STAFFORD SR. HIGH",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001602",
    },
    {
        "school": "T. BENTON GAYLE MIDDLE",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001603",
    },
    {
        "school": "WINDING CREEK ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001634",
    },
    {
        "school": "COLONIAL FORGE HIGH",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001923",
    },
    {
        "school": "ANDREW G. WRIGHT MIDDLE",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001978",
    },
    {
        "school": "NORTH STAFFORD HIGH",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366001979",
    },
    {
        "school": "GARRISONVILLE ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002084",
    },
    {
        "school": "WIDEWATER ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002106",
    },
    {
        "school": "ROCKHILL ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002135",
    },
    {
        "school": "PARK RIDGE ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002201",
    },
    {
        "school": "KATE WALLER BARRETT ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002320",
    },
    {
        "school": "ROCKY RUN ELEM",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002547",
    },
    {
        "school": "RODNEY E. THOMPSON MIDDLE",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002548",
    },
    {
        "school": "HILDA J. BARBOUR ELEM",
        "district": "WARREN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510387001636",
    },
    {
        "school": "A.S. RHODES ELEM",
        "district": "WARREN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510387001729",
    },
    {
        "school": "E. WILSON MORRISON ELEM",
        "district": "WARREN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510387001730",
    },
    {
        "school": "LESLIE FOX KEYSER ELEM",
        "district": "WARREN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510387001731",
    },
    {
        "school": "RESSIE JEFFRIES ELEM",
        "district": "WARREN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510387001732",
    },
    {
        "school": "WARREN COUNTY HIGH",
        "district": "WARREN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510387001733",
    },
    {
        "school": "CHARLES BARRETT ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000038",
    },
    {
        "school": "DOUGLAS MACARTHUR ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000039",
    },
    {
        "school": "GEORGE MASON ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000041",
    },
    {
        "school": "JAMES K POLK ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000043",
    },
    {
        "school": "JEFFERSON-HOUSTON ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000044",
    },
    {
        "school": "JOHN ADAMS ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000045",
    },
    {
        "school": "LYLES-CROUCH ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000047",
    },
    {
        "school": "MAURY ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000048",
    },
    {
        "school": "MOUNT VERNON ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000050",
    },
    {
        "school": "PATRICK HENRY ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000052",
    },
    {
        "school": "TC WILLIAMS HIGH",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000054",
    },
    {
        "school": "WILLIAM RAMSAY ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012000055",
    },
    {
        "school": "CORA KELLY MAGNET ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012001826",
    },
    {
        "school": "SAMUEL W TUCKER ELEM",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012002549",
    },
    {
        "school": "FAIRFAX HIGH",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000463",
    },
    {
        "school": "LANIER MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126000518",
    },
    {
        "school": "ALC AT MOUNTAIN VIEW",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510126001106",
    },
    {
        "school": "DANIELS RUN ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002530",
    },
    {
        "school": "PROVIDENCE ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002531",
    },
    {
        "school": "THOMAS JEFFERSON ELEM",
        "district": "FALLS CHURCH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510129001844",
    },
    {
        "school": "HUGH MERCER ELEM",
        "district": "FREDERICKSBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510151000660",
    },
    {
        "school": "JAMES MONROE HIGH",
        "district": "FREDERICKSBURG CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510151000661",
    },
    {
        "school": "WALKER-GRANT CENTER",
        "district": "FREDERICKSBURG CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510151002274",
    },
    {
        "school": "JOSEPH B. JOHNSON LRNG. CTR.",
        "district": "MANASSAS CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510236000738",
    },
    {
        "school": "BALDWIN ELEM",
        "district": "MANASSAS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510236000976",
    },
    {
        "school": "JENNIE DEAN ELEM",
        "district": "MANASSAS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510236000977",
    },
    {
        "school": "OSBOURN HIGH",
        "district": "MANASSAS CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510236000978",
    },
    {
        "school": "WEEMS ELEM",
        "district": "MANASSAS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510236000979",
    },
    {
        "school": "RICHARD C. HAYDON ELEM",
        "district": "MANASSAS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510236001854",
    },
    {
        "school": "GEORGE CARR ROUND ELEM",
        "district": "MANASSAS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510236002067",
    },
    {
        "school": "GRACE E. METZ MIDDLE",
        "district": "MANASSAS CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510236002226",
    },
    {
        "school": "MANASSAS PARK ELEM",
        "district": "MANASSAS PARK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510239000982",
    },
    {
        "school": "MANASSAS PARK HIGH",
        "district": "MANASSAS PARK CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510239000983",
    },
    {
        "school": "MANASSAS PARK MIDDLE",
        "district": "MANASSAS PARK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510239002227",
    },
    {
        "school": "COUGAR ELEM",
        "district": "MANASSAS PARK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510239002292",
    },
    {
        "school": "MILLBROOK HIGH",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147002337",
    },
    {
        "school": "ADMIRAL RICHARD E. BYRD MIDDLE",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147002437",
    },
    {
        "school": "NORTHWESTERN REG ED PGM",
        "district": "NORTHWESTERN REG ED PGM",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510002501575",
    },
    {
        "school": "ARMEL ELEM",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147000091",
    },
    {
        "school": "GAINESBORO ELEM",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147000095",
    },
    {
        "school": "SHERANDO HIGH",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147000524",
    },
    {
        "school": "APPLE PIE RIDGE ELEM",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147000646",
    },
    {
        "school": "BASS-HOOVER ELEM",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147000647",
    },
    {
        "school": "JAMES WOOD HIGH",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147000652",
    },
    {
        "school": "ROBERT E. AYLOR MIDDLE",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147000656",
    },
    {
        "school": "STONEWALL ELEM",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147000659",
    },
    {
        "school": "REDBUD RUN ELEM",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147001381",
    },
    {
        "school": "INDIAN HOLLOW ELEM",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147002121",
    },
    {
        "school": "MIDDLETOWN ELEM",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147002149",
    },
    {
        "school": "ORCHARD VIEW ELEM",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147002534",
    },
    {
        "school": "JAMES WOOD MIDDLE",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147000523",
    },
    {
        "school": "FREDERICK COUNTY MIDDLE",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147000649",
    },
    {
        "school": "DANIEL MORGAN MIDDLE",
        "district": "WINCHESTER CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510405001777",
    },
    {
        "school": "FREDERICK DOUGLASS ELEM",
        "district": "WINCHESTER CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510405001778",
    },
    {
        "school": "GARLAND R. QUARLES ELEM",
        "district": "WINCHESTER CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510405001779",
    },
    {
        "school": "JOHN HANDLEY HIGH",
        "district": "WINCHESTER CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510405001780",
    },
    {
        "school": "VIRGINIA AVE. CHARLOTTE DEHART ELEM",
        "district": "WINCHESTER CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510405001782",
    },
    {
        "school": "JULIUS E SPRAUVE",
        "district": "Saint Thomas - Saint John School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780003000022",
    },
    {
        "school": "CHARLOTTE AMALIE HIGH SCHOOL",
        "district": "Saint Thomas - Saint John School District",
        "level": "High",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780003000005",
    },
    {
        "school": "IVANNA EUDORA KEAN HIGH SCHOOL",
        "district": "Saint Thomas - Saint John School District",
        "level": "High",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780003000015",
    },
    {
        "school": "JANE E. TUITT ELEMENTARY SCHOOL",
        "district": "Saint Thomas - Saint John School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780003000018",
    },
    {
        "school": "JOSEPH GOMEZ ELEMENTARY SCHOOL",
        "district": "Saint Thomas - Saint John School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780003000019",
    },
    {
        "school": "JOSEPH SIBILLY ELEMENTARY SCHOOL",
        "district": "Saint Thomas - Saint John School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780003000020",
    },
    {
        "school": "LOCKHART ELEMENTARY SCHOOL",
        "district": "Saint Thomas - Saint John School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780003000024",
    },
    {
        "school": "ULLA F MULLER ELEMENTARY SCHOOL",
        "district": "Saint Thomas - Saint John School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780003000026",
    },
    {
        "school": "YVONNE BOWSKY ELEMENTARY SCHOOL",
        "district": "Saint Thomas - Saint John School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780003000027",
    },
    {
        "school": "CANCRYN JUNIOR HIGH SCHOOL",
        "district": "Saint Thomas - Saint John School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780003000033",
    },
    {
        "school": "BERTHA BOSCHULTE JUNIOR HIGH",
        "district": "Saint Thomas - Saint John School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780003000034",
    },
    {
        "school": "Stamford Elementary School",
        "district": "Stamford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500768000316",
    },
    {
        "school": "Danville School",
        "district": "Danville School District",
        "level": "Other",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500345000451",
    },
    {
        "school": "Peacham Elementary School",
        "district": "Peacham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500639000237",
    },
    {
        "school": "St. Johnsbury School",
        "district": "Saint Johnsbury School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500765000181",
    },
    {
        "school": "Hazen UHSD # 26",
        "district": "Hazen UHSD #26",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500824300343",
    },
    {
        "school": "Brighton Elementary School",
        "district": "Brighton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500261000054",
    },
    {
        "school": "Wolcott Elementary School",
        "district": "Wolcott School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500939000391",
    },
    {
        "school": "Charleston Elementary School",
        "district": "Charleston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500306000083",
    },
    {
        "school": "Coventry Village School",
        "district": "Coventry School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500336000096",
    },
    {
        "school": "Craftsbury Schools",
        "district": "Craftsbury School District",
        "level": "Other",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500339000428",
    },
    {
        "school": "Derby Elementary School",
        "district": "Derby School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500348000429",
    },
    {
        "school": "Jay/Westfield Joint Elementary School",
        "district": "Jay/Westfield Joint Elementary School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500496000015",
    },
    {
        "school": "Lake Region UHSD #24",
        "district": "Lake Region UHSD #24",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500505000170",
    },
    {
        "school": "Lowell Village School",
        "district": "Lowell School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500522000175",
    },
    {
        "school": "Newport City Elementary School",
        "district": "Newport City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500600000439",
    },
    {
        "school": "Newport Town School",
        "district": "Newport Town School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500603000218",
    },
    {
        "school": "Troy School",
        "district": "Troy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500813000328",
    },
    {
        "school": "North Country Junior UHSD #22",
        "district": "North Country Junior UHSD #22",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500957000470",
    },
    {
        "school": "North Country Career Center",
        "district": "North Country Senior UHSD #22",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500960000107",
    },
    {
        "school": "North Country Senior UHSD #22",
        "district": "North Country Senior UHSD #22",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500960000220",
    },
    {
        "school": "Marlboro Elementary School",
        "district": "Marlboro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500540000186",
    },
    {
        "school": "Bellows Falls Middle School",
        "district": "Rockingham School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500693000262",
    },
    {
        "school": "Central Elementary School",
        "district": "Rockingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500693000263",
    },
    {
        "school": "Saxton River Elementary School",
        "district": "Rockingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500693000264",
    },
    {
        "school": "Bellows Falls UHSD #27",
        "district": "Bellows Falls UHSD #27",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500824600346",
    },
    {
        "school": "Vernon Elementary School",
        "district": "Vernon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500831000351",
    },
    {
        "school": "Windham Elementary School",
        "district": "Windham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500927000384",
    },
    {
        "school": "Southwest Vermont Career Development Center",
        "district": "Southwest Vermont Career Development Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500002200103",
    },
    {
        "school": "Mt. Anthony Senior UHSD #14",
        "district": "Mount Anthony UHSD #14",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500581000208",
    },
    {
        "school": "Mt. Anthony Union Middle School",
        "district": "Mount Anthony UHSD #14",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500581000463",
    },
    {
        "school": "Canaan Schools",
        "district": "Canaan School District",
        "level": "Other",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500294000426",
    },
    {
        "school": "Chamberlin School",
        "district": "South Burlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500747000291",
    },
    {
        "school": "Orchard School",
        "district": "South Burlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500747000292",
    },
    {
        "school": "Rick Marcotte Central School",
        "district": "South Burlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500747000293",
    },
    {
        "school": "South Burlington High School",
        "district": "South Burlington School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500747000294",
    },
    {
        "school": "Frederick H. Tuttle Middle School",
        "district": "South Burlington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500747000295",
    },
    {
        "school": "Rutland Intermediate School",
        "district": "Rutland City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500705000075",
    },
    {
        "school": "Stafford Technical Center",
        "district": "Rutland City School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500705000094",
    },
    {
        "school": "Rutland Senior High School",
        "district": "Rutland City School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500705000271",
    },
    {
        "school": "Rutland Northeast Primary School",
        "district": "Rutland City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500705000274",
    },
    {
        "school": "Rutland Northwest School",
        "district": "Rutland City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500705000275",
    },
    {
        "school": "Rutland Middle School",
        "district": "Rutland City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500705000468",
    },
    {
        "school": "Newton Elementary School",
        "district": "Strafford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500783000320",
    },
    {
        "school": "Thetford Elementary School",
        "district": "Thetford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500801000325",
    },
    {
        "school": "Blue Mountain USD #21",
        "district": "Blue Mountain USD #21",
        "level": "Other",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500822400334",
    },
    {
        "school": "Waits River Valley USD #36",
        "district": "Waits River Valley USD #36",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500824200340",
    },
    {
        "school": "Cabot School",
        "district": "Cabot School District",
        "level": "Other",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500285000074",
    },
    {
        "school": "Twinfield USD #33",
        "district": "Twinfield USD #33",
        "level": "Other",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500822500335",
    },
    {
        "school": "Sharon Elementary School",
        "district": "Sharon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500726000283",
    },
    {
        "school": "Arlington Memorial",
        "district": "Arlington School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500183000005",
    },
    {
        "school": "Fisher School",
        "district": "Arlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500183000006",
    },
    {
        "school": "Patricia A. Hannaford Career Center",
        "district": "Patricia Hannaford Career Center School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500002100099",
    },
    {
        "school": "Winooski Middle School",
        "district": "Winooski School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500936000183",
    },
    {
        "school": "BFA Middle/High School ? Fairfax",
        "district": "Fairfax School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500393000204",
    },
    {
        "school": "BFA Elementary School ? Fairfax",
        "district": "Fairfax School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500393000206",
    },
    {
        "school": "Fletcher Elementary School",
        "district": "Fletcher School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500408000134",
    },
    {
        "school": "Cambridge Elementary School",
        "district": "Cambridge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500291000077",
    },
    {
        "school": "Woodside Juvenile Rehabilitation Center",
        "district": "Woodside Juvenile Rehabilitation Center",
        "level": "High",
        "type": "Alternative Education School",
        "state": "VT",
        "nces_id": "500000500251",
    },
    {
        "school": "Burlington Senior High School",
        "district": "Burlington School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500282000063",
    },
    {
        "school": "C. P. Smith School",
        "district": "Burlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500282000064",
    },
    {
        "school": "Champlain School",
        "district": "Burlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500282000065",
    },
    {
        "school": "Edmunds Middle School",
        "district": "Burlington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500282000066",
    },
    {
        "school": "J. J. Flynn School",
        "district": "Burlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500282000068",
    },
    {
        "school": "Sustainability Academy at Lawrence Barnes",
        "district": "Burlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500282000069",
    },
    {
        "school": "Lyman C. Hunt Middle School",
        "district": "Burlington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500282000070",
    },
    {
        "school": "Edmunds Elementary School",
        "district": "Burlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500282000071",
    },
    {
        "school": "Integrated Arts Academy at H. O. Wheeler",
        "district": "Burlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500282000073",
    },
    {
        "school": "Burlington Technical Center",
        "district": "Burlington School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500282000080",
    },
    {
        "school": "Colchester High School",
        "district": "Colchester School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500324000087",
    },
    {
        "school": "Colchester Middle School",
        "district": "Colchester School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500324000088",
    },
    {
        "school": "Malletts Bay School",
        "district": "Colchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500324000090",
    },
    {
        "school": "Porters Point School",
        "district": "Colchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500324000091",
    },
    {
        "school": "Union Memorial School",
        "district": "Colchester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500324000092",
    },
    {
        "school": "Milton Senior High School",
        "district": "Milton Incorporated School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500561000125",
    },
    {
        "school": "Milton Middle School",
        "district": "Milton Incorporated School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500561000193",
    },
    {
        "school": "Milton Elementary School",
        "district": "Milton Incorporated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500561000437",
    },
    {
        "school": "J. F. Kennedy Elementary School",
        "district": "Winooski School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500936000388",
    },
    {
        "school": "Winooski High School",
        "district": "Winooski School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500936000389",
    },
    {
        "school": "Georgia Elementary & Middle School",
        "district": "Georgia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500414000136",
    },
    {
        "school": "Alburg Community Education Center",
        "district": "Alburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500177000004",
    },
    {
        "school": "Folsum Education & Community Center",
        "district": "South Hero School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500750000296",
    },
    {
        "school": "Rivendell Academy",
        "district": "Rivendell Interstate School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500002400180",
    },
    {
        "school": "Samuel Morey Elementary School",
        "district": "Rivendell Interstate School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500002400131",
    },
    {
        "school": "Westshire Elementary School",
        "district": "Rivendell Interstate School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500002400250",
    },
    {
        "school": "Barnard Academy",
        "district": "Barnard School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500195000011",
    },
    {
        "school": "Dothan Brook School",
        "district": "Hartford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500459000047",
    },
    {
        "school": "Ottauquechee School",
        "district": "Hartford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500459000062",
    },
    {
        "school": "Hartford Area Career & Technology Center",
        "district": "Hartford School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500459000093",
    },
    {
        "school": "Hartford Memorial Middle School",
        "district": "Hartford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500459000150",
    },
    {
        "school": "Hartford High School",
        "district": "Hartford School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500459000151",
    },
    {
        "school": "White River School",
        "district": "Hartford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500459000153",
    },
    {
        "school": "Hartland Elementary School",
        "district": "Hartland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500462000155",
    },
    {
        "school": "Marion W. Cross School",
        "district": "Norwich School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500618000230",
    },
    {
        "school": "Riverside School",
        "district": "Springfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500753000298",
    },
    {
        "school": "Elm Hill School",
        "district": "Springfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500753000299",
    },
    {
        "school": "Springfield High School",
        "district": "Springfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500753000300",
    },
    {
        "school": "Union School",
        "district": "Springfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500753000303",
    },
    {
        "school": "Rutland Town Elementary School",
        "district": "Rutland Town School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500708000279",
    },
    {
        "school": "Insight School of Washington",
        "district": "Quillayute Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530702003078",
    },
    {
        "school": "Liberty Middle School",
        "district": "Camas School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081003066",
    },
    {
        "school": "Papermaker Preschool",
        "district": "Camas School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081003081",
    },
    {
        "school": "Special Education",
        "district": "Kelso School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530000303076",
    },
    {
        "school": "Crossroads Community School",
        "district": "Quilcene School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530699003083",
    },
    {
        "school": "Grand Ridge Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375003067",
    },
    {
        "school": "Issaquah ECEAP",
        "district": "Issaquah School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375003167",
    },
    {
        "school": "Renaissance School",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423003070",
    },
    {
        "school": "Rosa Parks Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423003077",
    },
    {
        "school": "Renton Academy",
        "district": "Renton School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530723003073",
    },
    {
        "school": "Birth to 3 Contracts",
        "district": "Seattle School District No. 1",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530771003033",
    },
    {
        "school": "Madrona Heights PreSchool Program",
        "district": "South Kitsap School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816003080",
    },
    {
        "school": "Kittitas B-5 Special Ed Program",
        "district": "Kittitas School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530405003188",
    },
    {
        "school": "White Salmon Academy",
        "district": "White Salmon Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530981003072",
    },
    {
        "school": "Garrett Heyns High School",
        "district": "Centralia College",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530001603208",
    },
    {
        "school": "Onalaska Middle School",
        "district": "Onalaska School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530624003062",
    },
    {
        "school": "Selkirk Elementary",
        "district": "Selkirk School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530780003074",
    },
    {
        "school": "Bates Technical High School",
        "district": "Bates Technical College",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530001403082",
    },
    {
        "school": "Lakeland Hills Elementary",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030003063",
    },
    {
        "school": "Eatonville Developmental Pre-School",
        "district": "Eatonville School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530237003060",
    },
    {
        "school": "Helen B. Stafford Elementary",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870003064",
    },
    {
        "school": "Ridgeline Middle School",
        "district": "Yelm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531014003068",
    },
    {
        "school": "Special Services School",
        "district": "Concrete School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530166003177",
    },
    {
        "school": "Good Beginnings Center",
        "district": "Sedro-Woolley School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530774003084",
    },
    {
        "school": "Arlington Special Educ School",
        "district": "Arlington School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530024003065",
    },
    {
        "school": "ECEAP",
        "district": "Marysville School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486003058",
    },
    {
        "school": "Central Valley Early Learning Center",
        "district": "Central Valley School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530111003059",
    },
    {
        "school": "Olympia Regional Learning Academy",
        "district": "Olympia School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530618003205",
    },
    {
        "school": "Ferndale Special Services",
        "district": "Ferndale School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530285003199",
    },
    {
        "school": "Meridian Parent Partnership Program",
        "district": "Meridian School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530501003036",
    },
    {
        "school": "Sierra Vista Middle School",
        "district": "Sunnyside School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530867003037",
    },
    {
        "school": "Republic Parent Partner",
        "district": "Republic School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530726002888",
    },
    {
        "school": "Republic Junior High",
        "district": "Republic School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530726002949",
    },
    {
        "school": "Goldendale Support Service Center",
        "district": "Goldendale School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530309002988",
    },
    {
        "school": "Lyle Middle School",
        "district": "Lyle School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530459002931",
    },
    {
        "school": "Ocean Park Elementary",
        "district": "Ocean Beach School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530606003050",
    },
    {
        "school": "Griffin Bay School",
        "district": "San Juan Island School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530765003136",
    },
    {
        "school": "Loon Lake Homelink Program",
        "district": "Loon Lake School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530450003098",
    },
    {
        "school": "Columbia Virtual Academy",
        "district": "Valley School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530924003107",
    },
    {
        "school": "Wellpinit Elementary School",
        "district": "Wellpinit School District #49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530963003146",
    },
    {
        "school": "Wellpinit Middle School",
        "district": "Wellpinit School District #49",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530963003150",
    },
    {
        "school": "Benge Elementary",
        "district": "Benge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530045000118",
    },
    {
        "school": "Lind Elementary School",
        "district": "Lind School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530441000695",
    },
    {
        "school": "Lind-Ritzville High School",
        "district": "Lind School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530441000696",
    },
    {
        "school": "Hiawatha Elementary School",
        "district": "Othello School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530648000954",
    },
    {
        "school": "Lutacaga Elementary",
        "district": "Othello School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530648000955",
    },
    {
        "school": "McFarland Middle School",
        "district": "Othello School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530648000956",
    },
    {
        "school": "Othello High School",
        "district": "Othello School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530648000957",
    },
    {
        "school": "Scootney Springs Elementary",
        "district": "Othello School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530648000958",
    },
    {
        "school": "Ritzville Grade School",
        "district": "Ritzville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530738001109",
    },
    {
        "school": "Ritzville High School",
        "district": "Ritzville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530738001111",
    },
    {
        "school": "Washtucna Elementary/High School",
        "district": "Washtucna School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530957001625",
    },
    {
        "school": "Dayton Elementary School",
        "district": "Dayton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530204000304",
    },
    {
        "school": "Dayton High School",
        "district": "Dayton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530204000305",
    },
    {
        "school": "Dayton Middle School",
        "district": "Dayton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530204002513",
    },
    {
        "school": "Starbuck School",
        "district": "Starbuck School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530840001427",
    },
    {
        "school": "Inchelium High School",
        "district": "Inchelium School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000200568",
    },
    {
        "school": "Inchelium Middle School",
        "district": "Inchelium School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000202870",
    },
    {
        "school": "Inchelium Elementary School",
        "district": "Inchelium School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000202871",
    },
    {
        "school": "Curlew Elem & High School",
        "district": "Curlew School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530189000295",
    },
    {
        "school": "Keller Elementary School",
        "district": "Keller School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530387000586",
    },
    {
        "school": "Orient Elementary School",
        "district": "Orient School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530636000948",
    },
    {
        "school": "Republic Elementary School",
        "district": "Republic School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530726001088",
    },
    {
        "school": "Republic Senior High School",
        "district": "Republic School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530726001089",
    },
    {
        "school": "Pomeroy Elementary School",
        "district": "Pomeroy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530678000993",
    },
    {
        "school": "Pomeroy Jr Sr High School",
        "district": "Pomeroy School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530678000994",
    },
    {
        "school": "Brinnon Elementary",
        "district": "Brinnon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530075000153",
    },
    {
        "school": "Chimacum Elementary School",
        "district": "Chimacum School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530129000232",
    },
    {
        "school": "Chimacum Junior/Senior High School",
        "district": "Chimacum School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530129000233",
    },
    {
        "school": "PI Program",
        "district": "Chimacum School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530129002630",
    },
    {
        "school": "Chimacum Creek Primary School",
        "district": "Chimacum School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530129002790",
    },
    {
        "school": "Queets-Clearwater Elementary",
        "district": "Queets-Clearwater School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530138000243",
    },
    {
        "school": "Salish Coast Elementary",
        "district": "Port Townsend School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530684001005",
    },
    {
        "school": "Port Townsend High School",
        "district": "Port Townsend School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530684001007",
    },
    {
        "school": "Blue Heron Middle School",
        "district": "Port Townsend School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530684001305",
    },
    {
        "school": "OCEAN",
        "district": "Port Townsend School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530684002791",
    },
    {
        "school": "Quilcene High And Elementary",
        "district": "Quilcene School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530699001045",
    },
    {
        "school": "Bickleton Elementary & High Schl",
        "district": "Bickleton School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530051000129",
    },
    {
        "school": "Centerville Elementary",
        "district": "Centerville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530105000175",
    },
    {
        "school": "Glenwood Elementary",
        "district": "Glenwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530303000248",
    },
    {
        "school": "Glenwood Secondary",
        "district": "Glenwood School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530303000489",
    },
    {
        "school": "Goldendale High School",
        "district": "Goldendale School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530309000490",
    },
    {
        "school": "Goldendale Middle School",
        "district": "Goldendale School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530309000491",
    },
    {
        "school": "Goldendale Primary School",
        "district": "Goldendale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530309000492",
    },
    {
        "school": "Klickitat Elem & High",
        "district": "Klickitat School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530408000644",
    },
    {
        "school": "Dallesport Elementary",
        "district": "Lyle School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530459000717",
    },
    {
        "school": "Lyle High School",
        "district": "Lyle School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530459000718",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Roosevelt School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530753001119",
    },
    {
        "school": "Trout Lake School",
        "district": "Trout Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530906001539",
    },
    {
        "school": "Trout Lake Elementary",
        "district": "Trout Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530906002657",
    },
    {
        "school": "Columbia High School",
        "district": "White Salmon Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530981001664",
    },
    {
        "school": "Hulan L Whitson Elem",
        "district": "White Salmon Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530981001665",
    },
    {
        "school": "Wayne M Henkle Middle School",
        "district": "White Salmon Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530981001666",
    },
    {
        "school": "Wishram High And Elementary Schl",
        "district": "Wishram School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531002001680",
    },
    {
        "school": "Almira Elementary School",
        "district": "Almira School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530009000179",
    },
    {
        "school": "Creston Elementary",
        "district": "Creston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530186000293",
    },
    {
        "school": "Creston Jr-Sr High School",
        "district": "Creston School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530186000294",
    },
    {
        "school": "Davenport Elementary",
        "district": "Davenport School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530201000302",
    },
    {
        "school": "Davenport Senior High School",
        "district": "Davenport School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530201000303",
    },
    {
        "school": "Harrington Elementary School",
        "district": "Harrington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530336000511",
    },
    {
        "school": "Harrington High School",
        "district": "Harrington School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530336000512",
    },
    {
        "school": "P C Jantz Elementary",
        "district": "Odessa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530612000915",
    },
    {
        "school": "Odessa High School",
        "district": "Odessa School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530612000916",
    },
    {
        "school": "Reardan Elementary School",
        "district": "Reardan-Edwall School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530721001062",
    },
    {
        "school": "Reardan Middle-Senior High School",
        "district": "Reardan-Edwall School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530721001063",
    },
    {
        "school": "Sprague Elementary",
        "district": "Sprague School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530828001418",
    },
    {
        "school": "Sprague High School",
        "district": "Sprague School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530828001419",
    },
    {
        "school": "Wilbur Elementary School",
        "district": "Wilbur School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530984001667",
    },
    {
        "school": "Wilbur Secondary School",
        "district": "Wilbur School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530984001668",
    },
    {
        "school": "Brewster Elementary School",
        "district": "Brewster School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530069000148",
    },
    {
        "school": "Brewster High School",
        "district": "Brewster School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530069000149",
    },
    {
        "school": "Brewster Middle School",
        "district": "Brewster School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530069002284",
    },
    {
        "school": "Lake Roosevelt Elementary",
        "district": "Grand Coulee Dam School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530313000494",
    },
    {
        "school": "Lake Roosevelt Jr/Sr High School",
        "district": "Grand Coulee Dam School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530313000496",
    },
    {
        "school": "Liberty Bell Jr Sr High",
        "district": "Methow Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530502000770",
    },
    {
        "school": "Alternative School",
        "district": "Methow Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530502001170",
    },
    {
        "school": "Methow Valley Elementary",
        "district": "Methow Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530502002526",
    },
    {
        "school": "Home School Experience",
        "district": "Methow Valley School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530502002807",
    },
    {
        "school": "Nespelem Elementary",
        "district": "Nespelem School District #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530555000832",
    },
    {
        "school": "E Omak Elementary",
        "district": "Omak School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530622000938",
    },
    {
        "school": "N Omak Elementary",
        "district": "Omak School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530622000939",
    },
    {
        "school": "Omak High School",
        "district": "Omak School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530622000940",
    },
    {
        "school": "Omak Middle School",
        "district": "Omak School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530622001912",
    },
    {
        "school": "Highlands High School",
        "district": "Omak School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530622002135",
    },
    {
        "school": "Oroville Elementary",
        "district": "Oroville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530642000950",
    },
    {
        "school": "Oroville Middle-High School",
        "district": "Oroville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530642000951",
    },
    {
        "school": "Pateros Elementary",
        "district": "Pateros School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530660000974",
    },
    {
        "school": "Pateros High School",
        "district": "Pateros School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530660000975",
    },
    {
        "school": "Tonasket Elementary School",
        "district": "Tonasket School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530894001529",
    },
    {
        "school": "Tonasket High School",
        "district": "Tonasket School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530894001530",
    },
    {
        "school": "Tonasket Middle School",
        "district": "Tonasket School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530894001647",
    },
    {
        "school": "Naselle Elementary",
        "district": "Naselle-Grays River Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530552000829",
    },
    {
        "school": "Naselle Youth Camp School",
        "district": "Naselle-Grays River Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530552000830",
    },
    {
        "school": "Naselle Jr Sr High Schools",
        "district": "Naselle-Grays River Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530552000831",
    },
    {
        "school": "Hilltop School",
        "district": "Ocean Beach School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530606000911",
    },
    {
        "school": "Long Beach Elementary School",
        "district": "Ocean Beach School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530606000912",
    },
    {
        "school": "Ilwaco High School",
        "district": "Ocean Beach School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530606002528",
    },
    {
        "school": "Raymond Elementary School",
        "district": "Raymond School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530714001059",
    },
    {
        "school": "Raymond Jr Sr High School",
        "district": "Raymond School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530714001060",
    },
    {
        "school": "Developmental Preschool",
        "district": "Raymond School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530714002460",
    },
    {
        "school": "Chauncey Davis Elementary",
        "district": "South Bend School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530810001336",
    },
    {
        "school": "South Bend High School",
        "district": "South Bend School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530810001337",
    },
    {
        "school": "Willapa Elementary",
        "district": "Willapa Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530987001672",
    },
    {
        "school": "Willapa Valley Middle-High",
        "district": "Willapa Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530987001673",
    },
    {
        "school": "Bess Herian Elementary",
        "district": "Cusick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530192000296",
    },
    {
        "school": "Cusick Jr Sr High School",
        "district": "Cusick School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530192000297",
    },
    {
        "school": "Newport High School",
        "district": "Newport School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530561000833",
    },
    {
        "school": "Sadie Halstead Middle School",
        "district": "Newport School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530561001911",
    },
    {
        "school": "Stratton Elementary",
        "district": "Newport School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530561002462",
    },
    {
        "school": "Lopez Middle High School",
        "district": "Lopez School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530453000713",
    },
    {
        "school": "Lopez Elementary School",
        "district": "Lopez School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530453001787",
    },
    {
        "school": "Orcas Island Elementary School",
        "district": "Orcas Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530630000944",
    },
    {
        "school": "Orcas Island High School",
        "district": "Orcas Island School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530630000945",
    },
    {
        "school": "Waldron Island School",
        "district": "Orcas Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530630000946",
    },
    {
        "school": "Orcas Island Middle School",
        "district": "Orcas Island School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530630002815",
    },
    {
        "school": "OASIS K-12",
        "district": "Orcas Island School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530630002869",
    },
    {
        "school": "Friday Harbor High School",
        "district": "San Juan Island School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530765001125",
    },
    {
        "school": "Friday Harbor Elementary School",
        "district": "San Juan Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530765001798",
    },
    {
        "school": "Friday Harbor Middle School",
        "district": "San Juan Island School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530765002666",
    },
    {
        "school": "Shaw Island Elementary School",
        "district": "Shaw Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530786001291",
    },
    {
        "school": "Decatur Elementary",
        "district": "Lopez School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530453001846",
    },
    {
        "school": "Gess Elementary",
        "district": "Chewelah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530126000229",
    },
    {
        "school": "Jenkins Junior/Senior High",
        "district": "Chewelah School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530126000230",
    },
    {
        "school": "Quartzite Learning",
        "district": "Chewelah School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530126002687",
    },
    {
        "school": "Columbia High And Elementary",
        "district": "Columbia (Stevens) School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530156000278",
    },
    {
        "school": "Colville Senior High School",
        "district": "Colville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530163000282",
    },
    {
        "school": "Colville Junior High School",
        "district": "Colville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530163000283",
    },
    {
        "school": "Hofstetter Elementary",
        "district": "Colville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530163000284",
    },
    {
        "school": "Fort Colville Elementary",
        "district": "Colville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530163001898",
    },
    {
        "school": "Evergreen School",
        "district": "Evergreen School District (Stevens)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530273000429",
    },
    {
        "school": "Kettle Falls Elementary School",
        "district": "Kettle Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530399000637",
    },
    {
        "school": "Kettle Falls Middle School",
        "district": "Kettle Falls School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530399001904",
    },
    {
        "school": "Kettle Falls High School",
        "district": "Kettle Falls School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530399001967",
    },
    {
        "school": "Loon Lake Elementary School",
        "district": "Loon Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530450000712",
    },
    {
        "school": "Mary Walker High School",
        "district": "Mary Walker School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530483000730",
    },
    {
        "school": "Springdale Elementary",
        "district": "Mary Walker School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530483000731",
    },
    {
        "school": "Springdale Middle School",
        "district": "Mary Walker School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530483000732",
    },
    {
        "school": "Northport Elementary School",
        "district": "Northport School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530588000873",
    },
    {
        "school": "Northport High School",
        "district": "Northport School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530588000874",
    },
    {
        "school": "Onion Creek Elementary",
        "district": "Onion Creek School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530627000943",
    },
    {
        "school": "Summit Valley School",
        "district": "Summit Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530858001203",
    },
    {
        "school": "Valley School",
        "district": "Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530924001555",
    },
    {
        "school": "Wellpinit High School",
        "district": "Wellpinit School District #49",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530963001629",
    },
    {
        "school": "Julius A Wendt Elementary/John C Thomas Middle School",
        "district": "Wahkiakum School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530933001593",
    },
    {
        "school": "Wahkiakum High School",
        "district": "Wahkiakum School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530933001594",
    },
    {
        "school": "Taholah Elementary & Middle School",
        "district": "Taholah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530873002956",
    },
    {
        "school": "A J West Elementary",
        "district": "Aberdeen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530003000001",
    },
    {
        "school": "Harbor High School",
        "district": "Aberdeen School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530003000002",
    },
    {
        "school": "Central Park Elementary",
        "district": "Aberdeen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530003000005",
    },
    {
        "school": "J M Weatherwax High School",
        "district": "Aberdeen School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530003000007",
    },
    {
        "school": "McDermoth Elementary",
        "district": "Aberdeen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530003000008",
    },
    {
        "school": "Miller Junior High",
        "district": "Aberdeen School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530003000009",
    },
    {
        "school": "Robert Gray Elementary",
        "district": "Aberdeen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530003000010",
    },
    {
        "school": "Stevens Elementary School",
        "district": "Aberdeen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530003000011",
    },
    {
        "school": "Grays Harbor Juvenile Detention",
        "district": "Aberdeen School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530003002055",
    },
    {
        "school": "Hopkins Elementary",
        "district": "Aberdeen School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530003002271",
    },
    {
        "school": "Cosmopolis Elementary School",
        "district": "Cosmopolis School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530171000288",
    },
    {
        "school": "Elma Elementary School",
        "district": "Elma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530249000371",
    },
    {
        "school": "Elma High School",
        "district": "Elma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530249000372",
    },
    {
        "school": "East Grays Harbor High School",
        "district": "Elma School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530249001298",
    },
    {
        "school": "Elma Middle School",
        "district": "Elma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530249002060",
    },
    {
        "school": "Central Elementary School",
        "district": "Hoquiam School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530366000562",
    },
    {
        "school": "Hoquiam High School",
        "district": "Hoquiam School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530366000564",
    },
    {
        "school": "Hoquiam Middle School",
        "district": "Hoquiam School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530366000565",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Hoquiam School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530366000566",
    },
    {
        "school": "Emerson Elementary",
        "district": "Hoquiam School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530366002105",
    },
    {
        "school": "Mccleary Elem",
        "district": "McCleary School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530489000742",
    },
    {
        "school": "Beacon Avenue Elementary School",
        "district": "Montesano School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530516000779",
    },
    {
        "school": "Montesano Jr-Sr High",
        "district": "Montesano School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530516000780",
    },
    {
        "school": "Simpson Avenue Elementary",
        "district": "Montesano School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530516000781",
    },
    {
        "school": "North Beach Senior High School",
        "district": "North Beach School District No. 64",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530570000842",
    },
    {
        "school": "Ocean Shores Elementary",
        "district": "North Beach School District No. 64",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530570000844",
    },
    {
        "school": "Pacific Beach Elementary School",
        "district": "North Beach School District No. 64",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530570000845",
    },
    {
        "school": "North Beach Junior High School",
        "district": "North Beach School District No. 64",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530570002039",
    },
    {
        "school": "North River School",
        "district": "North River School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530582000861",
    },
    {
        "school": "Oakville High School",
        "district": "Oakville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530600000909",
    },
    {
        "school": "Oakville Elementary",
        "district": "Oakville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530600001858",
    },
    {
        "school": "Ocosta Elementary School",
        "district": "Ocosta School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530609000913",
    },
    {
        "school": "Ocosta Junior - Senior High",
        "district": "Ocosta School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530609000914",
    },
    {
        "school": "Lake Quinault School",
        "district": "Lake Quinault School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530705001050",
    },
    {
        "school": "Satsop Elementary",
        "district": "Satsop School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530768001126",
    },
    {
        "school": "Taholah High School",
        "district": "Taholah School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530873001514",
    },
    {
        "school": "Wishkah Valley Elementary/High School",
        "district": "Wishkah Valley School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530999001679",
    },
    {
        "school": "Northern Heights Elementary Schl",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042002939",
    },
    {
        "school": "Blaine Home Connections",
        "district": "Blaine School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530057003020",
    },
    {
        "school": "Lynden Special Services",
        "district": "Lynden School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530462002903",
    },
    {
        "school": "Lynden Academy",
        "district": "Lynden School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530462003022",
    },
    {
        "school": "Educational Resource Center",
        "district": "Mount Baker School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530531003025",
    },
    {
        "school": "Alderwood Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000098",
    },
    {
        "school": "Bellingham High School",
        "district": "Bellingham School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000099",
    },
    {
        "school": "Birchwood Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000100",
    },
    {
        "school": "Carl Cozier Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000101",
    },
    {
        "school": "Columbia Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000103",
    },
    {
        "school": "Fairhaven Middle School",
        "district": "Bellingham School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000104",
    },
    {
        "school": "Geneva Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000105",
    },
    {
        "school": "Happy Valley Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000106",
    },
    {
        "school": "Lowell Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000108",
    },
    {
        "school": "Parkview Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000110",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000112",
    },
    {
        "school": "Sehome High School",
        "district": "Bellingham School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000113",
    },
    {
        "school": "Shuksan Middle School",
        "district": "Bellingham School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000114",
    },
    {
        "school": "Silver Beach Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000115",
    },
    {
        "school": "Sunnyland Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000116",
    },
    {
        "school": "Whatcom Middle School",
        "district": "Bellingham School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042000117",
    },
    {
        "school": "Options High School",
        "district": "Bellingham School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530042001738",
    },
    {
        "school": "Kulshan Middle School",
        "district": "Bellingham School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042001739",
    },
    {
        "school": "Squalicum High School",
        "district": "Bellingham School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042002693",
    },
    {
        "school": "Visions (Seamar Youth Center)",
        "district": "Bellingham School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530042002774",
    },
    {
        "school": "Blaine Elementary School",
        "district": "Blaine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530057000130",
    },
    {
        "school": "Blaine Middle School",
        "district": "Blaine School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530057000131",
    },
    {
        "school": "Blaine High School",
        "district": "Blaine School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530057000132",
    },
    {
        "school": "Point Roberts Primary",
        "district": "Blaine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530057001740",
    },
    {
        "school": "Blaine Primary School",
        "district": "Blaine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530057001741",
    },
    {
        "school": "Beach Elem",
        "district": "Ferndale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530285000457",
    },
    {
        "school": "Central Elementary",
        "district": "Ferndale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530285000458",
    },
    {
        "school": "Custer Elem",
        "district": "Ferndale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530285000459",
    },
    {
        "school": "Ferndale High School",
        "district": "Ferndale School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530285000460",
    },
    {
        "school": "Vista Middle School",
        "district": "Ferndale School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530285000463",
    },
    {
        "school": "Skyline Elementary School",
        "district": "Ferndale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530285001768",
    },
    {
        "school": "Eagleridge Elementary",
        "district": "Ferndale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530285002495",
    },
    {
        "school": "Horizon Middle School",
        "district": "Ferndale School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530285002832",
    },
    {
        "school": "Fisher Elementary School",
        "district": "Lynden School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530462000720",
    },
    {
        "school": "Lynden Middle School",
        "district": "Lynden School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530462000721",
    },
    {
        "school": "Lynden High School",
        "district": "Lynden School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530462002259",
    },
    {
        "school": "Isom Elementary School",
        "district": "Lynden School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530462002260",
    },
    {
        "school": "Vossbeck Elementary School",
        "district": "Lynden School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530462002605",
    },
    {
        "school": "Irene Reither Elementary School",
        "district": "Meridian School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530501000766",
    },
    {
        "school": "Meridian Middle School",
        "district": "Meridian School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530501000767",
    },
    {
        "school": "Meridian High School",
        "district": "Meridian School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530501000768",
    },
    {
        "school": "Meridian Special Programs",
        "district": "Meridian School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530501002697",
    },
    {
        "school": "Acme Elementary",
        "district": "Mount Baker School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530531000799",
    },
    {
        "school": "Harmony Elementary",
        "district": "Mount Baker School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530531000801",
    },
    {
        "school": "Mount Baker Senior High",
        "district": "Mount Baker School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530531000803",
    },
    {
        "school": "Mount Baker Junior High",
        "district": "Mount Baker School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530531002608",
    },
    {
        "school": "Kendall Elementary",
        "district": "Mount Baker School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530531002776",
    },
    {
        "school": "Nooksack Valley Middle School",
        "district": "Nooksack Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530567000838",
    },
    {
        "school": "Nooksack Valley High School",
        "district": "Nooksack Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530567000839",
    },
    {
        "school": "Sumas Elementary",
        "district": "Nooksack Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530567000840",
    },
    {
        "school": "Everson Elementary",
        "district": "Nooksack Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530567001220",
    },
    {
        "school": "Nooksack Elementary",
        "district": "Nooksack Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530567002699",
    },
    {
        "school": "Nooksack Valley Special Services",
        "district": "Nooksack Valley School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530567002775",
    },
    {
        "school": "Kingston High School",
        "district": "North Kitsap School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530576003201",
    },
    {
        "school": "Clallam Co Juvenile Detention",
        "district": "Olympic Educational Service District 114",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000702914",
    },
    {
        "school": "Kitsap Co Detention Ctr",
        "district": "Olympic Educational Service District 114",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000702927",
    },
    {
        "school": "Eagle Harbor High School",
        "district": "Bainbridge Island School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530033003110",
    },
    {
        "school": "Bainbridge Special Education Services",
        "district": "Bainbridge Island School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530033003113",
    },
    {
        "school": "Bainbridge High School",
        "district": "Bainbridge Island School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033000043",
    },
    {
        "school": "Capt. Charles Wilkes Elem School",
        "district": "Bainbridge Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033000044",
    },
    {
        "school": "Capt Johnston Blakely Elem Sch",
        "district": "Bainbridge Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033000045",
    },
    {
        "school": "Ordway Elementary",
        "district": "Bainbridge Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033000047",
    },
    {
        "school": "Woodward Middle School",
        "district": "Bainbridge Island School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033002452",
    },
    {
        "school": "Odyssey Multiage Program",
        "district": "Bainbridge Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033002523",
    },
    {
        "school": "Sakai Intermediate",
        "district": "Bainbridge Island School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033002734",
    },
    {
        "school": "Mosaic Home Education Partnership",
        "district": "Bainbridge Island School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530033002802",
    },
    {
        "school": "Armin Jahr Elementary",
        "district": "Bremerton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530066000135",
    },
    {
        "school": "Crownhill Elementary School",
        "district": "Bremerton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530066000137",
    },
    {
        "school": "Bremerton High School",
        "district": "Bremerton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530066000139",
    },
    {
        "school": "Naval Avenue Elementary School",
        "district": "Bremerton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530066000143",
    },
    {
        "school": "West Hills S.T.E.M. Academy",
        "district": "Bremerton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530066000144",
    },
    {
        "school": "View Ridge Elementary Arts Academy",
        "district": "Bremerton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530066000146",
    },
    {
        "school": "Kitsap Lake Elementary",
        "district": "Bremerton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530066000708",
    },
    {
        "school": "Mountain View Middle School",
        "district": "Bremerton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530066001144",
    },
    {
        "school": "Morgan Center School",
        "district": "Bremerton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530066001751",
    },
    {
        "school": "West Sound Technical Skills Center",
        "district": "Bremerton School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530066002081",
    },
    {
        "school": "Renaissance Alternative High School",
        "district": "Bremerton School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530066002573",
    },
    {
        "school": "Bremerton Home Link Program",
        "district": "Bremerton School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530066002652",
    },
    {
        "school": "Brownsville Elementary",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108000176",
    },
    {
        "school": "Central Kitsap High School",
        "district": "Central Kitsap School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108000177",
    },
    {
        "school": "Central Kitsap Middle School",
        "district": "Central Kitsap School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108000178",
    },
    {
        "school": "Clear Creek Elementary School",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108000180",
    },
    {
        "school": "Cottonwood Elementary School",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108000181",
    },
    {
        "school": "Esquire Hills Elementary",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108000182",
    },
    {
        "school": "Fairview Middle School",
        "district": "Central Kitsap School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108000183",
    },
    {
        "school": "John D. Bud Hawk Elementary at Jackson Park",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108000184",
    },
    {
        "school": "Green Mountain Elementary",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108000530",
    },
    {
        "school": "Emerald Heights Elementary",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108000757",
    },
    {
        "school": "Woodlands Elementary",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108001752",
    },
    {
        "school": "Olympic High School",
        "district": "Central Kitsap School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108001753",
    },
    {
        "school": "Silverdale Elementary",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108001754",
    },
    {
        "school": "Ridgetop Middle School",
        "district": "Central Kitsap School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108002056",
    },
    {
        "school": "Cougar Valley Elementary",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108002251",
    },
    {
        "school": "Silver Ridge Elementary",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108002287",
    },
    {
        "school": "Klahowya Secondary",
        "district": "Central Kitsap School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108002524",
    },
    {
        "school": "Pinecrest Elementary",
        "district": "Central Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530108002655",
    },
    {
        "school": "Poulsbo Middle School",
        "district": "North Kitsap School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530576000851",
    },
    {
        "school": "North Kitsap High School",
        "district": "North Kitsap School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530576000852",
    },
    {
        "school": "Hilder Pearson Elementary",
        "district": "North Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530576000853",
    },
    {
        "school": "Poulsbo Elementary School",
        "district": "North Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530576000854",
    },
    {
        "school": "Suquamish Elementary School",
        "district": "North Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530576000855",
    },
    {
        "school": "David Wolfle Elementary",
        "district": "North Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530576000856",
    },
    {
        "school": "Vinland Elementary",
        "district": "North Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530576001626",
    },
    {
        "school": "Richard Gordon Elementary",
        "district": "North Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530576001627",
    },
    {
        "school": "Kingston Middle School",
        "district": "North Kitsap School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530576002324",
    },
    {
        "school": "Special Programs",
        "district": "North Kitsap School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530576002453",
    },
    {
        "school": "Pal Program",
        "district": "North Kitsap School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530576002653",
    },
    {
        "school": "Middle School Options",
        "district": "North Kitsap School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530576002654",
    },
    {
        "school": "Burley Glenwood Elementary",
        "district": "South Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816001345",
    },
    {
        "school": "Cedar Heights Middle School",
        "district": "South Kitsap School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816001346",
    },
    {
        "school": "East Port Orchard Elementary",
        "district": "South Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816001347",
    },
    {
        "school": "Manchester Elementary School",
        "district": "South Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816001350",
    },
    {
        "school": "Marcus Whitman Middle School",
        "district": "South Kitsap School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816001351",
    },
    {
        "school": "Olalla Elementary School",
        "district": "South Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816001352",
    },
    {
        "school": "Orchard Heights Elementary",
        "district": "South Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816001353",
    },
    {
        "school": "Discovery",
        "district": "South Kitsap School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530816001355",
    },
    {
        "school": "South Colby Elementary",
        "district": "South Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816001356",
    },
    {
        "school": "South Kitsap High School",
        "district": "South Kitsap School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816001357",
    },
    {
        "school": "Sunnyslope Elementary School",
        "district": "South Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816001803",
    },
    {
        "school": "John Sedgwick Middle School",
        "district": "South Kitsap School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816001877",
    },
    {
        "school": "Hidden Creek Elementary School",
        "district": "South Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816002357",
    },
    {
        "school": "Mullenix Ridge Elementary School",
        "district": "South Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816002359",
    },
    {
        "school": "Sidney Glen Elementary School",
        "district": "South Kitsap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816002360",
    },
    {
        "school": "Explorer Academy",
        "district": "South Kitsap School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530816002575",
    },
    {
        "school": "Lewis County Juvenile Detention",
        "district": "Chehalis School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530117002883",
    },
    {
        "school": "Trojan Alternative School",
        "district": "Pe Ell School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530666003100",
    },
    {
        "school": "Adna Elementary School",
        "district": "Adna School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530006000012",
    },
    {
        "school": "Adna Middle/High School",
        "district": "Adna School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530006000013",
    },
    {
        "school": "Boistfort Elem",
        "district": "Boistfort School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530063000133",
    },
    {
        "school": "Centralia Middle School",
        "district": "Centralia School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530114000205",
    },
    {
        "school": "Centralia High School",
        "district": "Centralia School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530114000206",
    },
    {
        "school": "Edison Elementary",
        "district": "Centralia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530114000207",
    },
    {
        "school": "Fords Prairie Elementary",
        "district": "Centralia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530114000208",
    },
    {
        "school": "Jefferson Lincoln Elementary",
        "district": "Centralia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530114000209",
    },
    {
        "school": "Oakview Elementary School",
        "district": "Centralia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530114000210",
    },
    {
        "school": "Washington Elementary School",
        "district": "Centralia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530114000211",
    },
    {
        "school": "Green Hill Academic School",
        "district": "Chehalis School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530117000213",
    },
    {
        "school": "W F West High School",
        "district": "Chehalis School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530117000217",
    },
    {
        "school": "Chehalis Middle School",
        "district": "Chehalis School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530117002252",
    },
    {
        "school": "Evaline Elementary School",
        "district": "Evaline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530264000390",
    },
    {
        "school": "Morton Elementary School",
        "district": "Morton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530519000783",
    },
    {
        "school": "Morton Junior-Senior High",
        "district": "Morton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530519000784",
    },
    {
        "school": "Mossyrock Elementary School",
        "district": "Mossyrock School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530525000795",
    },
    {
        "school": "Mossyrock Jr./Sr. High School",
        "district": "Mossyrock School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530525000796",
    },
    {
        "school": "Napavine Elementary",
        "district": "Napavine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530549000826",
    },
    {
        "school": "Napavine Jr Sr High School",
        "district": "Napavine School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530549000827",
    },
    {
        "school": "Onalaska Elementary School",
        "district": "Onalaska School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530624000941",
    },
    {
        "school": "Onalaska High School",
        "district": "Onalaska School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530624000942",
    },
    {
        "school": "Pe Ell School",
        "district": "Pe Ell School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530666000977",
    },
    {
        "school": "Toledo Elementary School",
        "district": "Toledo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530891001526",
    },
    {
        "school": "Toledo High School",
        "district": "Toledo School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530891001527",
    },
    {
        "school": "Toledo Middle School",
        "district": "Toledo School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530891001528",
    },
    {
        "school": "White Pass Elementary School",
        "district": "White Pass School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530975001658",
    },
    {
        "school": "White Pass Jr. Sr. High School",
        "district": "White Pass School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530975001659",
    },
    {
        "school": "Winlock Senior High",
        "district": "Winlock School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530993001676",
    },
    {
        "school": "Winlock Miller Elementary",
        "district": "Winlock School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530993001677",
    },
    {
        "school": "Winlock Middle School",
        "district": "Winlock School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530993002392",
    },
    {
        "school": "Winolequa Learning Academy",
        "district": "Winlock School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530993002804",
    },
    {
        "school": "Swiftwater Learning Center",
        "district": "Cle Elum-Roslyn School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530135002987",
    },
    {
        "school": "Ellensburg Developmental Preschool",
        "district": "Ellensburg School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530246003099",
    },
    {
        "school": "K-12 Ellensburg Learning Center",
        "district": "Ellensburg School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530246003168",
    },
    {
        "school": "Parke Creek Treatment Ctr",
        "district": "Kittitas School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530405002916",
    },
    {
        "school": "Cle Elum Roslyn High School",
        "district": "Cle Elum-Roslyn School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530135000240",
    },
    {
        "school": "Cle Elum Roslyn Elementary",
        "district": "Cle Elum-Roslyn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530135000241",
    },
    {
        "school": "Walter Strom Middle School",
        "district": "Cle Elum-Roslyn School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530135000242",
    },
    {
        "school": "Damman Elementary",
        "district": "Damman School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530195000299",
    },
    {
        "school": "Easton School",
        "district": "Easton School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530234000324",
    },
    {
        "school": "Ellensburg High School",
        "district": "Ellensburg School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530246000365",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Ellensburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530246000366",
    },
    {
        "school": "Morgan Middle School",
        "district": "Ellensburg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530246000367",
    },
    {
        "school": "Mt. Stuart Elementary",
        "district": "Ellensburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530246000368",
    },
    {
        "school": "Valley View Elementary School",
        "district": "Ellensburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530246000688",
    },
    {
        "school": "Kittitas Elementary School",
        "district": "Kittitas School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530405000642",
    },
    {
        "school": "Kittitas High School",
        "district": "Kittitas School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530405000643",
    },
    {
        "school": "Thorp Elem & Jr Sr High",
        "district": "Thorp School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530885001525",
    },
    {
        "school": "Mid-Columbia Parent Partnership",
        "district": "Kennewick School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530393003115",
    },
    {
        "school": "Twin Rivers Group Home",
        "district": "Richland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732002925",
    },
    {
        "school": "Special Programs",
        "district": "Richland School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530732002941",
    },
    {
        "school": "White Bluffs Elementary School",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732003171",
    },
    {
        "school": "Ellen Ochoa Middle School",
        "district": "Pasco School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657002936",
    },
    {
        "school": "Maya Angelou Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657002950",
    },
    {
        "school": "Virgie Robinson Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657002951",
    },
    {
        "school": "Pasco Early Childhood",
        "district": "Pasco School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657003143",
    },
    {
        "school": "Walla Walla County Juvenile Detention",
        "district": "Educational Service District 123",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530001202920",
    },
    {
        "school": "Finley Elementary",
        "district": "Finley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530291000468",
    },
    {
        "school": "River View High School",
        "district": "Finley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530291000469",
    },
    {
        "school": "Finley Middle School",
        "district": "Finley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530291002100",
    },
    {
        "school": "Canyon View Elementary School",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000597",
    },
    {
        "school": "Desert Hills Middle School",
        "district": "Kennewick School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000598",
    },
    {
        "school": "Eastgate Elementary School",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000599",
    },
    {
        "school": "Edison Elementary School - Kennewick",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000600",
    },
    {
        "school": "Hawthorne Elementary School - Kennewick",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000602",
    },
    {
        "school": "Highlands Middle School",
        "district": "Kennewick School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000603",
    },
    {
        "school": "Kamiakin High School",
        "district": "Kennewick School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000604",
    },
    {
        "school": "Kennewick High School",
        "district": "Kennewick School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000605",
    },
    {
        "school": "Park Middle School",
        "district": "Kennewick School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000607",
    },
    {
        "school": "Southgate Elementary School",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000608",
    },
    {
        "school": "Vista Elementary School",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000609",
    },
    {
        "school": "Washington Elementary School",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000610",
    },
    {
        "school": "Westgate Elementary School",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000611",
    },
    {
        "school": "Amistad Elementary School",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000701",
    },
    {
        "school": "Horse Heaven Hills Middle School",
        "district": "Kennewick School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000750",
    },
    {
        "school": "Ridge View Elementary School",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393000762",
    },
    {
        "school": "Sunset View Elementary School",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393001774",
    },
    {
        "school": "Cascade Elementary School",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393001839",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393001903",
    },
    {
        "school": "Southridge High School",
        "district": "Kennewick School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393002009",
    },
    {
        "school": "Keewaydin Discovery Center",
        "district": "Kennewick School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393002109",
    },
    {
        "school": "Tri-Tech Skills Center",
        "district": "Kennewick School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530393002110",
    },
    {
        "school": "Benton/Franklin Juvenile Justice Center",
        "district": "Kennewick School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393002546",
    },
    {
        "school": "Kiona-Benton City High School",
        "district": "Kiona-Benton City School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530402000639",
    },
    {
        "school": "Kiona-Benton City Middle School",
        "district": "Kiona-Benton City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530402000640",
    },
    {
        "school": "Kiona-Benton City Primary School",
        "district": "Kiona-Benton City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530402000641",
    },
    {
        "school": "Paterson Elementary School",
        "district": "Paterson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530663000976",
    },
    {
        "school": "Prosser Heights Elementary",
        "district": "Prosser School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530690001011",
    },
    {
        "school": "Prosser High School",
        "district": "Prosser School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530690001012",
    },
    {
        "school": "Housel Middle School",
        "district": "Prosser School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530690001013",
    },
    {
        "school": "Keene-Riverview Elementary",
        "district": "Prosser School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530690001014",
    },
    {
        "school": "Whitstran Elementary",
        "district": "Prosser School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530690001015",
    },
    {
        "school": "Badger Mountain Elementary",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732001090",
    },
    {
        "school": "Carmichael Middle School",
        "district": "Richland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732001091",
    },
    {
        "school": "Richland High School",
        "district": "Richland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732001093",
    },
    {
        "school": "Hanford High School",
        "district": "Richland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732001095",
    },
    {
        "school": "Jason Lee Elementary School",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732001096",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732001097",
    },
    {
        "school": "Lewis & Clark Elementary School",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732001098",
    },
    {
        "school": "Marcus Whitman Elementary",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732001099",
    },
    {
        "school": "Sacajawea Elementary",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732001101",
    },
    {
        "school": "Tapteal Elementary School",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732001103",
    },
    {
        "school": "Chief Joseph Middle School",
        "district": "Richland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732001250",
    },
    {
        "school": "Rivers Edge High School",
        "district": "Richland School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530732002229",
    },
    {
        "school": "Enterprise Middle School",
        "district": "Richland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732002504",
    },
    {
        "school": "William Wiley Elementary School",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732002704",
    },
    {
        "school": "Kahlotus Elem & High",
        "district": "Kahlotus School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530378000583",
    },
    {
        "school": "Basin City Elem",
        "district": "North Franklin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530573000846",
    },
    {
        "school": "Connell Elem",
        "district": "North Franklin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530573000847",
    },
    {
        "school": "Connell High School",
        "district": "North Franklin School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530573000848",
    },
    {
        "school": "Mesa Elem",
        "district": "North Franklin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530573000849",
    },
    {
        "school": "Robert L Olds Junior High School",
        "district": "North Franklin School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530573000850",
    },
    {
        "school": "Palouse Junction High School",
        "district": "North Franklin School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530573002622",
    },
    {
        "school": "Edwin Markham Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657000963",
    },
    {
        "school": "Emerson Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657000964",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657000965",
    },
    {
        "school": "Mark Twain Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657000966",
    },
    {
        "school": "Mcloughlin Middle School",
        "district": "Pasco School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657000967",
    },
    {
        "school": "New Horizons High School",
        "district": "Pasco School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530657000968",
    },
    {
        "school": "Pasco Senior High School",
        "district": "Pasco School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657000969",
    },
    {
        "school": "Robert Frost Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657000970",
    },
    {
        "school": "Ruth Livingston Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657000971",
    },
    {
        "school": "Stevens Middle School",
        "district": "Pasco School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657000973",
    },
    {
        "school": "James McGee Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657001860",
    },
    {
        "school": "Whittier Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657002621",
    },
    {
        "school": "Rowena Chess Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657002785",
    },
    {
        "school": "Star Elem School",
        "district": "Star School District No. 054",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530837001426",
    },
    {
        "school": "Asotin Elementary",
        "district": "Asotin-Anatone School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530028000027",
    },
    {
        "school": "Asotin Jr Sr High",
        "district": "Asotin-Anatone School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530028000028",
    },
    {
        "school": "Charles Francis Adams High School",
        "district": "Clarkston School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530132000234",
    },
    {
        "school": "Grantham Elementary",
        "district": "Clarkston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530132000235",
    },
    {
        "school": "Highland Elementary",
        "district": "Clarkston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530132000236",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Clarkston School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530132000237",
    },
    {
        "school": "Parkway Elementary",
        "district": "Clarkston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530132000238",
    },
    {
        "school": "Educational Opportunity Center",
        "district": "Clarkston School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530132000990",
    },
    {
        "school": "Heights Elementary",
        "district": "Clarkston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530132002433",
    },
    {
        "school": "Special Services",
        "district": "Clarkston School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530132002613",
    },
    {
        "school": "Loowit High School",
        "district": "Kelso School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530000303109",
    },
    {
        "school": "Mt. Solo Middle School",
        "district": "Longview School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447002947",
    },
    {
        "school": "Carrolls Elementary",
        "district": "Kelso School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000300167",
    },
    {
        "school": "Barnes Elementary",
        "district": "Kelso School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000300587",
    },
    {
        "school": "Beacon Hill Elementary",
        "district": "Kelso School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000300588",
    },
    {
        "school": "Butler Acres Elementary",
        "district": "Kelso School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000300589",
    },
    {
        "school": "Catlin Elementary",
        "district": "Kelso School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000300590",
    },
    {
        "school": "Coweeman Middle School",
        "district": "Kelso School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000300591",
    },
    {
        "school": "Huntington Middle School",
        "district": "Kelso School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000300592",
    },
    {
        "school": "Kelso High School",
        "district": "Kelso School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000300593",
    },
    {
        "school": "Rose Valley Elementary",
        "district": "Kelso School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000300594",
    },
    {
        "school": "Wallace Elementary",
        "district": "Kelso School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000300596",
    },
    {
        "school": "Castle Rock Elementary",
        "district": "Castle Rock School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530099000171",
    },
    {
        "school": "Castle Rock High School",
        "district": "Castle Rock School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530099000172",
    },
    {
        "school": "Castle Rock Middle School",
        "district": "Castle Rock School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530099000173",
    },
    {
        "school": "Kalama Elem School",
        "district": "Kalama School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530381000584",
    },
    {
        "school": "Kalama Middle School",
        "district": "Kalama School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530381000585",
    },
    {
        "school": "Cascade Middle School",
        "district": "Longview School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447000699",
    },
    {
        "school": "Columbia Heights Elementary",
        "district": "Longview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447000700",
    },
    {
        "school": "Kessler Elementary School",
        "district": "Longview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447000702",
    },
    {
        "school": "Mark Morris High School",
        "district": "Longview School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447000703",
    },
    {
        "school": "Mint Valley Elementary",
        "district": "Longview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447000704",
    },
    {
        "school": "Monticello Middle School",
        "district": "Longview School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447000705",
    },
    {
        "school": "Olympic Elementary School",
        "district": "Longview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447000707",
    },
    {
        "school": "R A Long High School",
        "district": "Longview School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447000709",
    },
    {
        "school": "Robert Gray Elementary",
        "district": "Longview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447000710",
    },
    {
        "school": "Saint Helens Elementary",
        "district": "Longview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447000711",
    },
    {
        "school": "Columbia Valley Garden Elem Schl",
        "district": "Longview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447001845",
    },
    {
        "school": "Longview School District Special Services",
        "district": "Longview School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530447002118",
    },
    {
        "school": "Broadway Learning Center",
        "district": "Longview School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530447002217",
    },
    {
        "school": "Northlake Elementary School",
        "district": "Longview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530447002314",
    },
    {
        "school": "Toutle Lake High School",
        "district": "Toutle Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530903001538",
    },
    {
        "school": "Toutle Lake Elementary",
        "district": "Toutle Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530903002069",
    },
    {
        "school": "Woodland High School",
        "district": "Woodland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531005001682",
    },
    {
        "school": "Yale Elementary",
        "district": "Woodland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531005001684",
    },
    {
        "school": "TEAM High School",
        "district": "Woodland School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "531005002713",
    },
    {
        "school": "Beezley Springs Elementary",
        "district": "Ephrata School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530261002934",
    },
    {
        "school": "Okanogan Alternative High School",
        "district": "Okanogan School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530615002991",
    },
    {
        "school": "Quincy Innovation Academy",
        "district": "Quincy School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530708003089",
    },
    {
        "school": "Developmental Pre-School",
        "district": "Wahluke School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530936002952",
    },
    {
        "school": "Okanogan Co Juvenile Detention",
        "district": "Okanogan School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530615002915",
    },
    {
        "school": "Okanogan Middle School",
        "district": "Okanogan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530615003144",
    },
    {
        "school": "Columbia Ridge Elementary",
        "district": "Ephrata School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530261000384",
    },
    {
        "school": "Ephrata High School",
        "district": "Ephrata School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530261000386",
    },
    {
        "school": "Ephrata Middle School",
        "district": "Ephrata School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530261000387",
    },
    {
        "school": "Grant Elementary",
        "district": "Ephrata School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530261000388",
    },
    {
        "school": "Parkway School",
        "district": "Ephrata School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530261002559",
    },
    {
        "school": "Coulee City Elementary",
        "district": "Coulee-Hartline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530344000513",
    },
    {
        "school": "Almira Coulee Hartline High School",
        "district": "Coulee-Hartline School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530344000514",
    },
    {
        "school": "Coulee City MS",
        "district": "Coulee-Hartline School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530344001771",
    },
    {
        "school": "Chief Moses Middle School",
        "district": "Moses Lake School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522000785",
    },
    {
        "school": "Garden Heights Elementary",
        "district": "Moses Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522000787",
    },
    {
        "school": "Knolls Vista Elementary",
        "district": "Moses Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522000788",
    },
    {
        "school": "Lakeview Terrace Elementary",
        "district": "Moses Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522000789",
    },
    {
        "school": "Larson Heights Elementary",
        "district": "Moses Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522000790",
    },
    {
        "school": "Longview Elementary",
        "district": "Moses Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522000791",
    },
    {
        "school": "Moses Lake High School",
        "district": "Moses Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522000792",
    },
    {
        "school": "North Elementary",
        "district": "Moses Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522000793",
    },
    {
        "school": "Peninsula Elementary",
        "district": "Moses Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522000794",
    },
    {
        "school": "Midway Elementary",
        "district": "Moses Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522001982",
    },
    {
        "school": "Frontier Middle School",
        "district": "Moses Lake School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522002625",
    },
    {
        "school": "George Elementary",
        "district": "Quincy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530708001052",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Quincy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530708001053",
    },
    {
        "school": "Pioneer Elementary",
        "district": "Quincy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530708001054",
    },
    {
        "school": "Quincy High School",
        "district": "Quincy School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530708001055",
    },
    {
        "school": "Quincy Middle School",
        "district": "Quincy School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530708001056",
    },
    {
        "school": "Monument Elementary",
        "district": "Quincy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530708002714",
    },
    {
        "school": "Red Rock Elementary",
        "district": "Royal School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530762001122",
    },
    {
        "school": "Royal High School",
        "district": "Royal School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530762001123",
    },
    {
        "school": "Royal Middle School",
        "district": "Royal School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530762001124",
    },
    {
        "school": "Soap Lake Elementary",
        "district": "Soap Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530807001334",
    },
    {
        "school": "Soap Lake Middle & High School",
        "district": "Soap Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530807001335",
    },
    {
        "school": "RISE Academy",
        "district": "Soap Lake School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530807002355",
    },
    {
        "school": "Mattawa Elementary",
        "district": "Wahluke School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530936001595",
    },
    {
        "school": "Morris Schott Elementary",
        "district": "Wahluke School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530936001890",
    },
    {
        "school": "Wahluke High School",
        "district": "Wahluke School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530936002070",
    },
    {
        "school": "Saddle Mountain Elementary",
        "district": "Wahluke School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530936002514",
    },
    {
        "school": "Sentinel Tech Alt School",
        "district": "Wahluke School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530936002787",
    },
    {
        "school": "Warden Elementary",
        "district": "Warden School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530951001618",
    },
    {
        "school": "Warden High School",
        "district": "Warden School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530951001619",
    },
    {
        "school": "Warden Middle School",
        "district": "Warden School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530951001620",
    },
    {
        "school": "Wilson Creek Elementary",
        "district": "Wilson Creek School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530990001674",
    },
    {
        "school": "Wilson Creek High",
        "district": "Wilson Creek School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530990001675",
    },
    {
        "school": "Grainger Elementary",
        "district": "Okanogan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530615000917",
    },
    {
        "school": "Okanogan High School",
        "district": "Okanogan School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530615000920",
    },
    {
        "school": "Skagit County Detention Center",
        "district": "Northwest Educational Service District 189",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000802921",
    },
    {
        "school": "Burlington-Edison Alternative School",
        "district": "Burlington-Edison School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530078003103",
    },
    {
        "school": "Skagit Academy",
        "district": "Mount Vernon School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530540003006",
    },
    {
        "school": "Whatcom Co Detention Center",
        "district": "Northwest Educational Service District 189",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000802923",
    },
    {
        "school": "Anacortes Middle School",
        "district": "Anacortes School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530015000015",
    },
    {
        "school": "Anacortes High School",
        "district": "Anacortes School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530015000016",
    },
    {
        "school": "Fidalgo Elementary",
        "district": "Anacortes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530015000017",
    },
    {
        "school": "Island View Elementary",
        "district": "Anacortes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530015000018",
    },
    {
        "school": "Mount Erie Elementary",
        "district": "Anacortes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530015000019",
    },
    {
        "school": "Whitney Elementary Anacortes",
        "district": "Anacortes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530015000021",
    },
    {
        "school": "Allen Elementary",
        "district": "Burlington-Edison School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530078000154",
    },
    {
        "school": "Burlington Edison High School",
        "district": "Burlington-Edison School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530078000155",
    },
    {
        "school": "Edison Elementary - Burlington/Edison",
        "district": "Burlington-Edison School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530078000156",
    },
    {
        "school": "Lucille Umbarger Elementary",
        "district": "Burlington-Edison School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530078000157",
    },
    {
        "school": "West View Elementary",
        "district": "Burlington-Edison School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530078000159",
    },
    {
        "school": "Bay View Elementary",
        "district": "Burlington-Edison School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530078000689",
    },
    {
        "school": "BECC",
        "district": "Burlington-Edison School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530078001722",
    },
    {
        "school": "Twin Cedars High School",
        "district": "Concrete School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530166000084",
    },
    {
        "school": "Concrete Elementary",
        "district": "Concrete School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530166000285",
    },
    {
        "school": "Concrete High School",
        "district": "Concrete School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530166000286",
    },
    {
        "school": "Conway School",
        "district": "Conway School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530168000287",
    },
    {
        "school": "La Conner Elementary",
        "district": "La Conner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530411000645",
    },
    {
        "school": "La Conner High School",
        "district": "La Conner School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530411000646",
    },
    {
        "school": "La Conner Middle",
        "district": "La Conner School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530411001905",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Mount Vernon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530540000809",
    },
    {
        "school": "La Venture Middle School",
        "district": "Mount Vernon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530540000810",
    },
    {
        "school": "Madison Elementary",
        "district": "Mount Vernon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530540000812",
    },
    {
        "school": "Mount Vernon High School",
        "district": "Mount Vernon School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530540000813",
    },
    {
        "school": "Washington Elementary School",
        "district": "Mount Vernon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530540000814",
    },
    {
        "school": "Mount Vernon Special Ed",
        "district": "Mount Vernon School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530540001724",
    },
    {
        "school": "Centennial Elementary School",
        "district": "Mount Vernon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530540002262",
    },
    {
        "school": "Little Mountain Elementary",
        "district": "Mount Vernon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530540002584",
    },
    {
        "school": "Mount Baker Middle School",
        "district": "Mount Vernon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530540002585",
    },
    {
        "school": "Central Elementary School",
        "district": "Sedro-Woolley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530774000141",
    },
    {
        "school": "Big Lake Elementary School",
        "district": "Sedro-Woolley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530774001272",
    },
    {
        "school": "Cascade Middle School",
        "district": "Sedro-Woolley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530774001273",
    },
    {
        "school": "Clear Lake Elementary School",
        "district": "Sedro-Woolley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530774001274",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Sedro-Woolley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530774001275",
    },
    {
        "school": "Lyman Elementary School",
        "district": "Sedro-Woolley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530774001276",
    },
    {
        "school": "Mary Purcell Elementary School",
        "district": "Sedro-Woolley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530774001277",
    },
    {
        "school": "Samish Elementary School",
        "district": "Sedro-Woolley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530774001278",
    },
    {
        "school": "Sedro Woolley Senior High School",
        "district": "Sedro-Woolley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530774001279",
    },
    {
        "school": "State Street High School",
        "district": "Sedro-Woolley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530774002148",
    },
    {
        "school": "Toddler Learning Center",
        "district": "Coupeville School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530180002957",
    },
    {
        "school": "Coupeville Elementary School",
        "district": "Coupeville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530180000289",
    },
    {
        "school": "Coupeville High School",
        "district": "Coupeville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530180000290",
    },
    {
        "school": "Coupeville Middle School",
        "district": "Coupeville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530180002049",
    },
    {
        "school": "Broadview Elementary",
        "district": "Oak Harbor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530594000898",
    },
    {
        "school": "Crescent Harbor Elem",
        "district": "Oak Harbor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530594000900",
    },
    {
        "school": "North Whidbey Middle School",
        "district": "Oak Harbor School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530594000901",
    },
    {
        "school": "Oak Harbor Elementary",
        "district": "Oak Harbor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530594000902",
    },
    {
        "school": "Oak Harbor High School",
        "district": "Oak Harbor School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530594000903",
    },
    {
        "school": "Oak Harbor Intermediate School",
        "district": "Oak Harbor School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530594000904",
    },
    {
        "school": "Olympic View Elem",
        "district": "Oak Harbor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530594000905",
    },
    {
        "school": "Special Education",
        "district": "Oak Harbor School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530594002047",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Oak Harbor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530594002264",
    },
    {
        "school": "Homeconnection",
        "district": "Oak Harbor School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530594002628",
    },
    {
        "school": "South Whidbey Middle",
        "district": "South Whidbey School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530819001358",
    },
    {
        "school": "South Whidbey High School",
        "district": "South Whidbey School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530819001878",
    },
    {
        "school": "South Whidbey Academy",
        "district": "South Whidbey School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530819002050",
    },
    {
        "school": "South Whidbey Special Services",
        "district": "South Whidbey School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530819002051",
    },
    {
        "school": "South Whidbey Elementary",
        "district": "South Whidbey School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530819002240",
    },
    {
        "school": "Washington State School for the Deaf",
        "district": "Washington Center for Deaf and Hard of Hearing Youth",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530001501016",
    },
    {
        "school": "New Market High School",
        "district": "Tumwater School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530910003017",
    },
    {
        "school": "Lackamas Elementary",
        "district": "Yelm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531014003016",
    },
    {
        "school": "McKenna Elementary",
        "district": "Yelm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531014001714",
    },
    {
        "school": "Griffin School",
        "district": "Griffin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530333000510",
    },
    {
        "school": "Horizons Elementary",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000601",
    },
    {
        "school": "Komachin Middle School",
        "district": "North Thurston Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000606",
    },
    {
        "school": "Chinook Middle School",
        "district": "North Thurston Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000862",
    },
    {
        "school": "Evergreen Forest Elementary",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000863",
    },
    {
        "school": "Lacey Elementary",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000864",
    },
    {
        "school": "Lakes Elementary School",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000865",
    },
    {
        "school": "Lydia Hawk Elementary",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000866",
    },
    {
        "school": "Mountain View Elementary",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000867",
    },
    {
        "school": "Nisqually Middle School",
        "district": "North Thurston Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000868",
    },
    {
        "school": "North Thurston High School",
        "district": "North Thurston Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000869",
    },
    {
        "school": "Olympic View Elementary",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000870",
    },
    {
        "school": "South Bay Elementary",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000871",
    },
    {
        "school": "Timberline High School",
        "district": "North Thurston Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585000872",
    },
    {
        "school": "River Ridge High School",
        "district": "North Thurston Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585001208",
    },
    {
        "school": "Woodland Elementary",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585001857",
    },
    {
        "school": "Meadows Elementary",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585002064",
    },
    {
        "school": "Pleasant Glade Elementary",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585002129",
    },
    {
        "school": "South Sound High School",
        "district": "North Thurston Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530585002130",
    },
    {
        "school": "Seven Oaks Elementary",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585002327",
    },
    {
        "school": "Boston Harbor Elementary",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000922",
    },
    {
        "school": "Capital High School",
        "district": "Olympia School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000923",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000924",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Olympia School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000925",
    },
    {
        "school": "Leland P Brown Elementary",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000927",
    },
    {
        "school": "Madison Elementary School",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000929",
    },
    {
        "school": "McLane Elementary School",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000931",
    },
    {
        "school": "Pioneer Elementary School",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000932",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000934",
    },
    {
        "school": "Washington Middle School",
        "district": "Olympia School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000935",
    },
    {
        "school": "Reeves Middle School",
        "district": "Olympia School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000936",
    },
    {
        "school": "Olympia High School",
        "district": "Olympia School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618000937",
    },
    {
        "school": "McKenny Elementary",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618001210",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618001735",
    },
    {
        "school": "Julia Butler Hansen Elementary",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618001736",
    },
    {
        "school": "Thurgood Marshall Middle School",
        "district": "Olympia School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618001737",
    },
    {
        "school": "Centennial Elementary Olympia",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618002334",
    },
    {
        "school": "Avanti High School",
        "district": "Olympia School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530618002689",
    },
    {
        "school": "Rainier Middle School",
        "district": "Rainier School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530711001057",
    },
    {
        "school": "Rainier Senior High School",
        "district": "Rainier School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530711001058",
    },
    {
        "school": "Rainier Elementary School",
        "district": "Rainier School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530711002537",
    },
    {
        "school": "Grand Mound Elementary",
        "district": "Rochester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530747001116",
    },
    {
        "school": "Rochester Primary School",
        "district": "Rochester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530747001117",
    },
    {
        "school": "Rochester Middle School",
        "district": "Rochester School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530747001118",
    },
    {
        "school": "Rochester High School",
        "district": "Rochester School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530747002267",
    },
    {
        "school": "H.e.a.r.t. High School",
        "district": "Rochester School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530747002830",
    },
    {
        "school": "Tenino High School",
        "district": "Tenino School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530882001522",
    },
    {
        "school": "Tenino Middle School",
        "district": "Tenino School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530882001523",
    },
    {
        "school": "Parkside Elementary",
        "district": "Tenino School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530882001524",
    },
    {
        "school": "Tenino Elementary School",
        "district": "Tenino School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530882002241",
    },
    {
        "school": "Littlerock Elementary School",
        "district": "Tumwater School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530910001541",
    },
    {
        "school": "Michael T Simmons Elementary",
        "district": "Tumwater School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530910001542",
    },
    {
        "school": "Peter G Schmidt Elementary",
        "district": "Tumwater School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530910001543",
    },
    {
        "school": "Tumwater High School",
        "district": "Tumwater School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530910001544",
    },
    {
        "school": "Tumwater Middle School",
        "district": "Tumwater School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530910001545",
    },
    {
        "school": "George Washington Bush Middle Sch",
        "district": "Tumwater School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530910001734",
    },
    {
        "school": "Black Lake Elementary",
        "district": "Tumwater School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530910001889",
    },
    {
        "school": "New Market Skills Center",
        "district": "Tumwater School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530910002186",
    },
    {
        "school": "East Olympia Elementary",
        "district": "Tumwater School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530910002379",
    },
    {
        "school": "Thurs Co Juv Det/Tumwater West E",
        "district": "Tumwater School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530910002380",
    },
    {
        "school": "Tumwater Hill Elementary",
        "district": "Tumwater School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530910002381",
    },
    {
        "school": "A G West Black Hills High School",
        "district": "Tumwater School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530910002602",
    },
    {
        "school": "Secondary Options",
        "district": "Tumwater School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530910002688",
    },
    {
        "school": "Yelm Extension School",
        "district": "Yelm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "531014000134",
    },
    {
        "school": "Mill Pond Elementary School",
        "district": "Yelm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531014001204",
    },
    {
        "school": "Southworth Elementary",
        "district": "Yelm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531014001715",
    },
    {
        "school": "Yelm High School 12",
        "district": "Yelm School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531014001716",
    },
    {
        "school": "Yelm Middle School",
        "district": "Yelm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531014001717",
    },
    {
        "school": "Yelm Prairie Elementary",
        "district": "Yelm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531014001916",
    },
    {
        "school": "Fort Stevens Elementary",
        "district": "Yelm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531014002393",
    },
    {
        "school": "Cape Flattery Preschool",
        "district": "Cape Flattery School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530084003030",
    },
    {
        "school": "Neah Bay Elementary School",
        "district": "Cape Flattery School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530084003042",
    },
    {
        "school": "HomeConnection",
        "district": "Crescent School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530183002942",
    },
    {
        "school": "Special Education",
        "district": "Port Angeles School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530682003096",
    },
    {
        "school": "Clallam Bay High & Elementary",
        "district": "Cape Flattery School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530084000164",
    },
    {
        "school": "Neah Bay Junior/ Senior High School",
        "district": "Cape Flattery School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530084000165",
    },
    {
        "school": "Crescent School",
        "district": "Crescent School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530183000292",
    },
    {
        "school": "Lincoln High School",
        "district": "Port Angeles School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530682000995",
    },
    {
        "school": "Franklin Elementary",
        "district": "Port Angeles School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530682000998",
    },
    {
        "school": "Hamilton Elementary",
        "district": "Port Angeles School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530682000999",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Port Angeles School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530682001000",
    },
    {
        "school": "Port Angeles High School",
        "district": "Port Angeles School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530682001002",
    },
    {
        "school": "Stevens Middle School",
        "district": "Port Angeles School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530682001004",
    },
    {
        "school": "Dry Creek Elementary",
        "district": "Port Angeles School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530682002505",
    },
    {
        "school": "Forks Junior-Senior High School",
        "district": "Quillayute Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530702001047",
    },
    {
        "school": "Forks Elementary School",
        "district": "Quillayute Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530702001048",
    },
    {
        "school": "Forks Alternative School",
        "district": "Quillayute Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530702001260",
    },
    {
        "school": "District Run Home School",
        "district": "Quillayute Valley School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530702002507",
    },
    {
        "school": "Helen Haller Elementary School",
        "district": "Sequim School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530783001288",
    },
    {
        "school": "Sequim Senior High",
        "district": "Sequim School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530783001289",
    },
    {
        "school": "Greywolf Elementary School",
        "district": "Sequim School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530783002427",
    },
    {
        "school": "Olympic Peninsula Academy",
        "district": "Sequim School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530783002552",
    },
    {
        "school": "Sequim Middle School",
        "district": "Sequim School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530783002617",
    },
    {
        "school": "Daybreak Middle",
        "district": "Battle Ground School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038003176",
    },
    {
        "school": "Daybreak Primary",
        "district": "Battle Ground School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038003194",
    },
    {
        "school": "Camas High School",
        "district": "Camas School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081003152",
    },
    {
        "school": "Hayes Freedom High School",
        "district": "Camas School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081003200",
    },
    {
        "school": "Columbia Valley Elementary",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270002946",
    },
    {
        "school": "Home Choice Academy",
        "district": "Evergreen School District (Clark)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530270003101",
    },
    {
        "school": "York Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270003159",
    },
    {
        "school": "Hockinson High School",
        "district": "Hockinson School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530357002938",
    },
    {
        "school": "Vancouver Home Connection",
        "district": "Vancouver School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530927002943",
    },
    {
        "school": "Jefferson Middle School",
        "district": "Vancouver School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927002944",
    },
    {
        "school": "Early Childhood Education Center",
        "district": "Vancouver School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927003147",
    },
    {
        "school": "Washougal Special Services",
        "district": "Washougal School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530954002889",
    },
    {
        "school": "Mill A Elementary School",
        "district": "Mill A School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530504000772",
    },
    {
        "school": "Mount Pleasant School",
        "district": "Mount Pleasant School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530534000804",
    },
    {
        "school": "Skamania Elementary",
        "district": "Skamania School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530795001319",
    },
    {
        "school": "Carson Elementary",
        "district": "Stevenson-Carson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530852001434",
    },
    {
        "school": "Stevenson Elementary",
        "district": "Stevenson-Carson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530852001435",
    },
    {
        "school": "Stevenson High School",
        "district": "Stevenson-Carson School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530852001436",
    },
    {
        "school": "Wind River Middle School",
        "district": "Stevenson-Carson School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530852001437",
    },
    {
        "school": "Preschool",
        "district": "Stevenson-Carson School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530852002668",
    },
    {
        "school": "Amboy Middle School",
        "district": "Battle Ground School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038000048",
    },
    {
        "school": "Battle Ground High School",
        "district": "Battle Ground School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038000049",
    },
    {
        "school": "Glenwood Heights Primary",
        "district": "Battle Ground School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038000051",
    },
    {
        "school": "Laurin Middle School",
        "district": "Battle Ground School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038000052",
    },
    {
        "school": "Pleasant Valley Middle",
        "district": "Battle Ground School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038000054",
    },
    {
        "school": "Pleasant Valley Primary",
        "district": "Battle Ground School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038000055",
    },
    {
        "school": "Yacolt Primary",
        "district": "Battle Ground School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038000056",
    },
    {
        "school": "Summit View High School",
        "district": "Battle Ground School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530038001069",
    },
    {
        "school": "Prairie High School",
        "district": "Battle Ground School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038001747",
    },
    {
        "school": "Preschool Infant Other",
        "district": "Battle Ground School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530038002249",
    },
    {
        "school": "Captain Strong",
        "district": "Battle Ground School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038002278",
    },
    {
        "school": "CAM Academy",
        "district": "Battle Ground School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530038002782",
    },
    {
        "school": "Homelink River",
        "district": "Battle Ground School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530038002857",
    },
    {
        "school": "Lacamas Lake Elementary",
        "district": "Camas School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081000163",
    },
    {
        "school": "Dorothy Fox",
        "district": "Camas School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081001823",
    },
    {
        "school": "Helen Baller Elem",
        "district": "Camas School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081002083",
    },
    {
        "school": "Skyridge Middle School",
        "district": "Camas School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081002512",
    },
    {
        "school": "Prune Hill Elem",
        "district": "Camas School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081002880",
    },
    {
        "school": "Legacy High School",
        "district": "Evergreen School District (Clark)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530270000412",
    },
    {
        "school": "Burton Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000413",
    },
    {
        "school": "Cascade Middle School",
        "district": "Evergreen School District (Clark)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000414",
    },
    {
        "school": "Covington Middle School",
        "district": "Evergreen School District (Clark)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000415",
    },
    {
        "school": "Crestline Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000416",
    },
    {
        "school": "Ellsworth Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000417",
    },
    {
        "school": "Evergreen High School",
        "district": "Evergreen School District (Clark)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000418",
    },
    {
        "school": "Fircrest Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000419",
    },
    {
        "school": "Image Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000420",
    },
    {
        "school": "Marrion Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000421",
    },
    {
        "school": "Mill Plain Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000422",
    },
    {
        "school": "Orchards Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000423",
    },
    {
        "school": "Riverview Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000424",
    },
    {
        "school": "Sifton Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000425",
    },
    {
        "school": "Silver Star Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000426",
    },
    {
        "school": "Sunset Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000427",
    },
    {
        "school": "Wyeast Middle School",
        "district": "Evergreen School District (Clark)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000428",
    },
    {
        "school": "Pioneer Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270000760",
    },
    {
        "school": "49th Street Academy",
        "district": "Evergreen School District (Clark)",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530270001270",
    },
    {
        "school": "Hearthwood Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270001833",
    },
    {
        "school": "Mountain View High School",
        "district": "Evergreen School District (Clark)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270001834",
    },
    {
        "school": "Pacific Middle School",
        "district": "Evergreen School District (Clark)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270001901",
    },
    {
        "school": "Cascadia Technical Academy Skills Center",
        "district": "Evergreen School District (Clark)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530270002097",
    },
    {
        "school": "Burnt Bridge Creek Elementary Sch",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270002211",
    },
    {
        "school": "Early Childhood Center",
        "district": "Evergreen School District (Clark)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530270002299",
    },
    {
        "school": "Harmony Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270002429",
    },
    {
        "school": "Frontier Middle School",
        "district": "Evergreen School District (Clark)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270002510",
    },
    {
        "school": "Fishers Landing Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270002511",
    },
    {
        "school": "Heritage High School",
        "district": "Evergreen School District (Clark)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270002711",
    },
    {
        "school": "Illahee Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270002877",
    },
    {
        "school": "Shahala Middle School",
        "district": "Evergreen School District (Clark)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270002878",
    },
    {
        "school": "Green Mountain School",
        "district": "Green Mountain School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530330000509",
    },
    {
        "school": "Hockinson Middle School",
        "district": "Hockinson School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530357000559",
    },
    {
        "school": "La Center Middle School",
        "district": "La Center School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530417000649",
    },
    {
        "school": "La Center Elementary",
        "district": "La Center School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530417000650",
    },
    {
        "school": "La Center High School",
        "district": "La Center School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530417001049",
    },
    {
        "school": "Ridgefield High School",
        "district": "Ridgefield School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530735001105",
    },
    {
        "school": "South Ridge Elementary",
        "district": "Ridgefield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530735001106",
    },
    {
        "school": "Union Ridge Elementary",
        "district": "Ridgefield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530735001107",
    },
    {
        "school": "View Ridge Middle School",
        "district": "Ridgefield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530735001108",
    },
    {
        "school": "Chinook Elementary School",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927000572",
    },
    {
        "school": "Alki Middle School",
        "district": "Vancouver School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927000578",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927000638",
    },
    {
        "school": "Benjamin Franklin Elementary",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001556",
    },
    {
        "school": "Columbia River High",
        "district": "Vancouver School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001557",
    },
    {
        "school": "Dwight D Eisenhower Elementary",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001558",
    },
    {
        "school": "Felida Elementary School",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001559",
    },
    {
        "school": "Fort Vancouver High School",
        "district": "Vancouver School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001560",
    },
    {
        "school": "Fruit Valley Elementary School",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001561",
    },
    {
        "school": "Gaiser Middle School",
        "district": "Vancouver School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001562",
    },
    {
        "school": "George C Marshall Elementary",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001563",
    },
    {
        "school": "Harney Elementary School",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001564",
    },
    {
        "school": "Harry S Truman Elementary School",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001565",
    },
    {
        "school": "Hazel Dell Elementary School",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001566",
    },
    {
        "school": "Hough Elementary School",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001568",
    },
    {
        "school": "Hudson's Bay High School",
        "district": "Vancouver School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001569",
    },
    {
        "school": "Jason Lee Middle School",
        "district": "Vancouver School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001570",
    },
    {
        "school": "Lake Shore Elementary",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001572",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001575",
    },
    {
        "school": "Martin Luther King Elementary",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001576",
    },
    {
        "school": "Mcloughlin Middle School",
        "district": "Vancouver School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001577",
    },
    {
        "school": "Minnehaha Elementary School",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001578",
    },
    {
        "school": "Lewis and Clark High School",
        "district": "Vancouver School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001579",
    },
    {
        "school": "Peter S Ogden Elementary",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001580",
    },
    {
        "school": "Sacajawea Elementary School",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001581",
    },
    {
        "school": "Salmon Creek Elementary",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001582",
    },
    {
        "school": "Sarah J Anderson Elementary",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001583",
    },
    {
        "school": "Walnut Grove Elementary",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001586",
    },
    {
        "school": "Washington Elementary",
        "district": "Vancouver School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927001587",
    },
    {
        "school": "Discovery Middle School",
        "district": "Vancouver School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927002018",
    },
    {
        "school": "Fir Grove Childrens Center",
        "district": "Vancouver School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530927002408",
    },
    {
        "school": "Vancouver School of Arts and Academics",
        "district": "Vancouver School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927002508",
    },
    {
        "school": "Gate Program",
        "district": "Vancouver School District",
        "level": "High",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530927002554",
    },
    {
        "school": "Skyview High School",
        "district": "Vancouver School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927002555",
    },
    {
        "school": "Hathaway Elementary",
        "district": "Washougal School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530954001622",
    },
    {
        "school": "Gause Elementary",
        "district": "Washougal School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530954001623",
    },
    {
        "school": "Washougal High School",
        "district": "Washougal School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530954001624",
    },
    {
        "school": "Jemtegaard Middle School",
        "district": "Washougal School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530954001892",
    },
    {
        "school": "Cape Horn Skye Elementary",
        "district": "Washougal School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530954001621",
    },
    {
        "school": "Canyon Creek Middle School",
        "district": "Washougal School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530954002709",
    },
    {
        "school": "Garfield at Palouse High School",
        "district": "Garfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530300003135",
    },
    {
        "school": "Palouse at Garfield Middle School",
        "district": "Palouse School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530654003134",
    },
    {
        "school": "Colfax High School",
        "district": "Colfax School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530144000273",
    },
    {
        "school": "Leonard M Jennings Elementary",
        "district": "Colfax School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530144000274",
    },
    {
        "school": "Colton School",
        "district": "Colton School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530150000277",
    },
    {
        "school": "Endicott/St John Elem and Middle",
        "district": "Endicott School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530252000373",
    },
    {
        "school": "Garfield Elementary",
        "district": "Garfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530300000486",
    },
    {
        "school": "Garfield Middle School",
        "district": "Garfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530300000487",
    },
    {
        "school": "Lacrosse Elementary School",
        "district": "LaCrosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530415000647",
    },
    {
        "school": "Lacrosse High School",
        "district": "LaCrosse School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530415000648",
    },
    {
        "school": "Lamont Middle School",
        "district": "Lamont School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530429000687",
    },
    {
        "school": "Oakesdale Elementary School",
        "district": "Oakesdale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530597000907",
    },
    {
        "school": "Oakesdale High School",
        "district": "Oakesdale School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530597000908",
    },
    {
        "school": "Palouse High School",
        "district": "Palouse School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530654000152",
    },
    {
        "school": "Palouse Elementary",
        "district": "Palouse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530654000960",
    },
    {
        "school": "Franklin Elementary",
        "district": "Pullman School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530693001017",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Pullman School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530693001018",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Pullman School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530693001019",
    },
    {
        "school": "Pullman High School",
        "district": "Pullman School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530693001020",
    },
    {
        "school": "Sunnyside Elementary",
        "district": "Pullman School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530693001021",
    },
    {
        "school": "Rosalia Elementary & Secondary School",
        "district": "Rosalia School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530756002422",
    },
    {
        "school": "St John Elementary",
        "district": "St. John School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530831001420",
    },
    {
        "school": "St John/Endicott High",
        "district": "St. John School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530831001421",
    },
    {
        "school": "Steptoe Elementary School",
        "district": "Steptoe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530849001433",
    },
    {
        "school": "Tekoa Elementary School",
        "district": "Tekoa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530879001520",
    },
    {
        "school": "Tekoa High School",
        "district": "Tekoa School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530879001521",
    },
    {
        "school": "Special Ed School",
        "district": "Auburn School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530030002904",
    },
    {
        "school": "Little Cedars Elementary School",
        "district": "Snohomish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802003184",
    },
    {
        "school": "Saratoga School",
        "district": "Stanwood-Camano School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530834003011",
    },
    {
        "school": "Special Ed School",
        "district": "Enumclaw School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530000103038",
    },
    {
        "school": "Auburn Mountainview High School",
        "district": "Auburn School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030002978",
    },
    {
        "school": "Arthur Jacobsen Elementary",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030003174",
    },
    {
        "school": "International School",
        "district": "Bellevue School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530039003149",
    },
    {
        "school": "Support School",
        "district": "Federal Way School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282002961",
    },
    {
        "school": "Sequoyah Middle School",
        "district": "Federal Way School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282002964",
    },
    {
        "school": "Employment Transition Program",
        "district": "Federal Way School District",
        "level": "High",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530282003124",
    },
    {
        "school": "Todd Beamer High School",
        "district": "Federal Way School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282003154",
    },
    {
        "school": "New Start",
        "district": "Highline School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530354002967",
    },
    {
        "school": "Satellite High School",
        "district": "Highline School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530354002968",
    },
    {
        "school": "Head Start",
        "district": "Highline School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354002972",
    },
    {
        "school": "Raisbeck Aviation High School",
        "district": "Highline School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530354002974",
    },
    {
        "school": "Big Picture School",
        "district": "Highline School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530354002976",
    },
    {
        "school": "Newcastle Elementary School",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375002981",
    },
    {
        "school": "Mill Creek Middle School",
        "district": "Kent School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002986",
    },
    {
        "school": "Kent Phoenix Academy",
        "district": "Kent School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530396003178",
    },
    {
        "school": "Stella Schola",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423002983",
    },
    {
        "school": "Woodinville Community Center",
        "district": "Northshore School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591002922",
    },
    {
        "school": "Interagency Detention School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771002928",
    },
    {
        "school": "South Shore PK-8 School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771002933",
    },
    {
        "school": "Private School Services",
        "district": "Seattle School District No. 1",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530771003046",
    },
    {
        "school": "Fircrest Residential Habilitation",
        "district": "Shoreline School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792002912",
    },
    {
        "school": "Cascade K-8 Community School",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792003116",
    },
    {
        "school": "Cascade View Elementary School",
        "district": "Snoqualmie Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530804002980",
    },
    {
        "school": "Summit Trail Middle School",
        "district": "Tahoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530876002979",
    },
    {
        "school": "Student Link",
        "district": "Vashon Island School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530930003112",
    },
    {
        "school": "Graham Kapowsin High School",
        "district": "Bethel School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048003003",
    },
    {
        "school": "Thompson Preschool",
        "district": "Bethel School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048003091",
    },
    {
        "school": "Cougar Mountain Middle School",
        "district": "Bethel School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048003158",
    },
    {
        "school": "Harrison Prep School",
        "district": "Clover Park School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141003000",
    },
    {
        "school": "Columbia Junior High School",
        "district": "Fife School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530288003161",
    },
    {
        "school": "Midland Elementary",
        "district": "Franklin Pierce School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294003145",
    },
    {
        "school": "Orting Special Education",
        "district": "Orting School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530645002999",
    },
    {
        "school": "PSD Special Services",
        "district": "Puyallup School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530696002995",
    },
    {
        "school": "Edgerton Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696003191",
    },
    {
        "school": "Carson Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696003192",
    },
    {
        "school": "Developmental Preschool",
        "district": "Steilacoom Hist. School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530846002994",
    },
    {
        "school": "Bonney Lake High School",
        "district": "Sumner School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861002998",
    },
    {
        "school": "Madison Headstart",
        "district": "Tacoma School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870002997",
    },
    {
        "school": "Alternative Spcl Needs Div Occ",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530870003051",
    },
    {
        "school": "Angelo Giaudrone Middle School",
        "district": "Tacoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870003155",
    },
    {
        "school": "Glacier Middle School",
        "district": "White River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530978003005",
    },
    {
        "school": "White River Special Ed Services",
        "district": "White River School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530978003054",
    },
    {
        "school": "White River High School",
        "district": "White River School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530978003153",
    },
    {
        "school": "Pioneer Elementary",
        "district": "Arlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530024002940",
    },
    {
        "school": "Haller Middle School",
        "district": "Arlington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530024003008",
    },
    {
        "school": "Edmonds Heights K-12",
        "district": "Edmonds School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530240003139",
    },
    {
        "school": "Port Gardner",
        "district": "Everett School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530267002897",
    },
    {
        "school": "Forest View Elementary School",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267003195",
    },
    {
        "school": "Cavelero Mid High School",
        "district": "Lake Stevens School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420003190",
    },
    {
        "school": "Cougar Creek Elementary School",
        "district": "Lakewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530426003156",
    },
    {
        "school": "Marysville SD Special",
        "district": "Marysville School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530486002900",
    },
    {
        "school": "Legacy High School",
        "district": "Marysville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486003102",
    },
    {
        "school": "Fryelands Elementary",
        "district": "Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530513003009",
    },
    {
        "school": "Park Place Middle School",
        "district": "Monroe School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530513003040",
    },
    {
        "school": "ECEAP",
        "district": "Mukilteo School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543003133",
    },
    {
        "school": "Odyssey Elementary",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543003162",
    },
    {
        "school": "Parent Partnership",
        "district": "Snohomish School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530802002894",
    },
    {
        "school": "Utsalady Elementary",
        "district": "Stanwood-Camano School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530834002824",
    },
    {
        "school": "Elger Bay Elementary",
        "district": "Stanwood-Camano School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530834002825",
    },
    {
        "school": "Black Diamond Elementary",
        "district": "Enumclaw School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000100376",
    },
    {
        "school": "Byron Kibler Elementary School",
        "district": "Enumclaw School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000100377",
    },
    {
        "school": "Enumclaw Sr High School",
        "district": "Enumclaw School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000100379",
    },
    {
        "school": "Southwood Elementary School",
        "district": "Enumclaw School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000100382",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Enumclaw School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000100383",
    },
    {
        "school": "Sunrise Elementary",
        "district": "Enumclaw School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000100478",
    },
    {
        "school": "Enumclaw Middle School",
        "district": "Enumclaw School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000102054",
    },
    {
        "school": "Thunder Mountain Middle School",
        "district": "Enumclaw School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000102795",
    },
    {
        "school": "Alpac Elementary School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000029",
    },
    {
        "school": "West Auburn Senior High School",
        "district": "Auburn School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530030000031",
    },
    {
        "school": "Auburn Senior High School",
        "district": "Auburn School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000032",
    },
    {
        "school": "Cascade Middle School",
        "district": "Auburn School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000033",
    },
    {
        "school": "Chinook Elementary School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000034",
    },
    {
        "school": "Evergreen Heights Elementary",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000035",
    },
    {
        "school": "Lea Hill Elementary School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000036",
    },
    {
        "school": "Dick Scobee Elementary School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000037",
    },
    {
        "school": "Olympic Middle School",
        "district": "Auburn School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000038",
    },
    {
        "school": "Pioneer Elementary School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000039",
    },
    {
        "school": "Gildo Rey Elementary School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000040",
    },
    {
        "school": "Terminal Park Elementary School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000041",
    },
    {
        "school": "Washington Elementary School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000042",
    },
    {
        "school": "Ilalko Elementary School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030000698",
    },
    {
        "school": "Mt Baker Middle School",
        "district": "Auburn School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030001443",
    },
    {
        "school": "Lake View Elementary School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030001744",
    },
    {
        "school": "Hazelwood Elementary School",
        "district": "Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030002277",
    },
    {
        "school": "Rainier Middle School",
        "district": "Auburn School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030002434",
    },
    {
        "school": "Auburn Riverside High School",
        "district": "Auburn School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530030002445",
    },
    {
        "school": "Ardmore Elementary School",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000058",
    },
    {
        "school": "Bellevue High School",
        "district": "Bellevue School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000060",
    },
    {
        "school": "Bennett Elementary School",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000062",
    },
    {
        "school": "Cherry Crest Elementary School",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000063",
    },
    {
        "school": "Chinook Middle School",
        "district": "Bellevue School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000064",
    },
    {
        "school": "Clyde Hill Elementary",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000065",
    },
    {
        "school": "Eastgate Elementary School",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000066",
    },
    {
        "school": "Enatai Elementary School",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000067",
    },
    {
        "school": "Highland Middle School",
        "district": "Bellevue School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000068",
    },
    {
        "school": "Interlake Senior High School",
        "district": "Bellevue School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000072",
    },
    {
        "school": "Lake Hills Elementary",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000075",
    },
    {
        "school": "Medina Elementary School",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000076",
    },
    {
        "school": "Newport Heights Elementary",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000077",
    },
    {
        "school": "Newport Senior High School",
        "district": "Bellevue School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000078",
    },
    {
        "school": "Odle Middle School",
        "district": "Bellevue School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000079",
    },
    {
        "school": "Phantom Lake Elementary",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000082",
    },
    {
        "school": "Sammamish Senior High",
        "district": "Bellevue School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000085",
    },
    {
        "school": "Sherwood Forest Elementary",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000086",
    },
    {
        "school": "Somerset Elementary School",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000087",
    },
    {
        "school": "Spiritridge Elementary School",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000088",
    },
    {
        "school": "Stevenson Elementary",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000089",
    },
    {
        "school": "Puesta del Sol Elementary School",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000090",
    },
    {
        "school": "Tillicum Middle School",
        "district": "Bellevue School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000093",
    },
    {
        "school": "Tyee Middle School",
        "district": "Bellevue School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000094",
    },
    {
        "school": "Woodridge Elementary",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039000096",
    },
    {
        "school": "Adelaide Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000430",
    },
    {
        "school": "Brigadoon Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000431",
    },
    {
        "school": "Camelot Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000432",
    },
    {
        "school": "Decatur High School",
        "district": "Federal Way School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000434",
    },
    {
        "school": "Federal Way High School",
        "district": "Federal Way School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000435",
    },
    {
        "school": "Illahee Middle School",
        "district": "Federal Way School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000437",
    },
    {
        "school": "Kilo Middle School",
        "district": "Federal Way School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000438",
    },
    {
        "school": "Lake Dolloff Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000439",
    },
    {
        "school": "Lake Grove Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000440",
    },
    {
        "school": "Lakeland Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000441",
    },
    {
        "school": "Lakota Middle School",
        "district": "Federal Way School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000442",
    },
    {
        "school": "Mirror Lake Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000443",
    },
    {
        "school": "Nautilus K-8 School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000444",
    },
    {
        "school": "Olympic View Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000447",
    },
    {
        "school": "Sacajawea Middle School",
        "district": "Federal Way School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000448",
    },
    {
        "school": "Star Lake Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000449",
    },
    {
        "school": "Sunnycrest Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000450",
    },
    {
        "school": "Thomas Jefferson High School",
        "district": "Federal Way School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000451",
    },
    {
        "school": "Totem Middle School",
        "district": "Federal Way School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000452",
    },
    {
        "school": "Twin Lakes Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000453",
    },
    {
        "school": "Valhalla Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000454",
    },
    {
        "school": "Wildwood Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000455",
    },
    {
        "school": "Woodmont K-8 School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282000456",
    },
    {
        "school": "Green Gables Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282001120",
    },
    {
        "school": "Enterprise Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282001380",
    },
    {
        "school": "Panther Lake Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282001767",
    },
    {
        "school": "Mark Twain Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282001835",
    },
    {
        "school": "Silver Lake Elementary School - Federal Way",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282002255",
    },
    {
        "school": "Meredith Hill Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282002298",
    },
    {
        "school": "Sherwood Forest Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282002301",
    },
    {
        "school": "Rainier View Elementary School",
        "district": "Federal Way School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282002440",
    },
    {
        "school": "Internet Academy",
        "district": "Federal Way School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530282002638",
    },
    {
        "school": "Federal Way Public Academy",
        "district": "Federal Way School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282002719",
    },
    {
        "school": "Beverly Park Elem at Glendale",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000519",
    },
    {
        "school": "Bow Lake Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000521",
    },
    {
        "school": "Cascade Middle School",
        "district": "Highline School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000522",
    },
    {
        "school": "Cedarhurst Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000523",
    },
    {
        "school": "Chinook Middle School",
        "district": "Highline School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000524",
    },
    {
        "school": "Des Moines Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000525",
    },
    {
        "school": "Evergreen High School",
        "district": "Highline School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000526",
    },
    {
        "school": "Gregory Heights Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000528",
    },
    {
        "school": "Hazel Valley Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000529",
    },
    {
        "school": "Highline High School",
        "district": "Highline School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000531",
    },
    {
        "school": "Hilltop Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000532",
    },
    {
        "school": "Madrona Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000533",
    },
    {
        "school": "Marvista Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000535",
    },
    {
        "school": "McMicken Heights Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000536",
    },
    {
        "school": "Midway Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000537",
    },
    {
        "school": "Mount Rainier High School",
        "district": "Highline School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000538",
    },
    {
        "school": "Mount View Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000539",
    },
    {
        "school": "Pacific Middle School",
        "district": "Highline School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000543",
    },
    {
        "school": "Parkside Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000544",
    },
    {
        "school": "Seahurst Elementary School",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000549",
    },
    {
        "school": "Shorewood Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000550",
    },
    {
        "school": "Southern Heights Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000551",
    },
    {
        "school": "Sylvester Middle School",
        "district": "Highline School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000554",
    },
    {
        "school": "Tyee High School",
        "district": "Highline School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000555",
    },
    {
        "school": "White Center Heights Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354000557",
    },
    {
        "school": "Puget Sound Skills Center",
        "district": "Highline School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530354002103",
    },
    {
        "school": "North Hill Elementary",
        "district": "Highline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354002304",
    },
    {
        "school": "CHOICE Academy",
        "district": "Highline School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530354002640",
    },
    {
        "school": "Cougar Ridge Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375000482",
    },
    {
        "school": "Apollo Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375000570",
    },
    {
        "school": "Briarwood Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375000571",
    },
    {
        "school": "Issaquah Middle School",
        "district": "Issaquah School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375000573",
    },
    {
        "school": "Issaquah High School",
        "district": "Issaquah School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375000574",
    },
    {
        "school": "Issaquah Valley Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375000575",
    },
    {
        "school": "Liberty Sr High School",
        "district": "Issaquah School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375000576",
    },
    {
        "school": "Maple Hills Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375000577",
    },
    {
        "school": "Maywood Middle School",
        "district": "Issaquah School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375000579",
    },
    {
        "school": "Pine Lake Middle School",
        "district": "Issaquah School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375000580",
    },
    {
        "school": "Sunny Hills Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375000581",
    },
    {
        "school": "Issaquah Special Services",
        "district": "Issaquah School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530375001490",
    },
    {
        "school": "Beaver Lake Middle School",
        "district": "Issaquah School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375001495",
    },
    {
        "school": "Echo Glen School",
        "district": "Issaquah School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375001773",
    },
    {
        "school": "Clark Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375002107",
    },
    {
        "school": "Challenger Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375002214",
    },
    {
        "school": "Sunset Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375002307",
    },
    {
        "school": "Discovery Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375002426",
    },
    {
        "school": "Endeavour Elementary School",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375002518",
    },
    {
        "school": "Skyline High School",
        "district": "Issaquah School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375002567",
    },
    {
        "school": "Cascade Ridge Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375002881",
    },
    {
        "school": "Cedar Valley Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000612",
    },
    {
        "school": "Covington Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000613",
    },
    {
        "school": "East Hill Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000614",
    },
    {
        "school": "Fairwood Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000615",
    },
    {
        "school": "Grass Lake Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000617",
    },
    {
        "school": "Kent Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000619",
    },
    {
        "school": "Kent-Meridian High School",
        "district": "Kent School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000621",
    },
    {
        "school": "Kentridge High School",
        "district": "Kent School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000622",
    },
    {
        "school": "Lake Youngs Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000623",
    },
    {
        "school": "Meeker Middle School",
        "district": "Kent School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000624",
    },
    {
        "school": "Meridian Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000625",
    },
    {
        "school": "Meridian Middle School",
        "district": "Kent School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000626",
    },
    {
        "school": "Panther Lake Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000628",
    },
    {
        "school": "Park Orchard Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000629",
    },
    {
        "school": "Pine Tree Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000630",
    },
    {
        "school": "Scenic Hill Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000631",
    },
    {
        "school": "Soos Creek Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000633",
    },
    {
        "school": "Springbrook Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000635",
    },
    {
        "school": "George T. Daniel Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000690",
    },
    {
        "school": "Sunrise Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396000706",
    },
    {
        "school": "Cedar Heights Middle School",
        "district": "Kent School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396001142",
    },
    {
        "school": "Meadow Ridge Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396001603",
    },
    {
        "school": "Sawyer Woods Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396001610",
    },
    {
        "school": "Crestwood Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396001779",
    },
    {
        "school": "Mattson Middle School",
        "district": "Kent School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396001780",
    },
    {
        "school": "Kentwood High School",
        "district": "Kent School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396001840",
    },
    {
        "school": "Ridgewood Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002111",
    },
    {
        "school": "Martin Sortun Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002112",
    },
    {
        "school": "Jenkins Creek Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002113",
    },
    {
        "school": "Carriage Crest Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002308",
    },
    {
        "school": "Neely O Brien Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002309",
    },
    {
        "school": "Horizon Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002310",
    },
    {
        "school": "Northwood Middle School",
        "district": "Kent School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002521",
    },
    {
        "school": "Glenridge Elementary",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002522",
    },
    {
        "school": "Kent Mountain View Academy",
        "district": "Kent School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530396002569",
    },
    {
        "school": "Kentlake High School",
        "district": "Kent School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002570",
    },
    {
        "school": "Regional Justice Center",
        "district": "Kent School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530396002728",
    },
    {
        "school": "Emerald Park Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002729",
    },
    {
        "school": "Millennium Elementary School",
        "district": "Kent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530396002799",
    },
    {
        "school": "Bell Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000656",
    },
    {
        "school": "Audubon Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000657",
    },
    {
        "school": "Franklin Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000658",
    },
    {
        "school": "Rush Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000659",
    },
    {
        "school": "Sandburg Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000660",
    },
    {
        "school": "Dickinson Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000661",
    },
    {
        "school": "Finn Hill Middle School",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000663",
    },
    {
        "school": "Ready Start Preschool",
        "district": "Lake Washington School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000664",
    },
    {
        "school": "Keller Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000666",
    },
    {
        "school": "Mann Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000667",
    },
    {
        "school": "Muir Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000668",
    },
    {
        "school": "Juanita Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000669",
    },
    {
        "school": "Juanita High",
        "district": "Lake Washington School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000670",
    },
    {
        "school": "Kamiakin Middle School",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000671",
    },
    {
        "school": "Kirkland Middle School",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000672",
    },
    {
        "school": "Community School",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423000673",
    },
    {
        "school": "Lake Washington High",
        "district": "Lake Washington School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000674",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000675",
    },
    {
        "school": "Twain Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000676",
    },
    {
        "school": "Kirk Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000677",
    },
    {
        "school": "Redmond Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000678",
    },
    {
        "school": "Redmond High",
        "district": "Lake Washington School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000679",
    },
    {
        "school": "Redmond Middle School",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000680",
    },
    {
        "school": "Frost Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000681",
    },
    {
        "school": "Rose Hill Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000682",
    },
    {
        "school": "Rose Hill Middle School",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000683",
    },
    {
        "school": "Thoreau Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423000684",
    },
    {
        "school": "Eastlake High School",
        "district": "Lake Washington School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423001141",
    },
    {
        "school": "Contractual Schools",
        "district": "Lake Washington School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423001598",
    },
    {
        "school": "Emerson High School",
        "district": "Lake Washington School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423001784",
    },
    {
        "school": "Mead Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423001785",
    },
    {
        "school": "Evergreen Middle School",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423001841",
    },
    {
        "school": "Rockwell Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423001842",
    },
    {
        "school": "Northstar Middle School",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423001843",
    },
    {
        "school": "Alcott Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423002062",
    },
    {
        "school": "Smith Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423002216",
    },
    {
        "school": "Wilder Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423002257",
    },
    {
        "school": "Mcauliffe Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423002311",
    },
    {
        "school": "Inglewood Middle School",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423002435",
    },
    {
        "school": "Discovery School",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423002448",
    },
    {
        "school": "Explorer Community School",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423002519",
    },
    {
        "school": "International Community School",
        "district": "Lake Washington School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423002568",
    },
    {
        "school": "Einstein Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423002648",
    },
    {
        "school": "Blackwell Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423002649",
    },
    {
        "school": "Emerson K-12",
        "district": "Lake Washington School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423002725",
    },
    {
        "school": "Environmental & Adventure School",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423002726",
    },
    {
        "school": "Futures School",
        "district": "Lake Washington School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423002727",
    },
    {
        "school": "Carnation Elementary School",
        "district": "Riverview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530456000714",
    },
    {
        "school": "Cherry Valley Elementary School",
        "district": "Riverview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530456000715",
    },
    {
        "school": "Cedarcrest High School",
        "district": "Riverview School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530456000716",
    },
    {
        "school": "Tolt Middle School",
        "district": "Riverview School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530456002119",
    },
    {
        "school": "Stillwater Elementary",
        "district": "Riverview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530456002258",
    },
    {
        "school": "Eagle Rock Multiage School",
        "district": "Riverview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530456002566",
    },
    {
        "school": "CLIP",
        "district": "Riverview School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530456002644",
    },
    {
        "school": "PARADE",
        "district": "Riverview School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530456002797",
    },
    {
        "school": "Island Park Elementary",
        "district": "Mercer Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530498000758",
    },
    {
        "school": "Lakeridge Elementary School",
        "district": "Mercer Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530498000759",
    },
    {
        "school": "Mercer Island High School",
        "district": "Mercer Island School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530498000761",
    },
    {
        "school": "Islander Middle School",
        "district": "Mercer Island School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530498000764",
    },
    {
        "school": "West Mercer Elementary",
        "district": "Mercer Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530498000765",
    },
    {
        "school": "Arrowhead Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000875",
    },
    {
        "school": "Bothell High School",
        "district": "Northshore School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000876",
    },
    {
        "school": "C O Sorenson",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000877",
    },
    {
        "school": "Cottage Lake Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000880",
    },
    {
        "school": "Inglemoor HS",
        "district": "Northshore School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000884",
    },
    {
        "school": "Kenmore Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000885",
    },
    {
        "school": "Kenmore Middle School",
        "district": "Northshore School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000886",
    },
    {
        "school": "Leota Middle School",
        "district": "Northshore School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000887",
    },
    {
        "school": "Maywood Hills Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000889",
    },
    {
        "school": "Moorlands Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000890",
    },
    {
        "school": "Northshore Middle School",
        "district": "Northshore School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000891",
    },
    {
        "school": "Secondary Academy for Success",
        "district": "Northshore School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530591000892",
    },
    {
        "school": "Shelton View Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000893",
    },
    {
        "school": "Wellington Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000894",
    },
    {
        "school": "Westhill Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000895",
    },
    {
        "school": "Woodin Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000896",
    },
    {
        "school": "Hollywood Hill Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591001791",
    },
    {
        "school": "Sunrise Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591001993",
    },
    {
        "school": "Woodinville HS",
        "district": "Northshore School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591001994",
    },
    {
        "school": "Bear Creek Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591002221",
    },
    {
        "school": "Fernwood Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591002222",
    },
    {
        "school": "Woodmoor Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591002330",
    },
    {
        "school": "East Ridge Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591002428",
    },
    {
        "school": "Timbercrest Middle School",
        "district": "Northshore School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591002571",
    },
    {
        "school": "Northshore Networks",
        "district": "Northshore School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530591002730",
    },
    {
        "school": "Benson Hill Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001064",
    },
    {
        "school": "Bryn Mawr Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001065",
    },
    {
        "school": "Campbell Hill Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001066",
    },
    {
        "school": "Cascade Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001067",
    },
    {
        "school": "Nelsen Middle School",
        "district": "Renton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001070",
    },
    {
        "school": "Hazelwood Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001071",
    },
    {
        "school": "Highlands Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001072",
    },
    {
        "school": "Kennydale Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001075",
    },
    {
        "school": "Lakeridge Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001076",
    },
    {
        "school": "Lindbergh Senior High School",
        "district": "Renton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001077",
    },
    {
        "school": "Maplewood Heights Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001078",
    },
    {
        "school": "McKnight Middle School",
        "district": "Renton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001079",
    },
    {
        "school": "Hazen Senior High School",
        "district": "Renton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001080",
    },
    {
        "school": "Renton Park Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001081",
    },
    {
        "school": "Renton Senior High School",
        "district": "Renton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001082",
    },
    {
        "school": "Sierra Heights Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001084",
    },
    {
        "school": "Talbot Hill Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001085",
    },
    {
        "school": "Tiffany Park Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723001087",
    },
    {
        "school": "Out Of District Facility",
        "district": "Renton School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530723001410",
    },
    {
        "school": "Griffin Home",
        "district": "Renton School District",
        "level": "High",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530723002343",
    },
    {
        "school": "Dimmitt Middle School",
        "district": "Renton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723002564",
    },
    {
        "school": "H.O.M.E. Program",
        "district": "Renton School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530723002721",
    },
    {
        "school": "Pathfinder K-8 School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771001102",
    },
    {
        "school": "Adams Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001127",
    },
    {
        "school": "Alki Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001129",
    },
    {
        "school": "Licton Springs K-8",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771001132",
    },
    {
        "school": "Arbor Heights Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001135",
    },
    {
        "school": "Mercer International Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001136",
    },
    {
        "school": "Daniel Bagley Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001137",
    },
    {
        "school": "Ballard High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001138",
    },
    {
        "school": "Beacon Hill International School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001140",
    },
    {
        "school": "Martin Luther King Jr. Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001143",
    },
    {
        "school": "Broadview-Thomson K-8 School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001145",
    },
    {
        "school": "Bryant Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001146",
    },
    {
        "school": "Chief Sealth International High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001149",
    },
    {
        "school": "Cleveland High School STEM",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001150",
    },
    {
        "school": "Frantz Coe Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001151",
    },
    {
        "school": "Concord International School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001154",
    },
    {
        "school": "B F Day Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001157",
    },
    {
        "school": "Dearborn Park International School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001158",
    },
    {
        "school": "Dunlap Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001161",
    },
    {
        "school": "Eckstein Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001162",
    },
    {
        "school": "Emerson Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001163",
    },
    {
        "school": "Franklin High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001168",
    },
    {
        "school": "Kimball Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001169",
    },
    {
        "school": "Garfield High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001171",
    },
    {
        "school": "Gatewood Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001172",
    },
    {
        "school": "Bailey Gatzert Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001173",
    },
    {
        "school": "Graham Hill Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001175",
    },
    {
        "school": "Green Lake Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001176",
    },
    {
        "school": "Greenwood Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001177",
    },
    {
        "school": "Hamilton International Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001180",
    },
    {
        "school": "West Seattle Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001182",
    },
    {
        "school": "Highland Park Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001183",
    },
    {
        "school": "Ingraham High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001187",
    },
    {
        "school": "John Hay Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001192",
    },
    {
        "school": "John Rogers Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001193",
    },
    {
        "school": "Lafayette Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001195",
    },
    {
        "school": "John Stanford International School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001197",
    },
    {
        "school": "Laurelhurst Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001198",
    },
    {
        "school": "Lawton Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001199",
    },
    {
        "school": "Leschi Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001201",
    },
    {
        "school": "Lowell Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001205",
    },
    {
        "school": "Loyal Heights Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001206",
    },
    {
        "school": "Madison Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001207",
    },
    {
        "school": "Maple Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001209",
    },
    {
        "school": "McClure Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001212",
    },
    {
        "school": "McGilvra Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001214",
    },
    {
        "school": "Madrona K-5 School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001216",
    },
    {
        "school": "Montlake Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001219",
    },
    {
        "school": "John Muir Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001221",
    },
    {
        "school": "Nathan Hale High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001222",
    },
    {
        "school": "North Beach Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001223",
    },
    {
        "school": "Northgate Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001225",
    },
    {
        "school": "Nova High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771001226",
    },
    {
        "school": "Olympic Hills Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001228",
    },
    {
        "school": "Olympic View Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001229",
    },
    {
        "school": "South Lake High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771001234",
    },
    {
        "school": "Rainier Beach High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001236",
    },
    {
        "school": "Roosevelt High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001239",
    },
    {
        "school": "Roxhill Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001240",
    },
    {
        "school": "Sacajawea Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001242",
    },
    {
        "school": "Sanislo Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001244",
    },
    {
        "school": "Genesee Hill Elementary",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001245",
    },
    {
        "school": "Aki Kurose Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001249",
    },
    {
        "school": "Stevens Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001251",
    },
    {
        "school": "Thornton Creek Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771001253",
    },
    {
        "school": "Rising Star Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001255",
    },
    {
        "school": "View Ridge Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001256",
    },
    {
        "school": "Washington Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001259",
    },
    {
        "school": "Wedgwood Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001261",
    },
    {
        "school": "West Seattle High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001262",
    },
    {
        "school": "West Woodland Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001263",
    },
    {
        "school": "Whitman Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001264",
    },
    {
        "school": "Whittier Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001265",
    },
    {
        "school": "Wing Luke Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001267",
    },
    {
        "school": "Tops K-8 School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771001307",
    },
    {
        "school": "Seattle World School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771001311",
    },
    {
        "school": "Interagency Programs",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771001365",
    },
    {
        "school": "David T. Denny International Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771001913",
    },
    {
        "school": "Catharine Blaine K-8 School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771002017",
    },
    {
        "school": "Orca K-8 School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771002231",
    },
    {
        "school": "Hawthorne Elementary School - Seattle",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771002269",
    },
    {
        "school": "Thurgood Marshall Elementary",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771002347",
    },
    {
        "school": "Middle College High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771002349",
    },
    {
        "school": "Cascade Parent Partnership Program",
        "district": "Seattle School District No. 1",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771002635",
    },
    {
        "school": "Salmon Bay K-8 School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771002716",
    },
    {
        "school": "The Center School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771002842",
    },
    {
        "school": "Residential Consortium",
        "district": "Seattle School District No. 1",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530771002873",
    },
    {
        "school": "Meridian Park Elementary School",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792000404",
    },
    {
        "school": "Albert Einstein Middle School",
        "district": "Shoreline School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001297",
    },
    {
        "school": "Briarcrest Elementary",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001299",
    },
    {
        "school": "Brookside Elementary",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001300",
    },
    {
        "school": "Echo Lake Elementary School",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001302",
    },
    {
        "school": "Highland Terrace Elementary",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001304",
    },
    {
        "school": "Kellogg Middle School",
        "district": "Shoreline School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001308",
    },
    {
        "school": "Lake Forest Park Elementary",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001309",
    },
    {
        "school": "Melvin G Syre Elementary",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001310",
    },
    {
        "school": "Parkwood Elementary",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001313",
    },
    {
        "school": "Ridgecrest Elementary",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001314",
    },
    {
        "school": "Shorecrest High School",
        "district": "Shoreline School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001315",
    },
    {
        "school": "Shorewood High School",
        "district": "Shoreline School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792001317",
    },
    {
        "school": "Handicapped Contractual Services",
        "district": "Shoreline School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530792002447",
    },
    {
        "school": "Home Education Exchange",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530792002646",
    },
    {
        "school": "Skykomish Elementary School",
        "district": "Skykomish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530798001320",
    },
    {
        "school": "Skykomish High School",
        "district": "Skykomish School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530798001321",
    },
    {
        "school": "Fall City Elementary",
        "district": "Snoqualmie Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530804001329",
    },
    {
        "school": "Mount Si High School",
        "district": "Snoqualmie Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530804001330",
    },
    {
        "school": "North Bend Elementary School",
        "district": "Snoqualmie Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530804001331",
    },
    {
        "school": "Snoqualmie Elementary",
        "district": "Snoqualmie Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530804001332",
    },
    {
        "school": "Two Rivers School",
        "district": "Snoqualmie Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530804002158",
    },
    {
        "school": "Edwin R Opstad Elementary",
        "district": "Snoqualmie Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530804002239",
    },
    {
        "school": "Chief Kanim Middle School",
        "district": "Snoqualmie Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530804002439",
    },
    {
        "school": "Foster Senior High School",
        "district": "Tukwila School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530813001341",
    },
    {
        "school": "Showalter Middle School",
        "district": "Tukwila School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530813001342",
    },
    {
        "school": "Thorndyke Elementary",
        "district": "Tukwila School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530813001343",
    },
    {
        "school": "Tukwila Elementary",
        "district": "Tukwila School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530813001344",
    },
    {
        "school": "Cascade View Elementary",
        "district": "Tukwila School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530813002032",
    },
    {
        "school": "Rock Creek Elementary",
        "district": "Tahoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530876000692",
    },
    {
        "school": "Glacier Park Elementary",
        "district": "Tahoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530876001463",
    },
    {
        "school": "Maple View Middle School",
        "district": "Tahoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530876001515",
    },
    {
        "school": "Lake Wilderness Elementary",
        "district": "Tahoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530876001516",
    },
    {
        "school": "Shadow Lake Elementary",
        "district": "Tahoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530876001517",
    },
    {
        "school": "Tahoma Senior High School",
        "district": "Tahoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530876001519",
    },
    {
        "school": "Chautauqua Elementary",
        "district": "Vashon Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530930001394",
    },
    {
        "school": "McMurray Middle School",
        "district": "Vashon Island School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530930001589",
    },
    {
        "school": "Vashon Island High School",
        "district": "Vashon Island School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530930001591",
    },
    {
        "school": "Family Link",
        "district": "Vashon Island School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530930002720",
    },
    {
        "school": "Arlington High School",
        "district": "Arlington School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530024000023",
    },
    {
        "school": "Post Middle School",
        "district": "Arlington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530024000024",
    },
    {
        "school": "Kent Prairie Elementary",
        "district": "Arlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530024001190",
    },
    {
        "school": "Presidents Elementary",
        "district": "Arlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530024001815",
    },
    {
        "school": "Weston High School",
        "district": "Arlington School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530024002074",
    },
    {
        "school": "Eagle Creek Elementary",
        "district": "Arlington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530024002248",
    },
    {
        "school": "Stillaguamish Valley Learning Center",
        "district": "Arlington School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530024002589",
    },
    {
        "school": "Darrington Elementary School",
        "district": "Darrington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530198000300",
    },
    {
        "school": "Darrington High School",
        "district": "Darrington School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530198000301",
    },
    {
        "school": "Alderwood Middle School",
        "district": "Edmonds School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000329",
    },
    {
        "school": "Beverly Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000330",
    },
    {
        "school": "Brier Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000331",
    },
    {
        "school": "Brier Terrace Middle School",
        "district": "Edmonds School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000332",
    },
    {
        "school": "Cedar Valley Community School",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000333",
    },
    {
        "school": "Cedar Way Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000334",
    },
    {
        "school": "Chase Lake Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000335",
    },
    {
        "school": "College Place Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000336",
    },
    {
        "school": "College Place Middle School",
        "district": "Edmonds School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000337",
    },
    {
        "school": "Scriber Lake High School",
        "district": "Edmonds School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530240000338",
    },
    {
        "school": "Hazelwood Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000341",
    },
    {
        "school": "Hilltop Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000342",
    },
    {
        "school": "Lynndale Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000343",
    },
    {
        "school": "Lynnwood Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000344",
    },
    {
        "school": "Lynnwood High School",
        "district": "Edmonds School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000346",
    },
    {
        "school": "Madrona K-8 School",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530240000348",
    },
    {
        "school": "Meadowdale Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000350",
    },
    {
        "school": "Meadowdale Middle School",
        "district": "Edmonds School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000351",
    },
    {
        "school": "Meadowdale High School",
        "district": "Edmonds School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000352",
    },
    {
        "school": "Mountlake Terrace Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000354",
    },
    {
        "school": "Mountlake Terrace High School",
        "district": "Edmonds School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000356",
    },
    {
        "school": "Oak Heights Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000357",
    },
    {
        "school": "Seaview Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000359",
    },
    {
        "school": "Sherwood Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000360",
    },
    {
        "school": "Spruce Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000362",
    },
    {
        "school": "Westgate Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240000363",
    },
    {
        "school": "Challenge Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530240001189",
    },
    {
        "school": "Martha Lake Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240002089",
    },
    {
        "school": "Edmonds eLearning Academy",
        "district": "Edmonds School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530240002205",
    },
    {
        "school": "Unassigned School",
        "district": "Edmonds School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530240002290",
    },
    {
        "school": "Terrace Park Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240002292",
    },
    {
        "school": "Edmonds Elementary",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240002293",
    },
    {
        "school": "Early Childhood Center",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530240002420",
    },
    {
        "school": "Maplewood Parent Coop",
        "district": "Edmonds School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530240002474",
    },
    {
        "school": "Edmonds Woodway High School",
        "district": "Edmonds School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530240002673",
    },
    {
        "school": "Contracted Schools",
        "district": "Edmonds School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530240002821",
    },
    {
        "school": "Cascade High School",
        "district": "Everett School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000391",
    },
    {
        "school": "Eisenhower Middle School",
        "district": "Everett School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000393",
    },
    {
        "school": "Emerson Elementary School",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000394",
    },
    {
        "school": "Everett High School",
        "district": "Everett School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000395",
    },
    {
        "school": "Evergreen Middle School",
        "district": "Everett School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000397",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000398",
    },
    {
        "school": "North Middle School",
        "district": "Everett School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000399",
    },
    {
        "school": "Hawthorne Elementary School - Everett",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000400",
    },
    {
        "school": "Jackson Elementary School",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000401",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000402",
    },
    {
        "school": "Lowell Elementary - Everett",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000403",
    },
    {
        "school": "Madison Elementary",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000405",
    },
    {
        "school": "Monroe Elementary",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000406",
    },
    {
        "school": "Silver Lake Elementary - Everett",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000409",
    },
    {
        "school": "View Ridge Elementary",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000410",
    },
    {
        "school": "Whittier Elementary",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267000411",
    },
    {
        "school": "Gateway Middle School",
        "district": "Everett School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267001725",
    },
    {
        "school": "Henry M. Jackson High School",
        "district": "Everett School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267001726",
    },
    {
        "school": "Sequoia High School",
        "district": "Everett School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530267001765",
    },
    {
        "school": "Woodside Elementary",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267001792",
    },
    {
        "school": "Silver Firs Elementary",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267002208",
    },
    {
        "school": "Mill Creek Elementary",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267002209",
    },
    {
        "school": "Heatherwood Middle School",
        "district": "Everett School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267002253",
    },
    {
        "school": "Cedar Wood Elementary",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267002431",
    },
    {
        "school": "NW Learning Center",
        "district": "Everett School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530267002469",
    },
    {
        "school": "Penny Creek Elementary",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267002669",
    },
    {
        "school": "Special Services",
        "district": "Everett School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530267002818",
    },
    {
        "school": "Granite Falls High School",
        "district": "Granite Falls School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530321000506",
    },
    {
        "school": "Granite Falls Middle School",
        "district": "Granite Falls School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530321001770",
    },
    {
        "school": "Mountain Way Elementary",
        "district": "Granite Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530321002303",
    },
    {
        "school": "Monte Cristo Elementary",
        "district": "Granite Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530321002482",
    },
    {
        "school": "Index Elementary School",
        "district": "Index Elementary School District 63",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530372000569",
    },
    {
        "school": "Glenwood Elementary",
        "district": "Lake Stevens School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420000520",
    },
    {
        "school": "Skyline Elementary",
        "district": "Lake Stevens School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420000527",
    },
    {
        "school": "Hillcrest Elementary School",
        "district": "Lake Stevens School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420000651",
    },
    {
        "school": "Lake Stevens Middle School",
        "district": "Lake Stevens School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420000652",
    },
    {
        "school": "Lake Stevens Sr High School",
        "district": "Lake Stevens School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420000653",
    },
    {
        "school": "Mt. Pilchuck Elementary School",
        "district": "Lake Stevens School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420000654",
    },
    {
        "school": "Sunnycrest Elementary School",
        "district": "Lake Stevens School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420000655",
    },
    {
        "school": "Prove High School",
        "district": "Lake Stevens School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530420001782",
    },
    {
        "school": "North Lake Middle School",
        "district": "Lake Stevens School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420001906",
    },
    {
        "school": "Homelink",
        "district": "Lake Stevens School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530420002670",
    },
    {
        "school": "Highland Elementary",
        "district": "Lake Stevens School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420002756",
    },
    {
        "school": "Lakewood Elementary School",
        "district": "Lakewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530426000685",
    },
    {
        "school": "Lakewood Middle School",
        "district": "Lakewood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530426000686",
    },
    {
        "school": "Lakewood High School",
        "district": "Lakewood School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530426002117",
    },
    {
        "school": "English Crossing Elementary",
        "district": "Lakewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530426002478",
    },
    {
        "school": "Cascade Elementary",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486000733",
    },
    {
        "school": "Liberty Elementary",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486000734",
    },
    {
        "school": "Totem Middle School",
        "district": "Marysville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486000735",
    },
    {
        "school": "Marysville Middle School",
        "district": "Marysville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486000736",
    },
    {
        "school": "Pinewood Elementary",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486000738",
    },
    {
        "school": "Shoultes Elementary",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486000739",
    },
    {
        "school": "Sunnyside Elementary",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486000740",
    },
    {
        "school": "Allen Creek Elementary School",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486001191",
    },
    {
        "school": "Marshall Elementary",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486001847",
    },
    {
        "school": "Kellogg Marsh Elementary School",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486002261",
    },
    {
        "school": "Cedarcrest School",
        "district": "Marysville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486002425",
    },
    {
        "school": "10th Street School",
        "district": "Marysville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486002475",
    },
    {
        "school": "Heritage School",
        "district": "Marysville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486002476",
    },
    {
        "school": "School Home Partnership Program",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530486002590",
    },
    {
        "school": "Marysville Coop Program",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486002848",
    },
    {
        "school": "Frank Wagner Elementary",
        "district": "Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530513000773",
    },
    {
        "school": "Maltby Elementary",
        "district": "Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530513000774",
    },
    {
        "school": "Out Of District Special Ed",
        "district": "Monroe School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530513001729",
    },
    {
        "school": "Salem Woods Elementary School",
        "district": "Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530513001849",
    },
    {
        "school": "Chain Lake Elementary School",
        "district": "Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530513002316",
    },
    {
        "school": "Sky Valley Education Center",
        "district": "Monroe School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530513002675",
    },
    {
        "school": "Monroe Special Ed Preschool",
        "district": "Monroe School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530513002757",
    },
    {
        "school": "Leaders In Learning",
        "district": "Monroe School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530513002759",
    },
    {
        "school": "Monroe High School",
        "district": "Monroe School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530513002760",
    },
    {
        "school": "Hidden River Middle School",
        "district": "Monroe School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530513002761",
    },
    {
        "school": "Voyager Middle School",
        "district": "Mukilteo School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543000719",
    },
    {
        "school": "Fairmount Elementary",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543000816",
    },
    {
        "school": "Mariner High School",
        "district": "Mukilteo School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543000818",
    },
    {
        "school": "Olivia Park Elementary",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543000819",
    },
    {
        "school": "Olympic View Middle School",
        "district": "Mukilteo School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543000820",
    },
    {
        "school": "Serene Lake Elementary",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543000821",
    },
    {
        "school": "Harbour Pointe Middle School",
        "district": "Mukilteo School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543001185",
    },
    {
        "school": "Kamiak High School",
        "district": "Mukilteo School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543001188",
    },
    {
        "school": "Endeavour Elementary",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543001727",
    },
    {
        "school": "Mukilteo Elementary",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543001852",
    },
    {
        "school": "Picnic Point Elementary",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543001853",
    },
    {
        "school": "Explorer Middle School",
        "district": "Mukilteo School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543001910",
    },
    {
        "school": "ACES High School",
        "district": "Mukilteo School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530543002063",
    },
    {
        "school": "Sno-Isle Skills Center",
        "district": "Mukilteo School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530543002127",
    },
    {
        "school": "Challenger Elementary",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543002128",
    },
    {
        "school": "Discovery Elementary",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543002218",
    },
    {
        "school": "Columbia Elementary",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543002263",
    },
    {
        "school": "Horizon Elementary",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543002320",
    },
    {
        "school": "Special Services",
        "district": "Mukilteo School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530543002820",
    },
    {
        "school": "Skyview Middle School",
        "district": "Northshore School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000480",
    },
    {
        "school": "Canyon Creek Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000878",
    },
    {
        "school": "Canyon Park Middle School",
        "district": "Northshore School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000879",
    },
    {
        "school": "Crystal Springs Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000881",
    },
    {
        "school": "Lockwood Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591000888",
    },
    {
        "school": "Kokanee Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591001612",
    },
    {
        "school": "Frank Love Elementary",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591002329",
    },
    {
        "school": "Northshore Special Services",
        "district": "Northshore School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530591002731",
    },
    {
        "school": "Centennial Middle School",
        "district": "Snohomish School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802000540",
    },
    {
        "school": "Cathcart Elementary",
        "district": "Snohomish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802001322",
    },
    {
        "school": "Central Elementary",
        "district": "Snohomish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802001323",
    },
    {
        "school": "Emerson Elementary",
        "district": "Snohomish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802001324",
    },
    {
        "school": "Machias Elementary",
        "district": "Snohomish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802001325",
    },
    {
        "school": "Riverview Elementary",
        "district": "Snohomish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802001326",
    },
    {
        "school": "Snohomish High School",
        "district": "Snohomish School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802001328",
    },
    {
        "school": "Valley View Middle School",
        "district": "Snohomish School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802001790",
    },
    {
        "school": "High School Re Entry",
        "district": "Snohomish School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530802001801",
    },
    {
        "school": "Seattle Hill Elementary",
        "district": "Snohomish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802002028",
    },
    {
        "school": "Dutch Hill Elementary",
        "district": "Snohomish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802002029",
    },
    {
        "school": "AIM High School",
        "district": "Snohomish School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530802002068",
    },
    {
        "school": "Cascade View Elementary",
        "district": "Snohomish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802002354",
    },
    {
        "school": "Totem Falls",
        "district": "Snohomish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802002432",
    },
    {
        "school": "Snohomish Center",
        "district": "Snohomish School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530802002593",
    },
    {
        "school": "Stanwood High School",
        "district": "Stanwood-Camano School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530834001423",
    },
    {
        "school": "Stanwood Middle School",
        "district": "Stanwood-Camano School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530834001424",
    },
    {
        "school": "Stanwood Elementary School",
        "district": "Stanwood-Camano School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530834001425",
    },
    {
        "school": "Twin City Elementary",
        "district": "Stanwood-Camano School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530834002367",
    },
    {
        "school": "Lincoln Hill High School",
        "district": "Stanwood-Camano School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530834002594",
    },
    {
        "school": "Port Susan Middle School",
        "district": "Stanwood-Camano School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530834002595",
    },
    {
        "school": "Cedarhome Elementary School",
        "district": "Stanwood-Camano School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530834002596",
    },
    {
        "school": "Gold Bar Elementary",
        "district": "Sultan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530855000541",
    },
    {
        "school": "Sultan Elementary School",
        "district": "Sultan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530855001438",
    },
    {
        "school": "Sultan Middle School",
        "district": "Sultan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530855001439",
    },
    {
        "school": "Sultan Senior High School",
        "district": "Sultan School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530855002168",
    },
    {
        "school": "Student Services School",
        "district": "Sultan School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530855002480",
    },
    {
        "school": "Bethel High School",
        "district": "Bethel School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048000119",
    },
    {
        "school": "Bethel Middle School",
        "district": "Bethel School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048000120",
    },
    {
        "school": "Chester H Thompson Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048000121",
    },
    {
        "school": "Clover Creek Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048000122",
    },
    {
        "school": "Elk Plain School of Choice",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048000123",
    },
    {
        "school": "Kapowsin Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048000124",
    },
    {
        "school": "Roy Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048000126",
    },
    {
        "school": "Spanaway Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048000127",
    },
    {
        "school": "Spanaway Middle School",
        "district": "Bethel School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048000128",
    },
    {
        "school": "Frontier Middle School",
        "district": "Bethel School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048000595",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048001748",
    },
    {
        "school": "Naches Trail Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048001749",
    },
    {
        "school": "Shining Mountain Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048001750",
    },
    {
        "school": "Cedarcrest Middle School",
        "district": "Bethel School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048001819",
    },
    {
        "school": "Spanaway Lake High School",
        "district": "Bethel School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048001821",
    },
    {
        "school": "Rocky Ridge Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048001925",
    },
    {
        "school": "Challenger High School",
        "district": "Bethel School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530048002200",
    },
    {
        "school": "Camas Prairie Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048002202",
    },
    {
        "school": "Graham Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048002203",
    },
    {
        "school": "Centennial Elementary Bethel",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048002250",
    },
    {
        "school": "Pioneer Valley Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048002430",
    },
    {
        "school": "North Star Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048002747",
    },
    {
        "school": "Carbonado Historical School 19",
        "district": "Carbonado School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530087000166",
    },
    {
        "school": "Tillicum Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000158",
    },
    {
        "school": "Beachwood Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000246",
    },
    {
        "school": "Carter Lake Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000247",
    },
    {
        "school": "Clover Park High School",
        "district": "Clover Park School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000250",
    },
    {
        "school": "Custer Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000251",
    },
    {
        "school": "Dower Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000252",
    },
    {
        "school": "Hillside Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000256",
    },
    {
        "school": "Hudtloff Middle School",
        "district": "Clover Park School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000257",
    },
    {
        "school": "Idlewild Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000258",
    },
    {
        "school": "Lake Louise Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000260",
    },
    {
        "school": "Lakes High School",
        "district": "Clover Park School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000261",
    },
    {
        "school": "Lakeview Hope Academy",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000262",
    },
    {
        "school": "Lochburn Middle School",
        "district": "Clover Park School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000263",
    },
    {
        "school": "Mann Middle School",
        "district": "Clover Park School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000264",
    },
    {
        "school": "Oakbrook Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000265",
    },
    {
        "school": "Tyee Park Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000270",
    },
    {
        "school": "Firwood",
        "district": "Clover Park School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000271",
    },
    {
        "school": "Woodbrook Middle School",
        "district": "Clover Park School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141000272",
    },
    {
        "school": "Oak Grove",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141001897",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141002438",
    },
    {
        "school": "Park Lodge Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141002581",
    },
    {
        "school": "Alfaretta House",
        "district": "Clover Park School District",
        "level": "High",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530141002839",
    },
    {
        "school": "Re-Entry High School",
        "district": "Clover Park School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530141002860",
    },
    {
        "school": "Re-Entry Middle School",
        "district": "Clover Park School District",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530141002861",
    },
    {
        "school": "Special Education Services/relife",
        "district": "Clover Park School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530141002862",
    },
    {
        "school": "Lake Tapps Elementary",
        "district": "Dieringer School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530213000310",
    },
    {
        "school": "North Tapps Middle School",
        "district": "Dieringer School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530213000694",
    },
    {
        "school": "Dieringer Heights Elementary",
        "district": "Dieringer School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530213002812",
    },
    {
        "school": "Columbia Crest A-STEM Academy",
        "district": "Eatonville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530237000325",
    },
    {
        "school": "Eatonville Elementary School",
        "district": "Eatonville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530237000326",
    },
    {
        "school": "Eatonville High School",
        "district": "Eatonville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530237000327",
    },
    {
        "school": "Weyerhaeuser Elementary",
        "district": "Eatonville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530237000328",
    },
    {
        "school": "Eatonville Middle School",
        "district": "Eatonville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530237001899",
    },
    {
        "school": "Discovery Primary School",
        "district": "Fife School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530288000464",
    },
    {
        "school": "Fife High School",
        "district": "Fife School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530288000465",
    },
    {
        "school": "Endeavour Intermediate",
        "district": "Fife School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530288000466",
    },
    {
        "school": "Surprise Lake Middle School",
        "district": "Fife School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530288000467",
    },
    {
        "school": "Hedden Elementary School",
        "district": "Fife School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530288002875",
    },
    {
        "school": "Brookdale Elementary",
        "district": "Franklin Pierce School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294000470",
    },
    {
        "school": "Central Avenue Elementary",
        "district": "Franklin Pierce School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294000471",
    },
    {
        "school": "Christensen Elementary",
        "district": "Franklin Pierce School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294000472",
    },
    {
        "school": "Collins Elementary",
        "district": "Franklin Pierce School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294000473",
    },
    {
        "school": "Elmhurst Elementary School",
        "district": "Franklin Pierce School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294000474",
    },
    {
        "school": "Franklin Pierce High School",
        "district": "Franklin Pierce School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294000475",
    },
    {
        "school": "Harvard Elementary",
        "district": "Franklin Pierce School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294000476",
    },
    {
        "school": "James Sales Elementary",
        "district": "Franklin Pierce School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294000477",
    },
    {
        "school": "Morris Ford Middle School",
        "district": "Franklin Pierce School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294000479",
    },
    {
        "school": "Perry G Keithley Middle School",
        "district": "Franklin Pierce School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294000481",
    },
    {
        "school": "Washington High School",
        "district": "Franklin Pierce School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294000483",
    },
    {
        "school": "Gates Secondary School",
        "district": "Franklin Pierce School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530294001769",
    },
    {
        "school": "Orting Primary School",
        "district": "Orting School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530645000952",
    },
    {
        "school": "Orting High School",
        "district": "Orting School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530645000953",
    },
    {
        "school": "Orting Middle School",
        "district": "Orting School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530645002066",
    },
    {
        "school": "Ptarmigan Ridge Elementary School",
        "district": "Orting School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530645002813",
    },
    {
        "school": "Artondale Elementary School",
        "district": "Peninsula School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669000980",
    },
    {
        "school": "Discovery Elementary School",
        "district": "Peninsula School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669000981",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Peninsula School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669000982",
    },
    {
        "school": "Goodman Middle School",
        "district": "Peninsula School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669000983",
    },
    {
        "school": "Harbor Heights Elementary School",
        "district": "Peninsula School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669000984",
    },
    {
        "school": "Peninsula High School",
        "district": "Peninsula School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669000985",
    },
    {
        "school": "Purdy Elementary School",
        "district": "Peninsula School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669000986",
    },
    {
        "school": "Vaughn Elementary School",
        "district": "Peninsula School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669000988",
    },
    {
        "school": "Gig Harbor High",
        "district": "Peninsula School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669001793",
    },
    {
        "school": "Kopachuck Middle School",
        "district": "Peninsula School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669001862",
    },
    {
        "school": "Key Peninsula Middle School",
        "district": "Peninsula School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669001863",
    },
    {
        "school": "Minter Creek Elementary",
        "district": "Peninsula School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669002007",
    },
    {
        "school": "Voyager Elementary",
        "district": "Peninsula School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669002266",
    },
    {
        "school": "Harbor Ridge Middle School",
        "district": "Peninsula School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530669002436",
    },
    {
        "school": "Henderson Bay Alt High School",
        "district": "Peninsula School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530669002463",
    },
    {
        "school": "Shaw Road Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696000691",
    },
    {
        "school": "Aylen Jr High",
        "district": "Puyallup School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001022",
    },
    {
        "school": "Walker High School",
        "district": "Puyallup School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530696001023",
    },
    {
        "school": "Edgemont Jr High",
        "district": "Puyallup School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001024",
    },
    {
        "school": "Firgrove Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001025",
    },
    {
        "school": "Ballou Jr High",
        "district": "Puyallup School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001026",
    },
    {
        "school": "Fruitland Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001027",
    },
    {
        "school": "Rogers High School",
        "district": "Puyallup School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001028",
    },
    {
        "school": "Stewart Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001031",
    },
    {
        "school": "Kalles Junior High",
        "district": "Puyallup School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001032",
    },
    {
        "school": "Karshner Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001033",
    },
    {
        "school": "Maplewood Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001034",
    },
    {
        "school": "Meeker Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001035",
    },
    {
        "school": "Mt View Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001036",
    },
    {
        "school": "Northwood Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001037",
    },
    {
        "school": "Puyallup High School",
        "district": "Puyallup School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001038",
    },
    {
        "school": "Spinning Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001040",
    },
    {
        "school": "Sunrise Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001041",
    },
    {
        "school": "Waller Road Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001042",
    },
    {
        "school": "Wildwood Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001043",
    },
    {
        "school": "Woodland Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001044",
    },
    {
        "school": "Stahl Junior High",
        "district": "Puyallup School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001178",
    },
    {
        "school": "Ridgecrest Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001795",
    },
    {
        "school": "Ferrucci Jr High",
        "district": "Puyallup School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001865",
    },
    {
        "school": "Pope Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696001866",
    },
    {
        "school": "Brouillet Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696002340",
    },
    {
        "school": "Hunt Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696002341",
    },
    {
        "school": "Zeiger Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696002530",
    },
    {
        "school": "Emerald Ridge High School",
        "district": "Puyallup School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696002809",
    },
    {
        "school": "Cherrydale Elementary",
        "district": "Steilacoom Hist. School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530846001429",
    },
    {
        "school": "Anderson Island Elementary",
        "district": "Steilacoom Hist. School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530846001430",
    },
    {
        "school": "Pioneer Middle",
        "district": "Steilacoom Hist. School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530846001431",
    },
    {
        "school": "Saltars Point Elementary",
        "district": "Steilacoom Hist. School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530846001432",
    },
    {
        "school": "Steilacoom High",
        "district": "Steilacoom Hist. School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530846001807",
    },
    {
        "school": "Chloe Clark Elementary",
        "district": "Steilacoom Hist. School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530846002879",
    },
    {
        "school": "Liberty Ridge Elementary",
        "district": "Sumner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861000552",
    },
    {
        "school": "Bonney Lake Elementary",
        "district": "Sumner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861001441",
    },
    {
        "school": "Maple Lawn Elementary",
        "district": "Sumner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861001444",
    },
    {
        "school": "Eismann Elementary",
        "district": "Sumner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861001445",
    },
    {
        "school": "Sumner High School",
        "district": "Sumner School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861001446",
    },
    {
        "school": "Sumner Middle School",
        "district": "Sumner School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861001447",
    },
    {
        "school": "Lakeridge Middle School",
        "district": "Sumner School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861001808",
    },
    {
        "school": "Victor Falls Elementary",
        "district": "Sumner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861001886",
    },
    {
        "school": "Emerald Hills Elementary",
        "district": "Sumner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861002169",
    },
    {
        "school": "Mountain View Middle School",
        "district": "Sumner School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861002580",
    },
    {
        "school": "Crestwood Elementary",
        "district": "Sumner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861002665",
    },
    {
        "school": "Daffodil Valley Elementary",
        "district": "Sumner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861002744",
    },
    {
        "school": "Arlington",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001453",
    },
    {
        "school": "Baker",
        "district": "Tacoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001454",
    },
    {
        "school": "Birney",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001455",
    },
    {
        "school": "Boze",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001456",
    },
    {
        "school": "Browns Point",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001457",
    },
    {
        "school": "Bryant",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001458",
    },
    {
        "school": "Delong",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001460",
    },
    {
        "school": "Downing",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001461",
    },
    {
        "school": "Edison",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001462",
    },
    {
        "school": "Fawcett",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001464",
    },
    {
        "school": "Fern Hill",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001465",
    },
    {
        "school": "Foss",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001466",
    },
    {
        "school": "Franklin",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001467",
    },
    {
        "school": "Geiger",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001469",
    },
    {
        "school": "Grant",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001470",
    },
    {
        "school": "Gray",
        "district": "Tacoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001471",
    },
    {
        "school": "Jason Lee",
        "district": "Tacoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001473",
    },
    {
        "school": "Jefferson",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001474",
    },
    {
        "school": "Larchmont",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001475",
    },
    {
        "school": "Lincoln",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001476",
    },
    {
        "school": "Lister",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001477",
    },
    {
        "school": "Lowell",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001478",
    },
    {
        "school": "Lyon",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001479",
    },
    {
        "school": "Manitou Park",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001481",
    },
    {
        "school": "Mann",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001482",
    },
    {
        "school": "Mason",
        "district": "Tacoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001483",
    },
    {
        "school": "McCarver",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001484",
    },
    {
        "school": "Meeker",
        "district": "Tacoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001487",
    },
    {
        "school": "Mt Tahoma",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001488",
    },
    {
        "school": "Northeast Tacoma",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001489",
    },
    {
        "school": "Point Defiance",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001493",
    },
    {
        "school": "Reed",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001494",
    },
    {
        "school": "Blix Elementary",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001496",
    },
    {
        "school": "Roosevelt",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001497",
    },
    {
        "school": "Sheridan",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001500",
    },
    {
        "school": "Sherman",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001501",
    },
    {
        "school": "Stadium",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001502",
    },
    {
        "school": "Stewart",
        "district": "Tacoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001504",
    },
    {
        "school": "Skyline",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001506",
    },
    {
        "school": "Truman",
        "district": "Tacoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001507",
    },
    {
        "school": "Wainwright",
        "district": "Tacoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001508",
    },
    {
        "school": "Washington Elementary",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001509",
    },
    {
        "school": "Whitman",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001510",
    },
    {
        "school": "Whittier",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001511",
    },
    {
        "school": "Wilson",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870001513",
    },
    {
        "school": "Oakland High School",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530870001811",
    },
    {
        "school": "Remann Hall Juvenile Detention Center",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870002171",
    },
    {
        "school": "Stanley",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870002174",
    },
    {
        "school": "Pearl Street Center",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530870002177",
    },
    {
        "school": "Comm Based Trans Program",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530870002413",
    },
    {
        "school": "Crescent Heights",
        "district": "Tacoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870002742",
    },
    {
        "school": "TCC Fresh Start",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870002810",
    },
    {
        "school": "Tacoma School of the Arts",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870002846",
    },
    {
        "school": "Evergreen Primary",
        "district": "University Place School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530918001179",
    },
    {
        "school": "Curtis Junior High",
        "district": "University Place School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530918001548",
    },
    {
        "school": "Curtis Senior High",
        "district": "University Place School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530918001549",
    },
    {
        "school": "Narrows View Intermediate",
        "district": "University Place School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530918001550",
    },
    {
        "school": "Sunset Primary",
        "district": "University Place School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530918001551",
    },
    {
        "school": "Chambers Elementary",
        "district": "University Place School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530918001552",
    },
    {
        "school": "University Place Primary",
        "district": "University Place School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530918001553",
    },
    {
        "school": "Drum Intermediate",
        "district": "University Place School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530918002383",
    },
    {
        "school": "Elk Ridge Elementary",
        "district": "White River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530978001661",
    },
    {
        "school": "Mountain Meadow Elementary",
        "district": "White River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530978001720",
    },
    {
        "school": "Wilkeson Elementary School",
        "district": "White River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530978001894",
    },
    {
        "school": "Foothills Elementary",
        "district": "White River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530978002245",
    },
    {
        "school": "Olympic Middle School",
        "district": "Shelton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530790002990",
    },
    {
        "school": "Grapeview Elementary & Middle School",
        "district": "Grapeview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530324000507",
    },
    {
        "school": "Hood Canal Elementary School",
        "district": "Hood Canal School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530360000561",
    },
    {
        "school": "Belfair Elementary",
        "district": "North Mason School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530579000857",
    },
    {
        "school": "North Mason Senior High School",
        "district": "North Mason School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530579000859",
    },
    {
        "school": "Hawkins Middle School",
        "district": "North Mason School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530579000860",
    },
    {
        "school": "Sand Hill Elementary",
        "district": "North Mason School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530579002220",
    },
    {
        "school": "James A. Taylor High School",
        "district": "North Mason School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530579002577",
    },
    {
        "school": "North Mason Homelink Program",
        "district": "North Mason School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530579002847",
    },
    {
        "school": "Pioneer Middle School",
        "district": "Pioneer School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530675000992",
    },
    {
        "school": "Pioneer Elementary School",
        "district": "Pioneer School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530675002457",
    },
    {
        "school": "Bordeaux Elementary School",
        "district": "Shelton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530790001292",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Shelton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530790001293",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Shelton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530790001294",
    },
    {
        "school": "Shelton High School",
        "district": "Shelton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530790001295",
    },
    {
        "school": "Choice Middle and High School",
        "district": "Shelton School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530790002151",
    },
    {
        "school": "Oakland Bay Junior High School",
        "district": "Shelton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530790002353",
    },
    {
        "school": "Mason County Detention Center",
        "district": "Shelton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530790002865",
    },
    {
        "school": "Southside Elementary",
        "district": "Southside School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530822001360",
    },
    {
        "school": "Martin Hall Detention Ctr",
        "district": "Educational Service District 101",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530001002919",
    },
    {
        "school": "Structural Alt Confinement School",
        "district": "Educational Service District 101",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530001002929",
    },
    {
        "school": "Spokane Juvenile Detention School",
        "district": "Educational Service District 101",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530001002930",
    },
    {
        "school": "School to Life",
        "district": "Central Valley School District",
        "level": "High",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530111003012",
    },
    {
        "school": "Spokane Valley Learning Academy",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111003137",
    },
    {
        "school": "HomeWorks",
        "district": "Cheney School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530123003014",
    },
    {
        "school": "Children First",
        "district": "East Valley School District (Spokane)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530228003111",
    },
    {
        "school": "Freeman Middle School",
        "district": "Freeman School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530297003013",
    },
    {
        "school": "Prairie View Elementary",
        "district": "Mead School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492003193",
    },
    {
        "school": "Medical Lake Endeavors",
        "district": "Medical Lake School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530495003056",
    },
    {
        "school": "Michael Anderson Elementary",
        "district": "Medical Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530495003157",
    },
    {
        "school": "Independent Scholar",
        "district": "Riverside School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530744002908",
    },
    {
        "school": "Adams Elementary",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000187",
    },
    {
        "school": "Summit School",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000188",
    },
    {
        "school": "Bowdish Middle School",
        "district": "Central Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000189",
    },
    {
        "school": "Broadway Elementary",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000190",
    },
    {
        "school": "Central Valley High School",
        "district": "Central Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000191",
    },
    {
        "school": "Chester Elementary School",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000192",
    },
    {
        "school": "Evergreen Middle School",
        "district": "Central Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000193",
    },
    {
        "school": "Greenacres Elementary",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000194",
    },
    {
        "school": "Greenacres Middle School",
        "district": "Central Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000195",
    },
    {
        "school": "McDonald Elementary School",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000197",
    },
    {
        "school": "North Pines Middle School",
        "district": "Central Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000198",
    },
    {
        "school": "Opportunity Elementary",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000199",
    },
    {
        "school": "Progress Elementary School",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000200",
    },
    {
        "school": "South Pines Elementary",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000201",
    },
    {
        "school": "Mica Peak High School",
        "district": "Central Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530111000202",
    },
    {
        "school": "University Elementary School",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000203",
    },
    {
        "school": "University High School",
        "district": "Central Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111000204",
    },
    {
        "school": "Ponderosa Elementary",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111001756",
    },
    {
        "school": "Horizon Middle School",
        "district": "Central Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111001826",
    },
    {
        "school": "Sunrise Elementary",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111001827",
    },
    {
        "school": "Liberty Lake Elementary",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111002681",
    },
    {
        "school": "Betz Elementary",
        "district": "Cheney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530123000221",
    },
    {
        "school": "Cheney High School",
        "district": "Cheney School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530123000223",
    },
    {
        "school": "Cheney Middle School",
        "district": "Cheney School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530123000224",
    },
    {
        "school": "Salnave Elementary",
        "district": "Cheney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530123000226",
    },
    {
        "school": "Sunset Elementary",
        "district": "Cheney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530123000227",
    },
    {
        "school": "Windsor Elementary",
        "district": "Cheney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530123000228",
    },
    {
        "school": "Three Springs High School",
        "district": "Cheney School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530123002684",
    },
    {
        "school": "Arcadia Elementary",
        "district": "Deer Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530207000306",
    },
    {
        "school": "Deer Park Elementary",
        "district": "Deer Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530207000307",
    },
    {
        "school": "Deer Park Middle School",
        "district": "Deer Park School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530207000308",
    },
    {
        "school": "Deer Park High School",
        "district": "Deer Park School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530207001759",
    },
    {
        "school": "Deer Park Home Link Program",
        "district": "Deer Park School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530207002827",
    },
    {
        "school": "East Valley High School",
        "district": "East Valley School District (Spokane)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530228000312",
    },
    {
        "school": "Otis Orchards School",
        "district": "East Valley School District (Spokane)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530228000314",
    },
    {
        "school": "Trent School",
        "district": "East Valley School District (Spokane)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530228000315",
    },
    {
        "school": "Trentwood School",
        "district": "East Valley School District (Spokane)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530228000316",
    },
    {
        "school": "East Farms School",
        "district": "East Valley School District (Spokane)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530228001760",
    },
    {
        "school": "Continuous Curriculum School",
        "district": "East Valley School District (Spokane)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530228002600",
    },
    {
        "school": "Freeman Elementary School",
        "district": "Freeman School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530297000484",
    },
    {
        "school": "Freeman High School",
        "district": "Freeman School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530297000485",
    },
    {
        "school": "Great Northern Elementary",
        "district": "Great Northern School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530327000508",
    },
    {
        "school": "Liberty High School",
        "district": "Liberty School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530438000693",
    },
    {
        "school": "Liberty Jr High & Elementary",
        "district": "Liberty School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530438001908",
    },
    {
        "school": "Meadow Ridge Elementary",
        "district": "Mead School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492000545",
    },
    {
        "school": "Brentwood Elementary School",
        "district": "Mead School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492000743",
    },
    {
        "school": "Colbert Elementary School",
        "district": "Mead School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492000744",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "Mead School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492000745",
    },
    {
        "school": "Farwell Elementary School",
        "district": "Mead School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492000746",
    },
    {
        "school": "Mountainside Middle School",
        "district": "Mead School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492000747",
    },
    {
        "school": "Northwood Middle School",
        "district": "Mead School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492000748",
    },
    {
        "school": "Mead Senior High School",
        "district": "Mead School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492000749",
    },
    {
        "school": "Shiloh Hills Elementary",
        "district": "Mead School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492001789",
    },
    {
        "school": "Midway Elementary",
        "district": "Mead School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492001804",
    },
    {
        "school": "Mt Spokane High School",
        "district": "Mead School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492002599",
    },
    {
        "school": "Mead Education Partnership Prog",
        "district": "Mead School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530492002844",
    },
    {
        "school": "Medical Lake High School",
        "district": "Medical Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530495000755",
    },
    {
        "school": "Medical Lake Middle School",
        "district": "Medical Lake School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530495000756",
    },
    {
        "school": "Hallett Elementary",
        "district": "Medical Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530495002487",
    },
    {
        "school": "Lake Spokane Elementary",
        "district": "Nine Mile Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530564000836",
    },
    {
        "school": "Nine Mile Falls Elementary",
        "district": "Nine Mile Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530564000837",
    },
    {
        "school": "Lakeside High School",
        "district": "Nine Mile Falls School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530564002321",
    },
    {
        "school": "Lakeside Middle School",
        "district": "Nine Mile Falls School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530564002680",
    },
    {
        "school": "Orchard Prairie Elementary",
        "district": "Orchard Prairie School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530633000947",
    },
    {
        "school": "Chattaroy Elementary",
        "district": "Riverside School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530744001112",
    },
    {
        "school": "Riverside Middle School",
        "district": "Riverside School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530744001114",
    },
    {
        "school": "Riverside Elementary",
        "district": "Riverside School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530744001115",
    },
    {
        "school": "Riverside High School",
        "district": "Riverside School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530744002013",
    },
    {
        "school": "Alternative Tamarack School",
        "district": "Spokane School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825000074",
    },
    {
        "school": "Adams Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001361",
    },
    {
        "school": "Arlington Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001362",
    },
    {
        "school": "Audubon Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001363",
    },
    {
        "school": "Balboa Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001364",
    },
    {
        "school": "Bemiss Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001366",
    },
    {
        "school": "Browne Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001368",
    },
    {
        "school": "Cooper Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001370",
    },
    {
        "school": "Finch Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001373",
    },
    {
        "school": "Franklin Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001374",
    },
    {
        "school": "Garfield Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001375",
    },
    {
        "school": "Glover Middle School",
        "district": "Spokane School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001377",
    },
    {
        "school": "Grant Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001378",
    },
    {
        "school": "Hamblen Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001379",
    },
    {
        "school": "Holmes Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001381",
    },
    {
        "school": "Hutton Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001382",
    },
    {
        "school": "Indian Trail Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001383",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001384",
    },
    {
        "school": "Ferris High School",
        "district": "Spokane School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001385",
    },
    {
        "school": "Rogers High School",
        "district": "Spokane School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001386",
    },
    {
        "school": "Lewis & Clark High School",
        "district": "Spokane School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001388",
    },
    {
        "school": "Lidgerwood Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001390",
    },
    {
        "school": "Lincoln Heights Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001391",
    },
    {
        "school": "Linwood Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001392",
    },
    {
        "school": "Logan Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001393",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001395",
    },
    {
        "school": "Madison Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001396",
    },
    {
        "school": "Excelsior Youth Center School",
        "district": "Spokane School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001397",
    },
    {
        "school": "Mullan Road Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001398",
    },
    {
        "school": "North Central High School",
        "district": "Spokane School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001399",
    },
    {
        "school": "Regal Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001402",
    },
    {
        "school": "Ridgeview Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001403",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001404",
    },
    {
        "school": "Sacajawea Middle School",
        "district": "Spokane School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001405",
    },
    {
        "school": "Salk Middle School",
        "district": "Spokane School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001406",
    },
    {
        "school": "Shadle Park High School",
        "district": "Spokane School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001407",
    },
    {
        "school": "Shaw Middle School",
        "district": "Spokane School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001408",
    },
    {
        "school": "Sheridan Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001409",
    },
    {
        "school": "Garry Middle School",
        "district": "Spokane School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001411",
    },
    {
        "school": "Stevens Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001412",
    },
    {
        "school": "Westview Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001413",
    },
    {
        "school": "Whitman Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001414",
    },
    {
        "school": "Willard Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001415",
    },
    {
        "school": "Wilson Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001416",
    },
    {
        "school": "Chase Middle School",
        "district": "Spokane School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001732",
    },
    {
        "school": "Woodridge Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825001883",
    },
    {
        "school": "Daybreak Alternative School",
        "district": "Spokane School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530825002162",
    },
    {
        "school": "Spokane Area Professional-Technical Skills Center",
        "district": "Spokane School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530825002164",
    },
    {
        "school": "A-3 Multiagency Adolescent Prog",
        "district": "Spokane School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825002361",
    },
    {
        "school": "Alternative Northeast Community Center Preschool",
        "district": "Spokane School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825002362",
    },
    {
        "school": "Pratt Academy",
        "district": "Spokane School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530825002364",
    },
    {
        "school": "Moran Prairie Elementary",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825002366",
    },
    {
        "school": "Libby Center",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530825002484",
    },
    {
        "school": "SCCP Images",
        "district": "Spokane School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530825002534",
    },
    {
        "school": "The Healing Lodge",
        "district": "Spokane School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825002678",
    },
    {
        "school": "Bryant Center",
        "district": "Spokane School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530825002764",
    },
    {
        "school": "Ness Elementary",
        "district": "West Valley School District (Spokane)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530969001641",
    },
    {
        "school": "Millwood Kindergarten Center",
        "district": "West Valley School District (Spokane)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530969001643",
    },
    {
        "school": "Orchard Center Elementary",
        "district": "West Valley School District (Spokane)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530969001644",
    },
    {
        "school": "Centennial Middle School",
        "district": "West Valley School District (Spokane)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530969001645",
    },
    {
        "school": "Pasadena Park Elementary",
        "district": "West Valley School District (Spokane)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530969001646",
    },
    {
        "school": "West Valley High School",
        "district": "West Valley School District (Spokane)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530969001648",
    },
    {
        "school": "Dishman Hills High School",
        "district": "West Valley School District (Spokane)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530969002244",
    },
    {
        "school": "Seth Woodard Elementary",
        "district": "West Valley School District (Spokane)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530969002419",
    },
    {
        "school": "West Valley City School",
        "district": "West Valley School District (Spokane)",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530969002685",
    },
    {
        "school": "Spokane Valley High School",
        "district": "West Valley School District (Spokane)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530969002826",
    },
    {
        "school": "Spokane Valley Transition School",
        "district": "West Valley School District (Spokane)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530969002840",
    },
    {
        "school": "Davis Elementary",
        "district": "College Place School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530147000275",
    },
    {
        "school": "John Sager Middle School",
        "district": "College Place School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530147000276",
    },
    {
        "school": "Columbia Elementary",
        "district": "Columbia (Walla Walla) School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530159000279",
    },
    {
        "school": "Columbia Middle School",
        "district": "Columbia (Walla Walla) School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530159000280",
    },
    {
        "school": "Columbia High School",
        "district": "Columbia (Walla Walla) School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530159001758",
    },
    {
        "school": "Dixie Elementary School",
        "district": "Dixie School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530216000311",
    },
    {
        "school": "Prescott Elementary School",
        "district": "Prescott School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530687001009",
    },
    {
        "school": "Prescott Jr Sr High",
        "district": "Prescott School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530687001010",
    },
    {
        "school": "Touchet Elem & High School",
        "district": "Touchet School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530900001536",
    },
    {
        "school": "Waitsburg Elementary School",
        "district": "Waitsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530939001596",
    },
    {
        "school": "Waitsburg High School",
        "district": "Waitsburg School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530939001597",
    },
    {
        "school": "Preston Hall Middle School",
        "district": "Waitsburg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530939002492",
    },
    {
        "school": "Berney Elementary School",
        "district": "Walla Walla Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530945001599",
    },
    {
        "school": "Edison Elementary School - Walla Walla",
        "district": "Walla Walla Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530945001600",
    },
    {
        "school": "Garrison Middle School",
        "district": "Walla Walla Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530945001601",
    },
    {
        "school": "Green Park Elementary School",
        "district": "Walla Walla Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530945001602",
    },
    {
        "school": "Pioneer Middle School",
        "district": "Walla Walla Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530945001605",
    },
    {
        "school": "Prospect Point Elementary",
        "district": "Walla Walla Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530945001606",
    },
    {
        "school": "Lincoln High School",
        "district": "Walla Walla Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530945001607",
    },
    {
        "school": "Sharpstein Elementary School",
        "district": "Walla Walla Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530945001608",
    },
    {
        "school": "Walla Walla High School",
        "district": "Walla Walla Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530945001609",
    },
    {
        "school": "Blue Ridge Elementary",
        "district": "Walla Walla Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530945001891",
    },
    {
        "school": "Beaver Valley School",
        "district": "Cascade School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530095002937",
    },
    {
        "school": "Chelan School of Innovation",
        "district": "Lake Chelan School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530120003114",
    },
    {
        "school": "Bridgeport Aurora High School",
        "district": "Bridgeport School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530072002890",
    },
    {
        "school": "Canyon View Group Home",
        "district": "Eastmont School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530231002913",
    },
    {
        "school": "Clovis Point",
        "district": "Eastmont School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530231002948",
    },
    {
        "school": "Icicle River Middle School",
        "district": "Cascade School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530095000553",
    },
    {
        "school": "Peshastin Dryden Elementary",
        "district": "Cascade School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530095001933",
    },
    {
        "school": "Alpine Lakes Elementary",
        "district": "Cascade School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530095001934",
    },
    {
        "school": "Cascade High School",
        "district": "Cascade School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530095001935",
    },
    {
        "school": "CASHMERE HIGH SCHOOL",
        "district": "CASHMERE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530096000168",
    },
    {
        "school": "CASHMERE MIDDLE SCHOOL",
        "district": "CASHMERE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530096000169",
    },
    {
        "school": "VALE ELEMENTARY SCHOOL",
        "district": "CASHMERE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530096000170",
    },
    {
        "school": "Chelan Middle School",
        "district": "Lake Chelan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530120000218",
    },
    {
        "school": "Holden Village Community School",
        "district": "Lake Chelan School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530120000219",
    },
    {
        "school": "Morgen Owings Elementary School",
        "district": "Lake Chelan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530120000220",
    },
    {
        "school": "Lake Chelan Preschool",
        "district": "Lake Chelan School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530120002016",
    },
    {
        "school": "Chelan High School",
        "district": "Lake Chelan School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530120002058",
    },
    {
        "school": "Entiat Middle and High School",
        "district": "Entiat School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530255000374",
    },
    {
        "school": "Paul Rumburg Elementary",
        "district": "Entiat School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530255000375",
    },
    {
        "school": "Manson Elementary",
        "district": "Manson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530474000727",
    },
    {
        "school": "Manson High School",
        "district": "Manson School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530474000728",
    },
    {
        "school": "Stehekin Elementary",
        "district": "Stehekin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530843001428",
    },
    {
        "school": "Skill Source",
        "district": "Wenatchee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530966000097",
    },
    {
        "school": "John Newbery Elementary",
        "district": "Wenatchee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966000991",
    },
    {
        "school": "Foothills Middle School",
        "district": "Wenatchee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966001006",
    },
    {
        "school": "Columbia Elementary School",
        "district": "Wenatchee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966001630",
    },
    {
        "school": "Lewis And Clark Elementary Sch",
        "district": "Wenatchee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966001631",
    },
    {
        "school": "Abraham Lincoln Elementary",
        "district": "Wenatchee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966001632",
    },
    {
        "school": "Mission View Elementary School",
        "district": "Wenatchee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966001633",
    },
    {
        "school": "Orchard Middle School",
        "district": "Wenatchee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966001634",
    },
    {
        "school": "Pioneer Middle School",
        "district": "Wenatchee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966001635",
    },
    {
        "school": "Castlerock Early Learning Center",
        "district": "Wenatchee School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530966001636",
    },
    {
        "school": "Sunnyslope Elementary School",
        "district": "Wenatchee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966001637",
    },
    {
        "school": "Washington Elementary School",
        "district": "Wenatchee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966001638",
    },
    {
        "school": "Wenatchee High School",
        "district": "Wenatchee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966001639",
    },
    {
        "school": "Westside High School",
        "district": "Wenatchee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530966002193",
    },
    {
        "school": "Chelan County Juvenile Detention Center",
        "district": "Wenatchee School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530966002706",
    },
    {
        "school": "Bridgeport Elementary",
        "district": "Bridgeport School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530072000150",
    },
    {
        "school": "Bridgeport High School",
        "district": "Bridgeport School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530072000151",
    },
    {
        "school": "Bridgeport Middle School",
        "district": "Bridgeport School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530072001271",
    },
    {
        "school": "Cascade Elementary",
        "district": "Eastmont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530231000317",
    },
    {
        "school": "Eastmont Senior High",
        "district": "Eastmont School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530231000318",
    },
    {
        "school": "Grant Elementary School",
        "district": "Eastmont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530231000319",
    },
    {
        "school": "Kenroy Elementary",
        "district": "Eastmont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530231000320",
    },
    {
        "school": "Lee Elementary",
        "district": "Eastmont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530231000321",
    },
    {
        "school": "Rock Island Elementary",
        "district": "Eastmont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530231000322",
    },
    {
        "school": "Eastmont Junior High",
        "district": "Eastmont School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530231000323",
    },
    {
        "school": "Sterling School",
        "district": "Eastmont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530231001762",
    },
    {
        "school": "Mansfield Elem and High School",
        "district": "Mansfield School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530471000726",
    },
    {
        "school": "Orondo Elementary and Middle School",
        "district": "Orondo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530639000949",
    },
    {
        "school": "Palisades Elementary School",
        "district": "Palisades School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530651000959",
    },
    {
        "school": "Waterville High School",
        "district": "Waterville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530960001628",
    },
    {
        "school": "Waterville Elementary",
        "district": "Waterville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530960002192",
    },
    {
        "school": "Highland Junior High School",
        "district": "Highland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530351003148",
    },
    {
        "school": "Valley View Elementary",
        "district": "Toppenish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530897003027",
    },
    {
        "school": "West Valley Preschool",
        "district": "West Valley School District (Yakima)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530972003029",
    },
    {
        "school": "Children's Village",
        "district": "West Valley School District (Yakima)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530972003173",
    },
    {
        "school": "Juvenile Detention Center",
        "district": "Yakima School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011002932",
    },
    {
        "school": "Early Childhood Center",
        "district": "Yakima School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "531011003026",
    },
    {
        "school": "Smith Elementary School",
        "district": "Grandview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530315000497",
    },
    {
        "school": "Grandview Middle School",
        "district": "Grandview School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530315000498",
    },
    {
        "school": "Grandview High School",
        "district": "Grandview School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530315000499",
    },
    {
        "school": "Thompson Elementary School",
        "district": "Grandview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530315000500",
    },
    {
        "school": "Mcclure Elementary School",
        "district": "Grandview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530315000501",
    },
    {
        "school": "Contract Learning Center",
        "district": "Grandview School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530315002701",
    },
    {
        "school": "Granger High School",
        "district": "Granger School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530318000502",
    },
    {
        "school": "Granger Middle School",
        "district": "Granger School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530318000504",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Granger School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530318002780",
    },
    {
        "school": "Tieton Intermediate School",
        "district": "Highland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530351000517",
    },
    {
        "school": "Marcus Whitman-Cowiche Elementary",
        "district": "Highland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530351000518",
    },
    {
        "school": "Highland High School",
        "district": "Highland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530351002876",
    },
    {
        "school": "Artz Fox Elementary",
        "district": "Mabton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530465000723",
    },
    {
        "school": "Harrah Elementary School",
        "district": "Mount Adams School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530528000797",
    },
    {
        "school": "White Swan High School",
        "district": "Mount Adams School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530528000798",
    },
    {
        "school": "Mount Adams Middle School",
        "district": "Mount Adams School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530528001851",
    },
    {
        "school": "East Valley High School",
        "district": "East Valley School District (Yakima)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530537000805",
    },
    {
        "school": "East Valley Central Middle School",
        "district": "East Valley School District (Yakima)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530537000806",
    },
    {
        "school": "Moxee Elementary",
        "district": "East Valley School District (Yakima)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530537000807",
    },
    {
        "school": "Terrace Heights Elementary",
        "district": "East Valley School District (Yakima)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530537000808",
    },
    {
        "school": "East Valley Elementary",
        "district": "East Valley School District (Yakima)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530537002543",
    },
    {
        "school": "Naches Valley Middle School",
        "district": "Naches Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530546000824",
    },
    {
        "school": "Naches Valley High School",
        "district": "Naches Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530546000825",
    },
    {
        "school": "Selah High School",
        "district": "Selah School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530777001282",
    },
    {
        "school": "Selah Academy Online",
        "district": "Selah School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530777002149",
    },
    {
        "school": "Outlook Elementary School",
        "district": "Sunnyside School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530867001448",
    },
    {
        "school": "Sunnyside High School",
        "district": "Sunnyside School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530867001449",
    },
    {
        "school": "Chief Kamiakin Elementary School",
        "district": "Sunnyside School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530867001450",
    },
    {
        "school": "Harrison Middle School",
        "district": "Sunnyside School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530867001451",
    },
    {
        "school": "Washington Elementary",
        "district": "Sunnyside School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530867001452",
    },
    {
        "school": "Pioneer Elementary School",
        "district": "Sunnyside School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530867002544",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Toppenish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530897001531",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Toppenish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530897001532",
    },
    {
        "school": "Toppenish High School",
        "district": "Toppenish School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530897001534",
    },
    {
        "school": "Toppenish Middle School",
        "district": "Toppenish School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530897001535",
    },
    {
        "school": "Kirkwood Elementary School",
        "district": "Toppenish School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530897001812",
    },
    {
        "school": "Computer Academy Toppenish High School",
        "district": "Toppenish School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530897002378",
    },
    {
        "school": "Toppenish Pre School",
        "district": "Toppenish School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530897002835",
    },
    {
        "school": "Union Gap School",
        "district": "Union Gap School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530915002382",
    },
    {
        "school": "Pace Alternative High School",
        "district": "Wapato School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530948001611",
    },
    {
        "school": "Wapato Middle School",
        "district": "Wapato School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530948001615",
    },
    {
        "school": "Satus Elementary",
        "district": "Wapato School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530948001616",
    },
    {
        "school": "Wapato High School",
        "district": "Wapato School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530948001617",
    },
    {
        "school": "Adams Elementary",
        "district": "Wapato School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530948002611",
    },
    {
        "school": "Cottonwood Elementary School",
        "district": "West Valley School District (Yakima)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972001238",
    },
    {
        "school": "Ahtanum Valley Elementary",
        "district": "West Valley School District (Yakima)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972001649",
    },
    {
        "school": "Apple Valley Elementary",
        "district": "West Valley School District (Yakima)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972001650",
    },
    {
        "school": "Mountainview Elementary",
        "district": "West Valley School District (Yakima)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972001651",
    },
    {
        "school": "Summitview Elementary",
        "district": "West Valley School District (Yakima)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972001652",
    },
    {
        "school": "West Valley Jr High",
        "district": "West Valley School District (Yakima)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972001653",
    },
    {
        "school": "West Valley High School",
        "district": "West Valley School District (Yakima)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972001654",
    },
    {
        "school": "Wide Hollow Elementary",
        "district": "West Valley School District (Yakima)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972001655",
    },
    {
        "school": "West Valley Middle School",
        "district": "West Valley School District (Yakima)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972002545",
    },
    {
        "school": "Adams Elementary School",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001685",
    },
    {
        "school": "Barge-Lincoln Elementary School",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001686",
    },
    {
        "school": "Ridgeview Elementary",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001687",
    },
    {
        "school": "Davis High School",
        "district": "Yakima School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001689",
    },
    {
        "school": "Eisenhower High School",
        "district": "Yakima School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001690",
    },
    {
        "school": "Franklin Middle School",
        "district": "Yakima School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001691",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001692",
    },
    {
        "school": "Gilbert Elementary School",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001693",
    },
    {
        "school": "Hoover Elementary School",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001694",
    },
    {
        "school": "Lewis & Clark Middle School",
        "district": "Yakima School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001698",
    },
    {
        "school": "Mcclure Elementary School Yakima",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001699",
    },
    {
        "school": "Mckinley Elementary School",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001700",
    },
    {
        "school": "Nob Hill Elementary School",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001701",
    },
    {
        "school": "Robertson Elementary",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001703",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001704",
    },
    {
        "school": "Washington Middle School",
        "district": "Yakima School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001708",
    },
    {
        "school": "Whitney Elementary Yakima",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001709",
    },
    {
        "school": "Wilson Middle School",
        "district": "Yakima School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001710",
    },
    {
        "school": "Stanton Academy",
        "district": "Yakima School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "531011001713",
    },
    {
        "school": "Martin Luther King Jr Elementary",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011001814",
    },
    {
        "school": "Yakima Valley Technical Skills Center",
        "district": "Yakima School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "531011002195",
    },
    {
        "school": "Discovery Lab School",
        "district": "Yakima School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011002609",
    },
    {
        "school": "Hilton Elementary School",
        "district": "Zillah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531017001718",
    },
    {
        "school": "Zillah High School",
        "district": "Zillah School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531017001719",
    },
    {
        "school": "Zillah Intermediate School",
        "district": "Zillah School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531017001896",
    },
    {
        "school": "Zillah Middle School",
        "district": "Zillah School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531017002502",
    },
    {
        "school": "Metro School",
        "district": "Madison Metropolitan School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550852002670",
    },
    {
        "school": "Glacier Edge Elementary",
        "district": "Verona Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533002647",
    },
    {
        "school": "Arboretum Elementary",
        "district": "Waunakee Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551581002648",
    },
    {
        "school": "Second Avenue School",
        "district": "Eau Claire Area School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550405002658",
    },
    {
        "school": "Oxford Avenue School",
        "district": "Eau Claire Area School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550405002675",
    },
    {
        "school": "Watertown 4 Kids",
        "district": "Watertown Unified School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551575002661",
    },
    {
        "school": "Trevor-Wilmot Grade",
        "district": "Trevor-Wilmot Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550005202644",
    },
    {
        "school": "Mountain Bay Elementary",
        "district": "D C Everest Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317002643",
    },
    {
        "school": "Milwaukee County Correctional Facility South",
        "district": "Franklin Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550483002685",
    },
    {
        "school": "CORE4",
        "district": "Whitnall School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550600002673",
    },
    {
        "school": "Early Learning Academy",
        "district": "Oak Creek-Franklin Joint School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551083002659",
    },
    {
        "school": "Stephen Foster Elementary Charter",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002639",
    },
    {
        "school": "Appleton Cooperative Educational Center",
        "district": "Appleton Area School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550039002679",
    },
    {
        "school": "Woodland School",
        "district": "Kimberly Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550747002641",
    },
    {
        "school": "Mapleview Intermediate",
        "district": "Kimberly Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550747002642",
    },
    {
        "school": "All District 4 Year Old Kindergarten",
        "district": "Racine Unified School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236002657",
    },
    {
        "school": "Merrimac Community",
        "district": "Sauk Prairie School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551341002663",
    },
    {
        "school": "Washington Street School",
        "district": "West Bend School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551629002666",
    },
    {
        "school": "Ronald Reagan Elementary",
        "district": "New Berlin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551047002667",
    },
    {
        "school": "Merrill Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119002681",
    },
    {
        "school": "Marshfield K4",
        "district": "Marshfield Unified School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550882002672",
    },
    {
        "school": "Markesan Intermediate",
        "district": "Markesan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550876002597",
    },
    {
        "school": "Grayside Elementary",
        "district": "Mauston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550885002574",
    },
    {
        "school": "Westfield Area Middle",
        "district": "Westfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551644002535",
    },
    {
        "school": "Sparta High Point School",
        "district": "Sparta Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551416002542",
    },
    {
        "school": "Lakeview Montessori School",
        "district": "Sparta Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551416003358",
    },
    {
        "school": "Robert Kupper Learning Center",
        "district": "Tomah Area School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551491002543",
    },
    {
        "school": "Hayward Ctr for Individualized Learning",
        "district": "Hayward Community School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550627003339",
    },
    {
        "school": "Rural Virtual Academy",
        "district": "Medford Area Public School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550894002598",
    },
    {
        "school": "Birchwood Middle",
        "district": "Birchwood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550117003374",
    },
    {
        "school": "Tri-County Middle",
        "district": "Tri-County Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551182002620",
    },
    {
        "school": "Adams-Friendship High",
        "district": "Adams-Friendship Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006000005",
    },
    {
        "school": "Grand Marsh Elementary",
        "district": "Adams-Friendship Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006000010",
    },
    {
        "school": "Adams-Friendship Elementary",
        "district": "Adams-Friendship Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006001433",
    },
    {
        "school": "Adams-Friendship Middle",
        "district": "Adams-Friendship Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006001454",
    },
    {
        "school": "Ashland High",
        "district": "Ashland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550051000073",
    },
    {
        "school": "Ashland Middle",
        "district": "Ashland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550051000074",
    },
    {
        "school": "Lake Superior Elementary",
        "district": "Ashland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550051000077",
    },
    {
        "school": "Marengo Valley Elementary",
        "district": "Ashland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550051000079",
    },
    {
        "school": "Butternut Elementary",
        "district": "Butternut School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550192000245",
    },
    {
        "school": "Butternut High",
        "district": "Butternut School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550192000246",
    },
    {
        "school": "Almena Elementary",
        "district": "Barron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550087000113",
    },
    {
        "school": "Barron High",
        "district": "Barron Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550087000114",
    },
    {
        "school": "Ridgeland-Dallas Elementary",
        "district": "Barron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550087000117",
    },
    {
        "school": "Riverview Middle",
        "district": "Barron Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550087000118",
    },
    {
        "school": "Woodland Elementary",
        "district": "Barron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550087000119",
    },
    {
        "school": "Cameron Elementary",
        "district": "Cameron School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550213000256",
    },
    {
        "school": "Cameron High",
        "district": "Cameron School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550213000257",
    },
    {
        "school": "Cameron Middle",
        "district": "Cameron School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550213002286",
    },
    {
        "school": "Cumberland Middle",
        "district": "Cumberland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550309000304",
    },
    {
        "school": "Cumberland Elementary",
        "district": "Cumberland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550309000343",
    },
    {
        "school": "Cumberland High",
        "district": "Cumberland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550309000344",
    },
    {
        "school": "Prairie Farm Middle",
        "district": "Prairie Farm Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551218000445",
    },
    {
        "school": "Prairie Farm Elementary",
        "district": "Prairie Farm Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551218001585",
    },
    {
        "school": "Prairie Farm High",
        "district": "Prairie Farm Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551218001586",
    },
    {
        "school": "Tainter Elementary",
        "district": "Rice Lake Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551281000581",
    },
    {
        "school": "Haugen Elementary",
        "district": "Rice Lake Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551281001693",
    },
    {
        "school": "Hilltop Elementary",
        "district": "Rice Lake Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551281001694",
    },
    {
        "school": "Rice Lake Middle",
        "district": "Rice Lake Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551281001697",
    },
    {
        "school": "Rice Lake High",
        "district": "Rice Lake Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551281001699",
    },
    {
        "school": "Hilltop Day Care and Preschool",
        "district": "Rice Lake Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551281002526",
    },
    {
        "school": "Head Start",
        "district": "Rice Lake Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551281002528",
    },
    {
        "school": "Turtle Lake Elementary",
        "district": "Turtle Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551506001955",
    },
    {
        "school": "Turtle Lake High",
        "district": "Turtle Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551506001956",
    },
    {
        "school": "Bayfield Middle",
        "district": "Bayfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550090000082",
    },
    {
        "school": "Bayfield Elementary",
        "district": "Bayfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550090000120",
    },
    {
        "school": "Bayfield High",
        "district": "Bayfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550090000121",
    },
    {
        "school": "La Pointe Elementary",
        "district": "Bayfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550090002358",
    },
    {
        "school": "Drummond High",
        "district": "Drummond Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550381000396",
    },
    {
        "school": "Drummond Junior High",
        "district": "Drummond Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550381000397",
    },
    {
        "school": "Drummond Elementary",
        "district": "Drummond Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550381000398",
    },
    {
        "school": "South Shore Elementary",
        "district": "South Shore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551203001571",
    },
    {
        "school": "South Shore Jr/Sr High",
        "district": "South Shore School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551203001574",
    },
    {
        "school": "Washburn Middle",
        "district": "Washburn School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551554001984",
    },
    {
        "school": "Washburn High",
        "district": "Washburn School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551554001985",
    },
    {
        "school": "Washburn Elementary",
        "district": "Washburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551554002453",
    },
    {
        "school": "Alma Elementary",
        "district": "Alma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550018000017",
    },
    {
        "school": "Alma High",
        "district": "Alma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550018000018",
    },
    {
        "school": "Cochrane-Fountain City Elementary",
        "district": "Cochrane-Fountain City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550270000306",
    },
    {
        "school": "Cochrane-Fountain City High",
        "district": "Cochrane-Fountain City School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550270000307",
    },
    {
        "school": "Gilmanton Elementary",
        "district": "Gilmanton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550537000573",
    },
    {
        "school": "Gilmanton High",
        "district": "Gilmanton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550537000574",
    },
    {
        "school": "Grantsburg Elementary",
        "district": "Grantsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550567000601",
    },
    {
        "school": "Grantsburg High",
        "district": "Grantsburg School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550567000602",
    },
    {
        "school": "Grantsburg Middle",
        "district": "Grantsburg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550567000603",
    },
    {
        "school": "Nelson Elementary",
        "district": "Grantsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550567000604",
    },
    {
        "school": "Siren Elementary",
        "district": "Siren School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551389001816",
    },
    {
        "school": "Siren High",
        "district": "Siren School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551389001817",
    },
    {
        "school": "Webster Elementary",
        "district": "Webster School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551623002098",
    },
    {
        "school": "Webster High",
        "district": "Webster School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551623002099",
    },
    {
        "school": "Webster Middle",
        "district": "Webster School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551623002100",
    },
    {
        "school": "Abbotsford Elementary",
        "district": "Abbotsford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550003000001",
    },
    {
        "school": "Abbotsford Middle/Senior High",
        "district": "Abbotsford School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550003000002",
    },
    {
        "school": "Colby Elementary",
        "district": "Colby School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550273000308",
    },
    {
        "school": "Colby High",
        "district": "Colby School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550273000309",
    },
    {
        "school": "Colby Middle",
        "district": "Colby School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550273001226",
    },
    {
        "school": "Granton Elementary",
        "district": "Granton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550564000599",
    },
    {
        "school": "Granton High",
        "district": "Granton Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550564000600",
    },
    {
        "school": "Greenwood Elementary",
        "district": "Greenwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550597000656",
    },
    {
        "school": "Greenwood High",
        "district": "Greenwood School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550597000657",
    },
    {
        "school": "Loyal Elementary",
        "district": "Loyal School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550825000911",
    },
    {
        "school": "Loyal High",
        "district": "Loyal School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550825000912",
    },
    {
        "school": "Loyal Junior High",
        "district": "Loyal School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550825000913",
    },
    {
        "school": "Neillsville Elementary",
        "district": "Neillsville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551035001356",
    },
    {
        "school": "Neillsville High",
        "district": "Neillsville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551035001357",
    },
    {
        "school": "Neillsville Middle",
        "district": "Neillsville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551035002326",
    },
    {
        "school": "Owen-Withee Elementary",
        "district": "Owen-Withee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551131001509",
    },
    {
        "school": "Owen-Withee High",
        "district": "Owen-Withee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551131001510",
    },
    {
        "school": "Owen-Withee Junior High",
        "district": "Owen-Withee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551131001511",
    },
    {
        "school": "Thorp Elementary",
        "district": "Thorp School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551482001925",
    },
    {
        "school": "Thorp High",
        "district": "Thorp School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551482001926",
    },
    {
        "school": "North Crawford High",
        "district": "North Crawford School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550498000543",
    },
    {
        "school": "North Crawford Elementary",
        "district": "North Crawford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550498002244",
    },
    {
        "school": "Prairie du Chien High",
        "district": "Prairie du Chien Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551215001584",
    },
    {
        "school": "BA Kennedy School",
        "district": "Prairie du Chien Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551215002508",
    },
    {
        "school": "Seneca Elementary",
        "district": "Seneca Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551347001764",
    },
    {
        "school": "Seneca High",
        "district": "Seneca Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551347001765",
    },
    {
        "school": "Seneca Junior High",
        "district": "Seneca Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551347002399",
    },
    {
        "school": "Wauzeka Elementary",
        "district": "Wauzeka-Steuben School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551602002094",
    },
    {
        "school": "Wauzeka High",
        "district": "Wauzeka-Steuben School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551602002095",
    },
    {
        "school": "Gibraltar High",
        "district": "Gibraltar Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550522000561",
    },
    {
        "school": "Gibraltar Middle",
        "district": "Gibraltar Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550522001456",
    },
    {
        "school": "Gibraltar Elementary",
        "district": "Gibraltar Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550522002245",
    },
    {
        "school": "Sevastopol Pre-School",
        "district": "Sevastopol School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551350000229",
    },
    {
        "school": "Sevastopol Middle",
        "district": "Sevastopol School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551350000496",
    },
    {
        "school": "Sevastopol Elementary",
        "district": "Sevastopol School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551350001767",
    },
    {
        "school": "Sevastopol High",
        "district": "Sevastopol School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551350001768",
    },
    {
        "school": "Southern Door Elementary",
        "district": "Southern Door County School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551413001833",
    },
    {
        "school": "Southern Door High",
        "district": "Southern Door County School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551413001834",
    },
    {
        "school": "Southern Door Middle",
        "district": "Southern Door County School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551413001835",
    },
    {
        "school": "Sawyer Elementary",
        "district": "Sturgeon Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551461001392",
    },
    {
        "school": "Sturgeon Bay High",
        "district": "Sturgeon Bay School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551461001894",
    },
    {
        "school": "Sunrise Elementary",
        "district": "Sturgeon Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551461001895",
    },
    {
        "school": "Sunset Elementary",
        "district": "Sturgeon Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551461001896",
    },
    {
        "school": "Walker Middle",
        "district": "Sturgeon Bay School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551461002322",
    },
    {
        "school": "Washington Island Elementary",
        "district": "Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551557001986",
    },
    {
        "school": "Washington Island High",
        "district": "Washington School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551557001987",
    },
    {
        "school": "Crandon Elementary",
        "district": "Crandon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550291000326",
    },
    {
        "school": "Crandon High",
        "district": "Crandon School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550291000327",
    },
    {
        "school": "Crandon Middle",
        "district": "Crandon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550291002388",
    },
    {
        "school": "Laona High",
        "district": "Laona School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550783000893",
    },
    {
        "school": "Robinson Elementary",
        "district": "Laona School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550783000894",
    },
    {
        "school": "Wabeno Elementary",
        "district": "Wabeno Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551539001978",
    },
    {
        "school": "Wabeno High",
        "district": "Wabeno Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551539001979",
    },
    {
        "school": "Berlin High",
        "district": "Berlin Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550114000162",
    },
    {
        "school": "Clay Lamberton Elementary",
        "district": "Berlin Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550114000163",
    },
    {
        "school": "Berlin Middle",
        "district": "Berlin Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550114000164",
    },
    {
        "school": "Green Lake Elementary",
        "district": "Green Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550588000646",
    },
    {
        "school": "Green Lake High",
        "district": "Green Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550588000647",
    },
    {
        "school": "Markesan Primary",
        "district": "Markesan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550876001010",
    },
    {
        "school": "Markesan High",
        "district": "Markesan School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550876001011",
    },
    {
        "school": "Markesan Middle",
        "district": "Markesan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550876002414",
    },
    {
        "school": "Princeton School",
        "district": "Princeton School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551230001595",
    },
    {
        "school": "Hurley High",
        "district": "Hurley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550675000733",
    },
    {
        "school": "Hurley Elementary",
        "district": "Hurley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550675000734",
    },
    {
        "school": "Mercer School",
        "district": "Mercer School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550915001092",
    },
    {
        "school": "Lincoln High",
        "district": "Alma Center School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550021000020",
    },
    {
        "school": "Lincoln Junior High",
        "district": "Alma Center School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550021000021",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Alma Center School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550021000022",
    },
    {
        "school": "Black River Falls Middle",
        "district": "Black River Falls School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550126000174",
    },
    {
        "school": "Black River Falls High",
        "district": "Black River Falls School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550126000175",
    },
    {
        "school": "Forrest Street Early Learning Center",
        "district": "Black River Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550126000176",
    },
    {
        "school": "Red Creek Elementary",
        "district": "Black River Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550126002428",
    },
    {
        "school": "Royall Elementary",
        "district": "Royall School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550438000472",
    },
    {
        "school": "Royall Intermediate",
        "district": "Royall School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550438000473",
    },
    {
        "school": "Royall High",
        "district": "Royall School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550438000474",
    },
    {
        "school": "Lyndon Station Elementary",
        "district": "Mauston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550885001024",
    },
    {
        "school": "Mauston High",
        "district": "Mauston School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550885001025",
    },
    {
        "school": "Olson Middle",
        "district": "Mauston School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550885001026",
    },
    {
        "school": "West Side Elementary",
        "district": "Mauston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550885001027",
    },
    {
        "school": "Necedah Elementary",
        "district": "Necedah Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551023001337",
    },
    {
        "school": "Necedah High",
        "district": "Necedah Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551023001338",
    },
    {
        "school": "New Lisbon Elementary",
        "district": "New Lisbon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551056001381",
    },
    {
        "school": "New Lisbon Junior High/High",
        "district": "New Lisbon School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551056001382",
    },
    {
        "school": "Camp Douglas Elementary",
        "district": "Tomah Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551491001933",
    },
    {
        "school": "Wonewoc-Center Elementary",
        "district": "Wonewoc-Union Center School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551713002224",
    },
    {
        "school": "Wonewoc-Center High",
        "district": "Wonewoc-Union Center School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551713002225",
    },
    {
        "school": "Wonewoc-Center Junior High",
        "district": "Wonewoc-Union Center School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551713002226",
    },
    {
        "school": "Argyle Elementary",
        "district": "Argyle School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550045000069",
    },
    {
        "school": "Argyle High",
        "district": "Argyle School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550045000070",
    },
    {
        "school": "Belmont Elementary",
        "district": "Belmont Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550102000134",
    },
    {
        "school": "Belmont High",
        "district": "Belmont Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550102000135",
    },
    {
        "school": "Benton Elementary",
        "district": "Benton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550111000160",
    },
    {
        "school": "Benton High",
        "district": "Benton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550111000161",
    },
    {
        "school": "Darlington High",
        "district": "Darlington Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550315000348",
    },
    {
        "school": "Darlington Elementary/Middle",
        "district": "Darlington Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550315000704",
    },
    {
        "school": "Black Hawk High",
        "district": "Black Hawk School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550573000605",
    },
    {
        "school": "Black Hawk Middle",
        "district": "Black Hawk School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550573000606",
    },
    {
        "school": "Black Hawk Elementary",
        "district": "Black Hawk School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550573000608",
    },
    {
        "school": "Shullsburg Elementary",
        "district": "Shullsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551383001813",
    },
    {
        "school": "Shullsburg High",
        "district": "Shullsburg School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551383001814",
    },
    {
        "school": "Shullsburg Junior High",
        "district": "Shullsburg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551383002400",
    },
    {
        "school": "Antigo Middle",
        "district": "Antigo Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550036000036",
    },
    {
        "school": "Antigo High",
        "district": "Antigo Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550036000037",
    },
    {
        "school": "East Elementary",
        "district": "Antigo Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550036000039",
    },
    {
        "school": "North Elementary",
        "district": "Antigo Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550036000042",
    },
    {
        "school": "West Elementary",
        "district": "Antigo Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550036000046",
    },
    {
        "school": "Elcho Elementary",
        "district": "Elcho School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550417000447",
    },
    {
        "school": "Elcho High",
        "district": "Elcho School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550417000448",
    },
    {
        "school": "White Lake Elementary",
        "district": "White Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551659002164",
    },
    {
        "school": "White Lake High",
        "district": "White Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551659002165",
    },
    {
        "school": "Little Stars Pre-School",
        "district": "Colby School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550273000312",
    },
    {
        "school": "Forest Lane Community School",
        "district": "Montello School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550987001302",
    },
    {
        "school": "Montello Junior/Senior High",
        "district": "Montello School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550987001303",
    },
    {
        "school": "Oxford Elementary",
        "district": "Westfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551644002149",
    },
    {
        "school": "Westfield Elementary",
        "district": "Westfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551644002150",
    },
    {
        "school": "Westfield Area High",
        "district": "Westfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551644002151",
    },
    {
        "school": "Keshena Primary",
        "district": "Menominee Indian School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550907001069",
    },
    {
        "school": "Menominee Indian High",
        "district": "Menominee Indian School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550907001070",
    },
    {
        "school": "Menominee Indian Middle",
        "district": "Menominee Indian School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550907001071",
    },
    {
        "school": "Cashton Elementary",
        "district": "Cashton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550234000262",
    },
    {
        "school": "Cashton Middle/High",
        "district": "Cashton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550234000263",
    },
    {
        "school": "Norwalk-Ontario-Wilton Elementary",
        "district": "Norwalk-Ontario-Wilton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551077000683",
    },
    {
        "school": "Brookwood High",
        "district": "Norwalk-Ontario-Wilton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551077001402",
    },
    {
        "school": "Cataract Elementary",
        "district": "Sparta Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551416001837",
    },
    {
        "school": "Lawrence-Lawson Elementary",
        "district": "Sparta Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551416001839",
    },
    {
        "school": "Southside Elementary",
        "district": "Sparta Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551416001841",
    },
    {
        "school": "Sparta Meadowview Middle",
        "district": "Sparta Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551416001842",
    },
    {
        "school": "Sparta High",
        "district": "Sparta Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551416001843",
    },
    {
        "school": "Maplewood Elementary",
        "district": "Sparta Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551416002321",
    },
    {
        "school": "Sparta Meadowview Intermediate",
        "district": "Sparta Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551416002485",
    },
    {
        "school": "Sparta Alternative Independent Learning School",
        "district": "Sparta Area School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551416002486",
    },
    {
        "school": "Lemonweir Elementary",
        "district": "Tomah Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551491001934",
    },
    {
        "school": "Miller Elementary",
        "district": "Tomah Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551491001935",
    },
    {
        "school": "Oakdale Elementary",
        "district": "Tomah Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551491001937",
    },
    {
        "school": "Tomah Middle",
        "district": "Tomah Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551491001938",
    },
    {
        "school": "Tomah High",
        "district": "Tomah Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551491001939",
    },
    {
        "school": "Warrens Elementary",
        "district": "Tomah Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551491001940",
    },
    {
        "school": "Wyeville Elementary",
        "district": "Tomah Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551491001941",
    },
    {
        "school": "La Grange Elementary",
        "district": "Tomah Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551491002425",
    },
    {
        "school": "Lakeland High",
        "district": "Lakeland UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550963001274",
    },
    {
        "school": "Minocqua Elementary",
        "district": "Minocqua J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550969001278",
    },
    {
        "school": "Northwoods Community Elementary",
        "district": "Rhinelander School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551272001673",
    },
    {
        "school": "Central Elementary",
        "district": "Rhinelander School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551272001674",
    },
    {
        "school": "Crescent Elementary",
        "district": "Rhinelander School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551272001675",
    },
    {
        "school": "James Williams Middle",
        "district": "Rhinelander School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551272001677",
    },
    {
        "school": "Pelican Elementary",
        "district": "Rhinelander School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551272001680",
    },
    {
        "school": "Rhinelander High",
        "district": "Rhinelander School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551272001682",
    },
    {
        "school": "Sugar Camp Elementary",
        "district": "Three Lakes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551485001927",
    },
    {
        "school": "Three Lakes Elementary",
        "district": "Three Lakes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551485001928",
    },
    {
        "school": "Three Lakes High",
        "district": "Three Lakes School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551485001929",
    },
    {
        "school": "Sugar Bush Elementary",
        "district": "New London School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551059001387",
    },
    {
        "school": "Caddie Woodlawn Elementary",
        "district": "Durand-Arkansaw School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550384000116",
    },
    {
        "school": "Durand Middle/High",
        "district": "Durand-Arkansaw School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550384000136",
    },
    {
        "school": "Pepin Elementary",
        "district": "Pepin Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551158001531",
    },
    {
        "school": "Pepin High",
        "district": "Pepin Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551158001532",
    },
    {
        "school": "Lien Elementary",
        "district": "Amery School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550030000029",
    },
    {
        "school": "Amery High",
        "district": "Amery School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550030000030",
    },
    {
        "school": "Amery Middle",
        "district": "Amery School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550030000031",
    },
    {
        "school": "Amery Intermediate",
        "district": "Amery School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550030000075",
    },
    {
        "school": "Unity Elementary",
        "district": "Unity School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550075000097",
    },
    {
        "school": "Unity High",
        "district": "Unity School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550075000098",
    },
    {
        "school": "Unity Middle",
        "district": "Unity School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550075000099",
    },
    {
        "school": "Clayton Elementary",
        "district": "Clayton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550258000289",
    },
    {
        "school": "Clayton High",
        "district": "Clayton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550258000290",
    },
    {
        "school": "Clayton Middle",
        "district": "Clayton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550258000558",
    },
    {
        "school": "Gaylord A Nelson Educational Center",
        "district": "Clear Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550261000291",
    },
    {
        "school": "Clear Lake High",
        "district": "Clear Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550261000292",
    },
    {
        "school": "Clear Lake Junior High",
        "district": "Clear Lake School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550261000293",
    },
    {
        "school": "Frederic Elementary",
        "district": "Frederic School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550486000525",
    },
    {
        "school": "Frederic 6-12 School",
        "district": "Frederic School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550486000526",
    },
    {
        "school": "Luck Elementary",
        "district": "Luck School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550828000914",
    },
    {
        "school": "Luck High",
        "district": "Luck School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550828000915",
    },
    {
        "school": "Osceola Intermediate",
        "district": "Osceola School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551116001073",
    },
    {
        "school": "Osceola Elementary",
        "district": "Osceola School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551116001479",
    },
    {
        "school": "Osceola High",
        "district": "Osceola School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551116001480",
    },
    {
        "school": "Osceola Middle",
        "district": "Osceola School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551116002319",
    },
    {
        "school": "Dresser Elementary",
        "district": "Saint Croix Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551323001744",
    },
    {
        "school": "Saint Croix Falls Elementary",
        "district": "Saint Croix Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551323001745",
    },
    {
        "school": "Saint Croix Falls High",
        "district": "Saint Croix Falls School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551323001746",
    },
    {
        "school": "Saint Croix Falls Middle",
        "district": "Saint Croix Falls School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551323002314",
    },
    {
        "school": "Phillips Elementary",
        "district": "Phillips School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551173001543",
    },
    {
        "school": "Phillips High",
        "district": "Phillips School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551173001544",
    },
    {
        "school": "Phillips Middle",
        "district": "Phillips School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551173001545",
    },
    {
        "school": "Prentice Elementary",
        "district": "Prentice School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551221001588",
    },
    {
        "school": "Prentice High",
        "district": "Prentice School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551221001589",
    },
    {
        "school": "Ithaca Elementary",
        "district": "Ithaca School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550696000751",
    },
    {
        "school": "Ithaca High",
        "district": "Ithaca School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550696000752",
    },
    {
        "school": "Ithaca Middle",
        "district": "Ithaca School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550696000753",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551296001705",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Richland School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551296001706",
    },
    {
        "school": "Richland Center High",
        "district": "Richland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551296001707",
    },
    {
        "school": "Richland Middle",
        "district": "Richland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551296001708",
    },
    {
        "school": "Doudna Elementary",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551296002345",
    },
    {
        "school": "Bruce Elementary",
        "district": "Bruce School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550183000234",
    },
    {
        "school": "Bruce High",
        "district": "Bruce School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550183000235",
    },
    {
        "school": "Bruce Middle",
        "district": "Bruce School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550183001222",
    },
    {
        "school": "Ladysmith Elementary",
        "district": "Ladysmith School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550759000876",
    },
    {
        "school": "Ladysmith High",
        "district": "Ladysmith School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550759000877",
    },
    {
        "school": "Ladysmith Middle",
        "district": "Ladysmith School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550759000878",
    },
    {
        "school": "Flambeau Elementary",
        "district": "Flambeau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551497001919",
    },
    {
        "school": "Flambeau High",
        "district": "Flambeau School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551497001951",
    },
    {
        "school": "Flambeau Middle",
        "district": "Flambeau School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551497001952",
    },
    {
        "school": "Hayward Primary",
        "district": "Hayward Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550627000689",
    },
    {
        "school": "Hayward High",
        "district": "Hayward Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550627000690",
    },
    {
        "school": "Hayward Middle",
        "district": "Hayward Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550627000691",
    },
    {
        "school": "Hayward Intermediate",
        "district": "Hayward Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550627002417",
    },
    {
        "school": "Winter Elementary",
        "district": "Winter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551686002194",
    },
    {
        "school": "Winter High",
        "district": "Winter School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551686002195",
    },
    {
        "school": "Winter Middle",
        "district": "Winter School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551686002315",
    },
    {
        "school": "Bonduel Elementary",
        "district": "Bonduel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550147000188",
    },
    {
        "school": "Bonduel High",
        "district": "Bonduel School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550147000189",
    },
    {
        "school": "Bonduel Middle",
        "district": "Bonduel School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550147002383",
    },
    {
        "school": "Bowler Elementary",
        "district": "Bowler School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550156000199",
    },
    {
        "school": "Bowler High",
        "district": "Bowler School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550156000200",
    },
    {
        "school": "Shawano Community Middle",
        "district": "Shawano School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551362001775",
    },
    {
        "school": "Brener Elementary",
        "district": "Shawano School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551362001779",
    },
    {
        "school": "Shawano High",
        "district": "Shawano School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551362001780",
    },
    {
        "school": "Tigerton Elementary",
        "district": "Tigerton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551488001931",
    },
    {
        "school": "Tigerton High",
        "district": "Tigerton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551488001932",
    },
    {
        "school": "Gilman Elementary",
        "district": "Gilman School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550528000567",
    },
    {
        "school": "Gilman High",
        "district": "Gilman School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550528000568",
    },
    {
        "school": "Medford High",
        "district": "Medford Area Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550894001043",
    },
    {
        "school": "Medford Middle",
        "district": "Medford Area Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550894001044",
    },
    {
        "school": "Stetsonville Elementary",
        "district": "Medford Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550894001047",
    },
    {
        "school": "Medford Elementary",
        "district": "Medford Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550894002361",
    },
    {
        "school": "Rib Lake High",
        "district": "Rib Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551278001687",
    },
    {
        "school": "Rib Lake Middle",
        "district": "Rib Lake School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551278001688",
    },
    {
        "school": "Rib Lake Elementary",
        "district": "Rib Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551278002463",
    },
    {
        "school": "Blair-Taylor Middle/High",
        "district": "Blair-Taylor School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550001602378",
    },
    {
        "school": "Blair-Taylor Elementary",
        "district": "Blair-Taylor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550001602380",
    },
    {
        "school": "Arcadia High",
        "district": "Arcadia School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550042000068",
    },
    {
        "school": "Eleva-Strum High",
        "district": "Eleva-Strum School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550420000450",
    },
    {
        "school": "Eleva-Strum Elementary",
        "district": "Eleva-Strum School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550420000451",
    },
    {
        "school": "Ettrick Elementary",
        "district": "Galesville-Ettrick-Trempealeau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550496000535",
    },
    {
        "school": "Galesville-Ettrick-Trempealeau High",
        "district": "Galesville-Ettrick-Trempealeau School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550496000536",
    },
    {
        "school": "Galesville-Ettrick-Trempealeau Middle",
        "district": "Galesville-Ettrick-Trempealeau School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550496000537",
    },
    {
        "school": "Galesville Elementary",
        "district": "Galesville-Ettrick-Trempealeau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550496000538",
    },
    {
        "school": "Trempealeau Elementary",
        "district": "Galesville-Ettrick-Trempealeau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550496000539",
    },
    {
        "school": "Independence Elementary",
        "district": "Independence School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550681000739",
    },
    {
        "school": "Independence High",
        "district": "Independence School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550681000740",
    },
    {
        "school": "Whitehall Memorial Elementary",
        "district": "Whitehall School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551665002175",
    },
    {
        "school": "Whitehall Memorial Junior/Senior High",
        "district": "Whitehall School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551665002176",
    },
    {
        "school": "De Soto High",
        "district": "De Soto Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550324000365",
    },
    {
        "school": "De Soto Middle",
        "district": "De Soto Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550324000366",
    },
    {
        "school": "Prairie View Elementary",
        "district": "De Soto Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550324000368",
    },
    {
        "school": "Stoddard Elementary",
        "district": "De Soto Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550324000369",
    },
    {
        "school": "Hillsboro Elementary",
        "district": "Hillsboro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550648000702",
    },
    {
        "school": "Hillsboro High",
        "district": "Hillsboro School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550648000703",
    },
    {
        "school": "La Farge Elementary",
        "district": "La Farge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550756000872",
    },
    {
        "school": "La Farge High",
        "district": "La Farge School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550756000873",
    },
    {
        "school": "La Farge Middle",
        "district": "La Farge School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550756001757",
    },
    {
        "school": "Kickapoo High",
        "district": "Kickapoo Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551254001658",
    },
    {
        "school": "Kickapoo Elementary",
        "district": "Kickapoo Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551254001660",
    },
    {
        "school": "Laurel High",
        "district": "Viroqua Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551536001936",
    },
    {
        "school": "Viroqua Elementary",
        "district": "Viroqua Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551536001975",
    },
    {
        "school": "Viroqua High",
        "district": "Viroqua Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551536001976",
    },
    {
        "school": "Viroqua Middle",
        "district": "Viroqua Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551536001977",
    },
    {
        "school": "Vernon County Area Better Futures High",
        "district": "Viroqua Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551536002513",
    },
    {
        "school": "Westby Middle",
        "district": "Westby Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551641001207",
    },
    {
        "school": "Coon Valley Elementary",
        "district": "Westby Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551641002144",
    },
    {
        "school": "Westby Elementary",
        "district": "Westby Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551641002145",
    },
    {
        "school": "Westby High",
        "district": "Westby Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551641002146",
    },
    {
        "school": "North Lakeland Elementary",
        "district": "North Lakeland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550153000198",
    },
    {
        "school": "Northland Pines Elementary-Eagle River",
        "district": "Northland Pines School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550386000404",
    },
    {
        "school": "Northland Pines Elementary-Land O' Lakes",
        "district": "Northland Pines School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550386000405",
    },
    {
        "school": "Northland Pines High",
        "district": "Northland Pines School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550386000406",
    },
    {
        "school": "Northland Pines Middle",
        "district": "Northland Pines School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550386000407",
    },
    {
        "school": "Northland Pines Elementary-St Germain",
        "district": "Northland Pines School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550386000408",
    },
    {
        "school": "Lac du Flambeau Elementary",
        "district": "Lac du Flambeau #1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550462000488",
    },
    {
        "school": "Phelps Elementary",
        "district": "Phelps School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551171001539",
    },
    {
        "school": "Phelps High",
        "district": "Phelps School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551171001540",
    },
    {
        "school": "Arbor Vitae-Woodruff Elementary",
        "district": "Woodruff J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551716002227",
    },
    {
        "school": "Birchwood Elementary",
        "district": "Birchwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550117000168",
    },
    {
        "school": "Birchwood High",
        "district": "Birchwood School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550117000169",
    },
    {
        "school": "Shell Lake Primary (K-2)",
        "district": "Shell Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551371000507",
    },
    {
        "school": "Shell Lake Elementary (3-6)",
        "district": "Shell Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551371001804",
    },
    {
        "school": "Shell Lake Junior/Senior High",
        "district": "Shell Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551371001805",
    },
    {
        "school": "Spooner Elementary",
        "district": "Spooner Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551422001846",
    },
    {
        "school": "Spooner High",
        "district": "Spooner Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551422001848",
    },
    {
        "school": "Spooner Middle",
        "district": "Spooner Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551422001849",
    },
    {
        "school": "Clintonville Middle",
        "district": "Clintonville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550267000301",
    },
    {
        "school": "Clintonville High",
        "district": "Clintonville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550267000302",
    },
    {
        "school": "Dellwood Early Learning Center",
        "district": "Clintonville School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550267000303",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Clintonville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550267000305",
    },
    {
        "school": "Iola-Scandinavia Elementary",
        "district": "Iola-Scandinavia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550684000741",
    },
    {
        "school": "Iola-Scandinavia High",
        "district": "Iola-Scandinavia School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550684000742",
    },
    {
        "school": "Little Wolf High",
        "district": "Manawa School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550855000968",
    },
    {
        "school": "Manawa Elementary",
        "district": "Manawa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550855000969",
    },
    {
        "school": "Marion Elementary",
        "district": "Marion School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550873001004",
    },
    {
        "school": "Marion High",
        "district": "Marion School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550873001005",
    },
    {
        "school": "Lincoln Elementary",
        "district": "New London School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551059001383",
    },
    {
        "school": "New London High",
        "district": "New London School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551059001384",
    },
    {
        "school": "Parkview Elementary",
        "district": "New London School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551059001385",
    },
    {
        "school": "Readfield Elementary",
        "district": "New London School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551059001386",
    },
    {
        "school": "New London Middle",
        "district": "New London School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551059001388",
    },
    {
        "school": "Waupaca Learning Center Elementary",
        "district": "Waupaca School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551584001203",
    },
    {
        "school": "Chain O Lakes Elementary",
        "district": "Waupaca School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551584002033",
    },
    {
        "school": "Waupaca High",
        "district": "Waupaca School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551584002035",
    },
    {
        "school": "Waupaca Middle",
        "district": "Waupaca School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551584002036",
    },
    {
        "school": "Fremont Elementary",
        "district": "Weyauwega-Fremont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551650002157",
    },
    {
        "school": "Weyauwega Elementary",
        "district": "Weyauwega-Fremont School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551650002158",
    },
    {
        "school": "Weyauwega High",
        "district": "Weyauwega-Fremont School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551650002159",
    },
    {
        "school": "Weyauwega Middle",
        "district": "Weyauwega-Fremont School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551650002160",
    },
    {
        "school": "Tri-County High",
        "district": "Tri-County Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551182001548",
    },
    {
        "school": "Tri-County Elementary",
        "district": "Tri-County Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551182001550",
    },
    {
        "school": "Parkside School",
        "district": "Wautoma Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551596002071",
    },
    {
        "school": "Redgranite Elementary",
        "district": "Wautoma Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551596002072",
    },
    {
        "school": "Riverview Elementary",
        "district": "Wautoma Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551596002073",
    },
    {
        "school": "Wautoma High",
        "district": "Wautoma Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551596002074",
    },
    {
        "school": "Coloma Elementary",
        "district": "Westfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551644002147",
    },
    {
        "school": "Wild Rose Elementary",
        "district": "Wild Rose School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551671002184",
    },
    {
        "school": "Wild Rose High",
        "district": "Wild Rose School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551671002185",
    },
    {
        "school": "Osseo-Fairchild Elementary",
        "district": "Osseo-Fairchild School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551122001507",
    },
    {
        "school": "Osseo-Fairchild High",
        "district": "Osseo-Fairchild School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551122001508",
    },
    {
        "school": "Osseo-Fairchild Middle",
        "district": "Osseo-Fairchild School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551122002398",
    },
    {
        "school": "Melrose-Mindoro Elementary",
        "district": "Melrose-Mindoro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550900001050",
    },
    {
        "school": "Melrose-Mindoro Junior/Senior High",
        "district": "Melrose-Mindoro School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550900001051",
    },
    {
        "school": "Birnamwood Elementary",
        "district": "Wittenberg-Birnamwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551710002218",
    },
    {
        "school": "Wittenberg-Birnamwood High",
        "district": "Wittenberg-Birnamwood School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551710002222",
    },
    {
        "school": "Wittenberg Elementary",
        "district": "Wittenberg-Birnamwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551710002223",
    },
    {
        "school": "New Holstein Middle",
        "district": "New Holstein School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551053002550",
    },
    {
        "school": "Tesla Engineering Charter School",
        "district": "Appleton Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002547",
    },
    {
        "school": "Appleton eSchool",
        "district": "Appleton Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002549",
    },
    {
        "school": "Fox River Academy",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002582",
    },
    {
        "school": "Appleton Public Montessori",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002583",
    },
    {
        "school": "Valley New School",
        "district": "Appleton Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039003341",
    },
    {
        "school": "Greenville Middle",
        "district": "Hortonville Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550660002573",
    },
    {
        "school": "Madison Middle",
        "district": "Appleton Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000060",
    },
    {
        "school": "McKinley Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000061",
    },
    {
        "school": "Horizons Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002350",
    },
    {
        "school": "Berry Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002427",
    },
    {
        "school": "Brillion Elementary",
        "district": "Brillion School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550168000206",
    },
    {
        "school": "Brillion High",
        "district": "Brillion School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550168000207",
    },
    {
        "school": "Brillion Middle",
        "district": "Brillion School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550168002384",
    },
    {
        "school": "Chilton Elementary",
        "district": "Chilton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550252000278",
    },
    {
        "school": "Chilton High",
        "district": "Chilton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550252000279",
    },
    {
        "school": "Chilton Middle",
        "district": "Chilton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550252002430",
    },
    {
        "school": "Hilbert Elementary",
        "district": "Hilbert School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550645000700",
    },
    {
        "school": "Hilbert High",
        "district": "Hilbert School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550645000701",
    },
    {
        "school": "Hilbert Middle",
        "district": "Hilbert School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550645001458",
    },
    {
        "school": "New Holstein Elementary",
        "district": "New Holstein School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551053001378",
    },
    {
        "school": "New Holstein High",
        "district": "New Holstein School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551053001379",
    },
    {
        "school": "Stockbridge Elementary",
        "district": "Stockbridge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551452001882",
    },
    {
        "school": "Stockbridge High",
        "district": "Stockbridge School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551452001883",
    },
    {
        "school": "Stockbridge Middle",
        "district": "Stockbridge School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551452002499",
    },
    {
        "school": "East High",
        "district": "Appleton Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000047",
    },
    {
        "school": "West High",
        "district": "Appleton Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000048",
    },
    {
        "school": "Badger Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000049",
    },
    {
        "school": "Columbus Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000050",
    },
    {
        "school": "Edison Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000051",
    },
    {
        "school": "Einstein Middle",
        "district": "Appleton Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000052",
    },
    {
        "school": "Franklin Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000054",
    },
    {
        "school": "Highlands Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000055",
    },
    {
        "school": "Huntley Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000056",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000057",
    },
    {
        "school": "Johnston Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000058",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000059",
    },
    {
        "school": "Richmond Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000062",
    },
    {
        "school": "Wilson Middle",
        "district": "Appleton Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000065",
    },
    {
        "school": "North High",
        "district": "Appleton Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039000597",
    },
    {
        "school": "Classical School",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039001619",
    },
    {
        "school": "Odyssey-Magellan",
        "district": "Appleton Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002277",
    },
    {
        "school": "Renaissance School",
        "district": "Appleton Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002282",
    },
    {
        "school": "Houdini Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002366",
    },
    {
        "school": "Ferber Elementary",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002426",
    },
    {
        "school": "Freedom Elementary",
        "district": "Freedom Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550492000532",
    },
    {
        "school": "Freedom High",
        "district": "Freedom Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550492000533",
    },
    {
        "school": "Freedom Middle",
        "district": "Freedom Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550492000534",
    },
    {
        "school": "Hortonville Elementary",
        "district": "Hortonville Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550660000714",
    },
    {
        "school": "Hortonville High",
        "district": "Hortonville Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550660000715",
    },
    {
        "school": "Greenville Elementary",
        "district": "Hortonville Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550660002407",
    },
    {
        "school": "Hortonville Middle",
        "district": "Hortonville Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550660002408",
    },
    {
        "school": "Kaukauna High",
        "district": "Kaukauna Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550729000793",
    },
    {
        "school": "Park Community Charter School",
        "district": "Kaukauna Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550729000795",
    },
    {
        "school": "Quinney Elementary",
        "district": "Kaukauna Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550729000796",
    },
    {
        "school": "Haen Elementary",
        "district": "Kaukauna Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550729000797",
    },
    {
        "school": "River View School",
        "district": "Kaukauna Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550729001700",
    },
    {
        "school": "Dr H B Tanner Elementary",
        "district": "Kaukauna Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550729002433",
    },
    {
        "school": "Sunrise Elementary",
        "district": "Kimberly Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550747000732",
    },
    {
        "school": "Janssen Elementary",
        "district": "Kimberly Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550747000847",
    },
    {
        "school": "Gerritts Middle",
        "district": "Kimberly Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550747000849",
    },
    {
        "school": "Kimberly High",
        "district": "Kimberly Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550747000850",
    },
    {
        "school": "Westside Elementary",
        "district": "Kimberly Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550747000851",
    },
    {
        "school": "Little Chute Elementary",
        "district": "Little Chute Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550816000900",
    },
    {
        "school": "Little Chute High",
        "district": "Little Chute Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550816000901",
    },
    {
        "school": "Little Chute Middle",
        "district": "Little Chute Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550816000902",
    },
    {
        "school": "Black Creek Elementary",
        "district": "Seymour Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551353001769",
    },
    {
        "school": "Rock Ledge Elementary",
        "district": "Seymour Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551353001771",
    },
    {
        "school": "Seymour Middle",
        "district": "Seymour Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551353001772",
    },
    {
        "school": "Seymour High",
        "district": "Seymour Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551353001773",
    },
    {
        "school": "Shiocton Elementary",
        "district": "Shiocton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551377001807",
    },
    {
        "school": "Shiocton High",
        "district": "Shiocton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551377001808",
    },
    {
        "school": "West Elementary-Kindergarten Center",
        "district": "Baraboo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550081002587",
    },
    {
        "school": "Jack Young Middle",
        "district": "Baraboo School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550081000102",
    },
    {
        "school": "Baraboo High",
        "district": "Baraboo School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550081000103",
    },
    {
        "school": "East Elementary",
        "district": "Baraboo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550081000104",
    },
    {
        "school": "Willson Elementary",
        "district": "Baraboo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550081000106",
    },
    {
        "school": "North Freedom Elementary",
        "district": "Baraboo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550081000107",
    },
    {
        "school": "Al Behrman Elementary",
        "district": "Baraboo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550081000109",
    },
    {
        "school": "Pineview Elementary",
        "district": "Reedsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551266001604",
    },
    {
        "school": "Ironton-La Valle Elementary",
        "district": "Reedsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551266001662",
    },
    {
        "school": "Loganville Elementary",
        "district": "Reedsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551266001663",
    },
    {
        "school": "Reedsburg Area High",
        "district": "Reedsburg School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551266001664",
    },
    {
        "school": "Webb Middle",
        "district": "Reedsburg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551266001665",
    },
    {
        "school": "West Side Elementary",
        "district": "Reedsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551266001668",
    },
    {
        "school": "Grand Avenue Elementary",
        "district": "Sauk Prairie School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551341001756",
    },
    {
        "school": "Sauk Prairie High",
        "district": "Sauk Prairie School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551341001759",
    },
    {
        "school": "Sauk Prairie Middle",
        "district": "Sauk Prairie School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551341001760",
    },
    {
        "school": "Bridges Elementary",
        "district": "Sauk Prairie School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551341001761",
    },
    {
        "school": "Tower Rock Elementary",
        "district": "Sauk Prairie School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551341001762",
    },
    {
        "school": "River Valley High",
        "district": "River Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551425001855",
    },
    {
        "school": "River Valley Middle",
        "district": "River Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551425001856",
    },
    {
        "school": "River Valley Elementary",
        "district": "River Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551425002346",
    },
    {
        "school": "Weston Elementary",
        "district": "Weston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551647000548",
    },
    {
        "school": "Weston High",
        "district": "Weston School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551647002155",
    },
    {
        "school": "Weston Middle",
        "district": "Weston School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551647002156",
    },
    {
        "school": "Randolph Elementary",
        "district": "Randolph School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551242001650",
    },
    {
        "school": "Beaver Dam Middle",
        "district": "Beaver Dam Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550096000122",
    },
    {
        "school": "Beaver Dam High",
        "district": "Beaver Dam Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550096000123",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Beaver Dam Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550096000125",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Beaver Dam Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550096000126",
    },
    {
        "school": "South Beaver Dam Elementary",
        "district": "Beaver Dam Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550096000127",
    },
    {
        "school": "Washington Elementary",
        "district": "Beaver Dam Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550096000129",
    },
    {
        "school": "Wilson Elementary",
        "district": "Beaver Dam Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550096000130",
    },
    {
        "school": "Prairie View Elementary",
        "district": "Beaver Dam Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550096001455",
    },
    {
        "school": "Van Brunt Elementary",
        "district": "Horicon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550657000711",
    },
    {
        "school": "Horicon High",
        "district": "Horicon School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550657000712",
    },
    {
        "school": "Horicon Junior High",
        "district": "Horicon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550657000713",
    },
    {
        "school": "John Hustis Elementary",
        "district": "Hustisford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550678000737",
    },
    {
        "school": "Hustisford High",
        "district": "Hustisford School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550678000738",
    },
    {
        "school": "Dodgeland High",
        "district": "Dodgeland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550726000787",
    },
    {
        "school": "Dodgeland Elementary",
        "district": "Dodgeland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550726000791",
    },
    {
        "school": "Lomira Elementary",
        "district": "Lomira School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550822000907",
    },
    {
        "school": "Lomira High",
        "district": "Lomira School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550822000908",
    },
    {
        "school": "Lomira Middle",
        "district": "Lomira School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550822000909",
    },
    {
        "school": "Theresa Elementary",
        "district": "Lomira School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550822000910",
    },
    {
        "school": "Mayville Middle",
        "district": "Mayville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550888001029",
    },
    {
        "school": "Mayville High",
        "district": "Mayville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550888001030",
    },
    {
        "school": "Parkview Elementary",
        "district": "Mayville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550888001031",
    },
    {
        "school": "Randolph High",
        "district": "Randolph School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551242001651",
    },
    {
        "school": "Meadow View Primary",
        "district": "Waupun School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551587002044",
    },
    {
        "school": "Waupun Area Senior High",
        "district": "Waupun School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551587002045",
    },
    {
        "school": "Nash Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732002653",
    },
    {
        "school": "Mahone Middle",
        "district": "Kenosha School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732002538",
    },
    {
        "school": "Edward Bain School - Creative Arts",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732002591",
    },
    {
        "school": "Brighton Elementary",
        "district": "Brighton #1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550165000205",
    },
    {
        "school": "Bristol Elementary",
        "district": "Bristol #1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550171000209",
    },
    {
        "school": "Stocker Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000351",
    },
    {
        "school": "Bose Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000800",
    },
    {
        "school": "Bradford High",
        "district": "Kenosha School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000801",
    },
    {
        "school": "Bullen Middle",
        "district": "Kenosha School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000802",
    },
    {
        "school": "Forest Park Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000806",
    },
    {
        "school": "Frank Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000807",
    },
    {
        "school": "Grant Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000808",
    },
    {
        "school": "Harvey Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000810",
    },
    {
        "school": "Chavez Learning Station",
        "district": "Kenosha School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000811",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000813",
    },
    {
        "school": "Jeffery Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000814",
    },
    {
        "school": "Lance Middle",
        "district": "Kenosha School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000815",
    },
    {
        "school": "Brass Community School",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000816",
    },
    {
        "school": "Lincoln Middle",
        "district": "Kenosha School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000817",
    },
    {
        "school": "McKinley Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000818",
    },
    {
        "school": "Pleasant Prairie Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000820",
    },
    {
        "school": "Prairie Lane Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000821",
    },
    {
        "school": "Reuther Central High",
        "district": "Kenosha School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550732000822",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000823",
    },
    {
        "school": "Somers Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000824",
    },
    {
        "school": "Southport Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000825",
    },
    {
        "school": "Strange Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000826",
    },
    {
        "school": "Tremper High",
        "district": "Kenosha School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000828",
    },
    {
        "school": "Vernon Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000829",
    },
    {
        "school": "Washington Middle",
        "district": "Kenosha School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000831",
    },
    {
        "school": "Whittier Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000832",
    },
    {
        "school": "Wilson Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732000833",
    },
    {
        "school": "Brompton School",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732001285",
    },
    {
        "school": "Indian Trail High School and Academy",
        "district": "Kenosha School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732001461",
    },
    {
        "school": "Lakeview Technology Academy",
        "district": "Kenosha School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WI",
        "nces_id": "550732001462",
    },
    {
        "school": "Phoenix Project",
        "district": "Kenosha School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550732001714",
    },
    {
        "school": "Grewenow Elementary",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732002260",
    },
    {
        "school": "Hillcrest School",
        "district": "Kenosha School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550732002317",
    },
    {
        "school": "Dimensions of Learning Academy",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732002457",
    },
    {
        "school": "Paris Elementary",
        "district": "Paris J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551140001520",
    },
    {
        "school": "Randall Consolidated School",
        "district": "Randall J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551239001649",
    },
    {
        "school": "Central High",
        "district": "Central/Westosha UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551329001751",
    },
    {
        "school": "Salem Elementary",
        "district": "Salem School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551335001753",
    },
    {
        "school": "Riverview Elementary",
        "district": "Silver Lake J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551386001815",
    },
    {
        "school": "Lakewood Elementary",
        "district": "Twin Lakes #4 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551509001957",
    },
    {
        "school": "Wheatland Center Elementary",
        "district": "Wheatland J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551656002163",
    },
    {
        "school": "Wilmot High",
        "district": "Wilmot UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551677002188",
    },
    {
        "school": "Northern Lights Elementary",
        "district": "Superior School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551467002539",
    },
    {
        "school": "Iron River Elementary",
        "district": "Maple School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550864000983",
    },
    {
        "school": "Northwestern High",
        "district": "Maple School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550864000987",
    },
    {
        "school": "Northwestern Middle",
        "district": "Maple School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550864000988",
    },
    {
        "school": "Northwestern Elementary",
        "district": "Maple School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550864001481",
    },
    {
        "school": "Solon Springs School",
        "district": "Solon Springs School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551398001911",
    },
    {
        "school": "Great Lakes Elementary",
        "district": "Superior School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551467000687",
    },
    {
        "school": "Bryant Elementary",
        "district": "Superior School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551467001906",
    },
    {
        "school": "Superior Middle",
        "district": "Superior School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551467001907",
    },
    {
        "school": "Cooper Elementary",
        "district": "Superior School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551467001917",
    },
    {
        "school": "Superior High",
        "district": "Superior School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551467001918",
    },
    {
        "school": "Four Corners Elementary",
        "district": "Superior School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551467002347",
    },
    {
        "school": "Lake Superior Elementary",
        "district": "Superior School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551467002348",
    },
    {
        "school": "Augusta Middle",
        "district": "Augusta School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550063002585",
    },
    {
        "school": "Wildlands Charter School",
        "district": "Augusta School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550063002586",
    },
    {
        "school": "Chippewa Valley Montessori Charter School",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405002544",
    },
    {
        "school": "Mondovi Middle",
        "district": "Mondovi School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550978000383",
    },
    {
        "school": "Mondovi Elementary",
        "district": "Mondovi School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550978001286",
    },
    {
        "school": "Mondovi High",
        "district": "Mondovi School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550978001287",
    },
    {
        "school": "Bloomer Elementary",
        "district": "Bloomer School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550135000183",
    },
    {
        "school": "Bloomer High",
        "district": "Bloomer School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550135000184",
    },
    {
        "school": "Bloomer Middle",
        "district": "Bloomer School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550135000185",
    },
    {
        "school": "Cadott Elementary",
        "district": "Cadott Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550204000247",
    },
    {
        "school": "Cadott High",
        "district": "Cadott Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550204000248",
    },
    {
        "school": "Cadott Junior High",
        "district": "Cadott Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550204000249",
    },
    {
        "school": "Chippewa Falls Middle",
        "district": "Chippewa Falls Area Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550255000281",
    },
    {
        "school": "Chippewa Falls High",
        "district": "Chippewa Falls Area Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550255000282",
    },
    {
        "school": "Halmstad Elementary",
        "district": "Chippewa Falls Area Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550255000284",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Chippewa Falls Area Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550255000285",
    },
    {
        "school": "Jim Falls Elementary",
        "district": "Chippewa Falls Area Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550255000286",
    },
    {
        "school": "Stillson Elementary",
        "district": "Chippewa Falls Area Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550255000288",
    },
    {
        "school": "Parkview Elementary",
        "district": "Chippewa Falls Area Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550255000637",
    },
    {
        "school": "Southview Elementary",
        "district": "Chippewa Falls Area Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550255002295",
    },
    {
        "school": "Cornell Elementary",
        "district": "Cornell School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550288000323",
    },
    {
        "school": "Cornell High",
        "district": "Cornell School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550288000324",
    },
    {
        "school": "Holcombe Elementary",
        "district": "Lake Holcombe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550768000885",
    },
    {
        "school": "Holcombe High",
        "district": "Lake Holcombe School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550768000886",
    },
    {
        "school": "New Auburn Elementary",
        "district": "New Auburn School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551044001362",
    },
    {
        "school": "New Auburn High",
        "district": "New Auburn School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551044001363",
    },
    {
        "school": "Boyd Elementary",
        "district": "Stanley-Boyd Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551443001864",
    },
    {
        "school": "Stanley-Boyd Middle",
        "district": "Stanley-Boyd Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551443001866",
    },
    {
        "school": "Stanley-Boyd High",
        "district": "Stanley-Boyd Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551443001867",
    },
    {
        "school": "Stanley Elementary",
        "district": "Stanley-Boyd Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551443002363",
    },
    {
        "school": "Altoona High",
        "district": "Altoona School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550027000026",
    },
    {
        "school": "Altoona Middle",
        "district": "Altoona School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550027000027",
    },
    {
        "school": "Altoona Elementary",
        "district": "Altoona School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550027000028",
    },
    {
        "school": "Augusta Elementary",
        "district": "Augusta School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550063000092",
    },
    {
        "school": "Augusta High",
        "district": "Augusta School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550063000093",
    },
    {
        "school": "Flynn Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000417",
    },
    {
        "school": "DeLong Middle",
        "district": "Eau Claire Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000421",
    },
    {
        "school": "Prairie Ridge Early Learning School",
        "district": "Eau Claire Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000423",
    },
    {
        "school": "Locust Lane Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000424",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000425",
    },
    {
        "school": "Manz Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000427",
    },
    {
        "school": "Memorial High",
        "district": "Eau Claire Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000429",
    },
    {
        "school": "North High",
        "district": "Eau Claire Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000431",
    },
    {
        "school": "Putnam Heights Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000433",
    },
    {
        "school": "Robbins Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000436",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000437",
    },
    {
        "school": "Davey Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000438",
    },
    {
        "school": "Sherman Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000439",
    },
    {
        "school": "Northwoods Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000559",
    },
    {
        "school": "Northstar Middle",
        "district": "Eau Claire Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000645",
    },
    {
        "school": "McKinley Charter School",
        "district": "Eau Claire Area School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550405000705",
    },
    {
        "school": "Lakeshore Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405000708",
    },
    {
        "school": "South Middle",
        "district": "Eau Claire Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405002297",
    },
    {
        "school": "Meadowview Elementary",
        "district": "Eau Claire Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405002405",
    },
    {
        "school": "Fall Creek Elementary",
        "district": "Fall Creek School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550450000480",
    },
    {
        "school": "Fall Creek High",
        "district": "Fall Creek School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550450000481",
    },
    {
        "school": "Fall Creek Middle",
        "district": "Fall Creek School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550450000482",
    },
    {
        "school": "Early Learning Center",
        "district": "North Fond du Lac School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551074002531",
    },
    {
        "school": "Campbellsport Elementary",
        "district": "Campbellsport School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550216000258",
    },
    {
        "school": "Campbellsport High",
        "district": "Campbellsport School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550216000259",
    },
    {
        "school": "Eden Elementary",
        "district": "Campbellsport School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550216000260",
    },
    {
        "school": "Campbellsport Middle",
        "district": "Campbellsport School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550216002484",
    },
    {
        "school": "Chegwin Elementary",
        "district": "Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000493",
    },
    {
        "school": "Evans Elementary",
        "district": "Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000494",
    },
    {
        "school": "Riverside Elementary",
        "district": "Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000497",
    },
    {
        "school": "Fond du Lac High",
        "district": "Fond du Lac School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000498",
    },
    {
        "school": "Lakeshore Elementary",
        "district": "Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000499",
    },
    {
        "school": "Parkside Elementary",
        "district": "Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000500",
    },
    {
        "school": "Pier Elementary",
        "district": "Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000501",
    },
    {
        "school": "Roberts Elementary",
        "district": "Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000502",
    },
    {
        "school": "Rosenow Elementary",
        "district": "Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000503",
    },
    {
        "school": "Sabish Middle",
        "district": "Fond du Lac School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000504",
    },
    {
        "school": "Theisen Middle",
        "district": "Fond du Lac School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000505",
    },
    {
        "school": "Waters Elementary",
        "district": "Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468000506",
    },
    {
        "school": "Woodworth Middle",
        "district": "Fond du Lac School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468002325",
    },
    {
        "school": "Bessie Allen Middle",
        "district": "North Fond du Lac School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551074001396",
    },
    {
        "school": "Friendship Learning Elementary",
        "district": "North Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551074001398",
    },
    {
        "school": "Horace Mann High",
        "district": "North Fond du Lac School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551074001399",
    },
    {
        "school": "Oakfield Elementary",
        "district": "Oakfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551086001414",
    },
    {
        "school": "Oakfield High",
        "district": "Oakfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551086001415",
    },
    {
        "school": "Oakfield Middle",
        "district": "Oakfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551086001416",
    },
    {
        "school": "Murray Park Elementary",
        "district": "Ripon Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551302000487",
    },
    {
        "school": "Ripon High",
        "district": "Ripon Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551302001718",
    },
    {
        "school": "Ripon Middle",
        "district": "Ripon Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551302001719",
    },
    {
        "school": "Barlow Park Elementary",
        "district": "Ripon Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551302001893",
    },
    {
        "school": "Brandon Elementary",
        "district": "Rosendale-Brandon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551310001727",
    },
    {
        "school": "Brandon Middle",
        "district": "Rosendale-Brandon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551310001728",
    },
    {
        "school": "Laconia High",
        "district": "Rosendale-Brandon School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551310001729",
    },
    {
        "school": "Rosendale Primary",
        "district": "Rosendale-Brandon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551310001730",
    },
    {
        "school": "Rosendale Intermediate",
        "district": "Rosendale-Brandon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551310001731",
    },
    {
        "school": "Susie C Altmayer Elementary",
        "district": "De Pere School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550321002668",
    },
    {
        "school": "Green Bay Head Start",
        "district": "Green Bay Area Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582002589",
    },
    {
        "school": "Kewaunee Elementary",
        "district": "Kewaunee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550741002592",
    },
    {
        "school": "Algoma Elementary",
        "district": "Algoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550015000015",
    },
    {
        "school": "Algoma High",
        "district": "Algoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550015000016",
    },
    {
        "school": "Kewaunee High",
        "district": "Kewaunee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550741000841",
    },
    {
        "school": "Kewaunee Middle",
        "district": "Kewaunee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550741001726",
    },
    {
        "school": "Luxemburg-Casco Intermediate",
        "district": "Luxemburg-Casco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550834000916",
    },
    {
        "school": "Luxemburg-Casco Middle",
        "district": "Luxemburg-Casco School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550834000917",
    },
    {
        "school": "Luxemburg-Casco High",
        "district": "Luxemburg-Casco School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550834000918",
    },
    {
        "school": "Luxemburg-Casco Primary",
        "district": "Luxemburg-Casco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550834002525",
    },
    {
        "school": "Gillett High",
        "district": "Gillett School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550525000564",
    },
    {
        "school": "Gillett Middle",
        "district": "Gillett School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550525000565",
    },
    {
        "school": "Gillett Elementary",
        "district": "Gillett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550525000566",
    },
    {
        "school": "Lena Elementary",
        "district": "Lena School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550786000895",
    },
    {
        "school": "Lena High",
        "district": "Lena School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550786000896",
    },
    {
        "school": "Lena Middle",
        "district": "Lena School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550786000897",
    },
    {
        "school": "Oconto High",
        "district": "Oconto Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551092001428",
    },
    {
        "school": "Oconto Elementary",
        "district": "Oconto Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551092001429",
    },
    {
        "school": "Oconto Middle",
        "district": "Oconto Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551092001430",
    },
    {
        "school": "Oconto Falls Elementary",
        "district": "Oconto Falls Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551095001066",
    },
    {
        "school": "Abrams Elementary",
        "district": "Oconto Falls Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551095001431",
    },
    {
        "school": "Oconto Falls High",
        "district": "Oconto Falls Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551095001435",
    },
    {
        "school": "Washington Middle",
        "district": "Oconto Falls Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551095001438",
    },
    {
        "school": "Falls Alternative Learning Site (FALS)",
        "district": "Oconto Falls Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551095001853",
    },
    {
        "school": "Suring Elementary",
        "district": "Suring Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551470001921",
    },
    {
        "school": "Suring High",
        "district": "Suring Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551470001922",
    },
    {
        "school": "Hopp Elementary/Secondary",
        "district": "Brown Co CDEB",
        "level": "Other",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "550001801612",
    },
    {
        "school": "Ashwaubenon High",
        "district": "Ashwaubenon School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550054000081",
    },
    {
        "school": "Parkview Middle",
        "district": "Ashwaubenon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550054000083",
    },
    {
        "school": "Pioneer Elementary",
        "district": "Ashwaubenon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550054000084",
    },
    {
        "school": "Valley View Elementary",
        "district": "Ashwaubenon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550054000085",
    },
    {
        "school": "Cormier School and Early Learning Center",
        "district": "Ashwaubenon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550054000294",
    },
    {
        "school": "De Pere High",
        "district": "De Pere School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550321000361",
    },
    {
        "school": "De Pere Middle",
        "district": "De Pere School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550321000362",
    },
    {
        "school": "Dickinson Elementary",
        "district": "De Pere School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550321000363",
    },
    {
        "school": "Heritage Elementary",
        "district": "De Pere School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550321001254",
    },
    {
        "school": "Foxview Intermediate",
        "district": "De Pere School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550321002488",
    },
    {
        "school": "Denmark Early Childhood Ctr",
        "district": "Denmark School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550366000346",
    },
    {
        "school": "Denmark Elementary",
        "district": "Denmark School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550366000387",
    },
    {
        "school": "Denmark High",
        "district": "Denmark School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550366000388",
    },
    {
        "school": "Denmark Middle",
        "district": "Denmark School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550366000389",
    },
    {
        "school": "King Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000166",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000562",
    },
    {
        "school": "Aldo Leopold Community School K-8",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000610",
    },
    {
        "school": "Baird Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000611",
    },
    {
        "school": "Bay View",
        "district": "Green Bay Area Public School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550582000612",
    },
    {
        "school": "Beaumont Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000613",
    },
    {
        "school": "Chappell Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000614",
    },
    {
        "school": "Danz Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000616",
    },
    {
        "school": "Doty Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000617",
    },
    {
        "school": "East High",
        "district": "Green Bay Area Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000618",
    },
    {
        "school": "Edison Middle",
        "district": "Green Bay Area Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000619",
    },
    {
        "school": "Eisenhower Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000620",
    },
    {
        "school": "Elmore Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000621",
    },
    {
        "school": "Fort Howard Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000622",
    },
    {
        "school": "Franklin Middle",
        "district": "Green Bay Area Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000623",
    },
    {
        "school": "Howe Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000624",
    },
    {
        "school": "Jackson Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000625",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000626",
    },
    {
        "school": "Keller Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000627",
    },
    {
        "school": "Kennedy Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000628",
    },
    {
        "school": "Langlade Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000629",
    },
    {
        "school": "Lombardi Middle",
        "district": "Green Bay Area Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000631",
    },
    {
        "school": "MacArthur Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000632",
    },
    {
        "school": "Martin Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000633",
    },
    {
        "school": "Nicolet Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000634",
    },
    {
        "school": "Preble High",
        "district": "Green Bay Area Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000636",
    },
    {
        "school": "Southwest High",
        "district": "Green Bay Area Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000638",
    },
    {
        "school": "Sullivan Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000639",
    },
    {
        "school": "Tank Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000640",
    },
    {
        "school": "Washington Middle",
        "district": "Green Bay Area Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000641",
    },
    {
        "school": "Webster Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000642",
    },
    {
        "school": "Wequiock Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000643",
    },
    {
        "school": "West High",
        "district": "Green Bay Area Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582000644",
    },
    {
        "school": "Red Smith K-8",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582001672",
    },
    {
        "school": "Wilder Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582002406",
    },
    {
        "school": "McAuliffe Elementary",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582002431",
    },
    {
        "school": "Bay Port High",
        "district": "Howard-Suamico School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550663000716",
    },
    {
        "school": "Bay View Middle",
        "district": "Howard-Suamico School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550663000717",
    },
    {
        "school": "Meadowbrook Elementary",
        "district": "Howard-Suamico School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550663000718",
    },
    {
        "school": "Howard Elementary",
        "district": "Howard-Suamico School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550663000719",
    },
    {
        "school": "Suamico Elementary",
        "district": "Howard-Suamico School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550663000720",
    },
    {
        "school": "Forest Glen Elementary",
        "district": "Howard-Suamico School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550663002409",
    },
    {
        "school": "Lineville Intermediate",
        "district": "Howard-Suamico School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550663002456",
    },
    {
        "school": "Glenbrook Elementary",
        "district": "Pulaski Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551233001597",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Pulaski Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551233001598",
    },
    {
        "school": "Lannoye Elementary",
        "district": "Pulaski Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551233001599",
    },
    {
        "school": "Pulaski High",
        "district": "Pulaski Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551233001600",
    },
    {
        "school": "Pulaski Community Middle",
        "district": "Pulaski Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551233001888",
    },
    {
        "school": "West De Pere Middle",
        "district": "West De Pere School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551632000545",
    },
    {
        "school": "West De Pere High",
        "district": "West De Pere School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551632002138",
    },
    {
        "school": "Westwood Elementary",
        "district": "West De Pere School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551632002139",
    },
    {
        "school": "Wrightstown Middle",
        "district": "Wrightstown Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551719000280",
    },
    {
        "school": "Wrightstown Elementary",
        "district": "Wrightstown Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551719002228",
    },
    {
        "school": "Wrightstown High",
        "district": "Wrightstown Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551719002229",
    },
    {
        "school": "Fairview Elementary",
        "district": "Pulaski Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551233001596",
    },
    {
        "school": "Sunnyside Elementary",
        "district": "Pulaski Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551233001601",
    },
    {
        "school": "Florence Elementary",
        "district": "Florence County School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550465000489",
    },
    {
        "school": "Florence High",
        "district": "Florence County School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550465000490",
    },
    {
        "school": "Florence Middle",
        "district": "Florence County School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550465002360",
    },
    {
        "school": "Theodore Robinson Intermediate School",
        "district": "Evansville Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550444002552",
    },
    {
        "school": "Harmony Elementary",
        "district": "Milton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550957002600",
    },
    {
        "school": "Aldrich Intermediate",
        "district": "Beloit School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105000137",
    },
    {
        "school": "Converse Elementary",
        "district": "Beloit School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105000139",
    },
    {
        "school": "Cunningham Intermediate",
        "district": "Beloit School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105000140",
    },
    {
        "school": "Gaston Elementary",
        "district": "Beloit School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105000141",
    },
    {
        "school": "Hackett Elementary",
        "district": "Beloit School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105000142",
    },
    {
        "school": "Memorial High",
        "district": "Beloit School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105000146",
    },
    {
        "school": "Merrill Elementary",
        "district": "Beloit School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105000147",
    },
    {
        "school": "Robinson Elementary",
        "district": "Beloit School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105000150",
    },
    {
        "school": "Todd Elementary",
        "district": "Beloit School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105000153",
    },
    {
        "school": "McNeel Intermediate",
        "district": "Beloit School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105002330",
    },
    {
        "school": "Turner High",
        "district": "Beloit Turner School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550108000156",
    },
    {
        "school": "Powers Elementary",
        "district": "Beloit Turner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550108000157",
    },
    {
        "school": "Townview Elementary",
        "district": "Beloit Turner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550108000158",
    },
    {
        "school": "Turner Middle",
        "district": "Beloit Turner School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550108000159",
    },
    {
        "school": "Clinton Elementary",
        "district": "Clinton Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550264000295",
    },
    {
        "school": "Clinton High",
        "district": "Clinton Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550264000296",
    },
    {
        "school": "Clinton Middle",
        "district": "Clinton Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550264000297",
    },
    {
        "school": "Edgerton Community Elementary",
        "district": "Edgerton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550411000442",
    },
    {
        "school": "Edgerton High",
        "district": "Edgerton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550411000443",
    },
    {
        "school": "Edgerton Middle",
        "district": "Edgerton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550411000444",
    },
    {
        "school": "Yahara Elementary",
        "district": "Edgerton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550411000446",
    },
    {
        "school": "Levi Leonard Elementary",
        "district": "Evansville Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550444000477",
    },
    {
        "school": "Evansville High",
        "district": "Evansville Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550444000478",
    },
    {
        "school": "J C McKenna Middle",
        "district": "Evansville Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550444000479",
    },
    {
        "school": "Adams Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000756",
    },
    {
        "school": "Craig High",
        "district": "Janesville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000757",
    },
    {
        "school": "Edison Middle",
        "district": "Janesville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000758",
    },
    {
        "school": "Franklin Middle",
        "district": "Janesville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000759",
    },
    {
        "school": "Harrison Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000761",
    },
    {
        "school": "Jackson Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000763",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000764",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000766",
    },
    {
        "school": "Madison Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000767",
    },
    {
        "school": "Marshall Middle",
        "district": "Janesville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000768",
    },
    {
        "school": "Monroe Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000769",
    },
    {
        "school": "Parker High",
        "district": "Janesville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000770",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000773",
    },
    {
        "school": "Van Buren Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000774",
    },
    {
        "school": "Washington Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000775",
    },
    {
        "school": "Wilson Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702000776",
    },
    {
        "school": "Kennedy Elementary",
        "district": "Janesville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702001686",
    },
    {
        "school": "Rock River Charter School",
        "district": "Janesville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702001698",
    },
    {
        "school": "Northside Intermediate",
        "district": "Milton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550957000382",
    },
    {
        "school": "Consolidated Elementary",
        "district": "Milton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550957001115",
    },
    {
        "school": "East Elementary",
        "district": "Milton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550957001117",
    },
    {
        "school": "Milton High",
        "district": "Milton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550957001118",
    },
    {
        "school": "Milton Middle",
        "district": "Milton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550957001119",
    },
    {
        "school": "West Elementary",
        "district": "Milton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550957001120",
    },
    {
        "school": "Parkview Elementary",
        "district": "Parkview School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551113001475",
    },
    {
        "school": "Parkview High",
        "district": "Parkview School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551113001476",
    },
    {
        "school": "Parkview Junior High",
        "district": "Parkview School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551113001477",
    },
    {
        "school": "Bangor Elementary",
        "district": "Bangor School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550078000100",
    },
    {
        "school": "Bangor Middle/High",
        "district": "Bangor School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550078000101",
    },
    {
        "school": "Holmen High",
        "district": "Holmen School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550654000706",
    },
    {
        "school": "Holmen Middle",
        "district": "Holmen School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550654000707",
    },
    {
        "school": "Holmen Public Preschool",
        "district": "Holmen School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550654000709",
    },
    {
        "school": "Sand Lake Elementary",
        "district": "Holmen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550654001678",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Holmen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550654002259",
    },
    {
        "school": "Viking Elementary",
        "district": "Holmen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550654002298",
    },
    {
        "school": "Southern Bluffs Elementary",
        "district": "La Crosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000195",
    },
    {
        "school": "North Woods International School",
        "district": "La Crosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000196",
    },
    {
        "school": "School of Technology and Arts I",
        "district": "La Crosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000648",
    },
    {
        "school": "Central High",
        "district": "La Crosse School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000854",
    },
    {
        "school": "Emerson Elementary",
        "district": "La Crosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000855",
    },
    {
        "school": "Northside Elementary",
        "district": "La Crosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000857",
    },
    {
        "school": "Hamilton Early Learning Center",
        "district": "La Crosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000858",
    },
    {
        "school": "Spence Elementary",
        "district": "La Crosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000859",
    },
    {
        "school": "Hintgen Elementary",
        "district": "La Crosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000862",
    },
    {
        "school": "Lincoln Middle",
        "district": "La Crosse School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000863",
    },
    {
        "school": "Logan Middle",
        "district": "La Crosse School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000864",
    },
    {
        "school": "Logan High",
        "district": "La Crosse School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000865",
    },
    {
        "school": "Longfellow Middle",
        "district": "La Crosse School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000866",
    },
    {
        "school": "State Road Elementary",
        "district": "La Crosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000869",
    },
    {
        "school": "Summit Environmental School",
        "district": "La Crosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753000870",
    },
    {
        "school": "School of Technology and Arts II",
        "district": "La Crosse School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753001295",
    },
    {
        "school": "Coulee Montessori Charter School",
        "district": "La Crosse School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753001463",
    },
    {
        "school": "LaCrossroads Charter",
        "district": "La Crosse School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753002466",
    },
    {
        "school": "La Crosse Offsite Preschool",
        "district": "La Crosse School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753002467",
    },
    {
        "school": "Eagle Bluff Elementary",
        "district": "Onalaska School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551101001445",
    },
    {
        "school": "Northern Hills Elementary",
        "district": "Onalaska School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551101001446",
    },
    {
        "school": "Onalaska High",
        "district": "Onalaska School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551101001447",
    },
    {
        "school": "Onalaska Middle",
        "district": "Onalaska School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551101001448",
    },
    {
        "school": "Pertzsch Elementary",
        "district": "Onalaska School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551101001449",
    },
    {
        "school": "West Salem Elementary",
        "district": "West Salem School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551635002140",
    },
    {
        "school": "West Salem High",
        "district": "West Salem School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551635002141",
    },
    {
        "school": "West Salem Middle",
        "district": "West Salem School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551635002324",
    },
    {
        "school": "Stanley Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502632",
    },
    {
        "school": "Innovative & Alternative High",
        "district": "Madison Metropolitan School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550852003349",
    },
    {
        "school": "Nuestro Mundo",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852003356",
    },
    {
        "school": "Horizon Elementary",
        "district": "Sun Prairie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464002624",
    },
    {
        "school": "Prairie Phoenix Academy",
        "district": "Sun Prairie Area School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551464002625",
    },
    {
        "school": "John C Burke Correctional Center",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502635",
    },
    {
        "school": "Wisconsin Secure Program Facility",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502581",
    },
    {
        "school": "New Lisbon Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502633",
    },
    {
        "school": "Milwaukee Secure Detention Facility",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502561",
    },
    {
        "school": "Robert Ellsworth Correctional Center",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502572",
    },
    {
        "school": "Flambeau Correctional Center",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502634",
    },
    {
        "school": "Cambria Friesland Middle/High",
        "district": "Cambria-Friesland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550207000250",
    },
    {
        "school": "Cambria Friesland Elementary",
        "district": "Cambria-Friesland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550207000253",
    },
    {
        "school": "Columbus High",
        "district": "Columbus School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550282000318",
    },
    {
        "school": "Columbus Middle",
        "district": "Columbus School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550282000319",
    },
    {
        "school": "Columbus Elementary",
        "district": "Columbus School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550282000321",
    },
    {
        "school": "Fall River Elementary",
        "district": "Fall River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550453000483",
    },
    {
        "school": "Fall River High",
        "district": "Fall River School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550453000484",
    },
    {
        "school": "Lodi Primary",
        "district": "Lodi School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550819000903",
    },
    {
        "school": "Lodi Elementary",
        "district": "Lodi School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550819000904",
    },
    {
        "school": "Lodi High",
        "district": "Lodi School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550819000905",
    },
    {
        "school": "Lodi Middle",
        "district": "Lodi School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550819000906",
    },
    {
        "school": "Pardeeville Elementary",
        "district": "Pardeeville Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551137001517",
    },
    {
        "school": "Pardeeville High",
        "district": "Pardeeville Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551137001518",
    },
    {
        "school": "Pardeeville Middle",
        "district": "Pardeeville Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551137001519",
    },
    {
        "school": "Rusch Elementary",
        "district": "Portage Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551206001602",
    },
    {
        "school": "Portage Academy of Achievement",
        "district": "Portage Community School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551206002174",
    },
    {
        "school": "Lewiston Elementary",
        "district": "Portage Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551206002280",
    },
    {
        "school": "Wayne Bartels Middle",
        "district": "Portage Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551206002283",
    },
    {
        "school": "Portage High",
        "district": "Portage Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551206002284",
    },
    {
        "school": "Muir Elementary",
        "district": "Portage Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551206002310",
    },
    {
        "school": "Arlington Elementary",
        "district": "Poynette School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551212001577",
    },
    {
        "school": "Poynette Elementary",
        "district": "Poynette School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551212001579",
    },
    {
        "school": "Poynette High",
        "district": "Poynette School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551212001580",
    },
    {
        "school": "Poynette Middle",
        "district": "Poynette School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551212001581",
    },
    {
        "school": "Rio Elementary",
        "district": "Rio Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551299001712",
    },
    {
        "school": "Rio Middle/High",
        "district": "Rio Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551299001713",
    },
    {
        "school": "Wisconsin Dells High",
        "district": "Wisconsin Dells School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551704002200",
    },
    {
        "school": "Spring Hill Elementary",
        "district": "Wisconsin Dells School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551704002201",
    },
    {
        "school": "Spring Hill Middle",
        "district": "Wisconsin Dells School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551704002271",
    },
    {
        "school": "Barneveld Elementary",
        "district": "Barneveld School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550084000111",
    },
    {
        "school": "Barneveld High",
        "district": "Barneveld School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550084000112",
    },
    {
        "school": "Pecatonica Elementary",
        "district": "Pecatonica Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550131000181",
    },
    {
        "school": "Dodgeville Elementary",
        "district": "Dodgeville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550369000390",
    },
    {
        "school": "Dodgeville Middle",
        "district": "Dodgeville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550369000391",
    },
    {
        "school": "Dodgeville High",
        "district": "Dodgeville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550369000392",
    },
    {
        "school": "Ridgeway Elementary",
        "district": "Dodgeville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550369000393",
    },
    {
        "school": "Highland Community Elementary",
        "district": "Highland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550642000698",
    },
    {
        "school": "Highland Community High",
        "district": "Highland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550642000699",
    },
    {
        "school": "Iowa-Grant Elementary/Middle",
        "district": "Iowa-Grant School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550687000744",
    },
    {
        "school": "Iowa-Grant High",
        "district": "Iowa-Grant School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550687000745",
    },
    {
        "school": "Mineral Point Elementary",
        "district": "Mineral Point Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550966001275",
    },
    {
        "school": "Mineral Point High",
        "district": "Mineral Point Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550966001276",
    },
    {
        "school": "Mineral Point Middle",
        "district": "Mineral Point Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550966001277",
    },
    {
        "school": "Pecatonica High",
        "district": "Pecatonica Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550131000182",
    },
    {
        "school": "Endeavor Elementary",
        "district": "Portage Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551206002419",
    },
    {
        "school": "Neenah Creek Elementary",
        "district": "Wisconsin Dells School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551704000551",
    },
    {
        "school": "Lake Delton Elementary",
        "district": "Wisconsin Dells School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551704002198",
    },
    {
        "school": "Green Bay Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003501945",
    },
    {
        "school": "Northern Wisconsin Center",
        "district": "Wisconsin Department of Health Services",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003601983",
    },
    {
        "school": "Columbia Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502005",
    },
    {
        "school": "Prairie du Chien Correctional Inst",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502090",
    },
    {
        "school": "Oakhill Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502043",
    },
    {
        "school": "Central Wisconsin Center",
        "district": "Wisconsin Department of Health Services",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003602111",
    },
    {
        "school": "Mendota Mental Health Institution",
        "district": "Wisconsin Department of Health Services",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003602122",
    },
    {
        "school": "Belleville High",
        "district": "Belleville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550099000132",
    },
    {
        "school": "Belleville Middle",
        "district": "Belleville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550099000133",
    },
    {
        "school": "Belleville Elementary",
        "district": "Belleville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550099001211",
    },
    {
        "school": "Black Earth Elementary",
        "district": "Wisconsin Heights School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550123000170",
    },
    {
        "school": "Mazomanie Elementary",
        "district": "Wisconsin Heights School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550123000171",
    },
    {
        "school": "Wisconsin Heights High",
        "district": "Wisconsin Heights School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550123000172",
    },
    {
        "school": "Wisconsin Heights Middle",
        "district": "Wisconsin Heights School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550123000609",
    },
    {
        "school": "Cambridge Elementary",
        "district": "Cambridge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550210000254",
    },
    {
        "school": "Nikolay Middle",
        "district": "Cambridge School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550210000298",
    },
    {
        "school": "Yahara Elementary",
        "district": "De Forest Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550318000108",
    },
    {
        "school": "Eagle Point Elementary",
        "district": "De Forest Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550318000354",
    },
    {
        "school": "De Forest High",
        "district": "De Forest Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550318000355",
    },
    {
        "school": "De Forest Middle",
        "district": "De Forest Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550318000356",
    },
    {
        "school": "Windsor Elementary",
        "district": "De Forest Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550318000360",
    },
    {
        "school": "Holum Education Center",
        "district": "De Forest Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550318002368",
    },
    {
        "school": "Deerfield Elementary",
        "district": "Deerfield Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550327000370",
    },
    {
        "school": "Deerfield High",
        "district": "Deerfield Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550327000371",
    },
    {
        "school": "Deerfield Middle",
        "district": "Deerfield Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550327000372",
    },
    {
        "school": "James Wright Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000373",
    },
    {
        "school": "Spring Harbor Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000649",
    },
    {
        "school": "Sandburg Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000920",
    },
    {
        "school": "Lindbergh Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000921",
    },
    {
        "school": "Cherokee Heights Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000922",
    },
    {
        "school": "Crestwood Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000924",
    },
    {
        "school": "East High",
        "district": "Madison Metropolitan School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000925",
    },
    {
        "school": "Elvehjem Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000926",
    },
    {
        "school": "Emerson Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000927",
    },
    {
        "school": "Falk Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000928",
    },
    {
        "school": "Allis Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000929",
    },
    {
        "school": "Franklin Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000930",
    },
    {
        "school": "Glendale Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000931",
    },
    {
        "school": "Stephens Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000932",
    },
    {
        "school": "Whitehorse Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000934",
    },
    {
        "school": "Schenk Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000935",
    },
    {
        "school": "Memorial High",
        "district": "Madison Metropolitan School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000937",
    },
    {
        "school": "Jefferson Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000938",
    },
    {
        "school": "Kennedy Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000939",
    },
    {
        "school": "Muir Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000940",
    },
    {
        "school": "LaFollette High",
        "district": "Madison Metropolitan School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000941",
    },
    {
        "school": "Lake View Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000942",
    },
    {
        "school": "Leopold Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000944",
    },
    {
        "school": "Lowell Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000946",
    },
    {
        "school": "Marquette Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000948",
    },
    {
        "school": "O'Keeffe Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000949",
    },
    {
        "school": "Mendota Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000950",
    },
    {
        "school": "Midvale Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000951",
    },
    {
        "school": "Orchard Ridge Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000952",
    },
    {
        "school": "Toki Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000953",
    },
    {
        "school": "Randall Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000954",
    },
    {
        "school": "Sennett Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000955",
    },
    {
        "school": "Huegel Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000956",
    },
    {
        "school": "Gompers Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000958",
    },
    {
        "school": "Black Hawk Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000959",
    },
    {
        "school": "Shorewood Hills Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000962",
    },
    {
        "school": "Thoreau Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000964",
    },
    {
        "school": "Van Hise Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000965",
    },
    {
        "school": "Hamilton Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000966",
    },
    {
        "school": "West High",
        "district": "Madison Metropolitan School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852000967",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852002263",
    },
    {
        "school": "Shabazz-City High",
        "district": "Madison Metropolitan School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550852002265",
    },
    {
        "school": "Hawthorne Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852002410",
    },
    {
        "school": "Lapham Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852002412",
    },
    {
        "school": "Sherman Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852002435",
    },
    {
        "school": "4K PK Off Site",
        "district": "Madison Metropolitan School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852002475",
    },
    {
        "school": "Cesar Chavez Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852002483",
    },
    {
        "school": "Marshall Early Learning Center",
        "district": "Marshall School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550879000569",
    },
    {
        "school": "Marshall Elementary",
        "district": "Marshall School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550879001012",
    },
    {
        "school": "Marshall High",
        "district": "Marshall School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550879001013",
    },
    {
        "school": "Marshall Middle",
        "district": "Marshall School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550879001014",
    },
    {
        "school": "Conrad Elvehjem Primary School",
        "district": "McFarland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550891001034",
    },
    {
        "school": "McFarland High",
        "district": "McFarland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550891001035",
    },
    {
        "school": "Indian Mound Middle",
        "district": "McFarland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550891001036",
    },
    {
        "school": "Waubesa Intermediate",
        "district": "McFarland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550891002172",
    },
    {
        "school": "Glacier Creek Middle",
        "district": "Middleton-Cross Plains Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951000754",
    },
    {
        "school": "Sunset Ridge Elementary",
        "district": "Middleton-Cross Plains Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951000755",
    },
    {
        "school": "Kromrey Middle",
        "district": "Middleton-Cross Plains Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951001104",
    },
    {
        "school": "Elm Lawn Elementary",
        "district": "Middleton-Cross Plains Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951001105",
    },
    {
        "school": "Middleton High",
        "district": "Middleton-Cross Plains Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951001107",
    },
    {
        "school": "Northside Elementary",
        "district": "Middleton-Cross Plains Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951001109",
    },
    {
        "school": "Park Elementary",
        "district": "Middleton-Cross Plains Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951001110",
    },
    {
        "school": "Sauk Trail Elementary",
        "district": "Middleton-Cross Plains Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951001111",
    },
    {
        "school": "West Middleton Elementary",
        "district": "Middleton-Cross Plains Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951001113",
    },
    {
        "school": "Taylor Prairie Elementary",
        "district": "Monona Grove School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550981000682",
    },
    {
        "school": "Cottage Grove Elementary",
        "district": "Monona Grove School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550981001289",
    },
    {
        "school": "Monona Grove High",
        "district": "Monona Grove School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550981001291",
    },
    {
        "school": "Glacial Drumlin School",
        "district": "Monona Grove School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550981001293",
    },
    {
        "school": "Winnequah School",
        "district": "Monona Grove School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550981002343",
    },
    {
        "school": "Mount Horeb Middle",
        "district": "Mount Horeb Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550999000385",
    },
    {
        "school": "Mount Horeb Intermediate",
        "district": "Mount Horeb Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550999001311",
    },
    {
        "school": "Mount Horeb High",
        "district": "Mount Horeb Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550999001312",
    },
    {
        "school": "Mount Horeb Primary Center",
        "district": "Mount Horeb Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550999001313",
    },
    {
        "school": "Mount Horeb Early Learning Center",
        "district": "Mount Horeb Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550999002318",
    },
    {
        "school": "Brooklyn Elementary",
        "district": "Oregon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551110001468",
    },
    {
        "school": "Netherwood Knoll Elementary",
        "district": "Oregon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551110001469",
    },
    {
        "school": "Oregon High",
        "district": "Oregon School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551110001470",
    },
    {
        "school": "Oregon Middle",
        "district": "Oregon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551110001471",
    },
    {
        "school": "Prairie View Elementary",
        "district": "Oregon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551110001472",
    },
    {
        "school": "Rome Corners Intermediate",
        "district": "Oregon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551110002524",
    },
    {
        "school": "Kegonsa Elementary",
        "district": "Stoughton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551455001884",
    },
    {
        "school": "Stoughton High",
        "district": "Stoughton Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551455001886",
    },
    {
        "school": "River Bluff Middle",
        "district": "Stoughton Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551455001887",
    },
    {
        "school": "Fox Prairie Elementary",
        "district": "Stoughton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551455002424",
    },
    {
        "school": "Prairie View Middle",
        "district": "Sun Prairie Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464001400",
    },
    {
        "school": "Patrick Marsh Middle",
        "district": "Sun Prairie Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464001401",
    },
    {
        "school": "C H Bird Elementary",
        "district": "Sun Prairie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464001898",
    },
    {
        "school": "Eastside Elementary",
        "district": "Sun Prairie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464001899",
    },
    {
        "school": "Northside Elementary",
        "district": "Sun Prairie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464001900",
    },
    {
        "school": "Royal Oaks Elementary",
        "district": "Sun Prairie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464001901",
    },
    {
        "school": "Sun Prairie High",
        "district": "Sun Prairie Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464001902",
    },
    {
        "school": "Westside Elementary",
        "district": "Sun Prairie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464001904",
    },
    {
        "school": "Country View Elementary",
        "district": "Verona Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533000242",
    },
    {
        "school": "Savanna Oaks Middle",
        "district": "Verona Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533001149",
    },
    {
        "school": "Core Knowledge Charter School",
        "district": "Verona Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533001153",
    },
    {
        "school": "New Century School",
        "district": "Verona Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533001186",
    },
    {
        "school": "Sugar Creek Elementary",
        "district": "Verona Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533001971",
    },
    {
        "school": "Verona Area High",
        "district": "Verona Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533001972",
    },
    {
        "school": "Badger Ridge Middle",
        "district": "Verona Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533001973",
    },
    {
        "school": "Early Childhood",
        "district": "Verona Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533002285",
    },
    {
        "school": "Stoner Prairie Elementary",
        "district": "Verona Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533002376",
    },
    {
        "school": "Waunakee Heritage Elementary",
        "district": "Waunakee Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551581000269",
    },
    {
        "school": "Waunakee Prairie Elementary",
        "district": "Waunakee Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551581001198",
    },
    {
        "school": "Waunakee Intermediate",
        "district": "Waunakee Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551581002029",
    },
    {
        "school": "Waunakee High",
        "district": "Waunakee Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551581002030",
    },
    {
        "school": "Waunakee Middle",
        "district": "Waunakee Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551581002031",
    },
    {
        "school": "Fox Lake Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502010",
    },
    {
        "school": "Waupun Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502112",
    },
    {
        "school": "Taycheedah Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502118",
    },
    {
        "school": "Jackson Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003501970",
    },
    {
        "school": "Black River Correctional Center",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502116",
    },
    {
        "school": "Cambridge High",
        "district": "Cambridge School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550210000255",
    },
    {
        "school": "Lincoln Hills School",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502016",
    },
    {
        "school": "Racine Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003501949",
    },
    {
        "school": "Racine Youthful Offender Warren Young High",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003501965",
    },
    {
        "school": "Copper Lake School",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502110",
    },
    {
        "school": "WI Ctr for the Blind & Visually Impaired",
        "district": "Wisconsin Dept of Public Instruction",
        "level": "Other",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "550003700595",
    },
    {
        "school": "Kettle Moraine Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502026",
    },
    {
        "school": "Wisconsin School for the Deaf",
        "district": "Wisconsin Dept of Public Instruction",
        "level": "Other",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "550003700594",
    },
    {
        "school": "Redgranite Correctional Institute",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502233",
    },
    {
        "school": "Oshkosh Correctional Institution",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502052",
    },
    {
        "school": "Winnebago Mental Health Institution",
        "district": "Wisconsin Department of Health Services",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003602079",
    },
    {
        "school": "Wisconsin Resource Center",
        "district": "Wisconsin Department of Health Services",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003602080",
    },
    {
        "school": "Kiel eSchool",
        "district": "Kiel Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550744002554",
    },
    {
        "school": "Magee Elementary",
        "district": "Two Rivers Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551512002627",
    },
    {
        "school": "Kiel High",
        "district": "Kiel Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550744000844",
    },
    {
        "school": "Kiel Middle",
        "district": "Kiel Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550744000845",
    },
    {
        "school": "Zielanis Elementary",
        "district": "Kiel Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550744002333",
    },
    {
        "school": "Franklin Elementary",
        "district": "Manitowoc School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550861000973",
    },
    {
        "school": "Jackson Elementary",
        "district": "Manitowoc School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550861000974",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Manitowoc School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550861000975",
    },
    {
        "school": "Lincoln High",
        "district": "Manitowoc School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550861000976",
    },
    {
        "school": "Madison Elementary",
        "district": "Manitowoc School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550861000977",
    },
    {
        "school": "Monroe Elementary",
        "district": "Manitowoc School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550861000978",
    },
    {
        "school": "Riverview Elementary",
        "district": "Manitowoc School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550861000979",
    },
    {
        "school": "Washington Middle",
        "district": "Manitowoc School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550861000980",
    },
    {
        "school": "Wilson Middle",
        "district": "Manitowoc School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550861000981",
    },
    {
        "school": "Riverview Early Learning Center",
        "district": "Manitowoc School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550861002436",
    },
    {
        "school": "Mishicot High",
        "district": "Mishicot School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550975001283",
    },
    {
        "school": "Mishicot Middle",
        "district": "Mishicot School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550975001347",
    },
    {
        "school": "Schultz Elementary",
        "district": "Mishicot School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550975002273",
    },
    {
        "school": "Reedsville Elementary",
        "district": "Reedsville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551269001669",
    },
    {
        "school": "Reedsville High",
        "district": "Reedsville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551269001670",
    },
    {
        "school": "Reedsville Middle",
        "district": "Reedsville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551269001671",
    },
    {
        "school": "Koenig Elementary",
        "district": "Two Rivers Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551512001959",
    },
    {
        "school": "Clarke Middle",
        "district": "Two Rivers Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551512001960",
    },
    {
        "school": "Two Rivers High",
        "district": "Two Rivers Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551512001962",
    },
    {
        "school": "Valders Elementary",
        "district": "Valders Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551521001966",
    },
    {
        "school": "Valders High",
        "district": "Valders Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551521001967",
    },
    {
        "school": "Valders Middle",
        "district": "Valders Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551521001968",
    },
    {
        "school": "Coleman Elementary",
        "district": "Coleman School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550276000313",
    },
    {
        "school": "Coleman High",
        "district": "Coleman School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550276000314",
    },
    {
        "school": "Crivitz Elementary",
        "district": "Crivitz School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550297000329",
    },
    {
        "school": "Crivitz High",
        "district": "Crivitz School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550297000330",
    },
    {
        "school": "Crivitz Middle",
        "district": "Crivitz School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550297000331",
    },
    {
        "school": "Goodman High",
        "district": "Goodman-Armstrong Creek School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550558000592",
    },
    {
        "school": "Goodman-Armstrong Elementary",
        "district": "Goodman-Armstrong Creek School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550558000593",
    },
    {
        "school": "Marinette High",
        "district": "Marinette School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550870000995",
    },
    {
        "school": "Marinette Middle",
        "district": "Marinette School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550870000996",
    },
    {
        "school": "Merryman Elementary",
        "district": "Marinette School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550870000998",
    },
    {
        "school": "Park Elementary",
        "district": "Marinette School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550870000999",
    },
    {
        "school": "Garfield Elementary",
        "district": "Marinette School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550870002335",
    },
    {
        "school": "Niagara Elementary",
        "district": "Niagara School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551068001393",
    },
    {
        "school": "Niagara High",
        "district": "Niagara School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551068001394",
    },
    {
        "school": "Pembine Elementary",
        "district": "Beecher-Dunbar-Pembine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551155001529",
    },
    {
        "school": "Pembine High",
        "district": "Beecher-Dunbar-Pembine School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551155001530",
    },
    {
        "school": "Peshtigo Elementary",
        "district": "Peshtigo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551161001533",
    },
    {
        "school": "Peshtigo High",
        "district": "Peshtigo School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551161001534",
    },
    {
        "school": "Wausaukee Elementary",
        "district": "Wausaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551593002067",
    },
    {
        "school": "Wausaukee High",
        "district": "Wausaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551593002068",
    },
    {
        "school": "Wausaukee Middle",
        "district": "Wausaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551593002069",
    },
    {
        "school": "Tiffany Creek Elementary",
        "district": "Boyceville Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550159000201",
    },
    {
        "school": "Boyceville High",
        "district": "Boyceville Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550159000202",
    },
    {
        "school": "Boyceville Middle",
        "district": "Boyceville Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550159002460",
    },
    {
        "school": "Colfax Elementary",
        "district": "Colfax School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550279000315",
    },
    {
        "school": "Colfax High",
        "district": "Colfax School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550279000316",
    },
    {
        "school": "Elk Mound Middle",
        "district": "Elk Mound Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550423000452",
    },
    {
        "school": "Elk Mound High",
        "district": "Elk Mound Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550423000453",
    },
    {
        "school": "Mound View Elementary",
        "district": "Elk Mound Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550423000454",
    },
    {
        "school": "Knapp Elementary",
        "district": "Menomonie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550909000197",
    },
    {
        "school": "Oaklawn Elementary",
        "district": "Menomonie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550909000379",
    },
    {
        "school": "Wakanda Elementary",
        "district": "Menomonie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550909001072",
    },
    {
        "school": "Downsville Elementary",
        "district": "Menomonie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550909001074",
    },
    {
        "school": "Menomonie High",
        "district": "Menomonie Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550909001079",
    },
    {
        "school": "Menomonie Middle",
        "district": "Menomonie Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550909001080",
    },
    {
        "school": "River Heights Elementary",
        "district": "Menomonie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550909001082",
    },
    {
        "school": "Tomahawk Elementary",
        "district": "Tomahawk School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551494001946",
    },
    {
        "school": "Tomahawk High",
        "district": "Tomahawk School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551494001947",
    },
    {
        "school": "Tomahawk Middle",
        "district": "Tomahawk School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551494001948",
    },
    {
        "school": "Pine River School for Young Learners (PRSYL)",
        "district": "Merrill Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550921000746",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Merrill Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550921001094",
    },
    {
        "school": "Merrill High",
        "district": "Merrill Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550921001099",
    },
    {
        "school": "Washington Elementary",
        "district": "Merrill Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550921001103",
    },
    {
        "school": "Kate Goodrich Elementary",
        "district": "Merrill Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550921001490",
    },
    {
        "school": "Prairie River Middle",
        "district": "Merrill Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550921001506",
    },
    {
        "school": "Darrell Lynn Hines Academy",
        "district": "Darrell Lynn Hines Academy Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550004702536",
    },
    {
        "school": "Woodlands School",
        "district": "Woodlands School Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550011303353",
    },
    {
        "school": "Capitol West Academy",
        "district": "Capitol West Academy Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550011403355",
    },
    {
        "school": "Time 4 Learning Charter School",
        "district": "Greendale School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550591003347",
    },
    {
        "school": "Lad Lake Synergy School",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960002567",
    },
    {
        "school": "Grandview High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960002577",
    },
    {
        "school": "Rogers Street Academy",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002601",
    },
    {
        "school": "Carver Academy",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002602",
    },
    {
        "school": "Alliance School of Milwaukee",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002603",
    },
    {
        "school": "WHS Information Technology",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002608",
    },
    {
        "school": "Reagan College Preparatory High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960003342",
    },
    {
        "school": "ALBA - Academia de Lenguaje y Bellas Artes",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960003371",
    },
    {
        "school": "Deerfield Elementary",
        "district": "Oak Creek-Franklin Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551083002618",
    },
    {
        "school": "New Horizons for Learning",
        "district": "Shorewood School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551380002623",
    },
    {
        "school": "Addison Elementary",
        "district": "Slinger School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551395002540",
    },
    {
        "school": "Eagleville Charter School",
        "district": "Mukwonago School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551006003354",
    },
    {
        "school": "Waukesha Academy of Health Professions",
        "district": "Waukesha School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578003334",
    },
    {
        "school": "eAchieve Academy - Wisconsin",
        "district": "Waukesha School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578003380",
    },
    {
        "school": "Ixonia Elementary",
        "district": "Oconomowoc Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551089001419",
    },
    {
        "school": "Downtown Montessori",
        "district": "Downtown Montessori Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550003902153",
    },
    {
        "school": "Central City Cyberschool",
        "district": "Central City Cyberschool Agency",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550004102171",
    },
    {
        "school": "Milwaukee Academy of Science",
        "district": "Milwaukee Academy of Science Agency",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550004202234",
    },
    {
        "school": "Brown Deer Middle/High",
        "district": "Brown Deer School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550180000230",
    },
    {
        "school": "Brown Deer Elementary",
        "district": "Brown Deer School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550180000232",
    },
    {
        "school": "Cudahy High",
        "district": "Cudahy School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550306000336",
    },
    {
        "school": "Mitchell Elementary",
        "district": "Cudahy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550306000338",
    },
    {
        "school": "Jones Elementary",
        "district": "Cudahy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550306000339",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Cudahy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550306000340",
    },
    {
        "school": "Park View Elementary",
        "district": "Cudahy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550306000342",
    },
    {
        "school": "Kosciuszko Elementary",
        "district": "Cudahy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550306001228",
    },
    {
        "school": "Cudahy Middle",
        "district": "Cudahy School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550306002389",
    },
    {
        "school": "Indian Hill School",
        "district": "Maple Dale-Indian Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550477000515",
    },
    {
        "school": "Maple Dale School",
        "district": "Maple Dale-Indian Hill School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550477000516",
    },
    {
        "school": "Bayside Middle",
        "district": "Fox Point J2 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550480000517",
    },
    {
        "school": "Stormonth Elementary",
        "district": "Fox Point J2 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550480000518",
    },
    {
        "school": "Southwood Glen Elementary",
        "district": "Franklin Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550483000151",
    },
    {
        "school": "Ben Franklin Elementary",
        "district": "Franklin Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550483000519",
    },
    {
        "school": "Country Dale Elementary",
        "district": "Franklin Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550483000520",
    },
    {
        "school": "Forest Park Middle",
        "district": "Franklin Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550483000521",
    },
    {
        "school": "Franklin High",
        "district": "Franklin Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550483000522",
    },
    {
        "school": "Pleasant View Elementary",
        "district": "Franklin Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550483000523",
    },
    {
        "school": "Robinwood Elementary",
        "district": "Franklin Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550483000524",
    },
    {
        "school": "Glen Hills Middle",
        "district": "Glendale-River Hills School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550546000575",
    },
    {
        "school": "Parkway Elementary",
        "district": "Glendale-River Hills School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550546000577",
    },
    {
        "school": "Nicolet High",
        "district": "Nicolet UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550549000584",
    },
    {
        "school": "Canterbury Elementary",
        "district": "Greendale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550591002252",
    },
    {
        "school": "College Park Elementary",
        "district": "Greendale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550591002253",
    },
    {
        "school": "Greendale High",
        "district": "Greendale School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550591002254",
    },
    {
        "school": "Greendale Middle",
        "district": "Greendale School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550591002255",
    },
    {
        "school": "Highland View Elementary",
        "district": "Greendale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550591002256",
    },
    {
        "school": "Edgewood Elementary",
        "district": "Greenfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550594000650",
    },
    {
        "school": "Elm Dale Elementary",
        "district": "Greenfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550594000651",
    },
    {
        "school": "Glenwood Elementary",
        "district": "Greenfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550594000652",
    },
    {
        "school": "Greenfield High",
        "district": "Greenfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550594000653",
    },
    {
        "school": "Greenfield Middle",
        "district": "Greenfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550594000654",
    },
    {
        "school": "Maple Grove Elementary",
        "district": "Greenfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550594000655",
    },
    {
        "school": "Hales Corners Elementary",
        "district": "Whitnall School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550600000658",
    },
    {
        "school": "Whitnall High",
        "district": "Whitnall School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550600000661",
    },
    {
        "school": "Whitnall Middle",
        "district": "Whitnall School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550600000662",
    },
    {
        "school": "Edgerton Elementary",
        "district": "Whitnall School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550600002392",
    },
    {
        "school": "Hayes Bilingual School",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960000680",
    },
    {
        "school": "Wisconsin Conservatory of Lifelong Learning",
        "district": "Milwaukee School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960000681",
    },
    {
        "school": "ASSATA High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960000792",
    },
    {
        "school": "NOVA-Northwest Opportunities Vocational Academy",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960000843",
    },
    {
        "school": "Shalom High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960000856",
    },
    {
        "school": "Southeastern",
        "district": "Milwaukee School District",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960000936",
    },
    {
        "school": "Groppi High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960000963",
    },
    {
        "school": "Project STAY-Supporting Teachers and Youth",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960001007",
    },
    {
        "school": "Craig Montessori School",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001045",
    },
    {
        "school": "Alcott Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001121",
    },
    {
        "school": "Allen-Field Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001122",
    },
    {
        "school": "Audubon Technology and Communication Middle",
        "district": "Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001123",
    },
    {
        "school": "Auer Avenue Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001124",
    },
    {
        "school": "Barton Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001126",
    },
    {
        "school": "Bay View High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001127",
    },
    {
        "school": "Browning Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001132",
    },
    {
        "school": "Bruce Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001133",
    },
    {
        "school": "Bryant Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001134",
    },
    {
        "school": "Burbank Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001135",
    },
    {
        "school": "Burdick Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001136",
    },
    {
        "school": "Cass Street Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001139",
    },
    {
        "school": "Clarke Street Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001140",
    },
    {
        "school": "Clemens Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001141",
    },
    {
        "school": "Clement Avenue Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001142",
    },
    {
        "school": "Congress Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001143",
    },
    {
        "school": "Cooper Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001144",
    },
    {
        "school": "Curtin Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001146",
    },
    {
        "school": "Doerfler Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001148",
    },
    {
        "school": "Eighty-First Street Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001154",
    },
    {
        "school": "Milwaukee German Immersion",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001155",
    },
    {
        "school": "Starms Early Childhood",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001156",
    },
    {
        "school": "Emerson Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001157",
    },
    {
        "school": "Engleburg Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001158",
    },
    {
        "school": "Fairview Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001159",
    },
    {
        "school": "Fernwood Montessori",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001160",
    },
    {
        "school": "Milwaukee Spanish Immersion",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001161",
    },
    {
        "school": "Fifty-Third Street Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001162",
    },
    {
        "school": "Forest Home Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001163",
    },
    {
        "school": "Meir School",
        "district": "Milwaukee School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001164",
    },
    {
        "school": "Franklin Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001165",
    },
    {
        "school": "Fratney Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001166",
    },
    {
        "school": "Gaenslen Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001169",
    },
    {
        "school": "Barbee Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001170",
    },
    {
        "school": "Garland Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001172",
    },
    {
        "school": "Goodrich Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001173",
    },
    {
        "school": "River Trail Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001174",
    },
    {
        "school": "Grant Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001175",
    },
    {
        "school": "Grantosa Drive Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001176",
    },
    {
        "school": "King Jr Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001178",
    },
    {
        "school": "Greenfield Bilingual",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001179",
    },
    {
        "school": "Hamilton High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001180",
    },
    {
        "school": "Hampton Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001181",
    },
    {
        "school": "Hartford Avenue Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001183",
    },
    {
        "school": "Hawley Environmental School",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001184",
    },
    {
        "school": "Hawthorne Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001185",
    },
    {
        "school": "Hi-Mount Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001187",
    },
    {
        "school": "Holmes Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001188",
    },
    {
        "school": "Humboldt Park Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001190",
    },
    {
        "school": "Milwaukee Sign Language Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001191",
    },
    {
        "school": "Kagel Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001195",
    },
    {
        "school": "Keefe Avenue Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001196",
    },
    {
        "school": "Kilbourn Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001197",
    },
    {
        "school": "King International",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001199",
    },
    {
        "school": "Kluge Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001200",
    },
    {
        "school": "LaFollette Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001202",
    },
    {
        "school": "Lancaster Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001204",
    },
    {
        "school": "Lincoln Avenue Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001206",
    },
    {
        "school": "Hopkins Lloyd Community School",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001208",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001209",
    },
    {
        "school": "Lowell International Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001210",
    },
    {
        "school": "Manitoba Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001213",
    },
    {
        "school": "Maple Tree Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001214",
    },
    {
        "school": "Marshall High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001215",
    },
    {
        "school": "Maryland Montessori",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001216",
    },
    {
        "school": "Bradley Technology High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001218",
    },
    {
        "school": "Mitchell Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001219",
    },
    {
        "school": "Morgandale Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001220",
    },
    {
        "school": "Morse Mid",
        "district": "Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001221",
    },
    {
        "school": "Neeskara Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001224",
    },
    {
        "school": "Ninety-Fifth Street Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001225",
    },
    {
        "school": "Parkview Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001231",
    },
    {
        "school": "Riverwest Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001233",
    },
    {
        "school": "Pulaski High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001235",
    },
    {
        "school": "Riley Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001236",
    },
    {
        "school": "Riverside High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001237",
    },
    {
        "school": "Roosevelt Middle",
        "district": "Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001238",
    },
    {
        "school": "Academy of Accelerated Learning",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001239",
    },
    {
        "school": "Sherman Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001240",
    },
    {
        "school": "Pratt Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001243",
    },
    {
        "school": "Honey Creek Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001246",
    },
    {
        "school": "South Division High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001247",
    },
    {
        "school": "Story Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001249",
    },
    {
        "school": "Stuart Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001250",
    },
    {
        "school": "Thoreau Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001255",
    },
    {
        "school": "Bethune Academy",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001256",
    },
    {
        "school": "Townsend Street Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001258",
    },
    {
        "school": "Trowbridge Street School of Great Lakes Studies",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001259",
    },
    {
        "school": "Jackson Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001261",
    },
    {
        "school": "Victory Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001264",
    },
    {
        "school": "Vieau Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001265",
    },
    {
        "school": "Whitman Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001270",
    },
    {
        "school": "Whittier Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001271",
    },
    {
        "school": "Milwaukee School of Languages",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001273",
    },
    {
        "school": "Milwaukee County Youth Education Center",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960001306",
    },
    {
        "school": "La Causa Charter School",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001317",
    },
    {
        "school": "Next Door Charter",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001341",
    },
    {
        "school": "Westside Academy",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001512",
    },
    {
        "school": "Carson Academy",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001829",
    },
    {
        "school": "Highland Community School",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960001847",
    },
    {
        "school": "Vincent High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002272",
    },
    {
        "school": "Lincoln Middle",
        "district": "Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002302",
    },
    {
        "school": "Milwaukee High School of the Arts",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002339",
    },
    {
        "school": "Milwaukee French Immersion",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002340",
    },
    {
        "school": "Zablocki Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002342",
    },
    {
        "school": "Brown Street Academy",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002395",
    },
    {
        "school": "Milwaukee Parkside School",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002415",
    },
    {
        "school": "Elm Creative Arts Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002438",
    },
    {
        "school": "Thurston Woods Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002439",
    },
    {
        "school": "Starms Discovery",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002442",
    },
    {
        "school": "Metcalfe Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002464",
    },
    {
        "school": "IDEAL",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002493",
    },
    {
        "school": "Oak Creek West Middle",
        "district": "Oak Creek-Franklin Joint School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551083000419",
    },
    {
        "school": "Carollton Elementary",
        "district": "Oak Creek-Franklin Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551083001406",
    },
    {
        "school": "Cedar Hills Elementary",
        "district": "Oak Creek-Franklin Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551083001407",
    },
    {
        "school": "Edgewood Elementary",
        "district": "Oak Creek-Franklin Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551083001408",
    },
    {
        "school": "Meadowview Elementary",
        "district": "Oak Creek-Franklin Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551083001410",
    },
    {
        "school": "Oak Creek High",
        "district": "Oak Creek-Franklin Joint School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551083001411",
    },
    {
        "school": "Oak Creek East Middle",
        "district": "Oak Creek-Franklin Joint School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551083001412",
    },
    {
        "school": "Shepard Hills Elementary",
        "district": "Oak Creek-Franklin Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551083001413",
    },
    {
        "school": "Deer Creek Intermediate",
        "district": "Saint Francis School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551326001747",
    },
    {
        "school": "Saint Francis High",
        "district": "Saint Francis School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551326001748",
    },
    {
        "school": "Willow Glen Primary School",
        "district": "Saint Francis School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551326001750",
    },
    {
        "school": "Atwater Elementary",
        "district": "Shorewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551380001809",
    },
    {
        "school": "Lake Bluff Elementary",
        "district": "Shorewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551380001810",
    },
    {
        "school": "Shorewood High",
        "district": "Shorewood School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551380001811",
    },
    {
        "school": "Shorewood Intermediate",
        "district": "Shorewood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551380001812",
    },
    {
        "school": "Blakewood Elementary",
        "district": "South Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551404001826",
    },
    {
        "school": "Luther Elementary",
        "district": "South Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551404001827",
    },
    {
        "school": "Lakeview Elementary",
        "district": "South Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551404001828",
    },
    {
        "school": "Rawson Elementary",
        "district": "South Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551404001830",
    },
    {
        "school": "South Milwaukee Middle",
        "district": "South Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551404001831",
    },
    {
        "school": "South Milwaukee High",
        "district": "South Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551404001832",
    },
    {
        "school": "East High",
        "district": "Wauwatosa School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002077",
    },
    {
        "school": "Eisenhower Elementary",
        "district": "Wauwatosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002078",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Wauwatosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002081",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Wauwatosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002082",
    },
    {
        "school": "Longfellow Middle",
        "district": "Wauwatosa School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002083",
    },
    {
        "school": "Madison Elementary",
        "district": "Wauwatosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002085",
    },
    {
        "school": "McKinley Elementary",
        "district": "Wauwatosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002086",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Wauwatosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002087",
    },
    {
        "school": "Underwood Elementary",
        "district": "Wauwatosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002088",
    },
    {
        "school": "Washington Elementary",
        "district": "Wauwatosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002089",
    },
    {
        "school": "West High",
        "district": "Wauwatosa School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002091",
    },
    {
        "school": "Whitman Middle",
        "district": "Wauwatosa School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002092",
    },
    {
        "school": "Wilson Elementary",
        "district": "Wauwatosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002093",
    },
    {
        "school": "Vel R Phillips School",
        "district": "Wauwatosa School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551599002349",
    },
    {
        "school": "Central High",
        "district": "West Allis-West Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002101",
    },
    {
        "school": "Frank Lloyd Wright Intermediate",
        "district": "West Allis-West Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002102",
    },
    {
        "school": "Franklin Elementary",
        "district": "West Allis-West Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002103",
    },
    {
        "school": "Mitchell Elementary",
        "district": "West Allis-West Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002104",
    },
    {
        "school": "West Milwaukee Intermediate",
        "district": "West Allis-West Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002106",
    },
    {
        "school": "Irving Elementary",
        "district": "West Allis-West Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002107",
    },
    {
        "school": "Jefferson Elementary",
        "district": "West Allis-West Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002108",
    },
    {
        "school": "Longfellow Elementary",
        "district": "West Allis-West Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002114",
    },
    {
        "school": "Madison Elementary",
        "district": "West Allis-West Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002115",
    },
    {
        "school": "Nathan Hale High",
        "district": "West Allis-West Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002117",
    },
    {
        "school": "Pershing Elementary",
        "district": "West Allis-West Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002119",
    },
    {
        "school": "Walker Elementary",
        "district": "West Allis-West Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002121",
    },
    {
        "school": "Wilson Elementary",
        "district": "West Allis-West Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002124",
    },
    {
        "school": "Horace Mann Elementary",
        "district": "West Allis-West Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002377",
    },
    {
        "school": "James E Dottke Alternative School",
        "district": "West Allis-West Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551626002490",
    },
    {
        "school": "Cumberland Elementary",
        "district": "Whitefish Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551662002166",
    },
    {
        "school": "Richards Elementary",
        "district": "Whitefish Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551662002169",
    },
    {
        "school": "Whitefish Bay High",
        "district": "Whitefish Bay School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551662002170",
    },
    {
        "school": "Whitefish Bay Middle",
        "district": "Whitefish Bay School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551662002402",
    },
    {
        "school": "Cedarburg High",
        "district": "Cedarburg School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550246000270",
    },
    {
        "school": "Parkview Elementary",
        "district": "Cedarburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550246000271",
    },
    {
        "school": "Thorson Elementary",
        "district": "Cedarburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550246000272",
    },
    {
        "school": "Webster Middle",
        "district": "Cedarburg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550246000273",
    },
    {
        "school": "Westlawn Elementary",
        "district": "Cedarburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550246002403",
    },
    {
        "school": "Ozaukee Elementary",
        "district": "Northern Ozaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550489000529",
    },
    {
        "school": "Ozaukee High",
        "district": "Northern Ozaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550489000530",
    },
    {
        "school": "Ozaukee Middle",
        "district": "Northern Ozaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550489000531",
    },
    {
        "school": "Kennedy Elementary",
        "district": "Grafton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550561002247",
    },
    {
        "school": "Grafton High",
        "district": "Grafton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550561002248",
    },
    {
        "school": "John Long Middle",
        "district": "Grafton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550561002249",
    },
    {
        "school": "Woodview Elementary",
        "district": "Grafton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550561002250",
    },
    {
        "school": "Donges Bay Elementary",
        "district": "Mequon-Thiensville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550913001083",
    },
    {
        "school": "Homestead High",
        "district": "Mequon-Thiensville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550913001085",
    },
    {
        "school": "Lake Shore Middle",
        "district": "Mequon-Thiensville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550913001086",
    },
    {
        "school": "Oriole Lane Elementary",
        "district": "Mequon-Thiensville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550913001087",
    },
    {
        "school": "Steffen Middle",
        "district": "Mequon-Thiensville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550913001089",
    },
    {
        "school": "Wilson Elementary",
        "district": "Mequon-Thiensville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550913001090",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Port Washington-Saukville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551200001567",
    },
    {
        "school": "Port Washington High",
        "district": "Port Washington-Saukville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551200001568",
    },
    {
        "school": "Saukville Elementary",
        "district": "Port Washington-Saukville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551200001569",
    },
    {
        "school": "Thomas Jefferson Middle",
        "district": "Port Washington-Saukville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551200001570",
    },
    {
        "school": "Dunwiddie Elementary",
        "district": "Port Washington-Saukville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551200002320",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Muskego-Norway School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551017001332",
    },
    {
        "school": "Erin Elementary",
        "district": "Erin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550441000476",
    },
    {
        "school": "Amy Belle Elementary",
        "district": "Germantown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550516000549",
    },
    {
        "school": "County Line Elementary",
        "district": "Germantown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550516000550",
    },
    {
        "school": "Kennedy Middle",
        "district": "Germantown School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550516000554",
    },
    {
        "school": "MacArthur Elementary",
        "district": "Germantown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550516000555",
    },
    {
        "school": "Rockfield Elementary",
        "district": "Germantown School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550516000556",
    },
    {
        "school": "Germantown High",
        "district": "Germantown School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550516000557",
    },
    {
        "school": "Central Middle",
        "district": "Hartford J1 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550609000674",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Hartford J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550609000675",
    },
    {
        "school": "Rossman Elementary",
        "district": "Hartford J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550609000676",
    },
    {
        "school": "Hartford High",
        "district": "Hartford UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550612000677",
    },
    {
        "school": "Farmington Elementary",
        "district": "Kewaskum School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550738000835",
    },
    {
        "school": "Kewaskum Elementary",
        "district": "Kewaskum School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550738000836",
    },
    {
        "school": "Kewaskum High",
        "district": "Kewaskum School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550738000837",
    },
    {
        "school": "Kewaskum Middle",
        "district": "Kewaskum School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550738000838",
    },
    {
        "school": "i4Learning Community School",
        "district": "Kewaskum School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550738000839",
    },
    {
        "school": "Allenton Elementary",
        "district": "Slinger School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551395001818",
    },
    {
        "school": "Slinger Elementary",
        "district": "Slinger School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551395001819",
    },
    {
        "school": "Slinger Middle",
        "district": "Slinger School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551395001820",
    },
    {
        "school": "Slinger High",
        "district": "Slinger School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551395001821",
    },
    {
        "school": "Badger Middle",
        "district": "West Bend School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551629002125",
    },
    {
        "school": "Decorah Elementary",
        "district": "West Bend School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551629002127",
    },
    {
        "school": "East High",
        "district": "West Bend School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551629002128",
    },
    {
        "school": "Fair Park Elementary",
        "district": "West Bend School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551629002129",
    },
    {
        "school": "Green Tree Elementary",
        "district": "West Bend School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551629002130",
    },
    {
        "school": "Jackson Elementary",
        "district": "West Bend School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551629002131",
    },
    {
        "school": "McLane Elementary",
        "district": "West Bend School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551629002132",
    },
    {
        "school": "Silverbrook Intermediate",
        "district": "West Bend School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551629002134",
    },
    {
        "school": "West High",
        "district": "West Bend School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551629002135",
    },
    {
        "school": "Lake Country School",
        "district": "Lake Country School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550001300578",
    },
    {
        "school": "Central High",
        "district": "Elmbrook School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550177000214",
    },
    {
        "school": "East High",
        "district": "Elmbrook School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550177000215",
    },
    {
        "school": "Brookfield Elementary",
        "district": "Elmbrook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550177000216",
    },
    {
        "school": "Burleigh Elementary",
        "district": "Elmbrook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550177000218",
    },
    {
        "school": "Fairview South",
        "district": "Elmbrook School District",
        "level": "High",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "550177000221",
    },
    {
        "school": "Tonawanda Elementary",
        "district": "Elmbrook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550177000227",
    },
    {
        "school": "Wisconsin Hills Middle",
        "district": "Elmbrook School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550177000228",
    },
    {
        "school": "Swanson Elementary",
        "district": "Elmbrook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550177001217",
    },
    {
        "school": "Pilgrim Park Middle",
        "district": "Elmbrook School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550177002331",
    },
    {
        "school": "Dixon Elementary",
        "district": "Elmbrook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550177002367",
    },
    {
        "school": "Cushing Elementary",
        "district": "Kettle Moraine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550351000374",
    },
    {
        "school": "Dousman Elementary",
        "district": "Kettle Moraine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550351000375",
    },
    {
        "school": "Kettle Moraine High",
        "district": "Kettle Moraine School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550351000376",
    },
    {
        "school": "Kettle Moraine Middle",
        "district": "Kettle Moraine School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550351000377",
    },
    {
        "school": "Magee Elementary",
        "district": "Kettle Moraine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550351000378",
    },
    {
        "school": "Wales Elementary",
        "district": "Kettle Moraine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550351000380",
    },
    {
        "school": "Hamilton High",
        "district": "Hamilton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550603000664",
    },
    {
        "school": "Lannon Elementary",
        "district": "Hamilton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550603000665",
    },
    {
        "school": "Maple Avenue Elementary",
        "district": "Hamilton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550603000666",
    },
    {
        "school": "Marcy Elementary",
        "district": "Hamilton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550603000667",
    },
    {
        "school": "Templeton Middle",
        "district": "Hamilton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550603000669",
    },
    {
        "school": "Woodside Elementary",
        "district": "Hamilton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550603001676",
    },
    {
        "school": "Willow Springs Learning Center",
        "district": "Hamilton School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550603002432",
    },
    {
        "school": "North Shore Middle",
        "district": "Hartland-Lakeside J3 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550614001282",
    },
    {
        "school": "North Elementary",
        "district": "Hartland-Lakeside J3 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550614002257",
    },
    {
        "school": "South Elementary",
        "district": "Hartland-Lakeside J3 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550614002258",
    },
    {
        "school": "Arrowhead High",
        "district": "Arrowhead UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550618000678",
    },
    {
        "school": "Richmond Elementary",
        "district": "Richmond School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550813002262",
    },
    {
        "school": "Riverside Elementary",
        "district": "Menomonee Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550906000660",
    },
    {
        "school": "Valley View Elementary",
        "district": "Menomonee Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550906000663",
    },
    {
        "school": "Benjamin Franklin Elementary and Early Learning Center",
        "district": "Menomonee Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550906001061",
    },
    {
        "school": "Shady Lane Elementary",
        "district": "Menomonee Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550906001067",
    },
    {
        "school": "North Middle",
        "district": "Menomonee Falls School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550906001068",
    },
    {
        "school": "Menomonee Falls High",
        "district": "Menomonee Falls School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550906002338",
    },
    {
        "school": "Swallow Elementary",
        "district": "Swallow School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550924002267",
    },
    {
        "school": "North Lake Elementary",
        "district": "North Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550930002268",
    },
    {
        "school": "Merton Primary",
        "district": "Merton Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550936000750",
    },
    {
        "school": "Merton Intermediate",
        "district": "Merton Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550936002269",
    },
    {
        "school": "Stone Bank Elementary",
        "district": "Stone Bank School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550939002270",
    },
    {
        "school": "Big Bend Elementary",
        "district": "Mukwonago School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551006001315",
    },
    {
        "school": "Clarendon Avenue Elementary",
        "district": "Mukwonago School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551006001316",
    },
    {
        "school": "Mukwonago High",
        "district": "Mukwonago School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551006001319",
    },
    {
        "school": "Park View Middle",
        "district": "Mukwonago School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551006001320",
    },
    {
        "school": "Prairie View Elementary",
        "district": "Mukwonago School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551006001321",
    },
    {
        "school": "Rolling Hills Elementary",
        "district": "Mukwonago School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551006002251",
    },
    {
        "school": "Section Elementary",
        "district": "Mukwonago School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551006002307",
    },
    {
        "school": "Muskego Lakes Middle",
        "district": "Muskego-Norway School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551017001330",
    },
    {
        "school": "Mill Valley Elementary",
        "district": "Muskego-Norway School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551017001333",
    },
    {
        "school": "Muskego High",
        "district": "Muskego-Norway School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551017001335",
    },
    {
        "school": "Bay Lane Elementary",
        "district": "Muskego-Norway School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551017001336",
    },
    {
        "school": "Lake Denoon Middle",
        "district": "Muskego-Norway School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551017001850",
    },
    {
        "school": "Elmwood Elementary",
        "district": "New Berlin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551047000224",
    },
    {
        "school": "Poplar Creek Elementary",
        "district": "New Berlin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551047001365",
    },
    {
        "school": "Eisenhower Middle/High",
        "district": "New Berlin School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551047001366",
    },
    {
        "school": "New Berlin Middle/High",
        "district": "New Berlin School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551047001372",
    },
    {
        "school": "Orchard Lane Elementary",
        "district": "New Berlin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551047001373",
    },
    {
        "school": "Norris Academy",
        "district": "Norris School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551071001395",
    },
    {
        "school": "Greenland Elementary",
        "district": "Oconomowoc Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551089001418",
    },
    {
        "school": "Meadow View Elementary",
        "district": "Oconomowoc Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551089001420",
    },
    {
        "school": "Oconomowoc High",
        "district": "Oconomowoc Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551089001421",
    },
    {
        "school": "Silver Lake Intermediate",
        "district": "Oconomowoc Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551089001422",
    },
    {
        "school": "Park Lawn Elementary",
        "district": "Oconomowoc Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551089001424",
    },
    {
        "school": "Summit Elementary",
        "district": "Oconomowoc Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551089001425",
    },
    {
        "school": "Horizon School",
        "district": "Pewaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551164000226",
    },
    {
        "school": "Pewaukee Lake Elementary",
        "district": "Pewaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551164001536",
    },
    {
        "school": "Pewaukee High",
        "district": "Pewaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551164001537",
    },
    {
        "school": "Asa Clark Middle",
        "district": "Pewaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551164001538",
    },
    {
        "school": "Summit View Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578000261",
    },
    {
        "school": "West High",
        "district": "Waukesha School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578000528",
    },
    {
        "school": "Banting Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002004",
    },
    {
        "school": "Bethesda Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002006",
    },
    {
        "school": "Butler Middle",
        "district": "Waukesha School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002008",
    },
    {
        "school": "Les Paul Middle",
        "district": "Waukesha School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002009",
    },
    {
        "school": "Hadfield Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002011",
    },
    {
        "school": "Heyer Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002013",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002014",
    },
    {
        "school": "Horning Middle",
        "district": "Waukesha School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002015",
    },
    {
        "school": "Lowell Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002017",
    },
    {
        "school": "Meadowbrook Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002018",
    },
    {
        "school": "North High",
        "district": "Waukesha School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002019",
    },
    {
        "school": "Prairie Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002022",
    },
    {
        "school": "Waukesha STEM Academy",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002023",
    },
    {
        "school": "South High",
        "district": "Waukesha School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002025",
    },
    {
        "school": "White Rock School",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002027",
    },
    {
        "school": "Whittier Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002028",
    },
    {
        "school": "Rose Glen Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002290",
    },
    {
        "school": "Waukesha East Alternative School",
        "district": "Waukesha School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551578002502",
    },
    {
        "school": "Hoover Elementary",
        "district": "West Allis-West Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626002105",
    },
    {
        "school": "River Falls Public Montessori Academy",
        "district": "River Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551305002562",
    },
    {
        "school": "Ellsworth Middle",
        "district": "Ellsworth Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550432000463",
    },
    {
        "school": "Ellsworth High",
        "district": "Ellsworth Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550432000464",
    },
    {
        "school": "Ellsworth Elementary",
        "district": "Ellsworth Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550432000465",
    },
    {
        "school": "Elmwood Middle",
        "district": "Elmwood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550435000347",
    },
    {
        "school": "Elmwood Elementary",
        "district": "Elmwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550435000470",
    },
    {
        "school": "Elmwood High",
        "district": "Elmwood School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550435000471",
    },
    {
        "school": "Plum City Elementary",
        "district": "Plum City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551188001556",
    },
    {
        "school": "Plum City High",
        "district": "Plum City School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551188001557",
    },
    {
        "school": "Malone Elementary",
        "district": "Prescott School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551224001591",
    },
    {
        "school": "Prescott High",
        "district": "Prescott School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551224001592",
    },
    {
        "school": "Prescott Middle",
        "district": "Prescott School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551224001593",
    },
    {
        "school": "Greenwood Elementary",
        "district": "River Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551305001722",
    },
    {
        "school": "Meyer Middle",
        "district": "River Falls School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551305001723",
    },
    {
        "school": "River Falls High",
        "district": "River Falls School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551305001724",
    },
    {
        "school": "Westside Elementary",
        "district": "River Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551305001725",
    },
    {
        "school": "Renaissance Charter Academy",
        "district": "River Falls School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551305001910",
    },
    {
        "school": "Rocky Branch Elementary",
        "district": "River Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551305002448",
    },
    {
        "school": "Spring Valley Middle",
        "district": "Spring Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551434000511",
    },
    {
        "school": "Spring Valley Elementary",
        "district": "Spring Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551434001862",
    },
    {
        "school": "Spring Valley High",
        "district": "Spring Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551434001863",
    },
    {
        "school": "Baldwin-Woodville High",
        "district": "Baldwin-Woodville Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550072000094",
    },
    {
        "school": "Greenfield Elementary",
        "district": "Baldwin-Woodville Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550072000095",
    },
    {
        "school": "Viking Middle",
        "district": "Baldwin-Woodville Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550072000096",
    },
    {
        "school": "Glenwood City Elementary",
        "district": "Glenwood City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550552000586",
    },
    {
        "school": "Glenwood City High",
        "district": "Glenwood City School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550552000587",
    },
    {
        "school": "Glenwood City Middle",
        "district": "Glenwood City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550552000588",
    },
    {
        "school": "Saint Croix Central Elementary",
        "district": "Saint Croix Central School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550606000671",
    },
    {
        "school": "Saint Croix Central High",
        "district": "Saint Croix Central School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550606000672",
    },
    {
        "school": "Saint Croix Central Middle",
        "district": "Saint Croix Central School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550606000673",
    },
    {
        "school": "Houlton Elementary",
        "district": "Hudson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550669000725",
    },
    {
        "school": "Hudson Middle",
        "district": "Hudson School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550669000728",
    },
    {
        "school": "Hudson High",
        "district": "Hudson School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550669000729",
    },
    {
        "school": "North Hudson Elementary",
        "district": "Hudson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550669000730",
    },
    {
        "school": "Rock Elementary",
        "district": "Hudson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550669000731",
    },
    {
        "school": "Hudson Prairie Elementary",
        "district": "Hudson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550669001460",
    },
    {
        "school": "Willow River Elementary",
        "district": "Hudson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550669002332",
    },
    {
        "school": "New Richmond Paperjack Elementary",
        "district": "New Richmond School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551062000225",
    },
    {
        "school": "New Richmond Starr Elementary",
        "district": "New Richmond School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551062001389",
    },
    {
        "school": "New Richmond High",
        "district": "New Richmond School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551062001390",
    },
    {
        "school": "New Richmond Middle",
        "district": "New Richmond School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551062001391",
    },
    {
        "school": "Somerset Middle",
        "district": "Somerset School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551401001108",
    },
    {
        "school": "Somerset Elementary",
        "district": "Somerset School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551401001824",
    },
    {
        "school": "Somerset High",
        "district": "Somerset School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551401001825",
    },
    {
        "school": "Albany Elementary",
        "district": "Albany School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550012000013",
    },
    {
        "school": "Albany High",
        "district": "Albany School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550012000014",
    },
    {
        "school": "Albany Community Middle",
        "district": "Albany School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550012002357",
    },
    {
        "school": "Ronald R Albrecht Elementary",
        "district": "Brodhead School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550174000211",
    },
    {
        "school": "Brodhead High",
        "district": "Brodhead School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550174000212",
    },
    {
        "school": "Brodhead Middle",
        "district": "Brodhead School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550174000213",
    },
    {
        "school": "Juda Elementary",
        "district": "Juda School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550723000784",
    },
    {
        "school": "Juda High",
        "district": "Juda School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550723000785",
    },
    {
        "school": "Monroe High",
        "district": "Monroe School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550984001298",
    },
    {
        "school": "Monroe Middle",
        "district": "Monroe School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550984001299",
    },
    {
        "school": "Northside Elementary",
        "district": "Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550984001300",
    },
    {
        "school": "Parkside Elementary",
        "district": "Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550984002352",
    },
    {
        "school": "Monticello Middle",
        "district": "Monticello School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550990000384",
    },
    {
        "school": "Monticello Elementary",
        "district": "Monticello School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550990001304",
    },
    {
        "school": "Monticello High",
        "district": "Monticello School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550990001305",
    },
    {
        "school": "New Glarus Elementary",
        "district": "New Glarus School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551050001375",
    },
    {
        "school": "New Glarus High",
        "district": "New Glarus School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551050001376",
    },
    {
        "school": "ACE Alliance Charter Elementary",
        "district": "Neenah Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032003366",
    },
    {
        "school": "Oakwood Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119003340",
    },
    {
        "school": "Accelerated Advanced Learning Program",
        "district": "Oshkosh Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119003364",
    },
    {
        "school": "Banta School",
        "district": "Menasha Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550903000659",
    },
    {
        "school": "Maplewood Middle",
        "district": "Menasha Joint School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550903001053",
    },
    {
        "school": "Butte des Morts Elementary",
        "district": "Menasha Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550903001054",
    },
    {
        "school": "Clovis Grove Elementary",
        "district": "Menasha Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550903001055",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Menasha Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550903001056",
    },
    {
        "school": "Gegan Elementary",
        "district": "Menasha Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550903001057",
    },
    {
        "school": "Menasha High",
        "district": "Menasha Joint School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550903001059",
    },
    {
        "school": "Nicolet Elementary",
        "district": "Menasha Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550903002337",
    },
    {
        "school": "Horace Mann Middle",
        "district": "Neenah Joint School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032000579",
    },
    {
        "school": "Clayton Elementary",
        "district": "Neenah Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032001340",
    },
    {
        "school": "Coolidge Elementary",
        "district": "Neenah Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032001342",
    },
    {
        "school": "Hoover Elementary",
        "district": "Neenah Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032001344",
    },
    {
        "school": "Neenah High",
        "district": "Neenah Joint School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032001348",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Neenah Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032001350",
    },
    {
        "school": "Spring Road Elementary",
        "district": "Neenah Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032001351",
    },
    {
        "school": "Tullar Elementary",
        "district": "Neenah Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032001353",
    },
    {
        "school": "Washington School of Early Learning",
        "district": "Neenah Joint School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032001354",
    },
    {
        "school": "Wilson Elementary",
        "district": "Neenah Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032001355",
    },
    {
        "school": "Shattuck Middle",
        "district": "Neenah Joint School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032002308",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Neenah Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032002373",
    },
    {
        "school": "Patch Elementary",
        "district": "Omro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551098001440",
    },
    {
        "school": "Omro High",
        "district": "Omro School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551098001441",
    },
    {
        "school": "Omro Middle",
        "district": "Omro School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551098001443",
    },
    {
        "school": "Omro Elementary",
        "district": "Omro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551098002261",
    },
    {
        "school": "Traeger Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001359",
    },
    {
        "school": "Traeger Middle",
        "district": "Oshkosh Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001368",
    },
    {
        "school": "E Cook Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001483",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001487",
    },
    {
        "school": "Lakeside Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001488",
    },
    {
        "school": "Merrill Middle",
        "district": "Oshkosh Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001492",
    },
    {
        "school": "Oaklawn Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001493",
    },
    {
        "school": "North High",
        "district": "Oshkosh Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001495",
    },
    {
        "school": "West High",
        "district": "Oshkosh Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001496",
    },
    {
        "school": "Tipler Middle",
        "district": "Oshkosh Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001497",
    },
    {
        "school": "Read Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001498",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001499",
    },
    {
        "school": "South Park Middle",
        "district": "Oshkosh Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001501",
    },
    {
        "school": "Washington Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001503",
    },
    {
        "school": "Webster Stanley Middle",
        "district": "Oshkosh Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119001504",
    },
    {
        "school": "Webster Stanley Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119002309",
    },
    {
        "school": "Winneconne Elementary",
        "district": "Winneconne Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551683002190",
    },
    {
        "school": "Winneconne High",
        "district": "Winneconne Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551683002191",
    },
    {
        "school": "Winneconne Middle",
        "district": "Winneconne Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551683002192",
    },
    {
        "school": "River Ridge Elementary",
        "district": "River Ridge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550001700684",
    },
    {
        "school": "River Ridge Middle",
        "district": "River Ridge School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550001700685",
    },
    {
        "school": "River Ridge High",
        "district": "River Ridge School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550001700686",
    },
    {
        "school": "Boscobel Elementary",
        "district": "Boscobel Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550150000192",
    },
    {
        "school": "Boscobel High",
        "district": "Boscobel Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550150000193",
    },
    {
        "school": "Boscobel Junior High",
        "district": "Boscobel Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550150000194",
    },
    {
        "school": "Cassville Elementary",
        "district": "Cassville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550240000264",
    },
    {
        "school": "Cassville High",
        "district": "Cassville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550240000265",
    },
    {
        "school": "Cuba City Elementary",
        "district": "Cuba City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550303000332",
    },
    {
        "school": "Cuba City High",
        "district": "Cuba City School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550303000333",
    },
    {
        "school": "Fennimore Elementary",
        "district": "Fennimore Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550459000485",
    },
    {
        "school": "Fennimore High",
        "district": "Fennimore Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550459000486",
    },
    {
        "school": "Southwestern Wisconsin Elementary",
        "district": "Southwestern Wisconsin School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550630000695",
    },
    {
        "school": "Southwestern Wisconsin High",
        "district": "Southwestern Wisconsin School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550630000696",
    },
    {
        "school": "Lancaster Middle",
        "district": "Lancaster Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550777000890",
    },
    {
        "school": "Lancaster High",
        "district": "Lancaster Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550777000891",
    },
    {
        "school": "Winskill Elementary",
        "district": "Lancaster Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550777000892",
    },
    {
        "school": "Riverdale Elementary",
        "district": "Riverdale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551014001063",
    },
    {
        "school": "Riverdale Junior High",
        "district": "Riverdale School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551014001064",
    },
    {
        "school": "Riverdale High",
        "district": "Riverdale School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551014001328",
    },
    {
        "school": "Wilkins Elementary",
        "district": "Platteville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551185001551",
    },
    {
        "school": "Platteville High",
        "district": "Platteville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551185001553",
    },
    {
        "school": "Platteville Middle",
        "district": "Platteville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551185001554",
    },
    {
        "school": "Westview Elementary",
        "district": "Platteville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551185001555",
    },
    {
        "school": "Potosi Elementary",
        "district": "Potosi School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551209001575",
    },
    {
        "school": "Potosi High",
        "district": "Potosi School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551209001576",
    },
    {
        "school": "Potosi Middle",
        "district": "Potosi School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551209001603",
    },
    {
        "school": "21st Century Preparatory School",
        "district": "21st Century Preparatory School Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550004502575",
    },
    {
        "school": "Julian Thomas Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236003337",
    },
    {
        "school": "Burlington High",
        "district": "Burlington Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550189000237",
    },
    {
        "school": "Nettie E Karcher School",
        "district": "Burlington Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550189000238",
    },
    {
        "school": "Cooper Elementary",
        "district": "Burlington Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550189000239",
    },
    {
        "school": "Waller Elementary",
        "district": "Burlington Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550189000243",
    },
    {
        "school": "Winkler Elementary",
        "district": "Burlington Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550189000244",
    },
    {
        "school": "Lyons Center",
        "district": "Burlington Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550189000635",
    },
    {
        "school": "Dr Edward G Dyer School",
        "district": "Burlington Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550189002462",
    },
    {
        "school": "Kansasville Elementary",
        "district": "Dover #1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550375000394",
    },
    {
        "school": "Drought Elementary",
        "district": "Norway J7 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551080001405",
    },
    {
        "school": "O Brown Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001605",
    },
    {
        "school": "Gilmore Fine Arts School",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001608",
    },
    {
        "school": "Fratt Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001611",
    },
    {
        "school": "Giese Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001614",
    },
    {
        "school": "Horlick High",
        "district": "Racine Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001620",
    },
    {
        "school": "Case High",
        "district": "Racine Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001621",
    },
    {
        "school": "Janes Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001622",
    },
    {
        "school": "Jefferson Lighthouse Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001623",
    },
    {
        "school": "Jerstad-Agerholm School",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001624",
    },
    {
        "school": "Johnson Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001626",
    },
    {
        "school": "Jones Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001627",
    },
    {
        "school": "Knapp Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001628",
    },
    {
        "school": "Mitchell School",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001632",
    },
    {
        "school": "North Park Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001634",
    },
    {
        "school": "Park High",
        "district": "Racine Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001635",
    },
    {
        "school": "Red Apple Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001636",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001637",
    },
    {
        "school": "Schulte Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001638",
    },
    {
        "school": "Starbuck - An IB World School",
        "district": "Racine Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001639",
    },
    {
        "school": "Wadewitz Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001642",
    },
    {
        "school": "Walden III High",
        "district": "Racine Unified School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551236001644",
    },
    {
        "school": "West Ridge Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236001646",
    },
    {
        "school": "Gifford Elementary",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236002311",
    },
    {
        "school": "The REAL Sch",
        "district": "Racine Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236002471",
    },
    {
        "school": "Raymond Elementary",
        "district": "Raymond #14 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551248001656",
    },
    {
        "school": "North Cape Elementary",
        "district": "North Cape School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551251001657",
    },
    {
        "school": "Union Grove High",
        "district": "Union Grove UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551515001963",
    },
    {
        "school": "Union Grove Elementary",
        "district": "Union Grove J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551518001964",
    },
    {
        "school": "Waterford High",
        "district": "Waterford UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551560001988",
    },
    {
        "school": "Fox River Middle",
        "district": "Waterford Graded J1 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551566001989",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Waterford Graded J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551566002454",
    },
    {
        "school": "Trailside Elementary",
        "district": "Waterford Graded J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551566002509",
    },
    {
        "school": "Woodfield Elementary",
        "district": "Waterford Graded J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551566002510",
    },
    {
        "school": "Washington Elementary",
        "district": "Washington-Caldwell School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551570001993",
    },
    {
        "school": "Yorkville Elementary",
        "district": "Yorkville J2 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551722002230",
    },
    {
        "school": "Cleveland Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001781",
    },
    {
        "school": "Cedar Grove-Belgium Elementary",
        "district": "Cedar Grove-Belgium Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550243000266",
    },
    {
        "school": "Cedar Grove-Belgium High",
        "district": "Cedar Grove-Belgium Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550243000267",
    },
    {
        "school": "Cedar Grove-Belgium Middle",
        "district": "Cedar Grove-Belgium Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550243001629",
    },
    {
        "school": "Elkhart Lake Elementary/Middle",
        "district": "Elkhart Lake-Glenbeulah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550426000455",
    },
    {
        "school": "Elkhart Lake High",
        "district": "Elkhart Lake-Glenbeulah School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550426000456",
    },
    {
        "school": "Howards Grove Middle",
        "district": "Howards Grove School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550666000563",
    },
    {
        "school": "Howards Grove High",
        "district": "Howards Grove School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550666000721",
    },
    {
        "school": "Northview Elementary",
        "district": "Howards Grove School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550666000723",
    },
    {
        "school": "Kohler Elementary",
        "district": "Kohler School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550750000852",
    },
    {
        "school": "Kohler High",
        "district": "Kohler School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550750000853",
    },
    {
        "school": "Oostburg Middle",
        "district": "Oostburg School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551107001464",
    },
    {
        "school": "Oostburg Elementary",
        "district": "Oostburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551107001465",
    },
    {
        "school": "Oostburg High",
        "district": "Oostburg School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551107001466",
    },
    {
        "school": "Fairview Elementary",
        "district": "Plymouth Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551194001559",
    },
    {
        "school": "Parkview Elementary",
        "district": "Plymouth Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551194001560",
    },
    {
        "school": "Plymouth High",
        "district": "Plymouth Joint School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551194001562",
    },
    {
        "school": "Riverview Middle",
        "district": "Plymouth Joint School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551194001563",
    },
    {
        "school": "Horizon Elementary",
        "district": "Plymouth Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551194002445",
    },
    {
        "school": "Random Lake Elementary",
        "district": "Random Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551245001654",
    },
    {
        "school": "Random Lake High",
        "district": "Random Lake School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551245001655",
    },
    {
        "school": "Random Lake Middle",
        "district": "Random Lake School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551245002421",
    },
    {
        "school": "Cooper Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001782",
    },
    {
        "school": "Farnsworth Middle",
        "district": "Sheboygan Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001783",
    },
    {
        "school": "Grant Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001784",
    },
    {
        "school": "Horace Mann Middle",
        "district": "Sheboygan Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001785",
    },
    {
        "school": "Jackson Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001786",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001787",
    },
    {
        "school": "Lincoln-Erdman Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001789",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001790",
    },
    {
        "school": "James Madison Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001792",
    },
    {
        "school": "North High",
        "district": "Sheboygan Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001794",
    },
    {
        "school": "Pigeon River Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001795",
    },
    {
        "school": "Sheridan Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001796",
    },
    {
        "school": "South High",
        "district": "Sheboygan Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001797",
    },
    {
        "school": "Urban Middle",
        "district": "Sheboygan Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001798",
    },
    {
        "school": "Wilson Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365001800",
    },
    {
        "school": "Early Learning Center",
        "district": "Sheboygan Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365002423",
    },
    {
        "school": "Sheboygan Falls Elementary",
        "district": "Sheboygan Falls School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551368001801",
    },
    {
        "school": "Sheboygan Falls High",
        "district": "Sheboygan Falls School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551368001802",
    },
    {
        "school": "Sheboygan Falls Middle",
        "district": "Sheboygan Falls School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551368002289",
    },
    {
        "school": "Almond-Bancroft Elementary",
        "district": "Almond-Bancroft School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550024000023",
    },
    {
        "school": "Almond-Bancroft High",
        "district": "Almond-Bancroft School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550024000024",
    },
    {
        "school": "Amherst Elementary",
        "district": "Tomorrow River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550033000032",
    },
    {
        "school": "Amherst High",
        "district": "Tomorrow River School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550033000033",
    },
    {
        "school": "Amherst Middle",
        "district": "Tomorrow River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550033000034",
    },
    {
        "school": "Rosholt Elementary",
        "district": "Rosholt School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551314001732",
    },
    {
        "school": "Rosholt High",
        "district": "Rosholt School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551314001733",
    },
    {
        "school": "Rosholt Middle",
        "district": "Rosholt School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551314002449",
    },
    {
        "school": "Charles F Fernandez Center Alt Learning",
        "district": "Stevens Point Area Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551449001116",
    },
    {
        "school": "Juvenile Detention",
        "district": "Stevens Point Area Public School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551449001125",
    },
    {
        "school": "Preschool Options",
        "district": "Stevens Point Area Public School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "551449001145",
    },
    {
        "school": "Benjamin Franklin Junior High",
        "district": "Stevens Point Area Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449001868",
    },
    {
        "school": "Jefferson Elementary",
        "district": "Stevens Point Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449001872",
    },
    {
        "school": "Kennedy Elementary",
        "district": "Stevens Point Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449001873",
    },
    {
        "school": "Madison Elementary",
        "district": "Stevens Point Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449001874",
    },
    {
        "school": "McDill Elementary",
        "district": "Stevens Point Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449001875",
    },
    {
        "school": "P J Jacobs Junior High",
        "district": "Stevens Point Area Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449001877",
    },
    {
        "school": "Plover-Whiting Elementary",
        "district": "Stevens Point Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449001878",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Stevens Point Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449001879",
    },
    {
        "school": "Stevens Point Area Senior High",
        "district": "Stevens Point Area Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449001880",
    },
    {
        "school": "Washington Elementary",
        "district": "Stevens Point Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449001881",
    },
    {
        "school": "McKinley Center",
        "district": "Stevens Point Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449001914",
    },
    {
        "school": "CARE Concerned About Reaching Everyone",
        "district": "Stevens Point Area Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449002210",
    },
    {
        "school": "Bannach Elementary",
        "district": "Stevens Point Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449002452",
    },
    {
        "school": "Waterloo Intermediate",
        "district": "Waterloo School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551572002628",
    },
    {
        "school": "Douglas Elementary",
        "district": "Watertown Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551575001997",
    },
    {
        "school": "Lebanon Elementary",
        "district": "Watertown Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551575001998",
    },
    {
        "school": "Watertown High",
        "district": "Watertown Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551575002002",
    },
    {
        "school": "Barrie Elementary",
        "district": "Fort Atkinson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550474000509",
    },
    {
        "school": "Fort Atkinson High",
        "district": "Fort Atkinson School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550474000510",
    },
    {
        "school": "Fort Atkinson Middle",
        "district": "Fort Atkinson School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550474000512",
    },
    {
        "school": "Purdy Elementary",
        "district": "Fort Atkinson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550474000513",
    },
    {
        "school": "Rockwell Elementary",
        "district": "Fort Atkinson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550474000514",
    },
    {
        "school": "Luther Elementary",
        "district": "Fort Atkinson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550474002416",
    },
    {
        "school": "East Elementary",
        "district": "Jefferson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550705000777",
    },
    {
        "school": "Jefferson High",
        "district": "Jefferson School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550705000778",
    },
    {
        "school": "Jefferson Middle",
        "district": "Jefferson School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550705000779",
    },
    {
        "school": "West Elementary",
        "district": "Jefferson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550705000780",
    },
    {
        "school": "Sullivan Elementary",
        "district": "Jefferson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550705000781",
    },
    {
        "school": "Johnson Creek Elementary",
        "district": "Johnson Creek School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550717000782",
    },
    {
        "school": "Johnson Creek Middle and High",
        "district": "Johnson Creek School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550717000783",
    },
    {
        "school": "Lake Mills High",
        "district": "Lake Mills Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550771000887",
    },
    {
        "school": "Lake Mills Middle",
        "district": "Lake Mills Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550771000888",
    },
    {
        "school": "Lake Mills Elementary",
        "district": "Lake Mills Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550771000889",
    },
    {
        "school": "Waterloo Middle",
        "district": "Waterloo School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551572001943",
    },
    {
        "school": "Waterloo Elementary",
        "district": "Waterloo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551572001994",
    },
    {
        "school": "Waterloo High",
        "district": "Waterloo School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551572001995",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Watertown Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551575001999",
    },
    {
        "school": "Riverside Middle",
        "district": "Watertown Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551575002000",
    },
    {
        "school": "Schurz Elementary",
        "district": "Watertown Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551575002001",
    },
    {
        "school": "Webster Elementary",
        "district": "Watertown Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551575002003",
    },
    {
        "school": "Palmyra Elementary",
        "district": "Palmyra-Eagle Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551135001514",
    },
    {
        "school": "Palmyra-Eagle High",
        "district": "Palmyra-Eagle Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551135002274",
    },
    {
        "school": "Palmyra-Eagle Middle",
        "district": "Palmyra-Eagle Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551135002418",
    },
    {
        "school": "Eagle Elementary",
        "district": "Palmyra-Eagle Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551135001513",
    },
    {
        "school": "D C Everest Middle",
        "district": "D C Everest Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317002534",
    },
    {
        "school": "Wausau Area Montessori Charter School",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002629",
    },
    {
        "school": "Athens Elementary",
        "district": "Athens School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550057000086",
    },
    {
        "school": "Athens High",
        "district": "Athens School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550057000087",
    },
    {
        "school": "Athens Middle",
        "district": "Athens School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550057000088",
    },
    {
        "school": "Edgar Elementary",
        "district": "Edgar School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550408000440",
    },
    {
        "school": "Edgar High",
        "district": "Edgar School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550408000441",
    },
    {
        "school": "Edgar Middle",
        "district": "Edgar School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550408002391",
    },
    {
        "school": "Marathon Elementary",
        "district": "Marathon City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550867000991",
    },
    {
        "school": "Marathon High",
        "district": "Marathon City School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550867000992",
    },
    {
        "school": "Mosinee Elementary",
        "district": "Mosinee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550996001307",
    },
    {
        "school": "Mosinee High",
        "district": "Mosinee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550996001308",
    },
    {
        "school": "Mosinee Middle",
        "district": "Mosinee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550996001309",
    },
    {
        "school": "D C Everest High",
        "district": "D C Everest Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317001734",
    },
    {
        "school": "D C Everest Junior High",
        "district": "D C Everest Area School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317001735",
    },
    {
        "school": "Evergreen Elementary",
        "district": "D C Everest Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317001737",
    },
    {
        "school": "Hatley Elementary",
        "district": "D C Everest Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317001738",
    },
    {
        "school": "Rothschild Elementary",
        "district": "D C Everest Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317001739",
    },
    {
        "school": "Weston Elementary",
        "district": "D C Everest Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317001741",
    },
    {
        "school": "Riverside Elementary",
        "district": "D C Everest Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317002288",
    },
    {
        "school": "Spencer Elementary",
        "district": "Spencer School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551419001844",
    },
    {
        "school": "Spencer Junior High/High",
        "district": "Spencer School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551419001845",
    },
    {
        "school": "Stratford Elementary",
        "district": "Stratford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551458000582",
    },
    {
        "school": "Stratford High",
        "district": "Stratford School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551458001891",
    },
    {
        "school": "Horace Mann Middle",
        "district": "Wausau School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590000544",
    },
    {
        "school": "South Mountain Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590001409",
    },
    {
        "school": "Franklin Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002048",
    },
    {
        "school": "G D Jones Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002049",
    },
    {
        "school": "Grant Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002050",
    },
    {
        "school": "Hewitt-Texas Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002051",
    },
    {
        "school": "John Marshall Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002053",
    },
    {
        "school": "John Muir Middle",
        "district": "Wausau School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002054",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002056",
    },
    {
        "school": "Maine Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002058",
    },
    {
        "school": "Rib Mountain Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002059",
    },
    {
        "school": "Riverview Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002060",
    },
    {
        "school": "Stettin Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002061",
    },
    {
        "school": "Thomas Jefferson Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002062",
    },
    {
        "school": "East High",
        "district": "Wausau School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002063",
    },
    {
        "school": "West High",
        "district": "Wausau School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002064",
    },
    {
        "school": "Hawthorn Hills Elementary",
        "district": "Wausau School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590002365",
    },
    {
        "school": "Jackson Elementary",
        "district": "Elkhorn Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550429002529",
    },
    {
        "school": "Lakeland School",
        "district": "Walworth Co CDEB",
        "level": "Other",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "550002101615",
    },
    {
        "school": "Turtle Creek Elementary",
        "district": "Delavan-Darien School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550364000317",
    },
    {
        "school": "Delavan-Darien High",
        "district": "Delavan-Darien School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550364000386",
    },
    {
        "school": "Darien Elementary",
        "district": "Delavan-Darien School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550364002239",
    },
    {
        "school": "Phoenix Middle",
        "district": "Delavan-Darien School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550364002241",
    },
    {
        "school": "Little Prairie Primary",
        "district": "East Troy Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550402000409",
    },
    {
        "school": "East Troy High",
        "district": "East Troy Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550402000410",
    },
    {
        "school": "East Troy Middle",
        "district": "East Troy Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550402000411",
    },
    {
        "school": "Prairie View Elementary",
        "district": "East Troy Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550402001640",
    },
    {
        "school": "Elkhorn Area High",
        "district": "Elkhorn Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550429000459",
    },
    {
        "school": "Elkhorn Area Middle",
        "district": "Elkhorn Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550429000460",
    },
    {
        "school": "Tibbets Elementary",
        "district": "Elkhorn Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550429000461",
    },
    {
        "school": "West Side Elementary",
        "district": "Elkhorn Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550429000462",
    },
    {
        "school": "Walworth Co Educ Alt High",
        "district": "Elkhorn Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550429002520",
    },
    {
        "school": "Fontana Elementary",
        "district": "Fontana J8 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550472000508",
    },
    {
        "school": "Woods Elementary",
        "district": "Geneva J4 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550510000546",
    },
    {
        "school": "Brookwood Elementary",
        "district": "Genoa City J2 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550513000547",
    },
    {
        "school": "Brookwood Middle",
        "district": "Genoa City J2 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550513002327",
    },
    {
        "school": "Central - Denison Elementary",
        "district": "Lake Geneva J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550762000879",
    },
    {
        "school": "Lake Geneva Middle",
        "district": "Lake Geneva J1 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550762000881",
    },
    {
        "school": "Eastview Elementary",
        "district": "Lake Geneva J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550762000882",
    },
    {
        "school": "Star Center Elementary",
        "district": "Lake Geneva J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550762000883",
    },
    {
        "school": "Badger High",
        "district": "Lake Geneva-Genoa City UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550765000884",
    },
    {
        "school": "Traver Elementary",
        "district": "Linn J4 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550804000898",
    },
    {
        "school": "Reek Elementary",
        "district": "Linn J6 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550807000899",
    },
    {
        "school": "Sharon Community",
        "district": "Sharon J11 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551356001774",
    },
    {
        "school": "Walworth Elementary",
        "district": "Walworth J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551545001981",
    },
    {
        "school": "Big Foot High",
        "district": "Big Foot UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551548001982",
    },
    {
        "school": "Whitewater Middle",
        "district": "Whitewater Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551668002178",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Whitewater Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551668002179",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Whitewater Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551668002180",
    },
    {
        "school": "Washington Elementary",
        "district": "Whitewater Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551668002181",
    },
    {
        "school": "Whitewater High",
        "district": "Whitewater Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551668002182",
    },
    {
        "school": "Williams Bay Middle",
        "district": "Williams Bay School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551674000277",
    },
    {
        "school": "Williams Bay Elementary",
        "district": "Williams Bay School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551674002186",
    },
    {
        "school": "Williams Bay High",
        "district": "Williams Bay School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551674002187",
    },
    {
        "school": "Nekoosa Academy",
        "district": "Nekoosa School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551038002617",
    },
    {
        "school": "WRPS Four-year-old Kindergarten and PK Early Childhood",
        "district": "Wisconsin Rapids School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551707003357",
    },
    {
        "school": "River Cities High",
        "district": "Wisconsin Rapids School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551707003365",
    },
    {
        "school": "Grant Elementary",
        "district": "Wisconsin Rapids School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551707002205",
    },
    {
        "school": "Auburndale Elementary",
        "district": "Auburndale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550060000090",
    },
    {
        "school": "Auburndale High",
        "district": "Auburndale School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550060000091",
    },
    {
        "school": "Grant Elementary",
        "district": "Marshfield Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550882001016",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Marshfield Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550882001018",
    },
    {
        "school": "Madison Elementary",
        "district": "Marshfield Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550882001019",
    },
    {
        "school": "Marshfield Middle",
        "district": "Marshfield Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550882001020",
    },
    {
        "school": "Marshfield High",
        "district": "Marshfield Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550882001021",
    },
    {
        "school": "Nasonville Elementary",
        "district": "Marshfield Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550882001022",
    },
    {
        "school": "Washington Elementary",
        "district": "Marshfield Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550882001023",
    },
    {
        "school": "Alexander Middle",
        "district": "Nekoosa School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551038001358",
    },
    {
        "school": "Nekoosa High",
        "district": "Nekoosa School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551038001360",
    },
    {
        "school": "Humke Elementary",
        "district": "Nekoosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551038002344",
    },
    {
        "school": "Pittsville Elementary",
        "district": "Pittsville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551179001546",
    },
    {
        "school": "Pittsville High",
        "district": "Pittsville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551179001547",
    },
    {
        "school": "John Edwards Middle",
        "district": "Port Edwards School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551197000580",
    },
    {
        "school": "John Edwards High",
        "district": "Port Edwards School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551197001564",
    },
    {
        "school": "Port Edwards Elementary",
        "district": "Port Edwards School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551197001565",
    },
    {
        "school": "Grove Elementary",
        "district": "Wisconsin Rapids School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551707002206",
    },
    {
        "school": "Howe Elementary",
        "district": "Wisconsin Rapids School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551707002207",
    },
    {
        "school": "Lincoln High",
        "district": "Wisconsin Rapids School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551707002209",
    },
    {
        "school": "THINK Academy-Together Helping INspire Kids",
        "district": "Wisconsin Rapids School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551707002212",
    },
    {
        "school": "Washington Elementary",
        "district": "Wisconsin Rapids School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551707002215",
    },
    {
        "school": "Wisconsin Rapids Area Middle",
        "district": "Wisconsin Rapids School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551707002216",
    },
    {
        "school": "Woodside Elementary",
        "district": "Wisconsin Rapids School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551707002217",
    },
    {
        "school": "MOOREFIELD INTERMEDIATE SCHOOL",
        "district": "HARDY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540048001253",
    },
    {
        "school": "CEDAR GROVE MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060001252",
    },
    {
        "school": "DUVAL PK-8",
        "district": "LINCOLN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540066001236",
    },
    {
        "school": "HAMLIN PK-8",
        "district": "LINCOLN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540066001237",
    },
    {
        "school": "GUYAN VALLEY MIDDLE",
        "district": "LINCOLN COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540066001242",
    },
    {
        "school": "LINCOLN COUNTY HIGH SCHOOL",
        "district": "LINCOLN COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540066001245",
    },
    {
        "school": "MAN ELEMENTARY SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069001251",
    },
    {
        "school": "MAN MIDDLE SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069001060",
    },
    {
        "school": "LENORE PRE K-8 SCHOOL",
        "district": "MINGO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540090001063",
    },
    {
        "school": "WESTSIDE HIGH SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001085",
    },
    {
        "school": "BELINGTON ELEMENTARY",
        "district": "Barbour County Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540003000001",
    },
    {
        "school": "BELINGTON MIDDLE SCHOOL",
        "district": "Barbour County Board of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540003000002",
    },
    {
        "school": "JUNIOR ELEMENTARY",
        "district": "Barbour County Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540003000004",
    },
    {
        "school": "KASSON ELEMENTARY/MIDDLE SCHOOL",
        "district": "Barbour County Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540003000005",
    },
    {
        "school": "PHILIP BARBOUR HIGH SCHOOL COMPLEX",
        "district": "Barbour County Board of Education",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540003000008",
    },
    {
        "school": "PHILIPPI ELEMENTARY SCHOOL",
        "district": "Barbour County Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540003000009",
    },
    {
        "school": "PHILIPPI MIDDLE SCHOOL",
        "district": "Barbour County Board of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540003000010",
    },
    {
        "school": "BRAXTON COUNTY MIDDLE SCHOOL",
        "district": "BRAXTON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540012000006",
    },
    {
        "school": "BRAXTON COUNTY HIGH SCHOOL",
        "district": "BRAXTON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540012000061",
    },
    {
        "school": "DAVIS ELEMENTARY SCHOOL",
        "district": "BRAXTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540012000064",
    },
    {
        "school": "FLATWOODS ELEMENTARY SCHOOL",
        "district": "BRAXTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540012000065",
    },
    {
        "school": "FRAMETOWN ELEMENTARY SCHOOL",
        "district": "BRAXTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540012000066",
    },
    {
        "school": "LITTLE BIRCH ELEMENTARY SCHOOL",
        "district": "BRAXTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540012000068",
    },
    {
        "school": "SUTTON ELEMENTARY SCHOOL",
        "district": "BRAXTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540012000069",
    },
    {
        "school": "BURNSVILLE ELEMENTARY SCHOOL",
        "district": "BRAXTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540012001328",
    },
    {
        "school": "ARNOLDSBURG SCHOOL",
        "district": "CALHOUN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540021000139",
    },
    {
        "school": "CALHOUN MIDDLE/HIGH SCHOOL",
        "district": "CALHOUN COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540021000142",
    },
    {
        "school": "PLEASANT HILL SCHOOL",
        "district": "CALHOUN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540021000144",
    },
    {
        "school": "CALHOUN-GILMER CAREER CENTER",
        "district": "CALHOUN COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540021001379",
    },
    {
        "school": "GILMER COUNTY HIGH SCHOOL",
        "district": "GILMER COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540033000210",
    },
    {
        "school": "MAYSVILLE ELEMENTARY SCHOOL",
        "district": "GRANT COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540036000218",
    },
    {
        "school": "PETERSBURG ELEMENTARY SCHOOL",
        "district": "GRANT COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540036000219",
    },
    {
        "school": "PETERSBURG HIGH SCHOOL",
        "district": "GRANT COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540036000220",
    },
    {
        "school": "UNION EDUCATIONAL COMPLEX",
        "district": "GRANT COUNTY SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540036000687",
    },
    {
        "school": "SOUTH BRANCH VOCATIONAL SCHOOL",
        "district": "GRANT COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540036001383",
    },
    {
        "school": "EASTERN GREENBRIER MIDDLE SCHOOL",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039000050",
    },
    {
        "school": "ALDERSON ELEMENTARY",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039000224",
    },
    {
        "school": "CRICHTON ELEMENTARY",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039000227",
    },
    {
        "school": "FRANKFORD ELEMENTARY",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039000229",
    },
    {
        "school": "GREENBRIER EAST HIGH SCHOOL",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039000230",
    },
    {
        "school": "GREENBRIER WEST HIGH SCHOOL",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039000232",
    },
    {
        "school": "LEWISBURG ELEMENTARY",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039000233",
    },
    {
        "school": "RAINELLE ELEMENTARY",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039000237",
    },
    {
        "school": "RONCEVERTE ELEMENTARY",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039000239",
    },
    {
        "school": "RUPERT ELEMENTARY",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039000240",
    },
    {
        "school": "WHITE SULPHUR ELEMENTARY",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039000242",
    },
    {
        "school": "WESTERN GREENBRIER MIDDLE SCHOOL",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039001038",
    },
    {
        "school": "SMOOT ELEMENTARY",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540039001334",
    },
    {
        "school": "EAST HARDY EARLY/MIDDLE SCHOOL",
        "district": "HARDY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540048000056",
    },
    {
        "school": "MOOREFIELD ELEMENTARY SCHOOL",
        "district": "HARDY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540048000277",
    },
    {
        "school": "MOOREFIELD HIGH SCHOOL",
        "district": "HARDY COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540048000278",
    },
    {
        "school": "MOOREFIELD MIDDLE SCHOOL",
        "district": "HARDY COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540048000886",
    },
    {
        "school": "EAST HARDY HIGH SCHOOL",
        "district": "HARDY COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540048001279",
    },
    {
        "school": "COTTAGEVILLE ELEMENTARY SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054000326",
    },
    {
        "school": "EVANS ELEMENTARY SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054000328",
    },
    {
        "school": "FAIRPLAIN ELEMENTARY SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054000329",
    },
    {
        "school": "GILMORE ELEMENTARY SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054000331",
    },
    {
        "school": "KENNA ELEMENTARY SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054000333",
    },
    {
        "school": "HENRY J KAISER ELEMENTARY SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054000334",
    },
    {
        "school": "RAVENSWOOD GRADE SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054000335",
    },
    {
        "school": "RAVENSWOOD HIGH SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054000336",
    },
    {
        "school": "RIPLEY ELEMENTARY SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054000337",
    },
    {
        "school": "RIPLEY HIGH SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054000338",
    },
    {
        "school": "RIPLEY MIDDLE SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054001239",
    },
    {
        "school": "RAVENSWOOD MIDDLE SCHOOL",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540054001240",
    },
    {
        "school": "ROANE-JACKSON VO-TECH CENTER",
        "district": "JACKSON COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540054001391",
    },
    {
        "school": "LEWIS COUNTY HIGH SCHOOL",
        "district": "LEWIS COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540063000472",
    },
    {
        "school": "ROANOKE ELEMENTARY SCHOOL",
        "district": "LEWIS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540063000475",
    },
    {
        "school": "PETERSON-CENTRAL ELEMENTARY SCHOOL",
        "district": "LEWIS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540063000478",
    },
    {
        "school": "JANE LEW ELEMENTARY SCHOOL",
        "district": "LEWIS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540063000699",
    },
    {
        "school": "ROBERT L. BLAND MIDDLE SCHOOL",
        "district": "LEWIS COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540063001459",
    },
    {
        "school": "BUFFALO ELEMENTARY SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000506",
    },
    {
        "school": "CHAPMANVILLE REGIONAL HIGH SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000508",
    },
    {
        "school": "HOLDEN CENTRAL ELEMENTARY SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000515",
    },
    {
        "school": "HUGH DINGESS ELEMENTARY SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000516",
    },
    {
        "school": "JUSTICE ELEMENTARY SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000517",
    },
    {
        "school": "LOGAN MIDDLE SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000519",
    },
    {
        "school": "LOGAN ELEMENTARY SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000520",
    },
    {
        "school": "LOGAN SENIOR HIGH SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000521",
    },
    {
        "school": "MAN SENIOR HIGH SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000524",
    },
    {
        "school": "SOUTH MAN ELEMENTARY SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000532",
    },
    {
        "school": "VERDUNVILLE ELEMENTARY SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000536",
    },
    {
        "school": "OMAR ELEMENTARY",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000611",
    },
    {
        "school": "CHAPMANVILLE MIDDLE SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069000729",
    },
    {
        "school": "RALPH R WILLIS CAREER/TECHNICAL CENTER",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540069001395",
    },
    {
        "school": "ANAWALT ELEMENTARY SCHOOL",
        "district": "MCDOWELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540081000633",
    },
    {
        "school": "KIMBALL ELEMENTARY SCHOOL",
        "district": "MCDOWELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540081000654",
    },
    {
        "school": "CAREER AND TECHNOLOGY CENTER",
        "district": "MCDOWELL COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540081000657",
    },
    {
        "school": "WELCH ELEMENTARY SCHOOL",
        "district": "MCDOWELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540081000669",
    },
    {
        "school": "SANDY RIVER MIDDLE SCHOOL",
        "district": "MCDOWELL COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540081001046",
    },
    {
        "school": "MOUNT VIEW HIGH SCHOOL",
        "district": "MCDOWELL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540081001246",
    },
    {
        "school": "IAEGER ELEMENTARY SCHOOL",
        "district": "MCDOWELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540081001247",
    },
    {
        "school": "FALL RIVER ELEMENTARY SCHOOL",
        "district": "MCDOWELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540081001248",
    },
    {
        "school": "BRADSHAW ELEMENTARY SCHOOL",
        "district": "MCDOWELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540081001398",
    },
    {
        "school": "DINGESS ELEMENTARY SCHOOL",
        "district": "MINGO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540090000736",
    },
    {
        "school": "KERMIT PRE K-8",
        "district": "MINGO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540090000906",
    },
    {
        "school": "WILLIAMSON PRE K-8",
        "district": "MINGO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540090001254",
    },
    {
        "school": "MATEWAN PRE K-8",
        "district": "MINGO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540090001404",
    },
    {
        "school": "TUG VALLEY HIGH SCHOOL",
        "district": "MINGO COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540090001407",
    },
    {
        "school": "PETERSTOWN MIDDLE SCHOOL",
        "district": "MONROE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540096000765",
    },
    {
        "school": "JAMES MONROE HIGH SCHOOL",
        "district": "MONROE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540096000768",
    },
    {
        "school": "PETERSTOWN ELEMENTARY SCHOOL",
        "district": "MONROE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540096000814",
    },
    {
        "school": "MOUNTAIN VIEW ELEMENTARY & MIDDLE SCHOOL",
        "district": "MONROE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540096001044",
    },
    {
        "school": "MONROE COUNTY VOCATIONAL CENTER",
        "district": "MONROE COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540096001409",
    },
    {
        "school": "BIRCH RIVER ELEMENTARY SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102000828",
    },
    {
        "school": "GLADE CREEK ELEMENTARY SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102000834",
    },
    {
        "school": "PANTHER CREEK ELEMENTARY SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102000837",
    },
    {
        "school": "MT LOOKOUT ELEMENTARY SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102000838",
    },
    {
        "school": "MT NEBO ELEMENTARY SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102000839",
    },
    {
        "school": "NICHOLAS COUNTY HIGH SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102000843",
    },
    {
        "school": "RICHWOOD MIDDLE SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102000846",
    },
    {
        "school": "RICHWOOD HIGH SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102000847",
    },
    {
        "school": "SUMMERSVILLE ELEMENTARY SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102000849",
    },
    {
        "school": "ZELA ELEMENTARY SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102000852",
    },
    {
        "school": "SUMMERSVILLE MIDDLE SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102001262",
    },
    {
        "school": "CHERRY RIVER ELEMENTARY SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102001263",
    },
    {
        "school": "NICHOLAS COUNTY CAREER/TECHNICAL CENTER",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540102001410",
    },
    {
        "school": "BRANDYWINE ELEMENTARY SCHOOL",
        "district": "PENDLETON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540108000878",
    },
    {
        "school": "FRANKLIN ELEMENTARY SCHOOL",
        "district": "PENDLETON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540108000881",
    },
    {
        "school": "PENDLETON COUNTY MIDDLE/HIGH SCHOOL",
        "district": "PENDLETON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540108000882",
    },
    {
        "school": "NORTH FORK ELEMENTARY SCHOOL",
        "district": "PENDLETON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540108001007",
    },
    {
        "school": "HILLSBORO ELEMENTARY SCHOOL",
        "district": "POCAHONTAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540114000892",
    },
    {
        "school": "MARLINTON ELEMENTARY SCHOOL",
        "district": "POCAHONTAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540114000894",
    },
    {
        "school": "MARLINTON MIDDLE SCHOOL",
        "district": "POCAHONTAS COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540114000895",
    },
    {
        "school": "POCAHONTAS COUNTY HIGH SCHOOL",
        "district": "POCAHONTAS COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540114000896",
    },
    {
        "school": "GREEN BANK ELEMENTARY-MIDDLE SCHOOL",
        "district": "POCAHONTAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540114001448",
    },
    {
        "school": "ELKINS HIGH SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126000662",
    },
    {
        "school": "BEVERLY ELEMENTARY SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126000992",
    },
    {
        "school": "COALTON ELEMENTARY SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126000993",
    },
    {
        "school": "ELKINS MIDDLE SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126000996",
    },
    {
        "school": "GEORGE WARD ELEMENTARY SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126000998",
    },
    {
        "school": "HARMAN ELEMENTARY/HIGH SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126000999",
    },
    {
        "school": "MIDLAND ELEMENTARY SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126001002",
    },
    {
        "school": "NORTH ELEMENTARY SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126001004",
    },
    {
        "school": "ELKINS THIRD WARD ELEMENTARY SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126001010",
    },
    {
        "school": "TYGARTS VALLEY MIDDLE/HIGH SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126001011",
    },
    {
        "school": "RANDOLPH COUNTY ALTERNATIVE CENTER",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540126001017",
    },
    {
        "school": "PICKENS ELEMENTARY/HIGH SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126001363",
    },
    {
        "school": "JENNINGS RANDOLPH ELEMENTARY SCHOOL",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540126001371",
    },
    {
        "school": "RANDOLPH TECHNICAL CENTER",
        "district": "RANDOLPH COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540126001416",
    },
    {
        "school": "RITCHIE COUNTY MIDDLE",
        "district": "RITCHIE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540129000663",
    },
    {
        "school": "CREED COLLINS ELEMENTARY",
        "district": "RITCHIE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540129001018",
    },
    {
        "school": "HARRISVILLE ELEMENTARY",
        "district": "RITCHIE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540129001020",
    },
    {
        "school": "RITCHIE COUNTY HIGH SCHOOL",
        "district": "RITCHIE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540129001021",
    },
    {
        "school": "SMITHVILLE ELEMENTARY",
        "district": "RITCHIE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540129001024",
    },
    {
        "school": "ROANE COUNTY HIGH",
        "district": "ROANE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540132000666",
    },
    {
        "school": "SPENCER ELEMENTARY SCHOOL",
        "district": "ROANE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540132001031",
    },
    {
        "school": "WALTON ELEMENTARY/MIDDLE SCHOOL",
        "district": "ROANE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540132001033",
    },
    {
        "school": "SPENCER MIDDLE SCHOOL",
        "district": "ROANE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540132001270",
    },
    {
        "school": "GEARY ELEMENTARY/MIDDLE SCHOOL",
        "district": "ROANE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540132001305",
    },
    {
        "school": "SUMMERS MIDDLE SCHOOL",
        "district": "SUMMERS COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540135000785",
    },
    {
        "school": "SUMMERS COUNTY HIGH SCHOOL",
        "district": "SUMMERS COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540135000787",
    },
    {
        "school": "JUMPING BRANCH ELEMENTARY SCHOOL",
        "district": "SUMMERS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540135001042",
    },
    {
        "school": "TALCOTT ELEMENTARY SCHOOL",
        "district": "SUMMERS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540135001048",
    },
    {
        "school": "HINTON AREA ELEMENTARY",
        "district": "SUMMERS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540135001306",
    },
    {
        "school": "TUCKER VALLEY ELEMENTARY MIDDLE SCHOOL",
        "district": "TUCKER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540141000851",
    },
    {
        "school": "DAVIS THOMAS ELEMENTARY MIDDLE SCHOOL",
        "district": "TUCKER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540141001067",
    },
    {
        "school": "TUCKER COUNTY HIGH SCHOOL",
        "district": "TUCKER COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540141001272",
    },
    {
        "school": "TYLER CONSOLIDATED MIDDLE SCHOOL",
        "district": "TYLER COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540144000667",
    },
    {
        "school": "TYLER CONSOLIDATED HIGH SCHOOL",
        "district": "TYLER COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540144000671",
    },
    {
        "school": "ARTHUR I BOREMAN ELEMENTARY SCHOOL",
        "district": "TYLER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540144001068",
    },
    {
        "school": "SISTERSVILLE ELEMENTARY SCHOOL",
        "district": "TYLER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540144001071",
    },
    {
        "school": "B-U MIDDLE SCHOOL",
        "district": "UPSHUR COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540147001077",
    },
    {
        "school": "BUCKHANNON UPSHUR HIGH SCHOOL",
        "district": "UPSHUR COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540147001078",
    },
    {
        "school": "FRENCH CREEK ELEMENTARY",
        "district": "UPSHUR COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540147001080",
    },
    {
        "school": "HODGESVILLE ELEMENTARY",
        "district": "UPSHUR COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540147001082",
    },
    {
        "school": "ROCK CAVE ELEMENTARY",
        "district": "UPSHUR COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540147001084",
    },
    {
        "school": "TENNERTON ELEMENTARY",
        "district": "UPSHUR COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540147001088",
    },
    {
        "school": "WASHINGTON DISTRICT ELEMENTARY",
        "district": "UPSHUR COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540147001320",
    },
    {
        "school": "FRED W EBERLE TECH CENTER",
        "district": "UPSHUR COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540147001423",
    },
    {
        "school": "UNION ELEMENTARY SCHOOL",
        "district": "UPSHUR COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540147001432",
    },
    {
        "school": "GLADE ELEMENTARY SCHOOL",
        "district": "WEBSTER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540153001116",
    },
    {
        "school": "HACKER VALLEY ELEMENTARY SCHOOL",
        "district": "WEBSTER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540153001117",
    },
    {
        "school": "WEBSTER COUNTY HIGH SCHOOL",
        "district": "WEBSTER COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540153001118",
    },
    {
        "school": "WEBSTER SPRINGS ELEMENTARY SCHOOL",
        "district": "WEBSTER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540153001119",
    },
    {
        "school": "HUNDRED HIGH SCHOOL",
        "district": "WETZEL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540156001123",
    },
    {
        "school": "LONG DRAIN SCHOOL",
        "district": "WETZEL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540156001125",
    },
    {
        "school": "MAGNOLIA HIGH SCHOOL",
        "district": "WETZEL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540156001126",
    },
    {
        "school": "NEW MARTINSVILLE SCHOOL",
        "district": "WETZEL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540156001127",
    },
    {
        "school": "PADEN CITY ELEMENTARY SCHOOL",
        "district": "WETZEL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540156001128",
    },
    {
        "school": "PADEN CITY HIGH SCHOOL",
        "district": "WETZEL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540156001129",
    },
    {
        "school": "VALLEY HIGH SCHOOL",
        "district": "WETZEL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540156001132",
    },
    {
        "school": "SHORT LINE SCHOOL",
        "district": "WETZEL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540156001295",
    },
    {
        "school": "WYOMING COUNTY EAST HIGH SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001028",
    },
    {
        "school": "BAILEYSVILLE ELEMENTARY & MIDDLE SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001191",
    },
    {
        "school": "GLEN FORK ELEMENTARY & MIDDLE SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001196",
    },
    {
        "school": "HERNDON CONS ELEMENTARY & MIDDLE SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001201",
    },
    {
        "school": "HUFF CONS ELEMENTARY & MIDDLE SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001203",
    },
    {
        "school": "MULLENS ELEMENTARY SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001209",
    },
    {
        "school": "MULLENS MIDDLE SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001211",
    },
    {
        "school": "OCEANA MIDDLE SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001213",
    },
    {
        "school": "PINEVILLE ELEMENTARY SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001215",
    },
    {
        "school": "PINEVILLE MIDDLE SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001217",
    },
    {
        "school": "ROAD BRANCH ELEMENTARY & MIDDLE SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001218",
    },
    {
        "school": "BERLIN MCKINNEY ELEMENTARY SCHOOL",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540165001274",
    },
    {
        "school": "WYOMING COUNTY CAREER & TECHNICAL CENTER",
        "district": "WYOMING COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540165001429",
    },
    {
        "school": "BECKLEY ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123001176",
    },
    {
        "school": "INDEPENDENCE MIDDLE SCHOOL",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000779",
    },
    {
        "school": "MARSH FORK ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000848",
    },
    {
        "school": "BECKLEY-STRATTON MIDDLE SCHOOL",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000940",
    },
    {
        "school": "BRADLEY ELEMENTARY SCHOOL",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000941",
    },
    {
        "school": "CLEAR FORK DISTRICT ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000945",
    },
    {
        "school": "COAL CITY ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000947",
    },
    {
        "school": "CRANBERRY-PROSPERITY ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000949",
    },
    {
        "school": "CRESCENT ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000950",
    },
    {
        "school": "DANIELS ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000951",
    },
    {
        "school": "FAIRDALE ELEMENTARY SCHOOL",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000954",
    },
    {
        "school": "GHENT ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000956",
    },
    {
        "school": "HOLLYWOOD ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000957",
    },
    {
        "school": "INDEPENDENCE HIGH SCHOOL",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000958",
    },
    {
        "school": "LIBERTY HIGH SCHOOL",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000961",
    },
    {
        "school": "MABSCOTT ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000963",
    },
    {
        "school": "MAXWELL HILL ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000968",
    },
    {
        "school": "PARK MIDDLE SCHOOL",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000972",
    },
    {
        "school": "ACADEMY OF CAREERS AND TECHNOLOGY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540123000977",
    },
    {
        "school": "SHADY SPRING ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000979",
    },
    {
        "school": "SHADY SPRING HIGH",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000980",
    },
    {
        "school": "SHADY SPRING MIDDLE SCHOOL",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000981",
    },
    {
        "school": "STANAFORD ELEMENTARY SCHOOL",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000985",
    },
    {
        "school": "TRAP HILL MIDDLE SCHOOL",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000990",
    },
    {
        "school": "WOODROW WILSON HIGH SCHOOL",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123000991",
    },
    {
        "school": "STRATTON ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123001012",
    },
    {
        "school": "ATHENS ELEMENTARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000672",
    },
    {
        "school": "BLUEFIELD HIGH SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000674",
    },
    {
        "school": "BLUEWELL ELEMENTARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000675",
    },
    {
        "school": "BRUSHFORK ELEMENTARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000678",
    },
    {
        "school": "CERES ELEMENTARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000681",
    },
    {
        "school": "GLENWOOD SCHOOL (K-8)",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000685",
    },
    {
        "school": "LASHMEET/MATOAKA ELEMENTARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000689",
    },
    {
        "school": "MELROSE ELEMENTARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000692",
    },
    {
        "school": "MEMORIAL ELEMENTARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000693",
    },
    {
        "school": "MERCER ELEMENTARY",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000695",
    },
    {
        "school": "MONTCALM ELEMENTARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000696",
    },
    {
        "school": "MONTCALM HIGH SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000697",
    },
    {
        "school": "OAKVALE SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000698",
    },
    {
        "school": "PRINCETON SENIOR HIGH SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000701",
    },
    {
        "school": "PRINCETON MIDDLE SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000702",
    },
    {
        "school": "SPANISHBURG",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000705",
    },
    {
        "school": "WHITETHORN ELEMENTARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000710",
    },
    {
        "school": "BLUEFIELD MIDDLE SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000737",
    },
    {
        "school": "PIKEVIEW HIGH SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000741",
    },
    {
        "school": "MERCER COUNTY EARLY LEARNING CENTER",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084001087",
    },
    {
        "school": "BLUEFIELD INTERMEDIATE SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084001101",
    },
    {
        "school": "PRINCETON PRIMARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084001120",
    },
    {
        "school": "STRALEY ELEMENTARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084001311",
    },
    {
        "school": "MERCER COUNTY TECHNICAL EDUCATION CENTER",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540084001400",
    },
    {
        "school": "SUN VALLEY ELEMENTARY SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084000707",
    },
    {
        "school": "BOARD OF CHILD CARE",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101143",
    },
    {
        "school": "DONALD R. KUHN JUVENILE CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101144",
    },
    {
        "school": "ROBERT L. SHELL JUVENILE CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101234",
    },
    {
        "school": "J.M. CHICK BUCKBEE JUVENILE CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101159",
    },
    {
        "school": "JAMES H. TIGER MORTON JUVENILE CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101146",
    },
    {
        "school": "BURLINGTON CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101227",
    },
    {
        "school": "ASHFORD-RUMBLE ELEMENTARY",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009000035",
    },
    {
        "school": "BOONE CAREER-TECHNICAL CENTER",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540009000036",
    },
    {
        "school": "MADISON ELEMENTARY",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009000042",
    },
    {
        "school": "RAMAGE ELEMENTARY",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009000048",
    },
    {
        "school": "SCOTT HIGH SCHOOL",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009000049",
    },
    {
        "school": "SHERMAN HIGH SCHOOL",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009000051",
    },
    {
        "school": "VAN ELEMENTARY",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009000054",
    },
    {
        "school": "VAN JUNIOR/SENIOR HIGH SCHOOL",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009000055",
    },
    {
        "school": "WHITESVILLE ELEMENTARY SCHOOL",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009000059",
    },
    {
        "school": "SHERMAN ELEMENTARY SCHOOL",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009000793",
    },
    {
        "school": "BROOKVIEW ELEMENTARY",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009000880",
    },
    {
        "school": "MADISON MIDDLE SCHOOL",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009001324",
    },
    {
        "school": "SHERMAN JUNIOR HIGH SCHOOL",
        "district": "BOONE COUNTY  SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540009001325",
    },
    {
        "school": "CLAY MIDDLE SCHOOL",
        "district": "CLAY COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540024000030",
    },
    {
        "school": "CLAY COUNTY HIGH SCHOOL",
        "district": "CLAY COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540024000147",
    },
    {
        "school": "CLAY ELEMENTARY SCHOOL",
        "district": "CLAY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540024000148",
    },
    {
        "school": "H E WHITE ELEMENTARY SCHOOL",
        "district": "CLAY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540024000151",
    },
    {
        "school": "LIZEMORE ELEMENTARY SCHOOL",
        "district": "CLAY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540024000153",
    },
    {
        "school": "MIDWAY ELEMENTARY SCHOOL",
        "district": "LINCOLN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540066000498",
    },
    {
        "school": "RANGER ELEMENTARY",
        "district": "LINCOLN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540066000500",
    },
    {
        "school": "WEST HAMLIN ELEMENTARY",
        "district": "LINCOLN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540066000502",
    },
    {
        "school": "VICKI DOUGLAS JUVENILE CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101040",
    },
    {
        "school": "ANTHONY CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051100118",
    },
    {
        "school": "DAVIS-STUART SCHOOL",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051100796",
    },
    {
        "school": "BARBOURSVILLE SCHOOL",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051100110",
    },
    {
        "school": "ELK ELEMENTARY CENTER",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000060",
    },
    {
        "school": "BRIDGEVIEW ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000063",
    },
    {
        "school": "JOHN ADAMS MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000352",
    },
    {
        "school": "ALBAN ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000353",
    },
    {
        "school": "ALUM CREEK ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000354",
    },
    {
        "school": "ANDREW JACKSON MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000355",
    },
    {
        "school": "ANDREWS HEIGHTS ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000356",
    },
    {
        "school": "ANNE BAILEY ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000357",
    },
    {
        "school": "BELLE ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000359",
    },
    {
        "school": "BEN FRANKLIN CAREER CENTER",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540060000361",
    },
    {
        "school": "BRIDGE ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000365",
    },
    {
        "school": "CARVER CAREER CENTER",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540060000367",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000370",
    },
    {
        "school": "CHAMBERLAIN ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000371",
    },
    {
        "school": "CHESAPEAKE ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000375",
    },
    {
        "school": "CLENDENIN ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000376",
    },
    {
        "school": "CROSS LANES ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000378",
    },
    {
        "school": "DUNBAR PRIMARY CENTER",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000380",
    },
    {
        "school": "DUNBAR MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000382",
    },
    {
        "school": "DU PONT MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000384",
    },
    {
        "school": "EAST BANK MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000386",
    },
    {
        "school": "ELKVIEW MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000390",
    },
    {
        "school": "FLINN ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000393",
    },
    {
        "school": "GEORGE WASHINGTON HIGH SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000397",
    },
    {
        "school": "GEORGE C. WEIMER ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000398",
    },
    {
        "school": "GRANDVIEW ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000400",
    },
    {
        "school": "HAYES MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000402",
    },
    {
        "school": "HERBERT HOOVER HIGH SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000403",
    },
    {
        "school": "HOLZ ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000405",
    },
    {
        "school": "HORACE MANN MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000406",
    },
    {
        "school": "KANAWHA CITY ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000409",
    },
    {
        "school": "KENNA ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000410",
    },
    {
        "school": "LAKEWOOD ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000412",
    },
    {
        "school": "MALDEN ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000416",
    },
    {
        "school": "MARMET ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000417",
    },
    {
        "school": "MARY INGLES ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000419",
    },
    {
        "school": "MCKINLEY MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000420",
    },
    {
        "school": "MIDLAND TRAIL ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000421",
    },
    {
        "school": "MONTROSE ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000423",
    },
    {
        "school": "NITRO ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000425",
    },
    {
        "school": "NITRO HIGH SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000426",
    },
    {
        "school": "OVERBROOK ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000429",
    },
    {
        "school": "PINCH ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000433",
    },
    {
        "school": "POINT HARMONY ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000434",
    },
    {
        "school": "PRATT ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000435",
    },
    {
        "school": "RICHMOND ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000437",
    },
    {
        "school": "RUFFNER ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000440",
    },
    {
        "school": "RUTHLAWN ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000441",
    },
    {
        "school": "SOUTH CHARLESTON HIGH SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000442",
    },
    {
        "school": "SOUTH CHARLESTON MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000443",
    },
    {
        "school": "SAINT ALBANS HIGH SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000444",
    },
    {
        "school": "SHARON DAWES ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000446",
    },
    {
        "school": "SHOALS ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000448",
    },
    {
        "school": "SISSONVILLE ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000449",
    },
    {
        "school": "SISSONVILLE HIGH SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000450",
    },
    {
        "school": "SISSONVILLE MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000451",
    },
    {
        "school": "WEBERWOOD ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000464",
    },
    {
        "school": "PIEDMONT YEAR-ROUND EDUCATION",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060000872",
    },
    {
        "school": "CHANDLER ACADEMY",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540060000898",
    },
    {
        "school": "RIVERSIDE HIGH SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060001043",
    },
    {
        "school": "DUNBAR INTERMEDIATE CENTER",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060001124",
    },
    {
        "school": "CEDAR GROVE ELEMENTARY SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060001340",
    },
    {
        "school": "STONEWALL JACKSON MIDDLE SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060001442",
    },
    {
        "school": "CAPITAL HIGH SCHOOL",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060001443",
    },
    {
        "school": "WILLIAM J RAGLIN CENTER",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060001458",
    },
    {
        "school": "SAM PERDUE JUVENILE CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051100964",
    },
    {
        "school": "RONALD C MULHOLLAND JUVENILE CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051100967",
    },
    {
        "school": "BUFFALO ELEMENTARY SCHOOL",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000918",
    },
    {
        "school": "BUFFALO HIGH SCHOOL",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000919",
    },
    {
        "school": "CONFIDENCE ELEMENTARY",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000920",
    },
    {
        "school": "CONNER STREET ELEMENTARY",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000921",
    },
    {
        "school": "GEORGE WASHINGTON ELEMENTARY SCHOOL",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000922",
    },
    {
        "school": "GEORGE WASHINGTON MIDDLE SCHOOL",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000923",
    },
    {
        "school": "HOMETOWN ELEMENTARY",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000924",
    },
    {
        "school": "HURRICANE TOWN ELEMENTARY",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000925",
    },
    {
        "school": "HURRICANE HIGH SCHOOL",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000926",
    },
    {
        "school": "HURRICANE MIDDLE",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000927",
    },
    {
        "school": "POCA ELEMENTARY",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000930",
    },
    {
        "school": "POCA HIGH SCHOOL",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000931",
    },
    {
        "school": "POCA MIDDLE SCHOOL",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000932",
    },
    {
        "school": "PUTNAM CAREER & TECHNICAL CENTER",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540120000933",
    },
    {
        "school": "ROCK BRANCH ELEMENTARY",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000934",
    },
    {
        "school": "SCOTT TEAYS ELEMENTARY",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000935",
    },
    {
        "school": "WINFIELD ELEMENTARY",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000936",
    },
    {
        "school": "WINFIELD HIGH SCHOOL",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120000937",
    },
    {
        "school": "EASTBROOK ELEMENTARY SCHOOL",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120001301",
    },
    {
        "school": "LAKESIDE ELEMENTARY",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120001302",
    },
    {
        "school": "WEST TEAYS ELEMENTARY",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120001303",
    },
    {
        "school": "WINFIELD MIDDLE SCHOOL",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120001304",
    },
    {
        "school": "BECKLEY CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101130",
    },
    {
        "school": "ELKINS MOUNTAIN SCHOOL",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051100105",
    },
    {
        "school": "WV CHILDRENS HOME",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101047",
    },
    {
        "school": "KENNETH HONEY RUBENSTEIN CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051100136",
    },
    {
        "school": "LORRIE YEAGER JUVENILE CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051100974",
    },
    {
        "school": "DODDRIDGE COUNTY ELEMENTARY SCHOOL",
        "district": "DODDRIDGE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540027001059",
    },
    {
        "school": "SALEM ELEMENTARY",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051001230",
    },
    {
        "school": "MOUNTAINEER MIDDLE SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051001231",
    },
    {
        "school": "DODDRIDGE COUNTY MIDDLE SCHOOL",
        "district": "DODDRIDGE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540027000043",
    },
    {
        "school": "DODDRIDGE COUNTY HIGH SCHOOL",
        "district": "DODDRIDGE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540027000159",
    },
    {
        "school": "ADAMSTON ELEMENTARY SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000282",
    },
    {
        "school": "BRIDGEPORT HIGH SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000284",
    },
    {
        "school": "BRIDGEPORT MIDDLE SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000285",
    },
    {
        "school": "JOHNSON ELEMENTARY SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000296",
    },
    {
        "school": "LIBERTY HIGH SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000298",
    },
    {
        "school": "LOST CREEK ELEMENTARY SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000300",
    },
    {
        "school": "LUMBERPORT ELEMENTARY SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000301",
    },
    {
        "school": "NORWOOD ELEMENTARY SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000305",
    },
    {
        "school": "SIMPSON ELEMENTARY SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000313",
    },
    {
        "school": "SOUTH HARRISON HIGH SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000314",
    },
    {
        "school": "ROBERT C BYRD HIGH SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000320",
    },
    {
        "school": "WEST MILFORD ELEMENTARY SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000321",
    },
    {
        "school": "WILSONBURG ELEMENTARY SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000322",
    },
    {
        "school": "BIG ELM ELEMENTARY SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000586",
    },
    {
        "school": "NUTTER FORT PRIMARY SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000591",
    },
    {
        "school": "NUTTER FORT INTERMEDIATE SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000592",
    },
    {
        "school": "WASHINGTON IRVING MIDDLE SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000605",
    },
    {
        "school": "SOUTH HARRISON MIDDLE SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051000864",
    },
    {
        "school": "LINCOLN HIGH SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051001238",
    },
    {
        "school": "UNITED TECHNICAL CENTER",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540051001389",
    },
    {
        "school": "NORTH VIEW ELEMENTARY SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051001437",
    },
    {
        "school": "LINCOLN MIDDLE SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051001453",
    },
    {
        "school": "ANNA JARVIS ELEMENTARY SCHOOL",
        "district": "TAYLOR COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540138001050",
    },
    {
        "school": "FLEMINGTON ELEMENTARY SCHOOL",
        "district": "TAYLOR COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540138001051",
    },
    {
        "school": "GRAFTON HIGH SCHOOL",
        "district": "TAYLOR COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540138001053",
    },
    {
        "school": "WEST TAYLOR ELEMENTARY SCHOOL",
        "district": "TAYLOR COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540138001056",
    },
    {
        "school": "TAYLOR COUNTY MIDDLE SCHOOL",
        "district": "TAYLOR COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540138001462",
    },
    {
        "school": "FRANKFORT MIDDLE SCHOOL",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087000071",
    },
    {
        "school": "BURLINGTON PRIMARY",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087000711",
    },
    {
        "school": "MINERAL COUNTY ALTERNATIVE PROGRAM",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540087000712",
    },
    {
        "school": "FORT ASHBY PRIMARY SCHOOL",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087000715",
    },
    {
        "school": "FOUNTAIN PRIMARY SCHOOL",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087000716",
    },
    {
        "school": "FRANKFORT HIGH SCHOOL",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087000717",
    },
    {
        "school": "KEYSER HIGH SCHOOL",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087000718",
    },
    {
        "school": "MINERAL COUNTY TECHNICAL CENTER",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540087000720",
    },
    {
        "school": "NEW CREEK PRIMARY SCHOOL",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087000721",
    },
    {
        "school": "WILEY FORD PRIMARY SCHOOL",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087000725",
    },
    {
        "school": "FRANKFORT INTERMEDIATE SCHOOL",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087000747",
    },
    {
        "school": "ELK GARDEN SCHOOL",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087001346",
    },
    {
        "school": "KEYSER MIDDLE SCHOOL",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087001402",
    },
    {
        "school": "WEST FAIRMONT MIDDLE SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072001249",
    },
    {
        "school": "BLACKSHERE ELEMENTARY SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000104",
    },
    {
        "school": "BARRACKVILLE ELEMENTARY/MIDDLE SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000542",
    },
    {
        "school": "EAST DALE ELEMENTARY SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000550",
    },
    {
        "school": "EAST FAIRMONT HIGH SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000551",
    },
    {
        "school": "EAST PARK ELEMENTARY SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000552",
    },
    {
        "school": "FAIRMONT SENIOR HIGH SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000553",
    },
    {
        "school": "FAIRVIEW ELEMENTARY SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000554",
    },
    {
        "school": "JAYENNE ELEMENTARY SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000564",
    },
    {
        "school": "MONONGAH ELEMENTARY SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000570",
    },
    {
        "school": "PLEASANT VALLEY ELEMENTARY SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000572",
    },
    {
        "school": "RIVESVILLE ELEMENTARY/MIDDLE SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000574",
    },
    {
        "school": "WATSON ELEMENTARY SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000579",
    },
    {
        "school": "WHITE HALL ELEMENTARY SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000581",
    },
    {
        "school": "EAST FAIRMONT MIDDLE SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072000627",
    },
    {
        "school": "BARNES LEARNING CENTER (ALC)",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540072000997",
    },
    {
        "school": "FAIRVIEW MIDDLE SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072001281",
    },
    {
        "school": "NORTH MARION HIGH SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072001282",
    },
    {
        "school": "MONONGAH MIDDLE SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072001283",
    },
    {
        "school": "MANNINGTON MIDDLE SCHOOL",
        "district": "MARION COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540072001284",
    },
    {
        "school": "MARION COUNTY TECHNICAL CENTER",
        "district": "MARION COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540072001396",
    },
    {
        "school": "SPRING MILLS MIDDLE SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001207",
    },
    {
        "school": "MOUNTAIN RIDGE INTERMEDIATE",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001229",
    },
    {
        "school": "WIDMYER ELEMENTARY",
        "district": "MORGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540099001139",
    },
    {
        "school": "WARM SPRINGS INTERMEDIATE SCHOOL",
        "district": "MORGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540099001141",
    },
    {
        "school": "BERKELEY SPRINGS HIGH SCHOOL",
        "district": "MORGAN COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540099000819",
    },
    {
        "school": "PAW PAW ELEMENTARY SCHOOL",
        "district": "MORGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540099000823",
    },
    {
        "school": "PAW PAW HIGH SCHOOL",
        "district": "MORGAN COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540099000824",
    },
    {
        "school": "PLEASANT VIEW ELEMENTARY SCHOOL",
        "district": "MORGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540099000825",
    },
    {
        "school": "WARM SPRINGS MIDDLE SCHOOL",
        "district": "MORGAN COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540099000909",
    },
    {
        "school": "BACK CREEK VALLEY ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000012",
    },
    {
        "school": "BEDINGTON ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000013",
    },
    {
        "school": "BUNKER HILL ELEMENTARY",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000014",
    },
    {
        "school": "BURKE STREET ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000015",
    },
    {
        "school": "GERRARDSTOWN ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000017",
    },
    {
        "school": "HEDGESVILLE ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000018",
    },
    {
        "school": "HEDGESVILLE HIGH SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000019",
    },
    {
        "school": "HEDGESVILLE MIDDLE SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000020",
    },
    {
        "school": "INWOOD PRIMARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000021",
    },
    {
        "school": "MARLOWE ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000023",
    },
    {
        "school": "MARTINSBURG NORTH MIDDLE SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000024",
    },
    {
        "school": "MARTINSBURG SOUTH MIDDLE SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000025",
    },
    {
        "school": "MARTINSBURG HIGH SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000026",
    },
    {
        "school": "MUSSELMAN HIGH SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000027",
    },
    {
        "school": "OPEQUON ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000028",
    },
    {
        "school": "ROSEMONT ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000031",
    },
    {
        "school": "TUSCARORA ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000032",
    },
    {
        "school": "VALLEY VIEW ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000033",
    },
    {
        "school": "WINCHESTER AVENUE ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000034",
    },
    {
        "school": "POTOMACK INTERMEDIATE SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006000910",
    },
    {
        "school": "MILL CREEK INTERMEDIATE SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001029",
    },
    {
        "school": "EAGLE SCHOOL INTERMEDIATE",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001121",
    },
    {
        "school": "ORCHARD VIEW INTERMEDIATE SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001122",
    },
    {
        "school": "BERKELEY HEIGHTS ELEMENTARY SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001222",
    },
    {
        "school": "MUSSELMAN MIDDLE SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001375",
    },
    {
        "school": "JAMES RUMSEY TECHNICAL INSTITUTE",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540006001376",
    },
    {
        "school": "TOMAHAWK INTERMEDIATE SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001449",
    },
    {
        "school": "VILLAGE OF BARBOURSVILLE ELEMENTARY SCH",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018001049",
    },
    {
        "school": "ALTIZER ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000088",
    },
    {
        "school": "BARBOURSVILLE MIDDLE SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000091",
    },
    {
        "school": "COX LANDING ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000097",
    },
    {
        "school": "CULLODEN ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000099",
    },
    {
        "school": "DAVIS CREEK ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000100",
    },
    {
        "school": "GUYANDOTTE ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000109",
    },
    {
        "school": "HIGHLAWN ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000111",
    },
    {
        "school": "HITE SAUNDERS ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000112",
    },
    {
        "school": "MARTHA ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000120",
    },
    {
        "school": "MEADOWS ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000122",
    },
    {
        "school": "MILTON ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000125",
    },
    {
        "school": "NICHOLS ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000129",
    },
    {
        "school": "ONA ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000130",
    },
    {
        "school": "SALT ROCK ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000680",
    },
    {
        "school": "MILTON MIDDLE SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000683",
    },
    {
        "school": "CABELL MIDLAND HIGH SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000686",
    },
    {
        "school": "HUNTINGTON HIGH SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000860",
    },
    {
        "school": "CABELL ALTERNATIVE SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540018000884",
    },
    {
        "school": "CENTRAL CITY ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018000938",
    },
    {
        "school": "CABELL COUNTY CAREER TECHNOLOGY CENTER",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540018001307",
    },
    {
        "school": "SPRING HILL ELEMENTARY SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018001308",
    },
    {
        "school": "SPRING VALLEY HIGH SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001023",
    },
    {
        "school": "BUFFALO ELEMENTARY SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001091",
    },
    {
        "school": "DUNLOW ELEMENTARY SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001099",
    },
    {
        "school": "EAST LYNN ELEMENTARY SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001100",
    },
    {
        "school": "GENOA ELEMENTARY SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001104",
    },
    {
        "school": "KELLOGG ELEMENTARY SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001105",
    },
    {
        "school": "LAVALETTE ELEMENTARY SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001107",
    },
    {
        "school": "PRICHARD ELEMENTARY SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001108",
    },
    {
        "school": "WAYNE ELEMENTARY SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001111",
    },
    {
        "school": "WAYNE HIGH SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001112",
    },
    {
        "school": "WAYNE MIDDLE SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001113",
    },
    {
        "school": "VINSON MIDDLE SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001114",
    },
    {
        "school": "CEREDO-KENOVA MIDDLE SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001293",
    },
    {
        "school": "BUFFALO MIDDLE SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001294",
    },
    {
        "school": "TOLSIA HIGH SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001435",
    },
    {
        "school": "SKYVIEW ELEMENTARY SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093001220",
    },
    {
        "school": "MYLAN PARK ELEMENTARY SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093001224",
    },
    {
        "school": "CHEAT LAKE ELEMENTARY SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000073",
    },
    {
        "school": "MOUNTAINVIEW ELEMENTARY SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000078",
    },
    {
        "school": "MOUNTAINEER MIDDLE SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000655",
    },
    {
        "school": "MASON-DIXON  ELEMENTARY",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000750",
    },
    {
        "school": "WESTWOOD MIDDLE SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000755",
    },
    {
        "school": "BROOKHAVEN ELEMENTARY SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000762",
    },
    {
        "school": "RIDGEDALE ELEMENTARY SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000763",
    },
    {
        "school": "CLAY-BATTELLE HIGH SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000769",
    },
    {
        "school": "DAYBROOK EARLY HEADSTART CENTER(CLSD 97)",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000772",
    },
    {
        "school": "MORGANTOWN HIGH SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000786",
    },
    {
        "school": "SUNCREST MIDDLE SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000801",
    },
    {
        "school": "SUNCREST ELEMENTARY SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000802",
    },
    {
        "school": "UNIVERSITY HIGH SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093000803",
    },
    {
        "school": "TECHNICAL EDUCATION CENTER",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540093000804",
    },
    {
        "school": "NORTH ELEMENTARY SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093001291",
    },
    {
        "school": "SOUTH MIDDLE SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093001299",
    },
    {
        "school": "BRUCETON SCHOOL",
        "district": "PRESTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540117000901",
    },
    {
        "school": "CENTRAL PRESTON MIDDLE SCHOOL",
        "district": "PRESTON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540117000903",
    },
    {
        "school": "FELLOWSVILLE ELEMENTARY",
        "district": "PRESTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540117000905",
    },
    {
        "school": "KINGWOOD ELEMENTARY",
        "district": "PRESTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540117000907",
    },
    {
        "school": "TERRA ALTA/EAST PRESTON SCHOOL",
        "district": "PRESTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540117000913",
    },
    {
        "school": "AURORA SCHOOL",
        "district": "PRESTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540117001358",
    },
    {
        "school": "ROWLESBURG SCHOOL",
        "district": "PRESTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540117001431",
    },
    {
        "school": "PRESTON HIGH SCHOOL",
        "district": "PRESTON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540117001511",
    },
    {
        "school": "ANSTED ELEMENTARY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000167",
    },
    {
        "school": "OAK HILL MIDDLE SCHOOL",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000172",
    },
    {
        "school": "DIVIDE ELEMENTARY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000175",
    },
    {
        "school": "FAYETTEVILLE ELEMENTARY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000179",
    },
    {
        "school": "FAYETTEVILLE HIGH",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000180",
    },
    {
        "school": "GATEWOOD ELEMENTARY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000182",
    },
    {
        "school": "GAULEY BRIDGE ELEMENTARY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000183",
    },
    {
        "school": "MEADOW BRIDGE ELEMENTARY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000189",
    },
    {
        "school": "MEADOW BRIDGE HIGH",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000190",
    },
    {
        "school": "MIDLAND TRAIL HIGH",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000191",
    },
    {
        "school": "MOUNT HOPE ELEMENTARY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000194",
    },
    {
        "school": "OAK HILL HIGH",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000200",
    },
    {
        "school": "ROSEDALE ELEMENTARY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000205",
    },
    {
        "school": "VALLEY ELEMENTARY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000208",
    },
    {
        "school": "VALLEY HIGH SCHOOL",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030000209",
    },
    {
        "school": "FAYETTE INSTITUTE OF TECHNOLOGY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540030001380",
    },
    {
        "school": "ST. MARYS ELEMENTARY SCHOOL",
        "district": "PLEASANTS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540111000888",
    },
    {
        "school": "ST. MARYS HIGH SCHOOL",
        "district": "PLEASANTS COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540111000889",
    },
    {
        "school": "PLEASANTS COUNTY MIDDLE SCHOOL",
        "district": "PLEASANTS COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540111001264",
    },
    {
        "school": "BELMONT ELEMENTARY SCHOOL",
        "district": "PLEASANTS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540111001265",
    },
    {
        "school": "MID OHIO VALLEY TECHNICAL INSTITUTE",
        "district": "PLEASANTS COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540111001411",
    },
    {
        "school": "WIRT COUNTY MIDDLE SCHOOL",
        "district": "WIRT COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540159000102",
    },
    {
        "school": "WIRT COUNTY PRIMARY CENTER",
        "district": "WIRT COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540159001135",
    },
    {
        "school": "WIRT COUNTY HIGH SCHOOL",
        "district": "WIRT COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540159001140",
    },
    {
        "school": "FRANKLIN ELEMENTARY CENTER",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162000679",
    },
    {
        "school": "MARTIN ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162000792",
    },
    {
        "school": "BLENNERHASSETT ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001142",
    },
    {
        "school": "CRISS ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001147",
    },
    {
        "school": "EDISON MIDDLE SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001148",
    },
    {
        "school": "EMERSON ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001149",
    },
    {
        "school": "FAIRPLAINS ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001150",
    },
    {
        "school": "GIHON ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001152",
    },
    {
        "school": "GREENMONT ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001153",
    },
    {
        "school": "HAMILTON MIDDLE SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001154",
    },
    {
        "school": "JACKSON MIDDLE SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001156",
    },
    {
        "school": "JEFFERSON ELEMENTARY CENTER",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001157",
    },
    {
        "school": "KANAWHA ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001158",
    },
    {
        "school": "LUBECK ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001161",
    },
    {
        "school": "MADISON ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001162",
    },
    {
        "school": "MCKINLEY ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001164",
    },
    {
        "school": "MINERAL WELLS ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001165",
    },
    {
        "school": "NEALE ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001168",
    },
    {
        "school": "PARKERSBURG HIGH SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001170",
    },
    {
        "school": "PARKERSBURG SOUTH HIGH SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001171",
    },
    {
        "school": "VAN DEVENDER MIDDLE SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001180",
    },
    {
        "school": "VIENNA ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001181",
    },
    {
        "school": "WAVERLY ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001185",
    },
    {
        "school": "WILLIAMSTOWN ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001187",
    },
    {
        "school": "WILLIAMSTOWN HIGH SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001188",
    },
    {
        "school": "WORTHINGTON ELEMENTARY SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001190",
    },
    {
        "school": "BLENNERHASSETT MIDDLE SCHOOL",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540162001365",
    },
    {
        "school": "WOOD CO VOC TECH CTR",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540162001427",
    },
    {
        "school": "PT. PLEASANT PRIMARY",
        "district": "MASON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540078001086",
    },
    {
        "school": "PT. PLEASANT INTERMEDIATE",
        "district": "MASON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540078001136",
    },
    {
        "school": "BEALE ELEMENTARY SCHOOL",
        "district": "MASON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540078000609",
    },
    {
        "school": "HANNAN HIGH SCHOOL",
        "district": "MASON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540078000614",
    },
    {
        "school": "LEON ELEMENTARY SCHOOL",
        "district": "MASON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540078000616",
    },
    {
        "school": "MASON COUNTY CAREER CENTER",
        "district": "MASON COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540078000618",
    },
    {
        "school": "NEW HAVEN ELEMENTARY SCHOOL",
        "district": "MASON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540078000622",
    },
    {
        "school": "POINT PLEASANT JUNIOR/SENIOR HIGH SCHOOL",
        "district": "MASON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540078000625",
    },
    {
        "school": "ROOSEVELT ELEMENTARY SCHOOL",
        "district": "MASON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540078000628",
    },
    {
        "school": "WAHAMA HIGH SCHOOL",
        "district": "MASON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540078000630",
    },
    {
        "school": "ASHTON ELEMENTARY SCHOOL",
        "district": "MASON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540078001505",
    },
    {
        "school": "T A LOWERY ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000057",
    },
    {
        "school": "BLUE RIDGE ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000340",
    },
    {
        "school": "CHARLES TOWN MIDDLE SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000341",
    },
    {
        "school": "C. W. SHIPLEY ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000342",
    },
    {
        "school": "HARPERS FERRY MIDDLE SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000343",
    },
    {
        "school": "JEFFERSON HIGH SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000344",
    },
    {
        "school": "NORTH JEFFERSON ELEMENTARY",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000345",
    },
    {
        "school": "PAGE JACKSON ELEMENTARY",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000346",
    },
    {
        "school": "RANSON ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000347",
    },
    {
        "school": "SHEPHERDSTOWN ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000348",
    },
    {
        "school": "SHEPHERDSTOWN MIDDLE SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000349",
    },
    {
        "school": "SOUTH JEFFERSON ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000350",
    },
    {
        "school": "WRIGHT DENNY INTERMEDIATE SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057000351",
    },
    {
        "school": "A. T. ALLISON ELEMENTARY SCHOOL",
        "district": "HANCOCK COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540045001186",
    },
    {
        "school": "OAK GLEN MIDDLE SCHOOL",
        "district": "HANCOCK COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540045001193",
    },
    {
        "school": "BROOKE HIGH SCHOOL",
        "district": "BROOKE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540015000075",
    },
    {
        "school": "NEW MANCHESTER ELEMENTARY SCHOOL",
        "district": "HANCOCK COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540045000267",
    },
    {
        "school": "OAK GLEN HIGH SCHOOL",
        "district": "HANCOCK COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540045000268",
    },
    {
        "school": "WEIR HIGH SCHOOL",
        "district": "HANCOCK COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540045000269",
    },
    {
        "school": "JOHN D. ROCKEFELLER CAREER CENTER",
        "district": "HANCOCK COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540045001386",
    },
    {
        "school": "WEIR MIDDLE SCHOOL",
        "district": "HANCOCK COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540045001501",
    },
    {
        "school": "CAMERON ELEMENTARY SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075000588",
    },
    {
        "school": "CAMERON HIGH SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075000589",
    },
    {
        "school": "CENTRAL ELEMENTARY SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075000590",
    },
    {
        "school": "GLEN DALE ELEMENTARY SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075000593",
    },
    {
        "school": "JOHN MARSHALL HIGH SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075000594",
    },
    {
        "school": "CENTER MCMECHEN ELEMENTARY SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075000597",
    },
    {
        "school": "MOUNDSVILLE MIDDLE SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075000598",
    },
    {
        "school": "SAND HILL ELEMENTARY SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075000601",
    },
    {
        "school": "WASHINGTON LANDS ELEMENTARY SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075000607",
    },
    {
        "school": "MCNINCH PRIMARY SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075001285",
    },
    {
        "school": "SHERRARD MIDDLE SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075000604",
    },
    {
        "school": "BETHLEHEM ELEMENTARY SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000853",
    },
    {
        "school": "BRIDGE STREET MIDDLE SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000854",
    },
    {
        "school": "ELM GROVE ELEMENTARY SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000857",
    },
    {
        "school": "MADISON ELEMENTARY SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000861",
    },
    {
        "school": "MIDDLE CREEK ELEMENTARY SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000862",
    },
    {
        "school": "RITCHIE ELEMENTARY SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000866",
    },
    {
        "school": "STEENROD ELEMENTARY SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000868",
    },
    {
        "school": "TRIADELPHIA MIDDLE SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000869",
    },
    {
        "school": "WARWOOD SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000871",
    },
    {
        "school": "WEST LIBERTY ELEMENTARY SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000873",
    },
    {
        "school": "WHEELING MIDDLE SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000874",
    },
    {
        "school": "WHEELING PARK HIGH SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000875",
    },
    {
        "school": "WOODSDALE ELEMENTARY SCHOOL",
        "district": "OHIO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540105000876",
    },
    {
        "school": "WEST VIRGINIA SCHOOL FOR THE DEAF",
        "district": "WV SCHOOLS FOR THE DEAF AND THE BLIND",
        "level": "Other",
        "type": "Special education school",
        "state": "WV",
        "nces_id": "540162101200",
    },
    {
        "school": "WEST VIRGINIA SCHOOL FOR THE BLIND",
        "district": "WV SCHOOLS FOR THE DEAF AND THE BLIND",
        "level": "Other",
        "type": "Special education school",
        "state": "WV",
        "nces_id": "540162101204",
    },
    {
        "school": "CAPON BRIDGE ELEMENTARY SCHOOL",
        "district": "HAMPSHIRE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540042000245",
    },
    {
        "school": "HAMPSHIRE SENIOR HIGH SCHOOL",
        "district": "HAMPSHIRE COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540042000248",
    },
    {
        "school": "JOHN J. CORNWELL",
        "district": "HAMPSHIRE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540042000249",
    },
    {
        "school": "ROMNEY ELEMENTARY SCHOOL",
        "district": "HAMPSHIRE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540042000251",
    },
    {
        "school": "ROMNEY MIDDLE SCHOOL",
        "district": "HAMPSHIRE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540042000252",
    },
    {
        "school": "SLANESVILLE ELEMENTARY SCHOOL",
        "district": "HAMPSHIRE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540042000254",
    },
    {
        "school": "SPRINGFIELD-GREEN SPRING ELEMENTARY SCH",
        "district": "HAMPSHIRE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540042000255",
    },
    {
        "school": "AUGUSTA ELEMENTARY SCHOOL",
        "district": "HAMPSHIRE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540042001232",
    },
    {
        "school": "CAPON BRIDGE MIDDLE SCHOOL",
        "district": "HAMPSHIRE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540042001336",
    },
    {
        "school": "Cottonwood Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000377",
    },
    {
        "school": "Rocky Mountain Elementary",
        "district": "Big Horn County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560142000365",
    },
    {
        "school": "Big Horn Basin Children's Center",
        "district": "Northwest Wyoming BOCES",
        "level": "Elementary",
        "type": "Special education school",
        "state": "WY",
        "nces_id": "560001600045",
    },
    {
        "school": "New Frontier High School",
        "district": "Lincoln County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560403000358",
    },
    {
        "school": "Riverside Middle/High School",
        "district": "Big Horn County School District #4",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560109000036",
    },
    {
        "school": "Laura Irwin Elementary",
        "district": "Big Horn County School District #4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560109000038",
    },
    {
        "school": "Rocky Mountain High School",
        "district": "Big Horn County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560142000046",
    },
    {
        "school": "Burlington Elementary",
        "district": "Big Horn County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560142000049",
    },
    {
        "school": "Rocky Mountain Middle School",
        "district": "Big Horn County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560142000428",
    },
    {
        "school": "Burlington Middle School",
        "district": "Big Horn County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560142000477",
    },
    {
        "school": "Burlington High School",
        "district": "Big Horn County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560142000478",
    },
    {
        "school": "Lovell High School",
        "district": "Big Horn County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560146000054",
    },
    {
        "school": "Lovell Middle School",
        "district": "Big Horn County School District #2",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560146000055",
    },
    {
        "school": "Lovell Elementary",
        "district": "Big Horn County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560146000056",
    },
    {
        "school": "Greybull High School",
        "district": "Big Horn County School District #3",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560317000174",
    },
    {
        "school": "Greybull Elementary",
        "district": "Big Horn County School District #3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560317000176",
    },
    {
        "school": "Greybull Middle School",
        "district": "Big Horn County School District #3",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560317000378",
    },
    {
        "school": "Rawlins High School",
        "district": "Carbon County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560103000026",
    },
    {
        "school": "Rawlins Middle School",
        "district": "Carbon County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560103000028",
    },
    {
        "school": "Little Snake River Valley School",
        "district": "Carbon County School District #1",
        "level": "Other",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560103000124",
    },
    {
        "school": "Cooperative High",
        "district": "Carbon County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560103000147",
    },
    {
        "school": "Elk Mountain Elementary",
        "district": "Carbon County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560170000084",
    },
    {
        "school": "Hanna Elementary",
        "district": "Carbon County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560170000085",
    },
    {
        "school": "Medicine Bow Elementary",
        "district": "Carbon County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560170000087",
    },
    {
        "school": "Saratoga Elementary",
        "district": "Carbon County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560170000088",
    },
    {
        "school": "Douglas High School",
        "district": "Converse County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560214000127",
    },
    {
        "school": "Douglas Primary School",
        "district": "Converse County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560214000128",
    },
    {
        "school": "Dry Creek Elementary",
        "district": "Converse County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560214000129",
    },
    {
        "school": "Moss Agate Elementary",
        "district": "Converse County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560214000130",
    },
    {
        "school": "Shawnee Elementary",
        "district": "Converse County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560214000132",
    },
    {
        "school": "White Elementary",
        "district": "Converse County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560214000135",
    },
    {
        "school": "Douglas Upper Elementary School",
        "district": "Converse County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560214000352",
    },
    {
        "school": "Douglas Middle School",
        "district": "Converse County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560214000368",
    },
    {
        "school": "Glenrock Intermediate School",
        "district": "Converse County School District #2",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560215000037",
    },
    {
        "school": "Glenrock Jr/Sr High School",
        "district": "Converse County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560215000137",
    },
    {
        "school": "Grant Elementary",
        "district": "Converse County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560215000141",
    },
    {
        "school": "Boxelder Elementary",
        "district": "Converse County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560215000413",
    },
    {
        "school": "Sundance Elementary",
        "district": "Crook County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560237000150",
    },
    {
        "school": "Saint Joseph's Children's Home",
        "district": "Saint Joseph's Children's Home - Administration Office",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WY",
        "nces_id": "560001000156",
    },
    {
        "school": "Lingle-Ft. Laramie High School",
        "district": "Goshen County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560299000167",
    },
    {
        "school": "Torrington High School",
        "district": "Goshen County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560299000168",
    },
    {
        "school": "Torrington Middle School",
        "district": "Goshen County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560299000169",
    },
    {
        "school": "Southeast Elementary",
        "district": "Goshen County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560299000171",
    },
    {
        "school": "Lingle-Ft. Laramie Elementary",
        "district": "Goshen County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560299000172",
    },
    {
        "school": "Lingle-Ft. Laramie Middle School",
        "district": "Goshen County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560299000373",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Goshen County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560299000464",
    },
    {
        "school": "La Grange Elementary",
        "district": "Goshen County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560299000475",
    },
    {
        "school": "Southeast Junior High School",
        "district": "Goshen County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560299000482",
    },
    {
        "school": "Southeast High School",
        "district": "Goshen County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560299000483",
    },
    {
        "school": "Trail Elementary",
        "district": "Goshen County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560299000488",
    },
    {
        "school": "Hot Springs County High School",
        "district": "Hot Springs County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560331000180",
    },
    {
        "school": "Thermopolis Middle School",
        "district": "Hot Springs County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560331000181",
    },
    {
        "school": "Ralph Witters Elementary",
        "district": "Hot Springs County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560331000185",
    },
    {
        "school": "Buffalo High School",
        "district": "Johnson County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560377000187",
    },
    {
        "school": "Clear Creek Middle School",
        "district": "Johnson County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560377000191",
    },
    {
        "school": "Meadowlark Elementary",
        "district": "Johnson County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560377000380",
    },
    {
        "school": "Cloud Peak Elementary",
        "district": "Johnson County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560377000417",
    },
    {
        "school": "La Barge Elementary",
        "district": "Sublette County School District #9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560126000044",
    },
    {
        "school": "Swift Creek High School",
        "district": "Lincoln County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560406000193",
    },
    {
        "school": "Star Valley High School",
        "district": "Lincoln County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560406000202",
    },
    {
        "school": "Star Valley Middle School",
        "district": "Lincoln County School District #2",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560406000203",
    },
    {
        "school": "Afton Elementary",
        "district": "Lincoln County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560406000204",
    },
    {
        "school": "Cokeville Elementary",
        "district": "Lincoln County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560406000205",
    },
    {
        "school": "Thayne Elementary",
        "district": "Lincoln County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560406000206",
    },
    {
        "school": "Etna Elementary",
        "district": "Lincoln County School District #2",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560406000207",
    },
    {
        "school": "Cokeville High School",
        "district": "Lincoln County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560406000381",
    },
    {
        "school": "Osmond Elementary",
        "district": "Lincoln County School District #2",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560406000404",
    },
    {
        "school": "Niobrara County High School",
        "district": "Niobrara County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560423000214",
    },
    {
        "school": "Lusk Middle School",
        "district": "Niobrara County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560423000215",
    },
    {
        "school": "Lance Creek Elementary",
        "district": "Niobrara County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560423000218",
    },
    {
        "school": "Lusk Elementary",
        "district": "Niobrara County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560423000219",
    },
    {
        "school": "Cody High School",
        "district": "Park County School District # 6",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560207000121",
    },
    {
        "school": "Eastside Elementary",
        "district": "Park County School District # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560207000122",
    },
    {
        "school": "Wapiti Elementary",
        "district": "Park County School District # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560207000125",
    },
    {
        "school": "Glenn Livingston Elementary",
        "district": "Park County School District # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560207000126",
    },
    {
        "school": "Cody Middle School",
        "district": "Park County School District # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560207000351",
    },
    {
        "school": "Valley Elementary",
        "district": "Park County School District # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560207000430",
    },
    {
        "school": "Sunset Elementary",
        "district": "Park County School District # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560207000521",
    },
    {
        "school": "Meeteetse School",
        "district": "Park County School District #16",
        "level": "Other",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560438000139",
    },
    {
        "school": "Shoshone Learning Center",
        "district": "Park County School District # 1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560516000196",
    },
    {
        "school": "Powell High School",
        "district": "Park County School District # 1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560516000278",
    },
    {
        "school": "Powell Middle School",
        "district": "Park County School District # 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560516000279",
    },
    {
        "school": "Clark Elementary",
        "district": "Park County School District # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560516000280",
    },
    {
        "school": "Parkside Elementary",
        "district": "Park County School District # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560516000281",
    },
    {
        "school": "Southside Elementary",
        "district": "Park County School District # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560516000282",
    },
    {
        "school": "Westside Elementary",
        "district": "Park County School District # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560516000283",
    },
    {
        "school": "Guernsey-Sunrise Elementary",
        "district": "Platte County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560318000179",
    },
    {
        "school": "Guernsey-Sunrise High School",
        "district": "Platte County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560318000379",
    },
    {
        "school": "Guernsey-Sunrise Junior High",
        "district": "Platte County School District #2",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560318000499",
    },
    {
        "school": "Chugwater Elementary",
        "district": "Platte County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560509000271",
    },
    {
        "school": "Glendo Elementary",
        "district": "Platte County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560509000272",
    },
    {
        "school": "Wheatland High School",
        "district": "Platte County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560509000273",
    },
    {
        "school": "Wheatland Middle School",
        "district": "Platte County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560509000274",
    },
    {
        "school": "Libbey Elementary",
        "district": "Platte County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560509000275",
    },
    {
        "school": "West Elementary",
        "district": "Platte County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560509000277",
    },
    {
        "school": "Chugwater High School",
        "district": "Platte County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560509000391",
    },
    {
        "school": "Glendo High School",
        "district": "Platte County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560509000392",
    },
    {
        "school": "Chugwater Junior High School",
        "district": "Platte County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560509000509",
    },
    {
        "school": "Glendo Junior High School",
        "district": "Platte County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560509000533",
    },
    {
        "school": "Big Piney High School",
        "district": "Sublette County School District #9",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560126000041",
    },
    {
        "school": "Big Piney Middle School",
        "district": "Sublette County School District #9",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560126000042",
    },
    {
        "school": "Big Piney Elementary",
        "district": "Sublette County School District #9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560126000043",
    },
    {
        "school": "Pinedale High School",
        "district": "Sublette County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560486000267",
    },
    {
        "school": "Pinedale Middle School",
        "district": "Sublette County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560486000268",
    },
    {
        "school": "Bondurant Elementary",
        "district": "Sublette County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560486000269",
    },
    {
        "school": "Pinedale Elementary",
        "district": "Sublette County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560486000270",
    },
    {
        "school": "Worland High School",
        "district": "Washakie County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560624000343",
    },
    {
        "school": "Worland Middle School",
        "district": "Washakie County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560624000344",
    },
    {
        "school": "Newcastle Elementary K-2",
        "district": "Weston County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560483000015",
    },
    {
        "school": "Newcastle High School",
        "district": "Weston County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560483000263",
    },
    {
        "school": "Newcastle Middle School",
        "district": "Weston County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560483000264",
    },
    {
        "school": "Newcastle Elementary 3-5",
        "district": "Weston County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560483000265",
    },
    {
        "school": "Upton Middle School",
        "district": "Weston County School District #7",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560609000342",
    },
    {
        "school": "Upton Elementary",
        "district": "Weston County School District #7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560609000363",
    },
    {
        "school": "Upton High School",
        "district": "Weston County School District #7",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560609000401",
    },
    {
        "school": "Midwest School",
        "district": "Natrona County School District #1",
        "level": "Other",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000133",
    },
    {
        "school": "Casper Classical Academy",
        "district": "Natrona County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000183",
    },
    {
        "school": "Kelly Walsh High School",
        "district": "Natrona County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000229",
    },
    {
        "school": "Natrona County High School",
        "district": "Natrona County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000231",
    },
    {
        "school": "C Y Middle School",
        "district": "Natrona County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000232",
    },
    {
        "school": "Dean Morgan Middle School",
        "district": "Natrona County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000233",
    },
    {
        "school": "Alcova Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000235",
    },
    {
        "school": "Crest Hill Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000236",
    },
    {
        "school": "Evansville Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000237",
    },
    {
        "school": "Ft. Caspar Academy",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000240",
    },
    {
        "school": "Manor Heights Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000245",
    },
    {
        "school": "Journey Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000247",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000249",
    },
    {
        "school": "Paradise Valley Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000250",
    },
    {
        "school": "Park Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000251",
    },
    {
        "school": "Pineview Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000252",
    },
    {
        "school": "Poison Spider Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000253",
    },
    {
        "school": "Roosevelt High School",
        "district": "Natrona County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000256",
    },
    {
        "school": "Southridge Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000257",
    },
    {
        "school": "Woods Learning Center",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000262",
    },
    {
        "school": "Verda James Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000389",
    },
    {
        "school": "Oregon Trail Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000420",
    },
    {
        "school": "Sagewood Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000444",
    },
    {
        "school": "Bar Nunn Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000445",
    },
    {
        "school": "Red Creek Elementary",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000469",
    },
    {
        "school": "Centennial Middle School",
        "district": "Natrona County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000470",
    },
    {
        "school": "Freedom Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000371",
    },
    {
        "school": "Central High School",
        "district": "Laramie County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000090",
    },
    {
        "school": "East High School",
        "district": "Laramie County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000091",
    },
    {
        "school": "Triumph High School",
        "district": "Laramie County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000092",
    },
    {
        "school": "Carey Junior High School",
        "district": "Laramie County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000093",
    },
    {
        "school": "Johnson Junior High School",
        "district": "Laramie County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000094",
    },
    {
        "school": "McCormick Junior High School",
        "district": "Laramie County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000095",
    },
    {
        "school": "Alta Vista Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000096",
    },
    {
        "school": "Arp Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000097",
    },
    {
        "school": "Baggs Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000098",
    },
    {
        "school": "Bain Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000099",
    },
    {
        "school": "Buffalo Ridge Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000100",
    },
    {
        "school": "Cole Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000102",
    },
    {
        "school": "Davis Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000104",
    },
    {
        "school": "Deming Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000105",
    },
    {
        "school": "Dildine Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000106",
    },
    {
        "school": "Fairview Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000108",
    },
    {
        "school": "Gilchrist Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000109",
    },
    {
        "school": "Goins Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000110",
    },
    {
        "school": "Hebard Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000111",
    },
    {
        "school": "Henderson Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000112",
    },
    {
        "school": "Hobbs Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000113",
    },
    {
        "school": "Clawson Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000114",
    },
    {
        "school": "Jessup Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000115",
    },
    {
        "school": "Lebhart Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000116",
    },
    {
        "school": "Miller Elementary",
        "district": "Laramie County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000117",
    },
    {
        "school": "Pioneer Park Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000118",
    },
    {
        "school": "Rossman Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000119",
    },
    {
        "school": "Willadsen Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000120",
    },
    {
        "school": "Anderson Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000438",
    },
    {
        "school": "Afflerbach Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000480",
    },
    {
        "school": "Albin Elementary",
        "district": "Laramie County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560412000208",
    },
    {
        "school": "Burns Jr & Sr High School",
        "district": "Laramie County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560412000209",
    },
    {
        "school": "Pine Bluffs Jr & Sr High School",
        "district": "Laramie County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560412000210",
    },
    {
        "school": "Carpenter Elementary",
        "district": "Laramie County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560412000211",
    },
    {
        "school": "Pine Bluffs Elementary",
        "district": "Laramie County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560412000213",
    },
    {
        "school": "Burns Elementary",
        "district": "Laramie County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560412000504",
    },
    {
        "school": "Horizon Alternative School",
        "district": "Uinta County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560276000376",
    },
    {
        "school": "Evanston High School",
        "district": "Uinta County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560276000152",
    },
    {
        "school": "Davis Middle School",
        "district": "Uinta County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560276000153",
    },
    {
        "school": "Clark Elementary",
        "district": "Uinta County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560276000155",
    },
    {
        "school": "Uinta Meadows Elementary",
        "district": "Uinta County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560276000414",
    },
    {
        "school": "North Evanston Elementary",
        "district": "Uinta County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560276000433",
    },
    {
        "school": "Aspen Elementary",
        "district": "Uinta County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560276000462",
    },
    {
        "school": "Evanston Middle School",
        "district": "Uinta County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560276000463",
    },
    {
        "school": "Lyman High School",
        "district": "Uinta County School District #6",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560426000222",
    },
    {
        "school": "Lyman Intermediate School",
        "district": "Uinta County School District #6",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560426000357",
    },
    {
        "school": "Urie Elementary",
        "district": "Uinta County School District #6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560426000418",
    },
    {
        "school": "Mountain View High School",
        "district": "Uinta County School District #4",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560450000227",
    },
    {
        "school": "Pronghorn Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000019",
    },
    {
        "school": "Campbell County High School",
        "district": "Campbell County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000057",
    },
    {
        "school": "Twin Spruce Junior High School",
        "district": "Campbell County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000058",
    },
    {
        "school": "Cottonwood Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000064",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000067",
    },
    {
        "school": "Little Powder Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000068",
    },
    {
        "school": "Meadowlark Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000069",
    },
    {
        "school": "Lakeview Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000070",
    },
    {
        "school": "Rawhide Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000071",
    },
    {
        "school": "Recluse School",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000072",
    },
    {
        "school": "Rozet Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000073",
    },
    {
        "school": "Wagonwheel Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000076",
    },
    {
        "school": "Prairie Wind Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000349",
    },
    {
        "school": "Conestoga Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000409",
    },
    {
        "school": "Sage Valley Junior High School",
        "district": "Campbell County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000410",
    },
    {
        "school": "Wright Jr. & Sr. High School",
        "district": "Campbell County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000429",
    },
    {
        "school": "Paintbrush Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000435",
    },
    {
        "school": "Sunflower Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000436",
    },
    {
        "school": "4-J Elementary School",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000454",
    },
    {
        "school": "Westwood High School",
        "district": "Campbell County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000479",
    },
    {
        "school": "Powder River Basin Children's Center",
        "district": "Northeast Wyoming BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "WY",
        "nces_id": "568018000031",
    },
    {
        "school": "Red Top Meadows",
        "district": "Red Top Meadows - Administration Office",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WY",
        "nces_id": "560001500243",
    },
    {
        "school": "Colter Elementary",
        "district": "Teton County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560583000289",
    },
    {
        "school": "Jackson Elementary",
        "district": "Teton County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560583000313",
    },
    {
        "school": "Jackson Hole High School",
        "district": "Teton County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560583000335",
    },
    {
        "school": "Jackson Hole Middle School",
        "district": "Teton County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560583000336",
    },
    {
        "school": "Alta Elementary",
        "district": "Teton County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560583000337",
    },
    {
        "school": "Kelly Elementary",
        "district": "Teton County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560583000339",
    },
    {
        "school": "Moran Elementary",
        "district": "Teton County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560583000340",
    },
    {
        "school": "Wilson Elementary",
        "district": "Teton County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560583000341",
    },
    {
        "school": "Summit Innovations School",
        "district": "Teton County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560583000512",
    },
    {
        "school": "C-Bar-V Ranch",
        "district": "Region V BOCES",
        "level": "Other",
        "type": "Special education school",
        "state": "WY",
        "nces_id": "568025000048",
    },
    {
        "school": "Snowy Range Academy",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000216",
    },
    {
        "school": "Cathedral Home for Children",
        "district": "Cathedral Home for Children - Administration Office",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WY",
        "nces_id": "560000900145",
    },
    {
        "school": "Laramie High School",
        "district": "Albany County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000001",
    },
    {
        "school": "Laramie Middle School",
        "district": "Albany County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000002",
    },
    {
        "school": "Rock River High School",
        "district": "Albany County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000003",
    },
    {
        "school": "Indian Paintbrush  Elementary",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000004",
    },
    {
        "school": "Beitel Elementary",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000005",
    },
    {
        "school": "Spring Creek Elementary",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000006",
    },
    {
        "school": "Centennial Elementary",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000007",
    },
    {
        "school": "Harmony Elementary",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000011",
    },
    {
        "school": "Velma Linford Elementary",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000014",
    },
    {
        "school": "Rock River Junior High School",
        "district": "Albany County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000017",
    },
    {
        "school": "Slade Elementary",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000020",
    },
    {
        "school": "Valley View Elementary",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000025",
    },
    {
        "school": "Whiting High School",
        "district": "Albany County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000066",
    },
    {
        "school": "Rock River Elementary",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000453",
    },
    {
        "school": "UW Laboratory School",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000535",
    },
    {
        "school": "Arapahoe Charter High School",
        "district": "Fremont County School District #38",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560096000367",
    },
    {
        "school": "Dubois Middle School",
        "district": "Fremont County School District # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560267000366",
    },
    {
        "school": "Rendezvous Elementary",
        "district": "Fremont County School District #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560522000220",
    },
    {
        "school": "Arapahoe Elementary",
        "district": "Fremont County School District #38",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560096000162",
    },
    {
        "school": "Dubois High School",
        "district": "Fremont County School District # 2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560267000151",
    },
    {
        "school": "Dubois Elementary",
        "district": "Fremont County School District # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560267000432",
    },
    {
        "school": "Ft. Washakie Middle School",
        "district": "Fremont County School District #21",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560282000370",
    },
    {
        "school": "Ft. Washakie Elementary",
        "district": "Fremont County School District #21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560282000498",
    },
    {
        "school": "Crowheart Elementary",
        "district": "Fremont County School District # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560283000159",
    },
    {
        "school": "Wind River Elementary",
        "district": "Fremont County School District # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560283000160",
    },
    {
        "school": "Jeffrey City Elementary",
        "district": "Fremont County School District # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560287000074",
    },
    {
        "school": "Pathfinder High School",
        "district": "Fremont County School District # 1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560287000154",
    },
    {
        "school": "Lander Valley High School",
        "district": "Fremont County School District # 1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560287000163",
    },
    {
        "school": "Lander Middle School",
        "district": "Fremont County School District # 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560287000198",
    },
    {
        "school": "Wyoming Indian Elementary",
        "district": "Fremont County School District #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560445000226",
    },
    {
        "school": "Wyoming Indian Middle School",
        "district": "Fremont County School District #14",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560445000386",
    },
    {
        "school": "Wyoming Indian High School",
        "district": "Fremont County School District #14",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560445000441",
    },
    {
        "school": "Riverton High School",
        "district": "Fremont County School District #25",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560522000286",
    },
    {
        "school": "Riverton Middle School",
        "district": "Fremont County School District #25",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560522000287",
    },
    {
        "school": "Shoshoni High School",
        "district": "Fremont County School District #24",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560570000323",
    },
    {
        "school": "Shoshoni Elementary",
        "district": "Fremont County School District #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560570000362",
    },
    {
        "school": "Shoshoni Junior High School",
        "district": "Fremont County School District #24",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560570000510",
    },
    {
        "school": "Thoman Ranch Elementary",
        "district": "Sweetwater County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560576200528",
    },
    {
        "school": "Farson-Eden High School",
        "district": "Sweetwater County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200293",
    },
    {
        "school": "Rock Springs High School",
        "district": "Sweetwater County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200294",
    },
    {
        "school": "Rock Springs Junior High",
        "district": "Sweetwater County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200295",
    },
    {
        "school": "Pilot Butte Elementary",
        "district": "Sweetwater County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200296",
    },
    {
        "school": "Desert Elementary",
        "district": "Sweetwater County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200297",
    },
    {
        "school": "Desert View Elementary",
        "district": "Sweetwater County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200298",
    },
    {
        "school": "Overland Elementary",
        "district": "Sweetwater County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200301",
    },
    {
        "school": "Walnut Elementary",
        "district": "Sweetwater County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200305",
    },
    {
        "school": "Black Butte High School",
        "district": "Sweetwater County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200359",
    },
    {
        "school": "Northpark Elementary",
        "district": "Sweetwater County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200421",
    },
    {
        "school": "Westridge Elementary",
        "district": "Sweetwater County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200422",
    },
    {
        "school": "Farson-Eden Elementary",
        "district": "Sweetwater County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200489",
    },
    {
        "school": "Desert Middle School",
        "district": "Sweetwater County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200523",
    },
    {
        "school": "Farson-Eden Middle School",
        "district": "Sweetwater County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200524",
    },
    {
        "school": "Expedition Academy",
        "district": "Sweetwater County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560576200164",
    },
    {
        "school": "Green River High School",
        "district": "Sweetwater County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560576200324",
    },
    {
        "school": "Granger Elementary",
        "district": "Sweetwater County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560576200326",
    },
    {
        "school": "McKinnon Elementary",
        "district": "Sweetwater County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560576200329",
    },
    {
        "school": "Washington Elementary",
        "district": "Sweetwater County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560576200332",
    },
    {
        "school": "Lincoln Middle School",
        "district": "Sweetwater County School District #2",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560576200399",
    },
    {
        "school": "Truman Elementary",
        "district": "Sweetwater County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560576200425",
    },
    {
        "school": "Normative Services",
        "district": "Normative Services - Administration Office",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WY",
        "nces_id": "560001400225",
    },
    {
        "school": "Arvada Elementary",
        "district": "Sheridan County School District #3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560568000309",
    },
    {
        "school": "Big Horn High School",
        "district": "Sheridan County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569000311",
    },
    {
        "school": "Tongue River High School",
        "district": "Sheridan County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569000312",
    },
    {
        "school": "Tongue River Elementary",
        "district": "Sheridan County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569000314",
    },
    {
        "school": "Big Horn Elementary",
        "district": "Sheridan County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569000395",
    },
    {
        "school": "Big Horn Middle School",
        "district": "Sheridan County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569000446",
    },
    {
        "school": "Tongue River Middle School",
        "district": "Sheridan County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569000447",
    },
    {
        "school": "Slack Elementary",
        "district": "Sheridan County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569000472",
    },
    {
        "school": "The Wright Place",
        "district": "Sheridan County School District #2",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569500140",
    },
    {
        "school": "John C. Schiffer Collaborative School",
        "district": "Sheridan County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569500189",
    },
    {
        "school": "Henry A. Coffeen Elementary",
        "district": "Sheridan County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569500316",
    },
    {
        "school": "Highland Park Elementary",
        "district": "Sheridan County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569500317",
    },
    {
        "school": "Story Elementary",
        "district": "Sheridan County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569500320",
    },
    {
        "school": "Woodland Park Elementary",
        "district": "Sheridan County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569500322",
    },
    {
        "school": "Sheridan High School",
        "district": "Sheridan County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569500360",
    },
    {
        "school": "Sheridan Junior High School",
        "district": "Sheridan County School District #2",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569500361",
    },
    {
        "school": "Meadowlark Elementary",
        "district": "Sheridan County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569500397",
    },
    {
        "school": "Sagebrush Elementary",
        "district": "Sheridan County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569500474",
    },
    {
        "school": "Mill Creek Elementary School",
        "district": "Madison City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000802133",
    },
    {
        "school": "Mac Sim Butler Montgomery County Detention Facility",
        "district": "SafetyNet Academy Minter",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10001502118",
    },
    {
        "school": "Safety Net Academy Montgomery",
        "district": "SafetyNet Academy Minter",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10001502121",
    },
    {
        "school": "Safety Net Academy Montgomery",
        "district": "SafetyNet Academy Minter",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10001502126",
    },
    {
        "school": "Perry Varner Educational and Treatment Facility",
        "district": "SafetyNet Academy Minter",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10001502131",
    },
    {
        "school": "Daniel House",
        "district": "Glenwood Mental Health Service",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003302125",
    },
    {
        "school": "Glenwood Wilderness",
        "district": "Glenwood Mental Health Service",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003302130",
    },
    {
        "school": "POINTE Academy LLC",
        "district": "POINTE Academy LLC",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017502112",
    },
    {
        "school": "Childersburg Boot Camp",
        "district": "JF Ingram State Technical College",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017602108",
    },
    {
        "school": "Draper Correctional Facility",
        "district": "JF Ingram State Technical College",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017602109",
    },
    {
        "school": "Tutwiler Prison",
        "district": "JF Ingram State Technical College",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017602110",
    },
    {
        "school": "W E Donaldson",
        "district": "JF Ingram State Technical College",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017602111",
    },
    {
        "school": "Higdon Hill School",
        "district": "Higdon Hill School",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017802113",
    },
    {
        "school": "The Bridge Inc Mobile",
        "district": "The Bridge",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017902107",
    },
    {
        "school": "Compass School",
        "district": "Compass School",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10018102116",
    },
    {
        "school": "Alabama Clinical Schools",
        "district": "Alabama Clinical Schools",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10018302114",
    },
    {
        "school": "Excel Institute",
        "district": "Excel Institute",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10018402115",
    },
    {
        "school": "Saraland High School",
        "district": "Saraland City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018502137",
    },
    {
        "school": "Richland Elementary School",
        "district": "Auburn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021001879",
    },
    {
        "school": "Spanish Fort Middle School",
        "district": "Baldwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027001888",
    },
    {
        "school": "White Plains Middle School",
        "district": "Calhoun County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054001884",
    },
    {
        "school": "Holly Pond Middle",
        "district": "Cullman County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10102002132",
    },
    {
        "school": "Haleyville Middle School",
        "district": "Haleyville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10172001885",
    },
    {
        "school": "Henry County Virtual Campus",
        "district": "Henry County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10174002120",
    },
    {
        "school": "Irondale Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192002117",
    },
    {
        "school": "North Mobile County Middle School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237002136",
    },
    {
        "school": "Williams Intermediate School",
        "district": "Pell City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10265001883",
    },
    {
        "school": "Helena Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303002128",
    },
    {
        "school": "Tarrant Intermediate School",
        "district": "Tarrant City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10327002138",
    },
    {
        "school": "Northridge Middle School",
        "district": "Tuscaloosa City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336001889",
    },
    {
        "school": "Southview Elementary School",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336002134",
    },
    {
        "school": "Northport Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001880",
    },
    {
        "school": "Duncanville Middle School",
        "district": "Tuscaloosa County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001882",
    },
    {
        "school": "Lake View Elementary School",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339001887",
    },
    {
        "school": "Liberty Park Middle School",
        "district": "Vestavia Hills City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10343002135",
    },
    {
        "school": "Nicholas J. Begich Middle School",
        "district": "Anchorage School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000729",
    },
    {
        "school": "Rilke Schule Charter School",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000732",
    },
    {
        "school": "River City Academy",
        "district": "Kenai Peninsula Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000735",
    },
    {
        "school": "Mat-Su Career & Tech Ed High School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AK",
        "nces_id": "20051000731",
    },
    {
        "school": "Knik Elementary School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000733",
    },
    {
        "school": "Mat-Su Day School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Other",
        "type": "Special education school",
        "state": "AK",
        "nces_id": "20051000734",
    },
    {
        "school": "Ombudsman - Charter East II",
        "district": "Ombudsman Educational Services Ltd.a subsidiary  (4323)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40010302855",
    },
    {
        "school": "VACTE - Cottonwood-Oak Creek Unified School District",
        "district": "Valley Academy for Career and Technology Education (79397)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034102853",
    },
    {
        "school": "VACTE - Clarkdale Jerome School District",
        "district": "Valley Academy for Career and Technology Education (79397)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034102858",
    },
    {
        "school": "CAVIT - Casa Verde High School",
        "district": "Central Arizona Valley Institute of Technology (79385)",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034802876",
    },
    {
        "school": "Desert View Online School",
        "district": "Carpe Diem Collegiate High School (80001)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40038102866",
    },
    {
        "school": "Leading Edge Academy at East Mesa",
        "district": "LEAD Charter Schools (79967)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40039502826",
    },
    {
        "school": "Academy Adventures Mid-town",
        "district": "Educational Impact Inc. (81123)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40061302861",
    },
    {
        "school": "West-MEC - Peoria Transition Center",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502804",
    },
    {
        "school": "West-MEC - Youngker High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502824",
    },
    {
        "school": "West-MEC - Virtual Learning Academy",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502863",
    },
    {
        "school": "West-MEC - Metrocenter Academy",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061502879",
    },
    {
        "school": "Legacy Traditional School - Maricopa",
        "district": "Legacy Traditional School - Maricopa (88360)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40074502856",
    },
    {
        "school": "Eduprize School",
        "district": "Eduprize Schools LLC (89412)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40074602864",
    },
    {
        "school": "Great Hearts Academies - Scottsdale Prep",
        "district": "Scottsdale Preparatory Academy (89756)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40074702795",
    },
    {
        "school": "Sage Academy",
        "district": "Sage Academy Inc. (89414)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40074802870",
    },
    {
        "school": "Concordia Charter School",
        "district": "Concordia Charter School Inc. (89556)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40075102781",
    },
    {
        "school": "Eastern Sky Community Charter School",
        "district": "Concordia Charter School Inc. (89556)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40075102850",
    },
    {
        "school": "PCJTED - Baboquivari High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202767",
    },
    {
        "school": "PCJTED - Canyon Del Oro High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202772",
    },
    {
        "school": "PCJTED - Desert View High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202773",
    },
    {
        "school": "PCJTED - Cholla High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202774",
    },
    {
        "school": "PCJTED - Aztec Middle College",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202776",
    },
    {
        "school": "PCJTED - Tucson High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202778",
    },
    {
        "school": "PCJTED - Vail High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202790",
    },
    {
        "school": "PCJTED - Ajo High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202792",
    },
    {
        "school": "PCJTED - Amphitheater High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202793",
    },
    {
        "school": "PCJTED - University High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202796",
    },
    {
        "school": "PCJTED - Catalina Foothills High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202797",
    },
    {
        "school": "PCJTED - Sahuaro High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202801",
    },
    {
        "school": "PCJTED - Mountain View High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202803",
    },
    {
        "school": "PCJTED - Cienega High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202807",
    },
    {
        "school": "PCJTED - Palo Verde High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202809",
    },
    {
        "school": "PCJTED - Pueblo High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202810",
    },
    {
        "school": "PCJTED - Tanque Verde High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202814",
    },
    {
        "school": "PCJTED - Rincon High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202815",
    },
    {
        "school": "PCJTED - Flowing Wells High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202817",
    },
    {
        "school": "PCJTED - Central Campus",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202823",
    },
    {
        "school": "PCJTED - Sunnyside High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202828",
    },
    {
        "school": "PCJTED - Empire High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202830",
    },
    {
        "school": "PCJTED - Catalina High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202831",
    },
    {
        "school": "PCJTED - Santa Rita High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202834",
    },
    {
        "school": "PCJTED - Sahuarita High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202839",
    },
    {
        "school": "PCJTED - Ironwood Ridge High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202841",
    },
    {
        "school": "PCJTED - Marana High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202843",
    },
    {
        "school": "PCJTED - Howenstine High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202847",
    },
    {
        "school": "PCJTED - Sabino High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202848",
    },
    {
        "school": "PCJTED - Aztec Middle College East",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202852",
    },
    {
        "school": "PCJTED - Aztec Middle College North West",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202860",
    },
    {
        "school": "PCJTED - Aztec Middle College Desert Vista",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202868",
    },
    {
        "school": "PCJTED - Project MORE",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202877",
    },
    {
        "school": "Imagine Desert West Middle",
        "district": "Imagine Desert West Middle Inc. (89563)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40075402819",
    },
    {
        "school": "Freedom Academy",
        "district": "Freedom Academy Inc. (89506)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40075502371",
    },
    {
        "school": "Imagine Camelback Middle",
        "district": "Imagine Camelback Middle Inc. (89561)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40075602813",
    },
    {
        "school": "Great Hearts Academies - Arete Prep",
        "district": "Arete Preparatory Academy (89486)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40075702820",
    },
    {
        "school": "Candeo Peoria",
        "district": "Candeo Schools Inc. (89758)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40075802766",
    },
    {
        "school": "Steven R. Jasinski Elementary School",
        "district": "Buckeye Elementary District (4269)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40138002836",
    },
    {
        "school": "Youngker High School",
        "district": "Buckeye Union High School District (4284)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40141002786",
    },
    {
        "school": "McCartney Ranch Elementary School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171002865",
    },
    {
        "school": "Villago Middle School",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171002872",
    },
    {
        "school": "Perry High School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002806",
    },
    {
        "school": "Arizona College Prep Erie Campus",
        "district": "Chandler Unified District #80 (4242)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002822",
    },
    {
        "school": "Riggs Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002873",
    },
    {
        "school": "Ira A. Fulton Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002878",
    },
    {
        "school": "Heartland Ranch Elementary School",
        "district": "Coolidge Unified District (4442)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40232002800",
    },
    {
        "school": "Mesquite Elementary",
        "district": "Crane Elementary District (4501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240002779",
    },
    {
        "school": "Mountain View",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002780",
    },
    {
        "school": "Canyon Ridge School",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002837",
    },
    {
        "school": "Circle Cross K8 STEM Academy",
        "district": "Florence Unified School District (4437)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292002862",
    },
    {
        "school": "Quartz Hill Elementary",
        "district": "Gilbert Unified District (4239)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340002833",
    },
    {
        "school": "Gilbert Classical Academy 7-12",
        "district": "Gilbert Unified District (4239)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340002840",
    },
    {
        "school": "Chaparral Elementary School",
        "district": "Higley Unified School District (4248)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378002805",
    },
    {
        "school": "Williams Field High School",
        "district": "Higley Unified School District (4248)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378002835",
    },
    {
        "school": "Ellsworth Elementary School",
        "district": "J O Combs Unified School District (4445)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40399002811",
    },
    {
        "school": "Desert Meadows Elementary School",
        "district": "Laveen Elementary District (4276)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40429002769",
    },
    {
        "school": "Trailside Point Performing Arts Academy",
        "district": "Laveen Elementary District (4276)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40429002845",
    },
    {
        "school": "Verrado Elementary School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438002782",
    },
    {
        "school": "Estrella Vista Elementary School",
        "district": "Littleton Elementary District (4278)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40444002771",
    },
    {
        "school": "Madison Traditional Academy",
        "district": "Madison Elementary District (4270)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40450002874",
    },
    {
        "school": "Rattlesnake Ridge Elementary",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463002784",
    },
    {
        "school": "Mesa Academy for Advanced Studies",
        "district": "Mesa Unified District (4235)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497002770",
    },
    {
        "school": "M.U.S.D. #40 - Little Vandal Preschool",
        "district": "Miami Unified District (4211)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40503002789",
    },
    {
        "school": "Desert Oasis Elementary School",
        "district": "Nadaburg Unified School District (4252)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40546002875",
    },
    {
        "school": "Cholla Complex",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593002842",
    },
    {
        "school": "Betty Fairfax High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633002854",
    },
    {
        "school": "Franklin Police and Fire High School",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633002859",
    },
    {
        "school": "Red Valley/Cove High School",
        "district": "Red Mesa Unified District (4159)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40687002867",
    },
    {
        "school": "San Carlos Alternative High School",
        "district": "San Carlos Unified District (4210)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40696002788",
    },
    {
        "school": "Winters Well Elementary School",
        "district": "Saddle Mountain Unified School District (4254)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40717002808",
    },
    {
        "school": "Tartesso Elementary School",
        "district": "Saddle Mountain Unified School District (4254)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40717002812",
    },
    {
        "school": "Anza Trail",
        "district": "Sahuarita Unified District (4411)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40730002818",
    },
    {
        "school": "Coatimundi Middle School",
        "district": "Santa Cruz Valley Unified District (4458)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40752002768",
    },
    {
        "school": "PPEP Youth Build",
        "district": "Somerton Elementary District (4500)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40789002832",
    },
    {
        "school": "St. Johns Learning Center",
        "district": "St Johns Unified District (4153)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40808002871",
    },
    {
        "school": "Rivera Elementary",
        "district": "Sunnyside Unified District (4407)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817002849",
    },
    {
        "school": "Dos Rios Elementary",
        "district": "Union Elementary District (4277)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40882002794",
    },
    {
        "school": "Ocotillo Ridge Elementary",
        "district": "Vail Unified District (4413)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885002765",
    },
    {
        "school": "Senita Valley Elementary School",
        "district": "Vail Unified District (4413)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885002798",
    },
    {
        "school": "Festival Foothills Elementary School",
        "district": "Wickenburg Unified District (4236)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40919002827",
    },
    {
        "school": "Gila Ridge High School",
        "district": "Yuma Union High School District (4507)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40963002775",
    },
    {
        "school": "EVIT - Williams Field High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102785",
    },
    {
        "school": "EVIT - Perry High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102821",
    },
    {
        "school": "EVIT - Compadre High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102825",
    },
    {
        "school": "KIPP DELTA COLLEGIATE HIGH SCHOOL",
        "district": "KIPP DELTA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006201451",
    },
    {
        "school": "ARKANSAS VIRTUAL ACADEMY JR",
        "district": "ARKANSAS VIRTUAL ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039401447",
    },
    {
        "school": "ARKANSAS VIRTUAL ACADEMY",
        "district": "ARKANSAS VIRTUAL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039401461",
    },
    {
        "school": "ESTEM PUBLIC CHARTER HIGH SCHOOL",
        "district": "ESTEM HIGH CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039801470",
    },
    {
        "school": "COOPER ELEMENTARY SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001462",
    },
    {
        "school": "BROOKLAND MIDDLE SCHOOL",
        "district": "BROOKLAND SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50364001458",
    },
    {
        "school": "HURRICANE CREEK ELEMENTARY",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369001450",
    },
    {
        "school": "STAGECOACH ELEMENTARY SCHOOL",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375001445",
    },
    {
        "school": "CAVE CITY MIDDLE SCHOOL",
        "district": "CAVE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50405001457",
    },
    {
        "school": "JESSIEVILLE MIDDLE SCHOOL",
        "district": "JESSIEVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50792001464",
    },
    {
        "school": "CHICOT ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001463",
    },
    {
        "school": "WATSON ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001474",
    },
    {
        "school": "PLEASANT VIEW JUNIOR HIGH",
        "district": "MULBERRY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51029001454",
    },
    {
        "school": "MONITOR ELEMENTARY",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001452",
    },
    {
        "school": "WILLIS SHAW ELEMENTARY SCH",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001453",
    },
    {
        "school": "Canyon Ridge High",
        "district": "Hesperia Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60001412100",
    },
    {
        "school": "Cedar Middle",
        "district": "Hesperia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001412103",
    },
    {
        "school": "Mission Crest Elementary",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001412171",
    },
    {
        "school": "John Green Elementary",
        "district": "Dublin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001912078",
    },
    {
        "school": "Keith McCarthy Academy",
        "district": "Lake Elsinore Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60002712094",
    },
    {
        "school": "Redondo Beach Learning Academy",
        "district": "Redondo Beach Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60003212165",
    },
    {
        "school": "George and Evelyn Stein Continuation",
        "district": "Tracy Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004712105",
    },
    {
        "school": "Walnut Elementary Education Center",
        "district": "Turlock Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015812175",
    },
    {
        "school": "Etna Elementary",
        "district": "Scott Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015901473",
    },
    {
        "school": "Etna Union High",
        "district": "Scott Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015901474",
    },
    {
        "school": "Fort Jones Elementary",
        "district": "Scott Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015901615",
    },
    {
        "school": "Scott River High",
        "district": "Scott Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60015904089",
    },
    {
        "school": "Scott Valley Junior High",
        "district": "Scott Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60015908834",
    },
    {
        "school": "Scott Valley Community Day",
        "district": "Scott Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60015910426",
    },
    {
        "school": "Yosemite Falls Education Center",
        "district": "Yosemite Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60016012074",
    },
    {
        "school": "Campbell High Community Day",
        "district": "Yosemite Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60016012129",
    },
    {
        "school": "Russo/McEntee Academy",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60231012063",
    },
    {
        "school": "Carl Hankey Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744012093",
    },
    {
        "school": "Pathway Community Day",
        "district": "Central Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60797012076",
    },
    {
        "school": "Ocean Air",
        "district": "Del Mar Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61074012091",
    },
    {
        "school": "Robert F. Kennedy High",
        "district": "Delano Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61086012157",
    },
    {
        "school": "Summit High (Continuation)",
        "district": "Desert Sands Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61111012080",
    },
    {
        "school": "Sunrise Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233012101",
    },
    {
        "school": "Evergreen Community Day School (K-5)",
        "district": "Evergreen Union",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61317012160",
    },
    {
        "school": "Santa Margarita Academy",
        "district": "Fallbrook Union Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61350012099",
    },
    {
        "school": "Great Partnership Special Education Consortium",
        "district": "Gateway Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61495012116",
    },
    {
        "school": "Dr. TJ Owens Gilroy Early College Academy",
        "district": "Gilroy Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518012174",
    },
    {
        "school": "Hollister Dual Language Academy",
        "district": "Hollister",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61734012075",
    },
    {
        "school": "Patriot High",
        "district": "Jurupa Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926012095",
    },
    {
        "school": "Independence High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954012132",
    },
    {
        "school": "Mira Monte High",
        "district": "Kern High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61954012155",
    },
    {
        "school": "Island Community Day",
        "district": "Kingsburg Elementary Charter",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61980012097",
    },
    {
        "school": "Quest Academy",
        "district": "La Mesa-Spring Valley",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62025012168",
    },
    {
        "school": "Lakeport Community Day",
        "district": "Lakeport Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62067012081",
    },
    {
        "school": "Mariposa School of Global Education",
        "district": "Las Virgenes Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62100012182",
    },
    {
        "school": "Lindsey Academy",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250012117",
    },
    {
        "school": "Dooley Elementary",
        "district": "Long Beach Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250012153",
    },
    {
        "school": "West Adams Preparatory High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012114",
    },
    {
        "school": "John H. Liechty Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012144",
    },
    {
        "school": "ROP Center",
        "district": "Los Angeles Unified",
        "level": "Adult Education",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "62271012158",
    },
    {
        "school": "Pathway Independent Study",
        "district": "Lynwood Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62316012156",
    },
    {
        "school": "Lathrop High",
        "district": "Manteca Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361012065",
    },
    {
        "school": "California City High",
        "district": "Mojave Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62523012107",
    },
    {
        "school": "Monterey Peninsula UNF SCH",
        "district": "Monterey Peninsula Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62553012178",
    },
    {
        "school": "West Oakland Middle",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805012048",
    },
    {
        "school": "Oakland International High",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62805012049",
    },
    {
        "school": "Global Family",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805012053",
    },
    {
        "school": "Greenleaf Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805012055",
    },
    {
        "school": "Futures Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805012057",
    },
    {
        "school": "Community United Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805012058",
    },
    {
        "school": "East Oakland Pride Elementary",
        "district": "Oakland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805012059",
    },
    {
        "school": "OUSD Community Day",
        "district": "Orange Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62865012123",
    },
    {
        "school": "Pixley Middle",
        "district": "Pixley Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63063012170",
    },
    {
        "school": "Cobblestone Elementary",
        "district": "Plumas Lake Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63118012166",
    },
    {
        "school": "School of Extended Educational Options",
        "district": "Pomona Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63132012112",
    },
    {
        "school": "Riverside Virtual",
        "district": "Riverside Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315012176",
    },
    {
        "school": "Ethan A Chase Middle",
        "district": "Romoland Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63339012127",
    },
    {
        "school": "School of Engineering & Sciences",
        "district": "Sacramento City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63384012139",
    },
    {
        "school": "Colonel Joseph C. Rodriguez PREP Academy",
        "district": "San Bernardino City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417012143",
    },
    {
        "school": "Bing Wong Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417012181",
    },
    {
        "school": "Hector G. Godinez",
        "district": "Santa Ana Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531012133",
    },
    {
        "school": "Valentine Peyton Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801012085",
    },
    {
        "school": "Edward C. Merlo Institute of Environmental Studies",
        "district": "Stockton Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63801012098",
    },
    {
        "school": "Strathmore Elementary",
        "district": "Strathmore Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63813012108",
    },
    {
        "school": "East Hills Academy",
        "district": "Sweetwater Union High",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63864012173",
    },
    {
        "school": "Mission Oak High",
        "district": "Tulare Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63993012084",
    },
    {
        "school": "Vallejo Charter",
        "district": "Vallejo City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64074012088",
    },
    {
        "school": "Vista Magnet Middle School of Technology Science and Math",
        "district": "Vista Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64119012147",
    },
    {
        "school": "Major General Raymond Murray High",
        "district": "Vista Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64119012180",
    },
    {
        "school": "Stonegate Elementary",
        "district": "Washington Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64158012071",
    },
    {
        "school": "Washington Middle College High",
        "district": "Washington Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64158012111",
    },
    {
        "school": "Farmdale Elementary",
        "district": "Weaver Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64188012082",
    },
    {
        "school": "Early Childhood Learning Center",
        "district": "Irvine Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450012137",
    },
    {
        "school": "Irvine Adult Transition Programs",
        "district": "Irvine Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "68450012151",
    },
    {
        "school": "Napa Preschool Program",
        "district": "Napa County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102212072",
    },
    {
        "school": "San Pasqual Academy",
        "district": "San Diego County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103012159",
    },
    {
        "school": "CAPROCK ACADEMY",
        "district": "State Charter School Institute",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006305",
    },
    {
        "school": "COLORADO SPRINGS EARLY COLLEGES",
        "district": "State Charter School Institute",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006310",
    },
    {
        "school": "RICARDO FLORES MAGON ACADEMY",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006320",
    },
    {
        "school": "CHINOOK TRAIL ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006329",
    },
    {
        "school": "RANCH CREEK ELEMENTARY",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006336",
    },
    {
        "school": "GLOBAL VILLAGE ACADEMY AURORA",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006318",
    },
    {
        "school": "VANGUARD CLASSICAL SCHOOL - WEST",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006322",
    },
    {
        "school": "LANDMARK ACADEMY AT REUNION",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006325",
    },
    {
        "school": "WEST RIDGE ELEMENTARY",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006326",
    },
    {
        "school": "ADAMS YOUTH SERVICE CENTER",
        "district": "School District 27J",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80258006343",
    },
    {
        "school": "BUFFALO TRAIL ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006301",
    },
    {
        "school": "MARVIN W FOOTE YOUTH SERVICES",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80291006344",
    },
    {
        "school": "FREEDOM ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CO",
        "nces_id": "80306006317",
    },
    {
        "school": "MCAULIFFE ELEMENTARY",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306006319",
    },
    {
        "school": "MANUAL HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006328",
    },
    {
        "school": "WILLIAM (BILL) ROBERTS ECE-8 SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006332",
    },
    {
        "school": "GILLIAM SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006345",
    },
    {
        "school": "ROXBOROUGH INTERMEDIATE",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006299",
    },
    {
        "school": "STONE MOUNTAIN ELEMENTARY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006309",
    },
    {
        "school": "MAMMOTH HEIGHTS ELEMENTARY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006337",
    },
    {
        "school": "LONE TREE ELEMENTARY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006341",
    },
    {
        "school": "ROBERT DENIER YOUTH SERVICES CENTER",
        "district": "Durango School District No. 9-R",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80348006353",
    },
    {
        "school": "ENGLEWOOD MIDDLE SCHOOL",
        "district": "Englewood School District No. 1 in the county of Arapahoe",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80378006331",
    },
    {
        "school": "RICE ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399006315",
    },
    {
        "school": "POLARIS EXPEDITIONARY LEARNING SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80399006334",
    },
    {
        "school": "EAGLESIDE ELEMENTARY SCHOOL",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80408006330",
    },
    {
        "school": "GRAND MESA YOUTH SERVICES CENTER",
        "district": "Mesa County Valley School District No. 51",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80435006346",
    },
    {
        "school": "PLATTE VALLEY YOUTH SERVICES CENTER",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80441006355",
    },
    {
        "school": "PRAIRIE HEIGHTS ELEMENTARY SCHOOL",
        "district": "Hanover School District No. 28 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80450006304",
    },
    {
        "school": "CONNECTIONS LEARNING CENTER ON THE EARLE JOHNSON C",
        "district": "Jefferson County School District No. R-1",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80480006306",
    },
    {
        "school": "SOBESKY ACADEMY",
        "district": "Jefferson County School District No. R-1",
        "level": "Other",
        "type": "Special education school",
        "state": "CO",
        "nces_id": "80480006307",
    },
    {
        "school": "MOUNTAIN PHOENIX COMMUNITY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006311",
    },
    {
        "school": "MOUNTVIEW YOUTH SERVICE CENTER",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80480006347",
    },
    {
        "school": "PUEBLO YOUTH SERVICE CENTER",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80612006350",
    },
    {
        "school": "CAMPBELL ELEMENTARY SCHOOL",
        "district": "School District No. Re-1 Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80669006323",
    },
    {
        "school": "AYRES ELEMENTARY SCHOOL",
        "district": "School District No. Re-1 Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80669006339",
    },
    {
        "school": "STELLAR ELEMENTARY SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690006303",
    },
    {
        "school": "Highville Charter School",
        "district": "Highville Charter School District",
        "level": "Other",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90020700907",
    },
    {
        "school": "Achievement First Bridgeport Academy",
        "district": "Achievement First Bridgeport Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90020801493",
    },
    {
        "school": "Greater Hartford Academy of  the Arts High School - Full Tim",
        "district": "Capitol Region Education Council",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001497",
    },
    {
        "school": "Arts at the Capitol Theater Magnet School (ACT)",
        "district": "Eastern Connecticut Regional Educational Service Center",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90136001507",
    },
    {
        "school": "Northeast Academy Elementary School",
        "district": "GROTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90177001488",
    },
    {
        "school": "Catherine Kolnaski Magnet School",
        "district": "GROTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90177001494",
    },
    {
        "school": "Oxford High School",
        "district": "OXFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90324001504",
    },
    {
        "school": "Stafford Elementary School",
        "district": "STAFFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90429001503",
    },
    {
        "school": "Sterling Community School",
        "district": "STERLING SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90435001491",
    },
    {
        "school": "Townsend Early Childhood Center",
        "district": "Appoquinimink School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000314",
    },
    {
        "school": "Millsboro Middle School",
        "district": "Indian River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000303",
    },
    {
        "school": "Friendship PCS - Southeast ES",
        "district": "Friendship PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800382",
    },
    {
        "school": "Maya Angelou PCS - HS",
        "district": "Maya Angelou PCS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "DC",
        "nces_id": "110001400391",
    },
    {
        "school": "KIPP DC - LEAP Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100375",
    },
    {
        "school": "KIPP DC - WILL Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100376",
    },
    {
        "school": "KIPP DC - AIM Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100381",
    },
    {
        "school": "DC Prep PCS - Benning ES",
        "district": "DC Prep PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004800387",
    },
    {
        "school": "DC Prep PCS - Edgewood ES",
        "district": "DC Prep PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004800388",
    },
    {
        "school": "Hope Community PCS - Tolson",
        "district": "Hope Community PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110005100386",
    },
    {
        "school": "PALM BAY PREPARATORY ACADEMY 6-12",
        "district": "BAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009007472",
    },
    {
        "school": "MEADOWLANE INTERMEDIATE ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015007391",
    },
    {
        "school": "BEN GAMLA CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018006981",
    },
    {
        "school": "DISCOVERY ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007250",
    },
    {
        "school": "INTERNATIONAL SCHOOL OF BROWARD",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007300",
    },
    {
        "school": "RISE ACADEMY SCHOOL OF SCIENCE AND TECHNOLOGY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007464",
    },
    {
        "school": "CHARTER SCHOOL OF EXCELLENCE AT DAVIE",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007476",
    },
    {
        "school": "CENTRAL RIDGE ELEMENTARY SCHOOL",
        "district": "CITRUS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027006894",
    },
    {
        "school": "OAKLEAF VILLAGE ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030007243",
    },
    {
        "school": "SHADOWLAWN ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030007389",
    },
    {
        "school": "PLANTATION OAKS ELEMENTARY SCHOOL",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030007450",
    },
    {
        "school": "PALMETTO ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033007276",
    },
    {
        "school": "IMMOKALEE TECHNICAL COLLEGE",
        "district": "COLLIER",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120033007304",
    },
    {
        "school": "EDEN PARK ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033007371",
    },
    {
        "school": "MIKE DAVIS ELEMENTARY SCHOOL",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033007423",
    },
    {
        "school": "PINEMOUNT ELEMENTARY SCHOOL",
        "district": "COLUMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036007330",
    },
    {
        "school": "AVENTURA WATERWAYS K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007241",
    },
    {
        "school": "MATER ACADEMY EAST CHARTER HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007242",
    },
    {
        "school": "MIAMI COMMUNITY CHARTER MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007248",
    },
    {
        "school": "BEN GAMLA CHARTER SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007271",
    },
    {
        "school": "TURNER/GUILFORD/KNIGHT",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007278",
    },
    {
        "school": "RICHMOND PERRINE OPTIMIST",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007286",
    },
    {
        "school": "GOULDS ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007290",
    },
    {
        "school": "JORGE MAS CANOSA MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007291",
    },
    {
        "school": "BOYSTOWN",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007318",
    },
    {
        "school": "EXCELSIOR CHARTER ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007319",
    },
    {
        "school": "SPANISH LAKE ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007322",
    },
    {
        "school": "HERE'S HELP",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007352",
    },
    {
        "school": "SCHOOL FOR ADVANCED STUDIES HOMESTEAD",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007358",
    },
    {
        "school": "MANDARIN LAKES K-8 ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007377",
    },
    {
        "school": "SOMERSET ACADEMY CHARTER MIDDLE SCHOOL (SOUTH HOMESTEAD)",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007387",
    },
    {
        "school": "HIALEAH GARDENS MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007396",
    },
    {
        "school": "EXCELSIOR LANGUAGE ACADEMY OF HIALEAH",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007416",
    },
    {
        "school": "YOUNG MEN'S PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007420",
    },
    {
        "school": "SOMERSET ACADEMY SILVER PALMS",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007428",
    },
    {
        "school": "JACKSON SIPP/CHILD CRISIS",
        "district": "MIAMI-DADE",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007437",
    },
    {
        "school": "MIAMI BRIDGE NORTH",
        "district": "MIAMI-DADE",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007445",
    },
    {
        "school": "MIAMI BRIDGE SOUTH",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007447",
    },
    {
        "school": "PINECREST PREPARATORY ACADEMY CHARTER HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007453",
    },
    {
        "school": "CITY OF HIALEAH EDUCATION ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007454",
    },
    {
        "school": "ARCHIMEDEAN UPPER CONSERVATORY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007456",
    },
    {
        "school": "SOMERSET ACADEMY CHARTER ELEMENTARY SCHOOL (SOUTH HOMESTEAD)",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007466",
    },
    {
        "school": "MATER INTERNATIONAL PREPARATORY",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007484",
    },
    {
        "school": "MATER ACADEMY OF INTERNATIONAL STUDIES",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007485",
    },
    {
        "school": "SOMERSET ARTS ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007487",
    },
    {
        "school": "DESOTO SECONDARY SCHOOL",
        "district": "DESOTO",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120042006813",
    },
    {
        "school": "CHAFFEE TRAIL ELEMENTARY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048006904",
    },
    {
        "school": "TIGER ACADEMY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007273",
    },
    {
        "school": "RIVER CITY SCIENCE ACADEMY",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007418",
    },
    {
        "school": "ESE PRE KINDERGARTEN DISABILITIES CENTER",
        "district": "DUVAL",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120048007446",
    },
    {
        "school": "IMAGINE SCHOOL AT TOWN CENTER",
        "district": "FLAGLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054007480",
    },
    {
        "school": "WEEKI WACHEE HIGH SCHOOL",
        "district": "HERNANDO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081006808",
    },
    {
        "school": "EXPLORER K-8",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081007491",
    },
    {
        "school": "MEMORIAL ELEMENTARY SCHOOL",
        "district": "HIGHLANDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084007327",
    },
    {
        "school": "THE KINDERGARTEN LEARNING CENTER",
        "district": "HIGHLANDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084007362",
    },
    {
        "school": "BAILEY ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087006817",
    },
    {
        "school": "INDEPENDENCE ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087006873",
    },
    {
        "school": "BARRINGTON MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087006912",
    },
    {
        "school": "STEINBRENNER HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087006917",
    },
    {
        "school": "FLORIDA AUTISM CHARTER SCHOOL OF EXCELLENCE",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087006958",
    },
    {
        "school": "BROOKS DEBARTOLO COLLEGIATE HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087006987",
    },
    {
        "school": "STRAWBERRY CREST HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007001",
    },
    {
        "school": "STOWERS ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007252",
    },
    {
        "school": "SERGEANT PAUL R SMITH MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007336",
    },
    {
        "school": "COMMUNITY CHARTER SCHOOL OF EXCELLENCE",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007474",
    },
    {
        "school": "KIMBELL ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007493",
    },
    {
        "school": "REDDICK ELEMENTARY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007494",
    },
    {
        "school": "IMAGINE AT SOUTH VERO",
        "district": "INDIAN RIVER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093007488",
    },
    {
        "school": "GRASSY LAKE ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105006998",
    },
    {
        "school": "EAST RIDGE MIDDLE SCHOOL",
        "district": "LAKE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105007239",
    },
    {
        "school": "SAWGRASS BAY ELEMENTARY SCHOOL",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105007372",
    },
    {
        "school": "SW FL ADDICTION SERVICES-THE VINCE SMITH CENTER",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108006891",
    },
    {
        "school": "TREELINE ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007321",
    },
    {
        "school": "PATRIOT ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007328",
    },
    {
        "school": "ISLAND COAST HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007353",
    },
    {
        "school": "OAK HAMMOCK MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007395",
    },
    {
        "school": "OASIS CHARTER HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007441",
    },
    {
        "school": "NORTH NICHOLAS HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108007461",
    },
    {
        "school": "CORONADO HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108007465",
    },
    {
        "school": "GATEWAY CHARTER INTERMEDIATE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007470",
    },
    {
        "school": "WILLIAM J MONTFORD III MIDDLE SCHOOL",
        "district": "LEON",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111006856",
    },
    {
        "school": "J MICHAEL CONLEY ELEMENTARY SCHOOL AT SOUTHWOOD",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111006879",
    },
    {
        "school": "BUFFALO CREEK MIDDLE SCHOOL",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123007312",
    },
    {
        "school": "B.D. GULLETT ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123007315",
    },
    {
        "school": "ANNIE LUCY WILLIAMS ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123007368",
    },
    {
        "school": "IMAGINE CHARTER AT LAKEWOOD RANCH",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123007475",
    },
    {
        "school": "HORIZON ACADEMY AT MARION OAKS",
        "district": "MARION",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126007398",
    },
    {
        "school": "FRANCIS MARION MILITARY ACADEMY",
        "district": "MARION",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126007489",
    },
    {
        "school": "CITRUS GROVE ELEMENTARY",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129007264",
    },
    {
        "school": "TIMBER LAKES ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007434",
    },
    {
        "school": "PROSPERITAS LEADERSHIP ACADEMY CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144007442",
    },
    {
        "school": "ALOMA HIGH CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144007455",
    },
    {
        "school": "ORLANDO SCIENCE MIDDLE HIGH CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007458",
    },
    {
        "school": "UCP EAST CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144007459",
    },
    {
        "school": "NEPTUNE ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147007373",
    },
    {
        "school": "LIBERTY HIGH SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147007417",
    },
    {
        "school": "PALM BEACH VIRTUAL FRANCHISE",
        "district": "PALM BEACH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150007287",
    },
    {
        "school": "EMERALD COVE MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150007400",
    },
    {
        "school": "NEW RIVER ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007289",
    },
    {
        "school": "CHARLES S. RUSHE MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007326",
    },
    {
        "school": "SUNLAKE HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007331",
    },
    {
        "school": "CREWS LAKE MIDDLE SCHOOL.",
        "district": "PASCO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007339",
    },
    {
        "school": "VETERANS ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007385",
    },
    {
        "school": "GULF TRACE ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007406",
    },
    {
        "school": "IMAGINE SCHOOL AT LAND O' LAKES",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007452",
    },
    {
        "school": "ALFRED ADLER ELEMENTARY SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156007479",
    },
    {
        "school": "ENTERPRISE CHARTER HIGH SCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156007482",
    },
    {
        "school": "LAUREL ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159006951",
    },
    {
        "school": "BOK ACADEMY",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159006968",
    },
    {
        "school": "SPESSARD L HOLLAND ELEMENTARY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159007262",
    },
    {
        "school": "TENOROC HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159007310",
    },
    {
        "school": "HORIZONS ELEMENTARY SCHOOL",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159007399",
    },
    {
        "school": "SUNCOAST POLYTECHNICAL HIGH SCHOOL",
        "district": "SARASOTA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168007003",
    },
    {
        "school": "WOODLAND MIDDLE SCHOOL",
        "district": "SARASOTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168007410",
    },
    {
        "school": "IMAGINE SCHOOL AT NORTH PORT",
        "district": "SARASOTA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168007469",
    },
    {
        "school": "PONTE VEDRA HIGH SCHOOL",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174007246",
    },
    {
        "school": "WARDS CREEK ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174007272",
    },
    {
        "school": "PACETTI BAY MIDDLE SCHOOL",
        "district": "ST. JOHNS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174007334",
    },
    {
        "school": "CREEKSIDE HIGH SCHOOL",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174007388",
    },
    {
        "school": "SAMUEL S. GAINES ACADEMY OF EMERGING TECHNOLOGIES",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177006816",
    },
    {
        "school": "ALLAPATTAH FLATS K-8",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177006839",
    },
    {
        "school": "RIVER SPRINGS MIDDLE SCHOOL",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192006999",
    },
    {
        "school": "UNIVERSITY HIGH SCHOOL",
        "district": "VOLUSIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192007281",
    },
    {
        "school": "PRIDE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192007444",
    },
    {
        "school": "RIVERSINK ELEMENTARY SCHOOL",
        "district": "WAKULLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195007429",
    },
    {
        "school": "MOSSY HEAD SCHOOL",
        "district": "WALTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198007324",
    },
    {
        "school": "FAU/SLCSD PALM POINTE EDUCATIONAL RESEARCH SCHOOL @ TRADITIO",
        "district": "FAU LAB SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201207467",
    },
    {
        "school": "B.E.S.T Academy",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003558",
    },
    {
        "school": "Wesley International Academy Charter Facility",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003589",
    },
    {
        "school": "Mountain Education Charter High School",
        "district": "State Charter Schools- Mountain Education Center School",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130021403723",
    },
    {
        "school": "Pine Log Elementary",
        "district": "Bartow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130033003586",
    },
    {
        "school": "Nevils Elementary School",
        "district": "Bulloch County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063003549",
    },
    {
        "school": "Southeast Bulloch High School",
        "district": "Bulloch County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130063003550",
    },
    {
        "school": "Mt. Zion Middle School",
        "district": "Carroll County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084003562",
    },
    {
        "school": "Mt. Zion High School",
        "district": "Carroll County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084003582",
    },
    {
        "school": "Cedar Ridge Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141003554",
    },
    {
        "school": "Factory Shoals Middle School",
        "district": "Douglas County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186003557",
    },
    {
        "school": "Oakley Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003561",
    },
    {
        "school": "Renaissance Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003563",
    },
    {
        "school": "LAKE OCONEE CHARTER",
        "district": "Greene County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130249003570",
    },
    {
        "school": "AZ Kelsey Academy",
        "district": "Griffin-Spalding County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252003588",
    },
    {
        "school": "Gwinnett School of Mathematics- Science and Technology",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003553",
    },
    {
        "school": "Bethlehem Elementary School",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003566",
    },
    {
        "school": "Hilltop Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288003585",
    },
    {
        "school": "Pleasant Valley Innovative School",
        "district": "Murray County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130384003574",
    },
    {
        "school": "Monroe Elementary",
        "district": "Walton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539003569",
    },
    {
        "school": "Webster County High School",
        "district": "Webster County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130558003575",
    },
    {
        "school": "Kona Pacific - PCS",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000293",
    },
    {
        "school": "Kawaikini NCPCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000294",
    },
    {
        "school": "Hawaii Technology Academy - PCS",
        "district": "Hawaii Department of Education",
        "level": "Other",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000295",
    },
    {
        "school": "SALMON RIVER JR/SR HIGH SCHOOL",
        "district": "SALMON RIVER JOINT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160013800944",
    },
    {
        "school": "RIGGINS ELEMENTARY SCHOOL",
        "district": "SALMON RIVER JOINT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160013800959",
    },
    {
        "school": "ELK CITY SCHOOL",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160013900933",
    },
    {
        "school": "CLEARWATER VALLEY JR/SR",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160013900936",
    },
    {
        "school": "GRANGEVILLE HIGH SCHOOL",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160013900937",
    },
    {
        "school": "GRANGEVILLE ELEM/MIDDLE SCHOOL",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160013900946",
    },
    {
        "school": "CLEARWATER VALLEY ELEMENTARY",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160013900961",
    },
    {
        "school": "XAVIER CHARTER SCHOOL",
        "district": "XAVIER CHARTER SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160014000949",
    },
    {
        "school": "VISION CHARTER SCHOOL",
        "district": "VISION CHARTER SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160014100942",
    },
    {
        "school": "WHITE PINE CHARTER SCHOOL",
        "district": "WHITE PINE CHARTER SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160014200809",
    },
    {
        "school": "NORTH VALLEY ACADEMY",
        "district": "NORTH VALLEY ACADEMY INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160014300968",
    },
    {
        "school": "iSUCCEED VIRTUAL HIGH SCHOOL",
        "district": "ISUCCEED VIRTUAL HIGH SCHOOL INC.",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160014400967",
    },
    {
        "school": "DESERT SPRINGS ELEMENTARY SCHOOL",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060000935",
    },
    {
        "school": "CRIMSON POINT ELEMENTARY SCHOOL",
        "district": "KUNA JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160177000951",
    },
    {
        "school": "INITIAL POINT HIGH SCHOOL",
        "district": "KUNA JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160177000962",
    },
    {
        "school": "TWIN LAKES ELEMENTARY SCHOOL",
        "district": "LAKELAND DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160180000956",
    },
    {
        "school": "GALILEO MAGNET SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000945",
    },
    {
        "school": "PARAMOUNT ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000955",
    },
    {
        "school": "HERITAGE MIDDLE SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000958",
    },
    {
        "school": "MIDVALE ALTERNATIVE SCHOOL",
        "district": "MIDVALE DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160216000939",
    },
    {
        "school": "NEW HORIZON MAGNET SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000941",
    },
    {
        "school": "ENDEAVOR ELEMENTARY SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000947",
    },
    {
        "school": "United Jr High Sch",
        "district": "United CUSD 304",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032105921",
    },
    {
        "school": "United Elem Sch - West",
        "district": "United CUSD 304",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032105939",
    },
    {
        "school": "La Harpe Junior High School",
        "district": "La Harpe CSD 347",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170138105933",
    },
    {
        "school": "La Harpe Elementary School",
        "district": "La Harpe CSD 347",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170138105943",
    },
    {
        "school": "Thompsonville Grade  School",
        "district": "Thompsonville CUSD 174",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170138205923",
    },
    {
        "school": "Thompsonville High School",
        "district": "Thompsonville CUSD 174",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170138205940",
    },
    {
        "school": "Pace Elementary",
        "district": "Exc Children Have Opportunities",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170138305898",
    },
    {
        "school": "Able Program",
        "district": "Exc Children Have Opportunities",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170138305899",
    },
    {
        "school": "Academy for Learning",
        "district": "Exc Children Have Opportunities",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170138305900",
    },
    {
        "school": "MacArthur/Echo Elementary",
        "district": "Exc Children Have Opportunities",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170138305906",
    },
    {
        "school": "Echo School",
        "district": "Exc Children Have Opportunities",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170138305911",
    },
    {
        "school": "Illini West High School",
        "district": "Illini West H S Dist 307",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170138405922",
    },
    {
        "school": "Carthage Primary School",
        "district": "Carthage ESD 317",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170138505931",
    },
    {
        "school": "Carthage Middle School",
        "district": "Carthage ESD 317",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170138505937",
    },
    {
        "school": "Western Jr High School",
        "district": "Western CUSD 12",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170138705901",
    },
    {
        "school": "Western Barry Elem",
        "district": "Western CUSD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170138705902",
    },
    {
        "school": "Western High School",
        "district": "Western CUSD 12",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170138705910",
    },
    {
        "school": "Dallas City Elem School",
        "district": "Dallas ESD 327",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170138805917",
    },
    {
        "school": "Auburn Middle School",
        "district": "Auburn CUSD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170462005966",
    },
    {
        "school": "Belvidere North High Sch",
        "district": "Belvidere CUSD 100",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170579005909",
    },
    {
        "school": "Country Trails Elem",
        "district": "Central CUSD 301",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170783005946",
    },
    {
        "school": "Prairie Knolls Middle Sch",
        "district": "Central CUSD 301",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170783005957",
    },
    {
        "school": "Gary D Wright Elem Sch",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855005951",
    },
    {
        "school": "Cambridge Lakes Charter School",
        "district": "CUSD 300",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855005954",
    },
    {
        "school": "Gilberts Elem Sch",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855005956",
    },
    {
        "school": "Polaris Elem Charter Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005919",
    },
    {
        "school": "Frazier Perspectives Magnet ES",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005930",
    },
    {
        "school": "Catalyst Charter-Circle Rock ES",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005935",
    },
    {
        "school": "Collins Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005942",
    },
    {
        "school": "Crete-Monee Early Childhood Cntr",
        "district": "Crete Monee CUSD 201U",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171125005960",
    },
    {
        "school": "Fremont Jr High/Middle School",
        "district": "Fremont SD 79",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171593005958",
    },
    {
        "school": "Park East School",
        "district": "Grayslake CCSD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171752005952",
    },
    {
        "school": "Park West School",
        "district": "Grayslake CCSD 46",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171752005955",
    },
    {
        "school": "Ladse Learning Center",
        "district": "Lagrange Area Dept Spec Ed-Ladse",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172159005927",
    },
    {
        "school": "Brokaw Early Learning Center",
        "district": "CUSD 308",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027005924",
    },
    {
        "school": "Grande Park Elem Sch",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027005938",
    },
    {
        "school": "Knoxville Cntr Student Success",
        "district": "Peoria SD 150",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123005961",
    },
    {
        "school": "Thomas Jefferson Elem Sch",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174005968",
    },
    {
        "school": "Freedom Elem School",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174005969",
    },
    {
        "school": "John F Kennedy Middle Sch",
        "district": "Plainfield SD 202",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174005974",
    },
    {
        "school": "Emily G Johns School",
        "district": "Plano CUSD 88",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173177005936",
    },
    {
        "school": "Rock Island Academy",
        "district": "Rock Island SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441005967",
    },
    {
        "school": "Matthews Middle School",
        "district": "Wauconda CUSD 118",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174119005945",
    },
    {
        "school": "Whittier Elem School",
        "district": "Waukegan CUSD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174125005947",
    },
    {
        "school": "Danielle-Joy Peterson Elem Sch",
        "district": "Indian Prairie CUSD 204",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169005928",
    },
    {
        "school": "Prairiewood Elem Sch",
        "district": "Woodstock CUSD 200",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333005944",
    },
    {
        "school": "Clay Academy",
        "district": "Woodstock CUSD 200",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333005959",
    },
    {
        "school": "Worthridge School",
        "district": "Worth SD 127",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174338005905",
    },
    {
        "school": "Bristol Bay Elem Sch",
        "district": "Yorkville CUSD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396005920",
    },
    {
        "school": "Indianapolis Metropolitan High Sch",
        "district": "Indianapolis Metropolitan High Sch",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180006402408",
    },
    {
        "school": "Renaissance Academy Charter School",
        "district": "Renaissance Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180006502415",
    },
    {
        "school": "IN Math & Science Academy",
        "district": "IN Math & Science Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180006702416",
    },
    {
        "school": "Cedar Elementary School",
        "district": "Avon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027002194",
    },
    {
        "school": "Pleasant Crossing Elementary",
        "district": "Clark-Pleasant Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180189002411",
    },
    {
        "school": "Colonel John Wheeler Middle School",
        "district": "Crown Point Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180249002417",
    },
    {
        "school": "Eastern Greene Middle School",
        "district": "Eastern Greene Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180309002419",
    },
    {
        "school": "Southern Ind Career and Tech Cent",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180345002219",
    },
    {
        "school": "South Creek Elementary",
        "district": "Franklin Township Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180375002409",
    },
    {
        "school": "Joseph Hess Elementary School",
        "district": "School City of Hammond",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180432002413",
    },
    {
        "school": "Hal E Clark Middle School",
        "district": "Lake Central School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180545002420",
    },
    {
        "school": "Noble Crossing Elementary School",
        "district": "Noblesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180765002414",
    },
    {
        "school": "Ben Davis University High School",
        "district": "M S D Wayne Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002410",
    },
    {
        "school": "Lapel Middle School",
        "district": "Frankton-Lapel Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181288002418",
    },
    {
        "school": "Woodward Academy",
        "district": "Woodward-Granger Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "193201002079",
    },
    {
        "school": "Washington Elementary",
        "district": "Washington Co. Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200002801883",
    },
    {
        "school": "Central School",
        "district": "Atchison Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200354001868",
    },
    {
        "school": "Altoona-Midway Middle/High School",
        "district": "Altoona-Midway",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200417001872",
    },
    {
        "school": "Altoona-Midway Elementary",
        "district": "Altoona-Midway",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200417001898",
    },
    {
        "school": "Thayer Schools",
        "district": "Cherryvale",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200474001867",
    },
    {
        "school": "Mill Creek Middle School",
        "district": "De Soto",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549001871",
    },
    {
        "school": "Horizon Elementary",
        "district": "De Soto",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549001881",
    },
    {
        "school": "Wheatridge Middle School",
        "district": "Gardner Edgerton",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200642001878",
    },
    {
        "school": "Wheatland Elementary School",
        "district": "Wheatland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200663001873",
    },
    {
        "school": "Wheatland High School",
        "district": "Wheatland",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200663001891",
    },
    {
        "school": "Grinnell Middle School",
        "district": "Grinnell Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200678001895",
    },
    {
        "school": "Prairie Elementary School",
        "district": "Haysville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200705001876",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Hoisington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200732001884",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Hoisington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200732001886",
    },
    {
        "school": "Spring Valley Elementary",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789001892",
    },
    {
        "school": "Bluemont Elementary School",
        "district": "Manhattan-Ogden",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200918001875",
    },
    {
        "school": "Madison Place Elementary",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001882",
    },
    {
        "school": "Oskaloosa JR-SR High School",
        "district": "Oskaloosa Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201032001887",
    },
    {
        "school": "West Franklin High School",
        "district": "West Franklin",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201080001869",
    },
    {
        "school": "Appanoose Elementary School",
        "district": "West Franklin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201080001888",
    },
    {
        "school": "West Franklin Middle School",
        "district": "West Franklin",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201080001894",
    },
    {
        "school": "Williamsburg Elementary School",
        "district": "West Franklin",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201080001896",
    },
    {
        "school": "Oak Park-Carpenter Elementary",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001893",
    },
    {
        "school": "Merriam Park Elementary",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164001897",
    },
    {
        "school": "Spring Hill Elementary School",
        "district": "Spring Hill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201185001885",
    },
    {
        "school": "Randall K. Cooper High School",
        "district": "Boone County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051002206",
    },
    {
        "school": "Crossroads Elementary School",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210090002198",
    },
    {
        "school": "Walnut Hill Elementary School",
        "district": "Casey County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210105002211",
    },
    {
        "school": "Dawson Springs Elementary",
        "district": "Dawson Springs Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210150002200",
    },
    {
        "school": "Dawson Springs Jr/Sr High School",
        "district": "Dawson Springs Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210150002203",
    },
    {
        "school": "Sandersville Elementary",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002189",
    },
    {
        "school": "William Wells Brown Elementary",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002199",
    },
    {
        "school": "Liberty Elementary",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002207",
    },
    {
        "school": "Prestonsburg Elementary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195002210",
    },
    {
        "school": "Fulton Independent School",
        "district": "Fulton Independent",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210207002205",
    },
    {
        "school": "Success Academy",
        "district": "Glasgow Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210222002215",
    },
    {
        "school": "Sherman Elementary",
        "district": "Grant County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210225002201",
    },
    {
        "school": "Heartland Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249002209",
    },
    {
        "school": "Harlan County High School",
        "district": "Harlan County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210254002213",
    },
    {
        "school": "Farmer Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299002187",
    },
    {
        "school": "Ramsey Middle",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299002190",
    },
    {
        "school": "Stopher Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299002197",
    },
    {
        "school": "The Life Connection",
        "district": "LaRue County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210318002216",
    },
    {
        "school": "James R. Allen High School",
        "district": "Meade County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210405002202",
    },
    {
        "school": "Morgan Central Elementary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210429002194",
    },
    {
        "school": "Wrigley Elementary School",
        "district": "Morgan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210429002214",
    },
    {
        "school": "The Academy at Horizons",
        "district": "Nelson County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210441002212",
    },
    {
        "school": "Locust Grove Elementary School",
        "district": "Oldham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210453002196",
    },
    {
        "school": "Scott County Preschool",
        "district": "Scott County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526002204",
    },
    {
        "school": "Walton-Verona Middle School",
        "district": "Walton-Verona Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210570002191",
    },
    {
        "school": "Providence Elementary School",
        "district": "Webster County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210582002188",
    },
    {
        "school": "A. E. Phillips Laboratory School",
        "district": "A.E. Phillips Laboratory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220005600750",
    },
    {
        "school": "Bellingrath Hills Elementary School",
        "district": "Central Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012500351",
    },
    {
        "school": "Central High School",
        "district": "Central Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012500363",
    },
    {
        "school": "Central Middle School",
        "district": "Central Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012500364",
    },
    {
        "school": "Tanglewood Elementary School",
        "district": "Central Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012500433",
    },
    {
        "school": "The MAX Charter School",
        "district": "The MAX Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012602058",
    },
    {
        "school": "Bienville Educational Center",
        "district": "Bienville Parish",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220021002066",
    },
    {
        "school": "North DeSoto Upper Elementary School",
        "district": "DeSoto Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220051002064",
    },
    {
        "school": "John Martyn Community School",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002044",
    },
    {
        "school": "L. W. Ruppel Academy for Advanced Studies",
        "district": "Jefferson Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002051",
    },
    {
        "school": "Bayou Blue Middle School",
        "district": "Lafourche Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090001968",
    },
    {
        "school": "North Corbin Junior High School",
        "district": "Livingston Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102002060",
    },
    {
        "school": "St. Bernard Middle School",
        "district": "St. Bernard Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141002065",
    },
    {
        "school": "Raymond A. Geiger Elementary School",
        "district": "Lewiston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230732023113",
    },
    {
        "school": "Van Buren Elementary School",
        "district": "RSU 88/MSAD 24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231101001059",
    },
    {
        "school": "Medomak Middle School",
        "district": "RSU 40/MSAD 40",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231155023111",
    },
    {
        "school": "Sacopee Valley Middle School",
        "district": "RSU 55/MSAD 55",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231419001057",
    },
    {
        "school": "Mill Stream Elementary School",
        "district": "RSU 54/MSAD 54",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231459023112",
    },
    {
        "school": "Massabesic Middle School",
        "district": "RSU 57/MSAD 57",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231467001058",
    },
    {
        "school": "Se Do Mo Cha Elementary School",
        "district": "RSU 68/MSAD 68",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476123108",
    },
    {
        "school": "Chebeague Island School",
        "district": "Chebeague Island Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477100676",
    },
    {
        "school": "Mountain Ridge High School",
        "district": "Allegany County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240003001636",
    },
    {
        "school": "Seven Oaks Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001645",
    },
    {
        "school": "Baltimore International Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001631",
    },
    {
        "school": "Independence School Local I",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001632",
    },
    {
        "school": "Crossroads Center",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012001649",
    },
    {
        "school": "Theodore G. Davis Middle School",
        "district": "Charles County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027001647",
    },
    {
        "school": "Patterson Mill High School",
        "district": "Harford County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039001638",
    },
    {
        "school": "Patterson Mill Middle School",
        "district": "Harford County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039001642",
    },
    {
        "school": "Veterans Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001646",
    },
    {
        "school": "PEP - Itinerant",
        "district": "Montgomery County Public Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240048001635",
    },
    {
        "school": "Arcola Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001643",
    },
    {
        "school": "Imagine Foundations at Leeland PCS",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001637",
    },
    {
        "school": "Northview Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001641",
    },
    {
        "school": "Imagine Lincoln Public Charter",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001648",
    },
    {
        "school": "Matapeake Middle School",
        "district": "Queen Anne's County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240054001644",
    },
    {
        "school": "Chesapeake Charter School",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001639",
    },
    {
        "school": "Pioneer Valley Chinese Immersion Charter School",
        "district": "Pioneer Valley Chinese Immersion Charter (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250051702619",
    },
    {
        "school": "Pioneer Charter School of Science",
        "district": "Pioneer Charter School of Science (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250051802632",
    },
    {
        "school": "Global Learning Charter Public School",
        "district": "Global Learning Charter Public (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250051902629",
    },
    {
        "school": "Curley K-8 School",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002622",
    },
    {
        "school": "Rodman Early Childhood Center",
        "district": "Canton",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250330002635",
    },
    {
        "school": "Parthum Middle School",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002623",
    },
    {
        "school": "School for Exceptional Studies",
        "district": "Lawrence",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002625",
    },
    {
        "school": "High School Learning Center",
        "district": "Lawrence",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002628",
    },
    {
        "school": "Guilmette Middle School",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002630",
    },
    {
        "school": "Frances Drake School",
        "district": "Leominster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250678002637",
    },
    {
        "school": "Lynnfield Preschool",
        "district": "Lynnfield",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250714002617",
    },
    {
        "school": "Mashpee Middle School",
        "district": "Mashpee",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250744002638",
    },
    {
        "school": "Memorial Early Childhood Center",
        "district": "Middleborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250777002626",
    },
    {
        "school": "Edward G. Molin Elementary School",
        "district": "Newburyport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250858002624",
    },
    {
        "school": "West Area",
        "district": "Institutional Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MA",
        "nces_id": "251115002621",
    },
    {
        "school": "Daniel Feeney Preschool Center",
        "district": "Walpole",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251197002620",
    },
    {
        "school": "Chandler Park Academy  High School",
        "district": "Chandler Park Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260016807800",
    },
    {
        "school": "Oakland International Academy  Middle",
        "district": "Oakland International Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021707766",
    },
    {
        "school": "Riverside Academy  PreK",
        "district": "Riverside Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260029107794",
    },
    {
        "school": "Universal Learning Academy",
        "district": "Universal Learning Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260030007820",
    },
    {
        "school": "ACE Academy SDA Glendale Lincoln Woodward Jefferson",
        "district": "ACE Academy (SDA)",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260094307776",
    },
    {
        "school": "Flagship Charter Academy",
        "district": "Flagship Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260094507818",
    },
    {
        "school": "International Academy of Saginaw",
        "district": "International Academy of Saginaw",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260094607816",
    },
    {
        "school": "Clara B Ford Academy SDA",
        "district": "Clara B. Ford Academy (SDA)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260094707780",
    },
    {
        "school": "Skyline High School",
        "district": "Ann Arbor Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260282007761",
    },
    {
        "school": "Birch Run Progressive High School",
        "district": "Birch Run Area Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260582007768",
    },
    {
        "school": "R1TS",
        "district": "Cedar Springs Public Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260852007826",
    },
    {
        "school": "Clio Community High School",
        "district": "Clio Area School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261011007828",
    },
    {
        "school": "Henry Ford Early College",
        "district": "Dearborn City School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160007810",
    },
    {
        "school": "Fruitport Adult Education",
        "district": "Fruitport Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261539007822",
    },
    {
        "school": "Harper Woods Middle School",
        "district": "Harper Woods The School District of the City of",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261776007798",
    },
    {
        "school": "Horizon Alternative School",
        "district": "Hillsdale Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261839007796",
    },
    {
        "school": "Madison District Early Childhood Education Center",
        "district": "Madison District Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262229007787",
    },
    {
        "school": "Mason County Central Upper Elementary",
        "district": "Mason County Central Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262313007785",
    },
    {
        "school": "MALC",
        "district": "Millington Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262391007824",
    },
    {
        "school": "Isabella Day Treatment",
        "district": "Mt. Pleasant City School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262475007823",
    },
    {
        "school": "Cardinal Elementary",
        "district": "Orchard View Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262676007763",
    },
    {
        "school": "12th Street Elementary",
        "district": "Portage Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262895007802",
    },
    {
        "school": "University High School Academy",
        "district": "Southfield Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263231007791",
    },
    {
        "school": "Oakland Early College",
        "district": "West Bloomfield School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263582007784",
    },
    {
        "school": "Calhoun County Juvenile Home",
        "district": "Calhoun Intermediate School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268020007803",
    },
    {
        "school": "Calhoun Area Career Center",
        "district": "Calhoun Intermediate School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268020007819",
    },
    {
        "school": "Genesee ISD Transition Center",
        "district": "Genesee ISD",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268040007774",
    },
    {
        "school": "TBA ISD Traverse Heights",
        "district": "Traverse Bay Area ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268044007779",
    },
    {
        "school": "TBA ISD Oak Park Special Education",
        "district": "Traverse Bay Area ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268044007809",
    },
    {
        "school": "ISDLocal Programs",
        "district": "Bay-Arenac ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268050407773",
    },
    {
        "school": "Communitybased Transition Center",
        "district": "Van Buren ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268098507790",
    },
    {
        "school": "Behavioral Education Center",
        "district": "Van Buren ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268098507807",
    },
    {
        "school": "CHISAGO LAKES HS ALT LEARNING PROG",
        "district": "CHISAGO LAKES SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270001703889",
    },
    {
        "school": "MINNEWASKA AREA JUNIOR HIGH",
        "district": "MINNEWASKA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270001904237",
    },
    {
        "school": "NORTH EDUCATION CENTER ACADEMY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002503655",
    },
    {
        "school": "283-IND STDY 15 AND UNDER - I.S.",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504216",
    },
    {
        "school": "917 DASH",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002603897",
    },
    {
        "school": "917 SUN",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002604218",
    },
    {
        "school": "WEST HEIGHTS ALC",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002604250",
    },
    {
        "school": "EDOP DCALS EXTENDED DAY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002604253",
    },
    {
        "school": "WEST HEIGHTS EXTENDED DAY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002604256",
    },
    {
        "school": "WINGS ALTERNATIVE PROGRAM",
        "district": "MEEKER AND WRIGHT SPECIAL EDUCATION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270004503890",
    },
    {
        "school": "SWWC ELC - Cosmos",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270008604215",
    },
    {
        "school": "LAC QUI PARLE VALLEY MIDDLE SCHOOL",
        "district": "LAC QUI PARLE VALLEY SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270012503893",
    },
    {
        "school": "KIPP North Star Academy",
        "district": "KIPP MINNESOTA CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270030804244",
    },
    {
        "school": "Best Academy",
        "district": "BEST ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270030904261",
    },
    {
        "school": "ST CROIX PREPARATORY ACADEMY MIDDLE",
        "district": "ST. CROIX PREPARATORY ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036204222",
    },
    {
        "school": "CHANHASSEN HIGH SCHOOL",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819004260",
    },
    {
        "school": "LA CRESCENT-HOKAH MIDDLE SCHOOL",
        "district": "LA CRESCENT-HOKAH SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271725004238",
    },
    {
        "school": "HMONG INTERNATIONAL ACADEMY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004239",
    },
    {
        "school": "EARLY CHILDHOOD",
        "district": "PINE CITY PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272838003883",
    },
    {
        "school": "RICHFIELD DUAL LANGUAGE SCHOOL",
        "district": "RICHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273175004212",
    },
    {
        "school": "CREDIT RECOVERY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273180003887",
    },
    {
        "school": "FAIRVIEW ALTERNATIVE HIGH SCHOOL",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273243004233",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL ED PROGRAM",
        "district": "South St. Paul Public School Dist",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273327004234",
    },
    {
        "school": "Nuevas Fronteras Spanish Immersion",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381004232",
    },
    {
        "school": "EAST RIDGE HIGH SCHOOL",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381004246",
    },
    {
        "school": "ALC ON TRACK",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384003888",
    },
    {
        "school": "ST. PETER ECSE",
        "district": "ST. PETER PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273387003880",
    },
    {
        "school": "MN SECURITY HOSPITAL YAAP",
        "district": "ST. PETER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273387003881",
    },
    {
        "school": "ROCK BEND HS ALC",
        "district": "ST. PETER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273387004252",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL EDUCATION",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274216003898",
    },
    {
        "school": "ROGER AMOS MCMURTRY SCHOOL",
        "district": "ROGER AMOS MCMURTRY ADM",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018301317",
    },
    {
        "school": "LAKE CORMORANT ELEMENTARY",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001319",
    },
    {
        "school": "HEIDELBERG JUNIOR HIGH SCHOOL",
        "district": "EAST JASPER CONSOLIDATED SCH DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280138001315",
    },
    {
        "school": "OAK GROVE LOWER ELEMENTARY",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001314",
    },
    {
        "school": "SUMRALL MIDDLE SCHOOL",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001316",
    },
    {
        "school": "PURVIS UPPER ELEMENTARY",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001322",
    },
    {
        "school": "MADISON CO PRE SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001318",
    },
    {
        "school": "DELLA DAVIDSON ELEMENTARY",
        "district": "OXFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280345001312",
    },
    {
        "school": "ALGOA CORRECTIONAL CENTER",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003002980",
    },
    {
        "school": "KIPP ENDEAVOR ACADEMY",
        "district": "KIPP: ENDEAVOR ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290003103013",
    },
    {
        "school": "LIFT FOR LIFE ACADEMY",
        "district": "LIFT FOR LIFE ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290057402828",
    },
    {
        "school": "PREMIER CHARTER SCHOOL",
        "district": "PREMIER CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290057602831",
    },
    {
        "school": "ASPIRE ACADEMY",
        "district": "CONFLUENCE ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290057903014",
    },
    {
        "school": "OLD NORTH ACADEMY",
        "district": "CONFLUENCE ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290057903037",
    },
    {
        "school": "SOUTH CITY",
        "district": "CONFLUENCE ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290057903079",
    },
    {
        "school": "ROBINSON INTERMEDIATE",
        "district": "AURORA R-VIII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290402002981",
    },
    {
        "school": "KENTUCKY TRAIL ELEM.",
        "district": "BELTON 124",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290462002988",
    },
    {
        "school": "HAWTHORN ELEMENTARY",
        "district": "CAMDENTON R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290699002983",
    },
    {
        "school": "FT. ZUMWALT EAST HIGH",
        "district": "FT. ZUMWALT R-II",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837002978",
    },
    {
        "school": "EARLY CHILDHOOD CTR.",
        "district": "DESOTO 73",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291050002993",
    },
    {
        "school": "LEWIS AND CLARK LEARNING CTR.",
        "district": "FORT OSAGE R-I",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "291229002995",
    },
    {
        "school": "STONY POINT ELEM.",
        "district": "GRAIN VALLEY R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291308002976",
    },
    {
        "school": "HALLSVILLE PRIMARY",
        "district": "HALLSVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291356002975",
    },
    {
        "school": "CENTRAL MIDDLE",
        "district": "HAZELWOOD",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383003000",
    },
    {
        "school": "NORTH MIDDLE",
        "district": "HAZELWOOD",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383003004",
    },
    {
        "school": "SOUTHEAST MIDDLE",
        "district": "HAZELWOOD",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383003005",
    },
    {
        "school": "FREDA MARKLEY EARLY CHILDHOOD",
        "district": "HICKMAN MILLS C-1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434002979",
    },
    {
        "school": "FAIRVIEW INTERMEDIATE",
        "district": "JENNINGS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291629003081",
    },
    {
        "school": "SUMMIT POINTE ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830003010",
    },
    {
        "school": "WOODLAND MIDDLE",
        "district": "WOODLAND R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291935002985",
    },
    {
        "school": "ANDERSON MIDDLE",
        "district": "MCDONALD CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292061003007",
    },
    {
        "school": "JOHN CARY EARLY CHILDHOOD CTR.",
        "district": "MEHLVILLE R-IX",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067002996",
    },
    {
        "school": "GEORGE WASHINGTON CARVER ELEM.",
        "district": "NEOSHO SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292181003011",
    },
    {
        "school": "HIGH POINTE ELEM.",
        "district": "Nixa Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292253002998",
    },
    {
        "school": "OWENSVILLE ELEM.",
        "district": "GASCONADE CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292334003008",
    },
    {
        "school": "WEST ELEM.",
        "district": "OZARK R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292343003001",
    },
    {
        "school": "NORTHWOOD SCH.",
        "district": "RAYTOWN C-2",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607002984",
    },
    {
        "school": "MCKINLEY CLASS. LEADERSHIP AC.",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928002990",
    },
    {
        "school": "WARRIOR RIDGE ELEM.",
        "district": "WARREN CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293105002989",
    },
    {
        "school": "BESS TRUMAN PRIMARY CTR.",
        "district": "WEBB CITY R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293150002991",
    },
    {
        "school": "EARLY CHILDHOOD CTR.",
        "district": "WENTZVILLE R-IV",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165003006",
    },
    {
        "school": "DUELLO ELEM.",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165003080",
    },
    {
        "school": "Beartooth School",
        "district": "Billings Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387001092",
    },
    {
        "school": "LAUREL-CONCORD-COLERIDGE MIDDLE SCHOOL",
        "district": "LAUREL-CONCORD-COLERIDGE SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000402195",
    },
    {
        "school": "UPCHURCH ELEMENTARY",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317374002198",
    },
    {
        "school": "Nevada Connections Academy",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100731",
    },
    {
        "school": "Nevada Virtual Academy",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100734",
    },
    {
        "school": "Coral Academy of Science Las Vegas Sandy Ridge",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100742",
    },
    {
        "school": "Desert Willow Secondary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320006000683",
    },
    {
        "school": "Indian Springs High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000686",
    },
    {
        "school": "Miley Achievement Center Sec",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320006000694",
    },
    {
        "school": "Odyssey Charter School 6-8",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000698",
    },
    {
        "school": "Indian Springs Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000699",
    },
    {
        "school": "Explore Knowledge Academy Charter Secondary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000707",
    },
    {
        "school": "Wilbur & Theresa Faiss Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000730",
    },
    {
        "school": "James E & A Rae Smalley Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000732",
    },
    {
        "school": "Dr. Claude G Perkins Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000733",
    },
    {
        "school": "Sister Robert Joseph Bailey Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000736",
    },
    {
        "school": "Robert L Forbuss Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000737",
    },
    {
        "school": "Lyal Burkholder Junior High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000738",
    },
    {
        "school": "Edmundo Eddie Escobedo SR Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000739",
    },
    {
        "school": "Rainbow Dreams Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000740",
    },
    {
        "school": "D L Dusty Dickens Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000741",
    },
    {
        "school": "Dr. C Owen Roundy Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000743",
    },
    {
        "school": "West Prepatory Academy at Charles I West Hall Elem",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000744",
    },
    {
        "school": "Delta Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000745",
    },
    {
        "school": "Riverview Elementary School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000746",
    },
    {
        "school": "Duckwater Middle School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000729",
    },
    {
        "school": "Kendyl Depoali Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000678",
    },
    {
        "school": "Academy for Science and Design Charter (M)",
        "district": "Academy for Science and Design Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330004000678",
    },
    {
        "school": "Academy for Science and Design Charter (H)",
        "district": "Academy for Science and Design Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330004000684",
    },
    {
        "school": "CSI Charter School",
        "district": "CSI Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330004100677",
    },
    {
        "school": "Strong Foundations Charter School",
        "district": "Strong Foundations Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330004200683",
    },
    {
        "school": "Bedford High School",
        "district": "Bedford School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330174000680",
    },
    {
        "school": "Ross A. Lurgio Middle School",
        "district": "Bedford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330174000681",
    },
    {
        "school": "Virtual Learning Academy (H)",
        "district": "Virtual Learning Academy Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330327100679",
    },
    {
        "school": "Purple Panthers Preschool",
        "district": "Nashua School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000682",
    },
    {
        "school": "COSTELLO PREP",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008902973",
    },
    {
        "school": "Bergen Arts and Sciences Charter School",
        "district": "Bergen Arts and Science Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340071502923",
    },
    {
        "school": "Foundation Academy Charter School",
        "district": "Foundation Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340071702925",
    },
    {
        "school": "Burlington Township Middle School at Springside",
        "district": "Burlington Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340246002939",
    },
    {
        "school": "Clinton Township Middle School",
        "district": "Clinton Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340336002935",
    },
    {
        "school": "Alder Avenue Middle School",
        "district": "Egg Harbor Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340456002953",
    },
    {
        "school": "Fernwood Avenue Middle School",
        "district": "Egg Harbor Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340456002955",
    },
    {
        "school": "Hamilton Intermediate School",
        "district": "Harrison Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340687002933",
    },
    {
        "school": "Mt. Vernon Avenue Elementary School",
        "district": "Irvington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768002945",
    },
    {
        "school": "University Elementary School",
        "district": "Irvington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768002947",
    },
    {
        "school": "Augusta Preschool Academy",
        "district": "Irvington Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340768002949",
    },
    {
        "school": "John I. Dawes Early Learning Center",
        "district": "Manalapan-Englishtown Regional Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340939002941",
    },
    {
        "school": "Millstone Township Primary School",
        "district": "Millstone Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341023002931",
    },
    {
        "school": "New Brunswick Middle School",
        "district": "New Brunswick School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341122002936",
    },
    {
        "school": "Ivy Hill Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134002937",
    },
    {
        "school": "North Hanover Township Upper Elementary School",
        "district": "North Hanover Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341158002943",
    },
    {
        "school": "STARS Academy",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341269002929",
    },
    {
        "school": "Phillipsburg Early Childhood Learning Center",
        "district": "Phillipsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341296002957",
    },
    {
        "school": "Center for Lifelong Learning",
        "district": "Educational Services Commission of New Jersey",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348018002926",
    },
    {
        "school": "CLEVELAND HIGH SCHOOL",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001001024",
    },
    {
        "school": "TIERRA ANTIGUA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001018",
    },
    {
        "school": "THE ALB TALENT DEVELOPMENT CHARTER",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001026",
    },
    {
        "school": "CORRALES INTERNATIONAL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001028",
    },
    {
        "school": "RED MOUNTAIN MIDDLE",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069001023",
    },
    {
        "school": "CHIEF MANUELITO MIDDLE",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111001027",
    },
    {
        "school": "VISTA GRANDE HIGH SCHOOL",
        "district": "TAOS MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350252001021",
    },
    {
        "school": "DOLGEVILLE MIDDLE SCHOOL",
        "district": "DOLGEVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360000105991",
    },
    {
        "school": "LOWER EAST SIDE PREPARATORY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007600624",
    },
    {
        "school": "CASCADES HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007603352",
    },
    {
        "school": "LIBERTY HIGH SCHOOL ACADEMY FOR NEWCOMERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700637",
    },
    {
        "school": "HIGH SCHOOL 560 CITY-AS-SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700649",
    },
    {
        "school": "SATELLITE ACADEMY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007700668",
    },
    {
        "school": "INDEPENDENCE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705566",
    },
    {
        "school": "EDWARD A REYNOLDS WEST SIDE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007800619",
    },
    {
        "school": "HIGH SCHOOL MATHEMATICS SCIENCE AND ENGINEERING AT CCNY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008105116",
    },
    {
        "school": "HARLEM RENAISSANCE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008105758",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL FOR THE PERFORMING ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008105934",
    },
    {
        "school": "COLUMBIA SECONDARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008105944",
    },
    {
        "school": "HAMILTON HEIGHTS SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305989",
    },
    {
        "school": "WASHINGTON HEIGHTS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008305990",
    },
    {
        "school": "JILL CHAIFETZ TRANSFER HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405988",
    },
    {
        "school": "URBAN INSTITUTE OF MATHEMATICS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505982",
    },
    {
        "school": "BRONX COMMUNITY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505983",
    },
    {
        "school": "ANTONIA PANTOJA PREPARATORY ACADEMY - A COLLEGE BOARD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505984",
    },
    {
        "school": "ARCHIMEDES ACAD-MATH SCI TECH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505985",
    },
    {
        "school": "BRONX MATHEMATICS PREPARATORY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008505986",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL FOR APPLIED MATH AND SCIENCE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605673",
    },
    {
        "school": "MORRIS ACADEMY FOR COLLABORATIVE STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605693",
    },
    {
        "school": "ACADEMY FOR LANGUAGE AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605981",
    },
    {
        "school": "PROVIDING URBAN LEARNERS SUCCESS IN EDUCATION HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705760",
    },
    {
        "school": "KNOWLEDGE AND POWER PREP ACADEMY INTERNATIONAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705943",
    },
    {
        "school": "AMPARK NEIGHBORHOOD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008705993",
    },
    {
        "school": "LEADERS OF TOMORROW",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805969",
    },
    {
        "school": "CORNERSTONE ACADEMY FOR SOCIAL ACTION",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805971",
    },
    {
        "school": "BRONX REGIONAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009000744",
    },
    {
        "school": "BROOKLYN ACADEMY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009105563",
    },
    {
        "school": "WEST BROOKLYN COMMUNITY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009205864",
    },
    {
        "school": "KHALIL GIBRAN INTERNATIONAL ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009205930",
    },
    {
        "school": "BROWNSVILLE ACADEMY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505762",
    },
    {
        "school": "BROOKLYN COMMUNITY HIGH SCHOOL FOR EXCELLENCE AND EQUITY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009605956",
    },
    {
        "school": "KURT HAHN EXPEDITIONARY LEARNING SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009605957",
    },
    {
        "school": "MIDDLE SCHOOL FOR ART AND PHILOSPHY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009605958",
    },
    {
        "school": "MIDDLE SCHOOL OF MEDIA LAW AND FINE ARTS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009605960",
    },
    {
        "school": "BROOKLYN BRIDGE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009605961",
    },
    {
        "school": "IT TAKES A VILLAGE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009605964",
    },
    {
        "school": "BROOKLYN THEATRE ARTS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009605966",
    },
    {
        "school": "VICTORY COLLEGIATE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009605967",
    },
    {
        "school": "PS/IS 295",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010105925",
    },
    {
        "school": "CONCORD HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010300962",
    },
    {
        "school": "BROOKLYN PREPARATORY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011905699",
    },
    {
        "school": "LYONS COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011905933",
    },
    {
        "school": "QUEENS ACADEMY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012205503",
    },
    {
        "school": "BELL ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012205979",
    },
    {
        "school": "NORTH QUEENS COMMUNITY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012205980",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL FOR CRIMINAL JUSTICE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015105955",
    },
    {
        "school": "LIFE ACADEMY HIGH SCHOOL FOR FILM AND MUSIC",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015205940",
    },
    {
        "school": "LEADERS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015205941",
    },
    {
        "school": "LIBERATION DIPLOMA PLUS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015205942",
    },
    {
        "school": "ICAHN CHARTER SCHOOL 2",
        "district": "ICAHN CHARTER SCHOOL 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360094305973",
    },
    {
        "school": "KINGS COLLEGIATE CHARTER SCHOOL",
        "district": "KINGS COLLEGIATE CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360094405974",
    },
    {
        "school": "GREEN TECH HIGH CHARTER SCHOOL",
        "district": "GREEN TECH HIGH CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360094505946",
    },
    {
        "school": "HENRY JOHNSON CHARTER SCHOOL",
        "district": "HENRY JOHNSON CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360094605936",
    },
    {
        "school": "BEAVER RIVER MIDDLE SCHOOL",
        "district": "BEAVER RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360420005992",
    },
    {
        "school": "INTERNATIONAL PREPARATORY SCHOOL (THE)",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585005939",
    },
    {
        "school": "NELLIE THORNTON SCHOOL OF PERFORMING ARTS",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010005949",
    },
    {
        "school": "GASKILL PREPARATORY SCHOOL",
        "district": "NIAGARA FALLS CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362082005951",
    },
    {
        "school": "LASALLE PREPARATORY SCHOOL",
        "district": "NIAGARA FALLS CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362082005952",
    },
    {
        "school": "CATARACT ELEMENTARY SCHOOL",
        "district": "NIAGARA FALLS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362082005954",
    },
    {
        "school": "SHATEKON ELEMENTARY SCHOOL",
        "district": "SHENENDEHOWA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362667005972",
    },
    {
        "school": "INSTITUTE OF TECHNOLOGY AT SYRACUSE CENTRAL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859005977",
    },
    {
        "school": "STARBUCK ELEMENTARY SCHOOL",
        "district": "WATERTOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363012005921",
    },
    {
        "school": "Endeavor Charter",
        "district": "Endeavor Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370031403040",
    },
    {
        "school": "Triad Math and Science Academy",
        "district": "Triad Math and Science Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370031503031",
    },
    {
        "school": "Beaufort Co Early College High",
        "district": "Beaufort County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033003011",
    },
    {
        "school": "Morris Grove Elementary",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072003027",
    },
    {
        "school": "Cleveland ECHS",
        "district": "Cleveland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090003030",
    },
    {
        "school": "Sunset Avenue Elementary",
        "district": "Clinton City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370093003029",
    },
    {
        "school": "The JP Knapp ECH (i)School",
        "district": "Currituck County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370108003037",
    },
    {
        "school": "Jarvisburg Elementary",
        "district": "Currituck County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370108003039",
    },
    {
        "school": "Tyro Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114003015",
    },
    {
        "school": "Durham's Performance Learning Center",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370126003085",
    },
    {
        "school": "Early College of Forsyth Co",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150003038",
    },
    {
        "school": "Long Mill Elementary",
        "district": "Franklin County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153003013",
    },
    {
        "school": "Academy at Smith",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192002889",
    },
    {
        "school": "Mattamuskeet Early College High",
        "district": "Hyde County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370228003025",
    },
    {
        "school": "Crossroads Arts Sciences Early College",
        "district": "Iredell-Statesville Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231003087",
    },
    {
        "school": "SanLee Middle School",
        "district": "Lee County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256003036",
    },
    {
        "school": "Whitewater Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003018",
    },
    {
        "school": "Barnette Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003023",
    },
    {
        "school": "Ballantyne Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003026",
    },
    {
        "school": "Polo Ridge Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003032",
    },
    {
        "school": "Croft Community Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003034",
    },
    {
        "school": "Military and Global Leadership Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003042",
    },
    {
        "school": "Meadow View Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345003020",
    },
    {
        "school": "Providence Grove High",
        "district": "Randolph County School System",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378003016",
    },
    {
        "school": "Rockingham Co Early College High",
        "district": "Rockingham County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370399003014",
    },
    {
        "school": "Rowan Co Early College",
        "district": "Rowan-Salisbury Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405003035",
    },
    {
        "school": "Sampson Early College High",
        "district": "Sampson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414003086",
    },
    {
        "school": "Stallings Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462003022",
    },
    {
        "school": "Shiloh Valley Primary School",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462003043",
    },
    {
        "school": "Vance Co Early College",
        "district": "Vance County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465003024",
    },
    {
        "school": "Mills Park Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003012",
    },
    {
        "school": "Laurel Park Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003019",
    },
    {
        "school": "Sycamore Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003028",
    },
    {
        "school": "Warren Early College High",
        "district": "Warren County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370474003044",
    },
    {
        "school": "MARMOT SCHOOL K-8",
        "district": "MARMOT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380000500837",
    },
    {
        "school": "BARNES COUNTY NORTH  ELEMENTARY SCHOOL",
        "district": "BARNES COUNTY NORTH 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380006000701",
    },
    {
        "school": "BARNES COUNTY NORTH HIGH SCHOOL",
        "district": "BARNES COUNTY NORTH 7",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380006000702",
    },
    {
        "school": "ENDERLIN AREA ELEMENTARY SCHOOL",
        "district": "ENDERLIN AREA 24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380006100183",
    },
    {
        "school": "ENDERLIN AREA HIGH SCHOOL",
        "district": "ENDERLIN AREA 24",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380006100184",
    },
    {
        "school": "AURORA ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000830",
    },
    {
        "school": "WEST FARGO SHEYENNE HIGH SCHOOL",
        "district": "WEST FARGO 6",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000838",
    },
    {
        "school": "Monroe Primary School",
        "district": "Monroe Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390009405409",
    },
    {
        "school": "Clay Avenue Community School",
        "district": "Clay Avenue Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390129605436",
    },
    {
        "school": "Star Academy of Toledo",
        "district": "Star Academy of Toledo",
        "level": "Not reported",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390129805378",
    },
    {
        "school": "Foundation Academy",
        "district": "Foundation Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390130105401",
    },
    {
        "school": "Dayton Early College Academy Inc",
        "district": "Dayton Early College Academy Inc",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390130205399",
    },
    {
        "school": "Columbus Collegiate Academy",
        "district": "Columbus Collegiate Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390130505382",
    },
    {
        "school": "Central Academy of Ohio",
        "district": "Central Academy of Ohio",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390131305385",
    },
    {
        "school": "Zanesville Community School",
        "district": "Zanesville Community School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390131405407",
    },
    {
        "school": "Horizon Science Academy Columbus Middle School",
        "district": "Horizon Science Academy Columbus Middle School",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390132205440",
    },
    {
        "school": "Constellation Schools: Westside Community School of the Arts",
        "district": "Constellation Schools: Westside Community School of the Arts",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390132605397",
    },
    {
        "school": "Helen Arnold Community Learning Center",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434805372",
    },
    {
        "school": "Akron Early College High School",
        "district": "Akron City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434805431",
    },
    {
        "school": "Centerville Primary Village South",
        "district": "Centerville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437305402",
    },
    {
        "school": "James N. Gamble Montessori High School",
        "district": "Cincinnati Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505375",
    },
    {
        "school": "Rees E. Price Academy",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505404",
    },
    {
        "school": "Warner Girls Leadership Academy",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805395",
    },
    {
        "school": "Ginn Academy",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805414",
    },
    {
        "school": "Douglas MacArthur",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805433",
    },
    {
        "school": "Hampton Bennett Early Childhood Center",
        "district": "Franklin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440005438",
    },
    {
        "school": "Jackson Northview Elementary School",
        "district": "Jackson City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441505400",
    },
    {
        "school": "Harding Middle School",
        "district": "Lakewood City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441905364",
    },
    {
        "school": "Hayes Elementary School",
        "district": "Lakewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441905376",
    },
    {
        "school": "Garfield Middle School",
        "district": "Lakewood City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441905406",
    },
    {
        "school": "Harrison Elementary School",
        "district": "Lakewood City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441905437",
    },
    {
        "school": "Toni Wofford Morrison ES",
        "district": "Lorain City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442605374",
    },
    {
        "school": "Helen Steiner Rice ES",
        "district": "Lorain City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442605439",
    },
    {
        "school": "Legend Elementary",
        "district": "Newark City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444505369",
    },
    {
        "school": "Liberty Middle School",
        "district": "Newark City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444505379",
    },
    {
        "school": "Heritage Middle School",
        "district": "Newark City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444505383",
    },
    {
        "school": "Hillview Elementary School",
        "district": "Newark City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444505411",
    },
    {
        "school": "Carson Elementary School",
        "district": "Newark City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444505427",
    },
    {
        "school": "Jesup W. Scott High School",
        "district": "Toledo City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449005361",
    },
    {
        "school": "Willard Avenue PK-8 School",
        "district": "Warren City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449905413",
    },
    {
        "school": "Jefferson PK-8 School",
        "district": "Warren City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449905417",
    },
    {
        "school": "McGuffey PK-8 School",
        "district": "Warren City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449905430",
    },
    {
        "school": "Lincoln PK-8 School",
        "district": "Warren City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449905434",
    },
    {
        "school": "Phoenix Middle School",
        "district": "Worthington City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451305441",
    },
    {
        "school": "Jefferson Area Junior High School",
        "district": "Jefferson Area Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458705392",
    },
    {
        "school": "Ridgewood Elementary School",
        "district": "Ridgewood Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390464705423",
    },
    {
        "school": "Johnnycake Corners Elementary School",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605381",
    },
    {
        "school": "Liberty Tree Elementary School",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605386",
    },
    {
        "school": "Orange High School",
        "district": "Olentangy Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605390",
    },
    {
        "school": "Hyatts Middle School",
        "district": "Olentangy Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605422",
    },
    {
        "school": "Waggoner Road Junior High",
        "district": "Reynoldsburg City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470005388",
    },
    {
        "school": "Washington Elementary School",
        "district": "Hilliard City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470105370",
    },
    {
        "school": "Hilliard Bradley High School",
        "district": "Hilliard City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470105403",
    },
    {
        "school": "Hilliard City School District Preschool",
        "district": "Hilliard City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470105444",
    },
    {
        "school": "Madison Park Elementary",
        "district": "Trotwood-Madison City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486905389",
    },
    {
        "school": "Trotwood-Madison Early Learning Center",
        "district": "Trotwood-Madison City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486905445",
    },
    {
        "school": "Fairless Elementary School",
        "district": "Fairless Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390498405410",
    },
    {
        "school": "Miami Trace Elementary School",
        "district": "Miami Trace Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001005367",
    },
    {
        "school": "NORTH INTERMEDIATE SCHOOL",
        "district": "BIXBY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400450002665",
    },
    {
        "school": "COLLINSVILLE EC CTR",
        "district": "COLLINSVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400837002685",
    },
    {
        "school": "DICKSON MS",
        "district": "DICKSON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400991002667",
    },
    {
        "school": "PRAIRIE ES",
        "district": "GUYMON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401359002669",
    },
    {
        "school": "HUGO MS",
        "district": "HUGO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401521002670",
    },
    {
        "school": "MONRONEY MS",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995002655",
    },
    {
        "school": "CARL ALBERT MS",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995002659",
    },
    {
        "school": "JARMAN MS",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995002660",
    },
    {
        "school": "DEL CREST MS",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995002661",
    },
    {
        "school": "KERR MS",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995002671",
    },
    {
        "school": "MORRISON MS",
        "district": "MORRISON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402034002657",
    },
    {
        "school": "MUSTANG CENTENNIAL ES",
        "district": "MUSTANG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100002666",
    },
    {
        "school": "GARFIELD ES",
        "district": "PONCA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402469002668",
    },
    {
        "school": "JONES ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002656",
    },
    {
        "school": "TRAICE",
        "district": "TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002663",
    },
    {
        "school": "TULSA MET HS",
        "district": "TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002664",
    },
    {
        "school": "THOMAS JEFFERSON ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060002672",
    },
    {
        "school": "The Cottonwood School of Civics and Science",
        "district": "Oregon Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410000901734",
    },
    {
        "school": "Yamhill Carlton Intermediate School",
        "district": "Yamhill Carlton SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001601730",
    },
    {
        "school": "Trask River High School",
        "district": "ODE YCEP District",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004301740",
    },
    {
        "school": "Three Lakes High School",
        "district": "ODE YCEP District",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004301744",
    },
    {
        "school": "Health & Science School",
        "district": "Beaverton SD 48J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001745",
    },
    {
        "school": "Crater Academy of Health and Public Services",
        "district": "Central Point SD 6",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410294001720",
    },
    {
        "school": "Crater School of Business Innovation and Science",
        "district": "Central Point SD 6",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410294001728",
    },
    {
        "school": "Crater Renaissance Academy",
        "district": "Central Point SD 6",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410294001739",
    },
    {
        "school": "Corbett School",
        "district": "Corbett SD 39",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410342001729",
    },
    {
        "school": "Inavale Community Partners dba Muddy Creek Charter School",
        "district": "Corvallis SD 509J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410348001743",
    },
    {
        "school": "Arts and Technology Academy at Jefferson",
        "district": "Eugene SD 4J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001737",
    },
    {
        "school": "Forest Grove Community School",
        "district": "Forest Grove SD 15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410516001724",
    },
    {
        "school": "Gresham Arthur Academy",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600001733",
    },
    {
        "school": "Madrone Trail Public Charter School",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804001736",
    },
    {
        "school": "Alliance Charter Academy",
        "district": "Oregon City SD 62",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933001725",
    },
    {
        "school": "Early College High School",
        "district": "Salem-Keizer SD 24J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "411082001717",
    },
    {
        "school": "Roberts High School",
        "district": "Salem-Keizer SD 24J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "411082001738",
    },
    {
        "school": "Academy for Character Education",
        "district": "South Lane SD 45J3",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411158001727",
    },
    {
        "school": "St Helens Arthur Academy",
        "district": "St Helens SD 502",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411172001732",
    },
    {
        "school": "Creekside Community High School",
        "district": "Tigard-Tualatin SD 23J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "411224001722",
    },
    {
        "school": "Woodburn Academy of Art Science and Technology",
        "district": "Woodburn SD 103",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353001713",
    },
    {
        "school": "Academy of International Studies (at Woodburn)",
        "district": "Woodburn SD 103",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353001714",
    },
    {
        "school": "Woodburn Success",
        "district": "Woodburn SD 103",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353001715",
    },
    {
        "school": "Woodburn Arts and Communications Academy",
        "district": "Woodburn SD 103",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353001723",
    },
    {
        "school": "Wellness Business and Sports School",
        "district": "Woodburn SD 103",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411353001731",
    },
    {
        "school": "Propel CS-Montour",
        "district": "Propel CS-Montour",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420075206095",
    },
    {
        "school": "Southwest Leadership Academy CS",
        "district": "Southwest Leadership Academy CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420075806112",
    },
    {
        "school": "Boys Latin of Philadelphia CS",
        "district": "Boys Latin of Philadelphia CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420076006107",
    },
    {
        "school": "Mastery CS-Pickett Campus",
        "district": "Mastery CS-Pickett Campus",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420076106025",
    },
    {
        "school": "Keystone Academy Charter School",
        "district": "Keystone Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420076206103",
    },
    {
        "school": "Chester Co Technical College HS-Pennocks",
        "district": "Chester County Technical College HS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "420290006770",
    },
    {
        "school": "Mount Rock Elem Sch",
        "district": "Big Spring SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420366006116",
    },
    {
        "school": "North Schuylkill Elem Sch",
        "district": "North Schuylkill SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421011006069",
    },
    {
        "school": "Harbor Creek Senior HS",
        "district": "Harbor Creek SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421149006096",
    },
    {
        "school": "Hazleton El/MS",
        "district": "Hazleton Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421170006115",
    },
    {
        "school": "Arthur Street El Sch",
        "district": "Hazleton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421170006117",
    },
    {
        "school": "Lampeter El Sch",
        "district": "Lampeter-Strasburg SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421311006099",
    },
    {
        "school": "Leechburg Area HS",
        "district": "Leechburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421347006027",
    },
    {
        "school": "Manheim Central MS",
        "district": "Manheim Central SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421455006076",
    },
    {
        "school": "Mars Area Centennial Sch",
        "district": "Mars Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421479006074",
    },
    {
        "school": "McCormick El Sch",
        "district": "Moon Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421583006743",
    },
    {
        "school": "Mount Union Area SHS",
        "district": "Mount Union Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421602006104",
    },
    {
        "school": "Newport HS",
        "district": "Newport SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421689003413",
    },
    {
        "school": "Newport MS",
        "district": "Newport SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421689006078",
    },
    {
        "school": "Shallow Brook Inter Sch",
        "district": "Northeastern York SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421752006121",
    },
    {
        "school": "Pennridge North MS",
        "district": "Pennridge SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421875006093",
    },
    {
        "school": "Juniata Park Academy",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006123",
    },
    {
        "school": "Pittsburgh Whittier K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006747",
    },
    {
        "school": "Pittsburgh South Hills 6-8",
        "district": "Pittsburgh SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006749",
    },
    {
        "school": "Pittsburgh Manchester K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006750",
    },
    {
        "school": "Pittsburgh Arsenal 6-8",
        "district": "Pittsburgh SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006751",
    },
    {
        "school": "Pittsburgh Brookline K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006755",
    },
    {
        "school": "Pittsburgh Westwood K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006756",
    },
    {
        "school": "Pittsburgh Sunnyside K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006757",
    },
    {
        "school": "Pittsburgh King K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006761",
    },
    {
        "school": "Pittsburgh Mifflin K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006766",
    },
    {
        "school": "Pittsburgh Arlington K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006769",
    },
    {
        "school": "Portage Area El Sch",
        "district": "Portage Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421956006771",
    },
    {
        "school": "Richland HS",
        "district": "Richland SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422025006079",
    },
    {
        "school": "Shippensburg Intrm Sch",
        "district": "Shippensburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422157006021",
    },
    {
        "school": "Nancy Grayson El Sch",
        "district": "Shippensburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422157006114",
    },
    {
        "school": "James Burd El Sch",
        "district": "Shippensburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422157006120",
    },
    {
        "school": "Southeast Delco Kindergarten Center",
        "district": "Southeast Delco SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422240006023",
    },
    {
        "school": "Southmoreland Primary Center",
        "district": "Southmoreland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422241006029",
    },
    {
        "school": "Evans El Sch",
        "district": "Spring-Ford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422256006098",
    },
    {
        "school": "Lafayette El Sch",
        "district": "Uniontown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422415006097",
    },
    {
        "school": "Lafayette MS",
        "district": "Uniontown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422415006101",
    },
    {
        "school": "Biglerville El Sch",
        "district": "Upper Adams SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422430006031",
    },
    {
        "school": "Charles Kelly El Sch",
        "district": "Upper Darby SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422432006124",
    },
    {
        "school": "Valley Grove El Sch",
        "district": "Valley Grove SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422463006111",
    },
    {
        "school": "The Regional Career and Tech",
        "district": "Coventry",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "RI",
        "nces_id": "440021000355",
    },
    {
        "school": "Darlington County Institute of Technology",
        "district": "Darlington 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450186001498",
    },
    {
        "school": "Sisseton Middle School - 02",
        "district": "Sisseton School District 54-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460005301258",
    },
    {
        "school": "Hanson Colony Alternative High School - 07",
        "district": "Hanson School District 30-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460264001272",
    },
    {
        "school": "Belle Fourche Education Connection - 09",
        "district": "Belle Fourche School District 09-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "460561001277",
    },
    {
        "school": "Chester Area Cyber School - 92",
        "district": "Chester Area School District 39-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461230001269",
    },
    {
        "school": "Our Home Rediscovery - 77",
        "district": "Huron School District 02-2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "463548001279",
    },
    {
        "school": "Aurora Plains Academy High School - 05",
        "district": "Plankinton School District 01-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "465571001274",
    },
    {
        "school": "Aurora Plains Academy Middle School - 04",
        "district": "Plankinton School District 01-1",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "465571001276",
    },
    {
        "school": "Oglala Lakota County Virtual High School - 92",
        "district": "Oglala Lakota County 65-1",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466546001262",
    },
    {
        "school": "Rosa Parks Elementary - 15",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001275",
    },
    {
        "school": "Early Learning Center - 04",
        "district": "Wagner Community School District 11-4",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467542001278",
    },
    {
        "school": "Interior Elementary - 09",
        "district": "Kadoka Area School District 35-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043701245",
    },
    {
        "school": "Kadoka Area High School - 01",
        "district": "Kadoka Area School District 35-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043701247",
    },
    {
        "school": "Kadoka Elementary - 02",
        "district": "Kadoka Area School District 35-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043701249",
    },
    {
        "school": "Longvalley Elementary - 10",
        "district": "Kadoka Area School District 35-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043701256",
    },
    {
        "school": "Midland Elementary - 11",
        "district": "Kadoka Area School District 35-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043701257",
    },
    {
        "school": "Platte - Geddes Elementary - 02",
        "district": "Platte - Geddes School District 11-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043801244",
    },
    {
        "school": "Platte - Geddes High School - 01",
        "district": "Platte - Geddes School District 11-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043801248",
    },
    {
        "school": "Platte - Geddes Jr. High - 03",
        "district": "Platte - Geddes School District 11-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043801250",
    },
    {
        "school": "Cedar Grove Colony Elementary - 14",
        "district": "Platte - Geddes School District 11-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043801252",
    },
    {
        "school": "Platte Colony Elementary - 10",
        "district": "Platte - Geddes School District 11-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043801267",
    },
    {
        "school": "Irene - Wakonda Jr. High - 04",
        "district": "Irene - Wakonda School District 13-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043901253",
    },
    {
        "school": "Irene - Wakonda High School - 01",
        "district": "Irene - Wakonda School District 13-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043901254",
    },
    {
        "school": "Irene - Wakonda Elementary - 02",
        "district": "Irene - Wakonda School District 13-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043901255",
    },
    {
        "school": "West Tennessee School For Deaf",
        "district": "West Tennessee School for the Deaf",
        "level": "Elementary",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470014302131",
    },
    {
        "school": "Alvin C. York Institute",
        "district": "Alvin C York Institute",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014402133",
    },
    {
        "school": "Tenn School For Blind",
        "district": "Tennessee School for Blind",
        "level": "Other",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470014502138",
    },
    {
        "school": "Tennessee Elementary School For Deaf",
        "district": "Tennessee School for the Deaf",
        "level": "Elementary",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470014602124",
    },
    {
        "school": "Tennessee School for the Deaf Upper School",
        "district": "Tennessee School for the Deaf",
        "level": "High",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470014602140",
    },
    {
        "school": "LaFollette Elementary School",
        "district": "Campbell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470042002128",
    },
    {
        "school": "The Phoenix School",
        "district": "Cumberland County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470090002130",
    },
    {
        "school": "West Creek Middle",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303002123",
    },
    {
        "school": "Lead Academy",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002122",
    },
    {
        "school": "W. A. Bass Adult Program",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002125",
    },
    {
        "school": "Nashville Big Picture High School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002136",
    },
    {
        "school": "LaVergne Lake Elementary School",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002134",
    },
    {
        "school": "Longview Elementary School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002139",
    },
    {
        "school": "HERITAGE ACADEMY OF SAN ANTONIO",
        "district": "HERITAGE ACADEMY",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480008011924",
    },
    {
        "school": "TRIUMPH PUBLIC HIGH SCHOOLS-SAN BENITO",
        "district": "TRIUMPH PUBLIC HIGH SCHOOLS-RIO GRANDE VALLEY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480013311872",
    },
    {
        "school": "MID-VALLEY ACADEMY (PK-3)",
        "district": "TRIUMPH PUBLIC HIGH SCHOOLS-RIO GRANDE VALLEY",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480013311983",
    },
    {
        "school": "EDUCATION CENTER INTERNATIONAL ACADEMY 2",
        "district": "EDUCATION CENTER INTERNATIONAL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480018611928",
    },
    {
        "school": "YES PREP - GULFTON",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020911822",
    },
    {
        "school": "IDEA ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021111804",
    },
    {
        "school": "IDEA QUEST COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021111947",
    },
    {
        "school": "IDEA FRONTIER COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021111952",
    },
    {
        "school": "ST ANTHONY SCHOOL",
        "district": "ST ANTHONY SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024811778",
    },
    {
        "school": "KIPP AUSTIN COLLEGIATE",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026411782",
    },
    {
        "school": "KUJAWA EC/PK/K",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771011785",
    },
    {
        "school": "JONES EC/PK/K",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771011867",
    },
    {
        "school": "VICTORY EARLY COLLEGE H S",
        "district": "ALDINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771011879",
    },
    {
        "school": "JONES EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771011899",
    },
    {
        "school": "MCCALL EL",
        "district": "ALEDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480778011935",
    },
    {
        "school": "HOLMQUIST EL",
        "district": "ALIEF ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783011887",
    },
    {
        "school": "SAVANNAH LAKES EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809011776",
    },
    {
        "school": "LBJ ECHS",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011844",
    },
    {
        "school": "LASA H S",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894011930",
    },
    {
        "school": "THE MARY CATHERINE HARRIS SCHOOL-SCHOOL OF CHOICE",
        "district": "BRYAN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481179011886",
    },
    {
        "school": "NORTHWEST EARLY COLLEGE H S (NWECHS)",
        "district": "CANUTILLO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481278011864",
    },
    {
        "school": "CLEAR SPRINGS H S",
        "district": "CLEAR CREEK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428011984",
    },
    {
        "school": "SANTA FE EL",
        "district": "CLEBURNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481431011903",
    },
    {
        "school": "OAK CREEK EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473011768",
    },
    {
        "school": "JOHNSON RANCH EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473011815",
    },
    {
        "school": "KINDER RANCH EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473011820",
    },
    {
        "school": "MORNINGSIDE EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473011910",
    },
    {
        "school": "CLEAR SPRING EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473011919",
    },
    {
        "school": "PIEPER RANCH MIDDLE",
        "district": "COMAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473011943",
    },
    {
        "school": "MT VALLEY MIDDLE",
        "district": "COMAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473011948",
    },
    {
        "school": "LUBBOCK-COOPER WEST EL",
        "district": "LUBBOCK-COOPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481518011875",
    },
    {
        "school": "NEW TECH H S AT COPPELL",
        "district": "COPPELL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521011781",
    },
    {
        "school": "ROBINSON EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011909",
    },
    {
        "school": "HEMMENWAY EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611011956",
    },
    {
        "school": "H S POINT",
        "district": "DEER PARK ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481653011769",
    },
    {
        "school": "BLANTON EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674011871",
    },
    {
        "school": "HARPOOL MIDDLE",
        "district": "DENTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674011881",
    },
    {
        "school": "NORTHBROOK EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770011869",
    },
    {
        "school": "LAKE POINTE EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770011880",
    },
    {
        "school": "PARKVIEW EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770011940",
    },
    {
        "school": "EASTLAND CARE CAMPUS",
        "district": "EASTLAND ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481796011873",
    },
    {
        "school": "EDNA EL",
        "district": "EDNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481821011816",
    },
    {
        "school": "EVADALE J H",
        "district": "EVADALE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481875011904",
    },
    {
        "school": "JAN SCHIFF EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965011961",
    },
    {
        "school": "PK SATELLITE CENTERS",
        "district": "FORT WORTH ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970011911",
    },
    {
        "school": "OAK RIDGE EL",
        "district": "FRENSHIP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983011795",
    },
    {
        "school": "SAM HOUSTON EL",
        "district": "GALENA PARK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025011866",
    },
    {
        "school": "GOLIAD EL",
        "district": "GOLIAD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482103011823",
    },
    {
        "school": "HUFFMAN EL",
        "district": "HUFFMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482382011918",
    },
    {
        "school": "KCISD - DAEP",
        "district": "KARNES CITY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482514011954",
    },
    {
        "school": "MORTON RANCH EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517011835",
    },
    {
        "school": "BONNIE HOLLAND EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517011840",
    },
    {
        "school": "WOODCREEK J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517011937",
    },
    {
        "school": "TIMBER CREEK H S",
        "district": "KELLER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526011897",
    },
    {
        "school": "CAPROCK EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526011964",
    },
    {
        "school": "BASSWOOD EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526011970",
    },
    {
        "school": "KOUNTZE INT",
        "district": "KOUNTZE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482592011977",
    },
    {
        "school": "H F MCNEILL EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658011833",
    },
    {
        "school": "GEORGE RANCH H S",
        "district": "LAMAR CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658011891",
    },
    {
        "school": "READING J H",
        "district": "LAMAR CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658011978",
    },
    {
        "school": "LASARA H S",
        "district": "LASARA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482685011951",
    },
    {
        "school": "ROUSE H S",
        "district": "LEANDER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703011944",
    },
    {
        "school": "AMI KIDS RIO GRANDE VALLEY (FKA RGMI)",
        "district": "LOS FRESNOS CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482829011868",
    },
    {
        "school": "LOUISE J H",
        "district": "LOUISE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482835011929",
    },
    {
        "school": "ROBERT L PUSTER EL",
        "district": "LOVEJOY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482838011892",
    },
    {
        "school": "TALKINGTON SCHOOL FOR YOUNG WOMEN LEADERS",
        "district": "LUBBOCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850011896",
    },
    {
        "school": "MABANK INT",
        "district": "MABANK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482868011779",
    },
    {
        "school": "LINDA JOBE MIDDLE",
        "district": "MANSFIELD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011818",
    },
    {
        "school": "NANCY NEAL EL",
        "district": "MANSFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892011851",
    },
    {
        "school": "ACHIEVE EARLY COLLEGE H S",
        "district": "MCALLEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967011859",
    },
    {
        "school": "THIGPEN-ZAVALA EL",
        "district": "MCALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967011960",
    },
    {
        "school": "NORTH CREEK EL",
        "district": "MELISSA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483012011883",
    },
    {
        "school": "PORTER H S",
        "district": "NEW CANEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240011842",
    },
    {
        "school": "JOHNSON H S",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294011973",
    },
    {
        "school": "FORESTER EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312011780",
    },
    {
        "school": "VALE MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312011794",
    },
    {
        "school": "CARNAHAN EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312011863",
    },
    {
        "school": "SCARBOROUGH EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312011958",
    },
    {
        "school": "ALLEN & WILLIAM ARNOLD EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486011905",
    },
    {
        "school": "PLEASANTON ISD SCHOOL OF CHOICE",
        "district": "PLEASANTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483519011945",
    },
    {
        "school": "JOHN A BAKER",
        "district": "PROSPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600011847",
    },
    {
        "school": "HERMAN E UTLEY MIDDLE",
        "district": "ROCKWALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765011839",
    },
    {
        "school": "YOUNG WOMEN'S LEADERSHIP ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873011806",
    },
    {
        "school": "BUTTERFIELD EL",
        "district": "SANGER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483918011811",
    },
    {
        "school": "SANGER SIXTH GRADE CAMPUS",
        "district": "SANGER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483918011936",
    },
    {
        "school": "H M CARROLL EL",
        "district": "SHELDON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483999011827",
    },
    {
        "school": "CAROLEE BOOKER ELEMENTARY",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122011894",
    },
    {
        "school": "TENAHA SCHOOLS",
        "district": "TENAHA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484236011969",
    },
    {
        "school": "TOLAR J H",
        "district": "TOLAR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484290011962",
    },
    {
        "school": "CANYON POINTE EL",
        "district": "TOMBALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296011799",
    },
    {
        "school": "CREEKSIDE FOREST EL",
        "district": "TOMBALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296011921",
    },
    {
        "school": "VAN MIDDLE",
        "district": "VAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484392011810",
    },
    {
        "school": "FAMILY CONNECTION - CHILD DEVELOPMENT CENTER",
        "district": "VICTORIA ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415011927",
    },
    {
        "school": "STANTON-SMITH EL",
        "district": "WHITEHOUSE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484560011787",
    },
    {
        "school": "SCOTLAND PARK EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578011915",
    },
    {
        "school": "SOUTHERN HILLS EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578011922",
    },
    {
        "school": "W LLOYD MEADOR EL",
        "district": "WILLIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484590011830",
    },
    {
        "school": "WYLIE WEST EARLY CHILDHOOD CENTER",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484650011890",
    },
    {
        "school": "VALLE VERDE EARLY COLLEGE H S",
        "district": "YSLETA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668011982",
    },
    {
        "school": "Hidden Hollow School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001200",
    },
    {
        "school": "Beaver Preschool",
        "district": "Beaver District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490006001257",
    },
    {
        "school": "Open Classroom",
        "district": "Open Classroom",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490011801135",
    },
    {
        "school": "Mountainside School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012001227",
    },
    {
        "school": "Cache Preschool",
        "district": "Cache District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490012001251",
    },
    {
        "school": "Gateway Preparatory Academy",
        "district": "Gateway Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012201214",
    },
    {
        "school": "Salt Lake Center for Science Education",
        "district": "Salt Lake Center for Science Education",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012301208",
    },
    {
        "school": "Providence Hall",
        "district": "Providence Hall",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012401202",
    },
    {
        "school": "Rockwell Charter High School",
        "district": "Rockwell Charter High School",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012501199",
    },
    {
        "school": "Utah Virtual Academy",
        "district": "Utah Virtual Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490013001196",
    },
    {
        "school": "Merit College Preparatory Academy",
        "district": "Merit College Preparatory Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490013101220",
    },
    {
        "school": "Quest Academy",
        "district": "Quest Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490013201218",
    },
    {
        "school": "Venture Academy",
        "district": "Venture Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490013301216",
    },
    {
        "school": "Bruin Point School",
        "district": "Carbon District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015001209",
    },
    {
        "school": "Daggett Preschool",
        "district": "Daggett District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490018001252",
    },
    {
        "school": "Ellison Park School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001195",
    },
    {
        "school": "Syracuse High",
        "district": "Davis District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001205",
    },
    {
        "school": "Snow Horse School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001206",
    },
    {
        "school": "Buffalo Point School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001221",
    },
    {
        "school": "C R Sundwall Center",
        "district": "Grand District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490033001236",
    },
    {
        "school": "Headstart Preschool Special Education",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490036001237",
    },
    {
        "school": "Three Peaks Pre School",
        "district": "Iron District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490039001238",
    },
    {
        "school": "Iron County Preschool",
        "district": "Iron District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490039001240",
    },
    {
        "school": "Falcon Ridge School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001213",
    },
    {
        "school": "Midas Creek School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001223",
    },
    {
        "school": "Eastlake School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001225",
    },
    {
        "school": "Preschool (Sp Ed)",
        "district": "Jordan District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490042001243",
    },
    {
        "school": "Kane Preschool",
        "district": "Kane District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490048001258",
    },
    {
        "school": "Riverside Preschool",
        "district": "Logan City District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490051001234",
    },
    {
        "school": "Mountain Green School",
        "district": "Morgan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490057001259",
    },
    {
        "school": "Morgan Preschool",
        "district": "Morgan District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490057001260",
    },
    {
        "school": "Early Childhood Center",
        "district": "Murray District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490060001248",
    },
    {
        "school": "Cherry Creek School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001253",
    },
    {
        "school": "North Summit Preschool",
        "district": "North Summit District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490069001254",
    },
    {
        "school": "Ogden Preschool",
        "district": "Ogden City District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490072001232",
    },
    {
        "school": "MPES Preschool",
        "district": "Park City District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490075001255",
    },
    {
        "school": "Mc Polin Preschool",
        "district": "Park City District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490075001256",
    },
    {
        "school": "Circleville Preschool",
        "district": "Piute District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490078001261",
    },
    {
        "school": "Oscarson Preschool",
        "district": "Piute District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490078001262",
    },
    {
        "school": "Sunrise Preschool",
        "district": "Provo District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490081001233",
    },
    {
        "school": "Rich Preschool",
        "district": "Rich District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490084001264",
    },
    {
        "school": "Salt Lake Head Start",
        "district": "Salt Lake District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087001230",
    },
    {
        "school": "South Summit Preschool",
        "district": "South Summit District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490099001244",
    },
    {
        "school": "Tintic Preschool",
        "district": "Tintic District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490102001245",
    },
    {
        "school": "Early Learning Center",
        "district": "Tooele District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490105001246",
    },
    {
        "school": "Clarke N. Johnsen Jr High",
        "district": "Tooele District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105001263",
    },
    {
        "school": "Uintah Online School",
        "district": "Uintah District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490108001222",
    },
    {
        "school": "Uintah Specialized Preschool",
        "district": "Uintah District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490108001247",
    },
    {
        "school": "Tonaquint Intermediate",
        "district": "Washington District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001198",
    },
    {
        "school": "Desert Hills Middle",
        "district": "Washington District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001226",
    },
    {
        "school": "Canyon View Preschool",
        "district": "Weber District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490120001249",
    },
    {
        "school": "River Valley Technical Center",
        "district": "River Valley Technical Center",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500037100097",
    },
    {
        "school": "ALBEMARLE COUNTY COMMUNITY PUBLIC CHARTER",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510009002796",
    },
    {
        "school": "RUSTBURG MIDDLE",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060002771",
    },
    {
        "school": "LEWIS & CLARK ELEM",
        "district": "CAROLINE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510066002784",
    },
    {
        "school": "GRASSFIELD HIGH",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510081002765",
    },
    {
        "school": "TOMAHAWK CREEK MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002754",
    },
    {
        "school": "ELIZABETH DAVIS MIDDLE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002767",
    },
    {
        "school": "ELIZABETH SCOTT ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002779",
    },
    {
        "school": "WINTERPOCK ELEM",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084002780",
    },
    {
        "school": "YOWELL ELEM",
        "district": "CULPEPER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510105002748",
    },
    {
        "school": "EASTERN VIEW HIGH",
        "district": "CULPEPER CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510105002758",
    },
    {
        "school": "ALC AT MONTROSE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510126002790",
    },
    {
        "school": "KETTLE RUN HIGH SCH",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132002785",
    },
    {
        "school": "GREENVILLE ELEM",
        "district": "FAUQUIER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510132002786",
    },
    {
        "school": "WINDY GAP ELEM",
        "district": "FRANKLIN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510144002763",
    },
    {
        "school": "FRIES ELEMENTARY",
        "district": "GRAYSON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510169002747",
    },
    {
        "school": "CLUSTER SPRINGS ELEM",
        "district": "HALIFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510177002745",
    },
    {
        "school": "SOUTH BOSTON ELEM",
        "district": "HALIFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510177002759",
    },
    {
        "school": "SINAI ELEM",
        "district": "HALIFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510177002769",
    },
    {
        "school": "LAUREL MEADOW ELEM",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510183002772",
    },
    {
        "school": "THE HANOVER CTR. FOR TRADES AND TECH.",
        "district": "HANOVER CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510183002775",
    },
    {
        "school": "SMITHLAND ELEM",
        "district": "HARRISONBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510186002761",
    },
    {
        "school": "SKYLINE MIDDLE",
        "district": "HARRISONBURG CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510186002766",
    },
    {
        "school": "COLONIAL TRAIL ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002756",
    },
    {
        "school": "ELKO MIDDLE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002757",
    },
    {
        "school": "HARVIE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002788",
    },
    {
        "school": "ROSA LEE CARTER ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002751",
    },
    {
        "school": "SYCOLIN CREEK ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002755",
    },
    {
        "school": "ARCOLA ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002762",
    },
    {
        "school": "STONE HILL MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002764",
    },
    {
        "school": "CREIGHTON'S CORNER ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002773",
    },
    {
        "school": "LIBERTY ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002774",
    },
    {
        "school": "STEUART W. WELLER ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002776",
    },
    {
        "school": "TURNING POINT ALT. ED.",
        "district": "ORANGE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510282002746",
    },
    {
        "school": "REDIRECTION ALT. ED.",
        "district": "ORANGE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510282002760",
    },
    {
        "school": "VERNON JOHNS MIDDLE",
        "district": "PETERSBURG CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510291002794",
    },
    {
        "school": "FLAT ROCK ELEM",
        "district": "POWHATAN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510303002789",
    },
    {
        "school": "GAINESVILLE MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002753",
    },
    {
        "school": "FANNIE W. FITZGERALD ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002783",
    },
    {
        "school": "SAMUEL L. GRAVELY JR. ELEM SCH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002787",
    },
    {
        "school": "MARY G. PORTER TRADITIONAL",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002798",
    },
    {
        "school": "FOREST PARK ACADEMY",
        "district": "ROANOKE CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510330002797",
    },
    {
        "school": "CUB RUN ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339002782",
    },
    {
        "school": "COURTHOUSE ACADEMY PRGM.",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510364002749",
    },
    {
        "school": "CEDAR FOREST ELEM",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510364002768",
    },
    {
        "school": "JOHN J. WRIGHT ED. AND CULTURAL CTR.",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510364002793",
    },
    {
        "school": "SHIRLEY C. HEIM MIDDLE",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366002781",
    },
    {
        "school": "HILLPOINT ELEM",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371002777",
    },
    {
        "school": "DIAMOND SPRINGS ELEM",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002770",
    },
    {
        "school": "Northwest Career and Technical High School",
        "district": "Clover Park Technical College",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530001703209",
    },
    {
        "school": "Tukes Valley Middle School",
        "district": "Battle Ground School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038003214",
    },
    {
        "school": "Tukes Valley Primary",
        "district": "Battle Ground School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038003228",
    },
    {
        "school": "Wade King Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042003225",
    },
    {
        "school": "Birth To Three",
        "district": "Cheney School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530123003218",
    },
    {
        "school": "BIRTH TO 2 PRESCHOOL",
        "district": "Deer Park School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530207003237",
    },
    {
        "school": "Eastmont Preschools",
        "district": "Eastmont School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530231003236",
    },
    {
        "school": "Union High School",
        "district": "Evergreen School District (Clark)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270003222",
    },
    {
        "school": "Federal Way Running Start Home School",
        "district": "Federal Way School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282003232",
    },
    {
        "school": "Learning Support",
        "district": "Franklin Pierce School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294003216",
    },
    {
        "school": "Valley View Early Childhood Center",
        "district": "Highline School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354003220",
    },
    {
        "school": "Career Link",
        "district": "Highline School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530354003224",
    },
    {
        "school": "Phoenix High School",
        "district": "Kennewick School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530393003231",
    },
    {
        "school": "Grove Elementary",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486003235",
    },
    {
        "school": "Mead PreSchool",
        "district": "Mead School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530492003221",
    },
    {
        "school": "Mount Baker Academy",
        "district": "Mount Baker School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530531003211",
    },
    {
        "school": "Pend Oreille River School",
        "district": "Newport School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530561003234",
    },
    {
        "school": "Roosevelt Elementary School",
        "district": "Port Angeles School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530682003230",
    },
    {
        "school": "Glacier Peak High School",
        "district": "Snohomish School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530802003217",
    },
    {
        "school": "Spokane Regional Health District",
        "district": "Spokane School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825003213",
    },
    {
        "school": "Lincoln Academy",
        "district": "Stanwood-Camano School District",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530834003223",
    },
    {
        "school": "Sky Valley Options",
        "district": "Sultan School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530855003210",
    },
    {
        "school": "Mattawa Elementary Pre-School",
        "district": "Wahluke School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530936003227",
    },
    {
        "school": "HUNTINGTON MIDDLE SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018001465",
    },
    {
        "school": "SOUTHSIDE ELEMENTARY",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018001466",
    },
    {
        "school": "BIG OTTER ELEMENTARY SCHOOL",
        "district": "CLAY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540024001467",
    },
    {
        "school": "HARRISON CO EVOLUTION HIGH SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051001469",
    },
    {
        "school": "WILDWOOD MIDDLE SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057001463",
    },
    {
        "school": "WASHINGTON HIGH SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057001464",
    },
    {
        "school": "SOUTHSIDE K-8",
        "district": "MCDOWELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540081001468",
    },
    {
        "school": "MOUNTAIN VIEW ELEMENTARY SCHOOL",
        "district": "PUTNAM COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540120001470",
    },
    {
        "school": "Gresham High",
        "district": "Gresham School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550005602740",
    },
    {
        "school": "Gresham Elementary",
        "district": "Gresham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550005602748",
    },
    {
        "school": "Fox Cities Leadership Academy",
        "district": "Appleton Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002724",
    },
    {
        "school": "Kaleidoscope Academy",
        "district": "Appleton Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002759",
    },
    {
        "school": "Barron Area Montessori School",
        "district": "Barron Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550087002717",
    },
    {
        "school": "Promethean Charter School",
        "district": "Butternut School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550192002751",
    },
    {
        "school": "Discovery Charter School",
        "district": "Columbus School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550282002734",
    },
    {
        "school": "Fort Atkinson 4K",
        "district": "Fort Atkinson School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550474002749",
    },
    {
        "school": "iForward",
        "district": "Grantsburg School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550567002704",
    },
    {
        "school": "Bay Harbor Elementary",
        "district": "Howard-Suamico School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550663002709",
    },
    {
        "school": "River Crest Elementary",
        "district": "Hudson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550669002735",
    },
    {
        "school": "TAGOS Leadership Acad",
        "district": "Janesville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702002691",
    },
    {
        "school": "Harborside Academy",
        "district": "Kenosha School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732002754",
    },
    {
        "school": "Kenosha School of Technology Enhanced Curriculum",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732002758",
    },
    {
        "school": "McKinley Academy",
        "district": "Manitowoc School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550861002701",
    },
    {
        "school": "Merrill Adult Diploma Academy",
        "district": "Merrill Area School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550921002743",
    },
    {
        "school": "James Madison Academic Campus",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002700",
    },
    {
        "school": "Banner Preparatory School of Milwaukee",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960002707",
    },
    {
        "school": "Milwaukee Academy of Chinese Language",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002720",
    },
    {
        "school": "North Division High 0419",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002730",
    },
    {
        "school": "Wedgewood Park School",
        "district": "Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002737",
    },
    {
        "school": "Siefert Elementary",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002744",
    },
    {
        "school": "Carmen High School of Science and Technology South Campus",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002755",
    },
    {
        "school": "Transition High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960002760",
    },
    {
        "school": "Together 4 Kids School",
        "district": "Monona Grove School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550981002703",
    },
    {
        "school": "NR4Kids",
        "district": "New Richmond School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551062002757",
    },
    {
        "school": "New Path",
        "district": "Oconto Falls Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551095002736",
    },
    {
        "school": "Franklin Elementary",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119002699",
    },
    {
        "school": "Shapiro STEM Academy",
        "district": "Oshkosh Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119002719",
    },
    {
        "school": "Ready 4 Learning School",
        "district": "Oshkosh Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551119002723",
    },
    {
        "school": "Woodridge Elementary",
        "district": "Portage Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551206002711",
    },
    {
        "school": "Bull Early Education Center",
        "district": "Racine Unified School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236002708",
    },
    {
        "school": "George D Warriner High School for Personalized Learning",
        "district": "Sheboygan Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365002695",
    },
    {
        "school": "Northeast Wisconsin Montessori Charter School",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365002712",
    },
    {
        "school": "Etude Elementary",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365002716",
    },
    {
        "school": "Lake Country Academy - Charter",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365002733",
    },
    {
        "school": "Point 4 the Future",
        "district": "Stevens Point Area Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449002739",
    },
    {
        "school": "Creekside Elementary",
        "district": "Sun Prairie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464002756",
    },
    {
        "school": "Waukesha Engineering Preparatory Academy",
        "district": "Waukesha School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002688",
    },
    {
        "school": "Enrich Excel Achieve Learning Academy",
        "district": "Wausau School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551590002747",
    },
    {
        "school": "Wauwatosa STEM",
        "district": "Wauwatosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002728",
    },
    {
        "school": "Wauzeka Middle",
        "district": "Wauzeka-Steuben School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551602002738",
    },
    {
        "school": "Hemlock Creek Elementary",
        "district": "West De Pere School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551632002726",
    },
    {
        "school": "Phantom Knight School of Opportunity",
        "district": "West De Pere School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551632002752",
    },
    {
        "school": "HEM Junior/Senior High School",
        "district": "Carbon County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560170000385",
    },
    {
        "school": "Encampment K-12 School",
        "district": "Carbon County School District #2",
        "level": "Other",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560170000387",
    },
    {
        "school": "Saratoga Middle/High School",
        "district": "Carbon County School District #2",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560170000390",
    },
    {
        "school": "Sunrise Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000396",
    },
    {
        "school": "Ten Sleep K-12",
        "district": "Washakie County School District #2",
        "level": "Other",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560582000393",
    },
    {
        "school": "HECTOR HERNANDEZ ARANA (INTERMEDIA BO PILETAS)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001802",
    },
    {
        "school": "SUPERIOR VOC ELADIO RIVERA QUINONES (SUPERIOR VOC DE LOIZA)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001803",
    },
    {
        "school": "NUEVA ELEM BO QUEBRADA NEGRITO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001813",
    },
    {
        "school": "SUPERIOR VOCACIONAL NUEVA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001817",
    },
    {
        "school": "VIOLETA REYES PEREZ (ELEMENTAL URBANA K-6)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001829",
    },
    {
        "school": "VICENTE ACEVEDO BALLESTER",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001838",
    },
    {
        "school": "MILDRED ARROYO CARDOZA (SEGUNDA UNIDAD BO PUERTO REAL)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001856",
    },
    {
        "school": "ROBERTO SILVA MORALES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001860",
    },
    {
        "school": "ANTONIO FERNOS ISERN",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001862",
    },
    {
        "school": "ADRIAN TORRES TORRES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001882",
    },
    {
        "school": "EUGENIO MARIA DE HOSTOS (SUPERIOR)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001884",
    },
    {
        "school": "ALFREDO ANDREWS ELEMENTARY SCHOOL",
        "district": "Saint Croix School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780000200002",
    },
    {
        "school": "ARTHUR A. RICHARDS JUNIOR HIGH SCHOOL",
        "district": "Saint Croix School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780000200003",
    },
    {
        "school": "CLAUDE O. MARKOE ELEMENTARY SCHOOL",
        "district": "Saint Croix School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780000200006",
    },
    {
        "school": "ST. CROIX EDUCATIONAL COMPLEX VOCATIONAL SCHOOL",
        "district": "Saint Croix School District",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VI",
        "nces_id": "780000200007",
    },
    {
        "school": "EULALIE RIVERA ELEMENTARY SCHOOL",
        "district": "Saint Croix School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780000200011",
    },
    {
        "school": "ST. CROIX EDUCATIONAL COMPEX HIGH SCHOOL",
        "district": "Saint Croix School District",
        "level": "High",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780000200013",
    },
    {
        "school": "JUANITA GARDINE ELEMENTARY SCHOOL",
        "district": "Saint Croix School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780000200021",
    },
    {
        "school": "LEW MUCKLE ELEMENTARY SCHOOL",
        "district": "Saint Croix School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780000200023",
    },
    {
        "school": "PEARL B. LARSEN ELEMENTARY SCHOOL",
        "district": "Saint Croix School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780000200028",
    },
    {
        "school": "RICARDO RICHARDS ELEMENTARY SCCHOOL",
        "district": "Saint Croix School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780000200029",
    },
    {
        "school": "SAINT CROIX CENTRAL HIGH",
        "district": "Saint Croix School District",
        "level": "High",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780000200030",
    },
    {
        "school": "JOHN H. WOODSON JUNIOR HIGH SCHOOL",
        "district": "Saint Croix School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VI",
        "nces_id": "780000200037",
    },
    {
        "school": "Albertville Primary School",
        "district": "Albertville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000502150",
    },
    {
        "school": "Saraland Middle SchoolAdams Campus",
        "district": "Saraland City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018500893",
    },
    {
        "school": "Saraland Elementary School",
        "district": "Saraland City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018500952",
    },
    {
        "school": "Georgiana School",
        "district": "Butler County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10051002144",
    },
    {
        "school": "Redland Elementary School",
        "district": "Elmore County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129002142",
    },
    {
        "school": "Airport Road Intermediate School",
        "district": "Elmore County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10129002147",
    },
    {
        "school": "Williams Middle School",
        "district": "Huntsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180002146",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243002151",
    },
    {
        "school": "Carr Middle School",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243002152",
    },
    {
        "school": "Central Freshman Academy",
        "district": "Phenix City",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10270002140",
    },
    {
        "school": "Tuscaloosa Magnet School  Middle",
        "district": "Tuscaloosa City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336002143",
    },
    {
        "school": "Tuscaloosa Magnet School  Elementary",
        "district": "Tuscaloosa City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10336002145",
    },
    {
        "school": "Alaska Native Cultural Charter School",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000736",
    },
    {
        "school": "Thunder Mountain High School",
        "district": "Juneau Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000737",
    },
    {
        "school": "Yaakoosge Daakahidi Alt. H.S.",
        "district": "Juneau Borough School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20021000738",
    },
    {
        "school": "Fronteras Charter School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000740",
    },
    {
        "school": "Ombudsman - Charter Valencia",
        "district": "Ombudsman Educational Services Ltd.a subsidiary  (4323)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40010302950",
    },
    {
        "school": "Paradise Honors High School",
        "district": "Paragon Management Inc. (5180)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40024102957",
    },
    {
        "school": "E-Institute at Metro",
        "district": "E-Institute Charter Schools Inc. (79059)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40031102919",
    },
    {
        "school": "CVIT - Globe High School",
        "district": "Cobre Valley Institute of Technology District (79391)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40031602940",
    },
    {
        "school": "CAVIAT - CCC Central Campus",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034702944",
    },
    {
        "school": "CAVIT - San Tan Foothills High School",
        "district": "Central Arizona Valley Institute of Technology (79385)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034802917",
    },
    {
        "school": "TIA West",
        "district": "Tucson International Academy Inc. (79979)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40037302889",
    },
    {
        "school": "TIA East",
        "district": "Tucson International Academy Inc. (79979)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40037302936",
    },
    {
        "school": "Biyaagozhoo Center",
        "district": "Gila County Regional School District (87600)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40041902897",
    },
    {
        "school": "ASDB/Phoenix Day School",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046302884",
    },
    {
        "school": "Eastern Highlands Region (EHR)",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046302892",
    },
    {
        "school": "SOUTHEAST REGION",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046302900",
    },
    {
        "school": "ASDB/Tucson Blind School",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046302918",
    },
    {
        "school": "DESERT VALLEYS REGION",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046302921",
    },
    {
        "school": "ASDB/Tucson Deaf School",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046302923",
    },
    {
        "school": "SOUTHWEST REGION",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046302924",
    },
    {
        "school": "NORTH CENTRAL REGION",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046302927",
    },
    {
        "school": "Children First Leadership Academy",
        "district": "Edkey Inc. - Sequoia Ranch School (81052)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40064102881",
    },
    {
        "school": "Children First Academy - Tempe",
        "district": "Edkey Inc. - Sequoia Ranch School (81052)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40064102953",
    },
    {
        "school": "Great Hearts Academies - Glendale Prep",
        "district": "Glendale Preparatory Academy (89829)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40076002911",
    },
    {
        "school": "Tempe Preparatory Junior Academy",
        "district": "Tempe Preparatory Junior Academy (89947)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40076102947",
    },
    {
        "school": "EAGLE College Prep",
        "district": "EAGLE South Mountain Charter Inc. (89850)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40076302915",
    },
    {
        "school": "Imagine Coolidge Elementary",
        "district": "Imagine Coolidge Elementary Inc. (89786)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40076602901",
    },
    {
        "school": "Pima Partnership Academy",
        "district": "Pima Prevention Partnership dba Pima Partnership A (89864)",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40076802913",
    },
    {
        "school": "Imagine Prep Coolidge",
        "district": "Imagine Prep Coolidge Inc. (90034)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40076902956",
    },
    {
        "school": "Imagine Prep Surprise",
        "district": "Imagine Prep Surprise Inc. (89790)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40077002903",
    },
    {
        "school": "Sky Islands",
        "district": "Blue Adobe Project (89871)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40077102899",
    },
    {
        "school": "Sonoran Science Academy East",
        "district": "Daisy Education Corporation dba Sonoran Science Ac (89915)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40077402934",
    },
    {
        "school": "San Tan Charter School",
        "district": "San Tan Montessori School Inc. (89798)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40077502916",
    },
    {
        "school": "Sonoran Science Academy - Phoenix",
        "district": "Daisy Education Corporation dba Sonoran Science Ac (89914)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40077602387",
    },
    {
        "school": "Paragon Science Academy",
        "district": "Daisy Education Corporation dba Paragon Science Ac (89917)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40077802902",
    },
    {
        "school": "Imagine Avondale Elementary",
        "district": "Imagine Avondale Elementary Inc. (89784)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40078002928",
    },
    {
        "school": "Math and Science Success Academy",
        "district": "Math and Science Success Academy Inc. (89852)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40078102910",
    },
    {
        "school": "Haven Montessori Charter School",
        "district": "Haven Montessori Children's House Inc. (89951)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40078202954",
    },
    {
        "school": "Imagine Prep Superstition",
        "district": "Imagine Prep Superstition Inc. (89788)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40078302932",
    },
    {
        "school": "AZ Compass Prep School",
        "district": "AZ Compass Schools Inc. (89869)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40078502929",
    },
    {
        "school": "Riverbend Prep",
        "district": "West Valley Arts and Technology Academy Inc. (90036)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40078602885",
    },
    {
        "school": "Copper Trails",
        "district": "Avondale Elementary District (4272)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096002880",
    },
    {
        "school": "Raul H. Castro Middle School",
        "district": "Cartwright Elementary District (4282)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40168002904",
    },
    {
        "school": "Vista Grande High School",
        "district": "Casa Grande Union High School District (4453)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40174002909",
    },
    {
        "school": "Ken 'Chief' Hill Learning Academy",
        "district": "Chandler Unified District #80 (4242)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002939",
    },
    {
        "school": "Charlotte Patterson Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002948",
    },
    {
        "school": "Haley Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002951",
    },
    {
        "school": "Great Beginnings Pre-School",
        "district": "Crane Elementary District (4501)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240002882",
    },
    {
        "school": "Riverview School",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002907",
    },
    {
        "school": "Magma Ranch K8 School",
        "district": "Florence Unified School District (4437)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292002893",
    },
    {
        "school": "Mt. Turnbull Academy",
        "district": "Fort Thomas Unified District (4221)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40320002946",
    },
    {
        "school": "Bright Futures Preschool",
        "district": "Humboldt Unified District (4469)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40387002926",
    },
    {
        "school": "Combs High School",
        "district": "J O Combs Unified School District (4445)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40399002895",
    },
    {
        "school": "Ranch Elementary School",
        "district": "J O Combs Unified School District (4445)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40399002938",
    },
    {
        "school": "Tres Rios Elementary School",
        "district": "Littleton Elementary District (4278)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40444002908",
    },
    {
        "school": "Desert Wind Middle School",
        "district": "Maricopa Unified School District (4441)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40472002914",
    },
    {
        "school": "Butterfield Elementary School",
        "district": "Maricopa Unified School District (4441)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40472002920",
    },
    {
        "school": "Saddleback Elementary School",
        "district": "Maricopa Unified School District (4441)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40472002922",
    },
    {
        "school": "Newell Barney Middle School",
        "district": "Queen Creek Unified District (4245)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681002886",
    },
    {
        "school": "Norterra Canyon School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775002959",
    },
    {
        "school": "Sierra Linda High School",
        "district": "Tolleson Union High School District (4288)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40852002912",
    },
    {
        "school": "EVIT - Desert Ridge High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102887",
    },
    {
        "school": "EVIT - Highland High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102890",
    },
    {
        "school": "EVIT - Mesquite High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102935",
    },
    {
        "school": "MANILA MIDDLE SCHOOL",
        "district": "MANILA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004601478",
    },
    {
        "school": "BERRYVILLE INTERMEDIATE SCH",
        "district": "BERRYVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50315001496",
    },
    {
        "school": "CONWAY AREA CAREER CENTER",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50459001480",
    },
    {
        "school": "CONWAY ADULT EDUCATION CENTER",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Career and Technical School",
        "state": "AR",
        "nces_id": "50459001482",
    },
    {
        "school": "WOODROW CUMMINS ELEMENTARY SCH",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459001486",
    },
    {
        "school": "DANVILLE MIDDLE SCHOOL",
        "district": "DANVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50489001488",
    },
    {
        "school": "DREW CENTRAL MIDDLE SCHOOL",
        "district": "DREW CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50547001492",
    },
    {
        "school": "REED ELEMENTARY SCHOOL",
        "district": "DUMAS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50550001481",
    },
    {
        "school": "BOB FOLSOM ELEMENTARY SCHOOL",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50609001490",
    },
    {
        "school": "GREENBRIER WOOSTER ELEMENTARY",
        "district": "GREENBRIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50690001476",
    },
    {
        "school": "MOUNTAIN VIEW MIDDLE SCHOOL",
        "district": "MOUNTAIN VIEW SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51020001491",
    },
    {
        "school": "NEMO VISTA MIDDLE SCHOOL",
        "district": "NEMO VISTA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51041001493",
    },
    {
        "school": "CHENAL ELEMENTARY SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185001484",
    },
    {
        "school": "ROGERS HERITAGE HIGH SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197001483",
    },
    {
        "school": "Krystal School of Science Math & Technology",
        "district": "Hesperia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001412415",
    },
    {
        "school": "Oak Hills High",
        "district": "Hesperia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001412417",
    },
    {
        "school": "Dorothy McElhinney Middle",
        "district": "Murrieta Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002912243",
    },
    {
        "school": "Murrieta Mesa High",
        "district": "Murrieta Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002912289",
    },
    {
        "school": "H. Allen Hight Elementary",
        "district": "Natomas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003612351",
    },
    {
        "school": "John C. Kimball High",
        "district": "Tracy Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004712372",
    },
    {
        "school": "Independence High",
        "district": "Paso Robles Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60004812391",
    },
    {
        "school": "Valley Community Day",
        "district": "Hughson Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006012334",
    },
    {
        "school": "Mesa Verde Elementary",
        "district": "Riverbank Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006112206",
    },
    {
        "school": "Sentinel High",
        "district": "Waterford Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006312193",
    },
    {
        "school": "Richard M. Moon Primary",
        "district": "Waterford Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006312220",
    },
    {
        "school": "Lucille Whitehead Intermediate",
        "district": "Waterford Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006312224",
    },
    {
        "school": "Harmony Magnet Academy",
        "district": "Porterville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006412356",
    },
    {
        "school": "Minarets High",
        "district": "Chawanakee Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60011612212",
    },
    {
        "school": "Alps View High (Continuation)",
        "district": "Trinity Alps Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60133106604",
    },
    {
        "school": "Trinity High",
        "district": "Trinity Alps Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133106605",
    },
    {
        "school": "Weaverville Elementary",
        "district": "Trinity Alps Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133106872",
    },
    {
        "school": "Del Paso Heights Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133201201",
    },
    {
        "school": "Fairbanks Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133201202",
    },
    {
        "school": "Foothill Ranch Middle",
        "district": "Twin Rivers Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133201984",
    },
    {
        "school": "Foothill High",
        "district": "Twin Rivers Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133201985",
    },
    {
        "school": "Grant Union High",
        "district": "Twin Rivers Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133201987",
    },
    {
        "school": "Highlands High",
        "district": "Twin Rivers Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133201988",
    },
    {
        "school": "Rio Linda High",
        "district": "Twin Rivers Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133201991",
    },
    {
        "school": "Rio Linda Preparatory Academy",
        "district": "Twin Rivers Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133201992",
    },
    {
        "school": "Rio Tierra Junior High",
        "district": "Twin Rivers Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133201993",
    },
    {
        "school": "Foothill Oaks Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133203711",
    },
    {
        "school": "Smythe Academy of Arts and Sciences",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133204148",
    },
    {
        "school": "D. W. Babcock Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133204149",
    },
    {
        "school": "Hagginwood Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133204151",
    },
    {
        "school": "Harmon Johnson Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133204152",
    },
    {
        "school": "Hazel Strauch Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133204153",
    },
    {
        "school": "Michael J. Castori Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133204154",
    },
    {
        "school": "Noralto Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133204155",
    },
    {
        "school": "Northwood Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133204156",
    },
    {
        "school": "Woodlake Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133204157",
    },
    {
        "school": "Westside Preparatory Charter",
        "district": "Twin Rivers Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205023",
    },
    {
        "school": "Warren A. Allison Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205094",
    },
    {
        "school": "Dry Creek Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205095",
    },
    {
        "school": "Frederick Joyce Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205096",
    },
    {
        "school": "Frontier Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205097",
    },
    {
        "school": "Hillsdale Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205098",
    },
    {
        "school": "Kohler Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205100",
    },
    {
        "school": "Madison Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205102",
    },
    {
        "school": "Oakdale Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205103",
    },
    {
        "school": "Orchard Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205104",
    },
    {
        "school": "Pioneer Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205105",
    },
    {
        "school": "Sierra View Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205107",
    },
    {
        "school": "Village Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205108",
    },
    {
        "school": "Woodridge Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133205109",
    },
    {
        "school": "Elwood J. Keema High",
        "district": "Twin Rivers Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60133207240",
    },
    {
        "school": "Pacific Career and Technology High",
        "district": "Twin Rivers Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60133207727",
    },
    {
        "school": "Miles P. Richmond",
        "district": "Twin Rivers Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60133207728",
    },
    {
        "school": "Martin Luther King Jr. Technology Academy",
        "district": "Twin Rivers Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133207729",
    },
    {
        "school": "Garden Valley Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133208818",
    },
    {
        "school": "Ridgepoint Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133208952",
    },
    {
        "school": "Westside Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133209623",
    },
    {
        "school": "Morey Avenue Early Childhood Development",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133209783",
    },
    {
        "school": "Vista Nueva Career and Technology High",
        "district": "Twin Rivers Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60133210598",
    },
    {
        "school": "Creative Connections Arts Academy",
        "district": "Twin Rivers Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133211074",
    },
    {
        "school": "Norwood Junior High",
        "district": "Twin Rivers Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133211201",
    },
    {
        "school": "Regency Park Elementary",
        "district": "Twin Rivers Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133211730",
    },
    {
        "school": "Dozier-Libbey Medical High",
        "district": "Antioch Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60285012278",
    },
    {
        "school": "Anna Hause Elementary",
        "district": "Beaumont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60429012345",
    },
    {
        "school": "Community Day",
        "district": "Benicia Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60462012327",
    },
    {
        "school": "Douglas J. Miller Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639012414",
    },
    {
        "school": "Calexico Community Day",
        "district": "Calexico Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60690012355",
    },
    {
        "school": "Centinela Valley Independent Study",
        "district": "Centinela Valley Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60792012265",
    },
    {
        "school": "Clovis Online Charter",
        "district": "Clovis Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903012267",
    },
    {
        "school": "Env Acad of Research Tech and Earth Scis",
        "district": "Conejo Valley Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60964012393",
    },
    {
        "school": "Louis VanderMolen Fundamental Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985012394",
    },
    {
        "school": "Da Vinci Charter Academy",
        "district": "Davis Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062012422",
    },
    {
        "school": "Shadow Hills High",
        "district": "Desert Sands Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111012319",
    },
    {
        "school": "Desert Ridge Academy",
        "district": "Desert Sands Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111012396",
    },
    {
        "school": "Cosumnes Oaks High",
        "district": "Elk Grove Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233012274",
    },
    {
        "school": "Elizabeth Pinkerton Middle",
        "district": "Elk Grove Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233012284",
    },
    {
        "school": "Etiwanda Community Day",
        "district": "Etiwanda Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61296012260",
    },
    {
        "school": "Vang Pao Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455012411",
    },
    {
        "school": "Vernon E. Greer Elementary",
        "district": "Galt Joint Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61479012430",
    },
    {
        "school": "Liberty Ranch High",
        "district": "Galt Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61482012403",
    },
    {
        "school": "Christopher High",
        "district": "Gilroy Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518012264",
    },
    {
        "school": "Granite Pointe Elementary",
        "district": "Greenfield Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61605012269",
    },
    {
        "school": "Sierra Pacific High",
        "district": "Hanford Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61650012317",
    },
    {
        "school": "Academy of Careers and Exploration",
        "district": "Helendale Elementary",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61686012368",
    },
    {
        "school": "Rancho Viejo Middle",
        "district": "Hemet Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692012275",
    },
    {
        "school": "Silas Bartsch",
        "district": "Kings Canyon Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970012257",
    },
    {
        "school": "Dunlap Leadership Academy",
        "district": "Kings Canyon Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970012321",
    },
    {
        "school": "John and Jacquelyn Miller Elementary",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088012421",
    },
    {
        "school": "Pride Continuation",
        "district": "Linden Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62181012338",
    },
    {
        "school": "Podesta Ranch Elementary",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62223012344",
    },
    {
        "school": "Ophir STEAM Academy",
        "district": "Loomis Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62256004416",
    },
    {
        "school": "Loomis Basin Charter",
        "district": "Loomis Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62256012246",
    },
    {
        "school": "Jack London Community Day",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271012188",
    },
    {
        "school": "Roy Romer Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012207",
    },
    {
        "school": "Enadia Way Technology Charter",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012217",
    },
    {
        "school": "Dr. James Edward Jones Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012223",
    },
    {
        "school": "Helen Bernstein High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012234",
    },
    {
        "school": "Los Angeles High School of the Arts",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012270",
    },
    {
        "school": "Edward R. Roybal Learning Center",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012295",
    },
    {
        "school": "Contreras Learning Center-Academic Leadership Community",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012314",
    },
    {
        "school": "School for the Visual Arts and Humanities",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012370",
    },
    {
        "school": "Crossroads Alternative Education Center",
        "district": "Los Banos Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62274012358",
    },
    {
        "school": "Parkwood Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334012280",
    },
    {
        "school": "Edgewater Elementary",
        "district": "Marysville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62409012398",
    },
    {
        "school": "Quail Valley Elementary",
        "district": "Menifee Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454012252",
    },
    {
        "school": "Southshore Elementary",
        "district": "Menifee Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454012286",
    },
    {
        "school": "Hans Christensen Middle",
        "district": "Menifee Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454012424",
    },
    {
        "school": "New Jerusalem",
        "district": "New Jerusalem Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62703012204",
    },
    {
        "school": "Ralph J. Bunche High",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62805012325",
    },
    {
        "school": "OUSD Home Sch",
        "district": "Orange Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62865012382",
    },
    {
        "school": "Orcutt Academy Charter",
        "district": "Orcutt Union Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62871012315",
    },
    {
        "school": "Juan Lagunas Soria Elementary",
        "district": "Oxnard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62922012389",
    },
    {
        "school": "Cabot Yerxa Elementary",
        "district": "Palm Springs Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955012316",
    },
    {
        "school": "Oak Tree Community Day",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62958012221",
    },
    {
        "school": "Paramount Park Middle",
        "district": "Paramount Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985012400",
    },
    {
        "school": "Alondra Middle",
        "district": "Paramount Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985012423",
    },
    {
        "school": "CIS Academy",
        "district": "Pasadena Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62994012340",
    },
    {
        "school": "Walnut Grove Elementary",
        "district": "Patterson Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63003012186",
    },
    {
        "school": "Frontier Elementary",
        "district": "Pioneer Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63051012323",
    },
    {
        "school": "Marina Vista Elementary",
        "district": "Pittsburg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060012268",
    },
    {
        "school": "Valadez Middle School Academy",
        "district": "Placentia-Yorba Linda Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066012371",
    },
    {
        "school": "Yorba Linda High",
        "district": "Placentia-Yorba Linda Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63066012429",
    },
    {
        "school": "Del Sur Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153012196",
    },
    {
        "school": "Del Norte High",
        "district": "Poway Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153012216",
    },
    {
        "school": "Willow Grove Elementary",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153012226",
    },
    {
        "school": "Citrus Valley High",
        "district": "Redlands Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207012254",
    },
    {
        "school": "Charlotte N. Werner Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237012308",
    },
    {
        "school": "Frank Augustus Miller Middle",
        "district": "Riverside Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315012406",
    },
    {
        "school": "Junction Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360012329",
    },
    {
        "school": "Antelope High",
        "district": "Roseville Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63363012310",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Salinas City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63393012359",
    },
    {
        "school": "Memorial Scholars & Athletes",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432012239",
    },
    {
        "school": "East Village High",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63432012303",
    },
    {
        "school": "Innovation Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432012352",
    },
    {
        "school": "Millennial Tech Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432012376",
    },
    {
        "school": "Joli Ann Leichtag Elementary",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488012201",
    },
    {
        "school": "Creekside Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513012242",
    },
    {
        "school": "Gale Ranch Middle",
        "district": "San Ramon Valley Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513012300",
    },
    {
        "school": "Heroes Elementary",
        "district": "Santa Ana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531012200",
    },
    {
        "school": "West Creek Academy",
        "district": "Saugus Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63597012401",
    },
    {
        "school": "Silver Valley Community Day",
        "district": "Silver Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63682012326",
    },
    {
        "school": "Spanos (Alex G.) Elementary",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801012281",
    },
    {
        "school": "Golden Oak Community",
        "district": "Sulphur Springs Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63822012288",
    },
    {
        "school": "Manuel F. Hernandez",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116012218",
    },
    {
        "school": "Mission Vista High",
        "district": "Vista Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64119012341",
    },
    {
        "school": "Riverbank Elementary",
        "district": "Washington Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64158012263",
    },
    {
        "school": "Walnut Grove Intermediate",
        "district": "West Covina Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200012337",
    },
    {
        "school": "Williams Upper Elementary",
        "district": "Williams Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64254012298",
    },
    {
        "school": "Chapman Heights Elementary",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64356012266",
    },
    {
        "school": "Mesa View Middle",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64356012413",
    },
    {
        "school": "Heritage CCCOE Special Education Programs",
        "district": "Contra Costa County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100512255",
    },
    {
        "school": "Madera County Independent Academy",
        "district": "Madera County Superintendent of Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101712301",
    },
    {
        "school": "Sugarloaf Mountain Juvenile Hall Program",
        "district": "Nevada County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102312339",
    },
    {
        "school": "Earle Jamieson Educational Options",
        "district": "Nevada County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102312369",
    },
    {
        "school": "Gerber Jr./Sr. High",
        "district": "Sacramento County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102712343",
    },
    {
        "school": "Canyon Oaks Youth Center",
        "district": "San Mateo County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103312367",
    },
    {
        "school": "Shasta County Independent Study",
        "district": "Shasta County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69103712305",
    },
    {
        "school": "University Preparatory High",
        "district": "Tulare County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69104512387",
    },
    {
        "school": "May Ranch Elementary",
        "district": "Val Verde Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113512262",
    },
    {
        "school": "EARLY COLLEGE OF ARVADA",
        "district": "State Charter School Institute",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006390",
    },
    {
        "school": "ANIMAS HIGH SCHOOL",
        "district": "State Charter School Institute",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006418",
    },
    {
        "school": "THOMAS MACLAREN STATE CHARTER SCHOOL",
        "district": "State Charter School Institute",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006437",
    },
    {
        "school": "COLORADO SCHOOL FOR THE DEAF AND BLIND",
        "district": "COLORADO SCHOOL FOR THE DEAF AND BLIND",
        "level": "Other",
        "type": "Special education school",
        "state": "CO",
        "nces_id": "80002306410",
    },
    {
        "school": "Village High School",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006434",
    },
    {
        "school": "AXL ACADEMY",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006399",
    },
    {
        "school": "JAMAICA CHILD DEVELOPMENT CENTER",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006411",
    },
    {
        "school": "PRAIRIE VIEW MIDDLE SCHOOL",
        "district": "School District 27J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006362",
    },
    {
        "school": "SD 27J PRESCHOOL AT THE BRIGHTON LRC",
        "district": "School District 27J",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006377",
    },
    {
        "school": "TURNBERRY ELEMENTARY",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006401",
    },
    {
        "school": "OTHO E STUART MIDDLE SCHOOL",
        "district": "School District 27J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006420",
    },
    {
        "school": "FOX RIDGE MIDDLE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006367",
    },
    {
        "school": "GALILEO SCHOOL OF MATH AND SCIENCE",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306006379",
    },
    {
        "school": "WEST ELEMENTARY SCHOOL",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306006416",
    },
    {
        "school": "JACK SWIGERT AEROSPACE ACADEMY",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306006421",
    },
    {
        "school": "ACHIEVE ONLINE",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80306006428",
    },
    {
        "school": "COLE ARTS AND SCIENCE ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006364",
    },
    {
        "school": "TREVISTA AT HORACE MANN",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006389",
    },
    {
        "school": "PLACE BRIDGE ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006398",
    },
    {
        "school": "GOLD RUSH ELEMENTARY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006368",
    },
    {
        "school": "MESA MIDDLE SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006371",
    },
    {
        "school": "EDCSD",
        "district": "Douglas County School District No. Re 1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006372",
    },
    {
        "school": "HOPE ONLINE LEARNING ACADEMY HIGH SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006391",
    },
    {
        "school": "CLEAR SKY ELEMENTARY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006392",
    },
    {
        "school": "LEGEND HIGH SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006400",
    },
    {
        "school": "CIMARRON MIDDLE",
        "district": "Douglas County School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006404",
    },
    {
        "school": "JUNE CREEK ELEMENTARY SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354006366",
    },
    {
        "school": "VAIL SKI AND SNOWBOARD ACADEMY (VSSA)",
        "district": "Eagle County School District No. Re 50",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80354006422",
    },
    {
        "school": "ESTES PARK OPTIONS SCHOOL",
        "district": "Estes Park School District R-3",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80381006426",
    },
    {
        "school": "Grand Peak Academy",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387006386",
    },
    {
        "school": "PATRIOT HIGH SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80387006403",
    },
    {
        "school": "VISTA RIDGE HIGH SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387006408",
    },
    {
        "school": "BETHKE ELEMENTARY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399006380",
    },
    {
        "school": "PSD GLOBAL ACADEMY",
        "district": "Poudre School District R-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399006431",
    },
    {
        "school": "CHIPETA ELEMENTARY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435006374",
    },
    {
        "school": "MESA VALLEY COMMUNITY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435006384",
    },
    {
        "school": "ATLAS PREPARATORY HIGH SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453006425",
    },
    {
        "school": "WARREN TECH NORTH",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CO",
        "nces_id": "80480006438",
    },
    {
        "school": "JEFFCO VIRTUAL ACADEMY",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80480006439",
    },
    {
        "school": "DESTINATIONS CAREER ACADEMY OF COLORADO",
        "district": "Julesburg School District No. Re1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80486006387",
    },
    {
        "school": "LONE STAR MIDDLE SCHOOL",
        "district": "Lone Star School District No. 101",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80534006376",
    },
    {
        "school": "BLUE MOUNTAIN ELEMENTARY",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006381",
    },
    {
        "school": "IMAGINE CHARTER",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006388",
    },
    {
        "school": "CENTENNIAL ELEMENTARY",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006397",
    },
    {
        "school": "BLACK ROCK ELEMENTARY",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006409",
    },
    {
        "school": "MEAD HIGH SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006423",
    },
    {
        "school": "ST. VRAIN COMMUNITY MONTESSORI SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006430",
    },
    {
        "school": "COYOTE RIDGE ELEMENTARY SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540006406",
    },
    {
        "school": "PONDEROSA ELEMENTARY",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540006432",
    },
    {
        "school": "NORTH VALLEY SCHOOL FOR YOUNG ADULTS",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80555006433",
    },
    {
        "school": "PALMER RIDGE HIGH SCHOOL",
        "district": "Lewis-Palmer Consolidated School District No. 38 in the co",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80582006369",
    },
    {
        "school": "CORWIN INTERNATIONAL MAGNET SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612006361",
    },
    {
        "school": "FOUNTAIN INTERNATIONAL MAGNET SCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612006378",
    },
    {
        "school": "SWALLOWS CHARTER ACADEMY HIGH SCHOOL",
        "district": "Pueblo County School District 70",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615006360",
    },
    {
        "school": "ELK CREEK ELEMENTARY",
        "district": "Garfield School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80624006396",
    },
    {
        "school": "GRAHAM MESA ELEMENTARY SCHOOL",
        "district": "Garfield School District No. Re-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80624006436",
    },
    {
        "school": "HORIZONS EXPLORATORY ACADEMY",
        "district": "Salida School District No. R-32",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80633006413",
    },
    {
        "school": "THE STUDIO SCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690006375",
    },
    {
        "school": "WESTGATE CHARTER",
        "district": "Adams 12 Five Star Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690006417",
    },
    {
        "school": "ADAMS12 FIVE STAR PRESCHOOL",
        "district": "Adams 12 Five Star Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690006435",
    },
    {
        "school": "Josephine Hodgkins Leadership Academy",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723006373",
    },
    {
        "school": "WIGGINS MIDDLE SCHOOL",
        "district": "School District No. Re-50 Wiggins",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80729006394",
    },
    {
        "school": "SEVERANCE MIDDLE SCHOOL",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735006427",
    },
    {
        "school": "Achievement First Hartford Academy",
        "district": "Achievement First Hartford Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90021201528",
    },
    {
        "school": "International Magnet School for Global Citizenship",
        "district": "Capitol Region Education Council",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001511",
    },
    {
        "school": "Academy of Aerospace and Engineering",
        "district": "Capitol Region Education Council",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001513",
    },
    {
        "school": "Reggio Magnet School of the Arts",
        "district": "Capitol Region Education Council",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001516",
    },
    {
        "school": "Civic Leadership High School",
        "district": "Capitol Region Education Council",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001532",
    },
    {
        "school": "Quinebaug Middle College",
        "district": "Eastern Connecticut Regional Educational Service Center",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90136001530",
    },
    {
        "school": "Montessori Magnet at Fisher School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001531",
    },
    {
        "school": "Breakthrough Magnet School North",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001534",
    },
    {
        "school": "Global Communications Academy",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001535",
    },
    {
        "school": "Elisabeth M. Bennet Academy",
        "district": "MANCHESTER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90231001533",
    },
    {
        "school": "Strong 21st Century Communications Magnet and SCSU Lab Schoo",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001509",
    },
    {
        "school": "Engineering - Science University Magnet School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001519",
    },
    {
        "school": "Harry S. Fisher Elementary School",
        "district": "PLYMOUTH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90333001521",
    },
    {
        "school": "Quaker Hill Elementary School",
        "district": "WATERFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90486001512",
    },
    {
        "school": "Las Americas ASPIRA Academy",
        "district": "Las Americas Aspira Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100005000342",
    },
    {
        "school": "Bunker Hill Elementary School",
        "district": "Appoquinimink School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000339",
    },
    {
        "school": "Oberle (William) Elementary School",
        "district": "Christina School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100020000343",
    },
    {
        "school": "Georgetown Middle School",
        "district": "Indian River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100068000245",
    },
    {
        "school": "Columbia Heights Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000396",
    },
    {
        "school": "Washington Metropolitan HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "DC",
        "nces_id": "110003000397",
    },
    {
        "school": "Phelps Architecture Construction and Engineering HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000407",
    },
    {
        "school": "Achievement Preparatory Academy PCS - Wahler Place MS",
        "district": "Achievement Preparatory Academy PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110007200405",
    },
    {
        "school": "Center City PCS - Capitol Hill",
        "district": "Center City PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110007300393",
    },
    {
        "school": "Center City PCS - Petworth",
        "district": "Center City PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110007300395",
    },
    {
        "school": "Center City PCS - Brightwood",
        "district": "Center City PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110007300400",
    },
    {
        "school": "Center City PCS - Trinidad",
        "district": "Center City PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110007300403",
    },
    {
        "school": "Center City PCS - Shaw",
        "district": "Center City PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110007300404",
    },
    {
        "school": "Center City PCS - Congress Heights",
        "district": "Center City PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110007300412",
    },
    {
        "school": "Washington Yu Ying PCS",
        "district": "Washington Yu Ying PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110007700411",
    },
    {
        "school": "FLORIDA VIRTUAL SCHOOL FLEX K-5",
        "district": "FL VIRTUAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120000207575",
    },
    {
        "school": "BREAKFAST POINT ACADEMY",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009007518",
    },
    {
        "school": "DEER POINT ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009007649",
    },
    {
        "school": "HERITAGE HIGH SCHOOL",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015007530",
    },
    {
        "school": "BREVARD VIRTUAL INSTRUCTION PROGRAM",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015007609",
    },
    {
        "school": "WEST BROWARD HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007555",
    },
    {
        "school": "SOMERSET ACADEMY EAST PREPARATORY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007569",
    },
    {
        "school": "OAKLEAF HIGH SCHOOL",
        "district": "CLAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030007558",
    },
    {
        "school": "LAW ENFORCEMENT OFFICERS MEMORIAL HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007496",
    },
    {
        "school": "SOMERSET ACADEMY ELEMENTARY SCHOOL SOUTH MIAMI CAMPUS",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007511",
    },
    {
        "school": "ARCHCREEK ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007515",
    },
    {
        "school": "CITRUS HEALTH SIPP/CRISIS",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007516",
    },
    {
        "school": "LINCOLN-MARTI CHARTER SCHOOL HIALEAH CAMPUS",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007517",
    },
    {
        "school": "DR. ROLANDO ESPINOSA K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007520",
    },
    {
        "school": "SOMERSET GABLES ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007525",
    },
    {
        "school": "KEYS GATE CHARTER HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007529",
    },
    {
        "school": "NORMAN S. EDELCUP/SUNNY ISLES BEACH K-8",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007533",
    },
    {
        "school": "LINCOLN-MARTI CHARTER SCHOOL LITTLE HAVANA CAMPUS",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007538",
    },
    {
        "school": "ACADEMIR CHARTER SCHOOL WEST",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007540",
    },
    {
        "school": "C. G. BETHEL HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007542",
    },
    {
        "school": "SOUTH FLORIDA AUTISM CHARTER SCHOOL INC",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120039007553",
    },
    {
        "school": "SOMERSET ACADEMY CHARTER MIDDLE SCHOOL SOUTH MIAMI CAMPUS",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007554",
    },
    {
        "school": "ANDOVER MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007563",
    },
    {
        "school": "INTERNATIONAL STUDIES CHARTER MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007564",
    },
    {
        "school": "HIGHLY INQUISITIVE AND VERSATILE EDUCATION (HIVE) PREPARATOR",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007572",
    },
    {
        "school": "LINCOLN-MARTI SCHOOLS INTERNATIONAL CAMPUS",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007578",
    },
    {
        "school": "MIAMI-DADE ONLINE ACADEMY- VIRTUAL INSTRUCTION PROGRAM",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007580",
    },
    {
        "school": "NICKLAUS CHILDREN'S HOSPITAL",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007591",
    },
    {
        "school": "MIAMI ARTS CHARTER",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007599",
    },
    {
        "school": "GATEWAY ENVIRONMENTAL K-8 LEARNING CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007602",
    },
    {
        "school": "MIAMI COMMUNITY CHARTER HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007608",
    },
    {
        "school": "CHAMBERS HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007617",
    },
    {
        "school": "MIAMI ARTS STUDIO 6-12 AT ZELDA GLAZER",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007631",
    },
    {
        "school": "TERRA ENVIRONMENTAL RESEARCH INSTITUTE",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007634",
    },
    {
        "school": "ALONZO & TRACY MOURNING SENIOR HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007635",
    },
    {
        "school": "WESTVIEW K-8",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007504",
    },
    {
        "school": "WATERLEAF ELEMENTARY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007594",
    },
    {
        "school": "BARTRAM SPRINGS ELEMENTARY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007606",
    },
    {
        "school": "ATLANTIC COAST HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007629",
    },
    {
        "school": "ESCAMBIA VIRTUAL INSTRUCTION PROGRAM",
        "district": "ESCAMBIA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051007541",
    },
    {
        "school": "WINDING WATERS K-8",
        "district": "HERNANDO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081007637",
    },
    {
        "school": "HILLSBOROUGH VIRT INSTR PRGS",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007499",
    },
    {
        "school": "VALRICO LAKE ADVANTAGE ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007502",
    },
    {
        "school": "ADVANTAGE ACADEMY OF HILLSBOROUGH",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007633",
    },
    {
        "school": "SEMINOLE HEIGHTS CHARTER HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087007650",
    },
    {
        "school": "STORM GROVE MIDDLE SCHOOL",
        "district": "INDIAN RIVER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093007588",
    },
    {
        "school": "G. WEAVER HIPPS ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007539",
    },
    {
        "school": "JAMES STEPHENS INTERNATIONAL ACADEMY",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007597",
    },
    {
        "school": "LEVY VIRTUAL INSTRUCTION PROGRAM",
        "district": "LEVY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114007590",
    },
    {
        "school": "PALMETTO YOUTH ACADEMY",
        "district": "MANATEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120123007507",
    },
    {
        "school": "THE PORT ACADEMY",
        "district": "MANATEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120123007528",
    },
    {
        "school": "KEYS CENTER",
        "district": "MONROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120132007521",
    },
    {
        "school": "RICHBOURG SCHOOL",
        "district": "OKALOOSA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120138007622",
    },
    {
        "school": "WETHERBEE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007523",
    },
    {
        "school": "LAKE NONA MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007531",
    },
    {
        "school": "POSITIVE PATHWAYS TRANSITION CENTER",
        "district": "ORANGE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144007536",
    },
    {
        "school": "KEENES CROSSING ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007567",
    },
    {
        "school": "FORSYTH WOODS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007611",
    },
    {
        "school": "UNIVERSAL EDUCATION CENTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144007612",
    },
    {
        "school": "EAST RIVER HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007614",
    },
    {
        "school": "ESTEEM ACADEMY",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144007624",
    },
    {
        "school": "LAKE NONA HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007646",
    },
    {
        "school": "NARCOOSSEE ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147007498",
    },
    {
        "school": "OSCEOLA VIRTUAL INSTRUCTION PROGRAM",
        "district": "OSCEOLA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147007537",
    },
    {
        "school": "KOA ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147007621",
    },
    {
        "school": "WESTSIDE K-8 SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147007628",
    },
    {
        "school": "HARMONY COMMUNITY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147007630",
    },
    {
        "school": "OSCEOLA CENTER FOR EARLY LEARNING",
        "district": "OSCEOLA",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147007641",
    },
    {
        "school": "MARSH POINTE ELEMENTARY",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150007552",
    },
    {
        "school": "SUNSET PALMS ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150007561",
    },
    {
        "school": "PALM BEACH VIRTUAL INSTRUCTION PROGRAM",
        "district": "PALM BEACH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150007579",
    },
    {
        "school": "PINE JOG ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150007604",
    },
    {
        "school": "WATERGRASS ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007610",
    },
    {
        "school": "ANCLOTE HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007618",
    },
    {
        "school": "PINELLAS VIRTUAL INSTRUCTION PROGRAM",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156007524",
    },
    {
        "school": "HAINES CITY HEADSTART CENTER",
        "district": "POLK",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159007586",
    },
    {
        "school": "WINTER HAVEN HEAD START",
        "district": "POLK",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159007600",
    },
    {
        "school": "ST. JOHNS VIRTUAL FRANCHISE",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174007505",
    },
    {
        "school": "LIBERTY PINES ACADEMY",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174007576",
    },
    {
        "school": "ST. JOHNS VIRTUAL INSTRUCTION PROGRAM K-8",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174007626",
    },
    {
        "school": "SOMERSET ACADEMY ST. LUCIE",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177007574",
    },
    {
        "school": "VOLUSIA COUNTY VIRTUAL INSTRUCTION PROGRAM",
        "district": "VOLUSIA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192007653",
    },
    {
        "school": "WASHINGTON INSTITUTE FOR SPECIALIZED EDUCATION",
        "district": "WASHINGTON",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120201007647",
    },
    {
        "school": "Callaway Elementary School",
        "district": "Troup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000103789",
    },
    {
        "school": "Howard High School",
        "district": "Bibb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042003726",
    },
    {
        "school": "Bruce Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042003744",
    },
    {
        "school": "Bremen Middle School",
        "district": "Bremen City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130051003757",
    },
    {
        "school": "Bremen 4th & 5th Grade Academy",
        "district": "Bremen City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130051003762",
    },
    {
        "school": "Stark Elementary School",
        "district": "Butts County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130069003818",
    },
    {
        "school": "Coastal Empire Montessori Charter School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102003772",
    },
    {
        "school": "J. Knox Elementary",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111003769",
    },
    {
        "school": "Little River Elem.",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111003780",
    },
    {
        "school": "Mount Zion Primary",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123003752",
    },
    {
        "school": "Pickett's Mill Elementary",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129003732",
    },
    {
        "school": "Allatoona High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129003781",
    },
    {
        "school": "Lindley 6th Grade Academy",
        "district": "Cobb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129003795",
    },
    {
        "school": "Wadsworth Magnet School for High Achievers",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003750",
    },
    {
        "school": "Ronald E McNair Discover Learning Academy Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003766",
    },
    {
        "school": "Inman Elementary",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130213003802",
    },
    {
        "school": "Lake Forest Elementary",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003816",
    },
    {
        "school": "Lanier Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003738",
    },
    {
        "school": "Rosebud Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003785",
    },
    {
        "school": "Trip Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003786",
    },
    {
        "school": "Benefield Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003813",
    },
    {
        "school": "Puckett's Mill Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003814",
    },
    {
        "school": "World Language Academy",
        "district": "Hall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261003805",
    },
    {
        "school": "Tussahaw Elementary",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003730",
    },
    {
        "school": "Rock Spring Elementary",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003747",
    },
    {
        "school": "Gum Springs Elementary School",
        "district": "Jackson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130294003742",
    },
    {
        "school": "Lee High School 9th Grade Campus",
        "district": "Lee County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130327003761",
    },
    {
        "school": "Westside Elementary School",
        "district": "Lowndes County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130339003788",
    },
    {
        "school": "Thomson-McDuffie Middle School",
        "district": "McDuffie County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130357003737",
    },
    {
        "school": "South Salem Elementary School",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393003770",
    },
    {
        "school": "Terrell Middle School",
        "district": "Terrell County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130486003735",
    },
    {
        "school": "S.L. Mason Elementary School",
        "district": "Valdosta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130531003812",
    },
    {
        "school": "Rossville Middle School",
        "district": "Walker County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537003800",
    },
    {
        "school": "Mossy Creek Elementary School",
        "district": "White County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130567003803",
    },
    {
        "school": "MORLEY NELSON ELEMENTARY",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000980",
    },
    {
        "school": "GRACE JORDAN ELEMENTARY",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000982",
    },
    {
        "school": "FRANK CHURCH HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160036000984",
    },
    {
        "school": "WEST JUNIOR HIGH",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036000987",
    },
    {
        "school": "LAKEVUE ELEMENTARY SCHOOL",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060000976",
    },
    {
        "school": "DISCOVERY ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000971",
    },
    {
        "school": "BRIDGEWATER ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000975",
    },
    {
        "school": "FRUITLAND PREPARATORY ACADEMY",
        "district": "FRUITLAND DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160114000988",
    },
    {
        "school": "SUMMIT ELEMENTARY",
        "district": "JEROME JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160159000972",
    },
    {
        "school": "SOUTH FORK ELEMENTARY",
        "district": "MADISON DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160192000974",
    },
    {
        "school": "ROCKY MOUNTAIN HIGH SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000985",
    },
    {
        "school": "SIENA ELEMENTARY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210000989",
    },
    {
        "school": "LONE STAR MIDDLE SCHOOL",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000969",
    },
    {
        "school": "LAKE RIDGE ELEMENTARY",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234000986",
    },
    {
        "school": "TIMBERLINE ELEMENTARY",
        "district": "OROFINO JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160252000983",
    },
    {
        "school": "WEST RIDGE ELEMENTARY SCHOOL",
        "district": "POST FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160267000970",
    },
    {
        "school": "West Campus Facility",
        "district": "Illini Central CUSD 189",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011305990",
    },
    {
        "school": "Green Bay School",
        "district": "North Shore SD 112",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011906002",
    },
    {
        "school": "Adams County RSSP",
        "district": "Adam/Brwn/Cass/Morgn/Pik/Sctt ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016206022",
    },
    {
        "school": "Center for Educ Opp",
        "district": "Madison ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019805989",
    },
    {
        "school": "Flanagan Elem School",
        "district": "Flanagan-Cornell Dist 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170139001838",
    },
    {
        "school": "Flanagan-Cornell High School",
        "district": "Flanagan-Cornell Dist 74",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170139005987",
    },
    {
        "school": "Braun Educational Center",
        "district": "Southwest Cook Coop Spec Ed",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170139205775",
    },
    {
        "school": "Project Challenge",
        "district": "Southwest Cook Coop Spec Ed",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170139205777",
    },
    {
        "school": "Early Childhood Center",
        "district": "Bellwood SD 88",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170576006018",
    },
    {
        "school": "Estelle Sauget School of Choice",
        "district": "Cahokia CUSD 187",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170804006001",
    },
    {
        "school": "Joseph Arthur Middle School",
        "district": "Central SD 104",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170917006007",
    },
    {
        "school": "Novak Academy",
        "district": "Champaign CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942005982",
    },
    {
        "school": "LaSalle II Lang Acad Elem Sch",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005979",
    },
    {
        "school": "Plato Learning Acad  Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005980",
    },
    {
        "school": "Orr Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005983",
    },
    {
        "school": "Austin College and Career Acad HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005984",
    },
    {
        "school": "Edison Park Elem School",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993005985",
    },
    {
        "school": "Davis M Magnet Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006006",
    },
    {
        "school": "Academy for Global Citizenship",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006035",
    },
    {
        "school": "Disney II Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006036",
    },
    {
        "school": "Coal City Early Childhood Center",
        "district": "Coal City CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171053006031",
    },
    {
        "school": "Dunlap Valley Middle School",
        "district": "Dunlap CUSD 323",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171270006009",
    },
    {
        "school": "James Avant Elementary School",
        "district": "East St Louis SD 189",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332005999",
    },
    {
        "school": "Wyvetter Younge Altrntv Cntr",
        "district": "East St Louis SD 189",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171332006013",
    },
    {
        "school": "Goshen Elementary",
        "district": "Edwardsville CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353006000",
    },
    {
        "school": "Albert Cassens Elementary",
        "district": "Edwardsville CUSD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353006020",
    },
    {
        "school": "Chillicothe Jr High",
        "district": "Il Valley Central USD 321",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171997006015",
    },
    {
        "school": "Mossville Jr High",
        "district": "Il Valley Central USD 321",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171997006016",
    },
    {
        "school": "Barnsdale Road School",
        "district": "La Grange SD 102",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172160005976",
    },
    {
        "school": "Millstadt Primary Center",
        "district": "Millstadt CCSD 160",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172619006030",
    },
    {
        "school": "YBMC Charter Sch",
        "district": "McLean County USD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862006010",
    },
    {
        "school": "Southbury Elem School",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027006004",
    },
    {
        "school": "Elizabeth Eichelberger Elem Sch",
        "district": "Plainfield SD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174006026",
    },
    {
        "school": "Plainfield East High School",
        "district": "Plainfield SD 202",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173174006027",
    },
    {
        "school": "Magee Middle School",
        "district": "Round Lake CUSD 116",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173499005995",
    },
    {
        "school": "Troy Hofer Elem Sch",
        "district": "Troy CCSD 30C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173951006012",
    },
    {
        "school": "Woodstock North High School",
        "district": "Woodstock CUSD 200",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174333006032",
    },
    {
        "school": "New Tech High - Zion-Benton East",
        "district": "Zion-Benton Twp HSD 126",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174389005993",
    },
    {
        "school": "Aspire Charter Academy",
        "district": "Aspire Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180007102443",
    },
    {
        "school": "Hoosier Academy - Indianapolis",
        "district": "Hoosier Academy - Indianapolis",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180007202422",
    },
    {
        "school": "Anderson Preparatory Academy",
        "district": "Anderson Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180007702425",
    },
    {
        "school": "CSA Lincoln Campus",
        "district": "Bartholomew Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036002421",
    },
    {
        "school": "Reagan Elementary School",
        "district": "Brownsburg Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180102002430",
    },
    {
        "school": "Blue Ridge Primary Elementary Sch",
        "district": "Community Schools of Frankfort",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180366002423",
    },
    {
        "school": "Green Meadows Intermediate Elem",
        "district": "Community Schools of Frankfort",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180366002432",
    },
    {
        "school": "Custer Baker Intermediate School",
        "district": "Franklin Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180369002440",
    },
    {
        "school": "Franklin Township Middle Schl East",
        "district": "Franklin Township Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180375002436",
    },
    {
        "school": "Merle Sidener Gifted Academy",
        "district": "Indianapolis Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002439",
    },
    {
        "school": "Joyce Kilmer School 69",
        "district": "Indianapolis Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002442",
    },
    {
        "school": "Heritage Intermediate School",
        "district": "Middlebury Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180660002427",
    },
    {
        "school": "Clarks Creek Elementary",
        "district": "Plainfield Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180897002438",
    },
    {
        "school": "Thorpe Creek Elementary",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065002429",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Tippecanoe School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134002441",
    },
    {
        "school": "Hilltop School",
        "district": "M S D Washington Township",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002444",
    },
    {
        "school": "Ashland Ridge Elementary",
        "district": "Ankeny Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369002094",
    },
    {
        "school": "Richard O. Jacobson Elementary School",
        "district": "Belmond-Klemme Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190468002090",
    },
    {
        "school": "Centerville Community Preschool Bldg",
        "district": "Centerville Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190675002096",
    },
    {
        "school": "North Bend Elementary",
        "district": "Clear Creek Amana Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190759002103",
    },
    {
        "school": "North Ridge Elementary",
        "district": "Dallas Center-Grimes Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190852002099",
    },
    {
        "school": "Broadway Elementary School",
        "district": "Denison Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190891002097",
    },
    {
        "school": "Samuelson Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897002093",
    },
    {
        "school": "Cresco Early Childhood Development Center",
        "district": "Howard-Winneshiek Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191428002088",
    },
    {
        "school": "Wilder Elementary School",
        "district": "Indianola Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191464002100",
    },
    {
        "school": "Echo Hill Elementary",
        "district": "Linn-Mar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191722002092",
    },
    {
        "school": "Emerson Learning Center (HSAP)",
        "district": "Marion Independent School District",
        "level": "Other",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191869002098",
    },
    {
        "school": "North Polk Middle School",
        "district": "North Polk Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192091002095",
    },
    {
        "school": "Webster Building",
        "district": "Oskaloosa Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192187002087",
    },
    {
        "school": "Unity Elementary School",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640002089",
    },
    {
        "school": "THUNDER RIDGE MIDDLE SCHOOL",
        "district": "Thunder Ridge Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200034601900",
    },
    {
        "school": "THUNDER RIDGE ELEMENTARY",
        "district": "Thunder Ridge Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200034601903",
    },
    {
        "school": "THUNDER RIDGE HIGH SCHOOL",
        "district": "Thunder Ridge Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200034601922",
    },
    {
        "school": "Wheatland Elementary",
        "district": "Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200336001913",
    },
    {
        "school": "Chanute Elementary School",
        "district": "Chanute Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200459001926",
    },
    {
        "school": "St. Paul Middle School",
        "district": "Chetopa-St. Paul",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200477001907",
    },
    {
        "school": "St. Paul High School",
        "district": "Chetopa-St. Paul",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200477001928",
    },
    {
        "school": "Ross Elementary School",
        "district": "Dodge City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200558001905",
    },
    {
        "school": "Frontenac Sr. High School",
        "district": "Frontenac Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200630001912",
    },
    {
        "school": "Frontenac Jr. High",
        "district": "Frontenac Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200630001915",
    },
    {
        "school": "Haysville West Middle School",
        "district": "Haysville",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200705001906",
    },
    {
        "school": "Lansing Elementary School",
        "district": "Lansing",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200834001920",
    },
    {
        "school": "Rockville Elementary School",
        "district": "Louisburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200897001911",
    },
    {
        "school": "Woodland Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001924",
    },
    {
        "school": "Seaman Middle School",
        "district": "Seaman",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201149001921",
    },
    {
        "school": "Insight School of KS at Hilltop Ed Center",
        "district": "Spring Hill",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201185001918",
    },
    {
        "school": "Gordon Parks Academy",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001904",
    },
    {
        "school": "Marshall Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001908",
    },
    {
        "school": "Mead Middle School",
        "district": "Wichita",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299001919",
    },
    {
        "school": "Bardstown Early Childhood Center",
        "district": "Bardstown Independent",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210027002222",
    },
    {
        "school": "North Jackson Elementary",
        "district": "Barren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210030002232",
    },
    {
        "school": "Crossroads Elementary School",
        "district": "Bath County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210033002223",
    },
    {
        "school": "Clinton County Early Childhood Center",
        "district": "Clinton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210126002228",
    },
    {
        "school": "Corbin Primary",
        "district": "Corbin Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210132002218",
    },
    {
        "school": "Pathway Academy High School",
        "district": "Crittenden County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210138002225",
    },
    {
        "school": "Southern Oaks Elementary School",
        "district": "Daviess County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210147002230",
    },
    {
        "school": "ABLE",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Special education school",
        "state": "KY",
        "nces_id": "210186002236",
    },
    {
        "school": "Early Learning Village",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210201002219",
    },
    {
        "school": "Cordia School",
        "district": "Knott County",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210312002233",
    },
    {
        "school": "Central Elementary School",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210315002235",
    },
    {
        "school": "McDaniel Learning Center",
        "district": "Laurel County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210321002224",
    },
    {
        "school": "B. Michael Caudill Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372002217",
    },
    {
        "school": "South Magoffin Elementary",
        "district": "Magoffin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210375002227",
    },
    {
        "school": "North Magoffin Elementary",
        "district": "Magoffin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210375002238",
    },
    {
        "school": "Paris Preschool Center",
        "district": "Paris Independent",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210471002226",
    },
    {
        "school": "Prairieville Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009002076",
    },
    {
        "school": "Pecan Grove Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009002081",
    },
    {
        "school": "Central Intermediate School",
        "district": "Central Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220012502090",
    },
    {
        "school": "W.T. Lewis Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027002074",
    },
    {
        "school": "Legacy Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027002080",
    },
    {
        "school": "Scotlandville Pre-Engineering Academy",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002069",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072002078",
    },
    {
        "school": "Jefferson Island Road Elementary",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072002085",
    },
    {
        "school": "Early College Academy",
        "district": "Lafayette Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087002072",
    },
    {
        "school": "Little Pearl Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165002089",
    },
    {
        "school": "Bath Middle School",
        "district": "RSU 01 - LKRSU",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477200062",
    },
    {
        "school": "Bath Regional Career & Technical",
        "district": "RSU 01 - LKRSU",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231477200063",
    },
    {
        "school": "Fisher-Mitchell School",
        "district": "RSU 01 - LKRSU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477200067",
    },
    {
        "school": "Morse High School",
        "district": "RSU 01 - LKRSU",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477200068",
    },
    {
        "school": "Dike-Newell School",
        "district": "RSU 01 - LKRSU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477200069",
    },
    {
        "school": "Phippsburg Elementary School",
        "district": "RSU 01 - LKRSU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477200263",
    },
    {
        "school": "Woolwich Central School",
        "district": "RSU 01 - LKRSU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477200648",
    },
    {
        "school": "Nantucket Elementary",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001658",
    },
    {
        "school": "Baltimore Montessori Public Charter School",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001657",
    },
    {
        "school": "Afya Public Charter School",
        "district": "Baltimore City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001661",
    },
    {
        "school": "Joseph C. Briscoe Academy",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240009001662",
    },
    {
        "school": "The Reach! Partnership School",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001663",
    },
    {
        "school": "Vincent Farm Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001653",
    },
    {
        "school": "Barstow Elementary",
        "district": "Calvert County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240015001655",
    },
    {
        "school": "Ebb Valley Elementary",
        "district": "Carroll County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021001652",
    },
    {
        "school": "Mary B. Neal Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027001656",
    },
    {
        "school": "Vansville Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001660",
    },
    {
        "school": "Rockland Woods Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001667",
    },
    {
        "school": "Manchester Essex Regional Middle School",
        "district": "Manchester Essex Regional",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250006702653",
    },
    {
        "school": "Mitchell Elementary School",
        "district": "Bridgewater-Raynham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250303002643",
    },
    {
        "school": "Williams Intermediate School",
        "district": "Bridgewater-Raynham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250303002657",
    },
    {
        "school": "Bridgewater Middle School",
        "district": "Bridgewater-Raynham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250303002659",
    },
    {
        "school": "Mary E. Baker School",
        "district": "Brockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309002649",
    },
    {
        "school": "Brockton Champion High School",
        "district": "Brockton",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250309002652",
    },
    {
        "school": "Manthala George Jr. School",
        "district": "Brockton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309002655",
    },
    {
        "school": "Carver Elementary School",
        "district": "Carver",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250336002661",
    },
    {
        "school": "Carver Middle/High School",
        "district": "Carver",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250336002662",
    },
    {
        "school": "Community Education Center",
        "district": "Chelmsford",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250351002640",
    },
    {
        "school": "Carlton M. Viveiros Elementary School",
        "district": "Fall River",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483002644",
    },
    {
        "school": "Mary Fonseca Elementary School",
        "district": "Fall River",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483002650",
    },
    {
        "school": "Letourneau Elementary School",
        "district": "Fall River",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483002656",
    },
    {
        "school": "William R. Peck School",
        "district": "Holyoke",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627002645",
    },
    {
        "school": "Rollins Early Childhood Center",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002651",
    },
    {
        "school": "Frost Middle School",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002654",
    },
    {
        "school": "Fecteau-Leary Junior/Senior High School",
        "district": "Lynn",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711002647",
    },
    {
        "school": "Washington Elementary School",
        "district": "Lynn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250711002658",
    },
    {
        "school": "1 LT Charles W. Whitcomb School",
        "district": "Marlborough",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250732002639",
    },
    {
        "school": "STEM Middle Academy",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002642",
    },
    {
        "school": "Winchendon PreSchool Program",
        "district": "Winchendon",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251308002648",
    },
    {
        "school": "Alger Maximum Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107831",
    },
    {
        "school": "Thumb Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107838",
    },
    {
        "school": "Newberry Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107839",
    },
    {
        "school": "Handlon Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107845",
    },
    {
        "school": "SAI Camp Cassidy Lake",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107846",
    },
    {
        "school": "Carson City Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107852",
    },
    {
        "school": "St Louis Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107856",
    },
    {
        "school": "Baraga Maximum Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107857",
    },
    {
        "school": "Saginaw Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107860",
    },
    {
        "school": "Chippewa Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107884",
    },
    {
        "school": "Central Michigan Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107887",
    },
    {
        "school": "Bellamy Creek Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107890",
    },
    {
        "school": "Ionia Maximum Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107898",
    },
    {
        "school": "Lakeland Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107903",
    },
    {
        "school": "Marquette Branch Prison",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107907",
    },
    {
        "school": "Parnall Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107914",
    },
    {
        "school": "Macomb Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107923",
    },
    {
        "school": "Pugsley Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107927",
    },
    {
        "school": "Kinross Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107928",
    },
    {
        "school": "Brooks Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107929",
    },
    {
        "school": "Gus Harrison Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107931",
    },
    {
        "school": "Cooper Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107937",
    },
    {
        "school": "Egeler Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107941",
    },
    {
        "school": "Oaks Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107945",
    },
    {
        "school": "Huron Valley Womens",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107954",
    },
    {
        "school": "Cotton Correctional Facility",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000107957",
    },
    {
        "school": "Shawono Center",
        "district": "Michigan Department of Human Services",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000407871",
    },
    {
        "school": "Bay Pines Center",
        "district": "Michigan Department of Human Services",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260000407876",
    },
    {
        "school": "Charyl Stockwell Academy  High School",
        "district": "Charyl Stockwell Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260010007835",
    },
    {
        "school": "Advanced Technology Academy",
        "district": "Advanced Technology Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260025507882",
    },
    {
        "school": "Lighthouse Academy",
        "district": "Lighthouse Academy",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260094907848",
    },
    {
        "school": "Reach Charter Academy",
        "district": "Reach Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095007851",
    },
    {
        "school": "Vista Meadows Academy",
        "district": "Vista Meadows Academy",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260095107956",
    },
    {
        "school": "University Preparatory Science and Math PSAD Middle School",
        "district": "University Preparatory Science and Math (PSAD)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095207946",
    },
    {
        "school": "Youth Advancement Academy",
        "district": "Youth Advancement Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095507879",
    },
    {
        "school": "University Preparatory Academy PSAD  Elementary",
        "district": "University Preparatory Academy (PSAD)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095607836",
    },
    {
        "school": "University Preparatory Academy PSAD  High School",
        "district": "University Preparatory Academy (PSAD)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095607842",
    },
    {
        "school": "University Preparatory Academy PSAD  Elementary",
        "district": "University Preparatory Academy (PSAD)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095607905",
    },
    {
        "school": "University Preparatory Academy PSAD  Middle",
        "district": "University Preparatory Academy (PSAD)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095607940",
    },
    {
        "school": "Oakwood Intermediate",
        "district": "Allendale Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260255007943",
    },
    {
        "school": "Charles L Bowers Farm",
        "district": "Bloomfield Hills Schools",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "260609007840",
    },
    {
        "school": "Bridge Alternative High School",
        "district": "Brighton Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260687007925",
    },
    {
        "school": "International Academy of Macomb",
        "district": "Chippewa Valley Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260957007865",
    },
    {
        "school": "ClimaxScotts Virtual Academy",
        "district": "Climax-Scotts Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261002007847",
    },
    {
        "school": "Constantine Alternative Education",
        "district": "Constantine Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261075007891",
    },
    {
        "school": "Coopersville East Elementary",
        "district": "Coopersville Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261083007862",
    },
    {
        "school": "Westwood Virtual Academy",
        "district": "Westwood Community School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261164007904",
    },
    {
        "school": "Eau Claire Middle School",
        "district": "Eau Claire Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261281007880",
    },
    {
        "school": "Grand Rapids University Preparatory Academy",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644007902",
    },
    {
        "school": "Horizon High School",
        "district": "Hamtramck School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261752007965",
    },
    {
        "school": "Linden Grove Middle School",
        "district": "Kalamazoo Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995007864",
    },
    {
        "school": "El Sol Elementary",
        "district": "Kalamazoo Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261995007948",
    },
    {
        "school": "Ingham AcademyFamily Center",
        "district": "Lansing Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115007963",
    },
    {
        "school": "Post Secondary Transition Program",
        "district": "Midland Public Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262382007841",
    },
    {
        "school": "Juvenile Care Center",
        "district": "Midland Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262382007867",
    },
    {
        "school": "Saline Alternative High School",
        "district": "Saline Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263066007868",
    },
    {
        "school": "Appleview Elementary School",
        "district": "Sparta Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263237007892",
    },
    {
        "school": "CharEm Alternative Schools",
        "district": "Charlevoix-Emmet ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268024007895",
    },
    {
        "school": "Career and Technical Education Center",
        "district": "Iosco RESA",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268056007944",
    },
    {
        "school": "Maurice Spear Campus",
        "district": "Lenawee ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268068007910",
    },
    {
        "school": "Muskegon Area Career Tech Center",
        "district": "Muskegon Area ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268085007844",
    },
    {
        "school": "Careerline Tech Center",
        "district": "Ottawa Area ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268090007921",
    },
    {
        "school": "INVEST HIGH SCHOOL",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002504327",
    },
    {
        "school": "FERGUS FALLS EARLY CHILDHOOD SP ED",
        "district": "FERGUS FALLS AREA SP. ED. COOP.",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004304266",
    },
    {
        "school": "FERGUS FALLS EC/ELEMENTARY SP ED",
        "district": "FERGUS FALLS AREA SP. ED. COOP.",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004304289",
    },
    {
        "school": "FERGUS FALLS ELEMENTARY SP ED 5-8",
        "district": "FERGUS FALLS AREA SP. ED. COOP.",
        "level": "Middle",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004304316",
    },
    {
        "school": "STEP TD PROGRAM",
        "district": "MEEKER AND WRIGHT SPECIAL EDUCATION",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004504318",
    },
    {
        "school": "North Lakes Academy Upper School",
        "district": "NORTH LAKES ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270017704291",
    },
    {
        "school": "NATURAL SCIENCE ACADEMY",
        "district": "NATURAL SCIENCE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270031004276",
    },
    {
        "school": "ASPEN ACADEMY",
        "district": "ASPEN ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270031104282",
    },
    {
        "school": "GLOBAL ACADEMY",
        "district": "GLOBAL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270031304294",
    },
    {
        "school": "Lionsgate Academy - Minnetonka",
        "district": "LIONSGATE ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270031504325",
    },
    {
        "school": "BRIGHT WATER ELEMENTARY",
        "district": "BRIGHT WATER ELEMENTARY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270031604319",
    },
    {
        "school": "RUM RIVER NORTH",
        "district": "RUM RIVER SPECIAL EDUCATION COOP",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270031804296",
    },
    {
        "school": "RUM RIVER SOUTH",
        "district": "RUM RIVER SPECIAL EDUCATION COOP",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270031804298",
    },
    {
        "school": "COLOGNE ACADEMY",
        "district": "COLOGNE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270031904320",
    },
    {
        "school": "DAVINCI ACADEMY",
        "district": "DAVINCI ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270032004268",
    },
    {
        "school": "OSHKI OGIMAAG CHARTER SCHOOL",
        "district": "OSHKI OGIMAAG CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270032104293",
    },
    {
        "school": "CANNON RIVER STEM SCHOOL",
        "district": "CANNON RIVER STEM SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270032404271",
    },
    {
        "school": "COLLEGE PREPARATORY ELEMENTARY",
        "district": "COLLEGE PREPARATORY ELEMENTARY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270032504338",
    },
    {
        "school": "BAGLEY ALP",
        "district": "BAGLEY PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270357004279",
    },
    {
        "school": "PRIDE TRANSITIONS",
        "district": "BUFFALO-HANOVER-MONTROSE PUBLIC SCH",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270720004323",
    },
    {
        "school": "INTEGRATED ARTS ACADEMY",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270819004310",
    },
    {
        "school": "AFTERSCHOOL PROGRAM",
        "district": "DETROIT LAKES PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271023004330",
    },
    {
        "school": "HS EXTENDED YEAR PROGRAM",
        "district": "DETROIT LAKES PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271023004334",
    },
    {
        "school": "THE BRIDGE",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271104004328",
    },
    {
        "school": "OPTIONS AT EDINA HIGH SCHOOL",
        "district": "EDINA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271125004336",
    },
    {
        "school": "VOA HIGH SCHOOL",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004290",
    },
    {
        "school": "REDTAIL RIDGE ELEMENTARY SCHOOL",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273006004305",
    },
    {
        "school": "RED LAKE JUVENILE DETENTION FACLTY",
        "district": "RED LAKE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273051004337",
    },
    {
        "school": "GEORGE W. GIBBS ELEMENTARY",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180004287",
    },
    {
        "school": "Next Step Transition Program",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273381004280",
    },
    {
        "school": "EARLY ED GLOBAL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384004300",
    },
    {
        "school": "Central Education Center",
        "district": "STEWARTVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273816004326",
    },
    {
        "school": "WEST CENTRAL EDUCATION DISTRICT B-2",
        "district": "WEST CENTRAL EDUCATION DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279145504314",
    },
    {
        "school": "R.H. LONG BOONEVILLE MIDDLE SCHOOL",
        "district": "BOONEVILLE SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280082001329",
    },
    {
        "school": "CALHOUN CO CAREER & TECH CTR",
        "district": "CALHOUN CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280087001340",
    },
    {
        "school": "SEMINARY ELEMENTARY SCHOOL",
        "district": "COVINGTON COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280129001334",
    },
    {
        "school": "SEMINARY MIDDLE SCHOOL",
        "district": "COVINGTON COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280129001337",
    },
    {
        "school": "SOUTHAVEN INTERMEDIATE SCHOOL",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001336",
    },
    {
        "school": "WEST HANCOCK ELEMENTARY SCHOOL",
        "district": "HANCOCK CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280174001338",
    },
    {
        "school": "NORTH JONES ELEMENTARY SCHOOL",
        "district": "JONES CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280228001326",
    },
    {
        "school": "SHANNON MIDDLE SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280255001325",
    },
    {
        "school": "NORTH PANOLA MIDDLE SCHOOL",
        "district": "NORTH PANOLA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280321001339",
    },
    {
        "school": "PETAL ELEMENTARY",
        "district": "PETAL SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280353001330",
    },
    {
        "school": "HIGHLAND BLUFF ELEMENTARY",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001333",
    },
    {
        "school": "UNION MIDDLE SCHOOL",
        "district": "UNION PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280438001327",
    },
    {
        "school": "UNION ELEMENTARY SCHOOL",
        "district": "UNION PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280438001342",
    },
    {
        "school": "BOVINA ELEMENTARY SCHOOL",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280447001332",
    },
    {
        "school": "CONFLUENCE PREPARATORY ACADEMY",
        "district": "CONFLUENCE ACADEMIES",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290057903102",
    },
    {
        "school": "CITY GARDEN MONTESSORI SCHOOL",
        "district": "CITY GARDEN MONTESSORI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290058503101",
    },
    {
        "school": "BLOOMFIELD MIDDLE",
        "district": "BLOOMFIELD R-XIV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290525003104",
    },
    {
        "school": "CENTRALIA INTERMEDIATE",
        "district": "CENTRALIA R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290840003092",
    },
    {
        "school": "INDIAN TRAILS ELEM.",
        "district": "FORT OSAGE R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291229003103",
    },
    {
        "school": "HARRISBURG MIDDLE",
        "district": "HARRISBURG R-VIII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291371003100",
    },
    {
        "school": "CLIFFORD H. NOWLIN MIDDLE",
        "district": "INDEPENDENCE 30",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548003090",
    },
    {
        "school": "THREE TRAILS ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548003091",
    },
    {
        "school": "VAN HORN HIGH",
        "district": "INDEPENDENCE 30",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548003096",
    },
    {
        "school": "SUGAR CREEK ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548003098",
    },
    {
        "school": "FAIRMOUNT ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548003099",
    },
    {
        "school": "KORTE ELEM.",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548003107",
    },
    {
        "school": "M. L. KING  ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640003082",
    },
    {
        "school": "SOUTHEAST HIGH SCHOOL",
        "district": "KANSAS CITY 33",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640003097",
    },
    {
        "school": "NOEL PRIMARY",
        "district": "MCDONALD CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292061003094",
    },
    {
        "school": "PINEVILLE PRIMARY",
        "district": "MCDONALD CO. R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292061003106",
    },
    {
        "school": "CENTRAL PARK ELEM.",
        "district": "MONETT R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292112003089",
    },
    {
        "school": "MT. VERNON INTERMEDIATE",
        "district": "MT. VERNON R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292160003088",
    },
    {
        "school": "STALEY HIGH",
        "district": "NORTH KANSAS CITY 74",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280003083",
    },
    {
        "school": "GERNER FAMILY EARLY ED CTR.",
        "district": "PARK HILL",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355003087",
    },
    {
        "school": "PATHFINDER ELEM.",
        "district": "PLATTE CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292523003086",
    },
    {
        "school": "RAYTOWN CENTRAL MIDDLE",
        "district": "RAYTOWN C-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607003085",
    },
    {
        "school": "KINGSTON PRIMARY",
        "district": "KINGSTON K-14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293114003105",
    },
    {
        "school": "Midway Colony",
        "district": "Dutton/Brady K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300010201094",
    },
    {
        "school": "Ophir 7-8",
        "district": "Big Sky School K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065400135",
    },
    {
        "school": "Ophir Elementary School",
        "district": "Big Sky School K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065400604",
    },
    {
        "school": "Hyalite Elementary",
        "district": "Bozeman Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300456001096",
    },
    {
        "school": "Hawks Home School",
        "district": "Hawks Home Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301328001095",
    },
    {
        "school": "EARLY LEARNING CENTER",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001602207",
    },
    {
        "school": "TRI COMMUNITY PRESCHOOL",
        "district": "MORRILL PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009702206",
    },
    {
        "school": "SO VALLEY ELEMENTARY SCHOOL",
        "district": "SOUTHERN VALLEY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310010902208",
    },
    {
        "school": "ALEGENT/IMMANUEL RTC",
        "district": "ALEGENT/IMMANUEL RTC",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310018102199",
    },
    {
        "school": "PINE CREEK ELEMENTARY",
        "district": "BENNINGTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310399002213",
    },
    {
        "school": "DEERFIELD ELEMENTARY SCHOOL",
        "district": "BLAIR COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310410002205",
    },
    {
        "school": "ADAMS ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002211",
    },
    {
        "school": "PATRIOT ELEMENTARY",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527002209",
    },
    {
        "school": "PRESCHOOL LEARNING ACADEMY",
        "district": "YORK PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317905002201",
    },
    {
        "school": "HARMS ADV TECH CENTER-WNCC",
        "district": "EDUCATIONAL SERVICE UNIT 13",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "318013002212",
    },
    {
        "school": "Beacon Academy of Nevada",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100751",
    },
    {
        "school": "Quest Academy Northwest",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100759",
    },
    {
        "school": "Ruben P Diaz Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000747",
    },
    {
        "school": "East Career Technical Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000748",
    },
    {
        "school": "Innovations International Charter School of NV",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000749",
    },
    {
        "school": "Jesse D Scott ES",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000753",
    },
    {
        "school": "Desert Oasis High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000754",
    },
    {
        "school": "Northwest Career and Technical Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000755",
    },
    {
        "school": "Imagine 100 Academy of Excellence",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000756",
    },
    {
        "school": "Carolyn S Reedom Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000757",
    },
    {
        "school": "Thomas O'Roarke Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000758",
    },
    {
        "school": "Flagview Intermediate School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000750",
    },
    {
        "school": "Floyd Elementary School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000752",
    },
    {
        "school": "Ledyard Charter School",
        "district": "Ledyard Charter Academy",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330004300695",
    },
    {
        "school": "Great Bay Charter School (M)",
        "district": "Great Bay Elearning Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330004800688",
    },
    {
        "school": "Virtual Learning Academy (E)",
        "district": "Virtual Learning Academy Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330327100693",
    },
    {
        "school": "James House Preschool",
        "district": "Kearsarge Regional School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330404000687",
    },
    {
        "school": "Bud Carlson Academy",
        "district": "Rochester School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330594000694",
    },
    {
        "school": "Windham High School",
        "district": "Windham School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330717000692",
    },
    {
        "school": "Community Charter School of Paterson",
        "district": "Community Charter School of Paterson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340071803014",
    },
    {
        "school": "Pride Academy Charter School",
        "district": "Pride Academy Charter School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340071903017",
    },
    {
        "school": "Paul Robeson Charter School for the Humanities",
        "district": "Paul Robeson Charter School for the Humanities",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340072303015",
    },
    {
        "school": "Burch Charter School of Excellence",
        "district": "Burch Charter School of Excellence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340072403011",
    },
    {
        "school": "The Ethical Community Charter School",
        "district": "The Ethical Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340072703029",
    },
    {
        "school": "Vineland Public Charter School",
        "district": "Vineland Public Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340072903027",
    },
    {
        "school": "Newark Educators Community Charter School",
        "district": "Newark Educators Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340073003028",
    },
    {
        "school": "Riverbank Charter School of Excellence",
        "district": "Riverbank Charter School of Excellence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340073103022",
    },
    {
        "school": "Cresskill Middle School",
        "district": "Cresskill Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340360002993",
    },
    {
        "school": "Juan Pablo Duarte - Jose Julian Marti School No 28",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459002983",
    },
    {
        "school": "Dr. Antonia Pantoja School No. 27",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459002997",
    },
    {
        "school": "Oak Tree Elementary School",
        "district": "Monroe Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341050002982",
    },
    {
        "school": "New Roberto Clemente",
        "district": "Paterson Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003003",
    },
    {
        "school": "Edmund Hmieleski Early Childhood Center",
        "district": "Perth Amboy Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293002998",
    },
    {
        "school": "Primary Center at Wilson",
        "district": "Summit Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341590002985",
    },
    {
        "school": "Primary Center at Jefferson",
        "district": "Summit Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341590002987",
    },
    {
        "school": "GENERAL CHARLES G. HARKER SCHOOL",
        "district": "SWEDESBORO-WOOLWICH SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341599002995",
    },
    {
        "school": "Joseph T. Donahue Elementary School",
        "district": "Barnegat Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341647003007",
    },
    {
        "school": "Gloria M Sabater Elementary School",
        "district": "Vineland Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680003031",
    },
    {
        "school": "Lincoln Early Childhood Center",
        "district": "Westfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341776002999",
    },
    {
        "school": "Academy For Performing Arts",
        "district": "Union County Vocational-Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341804003009",
    },
    {
        "school": "New Jersey Virtual School",
        "district": "Monmouth-Ocean Educational Services Commission School Distri",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "348024002989",
    },
    {
        "school": "Hope Academy",
        "district": "Northern Region Educational Services Commission",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "348036402991",
    },
    {
        "school": "CIELO AZUL ELEMENTARY",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001001034",
    },
    {
        "school": "SANDIA VISTA ELEMENTARY",
        "district": "RIO RANCHO PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350001001039",
    },
    {
        "school": "RUDOLFO ANAYA ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001033",
    },
    {
        "school": "SUNSET VIEW ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001036",
    },
    {
        "school": "ATRISCO HERITAGE ACADEMY HS",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001037",
    },
    {
        "school": "GORDON BERNELL CHARTER",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001040",
    },
    {
        "school": "HELEN CORDERO PRIMARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001043",
    },
    {
        "school": "NORTH VALLEY ACADEMY",
        "district": "NORTH VALLEY CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350010600873",
    },
    {
        "school": "HORIZON ACADEMY WEST",
        "district": "HORIZON ACADEMY WEST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350010700874",
    },
    {
        "school": "MEDIA ARTS COLLABORATIVE CHARTER",
        "district": "MEDIA ARTS COLLABORATIVE CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350010901030",
    },
    {
        "school": "RUBEN S. TORRES ELEMENTARY",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069001035",
    },
    {
        "school": "NORTH VALLEY ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108001032",
    },
    {
        "school": "SUNDANCE ELEMENTARY",
        "district": "LOS LUNAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350168001029",
    },
    {
        "school": "LOVINGTON FRESHMAN ACADEMY",
        "district": "LOVINGTON MUNICIPAL SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350174001044",
    },
    {
        "school": "SIXTH GRADE ACADEMY",
        "district": "POJOAQUE VALLEY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350207001041",
    },
    {
        "school": "SCHOOL FOR GLOBAL LEADERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007606021",
    },
    {
        "school": "NYC ISCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706065",
    },
    {
        "school": "GRAMERCY ARTS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706077",
    },
    {
        "school": "MOSAIC PREPARATORY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007905998",
    },
    {
        "school": "ESPERANZA PREPARATORY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007906003",
    },
    {
        "school": "RENAISSANCE SCHOOL OF THE ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007906016",
    },
    {
        "school": "YOUNG LEADERS ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008406041",
    },
    {
        "school": "HUNTS POINT SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506081",
    },
    {
        "school": "ENGLISH LANGUAGE LEARNERS-INTER SUPP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008706010",
    },
    {
        "school": "SCHOOL FOR ENVIRONMENTAL CITIZENSHIP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008706015",
    },
    {
        "school": "ELEMENTARY SCHOOL FOR MATH SCIENCE AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008706057",
    },
    {
        "school": "EMOLIOR ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006002",
    },
    {
        "school": "PAN AMERICAN INTERNATIONAL HIGH SCHOOL AT MONROE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006030",
    },
    {
        "school": "URBAN ASSEMBLY INSTITUTE OF MATH AND SCIENCE FOR YOUNG WOMEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009105928",
    },
    {
        "school": "BROOKLYN HIGH SCHOOL FOR LEADERSHIP AND COMMUNITY SERVICE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009106029",
    },
    {
        "school": "BRIGHTER CHOICE COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009406049",
    },
    {
        "school": "BROOKLYN BROWNSTONE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009406050",
    },
    {
        "school": "OLYMPUS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009606009",
    },
    {
        "school": "HIGH SCHOOL FOR MEDICAL PROFESSIONS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009606023",
    },
    {
        "school": "CULTURAL ACADEMY FOR THE ARTS AND SCIENCES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009606042",
    },
    {
        "school": "URBAN ACTION ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009606052",
    },
    {
        "school": "ACADEMY FOR CONSERVATION AND THE ENVIRONMENT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009606054",
    },
    {
        "school": "HIGH SCHOOL FOR INNOVATION IN ADVERTISING AND MEDIA",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360009606059",
    },
    {
        "school": "BARD HIGH SCHOOL EARLY COLLEGE QUEENS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806004",
    },
    {
        "school": "CIVIC LEADERSHIP ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806028",
    },
    {
        "school": "LEARNERS AND LEADERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806040",
    },
    {
        "school": "PIONEER ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806060",
    },
    {
        "school": "VOYAGES PREPARATORY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806066",
    },
    {
        "school": "PAN AMERICAN INTERNATIONAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806084",
    },
    {
        "school": "QUEENS COLLEGIATE - A COLLEGE BOARD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006005",
    },
    {
        "school": "ACADEMY FOR EXCELLENCE THROUGH THE ARTS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006067",
    },
    {
        "school": "ACADEMY FOR CAREERS IN TELEVISION AND FILM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360010206070",
    },
    {
        "school": "MARSH AVENUE SCHOOL FOR EXPEDITIONARY LEARNING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306006",
    },
    {
        "school": "GAYNOR MCCOWN EXPEDITIONARY LEARNING SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306024",
    },
    {
        "school": "PS 65 ACADEMY OF INNOVATIVE LEARNING (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306035",
    },
    {
        "school": "YOUNG WOMEN'S LEADERSHIP SCHOOL OF BROOKLYN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011906033",
    },
    {
        "school": "MULTICULTURAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012005931",
    },
    {
        "school": "CYPRESS HILLS COLLEGIATE PREPARATORY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006031",
    },
    {
        "school": "BROOKLYN LAB SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006045",
    },
    {
        "school": "ACADEMY OF INNOVATIVE TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360012006046",
    },
    {
        "school": "BROOKLYN DEMOCRACY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012105997",
    },
    {
        "school": "METROPOLITAN DIPLOMA PLUS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012106064",
    },
    {
        "school": "EAGLE ACADEMY FOR YOUNG MEN II",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012106078",
    },
    {
        "school": "ACTIVE LEARNING ELEMENTARY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012206032",
    },
    {
        "school": "QUEENS HIGH SCHOOL FOR INFORMATION RESEARCH AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012305999",
    },
    {
        "school": "NEW YORK CITY ACADEMY FOR DISCOVERY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306036",
    },
    {
        "school": "ROBERT H GODDARD HS-COMM/TECH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306047",
    },
    {
        "school": "ACADEMY OF MEDICAL TECHNOLOGY - A COLLEGE BOARD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306079",
    },
    {
        "school": "NORTHSIDE CHARTER HIGH SCHOOL",
        "district": "NORTHSIDE CHARTER HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360094806058",
    },
    {
        "school": "PAVE ACADEMY CHARTER SCHOOL",
        "district": "PAVE ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360094906082",
    },
    {
        "school": "ROCHESTER ACADEMY CHARTER SCHOOL",
        "district": "ROCHESTER ACADEMY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360095005995",
    },
    {
        "school": "THE EQUITY PROJECT CHARTER SCHOOL",
        "district": "THE EQUITY PROJECT CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360095206000",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 4",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360095306018",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 2",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360095406017",
    },
    {
        "school": "ICAHN CHARTER SCHOOL 3",
        "district": "ICAHN CHARTER SCHOOL 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360095506027",
    },
    {
        "school": "BRONX ACADEMY OF PROMISE CHARTER SCHOOL",
        "district": "BRONX ACADEMY OF PROMISE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360095606025",
    },
    {
        "school": "VOICE CHARTER SCHOOL OF NEW YORK",
        "district": "VOICE CHARTER SCHOOL OF NEW YORK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360095706068",
    },
    {
        "school": "ST. HOPE LEADERSHIP ACADEMY CHARTER SCHOOL",
        "district": "ST. HOPE LEADERSHIP ACADEMY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360095806007",
    },
    {
        "school": "NYC CHARTER HS - AECI",
        "district": "NYC CHARTER HS - AECI",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360095906073",
    },
    {
        "school": "MOTT HAVEN ACADEMY CHARTER SCHOOL",
        "district": "MOTT HAVEN ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360096006013",
    },
    {
        "school": "LA CIMA CHARTER SCHOOL",
        "district": "LA CIMA CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360096106071",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 3",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 3",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360096206037",
    },
    {
        "school": "UNIVERSITY PREP CHARTER HIGH SCHOOL",
        "district": "UNIVERSITY PREP CHARTER HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360096306039",
    },
    {
        "school": "DREAM CHARTER SCHOOL",
        "district": "DREAM CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360096406038",
    },
    {
        "school": "BEDFORD STUYVESANT COLLEGIATE CHARTER SCHOOL",
        "district": "BEDFORD STUYVESANT COLLEGIATE CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360096506044",
    },
    {
        "school": "BROOKLYN ASCEND CHARTER SCHOOL",
        "district": "BROOKLYN ASCEND CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360096606069",
    },
    {
        "school": "BGLIG-SHIRLEY RODRIGUEZ-REMENESKI CS",
        "district": "BGLIG-SHIRLEY RODRIGUEZ-REMENESKI CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360096706008",
    },
    {
        "school": "BRONX COMMUNITY CHARTER SCHOOL",
        "district": "BRONX COMMUNITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360096806074",
    },
    {
        "school": "ACHIEVEMENT FIRST BROWNSVILLE CHARTER SCHOOL",
        "district": "ACHIEVEMENT FIRST BROWNSVILLE CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360096906014",
    },
    {
        "school": "MILTON TERRACE ELEMENTARY SCHOOL",
        "district": "BALLSTON SPA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360393006048",
    },
    {
        "school": "EAGLE ELEMENTARY SCHOOL",
        "district": "BETHLEHEM CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360471006072",
    },
    {
        "school": "HAMPTON BAYS MIDDLE SCHOOL",
        "district": "HAMPTON BAYS UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361353006043",
    },
    {
        "school": "CASTLETON ACADEMY HIGH SCHOOL OF OCEANSIDE",
        "district": "OCEANSIDE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362157006053",
    },
    {
        "school": "JOSEPH C WILSON FOUNDATION ACADEMY",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475006076",
    },
    {
        "school": "WILLIAM C KEANE ELEMENTARY SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601006063",
    },
    {
        "school": "PALISADE PREPARATORY SCHOOL",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192006001",
    },
    {
        "school": "Grays Creek Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001103082",
    },
    {
        "school": "Ridgewood Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001203109",
    },
    {
        "school": "Cox Mill High School",
        "district": "Cabarrus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053003083",
    },
    {
        "school": "Snow Creek Elementary",
        "district": "Catawba County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370069003084",
    },
    {
        "school": "City of Medicine Academy",
        "district": "Durham Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126003112",
    },
    {
        "school": "Spring Valley Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126003115",
    },
    {
        "school": "Franklin County Early College",
        "district": "Franklin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153003101",
    },
    {
        "school": "Phoenix Academy",
        "district": "Granville County Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370180003114",
    },
    {
        "school": "Hertford Co Early College",
        "district": "Hertford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370216003106",
    },
    {
        "school": "CS Brown High",
        "district": "Hertford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370216003107",
    },
    {
        "school": "Coddle Creek Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231003080",
    },
    {
        "school": "Cloverleaf Elementary",
        "district": "Iredell-Statesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231003081",
    },
    {
        "school": "Blue Ridge Early College",
        "district": "Jackson County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370234003104",
    },
    {
        "school": "Jackson Co Early College",
        "district": "Jackson County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370234003111",
    },
    {
        "school": "Powhatan Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237003113",
    },
    {
        "school": "Johnston Co Early College Academy",
        "district": "Johnston County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237003116",
    },
    {
        "school": "Princeton Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237003117",
    },
    {
        "school": "Berewick Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003103",
    },
    {
        "school": "Green Ridge Elementary",
        "district": "Montgomery County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306003108",
    },
    {
        "school": "Wheatmore High",
        "district": "Randolph County School System",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370378003100",
    },
    {
        "school": "Richmond 9th Grade Academy",
        "district": "Richmond County Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387003110",
    },
    {
        "school": "Union Intermediate",
        "district": "Sampson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370414003078",
    },
    {
        "school": "Cuthbertson High",
        "district": "Union County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462003093",
    },
    {
        "school": "Cuthbertson Middle",
        "district": "Union County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462003095",
    },
    {
        "school": "Poplin Elementary",
        "district": "Union County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370462003096",
    },
    {
        "school": "Roanoke Valley Early College",
        "district": "Weldon City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370489003079",
    },
    {
        "school": "John W Jones Elementary",
        "district": "Wilson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502003094",
    },
    {
        "school": "Wilson Early College Academy",
        "district": "Wilson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502003097",
    },
    {
        "school": "Forbush Middle",
        "district": "Yadkin County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504003098",
    },
    {
        "school": "Starmount Middle",
        "district": "Yadkin County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370504003099",
    },
    {
        "school": "STEELE-DAWSON ELEMENTARY SCHOOL",
        "district": "KIDDER COUNTY 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380038900611",
    },
    {
        "school": "STEELE-DAWSON HIGH SCHOOL",
        "district": "KIDDER COUNTY 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380038900612",
    },
    {
        "school": "TAPPEN ELEMENTARY SCHOOL",
        "district": "KIDDER COUNTY 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380038900624",
    },
    {
        "school": "NORTH STAR ELEMENTARY SCHOOL",
        "district": "NORTH STAR 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380039000595",
    },
    {
        "school": "NORTH STAR HIGH SCHOOL",
        "district": "NORTH STAR 10",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380039000596",
    },
    {
        "school": "BELL ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000028",
    },
    {
        "school": "Mahoning County High School",
        "district": "Mahoning County High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390132905451",
    },
    {
        "school": "KIPP Columbus",
        "district": "KIPP Columbus",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390133005487",
    },
    {
        "school": "Cesar Chavez College Preparatory School",
        "district": "Cesar Chavez College Preparatory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390133505496",
    },
    {
        "school": "Performance Academy Eastland",
        "district": "Performance Academy Eastland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390133705488",
    },
    {
        "school": "L. Hollingworth School for Talented and Gifted",
        "district": "L. Hollingworth School for Talented and Gifted",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390133905468",
    },
    {
        "school": "Sullivant Avenue Community School",
        "district": "Sullivant Avenue Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390134405464",
    },
    {
        "school": "Harrisburg Pike Community School",
        "district": "Harrisburg Pike Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390134505467",
    },
    {
        "school": "Madison Avenue School of Arts",
        "district": "Madison Avenue School of Arts",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390134605469",
    },
    {
        "school": "Klepinger Community School",
        "district": "Klepinger Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390134705453",
    },
    {
        "school": "Ashland County Community Academy",
        "district": "Ashland County Community Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390135005447",
    },
    {
        "school": "Horizon Science Academy Elementary School",
        "district": "Horizon Science Academy Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390135305483",
    },
    {
        "school": "Early Learning Program",
        "district": "Akron City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434805502",
    },
    {
        "school": "Canton Arts Academy @ Summit",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437105030",
    },
    {
        "school": "Canton City Digital Academy",
        "district": "Canton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437105489",
    },
    {
        "school": "Claymont Preschool",
        "district": "Claymont City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437705504",
    },
    {
        "school": "Design Lab @ Health Careers",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805466",
    },
    {
        "school": "MC^2 STEM High School",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805476",
    },
    {
        "school": "Ruskin Elementary School",
        "district": "Dayton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438405480",
    },
    {
        "school": "Shawnee Elementary",
        "district": "Huron City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441305456",
    },
    {
        "school": "Lockland Middle School",
        "district": "Lockland Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442305455",
    },
    {
        "school": "Mansfield Spanish Immersion School",
        "district": "Mansfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442905450",
    },
    {
        "school": "Anna Marie Ayers Elementary School",
        "district": "Martins Ferry City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443405465",
    },
    {
        "school": "Maddux-Lang Primary School",
        "district": "Miamisburg City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443905477",
    },
    {
        "school": "Glenwood Elementary School",
        "district": "Toledo City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449005482",
    },
    {
        "school": "New Miami Middle School",
        "district": "New Miami Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461305448",
    },
    {
        "school": "Berkshire Middle School",
        "district": "Olentangy Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605471",
    },
    {
        "school": "Heritage Elementary School",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605474",
    },
    {
        "school": "Freedom Trail Elementary",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605481",
    },
    {
        "school": "Cheshire Elementary",
        "district": "Olentangy Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605485",
    },
    {
        "school": "Madison Pre-K",
        "district": "Madison Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478805499",
    },
    {
        "school": "Northridge Intermediate",
        "district": "Northridge Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480305449",
    },
    {
        "school": "Northridge Primary",
        "district": "Northridge Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480305462",
    },
    {
        "school": "Midview East Intermediate School",
        "district": "Midview Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390481705463",
    },
    {
        "school": "Mad River Early Childhood Center",
        "district": "Mad River Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487005500",
    },
    {
        "school": "Danbury Middle School",
        "district": "Danbury Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390489305486",
    },
    {
        "school": "Sandy Valley Elementary School",
        "district": "Sandy Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499405457",
    },
    {
        "school": "Sandy Valley Middle School",
        "district": "Sandy Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390499405478",
    },
    {
        "school": "SalemTownship Elementary School",
        "district": "Little Miami Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504405492",
    },
    {
        "school": "East Knox Elementary School",
        "district": "East Knox Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001305458",
    },
    {
        "school": "Wooster Littlest Generals Preschool",
        "district": "Wooster City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003205503",
    },
    {
        "school": "DEBORAH BROWN COMMUNITY SCHOOL",
        "district": "DEBORAH BROWN (CHARTER)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400075102682",
    },
    {
        "school": "CARNEGIE MS",
        "district": "CARNEGIE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400663002676",
    },
    {
        "school": "COWETA INTERMEDIATE HS",
        "district": "COWETA",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400885002683",
    },
    {
        "school": "DALE MS",
        "district": "DALE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400939002681",
    },
    {
        "school": "THOMAS IES",
        "district": "HOLDENVILLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401479002673",
    },
    {
        "school": "JAY UPPER ES",
        "district": "JAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401569002680",
    },
    {
        "school": "EISENHOWER MS",
        "district": "LAWTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725002679",
    },
    {
        "school": "LEXINGTON MS",
        "district": "LEXINGTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401758002678",
    },
    {
        "school": "STRATFORD MS",
        "district": "STRATFORD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402898002677",
    },
    {
        "school": "WILBURTON MS",
        "district": "WILBURTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403279002675",
    },
    {
        "school": "Lincoln Street Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301749",
    },
    {
        "school": "Rosedale Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301750",
    },
    {
        "school": "Quatama Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301759",
    },
    {
        "school": "Free Orchards Elementary School",
        "district": "Hillsboro SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301764",
    },
    {
        "school": "Bonny Slope Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001753",
    },
    {
        "school": "Ponderosa Elementary",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001747",
    },
    {
        "school": "William E Miller Elementary",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001758",
    },
    {
        "school": "Summit Learning Charter",
        "district": "Estacada SD 108",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410470001766",
    },
    {
        "school": "Lewis and Clark Montessori Charter School",
        "district": "Gresham-Barlow SD 10J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600001757",
    },
    {
        "school": "Sue Buel Elementary",
        "district": "McMinnville SD 40",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410801001752",
    },
    {
        "school": "Oregon Virtual Academy",
        "district": "North Bend SD 13",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410882001751",
    },
    {
        "school": "Creative Science School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001765",
    },
    {
        "school": "Pan American Academy CS",
        "district": "Pan American Academy CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420081006871",
    },
    {
        "school": "Environmental Charter School at Frick Pa",
        "district": "Environmental Charter School at Frick Park",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420081206819",
    },
    {
        "school": "Antonia Pantoja Community Charter School",
        "district": "Antonia Pantoja Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420081306909",
    },
    {
        "school": "Altoona Area Jr HS",
        "district": "Altoona Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420234006850",
    },
    {
        "school": "Eden Hall Upper El Sch",
        "district": "Pine-Richland SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420285006816",
    },
    {
        "school": "Chester Upland Sch of Arts",
        "district": "Chester-Upland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420586006878",
    },
    {
        "school": "Daniel Boone Area Primary Ctr",
        "district": "Daniel Boone Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420729006772",
    },
    {
        "school": "Springton Manor El Sch",
        "district": "Downingtown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771006843",
    },
    {
        "school": "Tilden El Center",
        "district": "Hamburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421134006870",
    },
    {
        "school": "Jeannette McKee El Sch",
        "district": "Jeannette City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421233006807",
    },
    {
        "school": "Kindergarten Academy",
        "district": "Mechanicsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421503006867",
    },
    {
        "school": "Fink El Sch",
        "district": "Middletown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421524006934",
    },
    {
        "school": "C E Cole Intermediate Sch",
        "district": "Muhlenberg SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421620006905",
    },
    {
        "school": "Octorara Intermediate Sch",
        "district": "Octorara Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421803006848",
    },
    {
        "school": "West Vincent El Sch",
        "district": "Owen J Roberts SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421827006812",
    },
    {
        "school": "Parkside Education Center",
        "district": "Palmerton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421836006856",
    },
    {
        "school": "Barry Comm John Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006869",
    },
    {
        "school": "Arts Academy at Benjamin Rush",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899006904",
    },
    {
        "school": "Pocono Mountain East JHS",
        "district": "Pocono Mountain SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421950006820",
    },
    {
        "school": "Shaler Area MS",
        "district": "Shaler Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422120006774",
    },
    {
        "school": "Shaler Area El Sch",
        "district": "Shaler Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422120006855",
    },
    {
        "school": "Walnut Street El Sch",
        "district": "William Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422639006806",
    },
    {
        "school": "Colt Andrews School",
        "district": "Bristol Warren",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440006500468",
    },
    {
        "school": "North Smithfield MS",
        "district": "North Smithfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440081000469",
    },
    {
        "school": "Jacqueline M. Walsh School",
        "district": "Pawtucket",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440084000466",
    },
    {
        "school": "Providence Career Technical",
        "district": "Providence",
        "level": "High",
        "type": "Career and Technical School",
        "state": "RI",
        "nces_id": "440090000467",
    },
    {
        "school": "Flat Rock Elementary",
        "district": "Anderson 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450084001506",
    },
    {
        "school": "West Market School of Early Education",
        "district": "Anderson 05",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090001515",
    },
    {
        "school": "Cane Bay High",
        "district": "Berkeley 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001523",
    },
    {
        "school": "Charleston Charter School for Math and Science",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001505",
    },
    {
        "school": "Ashley Ridge High",
        "district": "Dorchester 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001508",
    },
    {
        "school": "Waccamaw Intermediate",
        "district": "Georgetown 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228001518",
    },
    {
        "school": "Ruldolph G. Gordon School at Jones Mill",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001517",
    },
    {
        "school": "Ralph Chandler Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001524",
    },
    {
        "school": "Greenwood Early Childhood Center",
        "district": "Greenwood 50",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450234001512",
    },
    {
        "school": "Forts Pond Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001514",
    },
    {
        "school": "New Providence Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001525",
    },
    {
        "school": "Bridge Creek Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001507",
    },
    {
        "school": "Abner Creek Academy",
        "district": "Spartanburg 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360001503",
    },
    {
        "school": "Lyman Elementary",
        "district": "Spartanburg 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450360001504",
    },
    {
        "school": "Hemingway Elementary",
        "district": "Williamsburg 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450378001519",
    },
    {
        "school": "Mount Holly Elementary",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001516",
    },
    {
        "school": "Dutchman Creek Middle",
        "district": "York 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001526",
    },
    {
        "school": "SC Connections Academy",
        "district": "SC Public Charter School District",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101520",
    },
    {
        "school": "Goldenview Colony School - 04",
        "district": "McCook Central School District 43-7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102601281",
    },
    {
        "school": "Journey Elementary - 05",
        "district": "Harrisburg School District 41-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463135001288",
    },
    {
        "school": "VOA - Adolescent Treatment - 73",
        "district": "Sioux Falls School District 49-5",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "466627001284",
    },
    {
        "school": "Highmore Elementary - 02",
        "district": "Highmore-Harrold 34-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468044000323",
    },
    {
        "school": "Highmore High School - 01",
        "district": "Highmore-Harrold 34-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468044000324",
    },
    {
        "school": "Highmore Jr. High - 03",
        "district": "Highmore-Harrold 34-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468044001049",
    },
    {
        "school": "Mobridge High School - 01",
        "district": "Mobridge-Pollock 62-6",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468044100449",
    },
    {
        "school": "Mobridge Middle School - 02",
        "district": "Mobridge-Pollock 62-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468044100450",
    },
    {
        "school": "Freeman Davis Elementary - 03",
        "district": "Mobridge-Pollock 62-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468044100486",
    },
    {
        "school": "Mobridge Upper Elementary - 04",
        "district": "Mobridge-Pollock 62-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468044100493",
    },
    {
        "school": "Anderson County Head Start / Preschool",
        "district": "Anderson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009002163",
    },
    {
        "school": "Union Grove Elementary School",
        "district": "Blount County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030002164",
    },
    {
        "school": "Special Services",
        "district": "Dickson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102002183",
    },
    {
        "school": "Rutledge Middle School",
        "district": "Grainger County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470144002165",
    },
    {
        "school": "Rutledge Primary",
        "district": "Grainger County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470144002187",
    },
    {
        "school": "Small Miracles - Holston U. M. Home For Children",
        "district": "Greene County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147002168",
    },
    {
        "school": "The Children's Center - Holston U. M. Home For Children",
        "district": "Greene County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470147002186",
    },
    {
        "school": "Grundy Academy",
        "district": "Grundy County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470153002144",
    },
    {
        "school": "Hancock County Early Learning Center",
        "district": "Hancock County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470162002166",
    },
    {
        "school": "Northwest Head Start - Huntingdon",
        "district": "Huntingdon Special School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470201002170",
    },
    {
        "school": "Dandridge Head Start",
        "district": "Jefferson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210002167",
    },
    {
        "school": "Little Buccaneers Student Child Care Center",
        "district": "Johnson City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213002173",
    },
    {
        "school": "Hardin Valley Academy",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222002151",
    },
    {
        "school": "West Creek Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303002152",
    },
    {
        "school": "West Creek High",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303002153",
    },
    {
        "school": "Rossview Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303002156",
    },
    {
        "school": "Middle College @ Austin Peay State University",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303002158",
    },
    {
        "school": "Cane Ridge High School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002142",
    },
    {
        "school": "John F. Kennedy Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002149",
    },
    {
        "school": "Wayne Reed Child Care Center",
        "district": "Davidson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002185",
    },
    {
        "school": "T T U Child Development Lab",
        "district": "Putnam County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348002162",
    },
    {
        "school": "Rockvale Middle School",
        "district": "Rutherford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002145",
    },
    {
        "school": "Catlettsburg Elementary School",
        "district": "Sevier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378002143",
    },
    {
        "school": "Douglas Dam Head Start",
        "district": "Sevier County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378002181",
    },
    {
        "school": "Highland Rim Head Start",
        "district": "Stewart County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470396002182",
    },
    {
        "school": "Station Camp Elementary",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402002155",
    },
    {
        "school": "Atoka Elementary School",
        "district": "Tipton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470408002159",
    },
    {
        "school": "Unicoi Community Learning Center",
        "district": "Unicoi County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470423002180",
    },
    {
        "school": "Ridgeview Elementary School",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438002154",
    },
    {
        "school": "Grandview Elementary School",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438002160",
    },
    {
        "school": "Elzie D Patton Elementary School",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455002157",
    },
    {
        "school": "RALPH PFLUGER EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001012146",
    },
    {
        "school": "UPLIFT EDUCATION-NORTH HILLS PREP H S",
        "district": "UPLIFT EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012221",
    },
    {
        "school": "PAUL AND JANE MEYER PUBLIC H S",
        "district": "RAPOPORT ACADEMY PUBLIC SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480004211302",
    },
    {
        "school": "JHW INSPIRE ACADEMY - ROCKDALE",
        "district": "INSPIRE ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480005312039",
    },
    {
        "school": "MILTON B LEE ACADEMY OF SCIENCE & ENGINEERING",
        "district": "SCHOOL OF EXCELLENCE IN EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006212237",
    },
    {
        "school": "HORIZON MONTESSORI III",
        "district": "HORIZON MONTESSORI PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006512111",
    },
    {
        "school": "HELPING HAND",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007112104",
    },
    {
        "school": "SARAH STRINDEN EL",
        "district": "PINEYWOODS COMMUNITY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007412201",
    },
    {
        "school": "LETOT CAMPUS",
        "district": "ACADEMY FOR ACADEMIC EXCELLENCE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480009312005",
    },
    {
        "school": "MEDLOCK YOUTH VILLAGE",
        "district": "ACADEMY FOR ACADEMIC EXCELLENCE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480009312112",
    },
    {
        "school": "DRC CAMPUS",
        "district": "ACADEMY FOR ACADEMIC EXCELLENCE",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480009312248",
    },
    {
        "school": "FAITH FAMILY MASTER ACADEMY",
        "district": "WAXAHACHIE FAITH FAMILY ACADEMY",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480010512070",
    },
    {
        "school": "TEKOA ACADEMY OF ACCELERATED STUDIES - ORANGE",
        "district": "TEKOA ACADEMY OF ACCELERATED STUDIES STEM SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480013912116",
    },
    {
        "school": "COASTAL HORIZONS ACADEMY",
        "district": "ERATH EXCELS ACADEMY INC",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480015912097",
    },
    {
        "school": "ISCHOOL HIGH - LEWISVILLE",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312093",
    },
    {
        "school": "CARROLLTON CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312148",
    },
    {
        "school": "VISTA ACADEMY OF WILLIS",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312179",
    },
    {
        "school": "VISTA ACADEMY OF GARLAND",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312215",
    },
    {
        "school": "TRIUMPH PUBLIC HIGH SCHOOLS-LAREDO SOUTH",
        "district": "TRIUMPH PUBLIC HIGH SCHOOLS-LAREDO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480017412212",
    },
    {
        "school": "JUBILEE - LAKE VIEW UNIVERSITY PREP",
        "district": "JUBILEE ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017912180",
    },
    {
        "school": "NORTH TEXAS COLLEGIATE ACADEMY-EAST CAMPUS",
        "district": "NORTH TEXAS COLLEGIATE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480018711999",
    },
    {
        "school": "AIA LANCASTER MIDDLE",
        "district": "ACCELERATED INTERMEDIATE ACADEMY",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480019212123",
    },
    {
        "school": "AIA LANCASTER EL",
        "district": "ACCELERATED INTERMEDIATE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480019212133",
    },
    {
        "school": "IDEA ACADEMY SAN JUAN",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021111996",
    },
    {
        "school": "IDEA ACADEMY SAN BENITO",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112007",
    },
    {
        "school": "IDEA COLLEGE PREPARATORY SAN JUAN",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112040",
    },
    {
        "school": "IDEA COLLEGE PREPARATORY MISSION",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112150",
    },
    {
        "school": "IDEA COLLEGE PREPARATORY SAN BENITO",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112164",
    },
    {
        "school": "IDEA ACADEMY MISSION",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112261",
    },
    {
        "school": "NEW HORIZONS",
        "district": "ORENDA CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480023511986",
    },
    {
        "school": "BAKER-RIPLEY CHARTER SCHOOL",
        "district": "PROMISE COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024012196",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY-PFLUGERVILLE",
        "district": "HARMONY SCIENCE ACADEMY (AUSTIN)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024112260",
    },
    {
        "school": "VISTA DEL FUTURO CHARTER SCHOOL",
        "district": "VISTA DEL FUTURO CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480139412121",
    },
    {
        "school": "STEPHEN F AUSTIN STATE UNIVERSITY CHARTER SCHOOL",
        "district": "STEPHEN F AUSTIN STATE UNIVERSITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480139512006",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY DISCOVERY",
        "district": "SCHOOL OF SCIENCE AND TECHNOLOGY DISCOVERY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140012140",
    },
    {
        "school": "OAKS ACADEMY",
        "district": "MEADOWLAND CHARTER DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480140412137",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY-SUGAR LAND",
        "district": "HARMONY SCHOOL OF SCIENCE - HOUSTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140512025",
    },
    {
        "school": "CHAPEL HILL ACADEMY",
        "district": "CHAPEL HILL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140712082",
    },
    {
        "school": "CREEK VIEW EL",
        "district": "COLLEGE STATION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735012023",
    },
    {
        "school": "GARCIA-LEZA EC/PK/K",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771012009",
    },
    {
        "school": "DAVIS H S ALDINE",
        "district": "ALDINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771012108",
    },
    {
        "school": "GRIGGS EC/PK/K",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771012117",
    },
    {
        "school": "GREENSPOINT EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771012174",
    },
    {
        "school": "GARCIA MIDDLE",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771012191",
    },
    {
        "school": "LEWIS MIDDLE",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771012198",
    },
    {
        "school": "DAVIS NINTH GRADE",
        "district": "ALDINE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771012202",
    },
    {
        "school": "CYPRESSWOOD EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771012216",
    },
    {
        "school": "MARY EVANS EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789012153",
    },
    {
        "school": "ARGYLE INT",
        "district": "ARGYLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480867012249",
    },
    {
        "school": "JAMES A MONACO",
        "district": "AUBREY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480891012259",
    },
    {
        "school": "EASTSIDE MEMORIAL ECHS",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894012013",
    },
    {
        "school": "UPHAUS EARLY CHILDHOOD CENTER",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894012058",
    },
    {
        "school": "TRAVIS COUNTY DAY SCHOOL",
        "district": "AUSTIN ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894012204",
    },
    {
        "school": "BOERNE - SAMUEL V CHAMPION H S",
        "district": "BOERNE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071012014",
    },
    {
        "school": "BROWNFIELD EDUCATION CENTER",
        "district": "BROWNFIELD ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481161012078",
    },
    {
        "school": "VETERANS MEMORIAL EARLY COLLEGE H S",
        "district": "BROWNSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168012029",
    },
    {
        "school": "MANZANO MIDDLE",
        "district": "BROWNSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168012072",
    },
    {
        "school": "PULLAM EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168012077",
    },
    {
        "school": "PENA EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168012087",
    },
    {
        "school": "KELLER EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168012099",
    },
    {
        "school": "BROWNSVILLE EARLY COLLEGE H S",
        "district": "BROWNSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168012172",
    },
    {
        "school": "BREEDEN EL",
        "district": "BROWNSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481168012238",
    },
    {
        "school": "BULLARD EARLY CHILDHOOD",
        "district": "BULLARD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481206012154",
    },
    {
        "school": "IRENE CLINKSCALE EL",
        "district": "BURLESON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218012251",
    },
    {
        "school": "BURLESON CENTENNIAL H S",
        "district": "BURLESON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218012263",
    },
    {
        "school": "KATHRYN GRIFFIS EL",
        "district": "CADDO MILLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481239012232",
    },
    {
        "school": "CITY VIEW EL",
        "district": "CANYON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281012109",
    },
    {
        "school": "HILLSIDE EL",
        "district": "CANYON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281012226",
    },
    {
        "school": "CEDAR HILL COLLEGIATE H S",
        "district": "CEDAR HILL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323012181",
    },
    {
        "school": "FREDERICK A DOUGLASS LEARNING ACADEMY",
        "district": "CLEVELAND ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481437012020",
    },
    {
        "school": "MT VALLEY EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473011987",
    },
    {
        "school": "VINTAGE OAKS AREA EL",
        "district": "COMAL ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473012061",
    },
    {
        "school": "NESMITH EL",
        "district": "COMMUNITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481485012184",
    },
    {
        "school": "PATTERSON EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500012002",
    },
    {
        "school": "BIRNHAM WOODS EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500012003",
    },
    {
        "school": "IRONS J H",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500012065",
    },
    {
        "school": "BOZMAN INT",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500012069",
    },
    {
        "school": "COX INT",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500012081",
    },
    {
        "school": "STEWART EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500012142",
    },
    {
        "school": "BARBARA WALKER EL",
        "district": "CRANDALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481551012027",
    },
    {
        "school": "OZONA EL",
        "district": "CROCKETT COUNTY CONSOLIDATED CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481569011990",
    },
    {
        "school": "SUMMER CREEK MIDDLE",
        "district": "CROWLEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591012022",
    },
    {
        "school": "S H CROWLEY EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591012229",
    },
    {
        "school": "SWENKE EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611012222",
    },
    {
        "school": "KATHLYN JOY GILLIAM COLLEGIATE ACADEMY",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012028",
    },
    {
        "school": "JOSE 'JOE' MAY EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012062",
    },
    {
        "school": "STEPHENS EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674012067",
    },
    {
        "school": "ATASCOSA COUNTY JJAEP",
        "district": "DEVINE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481695012032",
    },
    {
        "school": "3D ACADEMY",
        "district": "DONNA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481739012205",
    },
    {
        "school": "ED WILLKIE MIDDLE",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770012120",
    },
    {
        "school": "DR KAY TEER CRAWFORD EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818012033",
    },
    {
        "school": "R C FLORES-MARK A ZAPATA EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818012046",
    },
    {
        "school": "ALFONSO RAMIREZ EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818012060",
    },
    {
        "school": "ELIAS LONGORIA SR MIDDLE",
        "district": "EDINBURG CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818012118",
    },
    {
        "school": "ROBERT R VELA H S",
        "district": "EDINBURG CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818012159",
    },
    {
        "school": "MACARIA DELA GARZA GORENA EL",
        "district": "EDINBURG CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818012178",
    },
    {
        "school": "BETTY HARWELL MIDDLE",
        "district": "EDINBURG CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818012228",
    },
    {
        "school": "TRANSMOUNTAIN EARLY COLLEGE H S",
        "district": "EL PASO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830012055",
    },
    {
        "school": "G W CARVER EARLY CHILDHOOD CENTER",
        "district": "ENNIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481854012158",
    },
    {
        "school": "FABENS EL",
        "district": "FABENS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481890012036",
    },
    {
        "school": "BELL COUNTY JJAEP",
        "district": "FLORENCE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481932012084",
    },
    {
        "school": "HERITAGE ROSE EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965012010",
    },
    {
        "school": "JUAN SEGUIN EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965012016",
    },
    {
        "school": "CAROLYN AND VERNON MADDEN EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965012210",
    },
    {
        "school": "JAMES BOWIE MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965012214",
    },
    {
        "school": "FERNDELL HENRY CENTER FOR LEARNING",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481965012235",
    },
    {
        "school": "RIDGE POINT H S",
        "district": "FORT BEND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965012240",
    },
    {
        "school": "RONALD THORNTON MIDDLE",
        "district": "FORT BEND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965012242",
    },
    {
        "school": "TAKS",
        "district": "FORT WORTH ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970012258",
    },
    {
        "school": "EARLY CHILDHOOD SCHOOL",
        "district": "FRISCO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001011985",
    },
    {
        "school": "TADLOCK EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012138",
    },
    {
        "school": "ALLEN EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012141",
    },
    {
        "school": "HERITAGE H S",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012192",
    },
    {
        "school": "SCOGGINS MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012220",
    },
    {
        "school": "ELLIOTT EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012247",
    },
    {
        "school": "STAFFORD MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012255",
    },
    {
        "school": "JAMES E MITCHELL EL",
        "district": "GEORGETOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060012217",
    },
    {
        "school": "HOBBS WILLIAMS EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142012066",
    },
    {
        "school": "CROSSWINDS ACCELERATED H S",
        "district": "GRAND PRAIRIE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482142012100",
    },
    {
        "school": "JOHN A DUBISKI CAREER H S",
        "district": "GRAND PRAIRIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142012129",
    },
    {
        "school": "SOUTHWEST KEY",
        "district": "HARLINGEN CISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482253011995",
    },
    {
        "school": "LEE H MEANS EL",
        "district": "HARLINGEN CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253012048",
    },
    {
        "school": "HEARNE EL",
        "district": "HEARNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482283012113",
    },
    {
        "school": "INSPIRED FOR EXCELLENCE ACADEMY INC",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482364012042",
    },
    {
        "school": "REAGAN K-8 EDUCATIONAL CTR",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012085",
    },
    {
        "school": "DEANDA EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012088",
    },
    {
        "school": "MOUNT CARMEL ACADEMY",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012203",
    },
    {
        "school": "HOUSTON MATH SCIENCE AND TECHNOLOGY CENTER",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012211",
    },
    {
        "school": "ENERGIZED FOR STEM ACADEMY SOUTHEAST H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012243",
    },
    {
        "school": "NORTH HOUSTON EARLY COLLEGE H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012246",
    },
    {
        "school": "FARLEY MIDDLE",
        "district": "HUTTO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482410012021",
    },
    {
        "school": "JUDSON EARLY COLLEGE ACADEMY",
        "district": "JUDSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499012011",
    },
    {
        "school": "JAMES L MASTERS",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499012236",
    },
    {
        "school": "RICHARD E CAVAZOS EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566012047",
    },
    {
        "school": "CHARLES E PATTERSON MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566012054",
    },
    {
        "school": "THERAPEUTIC EDUCATION PROGRAM",
        "district": "KLEIN ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482574012071",
    },
    {
        "school": "KRUM EARLY EDUCATION CENTER",
        "district": "KRUM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482598012059",
    },
    {
        "school": "LA VERNIA INT",
        "district": "LA VERNIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482631012080",
    },
    {
        "school": "N A HOWRY INT",
        "district": "LAKE WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482649012068",
    },
    {
        "school": "JOE HUBENAK EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658012073",
    },
    {
        "school": "CORA THOMAS EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658012086",
    },
    {
        "school": "TAYLOR CREEK EL",
        "district": "LAMPASAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482664012241",
    },
    {
        "school": "RIVER RIDGE EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703011991",
    },
    {
        "school": "RONALD REAGAN EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703012130",
    },
    {
        "school": "VANDEGRIFT H S",
        "district": "LEANDER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703012156",
    },
    {
        "school": "PARKSIDE EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703012218",
    },
    {
        "school": "WESTSIDE EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703012256",
    },
    {
        "school": "LEWISVILLE EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730012074",
    },
    {
        "school": "TECHNOLOGY EXPLORATION AND CAREER CENTER (TECC-E)",
        "district": "LEWISVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730012207",
    },
    {
        "school": "MAGNOLIA PARKWAY EL",
        "district": "MAGNOLIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874012105",
    },
    {
        "school": "PIONEER CROSSING EL",
        "district": "MANOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889011988",
    },
    {
        "school": "EL #22",
        "district": "MCKINNEY ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985012075",
    },
    {
        "school": "LIZZIE NELL CUNDIFF MCCLURE EL",
        "district": "MCKINNEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985012083",
    },
    {
        "school": "ACHZIGER EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039012089",
    },
    {
        "school": "CASTLEMAN CREEK EL",
        "district": "MIDWAY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483064012131",
    },
    {
        "school": "MADELEY RANCH EL",
        "district": "MONTGOMERY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483126012213",
    },
    {
        "school": "KLEIN ROAD EL",
        "district": "NEW BRAUNFELS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237012223",
    },
    {
        "school": "ROBERT F HUNT EL",
        "district": "NEW DIANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483246012169",
    },
    {
        "school": "NORMANGEE MIDDLE",
        "district": "NORMANGEE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483291012155",
    },
    {
        "school": "HOFFMANN EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012076",
    },
    {
        "school": "KUENTZ EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012098",
    },
    {
        "school": "LANGLEY EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012182",
    },
    {
        "school": "GARCIA MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012195",
    },
    {
        "school": "O A PETERSON",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318011993",
    },
    {
        "school": "SENDERA RANCH EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318012004",
    },
    {
        "school": "BYRON NELSON H S",
        "district": "NORTHWEST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318012019",
    },
    {
        "school": "FAIRVIEW SPECIAL PROGRAMS",
        "district": "OLFEN ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483357012136",
    },
    {
        "school": "KELLER MIDDLE",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432012135",
    },
    {
        "school": "RIOJAS EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483012031",
    },
    {
        "school": "PSJA THOMAS JEFFERSON T-STEM EARLY COLLEGE H S",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486012225",
    },
    {
        "school": "BARRON EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510012132",
    },
    {
        "school": "ISAACS EARLY CHILDHOOD SCHOOL",
        "district": "PLANO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510012187",
    },
    {
        "school": "C A MCMILLEN H S",
        "district": "PLANO ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510012193",
    },
    {
        "school": "STAFF SERGEANT LUCIAN ADAMS EL",
        "district": "PORT ARTHUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540012209",
    },
    {
        "school": "HARPER EL",
        "district": "PRINCETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483585012208",
    },
    {
        "school": "RICE JH",
        "district": "RICE CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483697012186",
    },
    {
        "school": "RIO GRANDE CITY CISD GRULLA H S",
        "district": "RIO GRANDE CITY CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714012124",
    },
    {
        "school": "SOUTH TEXAS ISD PREPARATORY ACADEMY",
        "district": "SOUTH TEXAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483715012250",
    },
    {
        "school": "ROCKDALE INT",
        "district": "ROCKDALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483759012043",
    },
    {
        "school": "BELL COUNTY DAEP",
        "district": "ROGERS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483771012091",
    },
    {
        "school": "RUTH CHERRY INT",
        "district": "ROYSE CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483822012115",
    },
    {
        "school": "SALADO J H",
        "district": "SALADO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483858012125",
    },
    {
        "school": "COOPER ACADEMY AT NAVARRO",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483873012224",
    },
    {
        "school": "RGV YOUTH RECOVERY HOME",
        "district": "SAN BENITO CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483879012122",
    },
    {
        "school": "MENDEZ EL",
        "district": "SAN MARCOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483897012183",
    },
    {
        "school": "MICHAEL R NULL MIDDLE",
        "district": "SHELDON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483999012064",
    },
    {
        "school": "SHELDON EARLY CHILDHOOD ACADEMY",
        "district": "SHELDON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483999012101",
    },
    {
        "school": "PINEY WOODS EL",
        "district": "SPLENDORA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484107011989",
    },
    {
        "school": "HOYLAND EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122012103",
    },
    {
        "school": "RALPH EICKENROHT EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122012227",
    },
    {
        "school": "HELEN MAJOR EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122012252",
    },
    {
        "school": "EDWARD ROBERSON MIDDLE",
        "district": "SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122012254",
    },
    {
        "school": "SUNNYVALE H S",
        "district": "SUNNYVALE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484188011997",
    },
    {
        "school": "VALLEY VIEW J H",
        "district": "VALLEY VIEW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484380012094",
    },
    {
        "school": "RODOLFO TORRES EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415012253",
    },
    {
        "school": "ELLA SCHORLEMMER EL",
        "district": "VICTORIA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415012262",
    },
    {
        "school": "SCHULTZ J H",
        "district": "WALLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484443012000",
    },
    {
        "school": "EVELYN TURLINGTON EL",
        "district": "WALLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484443012190",
    },
    {
        "school": "WALNUT SPRINGS SCHOOL",
        "district": "WALNUT SPRINGS ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484452012079",
    },
    {
        "school": "WHARTON EL",
        "district": "WHARTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484538012197",
    },
    {
        "school": "FINE ARTS ACADEMY",
        "district": "WHITE SETTLEMENT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484554012161",
    },
    {
        "school": "J W HOLLOWAY SIXTH GRADE SCHOOL",
        "district": "WHITEHOUSE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484560012052",
    },
    {
        "school": "MOZELLE BROWN EL",
        "district": "WHITEHOUSE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484560012230",
    },
    {
        "school": "GUS WINSTON CAIN EL",
        "district": "WHITEHOUSE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484560012233",
    },
    {
        "school": "H L HIGGINS EL",
        "district": "WHITEHOUSE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484560012234",
    },
    {
        "school": "FARRIS EARLY CHILDHOOD CTR",
        "district": "WICHITA FALLS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578012030",
    },
    {
        "school": "DEL VALLE EL",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668012245",
    },
    {
        "school": "Thomas Edison - South",
        "district": "Thomas Edison",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490001501284",
    },
    {
        "school": "Westlake High",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001293",
    },
    {
        "school": "North Point School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001299",
    },
    {
        "school": "Excelsior Academy",
        "district": "Excelsior Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490013601272",
    },
    {
        "school": "Hawthorn Academy West Jordan",
        "district": "Hawthorn Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490013701298",
    },
    {
        "school": "Mountain Heights Academy",
        "district": "Mountain Heights Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490013801285",
    },
    {
        "school": "Jefferson Academy",
        "district": "Jefferson Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490013901289",
    },
    {
        "school": "Early Light Academy at Daybreak",
        "district": "Early Light Academy at Daybreak",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014001268",
    },
    {
        "school": "Vista School",
        "district": "Vista School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014101296",
    },
    {
        "school": "Legacy Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001275",
    },
    {
        "school": "Diamond Ridge School",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036001279",
    },
    {
        "school": "Heritage School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001280",
    },
    {
        "school": "Ben Lomond High",
        "district": "Ogden City District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001281",
    },
    {
        "school": "Lakeview School",
        "district": "Provo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081001267",
    },
    {
        "school": "Eagle View School",
        "district": "Uintah District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490108001270",
    },
    {
        "school": "Ashley Valley Educ. Ctr.",
        "district": "Uintah District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490108001302",
    },
    {
        "school": "Desert Hills High",
        "district": "Washington District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001290",
    },
    {
        "school": "Sunrise Ridge Intermediate",
        "district": "Washington District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001300",
    },
    {
        "school": "Weathersfield School",
        "district": "Weathersfield School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500870000536",
    },
    {
        "school": "COATES ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002800",
    },
    {
        "school": "LAUREL HILL ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002802",
    },
    {
        "school": "GREENWOOD MILL ELEM",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147002808",
    },
    {
        "school": "GRAYSON HIGHLANDS",
        "district": "GRAYSON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510169002806",
    },
    {
        "school": "HUNTER B ANDREWS",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180002811",
    },
    {
        "school": "GEORGE P PHENIX ELEM",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510180002816",
    },
    {
        "school": "KENNETH W CULBERT ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002809",
    },
    {
        "school": "WOODGROVE HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Other",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002812",
    },
    {
        "school": "TUSCARORA HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Other",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002817",
    },
    {
        "school": "LURAY MIDDLE",
        "district": "PAGE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510285002799",
    },
    {
        "school": "PAGE COUNTY MIDDLE",
        "district": "PAGE CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510285002801",
    },
    {
        "school": "PATRICK HENRY SCHOOL OF SCIENCE AND ARTS",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324002807",
    },
    {
        "school": "EAST ROCKINGHAM HIGH",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339002803",
    },
    {
        "school": "RIVER BEND ELEM",
        "district": "ROCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510339002804",
    },
    {
        "school": "J BLAINE BLAYTON ELEM",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402002815",
    },
    {
        "school": "Lake Washington Technical Academy",
        "district": "Lake Washington Institute of Technology",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530031303265",
    },
    {
        "school": "Chief Umtuch Middle",
        "district": "Battle Ground School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038003262",
    },
    {
        "school": "Island Juvenile Detention Education Program",
        "district": "Coupeville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530180003266",
    },
    {
        "school": "Endeavour Elementary School",
        "district": "Evergreen School District (Clark)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270003241",
    },
    {
        "school": "Legacy High School",
        "district": "Kennewick School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530393003258",
    },
    {
        "school": "Birth to Age 2",
        "district": "Kent School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530396003244",
    },
    {
        "school": "Carson Elementary",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423003242",
    },
    {
        "school": "Shoreline-Monroe High School",
        "district": "Monroe School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530513003259",
    },
    {
        "school": "Okanogan Outreach Alternative School",
        "district": "Okanogan School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530615003247",
    },
    {
        "school": "Glacier View Junior High",
        "district": "Puyallup School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696003260",
    },
    {
        "school": "Twin Falls Middle School",
        "district": "Snoqualmie Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530804003252",
    },
    {
        "school": "Sumner Special Services",
        "district": "Sumner School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530861003243",
    },
    {
        "school": "Sun Valley Elementary",
        "district": "Sunnyside School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530867003250",
    },
    {
        "school": "Vancouver Virtual Learning Academy",
        "district": "Vancouver School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530927003246",
    },
    {
        "school": "Wahluke Junior High",
        "district": "Wahluke School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530936003264",
    },
    {
        "school": "Yakima Online",
        "district": "Yakima School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "531011003263",
    },
    {
        "school": "NEW RIVER ELEMENTARY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030001475",
    },
    {
        "school": "ACADEMY PROGRAMS",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101471",
    },
    {
        "school": "PRESSLEY RIDGE @ GRANT GARDENS",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101473",
    },
    {
        "school": "HILLTOP ELEMENTARY SCHOOL",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540075001474",
    },
    {
        "school": "BUCKHANNON ACADEMY ELEMENTARY SCHOOL",
        "district": "UPSHUR COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540147001472",
    },
    {
        "school": "Chequamegon High",
        "district": "Chequamegon School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550005802763",
    },
    {
        "school": "Chequamegon Middle",
        "district": "Chequamegon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550005802766",
    },
    {
        "school": "Class ACT Charter",
        "district": "Chequamegon School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WI",
        "nces_id": "550005802780",
    },
    {
        "school": "Early Learning Center",
        "district": "Cedarburg School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "550246002772",
    },
    {
        "school": "Korger-Chestnut",
        "district": "Chippewa Falls Area Unified School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550255002784",
    },
    {
        "school": "Eau Claire Community Sites",
        "district": "Eau Claire Area School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "550405002778",
    },
    {
        "school": "Prairie View Elementary",
        "district": "Holmen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550654002764",
    },
    {
        "school": "Preschool 4 Janesville",
        "district": "Janesville School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702002770",
    },
    {
        "school": "Kenosha 4 Year Old Kindergarten",
        "district": "Kenosha School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732002779",
    },
    {
        "school": "Olson Elementary",
        "district": "Madison Metropolitan School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852002775",
    },
    {
        "school": "Audubon Technology and Communication High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002782",
    },
    {
        "school": "Abraham Lincoln Elementary",
        "district": "Monroe School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550984002771",
    },
    {
        "school": "New Richmond Hillside Elementary",
        "district": "New Richmond School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551062002789",
    },
    {
        "school": "Nature Hill Intermediate",
        "district": "Oconomowoc Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551089002795",
    },
    {
        "school": "Prentice Middle",
        "district": "Prentice School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551221002767",
    },
    {
        "school": "Prescott 4K",
        "district": "Prescott School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551224002762",
    },
    {
        "school": "Sun Prairie Four Kids",
        "district": "Sun Prairie Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464002761",
    },
    {
        "school": "Mead Elementary",
        "district": "Wisconsin Rapids School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551707002781",
    },
    {
        "school": "Sundance Secondary School",
        "district": "Crook County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560237000405",
    },
    {
        "school": "Hulett School",
        "district": "Crook County School District #1",
        "level": "Other",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560237000407",
    },
    {
        "school": "Eastside Elementary",
        "district": "Sweetwater County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200419",
    },
    {
        "school": "Wyoming Girls School",
        "district": "Wyoming Department of Family Services",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WY",
        "nces_id": "568025100534",
    },
    {
        "school": "Wyoming Boys School",
        "district": "Wyoming Department of Family Services",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WY",
        "nces_id": "568025100538",
    },
    {
        "school": "Turtle Mountain Middle School",
        "district": "Turtle Mountain Middle School",
        "level": "Middle",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590002500172",
    },
    {
        "school": "Naa Tsis'aan Community School",
        "district": "Naa Tsis'aan Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590002600183",
    },
    {
        "school": "Flandreau Indian Boarding School",
        "district": "Flandreau Indian Boarding School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590002700084",
    },
    {
        "school": "San Ildefonso Day School",
        "district": "San Ildefonso Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590002800094",
    },
    {
        "school": "Hopi Day School",
        "district": "Hopi Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590002900073",
    },
    {
        "school": "Santa Rosa Day School",
        "district": "Santa Rosa Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590003000106",
    },
    {
        "school": "Choctaw Central High School",
        "district": "Choctaw Central High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590003100047",
    },
    {
        "school": "Cottonwood Day School",
        "district": "Cottonwood Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590003200010",
    },
    {
        "school": "Dzilth-Na-O-Dith-Hle Community School",
        "district": "Dzilth-Na-O-Dith-Hle Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590003300029",
    },
    {
        "school": "Sequoyah High School",
        "district": "Sequoyah High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590003400104",
    },
    {
        "school": "Red Rock Day School",
        "district": "Red Rock Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590003500146",
    },
    {
        "school": "Chief Leschi School",
        "district": "Chief Leschi School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590003600121",
    },
    {
        "school": "Tuba City Boarding School",
        "district": "Tuba City Boarding School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590003700188",
    },
    {
        "school": "Circle of Life Academy",
        "district": "Circle of Life Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590003800082",
    },
    {
        "school": "Te Tsu Geh Oweenge Day School",
        "district": "Te Tsu Geh Oweenge Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590003900098",
    },
    {
        "school": "Moencopi Day School",
        "district": "Moencopi Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590004000077",
    },
    {
        "school": "Northern Cheyenne Tribal School",
        "district": "Northern Cheyenne Tribal School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590004100002",
    },
    {
        "school": "Indian Township School",
        "district": "Indian Township School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590004200052",
    },
    {
        "school": "Nazlini Community School",
        "district": "Nazlini Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590004300014",
    },
    {
        "school": "Na' Neelzhiin Ji'Olta",
        "district": "Na' Neelzhiin Ji'Olta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590004400033",
    },
    {
        "school": "Loneman Day School",
        "district": "Loneman Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590004500116",
    },
    {
        "school": "Alamo Navajo Community School",
        "district": "Alamo Navajo Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590004600023",
    },
    {
        "school": "Muckleshoot Tribal School",
        "district": "Muckleshoot Tribal School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590004700125",
    },
    {
        "school": "Ch'ooshgai Community School",
        "district": "Ch'ooshgai Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590004800061",
    },
    {
        "school": "Hunters Point Boarding School",
        "district": "Hunters Point Boarding School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590004900066",
    },
    {
        "school": "Laguna Middle School",
        "district": "Laguna Middle School",
        "level": "Middle",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590005000155",
    },
    {
        "school": "Cheyenne-Eagle Butte School",
        "district": "Cheyenne-Eagle Butte School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590005100004",
    },
    {
        "school": "Chilchinbeto Community School",
        "district": "Chilchinbeto Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590005200175",
    },
    {
        "school": "Standing Pine Elementary School",
        "district": "Standing Pine Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590005300056",
    },
    {
        "school": "JKL Bahweting Anishnabe School",
        "district": "JKL Bahweting Anishnabe School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590005400080",
    },
    {
        "school": "Marty Indian School",
        "district": "Marty Indian School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590005500132",
    },
    {
        "school": "Tse'ii'ahi' Community School",
        "district": "Tse'ii'ahi' Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590005600038",
    },
    {
        "school": "Yakama Nation Tribal School",
        "district": "Yakama Nation Tribal School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590005700130",
    },
    {
        "school": "Tate Topa Tribal School",
        "district": "Tate Topa Tribal School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590005800164",
    },
    {
        "school": "Wingate Elementary School",
        "district": "Wingate Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590005900039",
    },
    {
        "school": "T`siya Day School",
        "district": "T`siya Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590006000160",
    },
    {
        "school": "Pyramid Lake High School",
        "district": "Pyramid Lake High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590006100137",
    },
    {
        "school": "Wide Ruins Community School",
        "district": "Wide Ruins Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590006200070",
    },
    {
        "school": "Kayenta Boarding School",
        "district": "Kayenta Boarding School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590006300180",
    },
    {
        "school": "Nay-Ah-Shing School",
        "district": "Nay-Ah-Shing School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590006400089",
    },
    {
        "school": "Cove Day School",
        "district": "Cove Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590006500143",
    },
    {
        "school": "Cherokee Central Elementary School",
        "district": "Cherokee Central Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590006600044",
    },
    {
        "school": "Standing Rock Community School",
        "district": "Standing Rock Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590006700163",
    },
    {
        "school": "Ojibwa Indian School",
        "district": "Ojibwa Indian School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590006800168",
    },
    {
        "school": "Kha'p'o Community School",
        "district": "Kha'p'o Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590006900095",
    },
    {
        "school": "American Horse Elem.",
        "district": "American Horse Elem.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590007000113",
    },
    {
        "school": "Coeur d' Alene Tribal School",
        "district": "Coeur d' Alene Tribal School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590007100122",
    },
    {
        "school": "Hopi Jr/Sr High School",
        "district": "Hopi Jr/Sr High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590007200074",
    },
    {
        "school": "Crow Creek Reservation High School",
        "district": "Crow Creek Reservation High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590007300019",
    },
    {
        "school": "Hanaa'dli Community School",
        "district": "Hanaa'dli Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590007400030",
    },
    {
        "school": "Sanostee Day School",
        "district": "Sanostee Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590007500147",
    },
    {
        "school": "John F. Kennedy Day School",
        "district": "John F. Kennedy Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590007600059",
    },
    {
        "school": "Twin Buttes Day School",
        "district": "Twin Buttes Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590007700173",
    },
    {
        "school": "Choctaw Central Middle School",
        "district": "Choctaw Central Middle School",
        "level": "Middle",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590007800048",
    },
    {
        "school": "Jeehdeez'a Elementary School",
        "district": "Jeehdeez'a Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590007900011",
    },
    {
        "school": "Pine Ridge School",
        "district": "Pine Ridge School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590008000117",
    },
    {
        "school": "Isleta Elementary School",
        "district": "Isleta Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590008100152",
    },
    {
        "school": "Second Mesa Day School",
        "district": "Second Mesa Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590008200079",
    },
    {
        "school": "Paschal Sherman Indian School",
        "district": "Paschal Sherman Indian School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590008300126",
    },
    {
        "school": "Ojo Encino Day School",
        "district": "Ojo Encino Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590008400034",
    },
    {
        "school": "Lower Brule Day School",
        "district": "Lower Brule Day School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590008500021",
    },
    {
        "school": "Santa Rosa Ranch School",
        "district": "Santa Rosa Ranch School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590008600107",
    },
    {
        "school": "Baca/Dlo'ay Azhi Community School",
        "district": "Baca/Dlo'ay Azhi Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590008700024",
    },
    {
        "school": "Pinon Community School",
        "district": "Pinon Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590008800015",
    },
    {
        "school": "Rocky Ridge Boarding School",
        "district": "Rocky Ridge Boarding School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590008900185",
    },
    {
        "school": "Miccosukee Indian School",
        "district": "Miccosukee Indian School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590009000053",
    },
    {
        "school": "St. Francis Indian School",
        "district": "St. Francis Indian School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590009100134",
    },
    {
        "school": "Ahfachkee Day School",
        "district": "Ahfachkee Day School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590009200041",
    },
    {
        "school": "Mescalero Apache School",
        "district": "Mescalero Apache School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590009300156",
    },
    {
        "school": "Aneth Community School",
        "district": "Aneth Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590009400139",
    },
    {
        "school": "Circle of Nations",
        "district": "Circle of Nations",
        "level": "Middle",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590009500083",
    },
    {
        "school": "Theodore Jamerson Elementary",
        "district": "Theodore Jamerson Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590009600165",
    },
    {
        "school": "Shoshone-Bannock School District No 512",
        "district": "Shoshone-Bannock School District No 512",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590009700128",
    },
    {
        "school": "Crystal Boarding School",
        "district": "Crystal Boarding School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590009800062",
    },
    {
        "school": "Dennehotso Boarding School",
        "district": "Dennehotso Boarding School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590009900176",
    },
    {
        "school": "Tucker Elementary School",
        "district": "Tucker Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590010000057",
    },
    {
        "school": "Cherokee Central High School",
        "district": "Cherokee Central High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590010100045",
    },
    {
        "school": "Black Mesa Community School",
        "district": "Black Mesa Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590010200008",
    },
    {
        "school": "Kickapoo Nation School",
        "district": "Kickapoo Nation School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590010300102",
    },
    {
        "school": "Lac Courte Oreilles Ojibwa School",
        "district": "Lac Courte Oreilles Ojibwa School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590010400087",
    },
    {
        "school": "Sherman Indian High School",
        "district": "Sherman Indian High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590010500138",
    },
    {
        "school": "Turtle Mountain Elementary School",
        "district": "Turtle Mountain Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590010600170",
    },
    {
        "school": "Pierre Indian Learning Center",
        "district": "Pierre Indian Learning Center",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590010700005",
    },
    {
        "school": "Pine Hill Schools",
        "district": "Pine Hill Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590010800157",
    },
    {
        "school": "Kin Dah Lichi'i Olta",
        "district": "Kin Dah Lichi'i Olta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590010900067",
    },
    {
        "school": "Leupp School Inc.",
        "district": "Leupp School Inc.",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590011000181",
    },
    {
        "school": "Conehatta Elementary School",
        "district": "Conehatta Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590011100050",
    },
    {
        "school": "Lukachukai Community School",
        "district": "Lukachukai Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590011200012",
    },
    {
        "school": "Crazy Horse School",
        "district": "Crazy Horse School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590011300114",
    },
    {
        "school": "Oneida Nation School",
        "district": "Oneida Nation School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590011400090",
    },
    {
        "school": "Lummi High School",
        "district": "Lummi High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590011500123",
    },
    {
        "school": "Navajo Preparatory School",
        "district": "Navajo Preparatory School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590011600144",
    },
    {
        "school": "White Shield School",
        "district": "White Shield School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590011700174",
    },
    {
        "school": "Crow Creek Sioux Tribal Elem School",
        "district": "Crow Creek Sioux Tribal Elem School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590011800018",
    },
    {
        "school": "Wingate High School",
        "district": "Wingate High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590011900040",
    },
    {
        "school": "Salt River Elementary School",
        "district": "Salt River Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590012000112",
    },
    {
        "school": "First Mesa Elementary School",
        "district": "First Mesa Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590012100078",
    },
    {
        "school": "Rock Point Community School",
        "district": "Rock Point Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590012200016",
    },
    {
        "school": "Pearl River Elementary School",
        "district": "Pearl River Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590012300054",
    },
    {
        "school": "Porcupine Day School",
        "district": "Porcupine Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590012400118",
    },
    {
        "school": "Lake Valley Navajo School",
        "district": "Lake Valley Navajo School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590012500031",
    },
    {
        "school": "Northwest High School",
        "district": "Northwest High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590012600148",
    },
    {
        "school": "Quileute Tribal School",
        "district": "Quileute Tribal School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590012700127",
    },
    {
        "school": "Shonto Preparatory School",
        "district": "Shonto Preparatory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590012800186",
    },
    {
        "school": "Tiospa Zina Tribal School",
        "district": "Tiospa Zina Tribal School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590012900022",
    },
    {
        "school": "Santa Fe Indian School",
        "district": "Santa Fe Indian School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590013000096",
    },
    {
        "school": "Hotevilla Bacavi Community School",
        "district": "Hotevilla Bacavi Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590013100075",
    },
    {
        "school": "Theodore Roosevelt School",
        "district": "Theodore Roosevelt School",
        "level": "Middle",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590013200060",
    },
    {
        "school": "Greyhills Academy High School",
        "district": "Greyhills Academy High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590013300178",
    },
    {
        "school": "Rock Creek Grant School",
        "district": "Rock Creek Grant School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590013400162",
    },
    {
        "school": "Fond du Lac Ojibwe School",
        "district": "Fond du Lac Ojibwe School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590013500085",
    },
    {
        "school": "Pueblo Pintado Community School",
        "district": "Pueblo Pintado Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590013600035",
    },
    {
        "school": "Beatrice Rafferty School",
        "district": "Beatrice Rafferty School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590013700042",
    },
    {
        "school": "Bread Springs Day School",
        "district": "Bread Springs Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590013800025",
    },
    {
        "school": "Dilcon Community School",
        "district": "Dilcon Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590013900063",
    },
    {
        "school": "Jemez Day School",
        "district": "Jemez Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590014000153",
    },
    {
        "school": "St. Stephens Indian School",
        "district": "St. Stephens Indian School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590014100003",
    },
    {
        "school": "Blackwater Community School",
        "district": "Blackwater Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590014200109",
    },
    {
        "school": "Takini School",
        "district": "Takini School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590014300006",
    },
    {
        "school": "Menominee Tribal School",
        "district": "Menominee Tribal School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590014400088",
    },
    {
        "school": "Dishchii'bikoh Community School",
        "district": "Dishchii'bikoh Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590014500058",
    },
    {
        "school": "Chitimacha Tribal School",
        "district": "Chitimacha Tribal School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590014600046",
    },
    {
        "school": "Atsa Biyaazh Community School",
        "district": "Atsa Biyaazh Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590014700140",
    },
    {
        "school": "Many Farms Community School",
        "district": "Many Farms Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590014800009",
    },
    {
        "school": "Dunseith Day School",
        "district": "Dunseith Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590014900166",
    },
    {
        "school": "Tohaali' Community School",
        "district": "Tohaali' Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590015000151",
    },
    {
        "school": "San Felipe Pueblo Elementary School",
        "district": "San Felipe Pueblo Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590015100158",
    },
    {
        "school": "Pine Springs Day School",
        "district": "Pine Springs Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590015200068",
    },
    {
        "school": "Duckwater Shoshone Elementary School",
        "district": "Duckwater Shoshone Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590015300135",
    },
    {
        "school": "Enemy Swim Day School",
        "district": "Enemy Swim Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590015400020",
    },
    {
        "school": "Borrego Pass",
        "district": "Borrego Pass",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590015500027",
    },
    {
        "school": "San Simon School",
        "district": "San Simon School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590015600105",
    },
    {
        "school": "Nenahnezad Community School",
        "district": "Nenahnezad Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590015700145",
    },
    {
        "school": "Turtle Mountain High School",
        "district": "Turtle Mountain High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590015800171",
    },
    {
        "school": "Little Singer Community School",
        "district": "Little Singer Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590015900182",
    },
    {
        "school": "Indian Island School",
        "district": "Indian Island School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590016000051",
    },
    {
        "school": "Many Farms High School",
        "district": "Many Farms High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590016100013",
    },
    {
        "school": "Ohkay Owingeh Community School",
        "district": "Ohkay Owingeh Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590016200093",
    },
    {
        "school": "Riverside Indian School",
        "district": "Riverside Indian School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590016300103",
    },
    {
        "school": "Chemawa Indian School",
        "district": "Chemawa Indian School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590016400120",
    },
    {
        "school": "Havasupai Elementary School",
        "district": "Havasupai Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590016500072",
    },
    {
        "school": "Bug-O-Nay-Ge-Shig",
        "district": "Bug-O-Nay-Ge-Shig",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590016600081",
    },
    {
        "school": "Mariano Lake Community School",
        "district": "Mariano Lake Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590016700032",
    },
    {
        "school": "T'iis Nazbas Community School",
        "district": "T'iis Nazbas Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590016800150",
    },
    {
        "school": "Tohono O`odham High School",
        "district": "Tohono O`odham High School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590016900108",
    },
    {
        "school": "Tonalea Day School",
        "district": "Tonalea Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590017000187",
    },
    {
        "school": "Rough Rock Community School",
        "district": "Rough Rock Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590017100017",
    },
    {
        "school": "Red Water Elementary School",
        "district": "Red Water Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590017200055",
    },
    {
        "school": "Little Wound School",
        "district": "Little Wound School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590017300115",
    },
    {
        "school": "Taos Day School",
        "district": "Taos Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590017400097",
    },
    {
        "school": "Keams Canyon Elementary School",
        "district": "Keams Canyon Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590017500076",
    },
    {
        "school": "Lummi Elementary School",
        "district": "Lummi Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590017600124",
    },
    {
        "school": "T'iis Ts'ozi Bi'Olta'",
        "district": "T'iis Ts'ozi Bi'Olta'",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590017700036",
    },
    {
        "school": "Two Eagle River School",
        "district": "Two Eagle River School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590017800129",
    },
    {
        "school": "Chi Chil'tah Comm School",
        "district": "Chi Chil'tah Comm School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590017900026",
    },
    {
        "school": "Kaibeto Boarding School",
        "district": "Kaibeto Boarding School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590018000179",
    },
    {
        "school": "Sitting Bull School",
        "district": "Sitting Bull School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590018100161",
    },
    {
        "school": "Greasewood Springs Community School Inc",
        "district": "Greasewood Springs Community School Inc",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590018200064",
    },
    {
        "school": "Wounded Knee District School",
        "district": "Wounded Knee District School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590018300119",
    },
    {
        "school": "Laguna Elementary School",
        "district": "Laguna Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590018400154",
    },
    {
        "school": "Wa He Lut Indian School",
        "district": "Wa He Lut Indian School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590018500131",
    },
    {
        "school": "Casa Blanca Community School",
        "district": "Casa Blanca Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590018600110",
    },
    {
        "school": "Hannahville Indian School",
        "district": "Hannahville Indian School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590018700086",
    },
    {
        "school": "Beclabito Day School",
        "district": "Beclabito Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590018800142",
    },
    {
        "school": "Mandaree Day School",
        "district": "Mandaree Day School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590018900167",
    },
    {
        "school": "Tiospaye Topa School",
        "district": "Tiospaye Topa School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590019000007",
    },
    {
        "school": "To'hajiilee Day School",
        "district": "To'hajiilee Day School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590019100037",
    },
    {
        "school": "Gila Crossing Community School",
        "district": "Gila Crossing Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590019200111",
    },
    {
        "school": "Seba Dalkai Boarding School",
        "district": "Seba Dalkai Boarding School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590019300069",
    },
    {
        "school": "Bogue Chitto Elementary School",
        "district": "Bogue Chitto Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590019400043",
    },
    {
        "school": "Sky City Community School",
        "district": "Sky City Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590019500159",
    },
    {
        "school": "Meskwaki Settlement School",
        "district": "Meskwaki Settlement School",
        "level": "Other",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590019600091",
    },
    {
        "school": "Noli School",
        "district": "Noli School",
        "level": "High",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590019700136",
    },
    {
        "school": "George Washington High",
        "district": "Ogden City District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490072001265",
    },
    {
        "school": "Bonneville School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001266",
    },
    {
        "school": "Horace Mann School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001269",
    },
    {
        "school": "Ogden High",
        "district": "Ogden City District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001271",
    },
    {
        "school": "Odyssey School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001273",
    },
    {
        "school": "Thomas O. Smith School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001274",
    },
    {
        "school": "Wasatch School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001276",
    },
    {
        "school": "Hillcrest School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001282",
    },
    {
        "school": "James Madison School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001287",
    },
    {
        "school": "Mount Ogden Junior High",
        "district": "Ogden City District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001288",
    },
    {
        "school": "Polk School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001291",
    },
    {
        "school": "Highland Junior High",
        "district": "Ogden City District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001294",
    },
    {
        "school": "Mound Fort Junior High",
        "district": "Ogden City District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001295",
    },
    {
        "school": "Lincoln School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001297",
    },
    {
        "school": "Marbury Middle School",
        "district": "Autauga County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10024002159",
    },
    {
        "school": "Greensboro Middle School",
        "district": "Hale County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10171002156",
    },
    {
        "school": "Greensboro Elementary School",
        "district": "Hale County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10171002158",
    },
    {
        "school": "Greensboro High School",
        "district": "Hale County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10171002162",
    },
    {
        "school": "Hackleburg Elementary School",
        "district": "Marion County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10231002160",
    },
    {
        "school": "Fred and Sara Machetanz Elementary School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000741",
    },
    {
        "school": "Watershed Charter School",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000742",
    },
    {
        "school": "Salt River Accelerated Learning Academy",
        "district": "Salt River Pima-Maricopa  Community Schools (4320)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40004703031",
    },
    {
        "school": "Youth Works Charter High School",
        "district": "Tucson Youth Development/ACE Charter High School (4422)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40007903035",
    },
    {
        "school": "Edkey Inc. - Precision Learning Center",
        "district": "Edkey Inc. - Sequoia Choice Schools (4329)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40015703046",
    },
    {
        "school": "Cambridge Academy East",
        "district": "Cambridge Academy  East  Inc (78888)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40018202964",
    },
    {
        "school": "Harvest Preparatory Academy San Luis AZ",
        "district": "Harvest Power Community Development Group Inc. (79501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40028202993",
    },
    {
        "school": "E-Institute at Grovers",
        "district": "E-Institute Charter Schools Inc. (79059)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40031103001",
    },
    {
        "school": "Cobre Valley Central Programs",
        "district": "Cobre Valley Institute of Technology District (79391)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40031602979",
    },
    {
        "school": "Future Investment Middle School",
        "district": "Griffin Foundation Inc. The (79500)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40034303003",
    },
    {
        "school": "CAVIAT - Page Central Campus",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034703040",
    },
    {
        "school": "CAVIT - Poston Butte High School",
        "district": "Central Arizona Valley Institute of Technology (79385)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034803019",
    },
    {
        "school": "CAVIT - Vista Grande",
        "district": "Central Arizona Valley Institute of Technology (79385)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034803025",
    },
    {
        "school": "Intelli-School Glendale",
        "district": "PAS Charter Inc. dba Intelli-School (79953)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40036402985",
    },
    {
        "school": "Mohave Accelerated Elementary School East",
        "district": "Mohave Accelerated Elementary School Inc. (85516)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40041302986",
    },
    {
        "school": "West-MEC - Shadow Ridge High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503061",
    },
    {
        "school": "Heritage Elementary - Williams",
        "district": "Heritage Elementary School (81076)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40064902846",
    },
    {
        "school": "Arizona Conservatory for Arts and Academics Middle School",
        "district": "Edkey Inc. - Arizona Conservatory for Arts and Ac (79981)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40065303004",
    },
    {
        "school": "Pima County JTED Annex",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075202977",
    },
    {
        "school": "Pima County JTED NW Campus",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203042",
    },
    {
        "school": "Pima County JTED Cosmetology",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203054",
    },
    {
        "school": "Freedom Academy North",
        "district": "Freedom Academy Inc. (89506)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40075503029",
    },
    {
        "school": "ASU Preparatory Academy- Phoenix Elementary",
        "district": "ASU Preparatory Academy (89949)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40076403051",
    },
    {
        "school": "MIJTED - Chino Valley High School",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077202973",
    },
    {
        "school": "MIJTED - Ashfork High School",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077202974",
    },
    {
        "school": "MIJTED - Bagdad High School",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077202992",
    },
    {
        "school": "MIJTED - Bradshaw Mountain High School",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077203006",
    },
    {
        "school": "MIJTED - Seligman High School",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077203010",
    },
    {
        "school": "MIJTED - Mayer High School",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077203013",
    },
    {
        "school": "MIJTED - Prescott High School",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077203015",
    },
    {
        "school": "MIJTED - Yavapai College CTEC",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077203033",
    },
    {
        "school": "Kaizen Education Foundation dba Vista Grove Preparatory Acad",
        "district": "Kaizen Education Foundation dba Vista Grove Prepar (90330)",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40078702898",
    },
    {
        "school": "ASU Preparatory Academy - South Phoenix Intermediate",
        "district": "ASU Preparatory Academy (90273)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40078802999",
    },
    {
        "school": "Liberty Arts Academy",
        "district": "Kaizen Education Foundation dba Liberty Arts Acade (90334)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40078902931",
    },
    {
        "school": "Vector Prep and Arts Academy",
        "district": "Vector School District Inc. (90317)",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40079202970",
    },
    {
        "school": "Sun Valley Academy",
        "district": "Morrison Education Group Inc. (90192)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079302984",
    },
    {
        "school": "WAVE - Kingman High School",
        "district": "Western Arizona Vocational District #50 (90123)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40079402980",
    },
    {
        "school": "WAVE - Parker High School",
        "district": "Western Arizona Vocational District #50 (90123)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40079403030",
    },
    {
        "school": "WAVE - Lake Havasu High School",
        "district": "Western Arizona Vocational District #50 (90123)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40079403037",
    },
    {
        "school": "WAVE - Mohave High School",
        "district": "Western Arizona Vocational District #50 (90123)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40079403045",
    },
    {
        "school": "WAVE - River Valley High School",
        "district": "Western Arizona Vocational District #50 (90123)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40079403055",
    },
    {
        "school": "Learning Foundation and Performing Arts Alta Mesa",
        "district": "CAFA Inc. dba Learning Foundation and Performing  (90328)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079602645",
    },
    {
        "school": "Academy Del Sol",
        "district": "Academy Del Sol Inc. (90199)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079702994",
    },
    {
        "school": "Pioneer Preparatory - A Challenge Foundation",
        "district": "Pioneer Preparatory School (90140)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079803021",
    },
    {
        "school": "Kaizen Education Foundation dba Gilbert Arts Academy",
        "district": "Kaizen Education Foundation dba Gilbert Arts Acade (90333)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079902943",
    },
    {
        "school": "Skyline D5",
        "district": "Skyline Gila River Schools LLC (90329)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40080102941",
    },
    {
        "school": "Imagine Avondale Middle",
        "district": "Imagine Avondale Middle Inc. (90162)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40080202962",
    },
    {
        "school": "Learning Foundation and Performing Arts Gilbert",
        "district": "CAFA Inc. dba Learning Foundation and Performing  (90327)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40080302667",
    },
    {
        "school": "Adams Traditional Academy",
        "district": "Choice Academies Inc. (90138)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40080503050",
    },
    {
        "school": "Sonoran Science Academy - Davis Monthan",
        "district": "Daisy Education Corporation dba. Sonoran Science A (90284)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40080702976",
    },
    {
        "school": "Imagine Superstition Middle",
        "district": "Imagine Superstition Middle Inc. (90160)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40081003026",
    },
    {
        "school": "Envision High School",
        "district": "CPLC Community Schools dba Hiaki High School (90331)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40081402554",
    },
    {
        "school": "Paulden Community School",
        "district": "Research Based Education Corporation (90275)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40081503023",
    },
    {
        "school": "EdOptions Preparatory Academy",
        "district": "Educational Options Foundation (90201)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40081602998",
    },
    {
        "school": "Inca Elementary School",
        "district": "Buckeye Elementary District (4269)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40138003052",
    },
    {
        "school": "Arizona College Prep Oakland Campus",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187002995",
    },
    {
        "school": "Shadow Ridge High School",
        "district": "Dysart Unified District (4243)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269002971",
    },
    {
        "school": "Sinagua Middle School",
        "district": "Flagstaff Unified District (4192)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286002961",
    },
    {
        "school": "Poston Butte High School",
        "district": "Florence Unified School District (4437)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292002972",
    },
    {
        "school": "Summit School",
        "district": "Florence Unified School District (4437)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40292002987",
    },
    {
        "school": "Campo Verde High School",
        "district": "Gilbert Unified District (4239)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340002965",
    },
    {
        "school": "Centennial Elementary School",
        "district": "Higley Unified School District (4248)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378003007",
    },
    {
        "school": "L. Thomas Heck Middle School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438003036",
    },
    {
        "school": "Mayer Junior High School",
        "district": "Mayer Unified School District (4473)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40482002997",
    },
    {
        "school": "Franklin Junior High School",
        "district": "Mesa Unified District (4235)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497003005",
    },
    {
        "school": "The Academy At Mingus",
        "district": "Mingus Union High School District (4488)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40507003009",
    },
    {
        "school": "Pendergast Private Alternative School",
        "district": "Pendergast Elementary District (4283)",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40621002968",
    },
    {
        "school": "Lake Pleasant Elementary",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625002990",
    },
    {
        "school": "Santa Cruz Center for Success",
        "district": "Santa Cruz Valley Union High School District (4454)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40753002966",
    },
    {
        "school": "West Point High School",
        "district": "Tolleson Union High School District (4288)",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40852002975",
    },
    {
        "school": "Rincon Vista Middle School",
        "district": "Vail Unified District (4413)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885002991",
    },
    {
        "school": "EVIT - Campo Verde High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973102969",
    },
    {
        "school": "EVIT - Combs High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973103017",
    },
    {
        "school": "OAK GROVE ELEMENTARY SCHOOL",
        "district": "PARAGOULD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001701497",
    },
    {
        "school": "TRUMANN INTERMEDIATE SCHOOL7-8",
        "district": "TRUMANN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004701506",
    },
    {
        "school": "DEQUEEN JUNIOR HIGH SCHOOL",
        "district": "DEQUEEN SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004901503",
    },
    {
        "school": "ARKANSAS ARTS ACADEMY HIGH SCHOOL",
        "district": "BENTON COUNTY SCHOOL OF ARTS",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50005501508",
    },
    {
        "school": "KIPP DELTA ELEMENTARY LITERACY ACADEMY",
        "district": "KIPP DELTA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006201513",
    },
    {
        "school": "JACKSONVILLE LIGHTHOUSE ELEMENTARY",
        "district": "JACKSONVILLE LIGHTHOUSE CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040201504",
    },
    {
        "school": "LITTLE ROCK PREP ACADEMY",
        "district": "LITTLE ROCK PREPARATORY ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040301500",
    },
    {
        "school": "BEEBE EARLY CHILDHOOD",
        "district": "BEEBE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50288001498",
    },
    {
        "school": "PEA RIDGE PRIMARY SCHOOL",
        "district": "PEA RIDGE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50303001505",
    },
    {
        "school": "CROSS COUNTY ELEMENTARY TECH ACADEMY",
        "district": "CROSS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50774001509",
    },
    {
        "school": "NETTLETON STEAM SCHOOL",
        "district": "NETTLETON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51044001514",
    },
    {
        "school": "Sunset Ranch Elementary",
        "district": "Rocklin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001312558",
    },
    {
        "school": "Bridges Community Based School North County Consortium",
        "district": "Windsor Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60003412585",
    },
    {
        "school": "Natomas Pacific Pathways Prep Middle",
        "district": "Natomas Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003612523",
    },
    {
        "school": "Hamilton Elementary",
        "district": "Hamilton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133902076",
    },
    {
        "school": "Hamilton High",
        "district": "Hamilton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133902078",
    },
    {
        "school": "Hamilton Community Day",
        "district": "Hamilton Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60133908481",
    },
    {
        "school": "Ella Barkley High",
        "district": "Hamilton Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60133910219",
    },
    {
        "school": "Ponderosa Elementary",
        "district": "Anaheim Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261012518",
    },
    {
        "school": "West Sonoma County Consortium School",
        "district": "West Sonoma County Union High",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60267012473",
    },
    {
        "school": "Redwood Shores Elementary",
        "district": "Belmont-Redwood Shores Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60453012574",
    },
    {
        "school": "Horace Mann",
        "district": "Burbank Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60645012591",
    },
    {
        "school": "BSD Preschool",
        "district": "Burlingame Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60648012580",
    },
    {
        "school": "Alma Preschool",
        "district": "Castro Valley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780012607",
    },
    {
        "school": "Caswell State Preschool",
        "district": "Ceres Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813012599",
    },
    {
        "school": "Cal Aero Preserve Academy",
        "district": "Chino Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60846012552",
    },
    {
        "school": "Coachella Valley USD Special Ed PreK",
        "district": "Coachella Valley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60907012593",
    },
    {
        "school": "Nueva Vista Language Academy",
        "district": "Delano Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089012512",
    },
    {
        "school": "Jurupa Hills High",
        "district": "Fontana Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392012517",
    },
    {
        "school": "Fowler Academy Independent Study",
        "district": "Fowler Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61425012543",
    },
    {
        "school": "Phoenix Secondary",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61455012434",
    },
    {
        "school": "Cloud Preschool",
        "district": "Glendale Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524012596",
    },
    {
        "school": "Gratton Charter",
        "district": "Gratton Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61581012452",
    },
    {
        "school": "Greenfield Community",
        "district": "Greenfield Union",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61605012448",
    },
    {
        "school": "Western Center Academy",
        "district": "Hemet Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692012464",
    },
    {
        "school": "Accelerated Achievement Academy",
        "district": "Hollister",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61734012565",
    },
    {
        "school": "Chinese Camp Elementary",
        "district": "Jamestown Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61869000831",
    },
    {
        "school": "Desert View Community Day",
        "district": "Keppel Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61944012500",
    },
    {
        "school": "Felicitas and Gonzalo Mendez High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012438",
    },
    {
        "school": "Ramon C. Cortines School of Visual and Performing Arts",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012439",
    },
    {
        "school": "Young Oak Kim Academy",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012440",
    },
    {
        "school": "Dorothy V. Johnson Community Day",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271012482",
    },
    {
        "school": "Sal Castro Middle",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012483",
    },
    {
        "school": "New Open World Academy K-12",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012493",
    },
    {
        "school": "Sun Valley High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012520",
    },
    {
        "school": "UCLA Community K-12",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012524",
    },
    {
        "school": "Daniel Pearl Journalism & Communications Magnet",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012525",
    },
    {
        "school": "Ambassador-Global Leadership",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012559",
    },
    {
        "school": "Ambassador School-Global Education",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012566",
    },
    {
        "school": "Pacheco High",
        "district": "Los Banos Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274012432",
    },
    {
        "school": "Martinez Early Intervention Preschool Program (MEIPP)",
        "district": "Martinez Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62403012601",
    },
    {
        "school": "Joseph A. Gregori High",
        "district": "Modesto City High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62515012556",
    },
    {
        "school": "Stevenson Elementary",
        "district": "Mountain View Whisman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628012540",
    },
    {
        "school": "American Canyon High",
        "district": "Napa Valley Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664012535",
    },
    {
        "school": "Gateway to College at Laney College",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62805012506",
    },
    {
        "school": "Home and Hospital Program",
        "district": "Oakland Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805012610",
    },
    {
        "school": "Young Adult Program",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62805012611",
    },
    {
        "school": "Virtual Pre",
        "district": "Palm Springs Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955012602",
    },
    {
        "school": "Nancy R. Kordyak Elementary",
        "district": "Rialto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237012561",
    },
    {
        "school": "Rincon Valley Partnership",
        "district": "Rincon Valley Union Elementary",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63264012471",
    },
    {
        "school": "Independence Charter",
        "district": "Salida Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63390012472",
    },
    {
        "school": "iHigh Virtual Academy",
        "district": "San Diego Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63432012534",
    },
    {
        "school": "Chinese Immersion School at DeAvila",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441012487",
    },
    {
        "school": "S.F. International High",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63441012494",
    },
    {
        "school": "Academy (The)- SF @McAteer",
        "district": "San Francisco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63441012526",
    },
    {
        "school": "Tule Elk Park Children Center",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441012583",
    },
    {
        "school": "Megan Cope Elementary",
        "district": "San Jacinto Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444012563",
    },
    {
        "school": "San Pasqual Vocational Academy",
        "district": "San Pasqual Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63507012475",
    },
    {
        "school": "Stockton High",
        "district": "Stockton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801012443",
    },
    {
        "school": "Stockton Early College Academy",
        "district": "Stockton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801012446",
    },
    {
        "school": "Orchard Hills",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015012571",
    },
    {
        "school": "Visalia Technical Early College",
        "district": "Visalia Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116012503",
    },
    {
        "school": "Evergreen Elementary",
        "district": "Washington Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64158012499",
    },
    {
        "school": "Evergreen Middle",
        "district": "Washington Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64158012545",
    },
    {
        "school": "Ada Clegg Elementary",
        "district": "Westminster",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215012492",
    },
    {
        "school": "John F. Land",
        "district": "Westminster",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64215012589",
    },
    {
        "school": "Mt. McKinley",
        "district": "Contra Costa County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100512486",
    },
    {
        "school": "Fresno COE District-Wide Preschool",
        "district": "Fresno County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69100712597",
    },
    {
        "school": "Monarch",
        "district": "San Diego County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103012496",
    },
    {
        "school": "Davila Day",
        "district": "San Diego County Office of Education",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69103012550",
    },
    {
        "school": "TCA COLLEGE PATHWAYS",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006447",
    },
    {
        "school": "KUNSMILLER CREATIVE ARTS ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006442",
    },
    {
        "school": "DENVER JUSTICE HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006443",
    },
    {
        "school": "STRIVE PREP - WESTWOOD",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006444",
    },
    {
        "school": "MATHEMATICS AND SCIENCE LEADERSHIP ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006445",
    },
    {
        "school": "KIPP DENVER COLLEGIATE HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006448",
    },
    {
        "school": "Rocky Mountain Prep: Berkeley",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006449",
    },
    {
        "school": "Wintonbury Early Childhood Magnet School",
        "district": "BLOOMFIELD SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90033001565",
    },
    {
        "school": "Bulkeley High School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001572",
    },
    {
        "school": "Mauro-Sheridan Magnet School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001564",
    },
    {
        "school": "Dual Language & Arts Magnet Middle School",
        "district": "LEARN",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90345001556",
    },
    {
        "school": "Mispillion Elementary",
        "district": "Milford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100108000344",
    },
    {
        "school": "Milford Central Academy",
        "district": "Milford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100108000345",
    },
    {
        "school": "Friendship PCS - Technology Preparatory MS",
        "district": "Friendship PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800422",
    },
    {
        "school": "Washington Latin PCS - Upper School",
        "district": "Washington Latin PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110001900423",
    },
    {
        "school": "KIPP DC - Promise Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100419",
    },
    {
        "school": "KIPP DC - College Preparatory Academy PCS",
        "district": "KIPP DC PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100421",
    },
    {
        "school": "KIPP DC - Discover Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100427",
    },
    {
        "school": "National Collegiate Preparatory PCHS",
        "district": "National Collegiate Preparatory PCHS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110007900424",
    },
    {
        "school": "ALACHUA VIRTUAL INSTRUCTION PROGRAM",
        "district": "ALACHUA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003007696",
    },
    {
        "school": "BAKER VIRTUAL INSTRUCTION PROGRAM",
        "district": "BAKER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120006007718",
    },
    {
        "school": "ROSENWALD HIGH SCHOOL",
        "district": "BAY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120009007763",
    },
    {
        "school": "BAY VIRTUAL INSTRUCTION PROGRAM",
        "district": "BAY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009007771",
    },
    {
        "school": "BRADFORD VIRTUAL INSTRUCTION PROGRAM",
        "district": "BRADFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120012007697",
    },
    {
        "school": "HERON HEIGHTS ELEMENTARY SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007654",
    },
    {
        "school": "BROWARD VIRTUAL INSTRUCTION PROGRAM",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007755",
    },
    {
        "school": "POMPANO YOUTH TREATMENT CENTER",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018007767",
    },
    {
        "school": "BEN GAMLA CHARTER SCHOOL SOUTH BROWARD",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007770",
    },
    {
        "school": "CALHOUN VIRTUAL INSTRUCTION PROGRAM",
        "district": "CALHOUN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120021007757",
    },
    {
        "school": "FLORIDA SOUTHWESTERN COLLEGIATE HIGH SCHOOL",
        "district": "CHARLOTTE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024007659",
    },
    {
        "school": "CHARLOTTE VIRTUAL INSTRUCTION PROGRAM",
        "district": "CHARLOTTE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024007716",
    },
    {
        "school": "CITRUS VIRTUAL INSTRUCTION PROGRAM",
        "district": "CITRUS",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120027007745",
    },
    {
        "school": "CLAY VIRTUAL INSTRUCTION PROGRAM",
        "district": "CLAY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030007670",
    },
    {
        "school": "COLLIER VIRTUAL INSTRUCTION PROGRAM",
        "district": "COLLIER",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033007759",
    },
    {
        "school": "COLUMBIA VIRTUAL INSTRUCTION PROGRAM",
        "district": "COLUMBIA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036007700",
    },
    {
        "school": "ISAAC: INTEGRATED SCIENCE AND ASIAN CULTURE ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007748",
    },
    {
        "school": "DESOTO VIRTUAL INSTRUCTION PROGRAM",
        "district": "DESOTO",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120042007702",
    },
    {
        "school": "DIXIE VIRTUAL INSTRUCTION PROGRAM",
        "district": "DIXIE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120045007674",
    },
    {
        "school": "GLOBAL OUTREACH CHARTER ACADEMY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007658",
    },
    {
        "school": "DUVAL VIRTUAL INSTRUCTION PROGRAM",
        "district": "DUVAL",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007693",
    },
    {
        "school": "ESCAMBIA VIRTUAL ACADEMY FRANCHISE",
        "district": "ESCAMBIA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051007672",
    },
    {
        "school": "FLAGLER VIRTUAL INSTRUCTION PROGRAM",
        "district": "FLAGLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054007682",
    },
    {
        "school": "IFLAGLER-VIRTUAL FRANCHISE",
        "district": "FLAGLER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054007761",
    },
    {
        "school": "GADSDEN VIRTUAL INSTRUCTION PROGRAM",
        "district": "GADSDEN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060007756",
    },
    {
        "school": "GILCHRIST VIRTUAL INSTRUCTION PROGRAM",
        "district": "GILCHRIST",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120063007742",
    },
    {
        "school": "GLADES VIRTUAL INSTRUCTION PROGRAM",
        "district": "GLADES",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120066007719",
    },
    {
        "school": "HAMILTON VIRTUAL INSTRUCTION PROGRAM",
        "district": "HAMILTON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120072007749",
    },
    {
        "school": "HARDEE VIRTUAL INSTRUCTION PROGRAM",
        "district": "HARDEE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120075007656",
    },
    {
        "school": "HENDRY VIRTUAL INSTRUCTION PROGRAM (FLORIDA ONLINE)",
        "district": "HENDRY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078007725",
    },
    {
        "school": "HERNANDO VIRTUAL INSTRUCTION PROGRAM",
        "district": "HERNANDO",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081007710",
    },
    {
        "school": "HIGHLANDS VIRTUAL FRANCHISE",
        "district": "HIGHLANDS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084007753",
    },
    {
        "school": "PATRICIA SULLIVAN METROPOLITAN MINISTRIES PARTNERSHIP SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007676",
    },
    {
        "school": "HOLMES VIRTUAL-VENDOR INSTRUCTION PROGRAM",
        "district": "HOLMES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120090007694",
    },
    {
        "school": "INDIAN RIVER VIRTUAL INSTRUCTION PROGRAM",
        "district": "INDIAN RIVER",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093007737",
    },
    {
        "school": "JACKSON VIRTUAL INSTRUCTION PROGRAM",
        "district": "JACKSON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096007662",
    },
    {
        "school": "LAFAYETTE VIRTUAL INSTRUCTION PROGRAM",
        "district": "LAFAYETTE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120102007711",
    },
    {
        "school": "SORRENTO ELEMENTARY",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105007655",
    },
    {
        "school": "LAKE VIRTUAL INSTRUCTION PROGRAM",
        "district": "LAKE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105007681",
    },
    {
        "school": "LAKE MINNEOLA HIGH SCHOOL",
        "district": "LAKE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105007689",
    },
    {
        "school": "LEE VIRTUAL INSTRUCTION PROGRAM",
        "district": "LEE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007705",
    },
    {
        "school": "OAK CREEK CHARTER SCHOOL OF BONITA SPRINGS",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007768",
    },
    {
        "school": "LEON COUNTY VIRTUAL INSTRUCTION PROGRAM",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111007657",
    },
    {
        "school": "LIBERTY VIRTUAL INSTRUCTION PROGRAM",
        "district": "LIBERTY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120117007739",
    },
    {
        "school": "MADISON VIRTUAL INSTRUCTION PROGRAM",
        "district": "MADISON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120120007754",
    },
    {
        "school": "MANATEE VIRTUAL INSTRUCTION PROGRAM",
        "district": "MANATEE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123007747",
    },
    {
        "school": "SIGSBEE CHARTER SCHOOL",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132007698",
    },
    {
        "school": "MONROE VIRTUAL INSTRUCTION PROGRAM",
        "district": "MONROE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132007723",
    },
    {
        "school": "NASSAU VIRTUAL INSTRUCTION PROGRAM",
        "district": "NASSAU",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135007668",
    },
    {
        "school": "NASSAU VIRTUAL FRANCHISE",
        "district": "NASSAU",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135007722",
    },
    {
        "school": "SOUTHSIDE PRIMARY SCHOOL",
        "district": "OKALOOSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138007669",
    },
    {
        "school": "OKALOOSA VIRTUAL INSTRUCTION PROGRAM",
        "district": "OKALOOSA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138007675",
    },
    {
        "school": "OKEECHOBEE INTENSIVE HALFWAY HOUSE",
        "district": "OKEECHOBEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120141007704",
    },
    {
        "school": "OCVS VIRTUAL INSTRUCTION PROGRAM",
        "district": "ORANGE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007712",
    },
    {
        "school": "ACCELERATION EAST",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144007736",
    },
    {
        "school": "SUNRIDGE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007743",
    },
    {
        "school": "MAIN STREET HIGH SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120147007764",
    },
    {
        "school": "THE LEARNING ACADEMY AT THE ELS CENTER OF EXCELLENCE",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150007666",
    },
    {
        "school": "HOPE-CENTENNIAL ELEMENTARY SCHOOL",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150007679",
    },
    {
        "school": "PASCO ESCHOOL-VIRTUAL FRANCHISE",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007660",
    },
    {
        "school": "PASCO VIRTUAL INSTRUCTION PROGRAM",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007680",
    },
    {
        "school": "FIVAY HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007713",
    },
    {
        "school": "ODESSA ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153007744",
    },
    {
        "school": "POLK VIRTUAL INSTRUCTION PROGRAM",
        "district": "POLK",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159007686",
    },
    {
        "school": "LAKELAND MONTESSORI MIDDLE SCHOOL",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159007728",
    },
    {
        "school": "PUTNAM VIRTUAL INSTRUCTION PROGRAM",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162007708",
    },
    {
        "school": "SANTA ROSA VIRTUAL FRANCHISE",
        "district": "SANTA ROSA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165007684",
    },
    {
        "school": "SANTA ROSA ONLINE VIRTUAL INSTRUCTION PROGRAM",
        "district": "SANTA ROSA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165007727",
    },
    {
        "school": "CAPSTONE ACADEMY MILTON CHARTER SCHOOL",
        "district": "SANTA ROSA",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120165007740",
    },
    {
        "school": "SARASOTA VIRTUAL INSTRUCTION PROGRAM",
        "district": "SARASOTA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168007714",
    },
    {
        "school": "IMAGINE SCHOOL AT PALMER RANCH",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168007717",
    },
    {
        "school": "ATWATER ELEMENTARY",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168007758",
    },
    {
        "school": "SEMINOLE VIRTUAL INSTRUCTION PROGRAM (SVIP)",
        "district": "SEMINOLE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171007695",
    },
    {
        "school": "SEMINOLE COUNTY VIRTUAL FRANCHISE (SCVS)",
        "district": "SEMINOLE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171007703",
    },
    {
        "school": "JOURNEYS ACADEMY",
        "district": "SEMINOLE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120171007721",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL OF ST. LUCIE",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177007685",
    },
    {
        "school": "ST. LUCIE VIRTUAL INSTRUCTION PROGRAM",
        "district": "ST. LUCIE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177007766",
    },
    {
        "school": "SUMTER COUNTY VIRTUAL INSTRUCTION PROGRAM",
        "district": "SUMTER",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120180007769",
    },
    {
        "school": "SUWANNEE VIRTUAL INSTRUCTION PROGRAM",
        "district": "SUWANNEE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120183007751",
    },
    {
        "school": "UNION COUNTY VIRTUAL INSTRUCTION PROGRAM",
        "district": "UNION",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120189007677",
    },
    {
        "school": "WAKULLA COUNTY VIRTUAL INSTRUCTION PROGRAM",
        "district": "WAKULLA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195007715",
    },
    {
        "school": "WALTON INITIATIVE FOR SUCCESS IN EDUCATION (WISE)",
        "district": "WALTON",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120198007690",
    },
    {
        "school": "WALTON VIRTUAL SCHOOL FULL TIME",
        "district": "WALTON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198007730",
    },
    {
        "school": "WALTON VIRTUAL FRANCHISE",
        "district": "WALTON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198007734",
    },
    {
        "school": "WASHINGTON VIRTUAL INSTRUCTION PROGRAM",
        "district": "WASHINGTON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201007667",
    },
    {
        "school": "Kipp Strive Academy",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003823",
    },
    {
        "school": "Springdale Park Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003841",
    },
    {
        "school": "Atkinson Elementary School",
        "district": "Brantley County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130048003907",
    },
    {
        "school": "Jackson Elementary School",
        "district": "Butts County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130069003846",
    },
    {
        "school": "KidsPeace",
        "district": "Carroll County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084003483",
    },
    {
        "school": "The School of Liberal Studies at Savannah High",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102003941",
    },
    {
        "school": "Mill Creek Middle School",
        "district": "Cherokee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111003909",
    },
    {
        "school": "Judia Jackson Harris Elementary",
        "district": "Clarke County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130117003905",
    },
    {
        "school": "Charles R. Drew High School",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123003855",
    },
    {
        "school": "Elite Scholars Academy School",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123003896",
    },
    {
        "school": "Grovetown High School",
        "district": "Columbia County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141003903",
    },
    {
        "school": "Cook High School",
        "district": "Cook County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130147003900",
    },
    {
        "school": "Brooks Elementary",
        "district": "Coweta County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130150003881",
    },
    {
        "school": "Morris Innovative High School",
        "district": "Dalton Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130162003836",
    },
    {
        "school": "Margaret Harris Comprehensive School",
        "district": "DeKalb County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003868",
    },
    {
        "school": "DeKalb School of the Arts",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003884",
    },
    {
        "school": "Dunwoody Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003914",
    },
    {
        "school": "Arabia Mountain High School - Academy of Engineering- Medic",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003915",
    },
    {
        "school": "Elizabeth Andrews High School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003921",
    },
    {
        "school": "DeKalb Academy of Technology and the Environment Charter Sc",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174003955",
    },
    {
        "school": "Mason Creek Middle School",
        "district": "Douglas County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186003890",
    },
    {
        "school": "Mason Creek Elementary School",
        "district": "Douglas County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186003911",
    },
    {
        "school": "West Laurens High School",
        "district": "Laurens County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130189003887",
    },
    {
        "school": "Haw Creek Elementary",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003825",
    },
    {
        "school": "George W. Whitlow Elementary",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003853",
    },
    {
        "school": "Lakeside Middle School",
        "district": "Forsyth County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003858",
    },
    {
        "school": "Brookwood Elementary",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003923",
    },
    {
        "school": "Lambert High School",
        "district": "Forsyth County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222003954",
    },
    {
        "school": "Ison Springs Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003842",
    },
    {
        "school": "Birmingham Falls Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003874",
    },
    {
        "school": "Langston Hughes High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003913",
    },
    {
        "school": "Johns Creek High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003935",
    },
    {
        "school": "Cliftondale Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003940",
    },
    {
        "school": "Gainesville Middle School",
        "district": "Gainesville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130231003897",
    },
    {
        "school": "Sonoraville Elementary",
        "district": "Gordon County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130243003877",
    },
    {
        "school": "Rehoboth Road Middle School",
        "district": "Griffin-Spalding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130252003951",
    },
    {
        "school": "Starling Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003835",
    },
    {
        "school": "Archer High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003838",
    },
    {
        "school": "Bay Creek Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003870",
    },
    {
        "school": "Woodward Mill Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003893",
    },
    {
        "school": "Twin Rivers Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003912",
    },
    {
        "school": "Mountain View High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003916",
    },
    {
        "school": "Couch Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003917",
    },
    {
        "school": "White Oak Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003943",
    },
    {
        "school": "North Gwinnett Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003945",
    },
    {
        "school": "Creekside School",
        "district": "Harris County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130270003958",
    },
    {
        "school": "Rocky Creek Elementary",
        "district": "Henry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003824",
    },
    {
        "school": "Locust Grove High",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003928",
    },
    {
        "school": "Locust Grove Middle",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003937",
    },
    {
        "school": "Hampton Middle School",
        "district": "Henry County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282003952",
    },
    {
        "school": "Lanier County Elementary School",
        "district": "Lanier County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130324003829",
    },
    {
        "school": "Pine Grove Middle School",
        "district": "Lowndes County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130339003904",
    },
    {
        "school": "Mitchell County Elementary School",
        "district": "Mitchell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130369003832",
    },
    {
        "school": "Katherine B. Sutton Elementary School",
        "district": "Monroe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130372003839",
    },
    {
        "school": "North Murray High School",
        "district": "Murray County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130384003849",
    },
    {
        "school": "Clements Middle School",
        "district": "Newton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393003869",
    },
    {
        "school": "Live Oak Elementary",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393003876",
    },
    {
        "school": "Newton County Theme School at Ficquett",
        "district": "Newton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393003920",
    },
    {
        "school": "Liberty Middle School",
        "district": "Newton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130393003927",
    },
    {
        "school": "High Shoals Elementary School",
        "district": "Oconee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130396003854",
    },
    {
        "school": "Carl Scoggins Sr. Middle school",
        "district": "Paulding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402003822",
    },
    {
        "school": "Hal Hutchens Elementary",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402003827",
    },
    {
        "school": "Sara M. Ragsdale Elementary",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402003864",
    },
    {
        "school": "Van Wert Elementary School",
        "district": "Polk County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130420003939",
    },
    {
        "school": "Putnam County Elementary School",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130426003867",
    },
    {
        "school": "Putnam County Middle School",
        "district": "Putnam County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130426003878",
    },
    {
        "school": "Putnam County High School",
        "district": "Putnam County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130426003882",
    },
    {
        "school": "Putnam County Primary School",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130426003919",
    },
    {
        "school": "Quitman County High School",
        "district": "Quitman County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130429003850",
    },
    {
        "school": "W.S. Hornsby Middle School",
        "district": "Richmond County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438003924",
    },
    {
        "school": "Pine Hill Middle School",
        "district": "Richmond County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438003947",
    },
    {
        "school": "Walnut Grove High School",
        "district": "Walton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130539003901",
    },
    {
        "school": "Cedar Ridge Elementary",
        "district": "Whitfield County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570003844",
    },
    {
        "school": "Washington-Wilkes Comprehensive High School",
        "district": "Wilkes County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130576003852",
    },
    {
        "school": "Washington-Wilkes Middle School",
        "district": "Wilkes County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130576003942",
    },
    {
        "school": "Ewa Makai Middle School",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000296",
    },
    {
        "school": "IDAHO SCIENCE AND TECHNOLOGY CHARTER SCHOOL",
        "district": "IDAHO SCIENCE AND TECHNOLOGY CHARTER SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160014500996",
    },
    {
        "school": "IDAHO CONNECTS ONLINE SCHOOL",
        "district": "IDAHO VIRTUAL EDUCATION PARTNERS INC.",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160014800993",
    },
    {
        "school": "KOOTENAI BRIDGE ACADEMY",
        "district": "THE KOOTENAI BRIDGE ACADEMY INC.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160014900992",
    },
    {
        "school": "PALOUSE PRAIRIE CHARTER SCHOOL",
        "district": "PALOUSE PRAIRIE EDUCATIONAL ORGANIZATION INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160015100994",
    },
    {
        "school": "COSSA ACADEMY",
        "district": "CANYON-OWYHEE SCHOOL SERVICE AGENCY (COSSA)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160015200304",
    },
    {
        "school": "EAST JUNIOR HIGH SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036001002",
    },
    {
        "school": "HIDDEN SPRINGS ELEMENTARY SCHOOL",
        "district": "BOISE INDEPENDENT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160036001004",
    },
    {
        "school": "BONNEVILLE ONLINE ELEMENTARY",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093000999",
    },
    {
        "school": "FILER INTERMEDIATE SCHOOL",
        "district": "FILER DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160105001006",
    },
    {
        "school": "SOUTH FORK ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160157001001",
    },
    {
        "school": "RENAISSANCE HIGH SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210001000",
    },
    {
        "school": "CANYON RIDGE HIGH SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324000998",
    },
    {
        "school": "Chana Educ Center/Rock River",
        "district": "Ogle Co Education Cooperative",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170008106042",
    },
    {
        "school": "RAES Night School",
        "district": "Henderson/Knox/Mercer/Warren ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019206069",
    },
    {
        "school": "Lincoln School TAOEP",
        "district": "Will ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170021306059",
    },
    {
        "school": "Transition",
        "district": "Southwest Cook Coop Spec Ed",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170139206038",
    },
    {
        "school": "Mercer County High School",
        "district": "Mercer County School District 404",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170139500018",
    },
    {
        "school": "Apollo Elem School",
        "district": "Mercer County School District 404",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170139500019",
    },
    {
        "school": "New Boston Elem School",
        "district": "Mercer County School District 404",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170139504196",
    },
    {
        "school": "Mercer County Jr High School",
        "district": "Mercer County School District 404",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170139506040",
    },
    {
        "school": "Mercer County Intermediate School",
        "district": "Mercer County School District 404",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170139506060",
    },
    {
        "school": "Paris Cooperative High School",
        "district": "Paris Cooperative High School",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170139706061",
    },
    {
        "school": "Central Primary Sch",
        "district": "Central SD 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170915006096",
    },
    {
        "school": "Air Force Acad High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006055",
    },
    {
        "school": "Chicago HS for the Arts",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006058",
    },
    {
        "school": "Prieto Math-Science Elem Sch",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006067",
    },
    {
        "school": "Alcott Humanities High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006072",
    },
    {
        "school": "Chicago Technology Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006076",
    },
    {
        "school": "Skinner North Elem Sch",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006081",
    },
    {
        "school": "Westinghouse High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006083",
    },
    {
        "school": "EPIC Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006088",
    },
    {
        "school": "Hernandez Middle School",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006091",
    },
    {
        "school": "Williams Medical Prep High Sch",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006092",
    },
    {
        "school": "Ogden Int High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006093",
    },
    {
        "school": "South Shore Fine Arts Elem Sch",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006099",
    },
    {
        "school": "Hope Inst Lrning Acad Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006102",
    },
    {
        "school": "Fabyan Elementary School",
        "district": "Geneva CUSD 304",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171638006050",
    },
    {
        "school": "Grayslake Early Childhood",
        "district": "Grayslake CCSD 46",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171752006056",
    },
    {
        "school": "Lake Bluff Elem Sch",
        "district": "Lake Bluff ESD 65",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172172006073",
    },
    {
        "school": "Peoria Cty Jvnl Det Ctr 9-12",
        "district": "Limestone CHSD 310",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172295006049",
    },
    {
        "school": "Lincoln Way West",
        "district": "Lincoln Way CHSD 210",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172307006062",
    },
    {
        "school": "Jones Elementary School",
        "district": "Minooka CCSD 201",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172631006048",
    },
    {
        "school": "Peoria Cty Jvnl Det Ctr 6-8",
        "district": "Norwood ESD 63",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172904006082",
    },
    {
        "school": "Amelia V Carriel Jr High",
        "district": "O Fallon CCSD 90",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172976006079",
    },
    {
        "school": "Hunt Club Elem",
        "district": "CUSD 308",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027006054",
    },
    {
        "school": "Paris Cooperative High School 95",
        "district": "Paris-Union SD 95",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173075006066",
    },
    {
        "school": "Paris Cooperative High School 4",
        "district": "Paris CUSD 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173078006100",
    },
    {
        "school": "Willowbrook Middle School",
        "district": "Prairie Hill CCSD 133",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173255006063",
    },
    {
        "school": "Putnam Co Primary Sch",
        "district": "Putnam County CUSD 535",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173296006047",
    },
    {
        "school": "Galapagos Rockford Charter Sch",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451006044",
    },
    {
        "school": "Legacy Acad of Excellence Charter",
        "district": "Rockford SD 205",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451006077",
    },
    {
        "school": "Harry E Fry School",
        "district": "Burbank SD 111",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173681006065",
    },
    {
        "school": "North Grove Elementary School",
        "district": "Sycamore CUSD 427",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173846006074",
    },
    {
        "school": "Fischer Middle School",
        "district": "Indian Prairie CUSD 204",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169006041",
    },
    {
        "school": "Metea Valley High School",
        "district": "Indian Prairie CUSD 204",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174169006090",
    },
    {
        "school": "Nathaniel Hawthorne EC School",
        "district": "Wheeling CCSD 21",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174221006098",
    },
    {
        "school": "Autumn Creek Elem Sch",
        "district": "Yorkville CUSD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174396006052",
    },
    {
        "school": "Dept of Correction Adult Schools",
        "district": "Indiana Department of Correction",
        "level": "High",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180000602453",
    },
    {
        "school": "The Bloomington Project School",
        "district": "The Bloomington Project School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180008302446",
    },
    {
        "school": "Avon Middle School North",
        "district": "Avon Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027002450",
    },
    {
        "school": "Bailly Middle School",
        "district": "Gary Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180387002460",
    },
    {
        "school": "East Washington Academy",
        "district": "Muncie Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180732002451",
    },
    {
        "school": "Eel River Elementary School",
        "district": "Northwest Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180825002457",
    },
    {
        "school": "Starr Elementary School",
        "district": "Richmond Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180951002455",
    },
    {
        "school": "Riverside Intermediate School",
        "district": "Hamilton Southeastern Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065002452",
    },
    {
        "school": "Castle South Middle School",
        "district": "Warrick County School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239002454",
    },
    {
        "school": "Monon Trail Elementary School",
        "district": "Westfield-Washington Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181308002449",
    },
    {
        "school": "Prairie Point",
        "district": "College Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190786002110",
    },
    {
        "school": "Prairie Creek",
        "district": "College Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190786002113",
    },
    {
        "school": "McKee Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897002108",
    },
    {
        "school": "Louisa-Muscatine Jr High",
        "district": "Louisa-Muscatine Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191782002106",
    },
    {
        "school": "Storm Lake Elementary",
        "district": "Storm Lake Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192739002107",
    },
    {
        "school": "United North",
        "district": "United Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192856002105",
    },
    {
        "school": "West Liberty Elementary School",
        "district": "West Liberty Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193099002109",
    },
    {
        "school": "Republic County Jr./Sr. High School",
        "district": "Republic County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200003001958",
    },
    {
        "school": "Doniphan West Elementary School",
        "district": "Doniphan West Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200034801963",
    },
    {
        "school": "Farley Elementary",
        "district": "Auburn Washburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200320001935",
    },
    {
        "school": "Prairie Creek Elementary",
        "district": "Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200336001940",
    },
    {
        "school": "Caney Valley Charter Academy",
        "district": "Caney Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200441001961",
    },
    {
        "school": "Jackson Heights High School and Middle School",
        "district": "North Jackson",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200483001936",
    },
    {
        "school": "Jackson Heights Elementary School",
        "district": "North Jackson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200483001955",
    },
    {
        "school": "Atchison County Community JR/SR High",
        "district": "Atchison Co Comm Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200570001957",
    },
    {
        "school": "Atchison County Community Elementary School",
        "district": "Atchison Co Comm Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200570001962",
    },
    {
        "school": "Galesburg Middle School",
        "district": "Erie-Galesburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200600001932",
    },
    {
        "school": "Erie Elementary",
        "district": "Erie-Galesburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200600001946",
    },
    {
        "school": "Eudora Elementary School",
        "district": "Eudora",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200609001964",
    },
    {
        "school": "Hill City Junior-Senior High",
        "district": "Graham County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200726001954",
    },
    {
        "school": "Hugoton Learning Academy",
        "district": "Hugoton Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200756001965",
    },
    {
        "school": "Kinsley Jr/Sr High School",
        "district": "Kinsley-Offerle",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200810001944",
    },
    {
        "school": "South Barber Pre-K-6",
        "district": "South Barber",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200813001933",
    },
    {
        "school": "South Barber 7-12",
        "district": "South Barber",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200813001966",
    },
    {
        "school": "Wichita County Junior-Senior High School",
        "district": "Leoti",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200861001952",
    },
    {
        "school": "Maize South High School",
        "district": "Maize",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200914001956",
    },
    {
        "school": "Medicine Lodge Jr/Sr High School",
        "district": "Barber County North",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200945001931",
    },
    {
        "school": "Forest View Elem",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001929",
    },
    {
        "school": "Piper West Elementary School",
        "district": "Piper-Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201068001937",
    },
    {
        "school": "Flinthills High School",
        "district": "Flinthills",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201122001930",
    },
    {
        "school": "Flinthills Middle School",
        "district": "Flinthills",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201122001951",
    },
    {
        "school": "North Fairview",
        "district": "Seaman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201149001942",
    },
    {
        "school": "Logan Elementary",
        "district": "Seaman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201149001953",
    },
    {
        "school": "Timber Creek Elementary School",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001934",
    },
    {
        "school": "Muhlenberg County High School",
        "district": "Muhlenberg County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210008102258",
    },
    {
        "school": "Longbranch Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051002245",
    },
    {
        "school": "Boone County Alternative Center",
        "district": "Boone County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210051002266",
    },
    {
        "school": "Opportunity Middle College",
        "district": "Fayette County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210186002242",
    },
    {
        "school": "Wellington Elementary",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002247",
    },
    {
        "school": "Fayette County Learning Center",
        "district": "Fayette County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210186002251",
    },
    {
        "school": "Fayette Pre-School",
        "district": "Fayette County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002263",
    },
    {
        "school": "Green County Primary School",
        "district": "Green County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210234002244",
    },
    {
        "school": "Green County Intermediate School",
        "district": "Green County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210234002257",
    },
    {
        "school": "Spectrum Care Academy",
        "district": "Hardin County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210249002248",
    },
    {
        "school": "Lincoln Trail Behavioral Health Systems",
        "district": "Hardin County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210249002249",
    },
    {
        "school": "Crossroads Treatment Center",
        "district": "Hardin County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210249002269",
    },
    {
        "school": "Home/Hospital",
        "district": "Jefferson County",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299002262",
    },
    {
        "school": "Nelson County Early Learning Center",
        "district": "Nelson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210441002261",
    },
    {
        "school": "Millard School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480002240",
    },
    {
        "school": "Northpoint Academy",
        "district": "Pike County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210480002256",
    },
    {
        "school": "Martha Layne Collins High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532002253",
    },
    {
        "school": "Otter Creek Academy",
        "district": "Wayne County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210579002250",
    },
    {
        "school": "Williamstown Head Start Preschool",
        "district": "Williamstown Independent",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210594002260",
    },
    {
        "school": "Lakeside Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009002262",
    },
    {
        "school": "Spanish Lake Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009002269",
    },
    {
        "school": "Central Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009002279",
    },
    {
        "school": "D'Arbonne Woods Charter School",
        "district": "D'Arbonne Woods Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220014602282",
    },
    {
        "school": "Madison Preparatory Academy",
        "district": "Community School for Apprenticeship Learning Inc.",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220014802267",
    },
    {
        "school": "DeQuincy Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033002292",
    },
    {
        "school": "Woodlawn Elementary",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002265",
    },
    {
        "school": "Caneview Elementary School",
        "district": "Iberia Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220072002260",
    },
    {
        "school": "Ray St. Pierre Academy for Advanced Studies",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002268",
    },
    {
        "school": "Emily C. Watkins Elementary",
        "district": "St. John the Baptist Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220153002281",
    },
    {
        "school": "Raintree Elementary School",
        "district": "St. Mary Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220162002280",
    },
    {
        "school": "Lakeshore High School",
        "district": "St. Tammany Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165002255",
    },
    {
        "school": "Marigny Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165002256",
    },
    {
        "school": "Jewel M. Sumner Middle School",
        "district": "Tangipahoa Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168002274",
    },
    {
        "school": "Leblanc Elementary School",
        "district": "Vermilion Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180002273",
    },
    {
        "school": "Cony",
        "district": "Augusta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230264023118",
    },
    {
        "school": "Ridge View Community School",
        "district": "MSAD 46",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231453023115",
    },
    {
        "school": "Mildred L Day School",
        "district": "RSU 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477300008",
    },
    {
        "school": "Kennebunk Elementary School",
        "district": "RSU 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477300580",
    },
    {
        "school": "Kennebunk High School",
        "district": "RSU 21",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477300799",
    },
    {
        "school": "Middle School of the Kennebunks",
        "district": "RSU 21",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477300800",
    },
    {
        "school": "Kennebunkport Consolidated Sch",
        "district": "RSU 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477300801",
    },
    {
        "school": "Sea Road School",
        "district": "RSU 21",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477301054",
    },
    {
        "school": "Elm Street School-Mechanic Falls",
        "district": "RSU 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477500218",
    },
    {
        "school": "Minot Consolidated School",
        "district": "RSU 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477500228",
    },
    {
        "school": "Poland Community School",
        "district": "RSU 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477500265",
    },
    {
        "school": "Poland Regional H S",
        "district": "RSU 16",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477500436",
    },
    {
        "school": "Bruce M Whittier Middle School",
        "district": "RSU 16",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477500438",
    },
    {
        "school": "Dresden Elementary School",
        "district": "RSU 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477600131",
    },
    {
        "school": "Henry L Cottrell School",
        "district": "RSU 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477600230",
    },
    {
        "school": "Monmouth Academy",
        "district": "RSU 02",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477600231",
    },
    {
        "school": "Marcia Buker School",
        "district": "RSU 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477600296",
    },
    {
        "school": "Richmond High School",
        "district": "RSU 02",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477600298",
    },
    {
        "school": "Hall-Dale Elementary School",
        "district": "RSU 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477600352",
    },
    {
        "school": "Richmond Middle School",
        "district": "RSU 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477601008",
    },
    {
        "school": "Monmouth Middle School",
        "district": "RSU 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477601018",
    },
    {
        "school": "Ella P Burr School",
        "district": "RSU 67",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477700787",
    },
    {
        "school": "Mattanawcook Academy",
        "district": "RSU 67",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477700788",
    },
    {
        "school": "Mattanawcook Jr High School",
        "district": "RSU 67",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477700789",
    },
    {
        "school": "Asa C Adams School",
        "district": "RSU 26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477800251",
    },
    {
        "school": "Orono High School",
        "district": "RSU 26",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477800252",
    },
    {
        "school": "Orono Middle School",
        "district": "RSU 26",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477800297",
    },
    {
        "school": "China Middle School",
        "district": "RSU 18",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477900121",
    },
    {
        "school": "Messalonskee Middle School",
        "district": "RSU 18",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477900694",
    },
    {
        "school": "Belgrade Central School",
        "district": "RSU 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477900701",
    },
    {
        "school": "James H Bean School",
        "district": "RSU 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477900702",
    },
    {
        "school": "Williams Elementary School",
        "district": "RSU 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477900704",
    },
    {
        "school": "Messalonskee High School",
        "district": "RSU 18",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477900705",
    },
    {
        "school": "Ralph M Atwood Primary School",
        "district": "RSU 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477901023",
    },
    {
        "school": "China Primary School",
        "district": "RSU 18",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477901043",
    },
    {
        "school": "Chelsea Elementary School",
        "district": "RSU 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478000120",
    },
    {
        "school": "Palermo Consolidated School",
        "district": "RSU 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478000258",
    },
    {
        "school": "Somerville Elementary School",
        "district": "RSU 12",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478000571",
    },
    {
        "school": "Whitefield Elementary School",
        "district": "RSU 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478000625",
    },
    {
        "school": "Windsor Elementary School",
        "district": "RSU 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478000633",
    },
    {
        "school": "Viola Rand School",
        "district": "RSU 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478200082",
    },
    {
        "school": "Leonard Middle School",
        "district": "RSU 34",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478200246",
    },
    {
        "school": "Old Town High School",
        "district": "RSU 34",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478200248",
    },
    {
        "school": "Old Town Elementary School",
        "district": "RSU 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478200699",
    },
    {
        "school": "Alton Elementary School",
        "district": "RSU 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478201041",
    },
    {
        "school": "Libby-Tozier School",
        "district": "RSU 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478300205",
    },
    {
        "school": "Oak Hill High School",
        "district": "RSU 04",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478300207",
    },
    {
        "school": "Sabattus Primary School",
        "district": "RSU 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478300609",
    },
    {
        "school": "Jameson Elementary School",
        "district": "RSU 23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478400238",
    },
    {
        "school": "Loranger Memorial School",
        "district": "RSU 23",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478400240",
    },
    {
        "school": "Old Orchard Beach High School",
        "district": "RSU 23",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478400921",
    },
    {
        "school": "Nokomis Regional High School",
        "district": "RSU 19",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478500729",
    },
    {
        "school": "South School",
        "district": "RSU 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478700530",
    },
    {
        "school": "Cushing Community School",
        "district": "RSU 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478700707",
    },
    {
        "school": "Manchester Elementary School",
        "district": "RSU 38",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478800217",
    },
    {
        "school": "Maranacook Community High Sch",
        "district": "RSU 38",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478800234",
    },
    {
        "school": "Mt Vernon Elementary School",
        "district": "RSU 38",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478800235",
    },
    {
        "school": "Readfield Elementary School",
        "district": "RSU 38",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478800294",
    },
    {
        "school": "Maranacook Community Middle Sch",
        "district": "RSU 38",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478800540",
    },
    {
        "school": "Wayne Elementary School",
        "district": "RSU 38",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478800608",
    },
    {
        "school": "Durham Community School",
        "district": "RSU 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478900132",
    },
    {
        "school": "Freeport High School",
        "district": "RSU 05",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478900149",
    },
    {
        "school": "Morse Street School",
        "district": "RSU 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478900153",
    },
    {
        "school": "Pownal Elementary School",
        "district": "RSU 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478900683",
    },
    {
        "school": "Freeport Middle School",
        "district": "RSU 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478900979",
    },
    {
        "school": "Mast Landing School",
        "district": "RSU 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478901044",
    },
    {
        "school": "Sumner Memorial High School",
        "district": "RSU 24",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479000148",
    },
    {
        "school": "Cave Hill School",
        "district": "RSU 24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479000403",
    },
    {
        "school": "Mountain View School",
        "district": "RSU 24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479000566",
    },
    {
        "school": "Ella Lewis School",
        "district": "RSU 24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479000591",
    },
    {
        "school": "Peninsula School",
        "district": "RSU 24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479000640",
    },
    {
        "school": "Searsport Elementary",
        "district": "RSU 20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479100026",
    },
    {
        "school": "Searsport District High School",
        "district": "RSU 20",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479100768",
    },
    {
        "school": "Searsport District Middle School",
        "district": "RSU 20",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479100770",
    },
    {
        "school": "Jordan-Small Middle School",
        "district": "RSU 14",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479300292",
    },
    {
        "school": "Raymond Elementary School",
        "district": "RSU 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479300503",
    },
    {
        "school": "Windham Middle School",
        "district": "RSU 14",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479300629",
    },
    {
        "school": "Manchester School",
        "district": "RSU 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479300631",
    },
    {
        "school": "Windham High School",
        "district": "RSU 14",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479300632",
    },
    {
        "school": "Windham Primary School",
        "district": "RSU 14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479301034",
    },
    {
        "school": "Caribou RegionalTechnology Ctr",
        "district": "RSU 39",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231479400077",
    },
    {
        "school": "Rumford Elementary",
        "district": "RSU 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479500302",
    },
    {
        "school": "Mountain Valley High School",
        "district": "RSU 10",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479500303",
    },
    {
        "school": "Hartford-Sumner Elementary School",
        "district": "RSU 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479500470",
    },
    {
        "school": "Mountain Valley Middle School",
        "district": "RSU 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479500502",
    },
    {
        "school": "Meroby Elementary School",
        "district": "RSU 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479500823",
    },
    {
        "school": "Buckfield Jr-Sr High School",
        "district": "RSU 10",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479501053",
    },
    {
        "school": "Bucksport High School",
        "district": "RSU 25",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479600102",
    },
    {
        "school": "G Herbert Jewett School",
        "district": "RSU 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479600103",
    },
    {
        "school": "Bucksport Middle School",
        "district": "RSU 25",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479600685",
    },
    {
        "school": "Miles Lane School",
        "district": "RSU 25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479601027",
    },
    {
        "school": "The Seed School of Maryland",
        "district": "SEED School of Maryland",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240002701669",
    },
    {
        "school": "Monarch Academy",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001687",
    },
    {
        "school": "Elmer A. Henderson: A Johns Hopkins Partnership",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001670",
    },
    {
        "school": "Bluford Drew Jemison STEM Academy West",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001675",
    },
    {
        "school": "N.A.C.A. Freedom and Democracy Academy II",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001678",
    },
    {
        "school": "City Neighbors Hamilton",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001680",
    },
    {
        "school": "KIPP Harmony Academy",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001681",
    },
    {
        "school": "Baltimore Leadership School for Young Women",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001682",
    },
    {
        "school": "Manchester Valley High",
        "district": "Carroll County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240021001672",
    },
    {
        "school": "William B. Gibbs Jr. Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001673",
    },
    {
        "school": "Andrew Jackson Academy",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001683",
    },
    {
        "school": "Benjamin D. Foulois Academy",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001684",
    },
    {
        "school": "Accokeek Academy",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001686",
    },
    {
        "school": "Evergreen Elementary School",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001685",
    },
    {
        "school": "Barbara Ingram School for the Arts",
        "district": "Washingtion County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001674",
    },
    {
        "school": "Hampden Charter School of Science East",
        "district": "Hampden Charter School of Science East (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250052202680",
    },
    {
        "school": "Barnstable Intermediate School",
        "district": "Barnstable",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250231002678",
    },
    {
        "school": "West Villages Elementary School",
        "district": "Barnstable",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250231002679",
    },
    {
        "school": "King K-8",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002669",
    },
    {
        "school": "Mildred Avenue K-8",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002670",
    },
    {
        "school": "Lyon Upper 9-12",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002674",
    },
    {
        "school": "Higginson/Lewis K-8",
        "district": "Boston",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002677",
    },
    {
        "school": "Boston Teachers Union School",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002687",
    },
    {
        "school": "Edison K-8",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002689",
    },
    {
        "school": "Bournedale Elementary School",
        "district": "Bourne",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250282002664",
    },
    {
        "school": "Ashfield Middle School",
        "district": "Brockton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309002688",
    },
    {
        "school": "Joseph F. Plouffe Academy",
        "district": "Brockton",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309002691",
    },
    {
        "school": "Arthur M Longsjo Middle School",
        "district": "Fitchburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250489002672",
    },
    {
        "school": "Gateway Regional Middle School",
        "district": "Gateway",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250516002667",
    },
    {
        "school": "East Elementary School",
        "district": "Hingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250609002671",
    },
    {
        "school": "East Street Elementary School",
        "district": "Ludlow",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250705002663",
    },
    {
        "school": "Chapin Street Elementary School",
        "district": "Ludlow",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250705002665",
    },
    {
        "school": "High Rock School",
        "district": "Needham",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250837002690",
    },
    {
        "school": "Whaling City Junior/Senior High School",
        "district": "New Bedford",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843002681",
    },
    {
        "school": "Squannacook Early Childhood Center",
        "district": "North Middlesex",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250879002686",
    },
    {
        "school": "Northbridge Elementary",
        "district": "Northbridge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250894002682",
    },
    {
        "school": "Head Start",
        "district": "Worcester",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251323002684",
    },
    {
        "school": "Crestwood Accelerated Program",
        "district": "Crestwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001607978",
    },
    {
        "school": "Cesar Chavez Academy Intermediate",
        "district": "Cesar Chavez Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260013908078",
    },
    {
        "school": "Outlook Academy  Youth Home Campus",
        "district": "Outlook Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260027408003",
    },
    {
        "school": "American Montessori Academy Upper Elementary",
        "district": "American Montessori Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260031208089",
    },
    {
        "school": "WashingtonParks Academy",
        "district": "Washington-Parks Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095808086",
    },
    {
        "school": "Lansing Charter Academy",
        "district": "Lansing Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095908074",
    },
    {
        "school": "Center for Forensic Psychiatry",
        "district": "Michigan Department of Community Health",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260096007994",
    },
    {
        "school": "University Preparatory Art  Design MiddleHigh",
        "district": "University Prepararatory Art & Design",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260096108026",
    },
    {
        "school": "Achieve Charter Academy",
        "district": "Achieve Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260096307974",
    },
    {
        "school": "Four Corners Montessori Academy",
        "district": "Four Corners Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260096407979",
    },
    {
        "school": "Quest Charter Academy",
        "district": "Quest Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260096508062",
    },
    {
        "school": "Three Lakes Academy",
        "district": "Three Lakes Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260096607970",
    },
    {
        "school": "Michigan Mathematics and Science Academy Lorraine",
        "district": "Michigan Mathematics and Science Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260096708048",
    },
    {
        "school": "Virtual Learning Academyof St Clair County",
        "district": "Virtual Learning Academy of St. Clair County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260096808090",
    },
    {
        "school": "Addison Elementary School",
        "district": "Addison Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260192007996",
    },
    {
        "school": "Discovery Enrichment Center",
        "district": "Benton Harbor Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260483007874",
    },
    {
        "school": "Maltby Intermediate School",
        "district": "Brighton Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260687008044",
    },
    {
        "school": "Paris Ridge Elementary",
        "district": "Caledonia Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260762008102",
    },
    {
        "school": "Cedar View Elementary School",
        "district": "Cedar Springs Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260852007991",
    },
    {
        "school": "Beach Elementary School",
        "district": "Cedar Springs Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260852008092",
    },
    {
        "school": "Dearborn Magnet High School",
        "district": "Dearborn City School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261160008095",
    },
    {
        "school": "Center for Economicology",
        "district": "Grand Rapids Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644007875",
    },
    {
        "school": "Maplewood",
        "district": "Holland City School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261842007976",
    },
    {
        "school": "West",
        "district": "Holland City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261842008023",
    },
    {
        "school": "Jefferson",
        "district": "Holland City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261842008028",
    },
    {
        "school": "Holland Virtual Tech High School",
        "district": "Holland City School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261842008030",
    },
    {
        "school": "KND Elementary",
        "district": "Kaleva Norman Dickson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262001008070",
    },
    {
        "school": "Rolland Warner Campus 67",
        "district": "Lapeer Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262118008063",
    },
    {
        "school": "DiAnne M Pellerin Center",
        "district": "L'Anse Creuse Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262187008075",
    },
    {
        "school": "James C Harvey Education Center",
        "district": "Mason Public Schools (Ingham)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262307007988",
    },
    {
        "school": "Oakridge Fusion",
        "district": "Oakridge Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262622008077",
    },
    {
        "school": "Joseph G Steenland Elementary School",
        "district": "Roseville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263021008000",
    },
    {
        "school": "Joan C Sergent Instructional Resource Center",
        "district": "Utica Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263447007990",
    },
    {
        "school": "Monroe County Middle College",
        "district": "Monroe ISD",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268082008011",
    },
    {
        "school": "Early College Alliance",
        "district": "Washtenaw ISD",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268099008061",
    },
    {
        "school": "NECA INDEPENDENT STUDY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504381",
    },
    {
        "school": "TEA",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002604371",
    },
    {
        "school": "JOURNEYS ALTERNATIVE PROGRAM",
        "district": "MEEKER AND WRIGHT SPECIAL EDUCATION",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004504351",
    },
    {
        "school": "TRANSITION 2 SUCCESS",
        "district": "ZUMBRO EDUCATION DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270005404383",
    },
    {
        "school": "SWWC ELC - Pipestone",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270008604353",
    },
    {
        "school": "BBE LEARNING CENTER",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270008604361",
    },
    {
        "school": "WCA Middle School",
        "district": "WEST CENTRAL AREA",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270010404375",
    },
    {
        "school": "SOCRATES ONLINE",
        "district": "SOCRATES",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270023804367",
    },
    {
        "school": "Infinity: Minnesota Digital Academy",
        "district": "Infinity: Minnesota Digital Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270031204301",
    },
    {
        "school": "TRACY SECONDARY",
        "district": "TRACY AREA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270032604389",
    },
    {
        "school": "TRACY ELEMENTARY",
        "district": "TRACY AREA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270032604393",
    },
    {
        "school": "ORTONVILLE SECONDARY",
        "district": "ORTONVILLE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270032804386",
    },
    {
        "school": "KNOLL ELEMENTARY",
        "district": "ORTONVILLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270032804394",
    },
    {
        "school": "NOVA CLASSICAL ACADEMY UPPER SCHOOL",
        "district": "NOVA CLASSICAL ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270033704356",
    },
    {
        "school": "ST. CROIX PREPARATORY ACADEMY UPPER",
        "district": "ST. CROIX PREPARATORY ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036204360",
    },
    {
        "school": "OSHKI MANIDOO CENTER",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270444004315",
    },
    {
        "school": "INSIGHT SCHOOL OF MINNESOTA",
        "district": "BROOKLYN CENTER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270624004306",
    },
    {
        "school": "PROJECT SEARCH",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270810004359",
    },
    {
        "school": "STEPS TOWARD ADULT RESPONSIBILITY",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270819004380",
    },
    {
        "school": "LINCOLN EARLY CHILDHOOD ED. CENTER",
        "district": "DETROIT LAKES PUBLIC SCHOOL DIST.",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271023004362",
    },
    {
        "school": "DOVER-EYOTA MIDDLE SCHOOL",
        "district": "DOVER-EYOTA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271101004345",
    },
    {
        "school": "RIVERVIEW ELEMENTARY",
        "district": "FARMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271182004376",
    },
    {
        "school": "HERMANTOWN ALTERNATIVE LEARNING PRG",
        "district": "HERMANTOWN PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271392004370",
    },
    {
        "school": "TASSEL TRANSITION",
        "district": "EDEN PRAIRIE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271422004369",
    },
    {
        "school": "LINK12 LAKEVILLE",
        "district": "LAKEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271778004309",
    },
    {
        "school": "FUTURES PROGRAM",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271878004374",
    },
    {
        "school": "Rosa Parks Elementary",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878004388",
    },
    {
        "school": "PRIOR LAKE-SAVAGE AREA ALC",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273006004390",
    },
    {
        "school": "RICHFIELD COLLEGE EXPERIENCE PRG",
        "district": "RICHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273175004395",
    },
    {
        "school": "JACKSON ELEMENTARY",
        "district": "SHAKOPEE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273300004391",
    },
    {
        "school": "ST. JAMES EARLY CHILDHOOD",
        "district": "ST. JAMES PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273360004379",
    },
    {
        "school": "MELROSE",
        "district": "ST. LOUIS PARK PUBLIC SCHOOL DIST.",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273378004332",
    },
    {
        "school": "St. Michael-Albertville Middle West",
        "district": "ST. MICHAEL-ALBERTVILLE SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273379004346",
    },
    {
        "school": "RIVEREAST PROGRAM",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384004275",
    },
    {
        "school": "EARLY EDUCATION - BIRTH TO THREE",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384004382",
    },
    {
        "school": "ANNA WESTIN HOUSE",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384004398",
    },
    {
        "school": "BRANCH OUT TRANSITIONAL SERVICES",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274227004387",
    },
    {
        "school": "AWARE",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236004372",
    },
    {
        "school": "IMPRINTS PROGRAM",
        "district": "RIVER BEND EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279135304366",
    },
    {
        "school": "LEWISBURG MIDDLE",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001343",
    },
    {
        "school": "LAKE CORMORANT HIGH",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001357",
    },
    {
        "school": "CENTER HILL MIDDLE",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001358",
    },
    {
        "school": "T.L. WESTON MIDDLE SCHOOL",
        "district": "GREENVILLE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280162001361",
    },
    {
        "school": "TWENTY EIGHTH ST ELEM",
        "district": "GULFPORT SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280171001349",
    },
    {
        "school": "WEST HARRISON HIGH SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177001347",
    },
    {
        "school": "CROSSROADS ELEMENTARY SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177001351",
    },
    {
        "school": "WEST LAUDERDALE HIGH SCHOOL",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243001344",
    },
    {
        "school": "CLARKDALE HIGH SCHOOL",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243001348",
    },
    {
        "school": "CLARKDALE ELEMENTARY SCHOOL",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280243001362",
    },
    {
        "school": "LAUREL MIDDLE SCHOOL",
        "district": "LAUREL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280246001345",
    },
    {
        "school": "MANNSDALE ELEMENTARY",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001350",
    },
    {
        "school": "PEARL JUNIOR HIGH SCHOOL",
        "district": "PEARL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280352001354",
    },
    {
        "school": "CENTER FOR ALTERNATIVE EDUCATION",
        "district": "PEARL RIVER CO SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280354001359",
    },
    {
        "school": "PONTOTOC MIDDLE SCHOOL",
        "district": "PONTOTOC CITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280369001355",
    },
    {
        "school": "STONEBRIDGE ELEMENTARY",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001353",
    },
    {
        "school": "WESTERN MO CORRECTIONAL CENTER",
        "district": "DEPARTMENT OF CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290003003133",
    },
    {
        "school": "ST LOUIS LANG IMMERSION MARINE",
        "district": "ST. LOUIS LANG IMMERSION SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290058603124",
    },
    {
        "school": "NORTH SIDE COMMUNITY SCHOOL",
        "district": "NORTH SIDE COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290058903142",
    },
    {
        "school": "FRONTIER SCHOOL OF INNOVATION",
        "district": "FRONTIER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059003127",
    },
    {
        "school": "KIPP INSPIRE ACADEMY",
        "district": "KIPP ST LOUIS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059103122",
    },
    {
        "school": "CARROLLTON ELEMENTARY SCHOOL",
        "district": "CARROLLTON R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290738003129",
    },
    {
        "school": "ADAMS PRIMARY SCHOOL",
        "district": "CARROLLTON R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290738003131",
    },
    {
        "school": "CARTHAGE INTERMEDIATE CENTER",
        "district": "CARTHAGE R-IX",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290746003110",
    },
    {
        "school": "BLAIR OAKS MIDDLE SCHOOL",
        "district": "BLAIR OAKS R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290993003117",
    },
    {
        "school": "SOUTHWEST EARLY CHILDHOOD CTR",
        "district": "JEFFERSON CITY",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619003121",
    },
    {
        "school": "PIONEER TRAIL ELEMENTARY",
        "district": "JEFFERSON CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619003137",
    },
    {
        "school": "JEFFERSON HIGH SCHOOL",
        "district": "JEFFERSON CO. R-VII",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291623003144",
    },
    {
        "school": "SUNSET VALLEY ELEM.",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830003134",
    },
    {
        "school": "MILLER PARK CENTER",
        "district": "LEE'S SUMMIT R-VII",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291830003135",
    },
    {
        "school": "KELLYBROOK ELEM SCHOOL",
        "district": "LIBERTY 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854003113",
    },
    {
        "school": "LOGAN-ROGERSVILLE ELEMENTARY",
        "district": "LOGAN-ROGERSVILLE R-VIII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291917003128",
    },
    {
        "school": "MARIONVILLE MIDDLE",
        "district": "MARIONVILLE R-IX",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292031003139",
    },
    {
        "school": "MOUND CITY MIDDLE",
        "district": "MOUND CITY R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292148003112",
    },
    {
        "school": "EARLY LEARNING CENTER",
        "district": "Nixa Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292253003132",
    },
    {
        "school": "BELL PRAIRIE ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280003115",
    },
    {
        "school": "LITTLE BLUE ELEMENTARY",
        "district": "RAYTOWN C-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607003125",
    },
    {
        "school": "SMITH COTTON JUNIOR HIGH SCHL",
        "district": "SEDALIA 200",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292783003143",
    },
    {
        "school": "SOUTH SHELBY MIDDLE SCHOOL",
        "district": "SHELBY CO. R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292811003130",
    },
    {
        "school": "SOUTH CALLAWAY EARLY CHD PK-02",
        "district": "SOUTH CALLAWAY CO. R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292843003120",
    },
    {
        "school": "DAVID HARRISON ELEMENTARY",
        "district": "SPRINGFIELD R-XII",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292886003119",
    },
    {
        "school": "CUIVRE PARK ELEMENTARY",
        "district": "TROY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293045003136",
    },
    {
        "school": "WILLARD ORCHARD HILLS ELEM",
        "district": "WILLARD R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293201003116",
    },
    {
        "school": "WRIGHT CITY EAST ELEM",
        "district": "WRIGHT CITY R-II OF WARREN CO.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293231003138",
    },
    {
        "school": "Lone Peak High School",
        "district": "Big Sky School K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065401099",
    },
    {
        "school": "Browning Elementary",
        "district": "Browning Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300514001100",
    },
    {
        "school": "Fromberg School",
        "district": "Fromberg K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301165000316",
    },
    {
        "school": "Fromberg Middle School",
        "district": "Fromberg K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301165000938",
    },
    {
        "school": "LAKEVIEW JUNIOR HIGH SCHOOL",
        "district": "LAKEVIEW COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011202219",
    },
    {
        "school": "AURORA PRESCHOOL",
        "district": "AURORA PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310336002221",
    },
    {
        "school": "BELLEVUE ELEMENTARY SCHOOL",
        "district": "BELLEVUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310381002231",
    },
    {
        "school": "KOOSER ELEMENTARY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002214",
    },
    {
        "school": "SCHOO MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002215",
    },
    {
        "school": "INFANT TODDLER AT LINCOLN HIGH SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002222",
    },
    {
        "school": "INFANT TODDLER AT LINCOLN NORTHEAST HIGH SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002224",
    },
    {
        "school": "INFANT TODDLER AT LINCOLN NORTH STAR HIGH SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002225",
    },
    {
        "school": "INFANT TODDLER AT BRYAN COMMUNITY SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002226",
    },
    {
        "school": "SADDLEBROOK ELEMENTARY SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482002228",
    },
    {
        "school": "EARLY CHILDHOOD CENTER AT EDUCARE - INDIAN HILL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482002234",
    },
    {
        "school": "BELL ELEMENTARY",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527002232",
    },
    {
        "school": "SCHUYLER MIDDLE SCHOOL",
        "district": "SCHUYLER COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317645002216",
    },
    {
        "school": "NORTH WARD PREKINDERGARTEN",
        "district": "SCHUYLER COMMUNITY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317645002217",
    },
    {
        "school": "SCHUYLER HEADSTART",
        "district": "SCHUYLER COMMUNITY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317645002218",
    },
    {
        "school": "EARLY CHILDHOOD LEARNING CENTER",
        "district": "SCOTTSBLUFF PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317647002220",
    },
    {
        "school": "SIDNEY ALTERNATIVE PROGRAM",
        "district": "SIDNEY PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317671002229",
    },
    {
        "school": "Silver Sands Montessori",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100781",
    },
    {
        "school": "Elko Institute for Academic Achievement",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100784",
    },
    {
        "school": "Alpine Academy High School",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100800",
    },
    {
        "school": "Desert Rose High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000767",
    },
    {
        "school": "Mark L Fine Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000771",
    },
    {
        "school": "Helen J Stewart School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320006000774",
    },
    {
        "school": "Sunrise Mountain High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000777",
    },
    {
        "school": "Veterans Tribute Career Techincal Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000778",
    },
    {
        "school": "Southwest Career and Technical Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000780",
    },
    {
        "school": "Southern Desert Correctional Center",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000785",
    },
    {
        "school": "Henry & Evelyn Bozarth Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000786",
    },
    {
        "school": "High Desert State Prison",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000787",
    },
    {
        "school": "High Desert Correctional Center",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000790",
    },
    {
        "school": "Florence McClure Correctional Center",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000794",
    },
    {
        "school": "Clark Adult Program",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000795",
    },
    {
        "school": "Southeast Career Technical Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000796",
    },
    {
        "school": "Early Childhood Program",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320006000797",
    },
    {
        "school": "Charlotte & Jerry Keller Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000801",
    },
    {
        "school": "Douglas Alternative School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320009000764",
    },
    {
        "school": "Juvenile Detention",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320012000779",
    },
    {
        "school": "Leighton Hall (Dentention Center)",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320021000793",
    },
    {
        "school": "Eagle Ridge High School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320030000768",
    },
    {
        "school": "Mineral Alternative Education",
        "district": "MINERAL COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320033000763",
    },
    {
        "school": "Carson Adult Education Corrections",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320039000769",
    },
    {
        "school": "Carson Adult Education RG",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320039000792",
    },
    {
        "school": "Coal Canyon HS",
        "district": "PERSHING COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320042000762",
    },
    {
        "school": "Turning Point",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320048000766",
    },
    {
        "school": "Early Childhood",
        "district": "WHITE PINE COUNTY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320051000776",
    },
    {
        "school": "Mountain High School",
        "district": "WHITE PINE COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320051000802",
    },
    {
        "school": "Mountain Villa School",
        "district": "Allamuchy Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340072003066",
    },
    {
        "school": "Hoboken Dual Language Charter School",
        "district": "Hoboken Dual Language Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340073403037",
    },
    {
        "school": "Hatikvah International Academy Charter School",
        "district": "Hatikvah International Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340073503055",
    },
    {
        "school": "The Barack Obama Green Charter High School",
        "district": "The Barack Obama Green Charter High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340074003047",
    },
    {
        "school": "Academy for Urban Leadership Charter School",
        "district": "Academy for Urban Leadership Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340074103050",
    },
    {
        "school": "Thomas H. Dudley Family School",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340264003065",
    },
    {
        "school": "Admiral William F. Halsey Jr. Health & Public Safety Academy",
        "district": "Elizabeth Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459003039",
    },
    {
        "school": "Alexander Hamilton Preparatory Academy",
        "district": "Elizabeth Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459003043",
    },
    {
        "school": "Thomas A. Edison Career and Technical Academy",
        "district": "Elizabeth Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459003045",
    },
    {
        "school": "Thomas Jefferson Arts Academy",
        "district": "Elizabeth Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459003049",
    },
    {
        "school": "John E. Dwyer Technology Academy",
        "district": "Elizabeth Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459003071",
    },
    {
        "school": "Dr. John Grieco Elementary School",
        "district": "Englewood Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340474003063",
    },
    {
        "school": "Park Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134003061",
    },
    {
        "school": "Daniel F. Ryan Elementary School No. 19",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254003035",
    },
    {
        "school": "Plainfield Academy  For The Arts & Advanced Studies",
        "district": "Plainfield Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341314003041",
    },
    {
        "school": "Union City High School",
        "district": "Union City School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638003059",
    },
    {
        "school": "Union Hill Middle School",
        "district": "Union City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638003073",
    },
    {
        "school": "Jose Marti STEM Academy",
        "district": "Union City School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638003074",
    },
    {
        "school": "SPRINGER CORRECTIONAL FACILITY",
        "district": "NM CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001201046",
    },
    {
        "school": "NORTHEASTERN NM CORRECTIONAL FACILITY",
        "district": "NM CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001201049",
    },
    {
        "school": "TONY HILLERMAN MIDDLE SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001047",
    },
    {
        "school": "CORONADO ELEMENTARY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001054",
    },
    {
        "school": "SCHOOL OF DREAMS ACADEMY",
        "district": "SCHOOL OF DREAMS ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350011201051",
    },
    {
        "school": "ALMA D'ARTE CHARTER",
        "district": "ALMA D'ARTE CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350011600900",
    },
    {
        "school": "CESAR CHAVEZ COMMUNITY  SCHOOL",
        "district": "CESAR CHAVEZ COMMUNITY  SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350011700891",
    },
    {
        "school": "TAOS ACADEMY",
        "district": "TAOS ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350011801055",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL OF BUSINESS FOR YOUNG WOMEN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007705764",
    },
    {
        "school": "HIGH SCHOOL FOR LANGUAGE AND DIPLOMACY (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706105",
    },
    {
        "school": "MANHATTAN BUSINESS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706108",
    },
    {
        "school": "QUEST TO LEARN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706125",
    },
    {
        "school": "BUSINESS OF SPORTS SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007706126",
    },
    {
        "school": "SPRUCE STREET SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706130",
    },
    {
        "school": "BATTERY PARK CITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706158",
    },
    {
        "school": "YORKVILLE COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706166",
    },
    {
        "school": "EMMA LAZARUS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706169",
    },
    {
        "school": "SPECIAL MUSIC SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007806115",
    },
    {
        "school": "WEST PREP ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007806135",
    },
    {
        "school": "INNOVATION DIPLOMA PLUS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007806145",
    },
    {
        "school": "GLOBAL LEARNING COLLABORATIVE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007806146",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL FOR GREEN CAREERS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007806148",
    },
    {
        "school": "HIGH SCHOOL FOR EXCELLENCE AND INNOVATION",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008306099",
    },
    {
        "school": "INTERNATIONAL COMMUNITY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405873",
    },
    {
        "school": "SOUNDVIEW ACADEMY FOR CULTURE AND SCHOLARSHIP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506156",
    },
    {
        "school": "MOTT HALL COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506162",
    },
    {
        "school": "BRONX EARLY COLLEGE ACADEMY FOR TEACHING AND LEARNING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008605865",
    },
    {
        "school": "SCIENCE AND TECHNOLOGY ACADEMY:  A MOTT HALL SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606113",
    },
    {
        "school": "GRANT AVENUE ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606121",
    },
    {
        "school": "FAMILY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606132",
    },
    {
        "school": "SHERIDAN ACADEMY FOR YOUNG LEADERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606150",
    },
    {
        "school": "CRESTON ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008706141",
    },
    {
        "school": "ACAD-SCHOLARSHIP & ENTREPRENEURSHIP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008805810",
    },
    {
        "school": "CORNERSTONE ACADEMY FOR SOCIAL ACTION MIDDLE SCHOOL (CASA)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806107",
    },
    {
        "school": "PELHAM ACADEMY OF ACADEMICS AND COMMUNITY ENGAGEMENT",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806129",
    },
    {
        "school": "BAYCHESTER ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806144",
    },
    {
        "school": "EXPLORATIONS ACADEMY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009005792",
    },
    {
        "school": "URBAN SCHOLARS COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006133",
    },
    {
        "school": "CINEMA SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006160",
    },
    {
        "school": "BRONX CAREER AND COLLEGE PREPARATORY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006163",
    },
    {
        "school": "CITY POLYTECHNIC HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360009106164",
    },
    {
        "school": "SUNSET PARK HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009206111",
    },
    {
        "school": "RED HOOK NEIGHBORHOOD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009206143",
    },
    {
        "school": "BROOKLYN ACADEMY OF GLOBAL FINANCE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009406122",
    },
    {
        "school": "EAST BROOKLYN COMMUNITY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009606152",
    },
    {
        "school": "SCIENCE AND MEDICINE MIDDLE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009606155",
    },
    {
        "school": "STATEN ISLAND SCHOOL OF CIVIC LEADERSHIP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306149",
    },
    {
        "school": "EAST NEW YORK MIDDLE SCHOOL OF EXCELLENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006100",
    },
    {
        "school": "SCHOOL FOR CLASSICS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006118",
    },
    {
        "school": "EAST NEW YORK ELEMENTARY SCHOOL OF EXCELLENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006153",
    },
    {
        "school": "VILLAGE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306104",
    },
    {
        "school": "WATERSIDE CHILDREN'S STUDIO SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306106",
    },
    {
        "school": "WATERSIDE SCHOOL FOR LEADERSHIP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306127",
    },
    {
        "school": "ACADEMY OF TALENTED SCHOLARS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015106120",
    },
    {
        "school": "BROOKLYN SCHOOL OF INQUIRY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015106138",
    },
    {
        "school": "INTERNATIONAL HIGH SCHOOL AT LAFAYETTE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015205823",
    },
    {
        "school": "KINGSBOROUGH EARLY COLLEGE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #21",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015205926",
    },
    {
        "school": "BROWNSVILLE COLLEGIATE  CHARTER SCHOOL",
        "district": "BROWNSVILLE COLLEGIATE  CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360098406165",
    },
    {
        "school": "GIRLS PREPARATORY CHARTER SCHOOL OF THE BRONX",
        "district": "GIRLS PREPARATORY CHARTER SCHOOL OF THE BRONX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360098606161",
    },
    {
        "school": "GROWING UP GREEN CHARTER SCHOOL",
        "district": "GROWING UP GREEN CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360098706124",
    },
    {
        "school": "EVERGREEN CHARTER SCHOOL",
        "district": "EVERGREEN CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360098806137",
    },
    {
        "school": "BROOKLYN SCHOLARS CHARTER SCHOOL",
        "district": "BROOKLYN SCHOLARS CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360098906097",
    },
    {
        "school": "NEW ROOTS CHARTER SCHOOL",
        "district": "NEW ROOTS CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360099006102",
    },
    {
        "school": "BROOKLYN PROSPECT CHARTER SCHOOL-CSD 15",
        "district": "BROOKLYN PROSPECT CHARTER SCHOOL-CSD 15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360099106123",
    },
    {
        "school": "TRUE NORTH TROY PREPARATORY CHARTER SCHOOL",
        "district": "TRUE NORTH TROY PREPARATORY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360099206119",
    },
    {
        "school": "LEADERSHIP PREPARATORY OCEAN HILL CHARTER SCHOOL",
        "district": "LEADERSHIP PREPARATORY OCEAN HILL CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360099306157",
    },
    {
        "school": "EXPLORE EMPOWER CHARTER SCHOOL",
        "district": "EXPLORE EMPOWER CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360099406151",
    },
    {
        "school": "ICAHN CHARTER SCHOOL 4",
        "district": "ICAHN CHARTER SCHOOL 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360099506103",
    },
    {
        "school": "JOHN W LAVELLE PREPARATORY CHARTER SCHOOL",
        "district": "JOHN W LAVELLE PREPARATORY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360099606147",
    },
    {
        "school": "ACADEMY CHARTER SCHOOL",
        "district": "ACADEMY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360099706131",
    },
    {
        "school": "SUMMIT ACADEMY CHARTER SCHOOL",
        "district": "SUMMIT ACADEMY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360099806114",
    },
    {
        "school": "EXCELLENCE GIRLS CHARTER SCHOOL",
        "district": "EXCELLENCE GIRLS CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360100006112",
    },
    {
        "school": "ACADEMIC LEADERSHIP CHARTER SCHOOL",
        "district": "ACADEMIC LEADERSHIP CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360100106154",
    },
    {
        "school": "BROWNSVILLE ASCEND CHARTER SCHOOL",
        "district": "BROWNSVILLE ASCEND CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360100206167",
    },
    {
        "school": "HEBREW LANGUAGE ACADEMY CHARTER SCHOOL",
        "district": "HEBREW LANGUAGE ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360100306159",
    },
    {
        "school": "CONEY ISLAND PREPARATORY PUBLIC CHARTER SCHOOL",
        "district": "CONEY ISLAND PREPARATORY PUBLIC CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360100406101",
    },
    {
        "school": "EQUALITY CHARTER SCHOOL",
        "district": "EQUALITY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360100506110",
    },
    {
        "school": "PULASKI MIDDLE SCHOOL",
        "district": "PULASKI CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362388006170",
    },
    {
        "school": "DR WALTER COOPER ACADEMY",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475006109",
    },
    {
        "school": "CENTRAL PARK MIDDLE SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601006117",
    },
    {
        "school": "EAST RAMAPO EARLY CHILDHOOD CENTER AT KAKIAT",
        "district": "EAST RAMAPO CENTRAL SCHOOL DISTRICT (SPRING VALLEY)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362781006098",
    },
    {
        "school": "EXPEDITIONARY LEARNING MIDDLE SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859006134",
    },
    {
        "school": "UNATEGO MIDDLE SCHOOL",
        "district": "OTEGO-UNADILLA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362924006140",
    },
    {
        "school": "VOORHEESVILLE MIDDLE SCHOOL",
        "district": "VOORHEESVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362967006128",
    },
    {
        "school": "New Century International Elementary",
        "district": "Cumberland County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001103160",
    },
    {
        "school": "Career and Technical Education Center",
        "district": "Alamance-Burlington Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NC",
        "nces_id": "370003003171",
    },
    {
        "school": "Bertie Early College High",
        "district": "Bertie County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036003149",
    },
    {
        "school": "Town Creek Elementary",
        "district": "Brunswick County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042003134",
    },
    {
        "school": "Cedar Grove Middle",
        "district": "Brunswick County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042003135",
    },
    {
        "school": "Cabarrus-Kannapolis Early Coll",
        "district": "Cabarrus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053003159",
    },
    {
        "school": "Hickory Ridge Middle",
        "district": "Cabarrus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053003170",
    },
    {
        "school": "Patriots Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053003174",
    },
    {
        "school": "Phoenix Academy High",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370072003157",
    },
    {
        "school": "Southmont Elementary",
        "district": "Davidson County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114003119",
    },
    {
        "school": "Duplin Early College High",
        "district": "Duplin County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370120003154",
    },
    {
        "school": "Holton Career and Resource Center",
        "district": "Durham Public Schools",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "NC",
        "nces_id": "370126003130",
    },
    {
        "school": "Caleb's Creek Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150003122",
    },
    {
        "school": "Flat Rock Middle",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150003141",
    },
    {
        "school": "Kimmel Farm Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150003144",
    },
    {
        "school": "Granville Early College High",
        "district": "Granville County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180003142",
    },
    {
        "school": "Henderson County Early College",
        "district": "Henderson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370210003139",
    },
    {
        "school": "Northeast Elementary",
        "district": "Lenoir County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370261003143",
    },
    {
        "school": "Union Academy",
        "district": "Macon County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370276003126",
    },
    {
        "school": "Madison Early College High",
        "district": "Madison County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370282003145",
    },
    {
        "school": "Ridge Road Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003121",
    },
    {
        "school": "River Gate Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003123",
    },
    {
        "school": "River Oaks Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003128",
    },
    {
        "school": "Stoney Creek Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003131",
    },
    {
        "school": "Whitewater Middle",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003146",
    },
    {
        "school": "Rocky River High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003173",
    },
    {
        "school": "William Amos Hough High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003175",
    },
    {
        "school": "Mayland Early College",
        "district": "Mitchell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370300003137",
    },
    {
        "school": "Rocky River Elementary",
        "district": "Mooresville Graded School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370312003140",
    },
    {
        "school": "Early College EAST High",
        "district": "Craven County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370331003127",
    },
    {
        "school": "Castle Hayne Elementary",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333003136",
    },
    {
        "school": "Career Readiness Academy at Mosley PLC",
        "district": "New Hanover County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370333003138",
    },
    {
        "school": "Stateside Elementary",
        "district": "Onslow County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345003133",
    },
    {
        "school": "Topsail Elementary",
        "district": "Pender County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357003124",
    },
    {
        "school": "Stokes Early College",
        "district": "Stokes County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438003129",
    },
    {
        "school": "Clarke Elementary",
        "district": "Vance County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465003169",
    },
    {
        "school": "Herbert Akins Rd Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003120",
    },
    {
        "school": "Banks Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003132",
    },
    {
        "school": "Lake Myra Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003156",
    },
    {
        "school": "Wayne Middle / High Academy",
        "district": "Wayne County Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370488003147",
    },
    {
        "school": "Wilkes Early College High School",
        "district": "Wilkes County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370495003125",
    },
    {
        "school": "NEW SALEM-ALMONT HIGH SCHOOL",
        "district": "NEW SALEM-ALMONT 49",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380039200493",
    },
    {
        "school": "PRAIRIE VIEW ELEMENTARY SCHOOL",
        "district": "NEW SALEM-ALMONT 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380039200494",
    },
    {
        "school": "OSGOOD ELEM SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000841",
    },
    {
        "school": "DEL EASTON ALTERNATIVE HIGH SCHOOL",
        "district": "WILLISTON 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381988000848",
    },
    {
        "school": "Renaissance Academy",
        "district": "Renaissance Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390135405507",
    },
    {
        "school": "Achieve Career Preparatory Academy",
        "district": "Achieve Career Preparatory Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390136205524",
    },
    {
        "school": "Lakeland Academy Community School",
        "district": "Lakeland Academy Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390136305525",
    },
    {
        "school": "Horizon Science Academy Lorain",
        "district": "Horizon Science Academy Lorain",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390136505544",
    },
    {
        "school": "Horizon Science Academy Dayton High School",
        "district": "Horizon Science Academy Dayton High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390136605556",
    },
    {
        "school": "Village Preparatory School Cliffs",
        "district": "Village Preparatory School Cliffs",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390136805528",
    },
    {
        "school": "Greater Summit County Early Learning Center",
        "district": "Greater Summit County Early Learning Center",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390136905522",
    },
    {
        "school": "Bella Academy of Excellence",
        "district": "Bella Academy of Excellence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390137005562",
    },
    {
        "school": "Dayton Regional STEM School",
        "district": "Dayton Regional STEM School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390137405564",
    },
    {
        "school": "National Inventors Hall of Fame School Center for STEM",
        "district": "Akron City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434805555",
    },
    {
        "school": "Superior Intermediate School",
        "district": "Ashtabula Area City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435105520",
    },
    {
        "school": "Bucyrus Elementary School",
        "district": "Bucyrus City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436805533",
    },
    {
        "school": "Hughes STEM High School",
        "district": "Cincinnati Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505521",
    },
    {
        "school": "Martin Luther King Jr. Campus",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805523",
    },
    {
        "school": "Garfield Elementary School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805531",
    },
    {
        "school": "Cleveland School of Architecture & Design",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805538",
    },
    {
        "school": "Cleveland School of Science & Medicine",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805561",
    },
    {
        "school": "Defiance Elementary School",
        "district": "Defiance City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438605516",
    },
    {
        "school": "Gallia Academy Middle School",
        "district": "Gallipolis City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440305529",
    },
    {
        "school": "Linden Elementary School",
        "district": "Hamilton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441005541",
    },
    {
        "school": "Bridgeport Elementary School",
        "district": "Hamilton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441005549",
    },
    {
        "school": "Fairwood Elementary School",
        "district": "Hamilton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441005557",
    },
    {
        "school": "Ridgeway Elementary School",
        "district": "Hamilton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441005560",
    },
    {
        "school": "Ralph E. Waite Elementary",
        "district": "Medina City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443805534",
    },
    {
        "school": "Eliza Northrop Elementary",
        "district": "Medina City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443805535",
    },
    {
        "school": "Evolve Academy",
        "district": "Medina City SD",
        "level": "High",
        "type": "Special education school",
        "state": "OH",
        "nces_id": "390443805552",
    },
    {
        "school": "North College Hill Middle School",
        "district": "North College Hill City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445105554",
    },
    {
        "school": "Reading Community Middle School",
        "district": "Reading Community City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446905514",
    },
    {
        "school": "Martin Luther King Academy for Boys Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449005543",
    },
    {
        "school": "Spring Elementary School",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449005548",
    },
    {
        "school": "Wapakoneta Elementary",
        "district": "Wapakoneta City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449805536",
    },
    {
        "school": "Rayen Early College Middle School",
        "district": "Youngstown City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451605519",
    },
    {
        "school": "Buckeye Central Middle School",
        "district": "Buckeye Central Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465005506",
    },
    {
        "school": "Olmsted Falls Early Childhood Center",
        "district": "Olmsted Falls City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465705532",
    },
    {
        "school": "Toll Gate Elementary",
        "district": "Pickerington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468905547",
    },
    {
        "school": "Sycamore Creek Elementary School",
        "district": "Pickerington Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468905550",
    },
    {
        "school": "Toll Gate Middle School",
        "district": "Pickerington Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468905559",
    },
    {
        "school": "Whitaker Elementary School",
        "district": "Finneytown Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473305518",
    },
    {
        "school": "South Central Junior High School",
        "district": "South Central Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390477305546",
    },
    {
        "school": "Teays Valley West Middle School",
        "district": "Teays Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490905551",
    },
    {
        "school": "South Gallia Middle School",
        "district": "Gallia County Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390656805545",
    },
    {
        "school": "Cherry Hill Primary",
        "district": "Washington Court House City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001105509",
    },
    {
        "school": "Belle Aire Intermediate",
        "district": "Washington Court House City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001105513",
    },
    {
        "school": "Orange Inclusive Preschool",
        "district": "Orange City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001605553",
    },
    {
        "school": "DOVE SCH OF DISCOVERY TULSA",
        "district": "DOVE SCHOOLS OF TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400075302694",
    },
    {
        "school": "BLACKWELL ES",
        "district": "BLACKWELL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400463002687",
    },
    {
        "school": "COUNTRY LANE INTERMEDIATE ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002695",
    },
    {
        "school": "NICOMA PARK MS",
        "district": "CHOCTAW-NICOMA PARK",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400762002691",
    },
    {
        "school": "CHOCTAW MS",
        "district": "CHOCTAW-NICOMA PARK",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400762002698",
    },
    {
        "school": "HERITAGE INTERMEDIATE GRD CTR",
        "district": "COWETA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400885002697",
    },
    {
        "school": "GROVE VALLEY ES",
        "district": "DEER CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400957002696",
    },
    {
        "school": "LONGFELLOW MS",
        "district": "ENID",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092002686",
    },
    {
        "school": "EMERSON MS",
        "district": "ENID",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092002700",
    },
    {
        "school": "TRUMAN PRIMARY SCHOOL",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172002702",
    },
    {
        "school": "STONE CANYON ES",
        "district": "OWASSO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328002690",
    },
    {
        "school": "PERRY JHS",
        "district": "PERRY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402385002701",
    },
    {
        "school": "SHIDLER MS",
        "district": "SHIDLER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402763002689",
    },
    {
        "school": "SULPHUR MS",
        "district": "SULPHUR",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402916002703",
    },
    {
        "school": "The Ivy School",
        "district": "Oregon Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410000901784",
    },
    {
        "school": "Timber Ridge School",
        "district": "Greater Albany Public SD 8J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410112001773",
    },
    {
        "school": "Baker Web Academy",
        "district": "Baker SD 5J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410171001767",
    },
    {
        "school": "Baker Early College",
        "district": "Baker SD 5J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410171001783",
    },
    {
        "school": "Springville K-8 School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001779",
    },
    {
        "school": "Summit Community College High School",
        "district": "Estacada SD 108",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410470001778",
    },
    {
        "school": "Camas Ridge Community Elementary",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001781",
    },
    {
        "school": "Gladstone Center for Children and Families",
        "district": "Gladstone SD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410561001774",
    },
    {
        "school": "Metro East Web Academy",
        "district": "Gresham-Barlow SD 10J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410600001787",
    },
    {
        "school": "Mazama High School",
        "district": "Klamath County SD",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410702000513",
    },
    {
        "school": "Molalla River Academy",
        "district": "Molalla River SD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410831001789",
    },
    {
        "school": "Scouters Mountain Elementary",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001775",
    },
    {
        "school": "Verne A Duncan Elementary School",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001777",
    },
    {
        "school": "Happy Valley Middle School",
        "district": "North Clackamas SD 12",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001782",
    },
    {
        "school": "Redmond Proficiency Academy",
        "district": "Redmond SD 2J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035001785",
    },
    {
        "school": "Edy Ridge Elementary School",
        "district": "Sherwood SD 88J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411129001772",
    },
    {
        "school": "Laurel Ridge Middle School",
        "district": "Sherwood SD 88J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411129001788",
    },
    {
        "school": "The Community Roots School",
        "district": "Silver Falls SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411145001769",
    },
    {
        "school": "Arts and Technology High School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "411317001786",
    },
    {
        "school": "Vida Charter School",
        "district": "Vida Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420081406994",
    },
    {
        "school": "KIPP West Philadelphia Preparatory Chart",
        "district": "KIPP West Philadelphia Preparatory Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420081507308",
    },
    {
        "school": "Sankofa Freedom Academy Charter School",
        "district": "Sankofa Freedom Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420081606948",
    },
    {
        "school": "Franklin Towne Charter Elementary School",
        "district": "Franklin Towne Charter Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420081706985",
    },
    {
        "school": "Seven Generations Charter School",
        "district": "Seven Generations Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420081807148",
    },
    {
        "school": "Lincoln Leadership Academy Charter Schoo",
        "district": "Lincoln Leadership Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420081906955",
    },
    {
        "school": "Tacony Academy Charter School",
        "district": "Tacony Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420082106962",
    },
    {
        "school": "Eastern University Academy Charter Schoo",
        "district": "Eastern University Academy Charter School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420082206949",
    },
    {
        "school": "Central Valley MS",
        "district": "Central Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420082407317",
    },
    {
        "school": "Central Valley HS",
        "district": "Central Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420082407319",
    },
    {
        "school": "Todd Lane El Sch",
        "district": "Central Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420082407329",
    },
    {
        "school": "Center Grange Primary School",
        "district": "Central Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420082407339",
    },
    {
        "school": "Aliquippa JSHS",
        "district": "Aliquippa SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420213007336",
    },
    {
        "school": "California Area Intermediate MS",
        "district": "California Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420471006953",
    },
    {
        "school": "Benjamin Chambers El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555007328",
    },
    {
        "school": "Clairton MS/HS",
        "district": "Clairton City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420603007346",
    },
    {
        "school": "Cornell HS",
        "district": "Cornell SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420681007335",
    },
    {
        "school": "Shawnee El Sch",
        "district": "Easton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420885006947",
    },
    {
        "school": "Willow Creek El Sch",
        "district": "Fleetwood Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420978007311",
    },
    {
        "school": "Mifflin Park El Sch",
        "district": "Governor Mifflin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421086007065",
    },
    {
        "school": "Jenkintown Middle/High School",
        "district": "Jenkintown SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421242007327",
    },
    {
        "school": "Rayne El Sch",
        "district": "Marion Center Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421473007338",
    },
    {
        "school": "McDowell HS",
        "district": "Millcreek Township SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421533007320",
    },
    {
        "school": "Grandview El Sch",
        "district": "Morrisville Borough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421590007344",
    },
    {
        "school": "Nazareth Area Intermediate Sch",
        "district": "Nazareth Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421638007111",
    },
    {
        "school": "North Pocono Intmd Sch",
        "district": "North Pocono SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421731007314",
    },
    {
        "school": "Hahntown El Sch",
        "district": "Norwin SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421794007307",
    },
    {
        "school": "Hopewell El Sch",
        "district": "Oxford Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421830007313",
    },
    {
        "school": "Elk Ridge School",
        "district": "Oxford Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421830007333",
    },
    {
        "school": "Pittsburgh Science and Technology Academ",
        "district": "Pittsburgh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006989",
    },
    {
        "school": "Pittsburgh Obama 6-12",
        "district": "Pittsburgh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917006995",
    },
    {
        "school": "Pittsburgh CAPA 6-12",
        "district": "Pittsburgh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917007014",
    },
    {
        "school": "Pittsburgh Milliones 6-12",
        "district": "Pittsburgh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917007345",
    },
    {
        "school": "Central MS",
        "district": "Reading SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004006958",
    },
    {
        "school": "Larry J. Macaluso El Sch",
        "district": "Red Lion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422010006954",
    },
    {
        "school": "Sharon MS",
        "district": "Sharon City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422133007318",
    },
    {
        "school": "Sharon HS",
        "district": "Sharon City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422133007321",
    },
    {
        "school": "Southern Lehigh Intermediate Sch",
        "district": "Southern Lehigh SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422235006967",
    },
    {
        "school": "Southmoreland MS",
        "district": "Southmoreland SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422241006978",
    },
    {
        "school": "Spring Cove El Sch",
        "district": "Spring Cove SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422253007337",
    },
    {
        "school": "Zephyr El Sch",
        "district": "Whitehall-Coplay SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422625006938",
    },
    {
        "school": "Segue Inst for Learning",
        "district": "Segue Institute for Learning",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440001400472",
    },
    {
        "school": "Blackstone Valley Prep",
        "district": "Blackstone Valley Prep  A RI Mayoral Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440001500473",
    },
    {
        "school": "Joseph Gaudet Academy",
        "district": "Middletown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440063000471",
    },
    {
        "school": "Nathan Bishop Middle",
        "district": "Providence",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000474",
    },
    {
        "school": "Riverview Charter School",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001530",
    },
    {
        "school": "Red Cedar Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001538",
    },
    {
        "school": "Cane Bay Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001537",
    },
    {
        "school": "St. Matthews K-8 School",
        "district": "Calhoun 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450125001532",
    },
    {
        "school": "Jerry Zucker Middle School of Science",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001533",
    },
    {
        "school": "HCS Early College High",
        "district": "Horry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001531",
    },
    {
        "school": "Lee Central Middle",
        "district": "Lee 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450267001540",
    },
    {
        "school": "Blue Ridge Elementary",
        "district": "Oconee 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450306001528",
    },
    {
        "school": "Larne Elementary",
        "district": "York 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450384001539",
    },
    {
        "school": "Sugar Creek Elementary",
        "district": "York 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001529",
    },
    {
        "school": "Pleasant Knoll Elementary",
        "district": "York 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001535",
    },
    {
        "school": "Spartanburg Preparatory School",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101541",
    },
    {
        "school": "Palmetto Scholars Academy",
        "district": "SC Public Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101542",
    },
    {
        "school": "York Preparatory Academy",
        "district": "SC Public Charter School District",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101544",
    },
    {
        "school": "Fred Assam Elementary - 06",
        "district": "Brandon Valley School District 49-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460795001302",
    },
    {
        "school": "Camelot Intermediate - 06",
        "district": "Brookings School District 05-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460852001298",
    },
    {
        "school": "High Plains - 06",
        "district": "Chester Area School District 39-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "461230001295",
    },
    {
        "school": "Wood Elementary - 05",
        "district": "Colome Consolidated 59-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461413000787",
    },
    {
        "school": "Camrose Colony Elementary - 06",
        "district": "Doland School District 56-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461917001299",
    },
    {
        "school": "Gregory Junior High - 04",
        "district": "Gregory School District 26-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462988001296",
    },
    {
        "school": "RF Pettigrew Elementary - 17",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001300",
    },
    {
        "school": "Cameron Colony Elementary - 04",
        "district": "Viborg-Hurley School District 60-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467452001301",
    },
    {
        "school": "Collins Colony Elementary - 06",
        "district": "Willow Lake School District 12-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467935001297",
    },
    {
        "school": "Community Middle School",
        "district": "Bedford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018002218",
    },
    {
        "school": "Learning Way Elementary",
        "district": "Bedford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018002222",
    },
    {
        "school": "South Gibson County High School",
        "district": "Gibson Co Sp Dist",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470140002207",
    },
    {
        "school": "Grainger Academy",
        "district": "Grainger County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470144002193",
    },
    {
        "school": "Chattanooga Girls Leadership Academy",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159002211",
    },
    {
        "school": "East Hamilton School",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159002214",
    },
    {
        "school": "Ivy Academy Inc.",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159002220",
    },
    {
        "school": "John Adams Elementary School",
        "district": "Kingsport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470219002216",
    },
    {
        "school": "The Academy at Old Cockrill",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002192",
    },
    {
        "school": "The Academy at Opry Mills",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002198",
    },
    {
        "school": "Robert Churchwell Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002201",
    },
    {
        "school": "Madison Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002202",
    },
    {
        "school": "Algood Elementary",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348002195",
    },
    {
        "school": "White Plains Academy",
        "district": "Putnam County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470348002196",
    },
    {
        "school": "Brown's Chapel Elementary School",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002212",
    },
    {
        "school": "Gary Hardin Academy",
        "district": "Sevier County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378002215",
    },
    {
        "school": "Knox Doss Middle School at Drakes Creek",
        "district": "Sumner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402002203",
    },
    {
        "school": "Portland West Middle School",
        "district": "Sumner County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402002205",
    },
    {
        "school": "Portland Gateview Elementary School",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402002219",
    },
    {
        "school": "CROSBYTON DAEP",
        "district": "CROSBYTON CISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480000112448",
    },
    {
        "school": "TEXAS EMPOWERMENT ACADEMY EL",
        "district": "TEXAS EMPOWERMENT ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006612411",
    },
    {
        "school": "HOUSTON GATEWAY ACADEMY - CORAL CAMPUS",
        "district": "HOUSTON GATEWAY ACADEMY INC",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480011812310",
    },
    {
        "school": "TEKOA ACADEMY OF ACCELERATED STUDIES",
        "district": "TEKOA ACADEMY OF ACCELERATED STUDIES STEM SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480013912285",
    },
    {
        "school": "TEKOA ACADEMY OF ACCELERATED STUDIES",
        "district": "TEKOA ACADEMY OF ACCELERATED STUDIES STEM SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480013912365",
    },
    {
        "school": "VISTA ACADEMY OF JASPER",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312345",
    },
    {
        "school": "STEM ACADEMY - LEWISVILLE",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312415",
    },
    {
        "school": "YES PREP - BRAYS OAKS",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020912326",
    },
    {
        "school": "YES PREP - WEST",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020912401",
    },
    {
        "school": "IDEA ACADEMY PHARR",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112266",
    },
    {
        "school": "IDEA COLLEGE PREPARATORY ALAMO",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112306",
    },
    {
        "school": "IDEA COLLEGE PREPARATORY PHARR",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112390",
    },
    {
        "school": "IDEA ACADEMY ALAMO",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112418",
    },
    {
        "school": "TEXAS EARLY COLLEGE H S",
        "district": "PANOLA CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021312307",
    },
    {
        "school": "GATEWAY TECH H S",
        "district": "ORENDA CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480023512289",
    },
    {
        "school": "GATEWAY COLLEGE PREPARATORY SCHOOL",
        "district": "ORENDA CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023512294",
    },
    {
        "school": "GOLDEN RULE DESOTO",
        "district": "GOLDEN RULE CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023712366",
    },
    {
        "school": "GOLDEN RULE SOUTHWEST",
        "district": "GOLDEN RULE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023712372",
    },
    {
        "school": "HARMONY SCHOOL OF EXCELLENCE - AUSTIN",
        "district": "HARMONY SCIENCE ACADEMY (AUSTIN)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024112424",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY - ALAMO",
        "district": "SCHOOL OF SCIENCE AND TECHNOLOGY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480025812291",
    },
    {
        "school": "KIPP AUSTIN ACADEMY OF ARTS & LETTERS",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412305",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - EL PASO",
        "district": "HARMONY SCIENCE ACAD (EL PASO)",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027212339",
    },
    {
        "school": "HARMONY SCHOOL OF ENDEAVOR-HOUSTON",
        "district": "HARMONY SCHOOL OF EXCELLENCE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027412284",
    },
    {
        "school": "TLC ACADEMY",
        "district": "TEXAS LEADERSHIP",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140912357",
    },
    {
        "school": "BOB HOPE SCHOOL",
        "district": "BOB HOPE SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141012450",
    },
    {
        "school": "HENRY FORD ACADEMY ALAMEDA SCHOOL FOR ART + DESIGN",
        "district": "HENRY FORD ACADEMY ALAMEDA SCHOOL FOR ART + DESIGN",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141212313",
    },
    {
        "school": "THE EAST AUSTIN COLLEGE PREP AT SOUTHWEST KEY",
        "district": "PROMESA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141412335",
    },
    {
        "school": "MANARA ACADEMY",
        "district": "MANARA ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141512439",
    },
    {
        "school": "ACADEMY FOR TECHNOLOGY ENGINEERING MATH & SCIENCE",
        "district": "ABILENE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744012452",
    },
    {
        "school": "ALIEF EARLY COLLEGE H S",
        "district": "ALIEF ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783012389",
    },
    {
        "school": "DAVID AND LYNDA OLSON EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789012329",
    },
    {
        "school": "COMMUNITY BASED PK",
        "district": "ARLINGTON ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870012353",
    },
    {
        "school": "CEDAR CREEK H S",
        "district": "BASTROP ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957012272",
    },
    {
        "school": "FEHL-PRICE EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967012376",
    },
    {
        "school": "MARTIN EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967012429",
    },
    {
        "school": "DR MAE E JONES-CLARK EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967012433",
    },
    {
        "school": "BLANCHETTE EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967012437",
    },
    {
        "school": "CHARLTON-POLLARD EL",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967012447",
    },
    {
        "school": "MIDWAY ALTERNATIVE H S",
        "district": "CANYON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481281012356",
    },
    {
        "school": "CLEAR FALLS H S",
        "district": "CLEAR CREEK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428012296",
    },
    {
        "school": "CLEAR CREEK INT",
        "district": "CLEAR CREEK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428012359",
    },
    {
        "school": "SANDRA MOSSMAN EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428012385",
    },
    {
        "school": "BAYSIDE INT",
        "district": "CLEAR CREEK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428012409",
    },
    {
        "school": "RALPH PARR EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428012443",
    },
    {
        "school": "KINDER RANCH AREA H S",
        "district": "COMAL ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473012276",
    },
    {
        "school": "DAVENPORT H S",
        "district": "COMAL ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473012282",
    },
    {
        "school": "INDIAN SPRINGS EL",
        "district": "COMAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473012350",
    },
    {
        "school": "COMAL DISCIPLINE CENTER",
        "district": "COMAL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481473012361",
    },
    {
        "school": "ALTERNATIVE LEARNING CTR - WEST",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481611012265",
    },
    {
        "school": "RENNELL EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611012300",
    },
    {
        "school": "EMERY EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611012432",
    },
    {
        "school": "KENNEDY-CURRY MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012455",
    },
    {
        "school": "DAILEY MIDDLE",
        "district": "DEL VALLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662012337",
    },
    {
        "school": "CROSS OAKS EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674012271",
    },
    {
        "school": "EMILIO & GUADALUPE GONZALEZ PRE-K CENTER",
        "district": "DENTON ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674012327",
    },
    {
        "school": "CALDER ROAD EL",
        "district": "DICKINSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707012419",
    },
    {
        "school": "DUMAS INT",
        "district": "DUMAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481761012386",
    },
    {
        "school": "WILLOW CREEK EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770012416",
    },
    {
        "school": "WILSON COUNTY BOOT CAMP",
        "district": "EAST CENTRAL ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481785012320",
    },
    {
        "school": "BURLESON CENTER",
        "district": "EDGEWOOD ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815012382",
    },
    {
        "school": "STAFFORD CENTER",
        "district": "EDGEWOOD ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815012395",
    },
    {
        "school": "VISION ACADEMY OF EXCELLENCE",
        "district": "EDINBURG CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481818012377",
    },
    {
        "school": "E-17 NE EL SANDSTONE RANCH",
        "district": "EL PASO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830012374",
    },
    {
        "school": "JOHN AND POLLY TOWNLEY EL",
        "district": "EVERMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481881012275",
    },
    {
        "school": "FAIRFIELD INT",
        "district": "FAIRFIELD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481894012297",
    },
    {
        "school": "NORTH EL",
        "district": "FLORESVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481935012323",
    },
    {
        "school": "BENBROOK MIDDLE/HIGH SCHOOL",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970012309",
    },
    {
        "school": "JEAN MCCLUNG MIDDLE",
        "district": "FORT WORTH ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970012314",
    },
    {
        "school": "HAZEL HARVEY PEACE EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970012322",
    },
    {
        "school": "ROSEMONT PARK EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970012330",
    },
    {
        "school": "JOHN T WHITE EL",
        "district": "FORT WORTH ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970012334",
    },
    {
        "school": "TEXAS ACADEMY OF BIOMEDICAL",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970012338",
    },
    {
        "school": "YOUNG WOMEN'S LEADERSHIP ACADEMY",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970012392",
    },
    {
        "school": "AIM COLLEGE & CAREER PREP",
        "district": "GALVESTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482028012288",
    },
    {
        "school": "ROSENBERG EL LABORATORY FOR LEARNING AND LEADING",
        "district": "GALVESTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482028012362",
    },
    {
        "school": "COLLEGIATE ACADEMY",
        "district": "GALVESTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482028012369",
    },
    {
        "school": "GANADO JH",
        "district": "GANADO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482031012317",
    },
    {
        "school": "GORMAN MIDDLE",
        "district": "GORMAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482127012303",
    },
    {
        "school": "WILLIAM E WYLIE EL",
        "district": "HENDERSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482297012264",
    },
    {
        "school": "HITCHCOCK PRI",
        "district": "HITCHCOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482331012367",
    },
    {
        "school": "ENERGIZED FOR STEM ACADEMY SOUTHWEST H S",
        "district": "HOUSTON ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012269",
    },
    {
        "school": "TEXAS CONNECTIONS ACADEMY AT HOUSTON",
        "district": "HOUSTON ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012363",
    },
    {
        "school": "ENERGIZED FOR STEM ACADEMY SOUTHWEST MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012383",
    },
    {
        "school": "ATASCOCITA SPRINGS EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391012368",
    },
    {
        "school": "JOSHUA H S NINTH GRADE CAMPUS",
        "district": "JOSHUA ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482493012316",
    },
    {
        "school": "STANLEY C STANLEY EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517012315",
    },
    {
        "school": "KELLER EARLY LEARNING CENTER - NORTH",
        "district": "KELLER ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526012410",
    },
    {
        "school": "TIMBERVIEW MIDDLE",
        "district": "KELLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526012420",
    },
    {
        "school": "KERMIT EL",
        "district": "KERMIT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482556012414",
    },
    {
        "school": "HAYNES EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566012378",
    },
    {
        "school": "ULRICH INT",
        "district": "KLEIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574012283",
    },
    {
        "school": "MUELLER EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574012302",
    },
    {
        "school": "TRAVIS COUNTY JJAEP",
        "district": "LAGO VISTA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482640012434",
    },
    {
        "school": "FOUR POINTS MIDDLE",
        "district": "LEANDER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703012381",
    },
    {
        "school": "BURLEY PRI",
        "district": "LUFKIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482855012355",
    },
    {
        "school": "HILL COUNTY JJAEP",
        "district": "MALONE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482880012308",
    },
    {
        "school": "MANSFIELD FRONTIER H S",
        "district": "MANSFIELD ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892012371",
    },
    {
        "school": "JOHN F KENNEDY EL",
        "district": "MERCEDES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483025012403",
    },
    {
        "school": "MERCEDES EARLY COLLEGE ACADEMY",
        "district": "MERCEDES ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483025012441",
    },
    {
        "school": "JAMES BOWIE FINE ARTS ACADEMY",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057012290",
    },
    {
        "school": "EARLY COLLEGE H S AT MIDLAND COLLEGE",
        "district": "MIDLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057012458",
    },
    {
        "school": "RIVER VALLEY INT",
        "district": "MIDWAY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483064012440",
    },
    {
        "school": "MONTE ALTO H S",
        "district": "MONTE ALTO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483123012311",
    },
    {
        "school": "TUSCANY HEIGHTS",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294012435",
    },
    {
        "school": "CIBOLO GREEN",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294012442",
    },
    {
        "school": "BEHLAU EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012332",
    },
    {
        "school": "MARTIN EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012341",
    },
    {
        "school": "HENDERSON EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012344",
    },
    {
        "school": "BRENNAN H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012347",
    },
    {
        "school": "BRISCOE MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012413",
    },
    {
        "school": "TARRANT COUNTY JJAEP",
        "district": "NORTHWEST ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483318012273",
    },
    {
        "school": "CLARA LOVE EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318012293",
    },
    {
        "school": "JOHN M TIDWELL MIDDLE",
        "district": "NORTHWEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318012301",
    },
    {
        "school": "JAMES M STEELE H S",
        "district": "NORTHWEST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318012421",
    },
    {
        "school": "HILL COUNTY JJAEP",
        "district": "PENELOPE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483456012428",
    },
    {
        "school": "HALE CO JJAEP",
        "district": "PETERSBURG ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483468012451",
    },
    {
        "school": "PSJA EARLY START",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486012393",
    },
    {
        "school": "PLEASANT GROVE INT",
        "district": "PLEASANT GROVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483513012449",
    },
    {
        "school": "WASHINGTON EL",
        "district": "PORT ARTHUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483540012349",
    },
    {
        "school": "PROGRESO EL",
        "district": "PROGRESO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483591012422",
    },
    {
        "school": "EAGLE LAKE PRI",
        "district": "RICE CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483697012446",
    },
    {
        "school": "WILLOW VISTA ECA",
        "district": "RIVER ROAD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483726012346",
    },
    {
        "school": "VERIBEST SPECIAL PROGRAMS",
        "district": "ROBERT LEE ISD",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483738012298",
    },
    {
        "school": "PEARSON RANCH MIDDLE",
        "district": "ROUND ROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808012299",
    },
    {
        "school": "NEW NORTHEAST AREA EL",
        "district": "ROUND ROCK ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808012352",
    },
    {
        "school": "ELSA ENGLAND EL",
        "district": "ROUND ROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808012358",
    },
    {
        "school": "7TH H S - NORTHEAST",
        "district": "ROUND ROCK ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808012373",
    },
    {
        "school": "NEW LAKELINE AREA EL",
        "district": "ROUND ROCK ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808012405",
    },
    {
        "school": "PFC ROBERT P HERNANDEZ MIDDLE",
        "district": "ROUND ROCK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808012431",
    },
    {
        "school": "NEW 6TH H S - PEARSON RANCH",
        "district": "ROUND ROCK ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808012454",
    },
    {
        "school": "HARRY H HERNDON",
        "district": "ROYSE CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483822012391",
    },
    {
        "school": "CARROLL EARLY CHILDHOOD CAMPUS",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873012319",
    },
    {
        "school": "TYNAN EARLY CHILDHOOD CAMPUS",
        "district": "SAN ANTONIO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873012325",
    },
    {
        "school": "KNOX EARLY CHILDHOOD CAMPUS",
        "district": "SAN ANTONIO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873012394",
    },
    {
        "school": "CARVAJAL EL",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873012397",
    },
    {
        "school": "GATEWAY TO GRADUATION ACADEMY",
        "district": "SAN BENITO CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483879012292",
    },
    {
        "school": "GLORIA MARSHALL EL",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122012370",
    },
    {
        "school": "GOSHEN CREEK EL",
        "district": "SPRINGTOWN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484128012304",
    },
    {
        "school": "TOMBALL MEMORIAL H S",
        "district": "TOMBALL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296012380",
    },
    {
        "school": "VICTORIA EAST H S",
        "district": "VICTORIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415012267",
    },
    {
        "school": "VICTORIA WEST H S",
        "district": "VICTORIA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415012281",
    },
    {
        "school": "HAROLD CADE MIDDLE",
        "district": "VICTORIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484415012287",
    },
    {
        "school": "WINDTHORST JH",
        "district": "WINDTHORST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484608012438",
    },
    {
        "school": "3RD H S",
        "district": "WYLIE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653012331",
    },
    {
        "school": "WALLY WATKINS EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653012333",
    },
    {
        "school": "American Preparatory Academy - The School for New Americans",
        "district": "American Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490000501372",
    },
    {
        "school": "Sage Hills School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001320",
    },
    {
        "school": "Jean Massieu School for the Deaf",
        "district": "Utah Schools for Deaf & Blind",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490006901377",
    },
    {
        "school": "Alta View School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200286",
    },
    {
        "school": "Bell View School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200287",
    },
    {
        "school": "Bella Vista School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200288",
    },
    {
        "school": "Brighton High",
        "district": "Canyons District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200291",
    },
    {
        "school": "Brookwood School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200292",
    },
    {
        "school": "Butler Middle",
        "district": "Canyons District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200293",
    },
    {
        "school": "Butler School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200294",
    },
    {
        "school": "Canyon View School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200295",
    },
    {
        "school": "Copperview School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200296",
    },
    {
        "school": "Draper School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200299",
    },
    {
        "school": "East Midvale School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200300",
    },
    {
        "school": "East Sandy School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200301",
    },
    {
        "school": "Eastmont Middle",
        "district": "Canyons District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200302",
    },
    {
        "school": "Edgemont School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200303",
    },
    {
        "school": "Granite School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200304",
    },
    {
        "school": "Hillcrest High",
        "district": "Canyons District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200305",
    },
    {
        "school": "Jordan High",
        "district": "Canyons District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200307",
    },
    {
        "school": "Jordan Valley School",
        "district": "Canyons District",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490014200309",
    },
    {
        "school": "Midvale Middle",
        "district": "Canyons District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200311",
    },
    {
        "school": "Midvale School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200312",
    },
    {
        "school": "Midvalley School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200313",
    },
    {
        "school": "Mt. Jordan Middle",
        "district": "Canyons District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200316",
    },
    {
        "school": "Oakdale School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200317",
    },
    {
        "school": "Peruvian Park School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200318",
    },
    {
        "school": "Ridgecrest School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200319",
    },
    {
        "school": "Sandy School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200321",
    },
    {
        "school": "Sprucewood School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200325",
    },
    {
        "school": "Sunrise School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200326",
    },
    {
        "school": "Union Middle",
        "district": "Canyons District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200328",
    },
    {
        "school": "Willow Canyon School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200333",
    },
    {
        "school": "Oak Hollow School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200529",
    },
    {
        "school": "Silver Mesa School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200658",
    },
    {
        "school": "Alta High",
        "district": "Canyons District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200659",
    },
    {
        "school": "Park Lane School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200685",
    },
    {
        "school": "Altara School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200718",
    },
    {
        "school": "Indian Hills Middle",
        "district": "Canyons District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200719",
    },
    {
        "school": "Crescent School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200767",
    },
    {
        "school": "Quail Hollow School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200768",
    },
    {
        "school": "Albion Middle",
        "district": "Canyons District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200815",
    },
    {
        "school": "Lone Peak School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200856",
    },
    {
        "school": "Draper Park Middle",
        "district": "Canyons District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014200875",
    },
    {
        "school": "South Park Academy",
        "district": "Canyons District",
        "level": "High",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490014200950",
    },
    {
        "school": "Willow Springs School",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014201124",
    },
    {
        "school": "Canyons Technical Education Center",
        "district": "Canyons District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "UT",
        "nces_id": "490014201189",
    },
    {
        "school": "Special Ed Preschool",
        "district": "Canyons District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490014201309",
    },
    {
        "school": "Entrada",
        "district": "Canyons District",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014201368",
    },
    {
        "school": "Canyon Grove Academy",
        "district": "Canyon Grove Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014301376",
    },
    {
        "school": "Maria Montessori Academy",
        "district": "Maria Montessori Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014401374",
    },
    {
        "school": "Weilenmann School of Discovery",
        "district": "Weilenmann School of Discovery",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014501378",
    },
    {
        "school": "Bear River Charter School",
        "district": "Bear River Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014601375",
    },
    {
        "school": "Foxboro School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001369",
    },
    {
        "school": "Kauri Sue Hamilton",
        "district": "Jordan District",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490042001336",
    },
    {
        "school": "Herriman High",
        "district": "Jordan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001338",
    },
    {
        "school": "Silver Crest School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001353",
    },
    {
        "school": "Delta North School",
        "district": "Millard District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490054001337",
    },
    {
        "school": "Delta South School",
        "district": "Millard District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490054001354",
    },
    {
        "school": "Shadow Valley School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001317",
    },
    {
        "school": "Provo eSchool",
        "district": "Provo District",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490081001349",
    },
    {
        "school": "Southwest High",
        "district": "Washington District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490114001306",
    },
    {
        "school": "Out of State School",
        "district": "Washington District",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001371",
    },
    {
        "school": "REG ALT ED CENTER/BUENA VISTA",
        "district": "REG ALT ED CENTER/BUENA VISTA",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510025102823",
    },
    {
        "school": "VIRGINIA HILLS E C RESOURCE CTR",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002819",
    },
    {
        "school": "BULL RUN E C RESOURCE CTR",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002820",
    },
    {
        "school": "PLUM CENTER FOR LIFELONG LEARNING",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510126002827",
    },
    {
        "school": "EASTERN MONTGOMERY ELEM",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510252002818",
    },
    {
        "school": "GATEWAY ACADEMY",
        "district": "SPOTSYLVANIA CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510364002821",
    },
    {
        "school": "THE RENAISSANCE ACADEMY",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510384002822",
    },
    {
        "school": "Kelso Virtual Academy",
        "district": "Kelso School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000303314",
    },
    {
        "school": "Cap Sante High School",
        "district": "Anacortes School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530015003303",
    },
    {
        "school": "Frederickson Elementary",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048003272",
    },
    {
        "school": "Pierce County Skills Center",
        "district": "Bethel School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530048003284",
    },
    {
        "school": "Nelson Elementary School",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048003288",
    },
    {
        "school": "Special Services",
        "district": "Bremerton School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530066003269",
    },
    {
        "school": "Grass Valley Elementary",
        "district": "Camas School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081003312",
    },
    {
        "school": "I-TRACC",
        "district": "Central Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530111003278",
    },
    {
        "school": "Panorama School",
        "district": "Colville School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530163003305",
    },
    {
        "school": "Career Academy at Truman High School",
        "district": "Federal Way School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530282003306",
    },
    {
        "school": "Crossroads High School",
        "district": "Granite Falls School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530321003300",
    },
    {
        "school": "Puget Sound High School",
        "district": "Highline School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530354003283",
    },
    {
        "school": "Hoquiam Homelink School",
        "district": "Hoquiam School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530366003290",
    },
    {
        "school": "Columbia Virtual Academy - Kettle Falls",
        "district": "Kettle Falls School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530399003270",
    },
    {
        "school": "Kiona-Benton Intermediate School",
        "district": "Kiona-Benton City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530402003279",
    },
    {
        "school": "Washington Network for Innovative Careers",
        "district": "Lake Washington School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530423003289",
    },
    {
        "school": "Sage Point Elementary School",
        "district": "Moses Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522003281",
    },
    {
        "school": "Aspire Middle School",
        "district": "North Thurston Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585003280",
    },
    {
        "school": "Chambers Prairie Elementary School",
        "district": "North Thurston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585003308",
    },
    {
        "school": "Ocean Beach Early Childhood Center",
        "district": "Ocean Beach School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530606003296",
    },
    {
        "school": "Washington Virtual Academy Omak Elementary",
        "district": "Omak School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530622003282",
    },
    {
        "school": "Washington Virtual Academy Omak High School",
        "district": "Omak School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530622003304",
    },
    {
        "school": "Washington Virtual Academy Omak Middle School",
        "district": "Omak School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530622003307",
    },
    {
        "school": "Chiawana High School",
        "district": "Pasco School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657003292",
    },
    {
        "school": "Prescott Special Ed Pre-school",
        "district": "Prescott School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530687003274",
    },
    {
        "school": "Puyallup Online Academy/POA",
        "district": "Puyallup School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530696003315",
    },
    {
        "school": "Three Rivers Home Link",
        "district": "Richland School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530732003273",
    },
    {
        "school": "Hazel Wolf K-8",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003271",
    },
    {
        "school": "Snoqualmie Access",
        "district": "Snoqualmie Valley School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530804003309",
    },
    {
        "school": "Special Services",
        "district": "Tacoma School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530870003275",
    },
    {
        "school": "Science and Math Institute",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870003286",
    },
    {
        "school": "Tacoma Business Academy",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530870003298",
    },
    {
        "school": "First Creek Middle School",
        "district": "Tacoma School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870003299",
    },
    {
        "school": "Tacoma Pierce County Education Center",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870003313",
    },
    {
        "school": "Cowlitz Prairie Academy",
        "district": "Toledo School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530891003310",
    },
    {
        "school": "Head Start",
        "district": "Walla Walla Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530945003311",
    },
    {
        "school": "SPRING MILLS PRIMARY",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001479",
    },
    {
        "school": "GENE SPADARO REGIONAL JUVENILE CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101482",
    },
    {
        "school": "DRISWOOD ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540057001478",
    },
    {
        "school": "MARY C. SNOW WEST SIDE ELEMENTARY",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060001476",
    },
    {
        "school": "GATEWAY ACHIEVEMENT CENTER",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540075001481",
    },
    {
        "school": "RIVER VIEW HIGH SCHOOL",
        "district": "MCDOWELL COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540081001477",
    },
    {
        "school": "PIKEVIEW MIDDLE SCHOOL",
        "district": "MERCER COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540084001480",
    },
    {
        "school": "Glidden Elementary",
        "district": "Chequamegon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550005800590",
    },
    {
        "school": "Park Falls Elementary",
        "district": "Chequamegon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550005801523",
    },
    {
        "school": "Bruce Guadalupe",
        "district": "Bruce Guadalupe Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550005900772",
    },
    {
        "school": "Chetek-Weyerhaeuser Roselawn Elementary",
        "district": "Chetek-Weyerhaeuser Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006102805",
    },
    {
        "school": "Chetek-Weyerhaeuser Middle",
        "district": "Chetek-Weyerhaeuser Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006102806",
    },
    {
        "school": "Chetek-Weyerhaeuser High",
        "district": "Chetek-Weyerhaeuser Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006102807",
    },
    {
        "school": "BELC--Renewal Head Start",
        "district": "Baraboo School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550081002802",
    },
    {
        "school": "Baraboo Early Learning Cooperative",
        "district": "Baraboo School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550081002803",
    },
    {
        "school": "Don Smith Learning Academy",
        "district": "Beaver Dam Unified School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550096002815",
    },
    {
        "school": "Beloit Virtual School",
        "district": "Beloit School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105002799",
    },
    {
        "school": "Birchwood Blue Hills Charter School",
        "district": "Birchwood School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550117002800",
    },
    {
        "school": "Wisconsin Virtual Learning",
        "district": "Northern Ozaukee School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550489002801",
    },
    {
        "school": "Howard and Suamico 4K Collaborative",
        "district": "Howard-Suamico School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550663002814",
    },
    {
        "school": "21st Century eSchool",
        "district": "Middleton-Cross Plains Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951002818",
    },
    {
        "school": "High Marq Environmental Charter School",
        "district": "Montello School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550987002821",
    },
    {
        "school": "Hillcrest Primary School",
        "district": "Shawano School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551362002819",
    },
    {
        "school": "Sandhill Elementary",
        "district": "Stoughton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551455002813",
    },
    {
        "school": "Cardinal Heights Upper Middle",
        "district": "Sun Prairie Area School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464002810",
    },
    {
        "school": "Superior Community Preschool",
        "district": "Superior School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551467002811",
    },
    {
        "school": "Timber PUPS Learning Center",
        "district": "Tomah Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551491002797",
    },
    {
        "school": "Waupun Area Junior High",
        "district": "Waupun School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551587002808",
    },
    {
        "school": "Rock River Intermediate",
        "district": "Waupun School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551587002809",
    },
    {
        "school": "Saddle Ridge Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000426",
    },
    {
        "school": "South High School",
        "district": "Laramie County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000448",
    },
    {
        "school": "Sage Elementary",
        "district": "Sweetwater County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200427",
    },
    {
        "school": "Harrison Elementary",
        "district": "Sweetwater County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560576200439",
    },
    {
        "school": "Youth Emergency Services Inc.",
        "district": "Youth Emergency Services Inc. - Administration Office",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WY",
        "nces_id": "568025200350",
    },
    {
        "school": "Red Level Elementary School",
        "district": "Covington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10093002167",
    },
    {
        "school": "Providence Elementary",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180002172",
    },
    {
        "school": "GoldsmithSchiffman Elementary",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180002173",
    },
    {
        "school": "McAdory Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192002166",
    },
    {
        "school": "Blue Springs Elementary School",
        "district": "Limestone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210002164",
    },
    {
        "school": "Buckhorn Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222002163",
    },
    {
        "school": "Dawes Intermediate School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237002168",
    },
    {
        "school": "Pike County Alternative Learning Center",
        "district": "Pike County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10279002155",
    },
    {
        "school": "Wedowee Elementary School",
        "district": "Randolph County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10282002171",
    },
    {
        "school": "Margaret Elementary",
        "district": "St Clair County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306202170",
    },
    {
        "school": "Sipsey Valley High School",
        "district": "Tuscaloosa County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339002153",
    },
    {
        "school": "Sipsey Valley Middle School",
        "district": "Tuscaloosa County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339002154",
    },
    {
        "school": "Dillingham Correspondence School",
        "district": "Dillingham City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20012000745",
    },
    {
        "school": "Birchtree Charter School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000744",
    },
    {
        "school": "CRUHSD Academy",
        "district": "Colorado River Union High School District (4381)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40008203225",
    },
    {
        "school": "American Leadership Academy Queen Creek K-12",
        "district": "American Leadership Academy Inc. (4348)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011203179",
    },
    {
        "school": "San Pedro Valley Online Academy",
        "district": "Benson Unified School District (79226)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40021203232",
    },
    {
        "school": "Student Choice High School",
        "district": "GAR LLC dba Student Choice High School (78997)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40027303184",
    },
    {
        "school": "Desert Willow Elementary School",
        "district": "Kingman Unified School District (79598)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029503234",
    },
    {
        "school": "E-Institute at Buckeye",
        "district": "E-Institute Charter Schools Inc. (79059)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40031103186",
    },
    {
        "school": "E-Institute at Taylion",
        "district": "E-Institute Charter Schools Inc. (79059)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40031103189",
    },
    {
        "school": "GIFT-Mt. Turnbull Academy",
        "district": "Gila Institute for Technology (79387)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034903218",
    },
    {
        "school": "GIFT-Morenci High School",
        "district": "Gila Institute for Technology (79387)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034903239",
    },
    {
        "school": "Tucson CHIC Preschool",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046303236",
    },
    {
        "school": "Phoenix CHIC - Morton Ave",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046303237",
    },
    {
        "school": "RSD High School",
        "district": "RSD Charter School Inc. (81033)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40065603223",
    },
    {
        "school": "Concordia Charter School- Navajo Mission",
        "district": "Concordia Charter School Inc. (89556)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40075103213",
    },
    {
        "school": "Pima County JTED at Indian Oasis",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203181",
    },
    {
        "school": "PCJTED - Rio Rico High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203192",
    },
    {
        "school": "Pima County JTED at Camino Seco",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203198",
    },
    {
        "school": "Pima County JTED at Empire",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203208",
    },
    {
        "school": "Pima County JTED at Santa Rita",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203212",
    },
    {
        "school": "Pima County JTED at Flowing Wells",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203227",
    },
    {
        "school": "WAVE - Mohave Community College Neal Campus",
        "district": "Western Arizona Vocational District #50 (90123)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40079403200",
    },
    {
        "school": "WAVE-Arizona Western College",
        "district": "Western Arizona Vocational District #50 (90123)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40079403215",
    },
    {
        "school": "WAVE- Lee Williams High School",
        "district": "Western Arizona Vocational District #50 (90123)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40079403217",
    },
    {
        "school": "Academy Del Sol - Hope",
        "district": "Academy Del Sol Inc. (90199)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079703230",
    },
    {
        "school": "The Odyssey Preparatory Academy",
        "district": "The Odyssey Preparatory Academy Inc. (90287)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40080003211",
    },
    {
        "school": "EdOptions HS Learning Center",
        "district": "Educational Options Foundation (90201)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40081603219",
    },
    {
        "school": "Academy Adventures Midtown",
        "district": "Ed Ahead (90506)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40081703191",
    },
    {
        "school": "BASIS Oro Valley",
        "district": "BASIS Charter Schools Inc. (90508)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40081803197",
    },
    {
        "school": "Great Hearts Academies - Anthem Prep",
        "district": "Anthem Preparatory Academy (90532)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40081903187",
    },
    {
        "school": "Northpoint Expeditionary Learning Academy",
        "district": "Compass Points International Inc (90533)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40082002672",
    },
    {
        "school": "Arizona Collegiate High School",
        "district": "Pima Prevention Partnership (90536)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40082103226",
    },
    {
        "school": "Sonoran Science Academy-Peoria",
        "district": "Daisy Education Corporation dba. Sonoran Science A (90541)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40082203221",
    },
    {
        "school": "Leading Edge Academy Maricopa",
        "district": "Leading Edge Academy Maricopa (90637)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40082403178",
    },
    {
        "school": "Jack Thoman Air and Space Academy and Performing Arts Studio",
        "district": "Lifelong Learning Research Institute Inc. (90754)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40082603207",
    },
    {
        "school": "Arizona Agribusiness & Equine Center - Estrella",
        "district": "Arizona Agribusiness & Equine Center Inc. (90779)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40082803199",
    },
    {
        "school": "BASIS Flagstaff",
        "district": "BASIS Charter Schools Inc. (90862)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40083103196",
    },
    {
        "school": "Early Childhood Learning Center",
        "district": "Casa Grande Elementary District (4446)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40171003201",
    },
    {
        "school": "Mountain View Preparatory School",
        "district": "Cottonwood-Oak Creek Elementary District (4487)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40237003241",
    },
    {
        "school": "Dysart iSchool",
        "district": "Dysart Unified District (4243)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269003193",
    },
    {
        "school": "Florence Virtual Academy",
        "district": "Florence Unified School District (4437)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292003195",
    },
    {
        "school": "Fountain.Hills Online",
        "district": "Fountain Hills Unified District (4247)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40304003240",
    },
    {
        "school": "Southwest Key Transitional Learning Center",
        "district": "Maricopa County Regional School District (4234)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40386003209",
    },
    {
        "school": "Alternative Middle School (Indian Oasis Middle School)",
        "district": "Baboquivari Unified School District #40 (4412)",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40395003210",
    },
    {
        "school": "Alternative High School (Indian Oasis High School)",
        "district": "Baboquivari Unified School District #40 (4412)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40395003222",
    },
    {
        "school": "Combs Traditional Academy",
        "district": "J O Combs Unified School District (4445)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40399003231",
    },
    {
        "school": "Mabel Padgett Elementary School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438003185",
    },
    {
        "school": "Franklin at Alma Elementary",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497003205",
    },
    {
        "school": "Summit Academy",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497003229",
    },
    {
        "school": "pvONLINE",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593003216",
    },
    {
        "school": "Walden Grove High School",
        "district": "Sahuarita Unified District (4411)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40730003183",
    },
    {
        "school": "University High School",
        "district": "Tolleson Union High School District (4288)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40852003206",
    },
    {
        "school": "Vail Innovation Center",
        "district": "Vail Unified District (4413)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885003214",
    },
    {
        "school": "EVIT - East Campus",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973103224",
    },
    {
        "school": "Red Rock Academy",
        "district": "Sedona-Oak Creek JUSD #9 (4467)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40973303188",
    },
    {
        "school": "NEWPORT ELEMENTARY SCHOOL",
        "district": "NEWPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002301517",
    },
    {
        "school": "FORREST PARK PREP PRESCHOOL",
        "district": "PINE BLUFF SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002601530",
    },
    {
        "school": "HACKLER INTERMEDIATE SCHOOL",
        "district": "MOUNTAIN HOME SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004301522",
    },
    {
        "school": "KIPP BLYTHEVILLE COLLEGE PREPARATORY SCHOOL",
        "district": "KIPP DELTA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006201526",
    },
    {
        "school": "TWO RIVERS HIGH SCHOOL",
        "district": "TWO RIVERS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007901521",
    },
    {
        "school": "WICKES ELEMENTARY SCHOOL",
        "district": "COSSATOT RIVER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040501157",
    },
    {
        "school": "VAN COVE ELEMENTARY SCHOOL",
        "district": "COSSATOT RIVER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040501226",
    },
    {
        "school": "MOUNTAIN SPRINGS ELEM SCHOOL",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375001518",
    },
    {
        "school": "EAST POINTE ELEMENTARY SCHOOL",
        "district": "GREENWOOD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50699001523",
    },
    {
        "school": "WEINER ELEMENTARY",
        "district": "HARRISBURG SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50735001141",
    },
    {
        "school": "LAKESIDE HIGH SCHOOL",
        "district": "LAKESIDE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50867001525",
    },
    {
        "school": "DON ROBERTS ELEMENTARY SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001528",
    },
    {
        "school": "DELIGHT ELEMENTARY SCHOOL",
        "district": "SOUTH PIKE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51032000226",
    },
    {
        "school": "OSCEOLA ELEMENTARY SCHOOL",
        "district": "OSCEOLA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51095001524",
    },
    {
        "school": "Mt. Lassen Charter",
        "district": "Fort Sage Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001112763",
    },
    {
        "school": "Phoenix Academy",
        "district": "Apple Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001712663",
    },
    {
        "school": "Lakeland Village",
        "district": "Lake Elsinore Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002712772",
    },
    {
        "school": "Westside Community Day Middle High",
        "district": "Dos Palos Oro Loma Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60003312656",
    },
    {
        "school": "Valley Children's Hospital",
        "district": "Golden Valley Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006812658",
    },
    {
        "school": "North County Regional Occupational Program",
        "district": "North County Regional Occupational Center/Program (ROC/P)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60134312546",
    },
    {
        "school": "Home Street Middle",
        "district": "Bishop Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60140900490",
    },
    {
        "school": "Bishop Union High",
        "district": "Bishop Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60140900491",
    },
    {
        "school": "Keith B. Bright High (Juvenile Hall)",
        "district": "Bishop Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60140904490",
    },
    {
        "school": "Bishop Elementary",
        "district": "Bishop Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60140909309",
    },
    {
        "school": "Palisade Glacier High (Continuation)",
        "district": "Bishop Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60140909310",
    },
    {
        "school": "Bishop Union Elementary Community Day",
        "district": "Bishop Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60140910805",
    },
    {
        "school": "Bishop Union Elementary Community Day II",
        "district": "Bishop Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60140912380",
    },
    {
        "school": "Bishop Independent Study",
        "district": "Bishop Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60140912412",
    },
    {
        "school": "American River Charter",
        "district": "Black Oak Mine Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60524012774",
    },
    {
        "school": "Cesar Chavez Junior High",
        "district": "Ceres Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813012670",
    },
    {
        "school": "Roger S. Oraze Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903012798",
    },
    {
        "school": "Century Academy",
        "district": "Conejo Valley Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60964012664",
    },
    {
        "school": "Mission Community Day",
        "district": "Corcoran Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60969012716",
    },
    {
        "school": "Dr. Augustine Ramirez Intermediate",
        "district": "Corona-Norco Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985012824",
    },
    {
        "school": "Dunham Charter",
        "district": "Dunham Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61161012748",
    },
    {
        "school": "Eastside Academy/Transitional Learning Center",
        "district": "Eastside Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61191012703",
    },
    {
        "school": "Imperial Valley Home School Academy",
        "district": "El Centro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203012660",
    },
    {
        "school": "H. Glenn Richardson",
        "district": "Fairfield-Suisun Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61336012633",
    },
    {
        "school": "Matt Garcia Career and College Academy",
        "district": "Fairfield-Suisun Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336012797",
    },
    {
        "school": "Morris E. Dailey Charter Elementary",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455012619",
    },
    {
        "school": "Cedarlane Academy",
        "district": "Hacienda la Puente Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632512808",
    },
    {
        "school": "Goldenrod Elementary",
        "district": "Kerman Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61949012756",
    },
    {
        "school": "Woodrow Wallace Middle",
        "district": "Kernville Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61959012638",
    },
    {
        "school": "Liberty Primary",
        "district": "Liberty Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62154012693",
    },
    {
        "school": "Reagan Elementary",
        "district": "Lindsay Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62187012687",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Lindsay Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62187012765",
    },
    {
        "school": "Kennedy Elementary",
        "district": "Lindsay Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62187012815",
    },
    {
        "school": "Walter J. Katnich Community Day",
        "district": "Lodi Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62223012737",
    },
    {
        "school": "Dr. Owen Lloyd Knox Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012627",
    },
    {
        "school": "Judith F. Baca Arts Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012632",
    },
    {
        "school": "E. Los Angeles Renaiss Acad at Esteban E. Torres High #2",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012657",
    },
    {
        "school": "Quincy Jones Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012667",
    },
    {
        "school": "Stanley Mosk Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012671",
    },
    {
        "school": "Estrella Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012674",
    },
    {
        "school": "Andres and Maria Cardenas Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012677",
    },
    {
        "school": "Dolores Huerta Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012688",
    },
    {
        "school": "Carlos Santana Arts Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012692",
    },
    {
        "school": "Humanitas Acad of Art and Tech at Esteban E. Torres High #4",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012711",
    },
    {
        "school": "Jaime Escalante Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012719",
    },
    {
        "school": "Soc Just Leadership Acad at Esteban E. Torres High #5",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012720",
    },
    {
        "school": "Carson-Gore Academy of Enviornmental Studies",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012721",
    },
    {
        "school": "Julie Korenstein Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012724",
    },
    {
        "school": "Vista del Valle Dual Language Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012764",
    },
    {
        "school": "Barack Obama Global Preparation Academy",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012771",
    },
    {
        "school": "Orchard Academies 2C",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012779",
    },
    {
        "school": "Wisdom Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012780",
    },
    {
        "school": "Esteban Torres East LA Performing Arts Magnet",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012787",
    },
    {
        "school": "Math Science & Technology Magnet Academy at Roosevelt High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012791",
    },
    {
        "school": "Alta California Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012806",
    },
    {
        "school": "Engr and Tech Acad at Esteban E. Torres High #3",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012819",
    },
    {
        "school": "Orchard Academies 2B",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012825",
    },
    {
        "school": "Mountain Vista Educational Center",
        "district": "Madera Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62334012739",
    },
    {
        "school": "Mountain Vista High",
        "district": "Madera Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62334012807",
    },
    {
        "school": "Maricopa Middle",
        "district": "Maricopa Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62382012615",
    },
    {
        "school": "Independent Study Program",
        "district": "Mountain View Whisman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628012629",
    },
    {
        "school": "MVWSD Home & Hospital",
        "district": "Mountain View Whisman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628012773",
    },
    {
        "school": "Painted Hills Middle",
        "district": "Palm Springs Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955012795",
    },
    {
        "school": "Paradise eLearning Academy",
        "district": "Paradise Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62982012676",
    },
    {
        "school": "Mission Elementary",
        "district": "Redlands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207012666",
    },
    {
        "school": "Roberts Ferry Charter School Academy",
        "district": "Roberts Ferry Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63321012712",
    },
    {
        "school": "San Francisco Public Montessori",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441012788",
    },
    {
        "school": "San Jacinto Leadership Academy - Magnet",
        "district": "San Jacinto Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444012794",
    },
    {
        "school": "PEEP - PREPARE",
        "district": "San Luis Coastal Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63480012730",
    },
    {
        "school": "Short Elementary",
        "district": "San Rafael City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63509012694",
    },
    {
        "school": "Willow Elementary",
        "district": "San Ysidro Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63522012612",
    },
    {
        "school": "Sequoia Elementary",
        "district": "Sanger Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63525012753",
    },
    {
        "school": "Bolsa Knolls Middle",
        "district": "Santa Rita Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63579012689",
    },
    {
        "school": "Shiloh Charter",
        "district": "Shiloh Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63666012799",
    },
    {
        "school": "Soledad Transition Center",
        "district": "Soledad Unified",
        "level": "Adult Education",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63705012813",
    },
    {
        "school": "Health Careers Academy",
        "district": "Stockton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801012644",
    },
    {
        "school": "Primary Years Academy",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801012698",
    },
    {
        "school": "Edgewood High",
        "district": "West Covina Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64200012621",
    },
    {
        "school": "Wheatland Community Day High",
        "district": "Wheatland Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64235012741",
    },
    {
        "school": "Science & Technology Academy at Knights Landing",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308012745",
    },
    {
        "school": "Charter Alternative Program (CAP)",
        "district": "El Dorado County Office of Education",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100612762",
    },
    {
        "school": "Rockey Glenn Camp",
        "district": "Los Angeles County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69107812637",
    },
    {
        "school": "Nidorf Barry J.",
        "district": "Los Angeles County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69107812665",
    },
    {
        "school": "Scott Joseph Camp",
        "district": "Los Angeles County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69107812680",
    },
    {
        "school": "Central Juvenile Hall",
        "district": "Los Angeles County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69107812696",
    },
    {
        "school": "Afflerbaugh-Paige Camp",
        "district": "Los Angeles County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69107812710",
    },
    {
        "school": "Kirby Dorothy Camp",
        "district": "Los Angeles County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69107812777",
    },
    {
        "school": "Road to Success Academy at Campus Kilpatrick",
        "district": "Los Angeles County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69107812802",
    },
    {
        "school": "Val Verde Academy",
        "district": "Val Verde Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69113512749",
    },
    {
        "school": "ALAMOSA ELEMENTARY SCHOOL",
        "district": "Alamosa School District No. Re-11J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80207006459",
    },
    {
        "school": "VISTA PEAK 9-12 PREPARATORY",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006451",
    },
    {
        "school": "VISTA PEAK P-8 EXPLORATORY",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006483",
    },
    {
        "school": "BOULDER UNIVERSAL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249006463",
    },
    {
        "school": "FOUNDATIONS ACADEMY",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006465",
    },
    {
        "school": "EAGLE RIDGE ACADEMY",
        "district": "School District 27J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006474",
    },
    {
        "school": "PINE RIDGE ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006452",
    },
    {
        "school": "ACADEMY FOR ADVANCED AND CREATIVE LEARNING",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80306006456",
    },
    {
        "school": "DSST: GREEN VALLEY RANCH HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006450",
    },
    {
        "school": "Denver Green School Southeast",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006453",
    },
    {
        "school": "STRIVE PREP - SUNNYSIDE",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006457",
    },
    {
        "school": "GIRLS ATHLETIC LEADERSHIP SCHOOL MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006473",
    },
    {
        "school": "CENTER FOR TALENT DEVELOPMENT AT GREENLEE",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006477",
    },
    {
        "school": "STRIVE PREP - LAKE",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006479",
    },
    {
        "school": "DENVER LANGUAGE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006482",
    },
    {
        "school": "SOAR AT GREEN VALLEY RANCH",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006486",
    },
    {
        "school": "LAKE MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006490",
    },
    {
        "school": "SUMMIT ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006491",
    },
    {
        "school": "SKYVIEW ACADEMY",
        "district": "Douglas County School District No. Re 1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006455",
    },
    {
        "school": "SAGE CANYON ELEMENTARY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006472",
    },
    {
        "school": "SPRINGS STUDIO FOR ACADEMIC EXCELLENCE",
        "district": "El Paso County Colorado School District 49",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387006462",
    },
    {
        "school": "WEIKEL ELEMENTARY SCHOOL",
        "district": "Fountain School District No. 8 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80408006481",
    },
    {
        "school": "LINCOLN PARK PRESCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435006471",
    },
    {
        "school": "CAREER CENTER PRESCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435006487",
    },
    {
        "school": "JEFFERSON JUNIOR/SENIOR HIGH",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80441006461",
    },
    {
        "school": "MAPLEWOOD ELEMENTARY SCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441006469",
    },
    {
        "school": "TWO ROADS CHARTER SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006466",
    },
    {
        "school": "ARVADA K-8",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006489",
    },
    {
        "school": "LA JUNTA JR/SR HIGH SCHOOL",
        "district": "East Otero School District No. R1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80513006484",
    },
    {
        "school": "COLORADO CONNECTIONS ACADEMY",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555006488",
    },
    {
        "school": "YAMPA VALLEY HIGH SCHOOL",
        "district": "Steamboat Springs School District No. Re 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80666001924",
    },
    {
        "school": "SNOWY PEAKS JUNIOR/SENIOR HIGH SCHOOL",
        "district": "Summit School District No. Re 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80681006464",
    },
    {
        "school": "STEM LAB",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690006468",
    },
    {
        "school": "IVER C. RANUM MIDDLE SCHOOL",
        "district": "Westminster Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723006458",
    },
    {
        "school": "RANGE VIEW ELEMENTARY",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735006460",
    },
    {
        "school": "Interdistrict Discovery Magnet School",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045001590",
    },
    {
        "school": "Academy of Science and Innovation",
        "district": "Capitol Region Education Council",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001592",
    },
    {
        "school": "Derby Middle School",
        "district": "DERBY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90111001578",
    },
    {
        "school": "Renzulli Gifted and Talented Academy",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001582",
    },
    {
        "school": "Brennan Rogers School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001585",
    },
    {
        "school": "Connecticut River Academy",
        "district": "LEARN",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90345001581",
    },
    {
        "school": "Perry Hill Elementary School",
        "district": "SHELTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90405001584",
    },
    {
        "school": "Great Neck Elementary School",
        "district": "WATERFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90486001593",
    },
    {
        "school": "Gateway Lab School",
        "district": "Gateway Lab School",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100005200346",
    },
    {
        "school": "Old State Elementary School",
        "district": "Appoquinimink School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000347",
    },
    {
        "school": "Spring Meadow Early Childhood Center",
        "district": "Appoquinimink School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000348",
    },
    {
        "school": "KIPP DC - Grow Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100432",
    },
    {
        "school": "E.L. Haynes PCS - HS",
        "district": "E.L. Haynes PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004300433",
    },
    {
        "school": "Eagle Academy PCS - Fairlawn",
        "district": "Eagle Academy PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004900434",
    },
    {
        "school": "AppleTree Early Learning Center PCS - Oklahoma Avenue",
        "district": "AppleTree Early Learning PCS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110005400435",
    },
    {
        "school": "Early Childhood Academy PCS",
        "district": "Early Childhood Academy PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110005700431",
    },
    {
        "school": "Inspired Teaching Demonstration PCS",
        "district": "Inspired Teaching Demonstration PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110008000437",
    },
    {
        "school": "Shining Stars Montessori Academy PCS",
        "district": "Shining Stars Montessori Academy PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110008100442",
    },
    {
        "school": "Richard Wright PCS for Journalism and Media Arts",
        "district": "Richard Wright PCS for Journalism and Media Arts",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110008200441",
    },
    {
        "school": "BASIS DC PCS",
        "district": "Basis DC PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110008300443",
    },
    {
        "school": "Creative Minds International PCS",
        "district": "Creative Minds International PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110008400440",
    },
    {
        "school": "DC Scholars PCS",
        "district": "DC Scholars PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110008500438",
    },
    {
        "school": "Mundo Verde Bilingual PCS",
        "district": "Mundo Verde Bilingual PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110008600444",
    },
    {
        "school": "BAKER COUNTY VIRTUAL FRANCHISE",
        "district": "BAKER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120006007873",
    },
    {
        "school": "NORTH BAY HAVEN CHARTER ACADEMY MIDDLE SCHOOL",
        "district": "BAY",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009007791",
    },
    {
        "school": "BAY VIRTUAL FRANCHISE",
        "district": "BAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009007830",
    },
    {
        "school": "NORTH BAY HAVEN CHARTER ACADEMY ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009007896",
    },
    {
        "school": "NORTH BAY HAVEN CAREER ACADEMY",
        "district": "BAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009007903",
    },
    {
        "school": "BRADFORD VIRTUAL FRANCHISE",
        "district": "BRADFORD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120012007861",
    },
    {
        "school": "SOMERSET PREPARATORY ACADEMY CHARTER SCHOOL AT NORTH LAUDERD",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007780",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT CORAL SPRINGS",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007781",
    },
    {
        "school": "SOMERSET ACADEMY VILLAGE CHARTER MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007806",
    },
    {
        "school": "FRANKLIN ACADEMY PEMBROKE PINES",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007807",
    },
    {
        "school": "SOMERSET PREPARATORY CHARTER MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007832",
    },
    {
        "school": "SOMERSET VILLAGE ACADEMY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007837",
    },
    {
        "school": "BEACHSIDE MONTESSORI VILLAGE",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007843",
    },
    {
        "school": "BEN GAMLA CHARTER SCHOOL NORTH CAMPUS",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007858",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT PLANTATION",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007874",
    },
    {
        "school": "IMAGINE SCHOOLS AT BROWARD",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007881",
    },
    {
        "school": "SOMERSET PINES ACADEMY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007893",
    },
    {
        "school": "FRANKLIN ACADEMY SUNRISE",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007900",
    },
    {
        "school": "ANDREWS HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018007904",
    },
    {
        "school": "SOMERSET PREPARATORY ACADEMY CHARTER HIGH AT NORTH LAUDERDAL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007912",
    },
    {
        "school": "SUNRISE HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018007917",
    },
    {
        "school": "SOMERSET ACADEMY CHARTER HIGH SCHOOL MIRAMAR CAMPUS",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007921",
    },
    {
        "school": "CHARLOTTE VIRTUAL FRANCHISE",
        "district": "CHARLOTTE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024007805",
    },
    {
        "school": "CLAY VIRTUAL FRANCHISE",
        "district": "CLAY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030007840",
    },
    {
        "school": "COLUMBIA VIRTUAL FRANCHISE",
        "district": "COLUMBIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036007788",
    },
    {
        "school": "PREK ESE",
        "district": "COLUMBIA",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120036007857",
    },
    {
        "school": "SECONDARY STUDENT SUCCESS CENTER 803",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007783",
    },
    {
        "school": "PALM GLADES PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007797",
    },
    {
        "school": "INTERNATIONAL STUDIES PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007811",
    },
    {
        "school": "PINECREST COVE ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007815",
    },
    {
        "school": "HIS HOUSE",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007820",
    },
    {
        "school": "SECONDARY STUDENT SUCCESS CENTER 802",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007828",
    },
    {
        "school": "ACADEMY FOR INTERNATIONAL EDUCATION CHARTER SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007841",
    },
    {
        "school": "SPORTS LEADERSHIP OF MIAMI CHARTER HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007845",
    },
    {
        "school": "SOMERSET OAKS ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007851",
    },
    {
        "school": "I PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007855",
    },
    {
        "school": "BRIDGEPREP ACADEMY OF GREATER MIAMI",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007864",
    },
    {
        "school": "SECONDARY STUDENT SUCCESS CENTER 801",
        "district": "MIAMI-DADE",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007871",
    },
    {
        "school": "SOMERSET ACADEMY SILVER PALMS AT PRINCETON",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007884",
    },
    {
        "school": "DORAL ACADEMY OF TECHNOLOGY",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007892",
    },
    {
        "school": "ADVANTAGE ACADEMY OF MATH AND SCIENCE AT WATERSTONE",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007897",
    },
    {
        "school": "DORAL INTERNATIONAL ACADEMY OF MATH AND SCIENCE",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007911",
    },
    {
        "school": "PINECREST ACADEMY (NORTH CAMPUS)",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007916",
    },
    {
        "school": "MATER ACADEMY MIAMI BEACH",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007922",
    },
    {
        "school": "MEDICAL ACADEMY FOR SCIENCE AND TECHNOLOGY (M.A.S.T.) @ HOME",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007923",
    },
    {
        "school": "BRIDGEPREP ACADEMY SOUTH",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007932",
    },
    {
        "school": "MATER GROVE ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007935",
    },
    {
        "school": "DIXIE VIRTUAL FRANCHISE",
        "district": "DIXIE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120045007816",
    },
    {
        "school": "KINDER CUB SCHOOL INC",
        "district": "DIXIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120045007863",
    },
    {
        "school": "LONE STAR HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048007825",
    },
    {
        "school": "RIVER CITY SCIENCE ELEMENTARY ACADEMY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007826",
    },
    {
        "school": "DUVAL VIRTUAL ACADEMY FRANCHISE",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007860",
    },
    {
        "school": "KIPP VOICE / KIPP IMPACT K-8",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007894",
    },
    {
        "school": "SOMERSET ACADEMY-MIDDLE EAGLE CAMPUS",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007902",
    },
    {
        "school": "SOMERSET ACADEMY-ELEMENTARY EAGLE CAMPUS",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007908",
    },
    {
        "school": "DUVAL CHARTER SCHOLARS ACADEMY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048007909",
    },
    {
        "school": "FRANKLIN VIRTUAL INSTRUCTION PROGRAM",
        "district": "FRANKLIN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120057007934",
    },
    {
        "school": "GILCHRIST VIRTUAL FRANCHISE",
        "district": "GILCHRIST",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120063007927",
    },
    {
        "school": "GLADES VIRTUAL FRANCHISE",
        "district": "GLADES",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120066007834",
    },
    {
        "school": "TEEN PARENT PROGRAM PK",
        "district": "HAMILTON",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120072007790",
    },
    {
        "school": "HAMILTON VIRTUAL FRANCHISE",
        "district": "HAMILTON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120072007905",
    },
    {
        "school": "HARDEE VIRTUAL FRANCHISE",
        "district": "HARDEE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120075007802",
    },
    {
        "school": "HERNANDO COUNTY JAIL",
        "district": "HERNANDO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120081007829",
    },
    {
        "school": "HERNANDO ESCHOOL VIRTUAL FRANCHISE",
        "district": "HERNANDO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081007842",
    },
    {
        "school": "NON-ENROLLED PK EXCEPTIONAL ED PROGRAM",
        "district": "HIGHLANDS",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120084007787",
    },
    {
        "school": "HIGHLANDS VIRTUAL FRANCHISE",
        "district": "HIGHLANDS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084007859",
    },
    {
        "school": "HIGHLANDS COUNTY HOSPITAL/HOMEBOUND PROGRAM",
        "district": "HIGHLANDS",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120084007879",
    },
    {
        "school": "HIGHLANDS COUNTY SCHOOLS JAIL PROGRAM",
        "district": "HIGHLANDS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120084007885",
    },
    {
        "school": "FERRELL MIDDLE MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007782",
    },
    {
        "school": "FRANKLIN MIDDLE MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007794",
    },
    {
        "school": "HILLSBOROUGH ESE CONTRACTED RESIDENTIAL PLACEMENT",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087007836",
    },
    {
        "school": "CHANNELSIDE ACADEMY OF MATH AND SCIENCE",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007854",
    },
    {
        "school": "WOODMONT CHARTER SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087007862",
    },
    {
        "school": "GRADUATION ASSISTANCE PROGRAM",
        "district": "HOLMES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120090007853",
    },
    {
        "school": "DIST WIDE GIFTED PROGRAM",
        "district": "JACKSON",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120096007913",
    },
    {
        "school": "JEFFERSON VIRTUAL INSTRUCTION PROGRAM",
        "district": "JEFFERSON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120099007878",
    },
    {
        "school": "LAFAYETTE VIRTUAL FRANCHISE",
        "district": "LAFAYETTE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120102007808",
    },
    {
        "school": "LAKE VIRTUAL FRANCHISE",
        "district": "LAKE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105007880",
    },
    {
        "school": "NON SCHOOL PK",
        "district": "LAKE",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120105007924",
    },
    {
        "school": "LEE COUNTY VIRTUAL FRANCHISE",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007800",
    },
    {
        "school": "FLORIDA SOUTHWESTERN COLLEGIATE HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108007882",
    },
    {
        "school": "LEON COUNTY VIRTUAL SCHOOL FRANCHISE",
        "district": "LEON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111007793",
    },
    {
        "school": "SUCCESS ACADEMY AT GHAZVINI LEARNING CENTER",
        "district": "LEON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111007831",
    },
    {
        "school": "LEVY VIRTUAL FRANCHISE",
        "district": "LEVY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114007817",
    },
    {
        "school": "MADISON TAP PROGRAM",
        "district": "MADISON",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120120007821",
    },
    {
        "school": "PALMETTO CHARTER SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123007772",
    },
    {
        "school": "STATE COLLEGE OF FLORIDA COLLEGIATE SCHOOL",
        "district": "MANATEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123007901",
    },
    {
        "school": "MARION OAKS ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126007823",
    },
    {
        "school": "MONROE VIRTUAL FRANCHISE",
        "district": "MONROE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132007839",
    },
    {
        "school": "INNOVATIONS MIDDLE CHARTER",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144007785",
    },
    {
        "school": "CORNERSTONE ACADEMY CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007801",
    },
    {
        "school": "CORNERSTONE CHARTER ACADEMY HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007822",
    },
    {
        "school": "OCVS VIRTUAL FRANCHISE",
        "district": "ORANGE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007846",
    },
    {
        "school": "CENTRAL FLORIDA LEADERSHIP ACADEMY CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007869",
    },
    {
        "school": "PINECREST PREPARATORY CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007931",
    },
    {
        "school": "EAST LAKE ELEMENTARY SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147007895",
    },
    {
        "school": "EVERGLADES ELEMENTARY",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150007925",
    },
    {
        "school": "PINELLAS TELESCHOOL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156007852",
    },
    {
        "school": "PINELLAS COUNTY JAIL",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156007889",
    },
    {
        "school": "PLATO ACADEMY LARGO CHARTER SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156007910",
    },
    {
        "school": "PLATO ACADEMY PALM HARBOR CHARTER SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156007919",
    },
    {
        "school": "TRANSITION SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120159007835",
    },
    {
        "school": "NEW BEGINNINGS HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159007899",
    },
    {
        "school": "POLK PRE-COLLEGIATE ACADEMY",
        "district": "POLK",
        "level": "Secondary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159007906",
    },
    {
        "school": "PUTNAM VIRTUAL FRANCHISE",
        "district": "PUTNAM",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162007838",
    },
    {
        "school": "ST. JOHNS COMMUNITY CAMPUS",
        "district": "ST. JOHNS",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120174007833",
    },
    {
        "school": "COMMUNITY BASE SERVICE STUDENTS",
        "district": "SUWANNEE",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120183007849",
    },
    {
        "school": "TAYLOR COUNTY JAIL SERVICES",
        "district": "TAYLOR",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120186007844",
    },
    {
        "school": "UNION VIRTUAL FRANCHISE",
        "district": "UNION",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120189007804",
    },
    {
        "school": "ESE RELATED SERVICES",
        "district": "VOLUSIA",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120192007775",
    },
    {
        "school": "CITRUS GROVE ELEMENTARY SCHOOL",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192007786",
    },
    {
        "school": "IVY HAWN CHARTER SCHOOL OF THE ARTS",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192007795",
    },
    {
        "school": "WALTON COUNTY JAIL PROGRAM",
        "district": "WALTON",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120198007918",
    },
    {
        "school": "Aaron Cohn Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130002603806",
    },
    {
        "school": "Atkinson County Middle School",
        "district": "Atkinson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130009003996",
    },
    {
        "school": "Corretta Scott King Womens' Leadership Academy",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003980",
    },
    {
        "school": "KIPP VISION",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012003992",
    },
    {
        "school": "Kindezi",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004012",
    },
    {
        "school": "Fulton Leadership Academy",
        "district": "Commission Charter Schools- Fulton Leadership Academy",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130021703961",
    },
    {
        "school": "Pataula Charter Academy",
        "district": "Commission Charter Schools- Pataula Charter Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130021803964",
    },
    {
        "school": "Atlanta Heights Charter School",
        "district": "Commission Charter Schools- Atlanta Heights Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130022104021",
    },
    {
        "school": "Coweta Charter Academy",
        "district": "Commission Charter Schools- Coweta Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130022204007",
    },
    {
        "school": "Providence Elementary School",
        "district": "Carroll County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130084003982",
    },
    {
        "school": "Bethune Middle School",
        "district": "Charlton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130099004016",
    },
    {
        "school": "Godley Station School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102003972",
    },
    {
        "school": "Shuman Elementary School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102003975",
    },
    {
        "school": "Islands High School",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102003978",
    },
    {
        "school": "River Ridge High School",
        "district": "Cherokee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111004019",
    },
    {
        "school": "Eddie White Middle School",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123004022",
    },
    {
        "school": "Riverview Elementary School",
        "district": "Dawson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130165004005",
    },
    {
        "school": "Leadership Preparatory Academy",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174004006",
    },
    {
        "school": "Echols County Elementary/Middle School",
        "district": "Echols County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130195003976",
    },
    {
        "school": "Main Street Charter Academy",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228003990",
    },
    {
        "school": "Feldwood Elementary School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004002",
    },
    {
        "school": "Roberts Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003965",
    },
    {
        "school": "Burnette Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003979",
    },
    {
        "school": "Ferguson Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003989",
    },
    {
        "school": "New Life Academy of Excellence",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003991",
    },
    {
        "school": "Grace Snell Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003993",
    },
    {
        "school": "Lanier High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255003998",
    },
    {
        "school": "Anderson-Livsey Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004003",
    },
    {
        "school": "Jenkins Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004004",
    },
    {
        "school": "Veterans High School",
        "district": "Houston County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288003969",
    },
    {
        "school": "Turner Woods Elementary School",
        "district": "Jones County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130315004018",
    },
    {
        "school": "WC Abney Elementary",
        "district": "Paulding County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402003986",
    },
    {
        "school": "Midway Elementary School",
        "district": "Pierce County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130414003994",
    },
    {
        "school": "Youngs Grove Elementary School",
        "district": "Polk County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130420004001",
    },
    {
        "school": "CALDER SCHOOL",
        "district": "AVERY ELEMENTARY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160015001010",
    },
    {
        "school": "BLACKFOOT CHARTER COMMUNITY",
        "district": "BLACKFOOT CHARTER COMMUNITY LEARNING CENTER INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160015300796",
    },
    {
        "school": "MONTICELLO MONTESSORI CHARTER SCHOOL",
        "district": "MONTICELLO MONTESSORI CHARTER SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160015401014",
    },
    {
        "school": "ANOTHER CHOICE VIRTUAL CHARTER",
        "district": "ANOTHER CHOICE VIRTUAL CHARTER SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160015501008",
    },
    {
        "school": "SAGE INTERNATIONAL SCHOOL OF BOISE",
        "district": "THE SAGE INTERNATIONAL SCHOOL OF BOISE A PUBLIC CHARTER SCH",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160015601007",
    },
    {
        "school": "THE VILLAGE CHARTER SCHOOL",
        "district": "THE VILLAGE CHARTER SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160015701018",
    },
    {
        "school": "LEGACY CHARTER SCHOOL",
        "district": "LEGACY PUBLIC CHARTER SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160015801019",
    },
    {
        "school": "HERITAGE ACADEMY",
        "district": "HERITAGE ACADEMY INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160015901017",
    },
    {
        "school": "NORTH IDAHO STEM CHARTER ACADEMY",
        "district": "NORTH IDAHO STEM CHARTER ACADEMY INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160016001020",
    },
    {
        "school": "HERITAGE COMMUNITY CHARTER",
        "district": "HERITAGE COMMUNITY CHARTER SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160016101021",
    },
    {
        "school": "RIVERVUE MIDDLE SCHOOL",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160060001016",
    },
    {
        "school": "MOUNTAIN VALLEY ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093001015",
    },
    {
        "school": "PAYETTE RIVER TECHNICAL ACADEMY",
        "district": "EMMETT INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160102001009",
    },
    {
        "school": "RIVERVIEW ELEMENTARY SCHOOL",
        "district": "SHELLEY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160291001012",
    },
    {
        "school": "Transition Center",
        "district": "Spec Educ Dist Lake County/Sedol",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005906153",
    },
    {
        "school": "SEAPCO Academy",
        "district": "Spec Educ Assoc of Peoria County",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022506134",
    },
    {
        "school": "Bi-County Sp Ed Preschool Program",
        "district": "Bi-County Special Educ Coop",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706115",
    },
    {
        "school": "Central Intermediate School",
        "district": "Monmouth-Roseville CUSD 238",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170032006128",
    },
    {
        "school": "Southland College Prep Chtr HS",
        "district": "Southland College Prep Chtr HS",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170140006135",
    },
    {
        "school": "North Mac Elementary",
        "district": "North Mac CUSD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170140306109",
    },
    {
        "school": "North Mac Intermediate",
        "district": "North Mac CUSD 34",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170140306141",
    },
    {
        "school": "North Mac High School",
        "district": "North Mac CUSD 34",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170140306148",
    },
    {
        "school": "IHSCA Charter High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006103",
    },
    {
        "school": "West Ridge Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006108",
    },
    {
        "school": "Azuela Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006131",
    },
    {
        "school": "Urban Prep Chtr  Bronzeville HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006132",
    },
    {
        "school": "Solorio Academy High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006138",
    },
    {
        "school": "Garcia Lorca Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006139",
    },
    {
        "school": "Rowe Elementary",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006142",
    },
    {
        "school": "Camras Elem School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006149",
    },
    {
        "school": "Eagleview Elementary School",
        "district": "Columbia CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171074006140",
    },
    {
        "school": "Crosby Elem Sch",
        "district": "Harvard CUSD 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171842006116",
    },
    {
        "school": "Hawthorn Sch of Dual Language",
        "district": "Hawthorn CCSD 73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171857006114",
    },
    {
        "school": "William E Young School",
        "district": "Homer CCSD 33C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171950006105",
    },
    {
        "school": "Minooka Primary Center",
        "district": "Minooka CCSD 201",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172631006117",
    },
    {
        "school": "Ann Reid Early Childhood Center",
        "district": "Naperville CUSD 203",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172771006106",
    },
    {
        "school": "Brigham Elementary",
        "district": "McLean County USD 5",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862006104",
    },
    {
        "school": "Benjamin Elem School",
        "district": "McLean County USD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862006130",
    },
    {
        "school": "Quest Charter School Academy",
        "district": "Peoria SD 150",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123006112",
    },
    {
        "school": "Glen Hill Primary",
        "district": "Queen Bee SD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173297006136",
    },
    {
        "school": "Pheasant Ridge Primary School",
        "district": "Queen Bee SD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173297006137",
    },
    {
        "school": "Horace Mann ELC",
        "district": "Rock Island SD 41",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441006107",
    },
    {
        "school": "RICMS",
        "district": "Rock Island SD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173441006155",
    },
    {
        "school": "Jackson Charter School",
        "district": "Rockford SD 205",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451006154",
    },
    {
        "school": "Gardner Elementary School",
        "district": "Waterloo CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174107006144",
    },
    {
        "school": "Hammond Academy of Science & Tech",
        "district": "Hammond Academy of Science & Tech",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180008202466",
    },
    {
        "school": "Paramount Brookside",
        "district": "Paramount Brookside",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180008602478",
    },
    {
        "school": "Discovery Charter School",
        "district": "Discovery Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180008802495",
    },
    {
        "school": "Excel Center For Adult Learners",
        "district": "Excel Center for Adult Learners",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180009302475",
    },
    {
        "school": "IN Math & Science Academy - North",
        "district": "IN Math & Science Academy - North",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180009402487",
    },
    {
        "school": "Indiana Connections Academy",
        "district": "Indiana Connections Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180009802474",
    },
    {
        "school": "Rock Creek Community Academy",
        "district": "Rock Creek Community Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180009902497",
    },
    {
        "school": "Highland Middle School",
        "district": "Anderson Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180015002483",
    },
    {
        "school": "River Birch Elementary School",
        "district": "Avon Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180027002480",
    },
    {
        "school": "CSA Fodrea Campus",
        "district": "Bartholomew Con School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036002492",
    },
    {
        "school": "The Acad of Sci & Entrepreneurship",
        "district": "Monroe County Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063002467",
    },
    {
        "school": "Concord Intermediate School",
        "district": "Concord Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180240002484",
    },
    {
        "school": "Decatur Twp School for Excellence",
        "district": "M S D Decatur Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180264002463",
    },
    {
        "school": "Boone Meadow",
        "district": "Zionsville Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180283002481",
    },
    {
        "school": "Eastbrook South Elementary",
        "district": "Eastbrook Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180303002473",
    },
    {
        "school": "Eastbrook North Elementary",
        "district": "Eastbrook Community Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180303002489",
    },
    {
        "school": "Academy for Innovative Studies",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345002462",
    },
    {
        "school": "New Tech Institute",
        "district": "Evansville Vanderburgh School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345002464",
    },
    {
        "school": "Culver Family Learning Center",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345002491",
    },
    {
        "school": "Greenfield Central Junior High Sch",
        "district": "Greenfield-Central Com Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180405002476",
    },
    {
        "school": "CA Early Learning Center",
        "district": "New Albany-Floyd Co Con Sch",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180741002472",
    },
    {
        "school": "Pittsboro Primary School",
        "district": "North West Hendricks Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180810002465",
    },
    {
        "school": "Rushville Elementary School East",
        "district": "Rush County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180975002471",
    },
    {
        "school": "Rushville Elementary School West",
        "district": "Rush County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180975002485",
    },
    {
        "school": "Especially Kidz Health & Rehab Cnt",
        "district": "Shelbyville Central Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181014002496",
    },
    {
        "school": "South Ripley Junior High School",
        "district": "South Ripley Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181053002482",
    },
    {
        "school": "Claypool Elementary School",
        "district": "Warsaw Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181242002468",
    },
    {
        "school": "Bondurant - Farrar Middle School",
        "district": "Bondurant-Farrar Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190507002125",
    },
    {
        "school": "Galva-Holstein Upper Elementary",
        "district": "Galva-Holstein Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191223002122",
    },
    {
        "school": "Graettinger-Terril Middle School",
        "district": "Graettinger-Terril Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191281002118",
    },
    {
        "school": "Graettinger-Terril Elementary School",
        "district": "Graettinger-Terril Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191281002120",
    },
    {
        "school": "Buford Garner Elementary",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470002133",
    },
    {
        "school": "West Elementary",
        "district": "Knoxville Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191584002114",
    },
    {
        "school": "Northstar Elementary School",
        "district": "Knoxville Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191584002132",
    },
    {
        "school": "Lincoln Intermediate",
        "district": "Mason City Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191878002115",
    },
    {
        "school": "Thomas Jefferson Elementary School",
        "district": "Newton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192061002123",
    },
    {
        "school": "Schaller-Crestland Ridge View Middle School",
        "district": "Schaller-Crestland Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192538002121",
    },
    {
        "school": "Spring Creek - 6th Grade",
        "district": "Southeast Polk Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192682002134",
    },
    {
        "school": "Expo Alternative Learning Center",
        "district": "Waterloo Comm School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IA",
        "nces_id": "193048002126",
    },
    {
        "school": "South Middle School",
        "district": "Waukee Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051002116",
    },
    {
        "school": "Shuler Elementary School",
        "district": "Waukee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051002130",
    },
    {
        "school": "Doniphan West JR/SR High School",
        "district": "Doniphan West Schools",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200034801941",
    },
    {
        "school": "Wilson Elementary School",
        "district": "Central Plains",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200034901988",
    },
    {
        "school": "Wilson Junior/Senior High School",
        "district": "Central Plains",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200034902022",
    },
    {
        "school": "Sabetha Elementary School",
        "district": "Prairie Hills",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035001978",
    },
    {
        "school": "Wetmore High",
        "district": "Prairie Hills",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035001991",
    },
    {
        "school": "Sabetha High School",
        "district": "Prairie Hills",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035001996",
    },
    {
        "school": "Axtell High",
        "district": "Prairie Hills",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035002016",
    },
    {
        "school": "Sabetha Middle School",
        "district": "Prairie Hills",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035002026",
    },
    {
        "school": "Wetmore Elementary",
        "district": "Prairie Hills",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035002027",
    },
    {
        "school": "Riverside Middle School",
        "district": "Riverside",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035101983",
    },
    {
        "school": "Riverside Primary School",
        "district": "Riverside",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035101987",
    },
    {
        "school": "Riverside Intermediate",
        "district": "Riverside",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035102005",
    },
    {
        "school": "Riverside High School",
        "district": "Riverside",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035102032",
    },
    {
        "school": "Baldwin Elementary Primary Center",
        "district": "Baldwin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200372001989",
    },
    {
        "school": "Baldwin Elementary Intermediate Center",
        "district": "Baldwin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200372002015",
    },
    {
        "school": "Burlington Middle School 5 - 8",
        "district": "Burlington",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200429001994",
    },
    {
        "school": "Burlington Elementary School",
        "district": "Burlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200429002001",
    },
    {
        "school": "Chase County Elementary School",
        "district": "Chase County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200525002014",
    },
    {
        "school": "Chase County Junior Senior High School",
        "district": "Chase County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200525002024",
    },
    {
        "school": "Belmont Elementary School",
        "district": "De Soto",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200549002021",
    },
    {
        "school": "Kansas Connections Academy",
        "district": "Elkhart",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200579001973",
    },
    {
        "school": "Point Rock Alternative",
        "district": "Elkhart",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KS",
        "nces_id": "200579002003",
    },
    {
        "school": "Apollo Elementary School",
        "district": "Goddard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200654002020",
    },
    {
        "school": "West Elk Schools",
        "district": "West Elk",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200750002013",
    },
    {
        "school": "Norwich Middle School",
        "district": "Kingman - Norwich",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200807001969",
    },
    {
        "school": "Kingman Elementary School",
        "district": "Kingman - Norwich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200807001974",
    },
    {
        "school": "Norwich Elementary School",
        "district": "Kingman - Norwich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200807001985",
    },
    {
        "school": "Kingman Middle School",
        "district": "Kingman - Norwich",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200807001993",
    },
    {
        "school": "Fairfield Schools",
        "district": "Fairfield",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200831002025",
    },
    {
        "school": "Henry Leavenworth",
        "district": "Leavenworth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200843001968",
    },
    {
        "school": "Earl Lawson Elementary",
        "district": "Leavenworth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200843001979",
    },
    {
        "school": "Anthony Elementary",
        "district": "Leavenworth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200843001997",
    },
    {
        "school": "Richard Warren Middle School",
        "district": "Leavenworth",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200843002030",
    },
    {
        "school": "David Brewer Elementary",
        "district": "Leavenworth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200843002036",
    },
    {
        "school": "Centre",
        "district": "Centre",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200894002012",
    },
    {
        "school": "Jefferson West Elementary School",
        "district": "Jefferson West",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200951002023",
    },
    {
        "school": "Chisholm Middle School",
        "district": "Newton",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200996001975",
    },
    {
        "school": "Slate Creek Elementary",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200996001982",
    },
    {
        "school": "Northridge Elementary",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200996002002",
    },
    {
        "school": "Santa Fe 5/6 Center",
        "district": "Newton",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200996002006",
    },
    {
        "school": "Sunset Elementary",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200996002010",
    },
    {
        "school": "Walton Rural Life Center",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200996002031",
    },
    {
        "school": "South Breeze Elementary",
        "district": "Newton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200996002037",
    },
    {
        "school": "Mission Trail Middle School",
        "district": "Olathe",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014001971",
    },
    {
        "school": "Lincoln School",
        "district": "Parsons",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201056001980",
    },
    {
        "school": "Guthridge School",
        "district": "Parsons",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201056001986",
    },
    {
        "school": "Garfield School",
        "district": "Parsons",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201056001998",
    },
    {
        "school": "St. Marks School",
        "district": "Renwick",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201108002034",
    },
    {
        "school": "Pawnee Heights",
        "district": "Pawnee Heights",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201128002033",
    },
    {
        "school": "Blue Valley Southwest High School",
        "district": "Blue Valley",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200001990",
    },
    {
        "school": "Sylvan-Lucas Unified Jr. sr",
        "district": "Sylvan Grove",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201212001976",
    },
    {
        "school": "Lucas/Sylvan Elementary Unified",
        "district": "Sylvan Grove",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201212002008",
    },
    {
        "school": "Circle Greenwich Elementary",
        "district": "Circle",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201230002017",
    },
    {
        "school": "Victoria Junior-Senior High School",
        "district": "Victoria",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201260001999",
    },
    {
        "school": "Victoria Elementary",
        "district": "Victoria",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201260002018",
    },
    {
        "school": "Wichita Learning Center",
        "district": "Wichita",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299002009",
    },
    {
        "school": "Thornwilde Elementary School",
        "district": "Boone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051002290",
    },
    {
        "school": "Crossroads Elementary",
        "district": "Bullitt County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210075002286",
    },
    {
        "school": "Carroll Co Childhood Development Center",
        "district": "Carroll County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210099002293",
    },
    {
        "school": "Carter Virtual Academy",
        "district": "Carter County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210102002294",
    },
    {
        "school": "Homebound Secondary",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002272",
    },
    {
        "school": "Homebound Elementary",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002281",
    },
    {
        "school": "HOME INSTRUCTION ELEMENTARY",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195002276",
    },
    {
        "school": "HOME INSTRUCTION H.S.",
        "district": "Floyd County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195002284",
    },
    {
        "school": "North Park Elementary School",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210249002297",
    },
    {
        "school": "Hopkins County Schools Academy",
        "district": "Hopkins County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210286002280",
    },
    {
        "school": "Flaherty Primary School",
        "district": "Meade County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210405002295",
    },
    {
        "school": "Mercer County Intermediate School",
        "district": "Mercer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210411002273",
    },
    {
        "school": "Mercer Central",
        "district": "Mercer County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210411002285",
    },
    {
        "school": "Valley Elementary School",
        "district": "Pike County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210480002296",
    },
    {
        "school": "Elkhorn Crossing School",
        "district": "Scott County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210526002301",
    },
    {
        "school": "South Warren High School",
        "district": "Warren County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573002277",
    },
    {
        "school": "South Warren Middle School",
        "district": "Warren County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573002298",
    },
    {
        "school": "Louisiana School for the Visually Impaired",
        "district": "LA Schools for the Deaf and Visually Impaired",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220001800193",
    },
    {
        "school": "Zachary Early Learning Center",
        "district": "Zachary Community School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003902299",
    },
    {
        "school": "Howard School",
        "district": "Howard School",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015101195",
    },
    {
        "school": "International High School of New Orleans",
        "district": "Voices for International Business & Education",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015602270",
    },
    {
        "school": "Elm Grove Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027002310",
    },
    {
        "school": "Mentorship STEAM Academy",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002311",
    },
    {
        "school": "Inspire Charter Academy (Natl. Heritage Acad.)",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002316",
    },
    {
        "school": "Airline Park Academy for Advanced Studies",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002298",
    },
    {
        "school": "JCFA",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002305",
    },
    {
        "school": "David Thibodaux STEM Magnet Academy",
        "district": "Lafayette Parish",
        "level": "High",
        "type": "Career and Technical School",
        "state": "LA",
        "nces_id": "220087002301",
    },
    {
        "school": "Lincoln Parish Early Childhood Center",
        "district": "Lincoln Parish",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220099002304",
    },
    {
        "school": "Juban Parc Junior High School",
        "district": "Livingston Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102002312",
    },
    {
        "school": "Juban Parc Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102002313",
    },
    {
        "school": "South Fork Elementary School",
        "district": "Livingston Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102002315",
    },
    {
        "school": "Andrew Jackson Middle School",
        "district": "St. Bernard Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141002296",
    },
    {
        "school": "Arabi Elementary School",
        "district": "St. Bernard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141002302",
    },
    {
        "school": "Chalmette Elementary School",
        "district": "St. Bernard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141002306",
    },
    {
        "school": "Ashland District School",
        "district": "RSU 32/MSAD 32",
        "level": "Other",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231128023125",
    },
    {
        "school": "Buxton Center Elementary School",
        "district": "RSU 06/MSAD 06",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231179023123",
    },
    {
        "school": "Oak Hill Middle School",
        "district": "RSU 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478323122",
    },
    {
        "school": "Carrie Ricker School",
        "district": "RSU 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478323124",
    },
    {
        "school": "Rangeley Lakes Regional School",
        "district": "RSU 78",
        "level": "Other",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480300291",
    },
    {
        "school": "Tunbridge Public Charter School",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001689",
    },
    {
        "school": "City Neighbors High",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001690",
    },
    {
        "school": "Green Street Academy",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001691",
    },
    {
        "school": "Vanguard Collegiate Middle",
        "district": "Baltimore City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001693",
    },
    {
        "school": "West Towson Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001696",
    },
    {
        "school": "Crossroads Middle School",
        "district": "Carroll County Public Schools",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240021001694",
    },
    {
        "school": "Oakdale High",
        "district": "Frederick County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001688",
    },
    {
        "school": "Galena Elementary School",
        "district": "Kent County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240045001695",
    },
    {
        "school": "Barack Obama Elementary",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001697",
    },
    {
        "school": "Alma del Mar Charter School",
        "district": "Alma del Mar Charter School (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250052502708",
    },
    {
        "school": "Boston Green Academy Horace Mann Charter School",
        "district": "Boston Green Academy Horace Mann Charter School (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250052602703",
    },
    {
        "school": "Bridge Boston Charter School",
        "district": "Bridge Boston Charter School (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250052702710",
    },
    {
        "school": "UP Academy Charter School of Boston",
        "district": "UP Academy Charter School of Boston (District)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250053302713",
    },
    {
        "school": "Andrew B. Cushman School",
        "district": "Dartmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250402002698",
    },
    {
        "school": "Gardner Academy for Learning and Technology",
        "district": "Gardner",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250513002692",
    },
    {
        "school": "Provincetown Schools",
        "district": "Provincetown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250984002694",
    },
    {
        "school": "Mulcahey Elementary School",
        "district": "Taunton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251152002697",
    },
    {
        "school": "Naquag Elementary School",
        "district": "Wachusett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188002693",
    },
    {
        "school": "Michigan Reformatory",
        "district": "Michigan Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260000108154",
    },
    {
        "school": "Richfield Public School Academy K1",
        "district": "Richfield Public School Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260028608067",
    },
    {
        "school": "Madison Academy  High School",
        "district": "Madison Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260031708195",
    },
    {
        "school": "University Preparatory Science and Math PSAD High School",
        "district": "University Preparatory Science and Math (PSAD)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095208134",
    },
    {
        "school": "Hawthorn Center",
        "district": "Michigan Department of Community Health",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260096008066",
    },
    {
        "school": "Caro Center",
        "district": "Michigan Department of Community Health",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260096008126",
    },
    {
        "school": "Kalamazoo Psychiatric Hospital",
        "district": "Michigan Department of Community Health",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260096008136",
    },
    {
        "school": "Michigan Connections Academy",
        "district": "Michigan Connections Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260096908139",
    },
    {
        "school": "Leelanau Montessori Public School Academy",
        "district": "Leelanau Montessori Public School Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260097008196",
    },
    {
        "school": "University Yes Academy",
        "district": "University Yes Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260097108194",
    },
    {
        "school": "Michigan Virtual Charter Academy",
        "district": "Michigan Virtual Charter Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260097208180",
    },
    {
        "school": "Global Heights Academy",
        "district": "Global Heights Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260097308141",
    },
    {
        "school": "Detroit Leadership Academy Elementary",
        "district": "Detroit Leadership Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260097408187",
    },
    {
        "school": "West Michigan Aviation Academy",
        "district": "West Michigan Aviation Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260097708183",
    },
    {
        "school": "Legacy Charter Academy",
        "district": "Legacy Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260097908133",
    },
    {
        "school": "DeTour Arts and Technology Academy",
        "district": "DeTour Arts and Technology Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260098008109",
    },
    {
        "school": "Wellspring Preparatory High School",
        "district": "Wellspring Preparatory High School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260098108149",
    },
    {
        "school": "Meadows School",
        "district": "Avondale School District",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260369008205",
    },
    {
        "school": "Benzie Academy",
        "district": "Benzie County Central Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260495008155",
    },
    {
        "school": "Berrien Springs Virtual Academy",
        "district": "Berrien Springs Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008175",
    },
    {
        "school": "Miller",
        "district": "Brighton Area Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260687008101",
    },
    {
        "school": "Britton Deerfield SchoolsBritton Building",
        "district": "Britton Deerfield Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260693008119",
    },
    {
        "school": "Britton Deerfield SchoolDeerfield Building",
        "district": "Britton Deerfield Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260693008128",
    },
    {
        "school": "Centreville Adult Education",
        "district": "Centreville Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260867008068",
    },
    {
        "school": "Dearborn Heights Virtual Academy",
        "district": "Dearborn Heights School District #7",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261161008179",
    },
    {
        "school": "Douglas Elementary 34 Campus",
        "district": "Garden City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261554008161",
    },
    {
        "school": "Farmington 56 Campus",
        "district": "Garden City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261554008168",
    },
    {
        "school": "Memorial Elementary 12 Campus",
        "district": "Garden City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261554008200",
    },
    {
        "school": "Engadine Schools",
        "district": "Engadine Consolidated Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261560008159",
    },
    {
        "school": "Career Development School",
        "district": "Grand Haven Area Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261638008122",
    },
    {
        "school": "CW Neff Early Childhood and Kindergarten Center",
        "district": "Grand Ledge Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261641008124",
    },
    {
        "school": "Kenneth T Beagle Elementary School",
        "district": "Grand Ledge Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261641008188",
    },
    {
        "school": "Pioneer Tech High School",
        "district": "Hamilton Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261740008148",
    },
    {
        "school": "Huron AI Center FRCS Simpson Program",
        "district": "Huron School District",
        "level": "Middle",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261893007983",
    },
    {
        "school": "Apollo Center",
        "district": "Huron Valley Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261899007843",
    },
    {
        "school": "Pine Rest  Kentwood Public Schools",
        "district": "Kentwood Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262034008091",
    },
    {
        "school": "Ingham County Youth Center",
        "district": "Lansing Public School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262115008185",
    },
    {
        "school": "Zemmer Campus 89",
        "district": "Lapeer Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262118008121",
    },
    {
        "school": "Ingham Virtual High School",
        "district": "Leslie Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262145008189",
    },
    {
        "school": "Montague Area Childhood Center",
        "district": "Montague Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262418008170",
    },
    {
        "school": "Oak Park Alternative Education Center",
        "district": "Oak Park School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262619008174",
    },
    {
        "school": "NOVA Discipline Academy",
        "district": "Oak Park School District of the City of",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262619008212",
    },
    {
        "school": "Oxford Bridges High School",
        "district": "Oxford Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262724008184",
    },
    {
        "school": "Bethune Adult Education",
        "district": "Pontiac City School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262874008163",
    },
    {
        "school": "Beech Elementary",
        "district": "Redford Union Schools District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262946008208",
    },
    {
        "school": "Stuckey Center",
        "district": "Redford Union Schools District No. 1",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262946008210",
    },
    {
        "school": "Great Start Readiness Program",
        "district": "Reed City Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262949007918",
    },
    {
        "school": "CB Sabbath 68 Preparatory Academy",
        "district": "River Rouge School District of the City of",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262976008160",
    },
    {
        "school": "Romulus Adult Education",
        "district": "Romulus Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263012008080",
    },
    {
        "school": "Young Adult Program",
        "district": "Saline Area Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263066008201",
    },
    {
        "school": "Sault Area Career Center",
        "district": "Sault Ste. Marie Area Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "263099008098",
    },
    {
        "school": "Alice M Birney K8 School",
        "district": "Southfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263231008151",
    },
    {
        "school": "Thompson K8 International Academy",
        "district": "Southfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263231008202",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "Van Dyke Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263468008162",
    },
    {
        "school": "Warren Woods Education Center",
        "district": "Warren Woods Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "263522008138",
    },
    {
        "school": "West Bloomfield Transition Center",
        "district": "West Bloomfield School District",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263582008153",
    },
    {
        "school": "Jackson ISD Local Based Special Education Programs",
        "district": "Jackson ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268058008130",
    },
    {
        "school": "WoodsEdge Learning Center",
        "district": "Kalamazoo RESA",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268060008117",
    },
    {
        "school": "JCCLISD Academy  A Regional Middle College",
        "district": "Lenawee ISD",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268068008144",
    },
    {
        "school": "Early Childhood",
        "district": "West Shore Educational Service District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268075508182",
    },
    {
        "school": "Oakland Opportunity Academy",
        "district": "Oakland Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268088008169",
    },
    {
        "school": "Washtenaw International High School",
        "district": "Washtenaw ISD",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268099008147",
    },
    {
        "school": "Washtenaw Alliance for Virtual Education",
        "district": "Washtenaw ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "268099008165",
    },
    {
        "school": "W-ALT-IS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504416",
    },
    {
        "school": "TREK PROGRAM",
        "district": "MEEKER AND WRIGHT SPECIAL EDUCATION",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004504402",
    },
    {
        "school": "WIN-High School",
        "district": "MID STATE EDUCATION DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007304436",
    },
    {
        "school": "HLWW ALTERNATIVE LEARNING PROGRAM",
        "district": "HOWARD LAKE-WAVERLY-WINSTED",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270012304414",
    },
    {
        "school": "AURORA MIDDLE SCHOOL",
        "district": "AURORA CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270022004420",
    },
    {
        "school": "Stride Academy K-7 Charter School",
        "district": "STRIDE ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270025204405",
    },
    {
        "school": "EAGLE RIDGE ACADEMY LOWER SCHOOL",
        "district": "EAGLE RIDGE ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036404423",
    },
    {
        "school": "THE WILLOWS",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270226404404",
    },
    {
        "school": "916 MAHTOMEDI ACADEMY",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270226404430",
    },
    {
        "school": "Champlin/Brooklyn Pk Acd MathEnvSci",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318004406",
    },
    {
        "school": "MOVING FORWARD",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270741004425",
    },
    {
        "school": "112 ALC Independent Study",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270819004415",
    },
    {
        "school": "GRAND MARAIS COMMUNITY",
        "district": "COOK COUNTY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271311004413",
    },
    {
        "school": "LE SUEUR-HENDERSON MIDDLE SCHOOL",
        "district": "LE SUEUR-HENDERSON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271807004408",
    },
    {
        "school": "PHOENIX ACADEMY",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272385004401",
    },
    {
        "school": "Owatonna Summer School 6-8",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272805004400",
    },
    {
        "school": "WASHINGTON TECH SECONDARY MAGNET",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384004429",
    },
    {
        "school": "WASECA MIDDLE LEVEL ALC",
        "district": "WASECA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274188004403",
    },
    {
        "school": "HUGO ELEMENTARY",
        "district": "WHITE BEAR LAKE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274236004409",
    },
    {
        "school": "ABERDEEN ELEMENTARY SCHOOL",
        "district": "ABERDEEN SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280036001372",
    },
    {
        "school": "AMITE COUNTY ELEMENTARY",
        "district": "AMITE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280042001375",
    },
    {
        "school": "WAVELAND ELEMENTARY SCHOOL",
        "district": "BAY ST LOUIS WAVELAND SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280057001376",
    },
    {
        "school": "COLUMBUS MIDDLE SCHOOL",
        "district": "COLUMBUS MUNICIPAL SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280120001380",
    },
    {
        "school": "CORINTH ELEMENTARY SCHOOL",
        "district": "CORINTH SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280126001368",
    },
    {
        "school": "DESOTO CENTRAL PRIMARY",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001369",
    },
    {
        "school": "LEWISBURG PRIMARY",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280132001373",
    },
    {
        "school": "BATES ELEMENTARY SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219001364",
    },
    {
        "school": "KIRKSEY MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219001365",
    },
    {
        "school": "CARDOZO MIDDLE SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219001370",
    },
    {
        "school": "LAUREL UPPER ELEMENTARY",
        "district": "LAUREL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280246001374",
    },
    {
        "school": "ALTERNATIVE LEARNING SCHOOL",
        "district": "MARSHALL CO SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280285001379",
    },
    {
        "school": "MET DAY TREATMENT CENTER",
        "district": "DIVISION OF YOUTH SERVICE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000903153",
    },
    {
        "school": "GUADALUPE CENTERS MIDDLE",
        "district": "GUADALUPE CENTERS SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002903166",
    },
    {
        "school": "GATEWAY SCIENCE ACAD/ST LOUIS",
        "district": "GATEWAY SCIENCE ACAD/ST LOUIS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059203174",
    },
    {
        "school": "DeLaSalle Charter High School",
        "district": "DELASALLE CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059303176",
    },
    {
        "school": "CARONDELET LEADERSHIP ACADEMY",
        "district": "CARONDELET LEADERSHIP ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059403172",
    },
    {
        "school": "ALPHA HART LEWIS",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100003152",
    },
    {
        "school": "CLINTON INTERMEDIATE SCHOOL",
        "district": "CLINTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290986003145",
    },
    {
        "school": "ANTONIA MIDDLE SCHOOL",
        "district": "FOX C-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291230003151",
    },
    {
        "school": "GRAIN VALLEY NORTH MIDDLE SCHL",
        "district": "GRAIN VALLEY R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291308003161",
    },
    {
        "school": "GRAIN VALLEY EARLY CHILDHD CTR",
        "district": "GRAIN VALLEY R-V",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291308003169",
    },
    {
        "school": "RUSKIN HIGH SCHOOL",
        "district": "HICKMAN MILLS C-1",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434003156",
    },
    {
        "school": "SMITH-HALE MIDDLE",
        "district": "HICKMAN MILLS C-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434003162",
    },
    {
        "school": "HOLLISTER EARLY CHILDHOOD CTR",
        "district": "HOLLISTER R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291455003165",
    },
    {
        "school": "SUNSHINE CENTER",
        "district": "INDEPENDENCE 30",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548003157",
    },
    {
        "school": "LOCKWOOD SPECL. EDUC. COOP.",
        "district": "LAMAR R-I",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "291785001487",
    },
    {
        "school": "LIBERTY NORTH HIGH SCHOOL",
        "district": "LIBERTY 53",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854003148",
    },
    {
        "school": "Discovery Elementary",
        "district": "ORCHARD FARM R-V",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292316003177",
    },
    {
        "school": "PRICE ELEMENTARY",
        "district": "REPUBLIC R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292622003160",
    },
    {
        "school": "MCCULLOCH ELEMENTARY",
        "district": "REPUBLIC R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292622003171",
    },
    {
        "school": "LYON ELEMENTARY",
        "district": "REPUBLIC R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292622003173",
    },
    {
        "school": "SCHOFIELD ELEMENTARY",
        "district": "REPUBLIC R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292622003175",
    },
    {
        "school": "HIRAM NEUWOEHNER",
        "district": "SPECL. SCH. DST. ST. LOUIS CO.",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292676003154",
    },
    {
        "school": "SOUTHVIEW HIGH",
        "district": "SPECL. SCH. DST. ST. LOUIS CO.",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292676003168",
    },
    {
        "school": "SENECA INTERMEDIATE SCHOOL",
        "district": "SENECA R-VII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292790003164",
    },
    {
        "school": "LAKEVIEW ELEMENTARY",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165003149",
    },
    {
        "school": "DISCOVERY RIDGE ELEMENTARY",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165003155",
    },
    {
        "school": "Dodson School",
        "district": "Dodson K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300912000260",
    },
    {
        "school": "Dodson 7-8",
        "district": "Dodson K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300912001028",
    },
    {
        "school": "SUCCESS ACADEMY",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310001602235",
    },
    {
        "school": "SUPERIOR ELEMENTARY SCHOOL",
        "district": "SUPERIOR PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310002902244",
    },
    {
        "school": "CLAY CO LEARNING CENTER - FAIRFIELD",
        "district": "SOUTH CENTRAL NEBRASKA UNIFIED 5",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012200199",
    },
    {
        "school": "LAWRENCE EARLY LEARNING CENTER",
        "district": "SOUTH CENTRAL NEBRASKA UNIFIED 5",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012200698",
    },
    {
        "school": "AINSWORTH LITTLE PAWS PRESCHOOL",
        "district": "AINSWORTH COMMUNITY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310279002242",
    },
    {
        "school": "LITTLE LEARNERS  PRESCHOOL",
        "district": "AUBURN PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310333002237",
    },
    {
        "school": "WEST DODGE STATION ELEMENTARY",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011002239",
    },
    {
        "school": "ELKHORN SOUTH HIGH SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011002240",
    },
    {
        "school": "ELKHORN VALLEY VIEW MIDDLE SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011002245",
    },
    {
        "school": "MINATARE PRE-START PRE-SCHOOL",
        "district": "MINATARE PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317380002236",
    },
    {
        "school": "MIDDLE SCHOOL AT SYRACUSE",
        "district": "SYRACUSE-DUNBAR-AVOCA SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317755002238",
    },
    {
        "school": "Shirley & Bill Wallin Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000804",
    },
    {
        "school": "Ruby Duncan Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000805",
    },
    {
        "school": "Vincent L Triggs Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000806",
    },
    {
        "school": "Juvenile Detention 3-5",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000807",
    },
    {
        "school": "West Career & Technical Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000812",
    },
    {
        "school": "Northwest Career & Techincal Academy Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000814",
    },
    {
        "school": "Evelyn Stuckey Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000816",
    },
    {
        "school": "Silverland Middle School",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320030000810",
    },
    {
        "school": "Hawthorne Elementary School",
        "district": "MINERAL COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320033000811",
    },
    {
        "school": "Martha F Gleason Special Services Center 45-15",
        "district": "CARSON CITY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320039000803",
    },
    {
        "school": "Lyndeborough Central School",
        "district": "Wilton-Lyndeboro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330711500237",
    },
    {
        "school": "Florence Rideout Elementary School",
        "district": "Wilton-Lyndeboro School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330711500456",
    },
    {
        "school": "UMDNJ - CTR",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008503089",
    },
    {
        "school": "YOUTHBUILD CAMDEN",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008903134",
    },
    {
        "school": "Benjamin Banneker Preparatory Charter School",
        "district": "Benjamin Banneker Preparatory Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340074403139",
    },
    {
        "school": "Passaic Arts and Science Charter School",
        "district": "Passaic Arts and Science Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340074503137",
    },
    {
        "school": "Thomas Edison EnergySmart Charter School",
        "district": "Thomas Edison EnergySmart Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340074603143",
    },
    {
        "school": "John P. Holland Charter School",
        "district": "John P Holland Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340074803144",
    },
    {
        "school": "Cedar Creek High School",
        "district": "Greater Egg Harbor Regional High School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340606003115",
    },
    {
        "school": "Infinity Institute",
        "district": "Jersey City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783003121",
    },
    {
        "school": "UPLIFT Academy",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "341134003117",
    },
    {
        "school": "School Of Information Technology",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003101",
    },
    {
        "school": "School Of Culinary Arts Hospitality and Tourism",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003103",
    },
    {
        "school": "School of Government and Public Administration",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003105",
    },
    {
        "school": "School of Health Science",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003107",
    },
    {
        "school": "School of Earth and Space Science",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003109",
    },
    {
        "school": "Alternative High School",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "341269003111",
    },
    {
        "school": "Elmer Elementary School",
        "district": "Pittsgrove Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341311003113",
    },
    {
        "school": "Roselle Preschool",
        "district": "ROSELLE PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341428003147",
    },
    {
        "school": "Martin Luther King Jr. Elementary School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003123",
    },
    {
        "school": "Stonebridge Middle School",
        "district": "Upper Freehold Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341656003098",
    },
    {
        "school": "NEX GEN ACADEMY",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001075",
    },
    {
        "school": "NM SCHOOL FOR THE ARTS",
        "district": "NM SCHOOL FOR ARTS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350011901058",
    },
    {
        "school": "SOUTH VALLEY PREP",
        "district": "SOUTH VALLEY PREP",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012101076",
    },
    {
        "school": "ABQ SCHOOL OF EXCELLENCE",
        "district": "ABQ SCHOOL OF EXCELLENCE",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012201071",
    },
    {
        "school": "ABQ SIGN LANGUAGE ACADEMY",
        "district": "ABQ SIGN LANGUAGE ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012301066",
    },
    {
        "school": "TIERRA ADENTRO",
        "district": "TIERRA ADENTRO",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012401068",
    },
    {
        "school": "THE MASTERS PROGRAM",
        "district": "THE MASTERS PROGRAM",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012501069",
    },
    {
        "school": "THE ASK ACADEMY",
        "district": "THE ASK ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012601070",
    },
    {
        "school": "TAOS INTEGRATED SCHOOL OF ARTS",
        "district": "TAOS INTEGRATED SCHOOL OF THE ARTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350012701060",
    },
    {
        "school": "ALBUQUERQUE INSTITUTE OF MATH & SCIENCE",
        "district": "ALBUQUERQUE INSTITUTE OF MATH & SCIENCE",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350013000921",
    },
    {
        "school": "AMY BIEHL CHARTER HIGH SCHOOL",
        "district": "AMY BIEHL CHARTER HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350013100810",
    },
    {
        "school": "LA PROMESA EARLY LEARNING",
        "district": "LA PROMESA EARLY LEARNING",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350013400923",
    },
    {
        "school": "MONTESSORI ELEMENTARY SCHOOL",
        "district": "MONTESSORI ELEMENTARY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350013500929",
    },
    {
        "school": "SOUTHWEST PREPARATORY LEARNING CENTER",
        "district": "SOUTHWEST PREPARATORY LEARNING CENTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350013600927",
    },
    {
        "school": "SOUTHWEST SECONDARY LEARNING CENTER",
        "district": "SOUTHWEST SECONDARY LEARNING CENTER",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350013700819",
    },
    {
        "school": "ALDO LEOPOLD CHARTER",
        "district": "ALDO LEOPOLD CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350013800938",
    },
    {
        "school": "J PAUL TAYLOR ACADEMY",
        "district": "J PAUL TAYLOR ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350014101057",
    },
    {
        "school": "GADSDEN ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108001065",
    },
    {
        "school": "HEIZER MIDDLE SCHOOL",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126001067",
    },
    {
        "school": "MONTE VISTA ELEMENTARY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150001062",
    },
    {
        "school": "MESA MIDDLE",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150001063",
    },
    {
        "school": "EARLY COLLEGE HIGH SCHOOL",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150001064",
    },
    {
        "school": "LINDSEY-STEINER ELEMENTARY",
        "district": "PORTALES MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350210001073",
    },
    {
        "school": "ASPEN COMMUNITY SCHOOL",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237001059",
    },
    {
        "school": "AMY BIEHL COMMUNITY SCHOOL AT RANCHO VIEJO",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237001061",
    },
    {
        "school": "URBAN ASSEMBLY NEW YORK HARBOR SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007705560",
    },
    {
        "school": "MANHATTAN ACADEMY FOR ARTS AND LANGUAGES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706178",
    },
    {
        "school": "INTERNATIONAL HIGH SCHOOL AT UNION SQUARE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706191",
    },
    {
        "school": "HUDSON HIGH SCHOOL OF LEARNING TECHNOLOGIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706193",
    },
    {
        "school": "MURRAY HILL ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706207",
    },
    {
        "school": "EAST SIDE ELEMENTRAY SCHOOL-PS 267",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706210",
    },
    {
        "school": "FRANK MCCOURT HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007806185",
    },
    {
        "school": "PS 452",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007806187",
    },
    {
        "school": "UNIVERSITY HEIGHTS SECONDARY SCHOOL-BRONX COMMUNITY COLLEGE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008400749",
    },
    {
        "school": "BRONX LEADERSHIP ACADEMY II HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008405189",
    },
    {
        "school": "BRONX HAVEN HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008406056",
    },
    {
        "school": "BRONX BRIDGES HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506221",
    },
    {
        "school": "PS/MS 498 VAN NEST ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806217",
    },
    {
        "school": "ARTURO A SCHOMBURG SATELLITE ACADEMY BRONX",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006218",
    },
    {
        "school": "FORT GREEN PREPARATORY ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009106205",
    },
    {
        "school": "BROOKLYN HIGH SCHOOL FOR LAW AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009404079",
    },
    {
        "school": "PS 770 NEW AMERICAN ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009506176",
    },
    {
        "school": "HELEN M MARSHALL SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806179",
    },
    {
        "school": "ACE ACADEMY FOR SCHOLARS AT THE GERALDINE FERRARO CAMPUS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806223",
    },
    {
        "school": "HILLSIDE ARTS & LETTERS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006174",
    },
    {
        "school": "QUEENS SATELLITE HIGH SCHOOL FOR OPPORTUNITY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006182",
    },
    {
        "school": "METROPOLITAN EXPEDITIONARY LEARNING SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006188",
    },
    {
        "school": "QUEENS METROPOLITAN HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006209",
    },
    {
        "school": "HIGH SCHOOL FOR COMMUNITY LEADERSHIP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006213",
    },
    {
        "school": "EAGLE ACADEMY FOR YOUNG MEN III",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010106190",
    },
    {
        "school": "CAMBRIA HEIGHTS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010106220",
    },
    {
        "school": "PS 280",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010206186",
    },
    {
        "school": "PS 74 FUTURE LEADERS ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306184",
    },
    {
        "school": "MOTT HALL BRIDGES ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012106175",
    },
    {
        "school": "ROCKAWAY PARK HIGH SCHOOL FOR ENVIRONMENTAL SUSTAINABILITY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306194",
    },
    {
        "school": "PS 273",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306195",
    },
    {
        "school": "SCHOOL OF MATH SCIENCE AND HEALTHY LIVING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015106196",
    },
    {
        "school": "PS 748 BROOKLYN SCHOOL FOR GLOBAL SCHOLARS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015106197",
    },
    {
        "school": "PS 264 BAY RIDGE ELEMENTARY SCHOOL FOR THE ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015106198",
    },
    {
        "school": "SCHOOL FOR FUTURE LEADERS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015106199",
    },
    {
        "school": "ALBANY LEADERSHIP CHARTER HIGH SCHOOL FOR GIRLS",
        "district": "ALBANY LEADERSHIP CHARTER HIGH SCHOOL FOR GIRLS",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360100606202",
    },
    {
        "school": "UNIVERSITY PREPARATORY CHARTER SCHOOL FOR YOUNG MEN",
        "district": "UNIVERSITY PREPARATORY CHARTER SCHOOL FOR YOUNG MEN",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360100806204",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 5",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360100906212",
    },
    {
        "school": "DEMOCRACY PREP HARLEM CHARTER SCHOOL",
        "district": "DEMOCRACY PREP HARLEM CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360101006183",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-BRONX 1",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-BRONX 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360101106211",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-BRONX 2",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-BRONX 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360101206219",
    },
    {
        "school": "CULTURAL ARTS ACADEMY CHARTER SCHOOL AT SPRING CREEK",
        "district": "CULTURAL ARTS ACADEMY CHARTER SCHOOL AT SPRING CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360101406171",
    },
    {
        "school": "BROOKLYN DREAMS CHARTER SCHOOL",
        "district": "BROOKLYN DREAMS CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360101506206",
    },
    {
        "school": "LEADERSHIP PREPARATORY BROWNSVILLE CHARTER SCHOOL",
        "district": "LEADERSHIP PREPARATORY BROWNSVILLE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360101606201",
    },
    {
        "school": "BUSHWICK ASCEND CHARTER SCHOOL",
        "district": "BUSHWICK ASCEND CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360101706172",
    },
    {
        "school": "CHALLENGE PREPARATORY CHARTER SCHOOL",
        "district": "CHALLENGE PREPARATORY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360101806192",
    },
    {
        "school": "NEW WORLD PREPARATORY CHARTER SCHOOL",
        "district": "NEW WORLD PREPARATORY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360101906215",
    },
    {
        "school": "HEALTH SCIENCES CHARTER SCHOOL",
        "district": "HEALTH SCIENCES CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360102206239",
    },
    {
        "school": "NEW YORK FRENCH-AMERICAN CHARTER SCHOOL",
        "district": "NEW YORK FRENCH-AMERICAN CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360102306232",
    },
    {
        "school": "INWOOD ACADEMY FOR LEADERSHIP CHARTER SCHOOL",
        "district": "INWOOD ACADEMY FOR LEADERSHIP CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360102406241",
    },
    {
        "school": "METROPOLITAN LIGHTHOUSE CHARTER SCHOOL",
        "district": "METROPOLITAN LIGHTHOUSE CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360102506233",
    },
    {
        "school": "DR RICHARD IZQUIERDO HEALTH AND SCIENCE CHARTER SCHOOL",
        "district": "DR RICHARD IZQUIERDO HEALTH AND SCIENCE CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360102706234",
    },
    {
        "school": "ACHIEVEMENT FIRST APOLLO CHARTER SCHOOL",
        "district": "ACHIEVEMENT FIRST APOLLO CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360102806237",
    },
    {
        "school": "BEDFORD STUYVESANT NEW BEGINNINGS CHARTER SCHOOL",
        "district": "BEDFORD STUYVESANT NEW BEGINNINGS CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360102906236",
    },
    {
        "school": "HYDE LEADERSHIP CHARTER SCHOOL - BROOKLYN",
        "district": "HYDE LEADERSHIP CHARTER SCHOOL - BROOKLYN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360103006230",
    },
    {
        "school": "IMAGINE ME LEADERSHIP CHARTER SCHOOL",
        "district": "IMAGINE ME LEADERSHIP CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360103106238",
    },
    {
        "school": "OCEAN HILL COLLEGIATE CHARTER SCHOOL",
        "district": "OCEAN HILL COLLEGIATE CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360103206229",
    },
    {
        "school": "BROOKLYN EAST COLLEGIATE CHARTER SCHOOL",
        "district": "BROOKLYN EAST COLLEGIATE CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360103306240",
    },
    {
        "school": "ROCHDALE EARLY ADVANTAGE CHARTER SCHOOL",
        "district": "ROCHDALE EARLY ADVANTAGE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360103406224",
    },
    {
        "school": "RIVERTON STREET CHARTER SCHOOL",
        "district": "RIVERTON STREET CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360103506226",
    },
    {
        "school": "RENAISSANCE CHARTER HIGH SCHOOL FOR INNOVATION",
        "district": "RENAISSANCE CHARTER HIGH SCHOOL FOR INNOVATION",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360103606225",
    },
    {
        "school": "ROCHESTER EARLY COLLEGE INTERNATIONAL HIGH SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475006177",
    },
    {
        "school": "VANGUARD COLLEGIATE HIGH SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475006180",
    },
    {
        "school": "INTEGRATED ARTS AND TECHNOLOGY HIGH SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475006208",
    },
    {
        "school": "EDISON CAREER AND TECHNOLOGY HIGH SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475006216",
    },
    {
        "school": "Cumberland International Early College",
        "district": "Cumberland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001103228",
    },
    {
        "school": "Lakeforest Elementary",
        "district": "Pitt County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001203189",
    },
    {
        "school": "Global Scholars Academy",
        "district": "Global Scholars Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370031603198",
    },
    {
        "school": "Mountain Island Charter School",
        "district": "Mountain Island Charter",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370031703184",
    },
    {
        "school": "Lake Lure Classical Academy",
        "district": "Lake Lure Classical Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370031803187",
    },
    {
        "school": "Henderson Collegiate",
        "district": "Henderson Collegiate",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370031903193",
    },
    {
        "school": "Koontz Intermediate",
        "district": "Buncombe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045003190",
    },
    {
        "school": "Eblen Intermediate",
        "district": "Buncombe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045003191",
    },
    {
        "school": "Harold E. Winkler Middle",
        "district": "Cabarrus County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053003188",
    },
    {
        "school": "Margaret B. Pollard Middle",
        "district": "Chatham County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075003178",
    },
    {
        "school": "Sandy Ridge Elementary",
        "district": "Durham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126003185",
    },
    {
        "school": "Lakewood Montessori Middle",
        "district": "Durham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126003195",
    },
    {
        "school": "Atkins Academic & Tech High",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150003176",
    },
    {
        "school": "Kingswood School",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370150003183",
    },
    {
        "school": "Walkertown High",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150003194",
    },
    {
        "school": "Frank Morgan Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150003196",
    },
    {
        "school": "Gaston Early College High School",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162003217",
    },
    {
        "school": "Tar River Elementary",
        "district": "Granville County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180003227",
    },
    {
        "school": "Haynes Inman Education Center",
        "district": "Guilford County Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370192003197",
    },
    {
        "school": "UNCG Early/Middle College",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192003233",
    },
    {
        "school": "Career Academy and Technical School",
        "district": "Iredell-Statesville Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231003206",
    },
    {
        "school": "Cleveland High",
        "district": "Johnston County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237003215",
    },
    {
        "school": "Corinth Holders High",
        "district": "Johnston County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237003225",
    },
    {
        "school": "Warren Williams Elementary Alternative",
        "district": "Lee County Schools",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370256003182",
    },
    {
        "school": "Mountain View Intermediate",
        "district": "Macon County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370276003219",
    },
    {
        "school": "Dilworth Elementary School: Latta Campus",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003172",
    },
    {
        "school": "Crain's Creek Middle",
        "district": "Moore County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309003211",
    },
    {
        "school": "West Pine Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309003212",
    },
    {
        "school": "Holly Shelter Middle",
        "district": "New Hanover County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333003210",
    },
    {
        "school": "East Rockingham Elementary",
        "district": "Richmond County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370387003209",
    },
    {
        "school": "Scotland High School",
        "district": "Scotland County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370420003231",
    },
    {
        "school": "Pilot Mountain Elementary",
        "district": "Surry County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441003216",
    },
    {
        "school": "Rockford Elementary",
        "district": "Surry County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441003221",
    },
    {
        "school": "Walnut Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003186",
    },
    {
        "school": "Wake STEM Early College High School",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003192",
    },
    {
        "school": "Mills Park Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003205",
    },
    {
        "school": "Holly Grove Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003208",
    },
    {
        "school": "Alston Ridge Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003214",
    },
    {
        "school": "Heritage High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003226",
    },
    {
        "school": "SUNRISE ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400850",
    },
    {
        "school": "VALLEY-EDINBURG HIGH SCHOOL",
        "district": "VALLEY-EDINBURG 118",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380039700168",
    },
    {
        "school": "VALLEY-EDINBURG ELEMENTARY SCHOOL-CRYSTAL",
        "district": "VALLEY-EDINBURG 118",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380039700652",
    },
    {
        "school": "VALLEY-EDINBURG ELEMENTARY SCHOOL-HOOPLE",
        "district": "VALLEY-EDINBURG 118",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380039700852",
    },
    {
        "school": "FOUR WINDS COMMUNITY PK SCHOOL",
        "district": "FT TOTTEN 30",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380717000853",
    },
    {
        "school": "WHEATLAND COLONY SCHOOL",
        "district": "MAPLE VALLEY 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381202000851",
    },
    {
        "school": "Columbus Bilingual Academy-North",
        "district": "Columbus Bilingual Academy-North",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390137505565",
    },
    {
        "school": "Northeast Ohio College Preparatory School",
        "district": "Northeast Ohio College Preparatory School",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390137605644",
    },
    {
        "school": "Imagine Akron Academy",
        "district": "Imagine Akron Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390137705630",
    },
    {
        "school": "Everest High School",
        "district": "Everest High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390137805631",
    },
    {
        "school": "The Richland School of Academic Arts",
        "district": "The Richland School of Academic Arts",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390138105634",
    },
    {
        "school": "Graham Elementary and Middle School",
        "district": "Graham Elementary and Middle School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390138205643",
    },
    {
        "school": "Horizon Science Academy Dayton Downtown",
        "district": "Horizon Science Academy Dayton Downtown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390138305625",
    },
    {
        "school": "Horizon Science Academy Youngstown",
        "district": "Horizon Science Academy Youngstown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390138905567",
    },
    {
        "school": "Zenith Academy East",
        "district": "Zenith Academy East",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390139605579",
    },
    {
        "school": "Cleveland College Preparatory School",
        "district": "Cleveland College Preparatory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390139705615",
    },
    {
        "school": "Columbus Performance Academy",
        "district": "Columbus Performance Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390139805612",
    },
    {
        "school": "Constellation Schools: Stockyard Community Middle",
        "district": "Constellation Schools: Stockyard Community Middle",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390140305599",
    },
    {
        "school": "Near West Intergenerational School",
        "district": "Near West Intergenerational School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390140505596",
    },
    {
        "school": "Foxfire Intermediate School",
        "district": "Foxfire Intermediate School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390140705576",
    },
    {
        "school": "Regent High School",
        "district": "Regent High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390140905571",
    },
    {
        "school": "Mason Run High School",
        "district": "Mason Run High School",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390141005568",
    },
    {
        "school": "Old Brook High School",
        "district": "Old Brook High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390141105590",
    },
    {
        "school": "Road to Success Academy",
        "district": "Road to Success Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390141205608",
    },
    {
        "school": "Central High School",
        "district": "Central High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390141305569",
    },
    {
        "school": "George V. Voinovich High School",
        "district": "George V. Voinovich High School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390141405602",
    },
    {
        "school": "Frederick Douglass High School",
        "district": "Frederick Douglass High School",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390141505601",
    },
    {
        "school": "Capital High School",
        "district": "Capital High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390141605649",
    },
    {
        "school": "Patriot Preparatory Academy",
        "district": "Patriot Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390141705597",
    },
    {
        "school": "North Central Academy",
        "district": "North Central Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390142005577",
    },
    {
        "school": "Southside Academy",
        "district": "Southside Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390142705618",
    },
    {
        "school": "Akros Middle School",
        "district": "Akros Middle School",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390142805651",
    },
    {
        "school": "New Technology West",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805573",
    },
    {
        "school": "New Technology HS@East Tech",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805586",
    },
    {
        "school": "Campus International School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805591",
    },
    {
        "school": "Facing History High School@Charles Mooney",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805603",
    },
    {
        "school": "Thomas Jefferson School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805624",
    },
    {
        "school": "Washington Park",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805626",
    },
    {
        "school": "Willson School",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805637",
    },
    {
        "school": "Euclid Park Elementary School",
        "district": "Cleveland Municipal",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805641",
    },
    {
        "school": "Columbus City Preparatory School for Boys",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438005572",
    },
    {
        "school": "Columbus North International School (7-12)",
        "district": "Columbus City School District",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438005592",
    },
    {
        "school": "Columbus City Preparatory School for Girls",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438005610",
    },
    {
        "school": "Geneva Platt R. Spencer Elementary School",
        "district": "Geneva Area City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390440505575",
    },
    {
        "school": "New Beginnings",
        "district": "Lorain City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442605595",
    },
    {
        "school": "Jane Chance Elementary",
        "district": "Miamisburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443905617",
    },
    {
        "school": "Clark Center",
        "district": "Springfield City School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448105635",
    },
    {
        "school": "Early Learning Preschool",
        "district": "Strongsville City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448405639",
    },
    {
        "school": "Struthers Preschool",
        "district": "Struthers City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448505633",
    },
    {
        "school": "Wapakoneta Jr. High",
        "district": "Wapakoneta City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449805636",
    },
    {
        "school": "John Dewey Elementary School",
        "district": "Warrensville Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450005598",
    },
    {
        "school": "Eastwood Elementary School",
        "district": "Warrensville Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450005621",
    },
    {
        "school": "Harrison Central Elementary School",
        "district": "Harrison Hills City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452405614",
    },
    {
        "school": "Mapleton Middle School",
        "district": "Mapleton Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390458305578",
    },
    {
        "school": "Wynford Junior High",
        "district": "Wynford Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465205594",
    },
    {
        "school": "General Rosecrans Elementary",
        "district": "Big Walnut Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467405600",
    },
    {
        "school": "Reynoldsburg High School eSTEM",
        "district": "Reynoldsburg City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470005566",
    },
    {
        "school": "Houston Educational Service and Early Childhood Center",
        "district": "Northwest Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473605632",
    },
    {
        "school": "South Bloomfield Elementary",
        "district": "Teays Valley Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390490905628",
    },
    {
        "school": "Head Start",
        "district": "Celina City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003005629",
    },
    {
        "school": "OKEMAH NOBLE CTR",
        "district": "OKEMAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400685002711",
    },
    {
        "school": "VIRGIL COOPER MS",
        "district": "DRUMRIGHT",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401020002709",
    },
    {
        "school": "MANNFORD EC CTR",
        "district": "MANNFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401884002716",
    },
    {
        "school": "HERITAGE TRAILS ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025002705",
    },
    {
        "school": "OAKRIDGE ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025002707",
    },
    {
        "school": "DIMENSIONS ACADEMY",
        "district": "NORMAN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172002710",
    },
    {
        "school": "DIMENSIONS ACADEMY",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172002714",
    },
    {
        "school": "NORTHWOOD ES",
        "district": "PIEDMONT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402397002712",
    },
    {
        "school": "SEQUOYAH MS",
        "district": "SEQUOYAH",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402739002706",
    },
    {
        "school": "EAGLE CAP Innovative HS",
        "district": "Baker SD 5J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410171001516",
    },
    {
        "school": "Arco Iris Spanish Immersion School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001791",
    },
    {
        "school": "Rosland Elementary",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001794",
    },
    {
        "school": "Sunny Wolf Charter School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690001797",
    },
    {
        "school": "Logos Public Charter School",
        "district": "Medford SD 549C",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804001796",
    },
    {
        "school": "Renaissance Public Academy",
        "district": "Molalla River SD 35",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410831001800",
    },
    {
        "school": "Clackamas Academy of Industrial Sciences",
        "district": "Oregon City SD 62",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410933001793",
    },
    {
        "school": "Rockwood Preparatory Academy",
        "district": "Reynolds SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411052001798",
    },
    {
        "school": "Oregon Trail  Academy",
        "district": "Oregon Trail SD 46",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411089001799",
    },
    {
        "school": "Sheridan AllPrep Academy",
        "district": "Sheridan SD 48J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411122001803",
    },
    {
        "school": "Universal Daroff Charter School",
        "district": "Universal Daroff Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420082707366",
    },
    {
        "school": "Mastery CS-Harrity Campus",
        "district": "Mastery CS-Harrity Campus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420082807351",
    },
    {
        "school": "Mastery CS-Smedley Campus",
        "district": "Mastery CS-Smedley Campus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420082907358",
    },
    {
        "school": "Frederick Douglass Mastery Charter Schoo",
        "district": "Frederick Douglass Mastery Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420083007365",
    },
    {
        "school": "Mastery CS - Mann Campus",
        "district": "Mastery CS-Mann Campus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420083107367",
    },
    {
        "school": "Lehigh Valley Dual Language Charter Scho",
        "district": "Lehigh Valley Dual Language Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420083207361",
    },
    {
        "school": "Propel CS-Braddock Hills",
        "district": "Propel CS-Braddock Hills",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420083307363",
    },
    {
        "school": "Universal Bluford Charter School",
        "district": "Universal Bluford Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420083407357",
    },
    {
        "school": "ASPIRA Bilingual Cyber Charter School",
        "district": "ASPIRA Bilingual Cyber Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420083507354",
    },
    {
        "school": "Gettysburg Montessori Charter School",
        "district": "Gettysburg Montessori Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420083607370",
    },
    {
        "school": "John B. Stetson Charter School",
        "district": "John B Stetson Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420083907353",
    },
    {
        "school": "Luis A. Ramos El Sch",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228007364",
    },
    {
        "school": "Dallastown Area Intermediate Sch",
        "district": "Dallastown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420723007355",
    },
    {
        "school": "ELCO Intermd Sch",
        "district": "Eastern Lebanon County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420846007359",
    },
    {
        "school": "Willow Lane El Sch",
        "district": "East Penn SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420855007352",
    },
    {
        "school": "Skyview Upper El Sch",
        "district": "Methacton SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421425007347",
    },
    {
        "school": "W.A. McCreery El Sch",
        "district": "Marion Center Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421473007362",
    },
    {
        "school": "Mount Carmel Area JH",
        "district": "Mount Carmel Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421599007369",
    },
    {
        "school": "Highcliff El Sch",
        "district": "North Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421722007348",
    },
    {
        "school": "Fred J. Jaindl El Sch",
        "district": "Parkland SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421851007356",
    },
    {
        "school": "Springfield Literacy Center",
        "district": "Springfield SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422260007368",
    },
    {
        "school": "Blackstone Valley Prep",
        "district": "Blackstone Valley Prep  A RI Mayoral Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440001500475",
    },
    {
        "school": "The Greene School",
        "district": "The Greene School",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440001700477",
    },
    {
        "school": "Trinity Academy Performing Art",
        "district": "Trinity Academy for the Performing Arts",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440001800478",
    },
    {
        "school": "Pritchardville Elementary",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001549",
    },
    {
        "school": "Whale Branch Early College High",
        "district": "Beaufort 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001550",
    },
    {
        "school": "Bluffton Middle",
        "district": "Beaufort 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001552",
    },
    {
        "school": "Berkeley County Middle College High",
        "district": "Berkeley 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001556",
    },
    {
        "school": "Pattison's Academy for Comprehensive Education",
        "district": "Charleston 01",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001553",
    },
    {
        "school": "Pinehurst Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001562",
    },
    {
        "school": "A.J. Whittenburg Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001551",
    },
    {
        "school": "Palmetto Academy of Learning and Success Charter",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001561",
    },
    {
        "school": "Rocky Creek Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001547",
    },
    {
        "school": "Lexington Four Early Childhood Center",
        "district": "Lexington 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450279001548",
    },
    {
        "school": "Richland Two Charter High",
        "district": "Richland 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001554",
    },
    {
        "school": "Langford Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001555",
    },
    {
        "school": "Rainbow Lake Middle",
        "district": "Spartanburg 02",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351001558",
    },
    {
        "school": "Hemingway MB Lee Middle",
        "district": "Williamsburg 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450378001559",
    },
    {
        "school": "York Intermediate",
        "district": "York 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450381001557",
    },
    {
        "school": "Teachwell Transitions - 03",
        "district": "East Dakota Educational Cooperative",
        "level": "High",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "460002701316",
    },
    {
        "school": "New Technology High School - 30",
        "district": "Sioux Falls School District 49-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001303",
    },
    {
        "school": "CTE - 37",
        "district": "Sioux Falls School District 49-5",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SD",
        "nces_id": "466627001305",
    },
    {
        "school": "Black Hills Education Connections - 06",
        "district": "Spearfish School District 40-2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "466693001304",
    },
    {
        "school": "Black Hills Academy at Canyon Hills High School - 07",
        "district": "Black Hills Special Services Cooperative",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "468012001308",
    },
    {
        "school": "Park View Elementary School",
        "district": "Bradley County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033002224",
    },
    {
        "school": "Deerfield Elementary School",
        "district": "Coffee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470078002234",
    },
    {
        "school": "Northside Elementary",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470168002223",
    },
    {
        "school": "East Hardin Elementary",
        "district": "Hardin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470168002246",
    },
    {
        "school": "Church Hill Intermediate School",
        "district": "Hawkins County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470174002240",
    },
    {
        "school": "East Elementary School",
        "district": "Humboldt City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470195002239",
    },
    {
        "school": "Stigall Primary School",
        "district": "Humboldt City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470195002242",
    },
    {
        "school": "Dr. Paul L. Kelley Volunteer Academy",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222002249",
    },
    {
        "school": "Spring Hill Middle School",
        "district": "Maury County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276002227",
    },
    {
        "school": "Prescott South Elementary",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348002226",
    },
    {
        "school": "Prescott South Middle School",
        "district": "Putnam County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348002230",
    },
    {
        "school": "White House Heritage Elementary School",
        "district": "Robertson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360002225",
    },
    {
        "school": "Central Magnet School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002247",
    },
    {
        "school": "Oakland Middle School",
        "district": "Rutherford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002251",
    },
    {
        "school": "Whitworth-Buchanan Middle School",
        "district": "Rutherford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002253",
    },
    {
        "school": "Spring Station Middle School",
        "district": "Williamson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002237",
    },
    {
        "school": "Allendale Elementary School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002244",
    },
    {
        "school": "Pearre Creek Elementary School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002252",
    },
    {
        "school": "SER-NINOS CHARTER EL II",
        "district": "SER-NINOS CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001812493",
    },
    {
        "school": "ELITE STEM PRI ACADEMY",
        "district": "RAUL YZAGUIRRE SCHOOLS FOR SUCCESS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480002212583",
    },
    {
        "school": "HOUSTON STEM AND EARLY COLLEGE MIDDLE",
        "district": "RAUL YZAGUIRRE SCHOOLS FOR SUCCESS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480002212626",
    },
    {
        "school": "LIFE SCHOOL CEDAR HILL",
        "district": "LIFE SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480005512477",
    },
    {
        "school": "SOUTHWEST SCHOOLS MANGUM EL CAMPUS",
        "district": "SOUTHWEST SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480012512514",
    },
    {
        "school": "ARLINGTON CLASSICS ACADEMY -INTERMEDIATE",
        "district": "ARLINGTON CLASSICS ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480015812532",
    },
    {
        "school": "ARLINGTON CLASSICS ACADEMY - MIDDLE",
        "district": "ARLINGTON CLASSICS ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480015812533",
    },
    {
        "school": "CLAY CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312538",
    },
    {
        "school": "JUBILEE HIGHLAND PARK",
        "district": "JUBILEE ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017912584",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - HOUSTON",
        "district": "HARMONY SCIENCE ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021012488",
    },
    {
        "school": "HARMONY SCHOOL OF INGENUITY-HOUSTON",
        "district": "HARMONY SCIENCE ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021012506",
    },
    {
        "school": "HARMONY SCHOOL OF SCIENCE-HOUSTON",
        "district": "HARMONY SCIENCE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021012560",
    },
    {
        "school": "HARMONY SCHOOL OF FINE ARTS AND TECHNOLOGY-HOUSTON",
        "district": "HARMONY SCIENCE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021012561",
    },
    {
        "school": "IDEA COLLEGE PREP WESLACO",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112495",
    },
    {
        "school": "IDEA EDINBURG COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112500",
    },
    {
        "school": "IDEA EDINBURG ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112638",
    },
    {
        "school": "IDEA ACADEMY WESLACO",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112641",
    },
    {
        "school": "PANOLA EARLY COLLEGE H S",
        "district": "PANOLA CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021312565",
    },
    {
        "school": "HARMONY SCHOOL OF SCIENCE - AUSTIN",
        "district": "HARMONY SCIENCE ACADEMY (AUSTIN)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024112574",
    },
    {
        "school": "KIPP AUSTIN COMUNIDAD",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412553",
    },
    {
        "school": "KIPP AUSTIN CONNECTIONS EL",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412559",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - SAN ANTONIO",
        "district": "HARMONY SCIENCE ACAD (SAN ANTONIO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026612580",
    },
    {
        "school": "HARMONY SCHOOL OF DISCOVERY - HOUSTON",
        "district": "HARMONY SCHOOL OF EXCELLENCE",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027412489",
    },
    {
        "school": "HARMONY SCHOOL OF TECHNOLOGY-HOUSTON",
        "district": "HARMONY SCHOOL OF EXCELLENCE",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027412490",
    },
    {
        "school": "HARMONY SCHOOL OF ADVANCEMENT-HOUSTON",
        "district": "HARMONY SCHOOL OF EXCELLENCE",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027412494",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - BRYAN",
        "district": "HARMONY SCHOOL OF EXCELLENCE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027412518",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - GARLAND",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029212536",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - DALLAS",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029212542",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - CARROLLTON",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029212548",
    },
    {
        "school": "ARROW ACADEMY - LIBERATION ACADEMY",
        "district": "ARROW ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141612563",
    },
    {
        "school": "COMPASS ACADEMY CHARTER SCHOOL",
        "district": "COMPASS ACADEMY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141712503",
    },
    {
        "school": "THE LAWSON ACADEMY",
        "district": "THE LAWSON ACADEMY",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480141812485",
    },
    {
        "school": "LEADERSHIP PREP SCHOOL",
        "district": "LEADERSHIP PREP SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142012633",
    },
    {
        "school": "NEWMAN INTERNATIONAL ACADEMY OF ARLINGTON",
        "district": "NEWMAN INTERNATIONAL ACADEMY OF ARLINGTON",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142112625",
    },
    {
        "school": "MERIDIAN WORLD SCHOOL LLC",
        "district": "MERIDIAN WORLD SCHOOL LLC",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142212570",
    },
    {
        "school": "GREENS PRAIRIE EL",
        "district": "COLLEGE STATION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735012479",
    },
    {
        "school": "COLLEGE STATION H S",
        "district": "COLLEGE STATION ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735012482",
    },
    {
        "school": "HALL CENTER FOR EDUCATION",
        "district": "ALDINE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480771012521",
    },
    {
        "school": "DON R DANIEL NINTH GRADE CAMPUS",
        "district": "ALEDO ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480778012586",
    },
    {
        "school": "BEVERLY CHEATHAM EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789012461",
    },
    {
        "school": "GLENN YORK EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809012607",
    },
    {
        "school": "MANVEL J H",
        "district": "ALVIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809012631",
    },
    {
        "school": "CENTRAL EL",
        "district": "ANGLETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480831012579",
    },
    {
        "school": "LUCAS PK",
        "district": "BEAUMONT ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967012562",
    },
    {
        "school": "BINGMAN PK",
        "district": "BEAUMONT ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967012566",
    },
    {
        "school": "SOUTH BELTON MIDDLE",
        "district": "BELTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986012476",
    },
    {
        "school": "BRIGHT BEGINNINGS ACADEMIC CENTER",
        "district": "BROWNFIELD ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481161012545",
    },
    {
        "school": "CALLISBURG MIDDLE",
        "district": "CALLISBURG ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481251012462",
    },
    {
        "school": "CANUTILLO JJAEP",
        "district": "CANUTILLO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481278012530",
    },
    {
        "school": "COASTAL ALTERNATIVE PROGRAM",
        "district": "CLEAR CREEK ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481428012511",
    },
    {
        "school": "HWY 46 AREA EL",
        "district": "COMAL ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473012463",
    },
    {
        "school": "DANVILLE MIDDLE",
        "district": "COMAL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473012557",
    },
    {
        "school": "MEMORIAL EARLY COLLEGE H S WITH ST PHILIP'S",
        "district": "COMAL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473012564",
    },
    {
        "school": "SERENITY HIGH",
        "district": "COMMUNITY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481485012628",
    },
    {
        "school": "SNYDER EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500012544",
    },
    {
        "school": "LUBBOCK-COOPER BUSH MIDDLE",
        "district": "LUBBOCK-COOPER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481518012535",
    },
    {
        "school": "LUBBOCK-COOPER CENTRAL EL",
        "district": "LUBBOCK-COOPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481518012577",
    },
    {
        "school": "HOUSE CREEK EL",
        "district": "COPPERAS COVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481524012594",
    },
    {
        "school": "MARY HARRIS EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591012630",
    },
    {
        "school": "DAVID L WALKER ELT",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591012636",
    },
    {
        "school": "SALYARDS MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611012598",
    },
    {
        "school": "EBBY HALLIDAY EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012460",
    },
    {
        "school": "GEORGE HERBERT WALKER BUSH EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012472",
    },
    {
        "school": "WILMER-HUTCHINS EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012474",
    },
    {
        "school": "RESERVED FOR FUTURE USE",
        "district": "DALLAS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012550",
    },
    {
        "school": "WILMER-HUTCHINS H S",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012551",
    },
    {
        "school": "BARACK OBAMA MALE LEADERSHIP ACAD AT A MACEO SMITH",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012569",
    },
    {
        "school": "YOUNG EL",
        "district": "DECATUR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481650012615",
    },
    {
        "school": "JOSEPH GILBERT EL",
        "district": "DEL VALLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662012601",
    },
    {
        "school": "COASTAL ALTERNATIVE PROGRAM (CAP)",
        "district": "DICKINSON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481707012502",
    },
    {
        "school": "DICKINSON CONTINUATION CENTER",
        "district": "DICKINSON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481707012520",
    },
    {
        "school": "PERFECTO MANCHA EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773012537",
    },
    {
        "school": "ARMANDO CERNA EL",
        "district": "EAGLE PASS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481773012546",
    },
    {
        "school": "ABOUT FACE JJAEP",
        "district": "EL PASO ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481830012491",
    },
    {
        "school": "SOUTH EL",
        "district": "FLORESVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481935012576",
    },
    {
        "school": "HERITAGE MIDDLE",
        "district": "FRENSHIP ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983012558",
    },
    {
        "school": "MAUS MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012470",
    },
    {
        "school": "LONE STAR H S",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012473",
    },
    {
        "school": "COBB MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012481",
    },
    {
        "school": "HUNT MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012483",
    },
    {
        "school": "PUREFOY EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012590",
    },
    {
        "school": "SONNTAG EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012599",
    },
    {
        "school": "BURNET EL",
        "district": "GALVESTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482028012555",
    },
    {
        "school": "MCLENNAN COUNTY CHALLENGE ACADEMY",
        "district": "GHOLSON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482061012571",
    },
    {
        "school": "JCSSA",
        "district": "GODLEY ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482096012629",
    },
    {
        "school": "IMPACT EARLY COLLEGE H S",
        "district": "GOOSE CREEK CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115012492",
    },
    {
        "school": "JAMES FANNIN MIDDLE",
        "district": "GRAND PRAIRIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142012480",
    },
    {
        "school": "ROBERT E LEE EL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142012613",
    },
    {
        "school": "BONHAM EES",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142012624",
    },
    {
        "school": "H S AHEAD ACADEMY",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482364012602",
    },
    {
        "school": "ENERGIZED FOR STEM ACADEMY SOUTHEAST MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012609",
    },
    {
        "school": "MICKEY LELAND COLLEGE PREP ACAD FOR YOUNG MEN",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012618",
    },
    {
        "school": "YOUNG WOMEN'S COLLEGE PREP ACADEMY",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012621",
    },
    {
        "school": "ROLLING MEADOWS EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499012467",
    },
    {
        "school": "JUDSON MIDDLE",
        "district": "JUDSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499012469",
    },
    {
        "school": "FRED AND PATTI SHAFER EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517012499",
    },
    {
        "school": "TOM WILSON EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517012515",
    },
    {
        "school": "RAY AND JAMIE WOLMAN EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517012517",
    },
    {
        "school": "SEVEN LAKES J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517012519",
    },
    {
        "school": "RIDGEVIEW EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526012616",
    },
    {
        "school": "FISD DAEP",
        "district": "KENEDY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482544012592",
    },
    {
        "school": "BLACKSHEAR EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574012603",
    },
    {
        "school": "DOMINGO TREVINO MIDDLE",
        "district": "LA JOYA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613012498",
    },
    {
        "school": "OFFICER LEONARD A REED EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703012568",
    },
    {
        "school": "FLORENCE W STILES MIDDLE",
        "district": "LEANDER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703012611",
    },
    {
        "school": "CAPITOL EL",
        "district": "LEVELLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482724012632",
    },
    {
        "school": "LONDON H S",
        "district": "LONDON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482799012600",
    },
    {
        "school": "NED E WILLIAMS EL",
        "district": "LONGVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811012484",
    },
    {
        "school": "WARE EL",
        "district": "LONGVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811012487",
    },
    {
        "school": "SOUTH WARD EL",
        "district": "LONGVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811012508",
    },
    {
        "school": "LEAD ACADEMY H S",
        "district": "LONGVIEW ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482811012512",
    },
    {
        "school": "J L EVERHART MAGNET EL",
        "district": "LONGVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811012528",
    },
    {
        "school": "JOHNSTON-MCQUEEN EL",
        "district": "LONGVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811012529",
    },
    {
        "school": "OAKLEY EL",
        "district": "NEW CANEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240012541",
    },
    {
        "school": "SCHOOL AGED PARENTING PROGRAM",
        "district": "NORTHSIDE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312012591",
    },
    {
        "school": "LIECK EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012604",
    },
    {
        "school": "MIRELES EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012627",
    },
    {
        "school": "ORANGE GROVE EL",
        "district": "ORANGE GROVE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483372012525",
    },
    {
        "school": "WASHINGTON EARLY CHILDHOOD CENTER",
        "district": "PALESTINE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483405012588",
    },
    {
        "school": "CROCKETT INT",
        "district": "PARIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483429012578",
    },
    {
        "school": "NEW EL #135",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486012587",
    },
    {
        "school": "JAIME ESCALANTE MIDDLE",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486012589",
    },
    {
        "school": "AUDIE MURPHY MIDDLE",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486012596",
    },
    {
        "school": "MARCIA R GARZA",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486012605",
    },
    {
        "school": "NEW EL #133",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486012634",
    },
    {
        "school": "NEW EL #132",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486012640",
    },
    {
        "school": "EXCEL H S OF CHOICE",
        "district": "PINE TREE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483498012556",
    },
    {
        "school": "DAEP",
        "district": "PROGRESO ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483591012608",
    },
    {
        "school": "CYNTHIA A COCKRELL EL",
        "district": "PROSPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600012464",
    },
    {
        "school": "REYNOLDS MIDDLE",
        "district": "PROSPER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600012465",
    },
    {
        "school": "RAYMONDVILLE OPTIONS ACADEMIC ACADEMY",
        "district": "RAYMONDVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483654012552",
    },
    {
        "school": "RICE INTERMEDIATE/MIDDLE SCHOOL",
        "district": "RICE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483696012619",
    },
    {
        "school": "ANGELA GERUSA LEAL EL",
        "district": "SAN BENITO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483879012468",
    },
    {
        "school": "COASTAL ALTERNATIVE PROGRAM",
        "district": "SANTA FE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483927012582",
    },
    {
        "school": "GARRETT EL",
        "district": "SHELDON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483999012497",
    },
    {
        "school": "SONORA EL",
        "district": "SONORA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484080012547",
    },
    {
        "school": "MEDIO CREEK EL",
        "district": "SOUTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095012595",
    },
    {
        "school": "STERLING CITY/VERIBEST SPECIAL PROGRAMS",
        "district": "STERLING CITY ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484155012554",
    },
    {
        "school": "FRED W EDWARDS ACADEMY AEC",
        "district": "TEMPLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484233012581",
    },
    {
        "school": "TERRELL ALTERNATIVE EDUCATION CENTER/PHOENIX SCH",
        "district": "TERRELL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484245012620",
    },
    {
        "school": "TIMBER CREEK EL",
        "district": "TOMBALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296012593",
    },
    {
        "school": "ST LOUIS EARLY CHILDHOOD CENTER",
        "district": "TYLER ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347012531",
    },
    {
        "school": "VALLEY VIEW 5TH GRADE CAMPUS",
        "district": "VALLEY VIEW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484380012639",
    },
    {
        "school": "LIBERTY DAEP MIDDLE",
        "district": "VICTORIA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484415012575",
    },
    {
        "school": "OLIVER E CLIFT EL",
        "district": "WAXAHACHIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473012617",
    },
    {
        "school": "PFC MARIO YBARRA EL",
        "district": "WESLACO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496012496",
    },
    {
        "school": "WHARTON J H",
        "district": "WHARTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484538012610",
    },
    {
        "school": "WHITNEY ALTERNATIVE EDUCATION CENTER",
        "district": "WHITNEY ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484572012513",
    },
    {
        "school": "American Preparatory Academy - Accelerated School",
        "district": "American Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490000501404",
    },
    {
        "school": "Mountain Trails School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001381",
    },
    {
        "school": "Traverse Mountain School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001385",
    },
    {
        "school": "Vista Heights Middle",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001387",
    },
    {
        "school": "Heritage School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012001379",
    },
    {
        "school": "Birch Creek School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012001392",
    },
    {
        "school": "Goldminer's Daughter",
        "district": "Canyons District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014201380",
    },
    {
        "school": "Canyons Transition Academy",
        "district": "Canyons District",
        "level": "High",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490014201384",
    },
    {
        "school": "Good Foundations Academy",
        "district": "Good Foundations Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014701389",
    },
    {
        "school": "Summit Academy High School",
        "district": "Summit Academy High School",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014801396",
    },
    {
        "school": "Utah Connections Academy",
        "district": "Utah Connections Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015101386",
    },
    {
        "school": "Endeavour School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001382",
    },
    {
        "school": "Centennial Jr High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001403",
    },
    {
        "school": "Salem Junior High",
        "district": "Nebo District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001390",
    },
    {
        "school": "Sierra Bonita Elementary",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001391",
    },
    {
        "school": "Taylor Canyon School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001383",
    },
    {
        "school": "Tooele Community Learning Center",
        "district": "Tooele District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105001401",
    },
    {
        "school": "THE GOVERNOR'S SCHOOL @ INNOVATION PARK",
        "district": "THE GOVERNOR'S SCHOOL @ INNOVATION PARK",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510025202848",
    },
    {
        "school": "BROOKNEAL ELEM",
        "district": "CAMPBELL CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510060002834",
    },
    {
        "school": "SOUTH BOSTON/HALIFAX EARLY LEARNING CTR",
        "district": "HALIFAX CO PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510177002836",
    },
    {
        "school": "HOLMAN MIDDLE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002833",
    },
    {
        "school": "GLEN ALLEN HIGH",
        "district": "HENRICO CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002837",
    },
    {
        "school": "EVENING SCHOOL OF EXCELLENCE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510189002840",
    },
    {
        "school": "CENTER FOR DIVERSIFIED STUDIES",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510189002841",
    },
    {
        "school": "PACE",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510189002842",
    },
    {
        "school": "ISEAP PRGM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510189002844",
    },
    {
        "school": "GENERAL ACADEMIC DEVELOPMENT",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510189002845",
    },
    {
        "school": "AXTON ELEM",
        "district": "HENRY CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510192002839",
    },
    {
        "school": "HARMONY MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002831",
    },
    {
        "school": "BUFFALO TRAIL ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002832",
    },
    {
        "school": "MOSS-NUCKOLS ELEM",
        "district": "LOUISA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510228002838",
    },
    {
        "school": "THE ACADEMY OF INTERNATIONAL STUDIES AT ROSEMONT",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510267002843",
    },
    {
        "school": "CHURCHLAND PRESCHOOL CTR",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300002829",
    },
    {
        "school": "PATRIOT HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002850",
    },
    {
        "school": "FRESH START CENTER",
        "district": "SOUTHAMPTON CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510360002846",
    },
    {
        "school": "STAUNTON PRESCHOOL PROGRAMS",
        "district": "STAUNTON CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510369002828",
    },
    {
        "school": "LOIS HORNSBY MIDDLE",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402002830",
    },
    {
        "school": "Twin Harbors - A Branch of New Market Skills Center",
        "district": "Aberdeen School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530003003334",
    },
    {
        "school": "Washington State School for the Blind",
        "district": "Office of the Governor (Sch for Blind)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530031802385",
    },
    {
        "school": "Liberty Middle School",
        "district": "Bethel School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048003343",
    },
    {
        "school": "ICCF Ed Program",
        "district": "Coupeville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530180003350",
    },
    {
        "school": "Federal Way Public Schools Headstart",
        "district": "Federal Way School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282003320",
    },
    {
        "school": "Federal Way Public School ECEAP",
        "district": "Federal Way School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282003321",
    },
    {
        "school": "Cascadia Elementary",
        "district": "Ferndale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530285003339",
    },
    {
        "school": "Creekside Elementary",
        "district": "Issaquah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375003331",
    },
    {
        "school": "Pacific Cascade Middle School",
        "district": "Issaquah School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375003337",
    },
    {
        "school": "Cottonwood Elementary",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393003330",
    },
    {
        "school": "Marysville Pilchuck High School",
        "district": "Marysville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486003317",
    },
    {
        "school": "Honey Dew Elementary",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723003351",
    },
    {
        "school": "Sand Point Elementary",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003316",
    },
    {
        "school": "Queen Anne Elementary",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003318",
    },
    {
        "school": "McDonald International School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003332",
    },
    {
        "school": "Robert Lince Early Learning Center",
        "district": "Selah School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530777003347",
    },
    {
        "school": "Selah HomeLink",
        "district": "Selah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530777003348",
    },
    {
        "school": "Selkirk Middle School",
        "district": "Selkirk School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530780003341",
    },
    {
        "school": "Selkirk High School",
        "district": "Selkirk School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530780003344",
    },
    {
        "school": "Paideia High School",
        "district": "Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530924003327",
    },
    {
        "school": "Wenatchee Valley Technical Skills Center",
        "district": "Wenatchee School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530966002783",
    },
    {
        "school": "West Valley High School Freshman Campus",
        "district": "West Valley School District (Yakima)",
        "level": "Secondary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972003340",
    },
    {
        "school": "Yakima Satellite Alternative Programs",
        "district": "Yakima School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "531011003324",
    },
    {
        "school": "HUNTINGTON EAST MIDDLE SCHOOL",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018001483",
    },
    {
        "school": "Thompson Correctional Center",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502835",
    },
    {
        "school": "Gordon Correctional Center",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502836",
    },
    {
        "school": "St Croix Correctional Center",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502842",
    },
    {
        "school": "Felmers O Chaney Correctional Center",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003502843",
    },
    {
        "school": "Wisconsin Connections Academy",
        "district": "Appleton Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002825",
    },
    {
        "school": "Cameron Academy of Virtual Education",
        "district": "Cameron School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550213002851",
    },
    {
        "school": "Coleman Middle",
        "district": "Coleman School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550276002847",
    },
    {
        "school": "Kettle Moraine 4K",
        "district": "Kettle Moraine School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550351002852",
    },
    {
        "school": "LIFE Entrepreneur Magnet Sch",
        "district": "Hartland-Lakeside J3 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550614002837",
    },
    {
        "school": "Hartland School of Community Learning",
        "district": "Hartland-Lakeside J3 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550614002845",
    },
    {
        "school": "Highland Community Middle",
        "district": "Highland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550642002829",
    },
    {
        "school": "Hortonville Area K4 School",
        "district": "Hortonville Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550660002848",
    },
    {
        "school": "Woodland Intermediate",
        "district": "Kimberly Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550747002824",
    },
    {
        "school": "Sunrise Early Learning Center",
        "district": "Marinette School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550870002838",
    },
    {
        "school": "Milwaukee Community Cyber High",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002822",
    },
    {
        "school": "Woodland Progressive School for 21st Century Citizens",
        "district": "Minocqua J1 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550969002840",
    },
    {
        "school": "Monona Grove Liberal Arts",
        "district": "Monona Grove School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550981002828",
    },
    {
        "school": "Oregon 4K",
        "district": "Oregon School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551110002841",
    },
    {
        "school": "Bluff View Elementary",
        "district": "Prairie du Chien Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551215002830",
    },
    {
        "school": "Bluff View Middle",
        "district": "Prairie du Chien Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551215002833",
    },
    {
        "school": "Bluff View Junior High",
        "district": "Prairie du Chien Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551215002844",
    },
    {
        "school": "Quest Charter School",
        "district": "Ripon Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551302002839",
    },
    {
        "school": "Verona Area International School",
        "district": "Verona Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533002849",
    },
    {
        "school": "Whitewater 4K",
        "district": "Whitewater Unified School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551668002834",
    },
    {
        "school": "Kaycee School",
        "district": "Johnson County School District #1",
        "level": "Other",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560377000449",
    },
    {
        "school": "Summit Elementary School",
        "district": "Natrona County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560451000451",
    },
    {
        "school": "JOSE PAGAN DE JESUS (ELEMENTAL BO SABANA HOYOS)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001890",
    },
    {
        "school": "SUPERIOR URBANA",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001891",
    },
    {
        "school": "INT BO QUEBRADA ARENAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001907",
    },
    {
        "school": "INTERMEDIA BO QUEBRADILLAS",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001909",
    },
    {
        "school": "Brocks Gap Intermediate School",
        "district": "Hoover City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000702186",
    },
    {
        "school": "Chickasaw City Elementary School",
        "district": "Chickasaw City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018802193",
    },
    {
        "school": "Chickasaw City High School",
        "district": "Chickasaw City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018802194",
    },
    {
        "school": "CF Taylor Alternative School",
        "district": "Baldwin County",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10027002180",
    },
    {
        "school": "Huffman Academy",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039002185",
    },
    {
        "school": "West End Academy",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039002187",
    },
    {
        "school": "Chilton County Alternative School",
        "district": "Chilton County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10066002190",
    },
    {
        "school": "Decatur High Developmental",
        "district": "Decatur City",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10117002175",
    },
    {
        "school": "Greene County Career Center",
        "district": "Greene County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10168002181",
    },
    {
        "school": "Corner Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192002174",
    },
    {
        "school": "Erwin Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192002182",
    },
    {
        "school": "Wacoochee Elementary School",
        "district": "Lee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207002188",
    },
    {
        "school": "Riverton Intermediate School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222002178",
    },
    {
        "school": "Evening Educational Options",
        "district": "Mobile County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10237002177",
    },
    {
        "school": "Lakewood Primary School",
        "district": "Phenix City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10270002179",
    },
    {
        "school": "Mt Olive Primary School",
        "district": "Russell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10288002192",
    },
    {
        "school": "Forest Oaks Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303002189",
    },
    {
        "school": "Helena High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303002191",
    },
    {
        "school": "Totem Correspondence School",
        "district": "Hydaburg City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20033000746",
    },
    {
        "school": "American Leadership Academy San Tan Valley K-6",
        "district": "American Leadership Academy Inc. (4348)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011203279",
    },
    {
        "school": "Amerischools Academy North",
        "district": "The Charter Foundation Inc. (6355)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40013103274",
    },
    {
        "school": "Liberty Traditional Charter School - Saddleback",
        "district": "Liberty Traditional Charter School (10968)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40019003247",
    },
    {
        "school": "E-Institute at Avondale",
        "district": "E-Institute Charter Schools Inc. (79059)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40031103292",
    },
    {
        "school": "CAVIAT - eCampus",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034703268",
    },
    {
        "school": "CAVIAT-Williams Central Program",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034703270",
    },
    {
        "school": "Pillar Academy Online",
        "district": "Pillar Charter School (87334)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40042003277",
    },
    {
        "school": "NATIVE - Red Valley/Cove High School",
        "district": "Northeast Arizona Technological Institute of Vocat (81114)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061203265",
    },
    {
        "school": "PCJTED - Southwest Alt. High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203256",
    },
    {
        "school": "PCJTED - Walden Grove High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203258",
    },
    {
        "school": "The Odyssey Preparatory Academy Goodyear",
        "district": "The Odyssey Preparatory Academy Inc. (90287)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40080003288",
    },
    {
        "school": "Mission Heights Preparatory High School",
        "district": "Kaizen Education Foundation dba Mission Heights Pr (90548)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40082303296",
    },
    {
        "school": "Astravo Online Academy",
        "district": "Arizona Education Solutions (90758)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40082703309",
    },
    {
        "school": "BASIS Peoria",
        "district": "BASIS Charter Schools Inc. (90841)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40082903278",
    },
    {
        "school": "BASIS Chandler",
        "district": "BASIS Charter Schools Inc. (90842)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40083003253",
    },
    {
        "school": "Great Hearts Academies - Archway Trivium West",
        "district": "Archway Classical Academy Trivium West (90915)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40083203290",
    },
    {
        "school": "Great Hearts Academies - Archway Veritas",
        "district": "Archway Classical Academy Veritas (90916)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40083303283",
    },
    {
        "school": "Great Hearts Academies - Archway Chandler",
        "district": "Archway Classical Academy Chandler (90917)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40083403244",
    },
    {
        "school": "Arizona Agribusiness & Equine Center Inc. - Prescott Valley",
        "district": "Arizona Agribusiness & Equine Center Inc. (91131)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40083803243",
    },
    {
        "school": "Pima Rose Academy",
        "district": "Pima Rose Academy Inc. (90997)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40083903273",
    },
    {
        "school": "Great Hearts Academies - Archway Scottsdale",
        "district": "Archway Classical Academy Scottsdale (90857)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40084103259",
    },
    {
        "school": "Legacy Traditional School - Northwest Tucson",
        "district": "Legacy Traditional School - Northwest Tucson (91137)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40084203300",
    },
    {
        "school": "La Tierra Community School",
        "district": "La Tierra Community School Inc (90900)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40084403285",
    },
    {
        "school": "Leading Edge Academy Mountain View",
        "district": "Leading Edge Academy Queen Creek  (91174)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40084503242",
    },
    {
        "school": "South Valley Prep and Arts School",
        "district": "South Valley Academy Inc. (90540)",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40084603245",
    },
    {
        "school": "Legacy Traditional School - Avondale",
        "district": "Legacy Traditional School - Avondale (91135)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40084703301",
    },
    {
        "school": "PLC Arts Academy at Scottsdale Inc.",
        "district": "Arts Academy at Scottsdale Inc. (91053)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40084803293",
    },
    {
        "school": "EAGLE College Prep Phoenix South",
        "district": "EAGLE College Prep Harmony LLC (91170)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40084903266",
    },
    {
        "school": "Great Hearts Academies - Trivium Prep",
        "district": "Trivium Preparatory Academy (90859)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40085103271",
    },
    {
        "school": "Havasu Preparatory Academy",
        "district": "Kaizen Education Foundation dba Havasu Preparatory (90535)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40085203257",
    },
    {
        "school": "South Phoenix Prep and Arts Academy",
        "district": "South Phoenix Academy Inc. (91108)",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40085303297",
    },
    {
        "school": "Legacy Traditional School - Chandler",
        "district": "Legacy Traditional School - Chandler (91133)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40085503275",
    },
    {
        "school": "ASU Preparatory Academy-Polytechnic Elementary",
        "district": "ASU Preparatory Academy (91307)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40085703260",
    },
    {
        "school": "ASU Preparatory Academy- Phoenix High School",
        "district": "ASU Preparatory Academy (91303)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40085803286",
    },
    {
        "school": "ASU Preparatory Academy-Polytechnic High School",
        "district": "ASU Preparatory Academy (91305)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40085903251",
    },
    {
        "school": "Chandler Online Academy",
        "district": "Chandler Unified District #80 (4242)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187003306",
    },
    {
        "school": "Arizona iZone Institute Online Program",
        "district": "Cottonwood-Oak Creek Elementary District (4487)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40237003299",
    },
    {
        "school": "Gilbert Global Academy 7-12",
        "district": "Gilbert Unified District (4239)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40340003261",
    },
    {
        "school": "MCAT High School",
        "district": "Marana Unified District (4404)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40463003302",
    },
    {
        "school": "Mingus Online Academy",
        "district": "Mingus Union High School District (4488)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40507003308",
    },
    {
        "school": "NUSD Online",
        "district": "Nogales Unified District (4457)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40553003246",
    },
    {
        "school": "Payson Center for Success - Online",
        "district": "Payson Unified District (4209)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40607003305",
    },
    {
        "school": "Peoria Traditional School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625003255",
    },
    {
        "school": "Scottsdale Online Learning",
        "district": "Scottsdale Unified District (4240)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40757003250",
    },
    {
        "school": "WMI ON LINE",
        "district": "Show Low Unified District (4393)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40770003276",
    },
    {
        "school": "McCorkle PK-8",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880003282",
    },
    {
        "school": "Andrada Polytechnic High School",
        "district": "Vail Unified District (4413)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885003272",
    },
    {
        "school": "Wickenburg Virtual Academy",
        "district": "Wickenburg Unified District (4236)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40919003248",
    },
    {
        "school": "Yuma Online Distance Academy",
        "district": "Yuma Union High School District (4507)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40963003280",
    },
    {
        "school": "RIVERSIDE HIGH SCHOOL",
        "district": "RIVERSIDE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001201538",
    },
    {
        "school": "NOBLE/ALLBRITTON ELEMENTARY SCHOOL",
        "district": "HAMBURG SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004201540",
    },
    {
        "school": "FLIGHTLINE UPPER ACADEMY",
        "district": "JACKSONVILLE LIGHTHOUSE CHARTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040201531",
    },
    {
        "school": "PINE BLUFF LIGHTHOUSE ACADEMY",
        "district": "PINE BLUFF LIGHTHOUSE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040601541",
    },
    {
        "school": "SIATECH HIGH CHARTER",
        "district": "GRADUATE ARKANSAS SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040701539",
    },
    {
        "school": "BAUXITE MIDDLE SCHOOL",
        "district": "BAUXITE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50279001536",
    },
    {
        "school": "BROOKLAND JUNIOR HIGH SCHOOL",
        "district": "BROOKLAND SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50364001534",
    },
    {
        "school": "CROSS CNTY HIGH A NEW TECH SCH",
        "district": "CROSS COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50774001537",
    },
    {
        "school": "SOUTHWEST MIDDLE SCHOOL",
        "district": "SEARCY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51221001533",
    },
    {
        "school": "SOUTHSIDE JUNIOR HIGH SCHOOL",
        "district": "SOUTHSIDE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51254001542",
    },
    {
        "school": "SONORA ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001532",
    },
    {
        "school": "Hidden Valley Elementary",
        "district": "Ross Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60000612911",
    },
    {
        "school": "Harold William Kolb",
        "district": "Dublin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001912927",
    },
    {
        "school": "Healdsburg Charter",
        "district": "Healdsburg Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004412872",
    },
    {
        "school": "Minarets Charter High",
        "district": "Chawanakee Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60011613035",
    },
    {
        "school": "Nova Opportunity",
        "district": "Twin Rivers Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133213020",
    },
    {
        "school": "Community Day School III",
        "district": "Bishop Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60140913022",
    },
    {
        "school": "Lammersville Elementary",
        "district": "Lammersville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141002500",
    },
    {
        "school": "Wicklund Elementary",
        "district": "Lammersville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141011412",
    },
    {
        "school": "Bethany Elementary",
        "district": "Lammersville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141012109",
    },
    {
        "school": "Sebastian Questa Elementary",
        "district": "Lammersville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141012551",
    },
    {
        "school": "Santa Barbara Charter",
        "district": "Santa Barbara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141402792",
    },
    {
        "school": "Adams Elementary",
        "district": "Santa Barbara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406015",
    },
    {
        "school": "Cleveland Elementary",
        "district": "Santa Barbara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406016",
    },
    {
        "school": "Dos Pueblos Senior High",
        "district": "Santa Barbara Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406017",
    },
    {
        "school": "Franklin Elementary",
        "district": "Santa Barbara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406018",
    },
    {
        "school": "Goleta Valley Junior High",
        "district": "Santa Barbara Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406020",
    },
    {
        "school": "Harding University Partnership",
        "district": "Santa Barbara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406021",
    },
    {
        "school": "La Colina Junior High",
        "district": "Santa Barbara Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406022",
    },
    {
        "school": "La Cuesta Continuation High",
        "district": "Santa Barbara Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60141406023",
    },
    {
        "school": "La Cumbre Junior High",
        "district": "Santa Barbara Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406024",
    },
    {
        "school": "Monroe Elementary",
        "district": "Santa Barbara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406025",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Santa Barbara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406028",
    },
    {
        "school": "San Marcos Senior High",
        "district": "Santa Barbara Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406029",
    },
    {
        "school": "Santa Barbara Junior High",
        "district": "Santa Barbara Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406030",
    },
    {
        "school": "Santa Barbara Senior High",
        "district": "Santa Barbara Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406031",
    },
    {
        "school": "Washington Elementary",
        "district": "Santa Barbara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141406032",
    },
    {
        "school": "Santa Barbara Community Academy",
        "district": "Santa Barbara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141408347",
    },
    {
        "school": "McKinley Elementary",
        "district": "Santa Barbara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141408980",
    },
    {
        "school": "Alta Vista Alternative High",
        "district": "Santa Barbara Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60141412435",
    },
    {
        "school": "Alta Vista Alternative Junior High",
        "district": "Santa Barbara Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60141412760",
    },
    {
        "school": "American Union Elementary",
        "district": "Washington Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141500147",
    },
    {
        "school": "West Fresno Middle",
        "district": "Washington Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141501784",
    },
    {
        "school": "West Fresno Elementary",
        "district": "Washington Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141501785",
    },
    {
        "school": "Washington High",
        "district": "Washington Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141506864",
    },
    {
        "school": "Easton Continuation High",
        "district": "Washington Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60141507896",
    },
    {
        "school": "Easton Community Day",
        "district": "Washington Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60141510785",
    },
    {
        "school": "Elm High",
        "district": "Washington Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60141512820",
    },
    {
        "school": "Banning PreK",
        "district": "Banning Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60384012834",
    },
    {
        "school": "BUSD School of Opportunity",
        "district": "Barstow Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60402012957",
    },
    {
        "school": "Berkeley Special Education Preschool",
        "district": "Berkeley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60474012843",
    },
    {
        "school": "California Preparatory Academy",
        "district": "Capistrano Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60744012894",
    },
    {
        "school": "Glacier Point Middle",
        "district": "Central Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797012888",
    },
    {
        "school": "Chicago Park Community Charter",
        "district": "Chicago Park Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60834013003",
    },
    {
        "school": "Center for Alternative Learning",
        "district": "Chico Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60837012830",
    },
    {
        "school": "Grand Terrace High Sch at the Ray Abril Jr. Edal Complex",
        "district": "Colton Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939012987",
    },
    {
        "school": "University Center Preschool",
        "district": "Conejo Valley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60964012840",
    },
    {
        "school": "Calero High",
        "district": "East Side Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61182013019",
    },
    {
        "school": "Early Learning Program",
        "district": "El Rancho Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218012841",
    },
    {
        "school": "Heritage Valley Independent Study",
        "district": "Fillmore Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61380012893",
    },
    {
        "school": "Firebaugh Community Day",
        "district": "Firebaugh-Las Deltas Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61384012917",
    },
    {
        "school": "Palm Canyon",
        "district": "Hacienda la Puente Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61632513034",
    },
    {
        "school": "Tierra Del Sol Continuation High",
        "district": "Kern High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61954013031",
    },
    {
        "school": "Kingsburg Independent Study High",
        "district": "Kingsburg Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61983012859",
    },
    {
        "school": "Discovery",
        "district": "Lancaster Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088012829",
    },
    {
        "school": "Early Childhood Education",
        "district": "Lancaster Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088012836",
    },
    {
        "school": "Buttercup Pre-School",
        "district": "Las Virgenes Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62100012838",
    },
    {
        "school": "Loma Vista Charter",
        "district": "Lindsay Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62187012847",
    },
    {
        "school": "Turner Academy at Tokay Colony",
        "district": "Lodi Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62223012997",
    },
    {
        "school": "Beach High-Intensive Learning Program",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62250013001",
    },
    {
        "school": "Special Education-Infant/Preschool Program",
        "district": "Los Angeles Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012837",
    },
    {
        "school": "Cesar E. Chavez Lrng Acads-Acad of Scientific Explr (ASE)",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012858",
    },
    {
        "school": "Dr. Maya Angelou Community High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012871",
    },
    {
        "school": "Performing Arts Community at Diego Rivera Learning Complex",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012885",
    },
    {
        "school": "Cesar E. Chavez Lrng Acads-Soc Just Humanitas Acad",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012895",
    },
    {
        "school": "Dr. Julian Nava Learning Academy",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012896",
    },
    {
        "school": "Rancho Dominguez Preparatory",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012898",
    },
    {
        "school": "Sotomayor Arts and Sciences Magnet",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012916",
    },
    {
        "school": "Cesar E. Chavez Lrng Acads-Arts/Theatre/Entertain Mag",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012926",
    },
    {
        "school": "Diego Rivera Learning Complex Green Design STEAM Academy",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012937",
    },
    {
        "school": "Valley Academy of Arts and Sciences",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012946",
    },
    {
        "school": "Cesar E. Chavez Lrng Acads-Tech Prep Acad",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012964",
    },
    {
        "school": "Public Service Community at Diego Rivera Learning Complex",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012971",
    },
    {
        "school": "Communication and Tech at Diego Rivera Lrng Complex",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271012973",
    },
    {
        "school": "Academy for Enriched Sciences",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013006",
    },
    {
        "school": "Academies of Education and Empowerment at Carson High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013040",
    },
    {
        "school": "Central Coast New Tech High",
        "district": "Lucia Mar Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62308013014",
    },
    {
        "school": "Applied Technology Center",
        "district": "Montebello Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62547012972",
    },
    {
        "school": "Monte Vista",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553012851",
    },
    {
        "school": "Rainbow Springs",
        "district": "Moreno Valley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580012835",
    },
    {
        "school": "Hurd Barrington Elementary",
        "district": "Newman-Crows Landing Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62720012979",
    },
    {
        "school": "San Jose Intermediate",
        "district": "Novato Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772012874",
    },
    {
        "school": "Infant and Preschool Program",
        "district": "Oakland Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805012842",
    },
    {
        "school": "Castlemont High",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805012992",
    },
    {
        "school": "Olga L. Reed Elementary",
        "district": "Orcutt Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62871002781",
    },
    {
        "school": "Condor High",
        "district": "Oxnard Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62927013007",
    },
    {
        "school": "Dos Caminos Dual Immersion",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62958012870",
    },
    {
        "school": "Sixth Grade Charter Academy at Petaluma Jr. High",
        "district": "Petaluma City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63023012877",
    },
    {
        "school": "Martin Luther King Jr. Junior High",
        "district": "Pittsburg Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63060013016",
    },
    {
        "school": "Cameron",
        "district": "West Contra Costa Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255012839",
    },
    {
        "school": "Roseland Creek Elementary",
        "district": "Roseland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63351013038",
    },
    {
        "school": "Telesis Academy of Science & Math",
        "district": "Rowland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375013012",
    },
    {
        "school": "El Puente",
        "district": "Salinas Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63398012977",
    },
    {
        "school": "Indian Springs High",
        "district": "San Bernardino City Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417013013",
    },
    {
        "school": "Knox Middle",
        "district": "San Diego Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432012892",
    },
    {
        "school": "Vista Del Mar",
        "district": "San Ysidro Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63522012993",
    },
    {
        "school": "Santa Clara Community Day",
        "district": "Santa Clara Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63543012999",
    },
    {
        "school": "Foothill Elementary",
        "district": "Sierra Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680512884",
    },
    {
        "school": "Sierra Junior High",
        "district": "Sierra Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680512899",
    },
    {
        "school": "Adelanto High",
        "district": "Victor Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63697212990",
    },
    {
        "school": "South Bay Charter",
        "district": "South Bay Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63735012891",
    },
    {
        "school": "Pacific Law Academy",
        "district": "Stockton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801012846",
    },
    {
        "school": "Tulare Support",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63987012991",
    },
    {
        "school": "Yucaipa Early Childhood Education Center",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64356012831",
    },
    {
        "school": "Competitive Edge Charter Academy (CECA)",
        "district": "Yucaipa-Calimesa Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64356012910",
    },
    {
        "school": "Inyo Co Small Steps Infant Toddler and PreSch Program",
        "district": "Inyo County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69101112832",
    },
    {
        "school": "Urban Corps of San Diego County Charter",
        "district": "Mono County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69105212994",
    },
    {
        "school": "COMMUNITY LEADERSHIP ACADEMY",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002001876",
    },
    {
        "school": "MOUNTAIN MIDDLE SCHOOL",
        "district": "State Charter School Institute",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006502",
    },
    {
        "school": "ALAMOSA OMBUDSMAN SCHOOL OF EXCELLENCE",
        "district": "Alamosa School District No. Re-11J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80207006508",
    },
    {
        "school": "MEADOWOOD CHILD DEVELOPMENT CENTER",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006495",
    },
    {
        "school": "CENTER VIRTUAL ACADEMY",
        "district": "Center Consolidated School District No. 26 Jt. of the count",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80285006513",
    },
    {
        "school": "VISTA ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006514",
    },
    {
        "school": "COLLEGIATE PREPARATORY ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006515",
    },
    {
        "school": "DENVER CENTER FOR 21ST-CENTURY LEARNING AT WYMAN",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006516",
    },
    {
        "school": "UNIVERSITY PREP - ARAPAHOE ST.",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006517",
    },
    {
        "school": "SWIGERT INTERNATIONAL SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006518",
    },
    {
        "school": "KIPP NORTHEAST DENVER MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006519",
    },
    {
        "school": "NOEL COMMUNITY ARTS SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006520",
    },
    {
        "school": "DCIS AT FORD",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006521",
    },
    {
        "school": "ESCALANTE-BIGGS ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006522",
    },
    {
        "school": "DSST: COLE MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006523",
    },
    {
        "school": "STEPHEN KNIGHT CENTER FOR EARLY EDUCATION",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006524",
    },
    {
        "school": "OAKLAND ELEMENTARY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006525",
    },
    {
        "school": "Northeast Early College",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006527",
    },
    {
        "school": "DCIS AT MONTBELLO",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006528",
    },
    {
        "school": "BEN FRANKLIN ACADEMY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006492",
    },
    {
        "school": "STEM SCHOOL HIGHLANDS RANCH",
        "district": "Douglas County School District No. Re 1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006493",
    },
    {
        "school": "CLOVERLEAF HOME EDUCATION",
        "district": "Douglas County School District No. Re 1",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80345006494",
    },
    {
        "school": "WORLD ACADEMY",
        "district": "Eagle County School District No. Re 50",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354006533",
    },
    {
        "school": "GRAND RIVER ACADEMY",
        "district": "Mesa County Valley School District No. 51",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435006498",
    },
    {
        "school": "WEST RIDGE ACADEMY",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441006504",
    },
    {
        "school": "CAREER READINESS ACADEMY",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80453006535",
    },
    {
        "school": "STEVENS ELEMENTARY SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006511",
    },
    {
        "school": "ASPEN RIDGE PREPARATORY SCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006530",
    },
    {
        "school": "RED HAWK ELEMENTARY",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006531",
    },
    {
        "school": "ST. VRAIN GLOBAL ONLINE ACADEMY",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80537006532",
    },
    {
        "school": "LOVELAND CLASSICAL SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540006534",
    },
    {
        "school": "PEAK VIRTUAL ACADEMY",
        "district": "Montrose County School District Re-1J",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80579006499",
    },
    {
        "school": "NORTHMOOR PRESCHOOL",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612006529",
    },
    {
        "school": "70 ONLINE",
        "district": "Pueblo County School District 70",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80615006496",
    },
    {
        "school": "CREST ACADEMY",
        "district": "Salida School District No. R-32",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80633006500",
    },
    {
        "school": "SALIDA EARLY CHILDHOOD CENTER",
        "district": "Salida School District No. R-32",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80633006501",
    },
    {
        "school": "PROSPECT RIDGE ACADEMY",
        "district": "Adams 12 Five Star Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690006507",
    },
    {
        "school": "CENTENNIAL BOCES HIGH SCHOOL",
        "district": "CENTENNIAL BOCES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "89920006526",
    },
    {
        "school": "Southwest Colorado eSchool",
        "district": "SAN JUAN BOCES",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "89930006497",
    },
    {
        "school": "Elm City College Preparatory School",
        "district": "Elm City College Preparatory School District",
        "level": "Other",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90021401548",
    },
    {
        "school": "Discovery Academy",
        "district": "Capitol Region Education Council",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001597",
    },
    {
        "school": "Museum Academy",
        "district": "Capitol Region Education Council",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001601",
    },
    {
        "school": "Marine Science Magnet High School",
        "district": "LEARN",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90345001606",
    },
    {
        "school": "Duggan School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483001602",
    },
    {
        "school": "Christina Early Education Center",
        "district": "Christina School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100020000349",
    },
    {
        "school": "Clayton Intermediate School",
        "district": "Smyrna School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100162000352",
    },
    {
        "school": "Cesar Chavez PCS for Public Policy - Parkside HS",
        "district": "Cesar Chavez PCS for Public Policy",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000500456",
    },
    {
        "school": "Langley ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000445",
    },
    {
        "school": "Capitol Hill Montessori School at Logan",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000446",
    },
    {
        "school": "Jefferson MS Academy",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000453",
    },
    {
        "school": "KIPP DC - Heights Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100452",
    },
    {
        "school": "AppleTree Early Learning Center PCS - Douglas Knoll",
        "district": "AppleTree Early Learning PCS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110005400447",
    },
    {
        "school": "AppleTree Early Learning Center PCS - Lincoln Park",
        "district": "AppleTree Early Learning PCS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110005400448",
    },
    {
        "school": "Maya Angelou Academy at New Beginnings formerly Oak Hill",
        "district": "DYRS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "DC",
        "nces_id": "110008700213",
    },
    {
        "school": "Sela PCS",
        "district": "Sela PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110008800461",
    },
    {
        "school": "Ingenuity Prep PCS",
        "district": "Ingenuity Prep PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110009000460",
    },
    {
        "school": "FLVS FULL TIME K-5",
        "district": "FL VIRTUAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120000207976",
    },
    {
        "school": "FLVS FULL-TIME 9-12",
        "district": "FL VIRTUAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120000207982",
    },
    {
        "school": "ALACHUA ESCHOOL (VIRTUAL FRANCHISE)",
        "district": "ALACHUA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003007945",
    },
    {
        "school": "NORTH CENTRAL FLORIDA PUBLIC CHARTER SCHOOL",
        "district": "ALACHUA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120003007948",
    },
    {
        "school": "ALACHUA LEARNING ACADEMY MIDDLE",
        "district": "ALACHUA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003007954",
    },
    {
        "school": "BAKER VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "BAKER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120006007975",
    },
    {
        "school": "RISING LEADERS ACADEMY",
        "district": "BAY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009008094",
    },
    {
        "school": "UNIVERSITY ACADEMY SABL INC",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009008103",
    },
    {
        "school": "BRADFORD VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "BRADFORD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120012008001",
    },
    {
        "school": "PROJECT SEARCH",
        "district": "BREVARD",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120015007957",
    },
    {
        "school": "BREVARD VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "BREVARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015007961",
    },
    {
        "school": "BREVARD VIRTUAL ESCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015007962",
    },
    {
        "school": "SOUTH AREA HEAD START",
        "district": "BREVARD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015008082",
    },
    {
        "school": "CHAMPIONSHIP ACADEMY OF DISTINCTION AT DAVIE",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018007977",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT UNIVERSITY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008073",
    },
    {
        "school": "SUNFIRE HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018008087",
    },
    {
        "school": "IMAGINE SCHOOLS PLANTATION  CAMPUS",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008090",
    },
    {
        "school": "SOMERSET ACADEMY MIRAMAR SOUTH",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008102",
    },
    {
        "school": "FRANKLIN ACADEMY F",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008116",
    },
    {
        "school": "WEST BROWARD ACADEMY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008118",
    },
    {
        "school": "FRANKLIN ACADEMY COOPER CITY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008128",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT COOPER CITY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008139",
    },
    {
        "school": "ATLANTIC MONTESSORI CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008151",
    },
    {
        "school": "ALPHA INTERNATIONAL ACADEMY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008155",
    },
    {
        "school": "SOMERSET ACADEMY POMPANO (K-5)",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008157",
    },
    {
        "school": "EVEREST CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008164",
    },
    {
        "school": "CALHOUN VIRTUAL FRANCHISE",
        "district": "CALHOUN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120021008042",
    },
    {
        "school": "CALHOUN VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "CALHOUN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120021008045",
    },
    {
        "school": "CLAY VIRTUAL ACADEMY",
        "district": "CLAY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030007967",
    },
    {
        "school": "CLAY VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "CLAY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030007969",
    },
    {
        "school": "MARCO ISLAND ACADEMY",
        "district": "COLLIER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033007999",
    },
    {
        "school": "COLUMBIA VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "COLUMBIA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036008022",
    },
    {
        "school": "SOMERSET ACADEMY CHARTER HIGH SCHOOL (SOUTH HOMESTEAD)",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007971",
    },
    {
        "school": "ARTHUR AND POLLY MAYS CONSERVATORY OF THE ARTS",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007972",
    },
    {
        "school": "SECONDARY STUDENT SUCCESS CENTER-804",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007979",
    },
    {
        "school": "GREEN SPRINGS HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007980",
    },
    {
        "school": "JOSE MARTI MAST 6-12 ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007981",
    },
    {
        "school": "NORTH PARK HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007983",
    },
    {
        "school": "NORTH GARDENS HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039007984",
    },
    {
        "school": "BRIDGEPREP ACADEMY OF VILLAGE GREEN",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039007987",
    },
    {
        "school": "CHAPMAN PARTNERSHIP EARLY CHILDHOOD CENTER N",
        "district": "MIAMI-DADE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008101",
    },
    {
        "school": "CHAPMAN PARTNERSHIP EARLY CHILDHOOD CENTER SOUTH",
        "district": "MIAMI-DADE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008119",
    },
    {
        "school": "YOUTH CO-OP PREPARATORY HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008125",
    },
    {
        "school": "LATIN BUILDERS ASSOCIATION CONSTRUCTION AND BUSINESS MANAGEM",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008132",
    },
    {
        "school": "EVERGLADES PREPARATORY ACADEMY HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008138",
    },
    {
        "school": "ALPHA CHARTER OF EXCELLENCE",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008147",
    },
    {
        "school": "MATER ACADEMY AT MOUNT SINAI",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008150",
    },
    {
        "school": "SOMERSET ACADEMY BAY MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008153",
    },
    {
        "school": "IMATER PREPARATORY ACADEMY HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008154",
    },
    {
        "school": "BRIDGEPREP ACADEMY INTERAMERICAN CAMPUS",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008159",
    },
    {
        "school": "SOMERSET ACADEMY BAY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008160",
    },
    {
        "school": "EVERGLADES PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008161",
    },
    {
        "school": "JUST ARTS AND MANAGEMENT CHARTER MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008165",
    },
    {
        "school": "DIXIE VIRTUAL INSTRUCTION PROGRAM",
        "district": "DIXIE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120045008031",
    },
    {
        "school": "SEACOAST CHARTER ACADEMY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008002",
    },
    {
        "school": "DUVAL VIRTUAL INSTRUCTION ACADEMY",
        "district": "DUVAL",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008007",
    },
    {
        "school": "DUVAL VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008008",
    },
    {
        "school": "WAVERLY ACADEMY",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008011",
    },
    {
        "school": "DUVAL CHARTER AT BAYMEADOWS",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008013",
    },
    {
        "school": "DUVAL CHARTER HIGH SCHOOL AT BAYMEADOWS",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008016",
    },
    {
        "school": "DUVAL MYCROSCHOOL OF INTEGRATED ACADEMICS AND TECHNOLOGIES",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048008096",
    },
    {
        "school": "GLOBAL LEARNING ACADEMY",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051007989",
    },
    {
        "school": "GILCHRIST VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "GILCHRIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120063008037",
    },
    {
        "school": "GLADES WEST",
        "district": "GLADES",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120066008058",
    },
    {
        "school": "GULF VIRTUAL FRANCHISE",
        "district": "GULF",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120069007970",
    },
    {
        "school": "HAMILTON VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "HAMILTON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120072008026",
    },
    {
        "school": "HARDEE VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "HARDEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120075007998",
    },
    {
        "school": "CONTRACTED SERVICES",
        "district": "HERNANDO",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120081007965",
    },
    {
        "school": "HERNANDO VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "HERNANDO",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081007966",
    },
    {
        "school": "HERNANDO VIRTUAL INSTRUCTION",
        "district": "HERNANDO",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081008127",
    },
    {
        "school": "HILLSBOROUGH VIRTUAL INSTRUCTION COURSE OFFERINGS",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008047",
    },
    {
        "school": "WALKER MIDDLE MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008049",
    },
    {
        "school": "PIVOT CHARTER SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008050",
    },
    {
        "school": "NEW SPRINGS SCHOOLS",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008052",
    },
    {
        "school": "HILLSBOROUGH VIRTUAL SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008053",
    },
    {
        "school": "WINTHROP CHARTER SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008054",
    },
    {
        "school": "ACTS",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087008057",
    },
    {
        "school": "ROLAND PARK K-8 MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008061",
    },
    {
        "school": "LUTZ PREPARATORY SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008063",
    },
    {
        "school": "WILLIS PETERS EXCEPTIONAL CENTER",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087008067",
    },
    {
        "school": "RCMA LEADERSHIP ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008078",
    },
    {
        "school": "LOPEZ EXCEPTIONAL STUDENT EDUCATION CENTER",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087008084",
    },
    {
        "school": "HENDERSON HAMMOCK CHARTER SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008104",
    },
    {
        "school": "WEST UNIVERSITY CHARTER HIGH",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087008112",
    },
    {
        "school": "KIDS COMMUNITY COLLEGE CHARTER SCHOOL SOUTHEAST HILLSBOROUGH",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008137",
    },
    {
        "school": "BELL CREEK ACADEMY HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008148",
    },
    {
        "school": "HOLMES VIRTUAL-FRANCHISE PAEC-FLVS",
        "district": "HOLMES",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120090008039",
    },
    {
        "school": "LEE COUNTY VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108008048",
    },
    {
        "school": "LEE VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108008051",
    },
    {
        "school": "HERITAGE CHARTER ACADEMY OF CAPE CORAL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108008062",
    },
    {
        "school": "TORTUGA PRESERVE ELEMENTARY SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108008105",
    },
    {
        "school": "HARNS MARSH MIDDLE SCHOOL",
        "district": "LEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108008167",
    },
    {
        "school": "LEON VIRTUAL ACADEMY",
        "district": "LEON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111008021",
    },
    {
        "school": "LEON VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "LEON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111008023",
    },
    {
        "school": "GOVERNOR'S CHARTER SCHOOL",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111008156",
    },
    {
        "school": "LIBERTY VIRTUAL FRANCHISE",
        "district": "LIBERTY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120117007958",
    },
    {
        "school": "MADISON VIRTUAL FRANCHISE",
        "district": "MADISON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120120007997",
    },
    {
        "school": "MANATEE VIRTUAL SCHOOL ( VIRTUAL FRANCHISE)",
        "district": "MANATEE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123008027",
    },
    {
        "school": "MANATEE CHARTER SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123008145",
    },
    {
        "school": "OCEAN STUDIES CHARTER",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132007956",
    },
    {
        "school": "SOMERSET ISLAND PREP",
        "district": "MONROE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132007960",
    },
    {
        "school": "OKALOOSA STEMM CENTER",
        "district": "OKALOOSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138008072",
    },
    {
        "school": "ASPIRE ACADEMY CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144007942",
    },
    {
        "school": "UCP TRANSITIONAL LEARNING ACADEMY HIGH CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120144007944",
    },
    {
        "school": "OCVS VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "ORANGE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007950",
    },
    {
        "school": "ACCESS CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120144007952",
    },
    {
        "school": "INNOVATION MONTESSORI OCOEE",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144007955",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT CHICKASAW TRAIL",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008091",
    },
    {
        "school": "ACCELERATION WEST",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144008097",
    },
    {
        "school": "SUNSHINE HIGH SCHOOL-GREATER ORLANDO CAMPUS",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144008152",
    },
    {
        "school": "OSCEOLA VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008034",
    },
    {
        "school": "FLORIDA CYBER CHARTER ACADEMY AT OSCEOLA",
        "district": "OSCEOLA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008079",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT POINCIANA",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008123",
    },
    {
        "school": "FOUR CORNERS UPPER SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008141",
    },
    {
        "school": "PALM BEACH PREPARATORY CHARTER ACADEMY",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150008009",
    },
    {
        "school": "GARDENS SCHOOL OF TECHNOLOGY ARTS INC",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008014",
    },
    {
        "school": "PALM BEACH VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008015",
    },
    {
        "school": "EDUCATIONAL SERVICES PROGRAM-EAST",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150008018",
    },
    {
        "school": "BEN GAMLA-PALM BEACH",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008019",
    },
    {
        "school": "EDUCATIONAL SERVICES PROGRAM-WEST",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150008020",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT WEST PALM BEACH",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008162",
    },
    {
        "school": "WORTHINGTON HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150008168",
    },
    {
        "school": "QUANTUM HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150008169",
    },
    {
        "school": "BAYCARE BEHAVIORAL HEALTH",
        "district": "PASCO",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120153008032",
    },
    {
        "school": "PASCO VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "PASCO",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008033",
    },
    {
        "school": "PASCO VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008035",
    },
    {
        "school": "PINELLAS VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156007941",
    },
    {
        "school": "PINELLAS PRIMARY ACADEMY",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156007943",
    },
    {
        "school": "PINELLAS VIRTUAL K-12",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156007951",
    },
    {
        "school": "PLATO SEMINOLE",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156007953",
    },
    {
        "school": "PINELLAS ACADEMY OF MATH AND SCIENCE",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008100",
    },
    {
        "school": "PLATO ACADEMY CHARTER SCHOOL TARPON SPRINGS",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008135",
    },
    {
        "school": "PINELLAS MYCROSCHOOL OF INTEGRATED ACADEMICS AND TECHNOLOGIE",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156008144",
    },
    {
        "school": "FRESH START COMMUNITY SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159007992",
    },
    {
        "school": "POLK VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "POLK",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159007993",
    },
    {
        "school": "POLK COUNTY SHERIFFS REGIONAL DETENTION CENTER",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159007994",
    },
    {
        "school": "PUTNAM VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "PUTNAM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162008000",
    },
    {
        "school": "PUTNAM ACADEMY OF ARTS AND SCIENCES",
        "district": "PUTNAM",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162008064",
    },
    {
        "school": "SANTA ROSA VIRTUAL INSTRUCTION COURSE OFFERINGS",
        "district": "SANTA ROSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165008065",
    },
    {
        "school": "SKY ACADEMY VENICE",
        "district": "SARASOTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168008043",
    },
    {
        "school": "SARASOTA VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "SARASOTA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168008044",
    },
    {
        "school": "GALILEO SCHOOL FOR GIFTED LEARNING",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171007937",
    },
    {
        "school": "SEMINOLE ACADEMY OF DIGITAL LEARNING",
        "district": "SEMINOLE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171008113",
    },
    {
        "school": "SEMINOLE COUNTY DETENTION CENTER",
        "district": "SEMINOLE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120171008121",
    },
    {
        "school": "ST. AUGUSTINE PUBLIC MONTESSORI SCHOOL (SAPMS)",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174008088",
    },
    {
        "school": "MOSAIC DIGITAL ACADEMY PT ST. LUCIE VIRTUAL INSTRUC (COURSE",
        "district": "ST. LUCIE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177007988",
    },
    {
        "school": "SOMERSET COLLEGE PREPARATORY ACADEMY",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177008089",
    },
    {
        "school": "SUMTER VIRTUAL FRANCHISE",
        "district": "SUMTER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120180007964",
    },
    {
        "school": "TAYLOR VIRTUAL FRANCHISE",
        "district": "TAYLOR",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120186007995",
    },
    {
        "school": "UNION VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "UNION",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120189008029",
    },
    {
        "school": "VOLUSIA VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "VOLUSIA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192008036",
    },
    {
        "school": "BURNS SCIENCE AND TECHNOLOGY CHARTER SCHOOL",
        "district": "VOLUSIA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192008038",
    },
    {
        "school": "SAMSULA ACADEMY",
        "district": "VOLUSIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192008041",
    },
    {
        "school": "WASHINGTON VIRTUAL FRANCHISE",
        "district": "WASHINGTON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201008010",
    },
    {
        "school": "FSUS VIRTUAL SCHOOL FRANCHISE",
        "district": "FSU LAB SCH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201308056",
    },
    {
        "school": "P. K. YONGE VIRTUAL FRANCHISE",
        "district": "UF LAB SCH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201507968",
    },
    {
        "school": "KIPP Atlanta Collegiate Academy",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004059",
    },
    {
        "school": "Ivy Preparatory Academy- Inc",
        "district": "State Charter Schools- Ivy Prep Academy at Kirkwood for Gir",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130022604023",
    },
    {
        "school": "Georgia Connections Academy",
        "district": "State Charter Schools- Georgia Connections Academy",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130022704031",
    },
    {
        "school": "Cherokee Charter Academy",
        "district": "State Charter Schools- Cherokee Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130023004051",
    },
    {
        "school": "Woodville-Tompkins Technical and Career High School",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102004044",
    },
    {
        "school": "Indian Knoll Elementary",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111004033",
    },
    {
        "school": "Baker Place Elementary",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141004042",
    },
    {
        "school": "New Glennwood Elementary",
        "district": "City Schools of Decatur",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130168004028",
    },
    {
        "school": "Museum School Avondale Estates",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174004039",
    },
    {
        "school": "New Manchester High School",
        "district": "Douglas County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130186004034",
    },
    {
        "school": "Moore Street Facility",
        "district": "Dublin City",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130187004050",
    },
    {
        "school": "Hillcrest Elementary",
        "district": "Dublin City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130187004061",
    },
    {
        "school": "Hapeville Charter Career Academy",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004045",
    },
    {
        "school": "Moore Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004026",
    },
    {
        "school": "Gwinnett Online Campus",
        "district": "Gwinnett County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004057",
    },
    {
        "school": "Hilliard A. Wilbanks Middle School",
        "district": "Habersham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258004032",
    },
    {
        "school": "Coahulla Creek High School",
        "district": "Whitfield County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130570004053",
    },
    {
        "school": "INSIGHT SCHOOL OF IDAHO",
        "district": "IDAHO VIRTUAL ACADEMY INC.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160000401035",
    },
    {
        "school": "IDAHO CONNECTS ONLINE ALTERNATIVE SCHOOL",
        "district": "IDAHO VIRTUAL EDUCATION PARTNERS INC.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160014801023",
    },
    {
        "school": "SILVER TRAIL ELEMENTARY SCHOOL",
        "district": "KUNA JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160177001029",
    },
    {
        "school": "REBOUND SCHOOL OF OPPORTUNITY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160210001025",
    },
    {
        "school": "PRESCHOOL CENTER",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160219001033",
    },
    {
        "school": "MURTAUGH SCHOOLS",
        "district": "MURTAUGH JOINT DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160231001034",
    },
    {
        "school": "HIGH DESERT",
        "district": "SHOSHONE JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160294001026",
    },
    {
        "school": "RENDEZVOUS UPPER ELEMENTARY SCHOOL",
        "district": "TETON COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160318001022",
    },
    {
        "school": "Academic Behavior&Community Acad",
        "district": "Adam/Brwn/Cass/Morgn/Pik/Sctt ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016206156",
    },
    {
        "school": "PACE Alternative School",
        "district": "Adam/Brwn/Cass/Morgn/Pik/Sctt ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016206163",
    },
    {
        "school": "ECHO Juvenile Detention Ctr",
        "district": "Frankln/Johnsn/Massc/Willimsn ROE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018206181",
    },
    {
        "school": "Premier Academy Morris TAOEP",
        "district": "Grundy/Kendall ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018406203",
    },
    {
        "school": "Regl Inst Scholastic Excellence",
        "district": "Region 07 South Cook ISC 4",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170018806165",
    },
    {
        "school": "Oak Ridge RSSP",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106184",
    },
    {
        "school": "Mades-Johnstone RSSP",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106185",
    },
    {
        "school": "East Aurora HS RSSP",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106186",
    },
    {
        "school": "West Aurora HS RSSP",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106187",
    },
    {
        "school": "Peoria Regional High School",
        "district": "Peoria ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020306202",
    },
    {
        "school": "MLK A R T Program",
        "district": "Rock Island ROE",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020406200",
    },
    {
        "school": "Coolidge RSSP",
        "district": "Rock Island ROE",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020406201",
    },
    {
        "school": "ROE 53 Academy",
        "district": "Mason/Tazewell/Woodford ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020906194",
    },
    {
        "school": "Lincoln School ALOP",
        "district": "Will ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170021306192",
    },
    {
        "school": "West 40-Sr. Plus",
        "district": "Region 06 West Cook ISC 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170022106161",
    },
    {
        "school": "West 40 ALOP Achievers",
        "district": "Region 06 West Cook ISC 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170022106162",
    },
    {
        "school": "Odin Attendance Center K-8",
        "district": "Odin PSD 722",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170140403079",
    },
    {
        "school": "Odin Attendance Center 9-12",
        "district": "Odin PSD 722",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170140403080",
    },
    {
        "school": "Child Service Center Preschool",
        "district": "Aurora East USD 131",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468006188",
    },
    {
        "school": "Glenwood Elementary School",
        "district": "Ball Chatham CUSD 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170492006196",
    },
    {
        "school": "South Shore Intl Col Prep HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006170",
    },
    {
        "school": "STEM Magnet Academy Elem",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006173",
    },
    {
        "school": "Founders Elementary School",
        "district": "DeKalb CUSD 428",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200006172",
    },
    {
        "school": "East Dubuque Jr High",
        "district": "East Dubuque USD 119",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171305006158",
    },
    {
        "school": "Isaac Singleton Elem Sch",
        "district": "Joliet PSD 86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058006191",
    },
    {
        "school": "Neponset Grade School",
        "district": "Kewanee CUSD 229",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172100002954",
    },
    {
        "school": "Evans Junior High School",
        "district": "McLean County USD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862006180",
    },
    {
        "school": "Woodruff Career & Tech Center",
        "district": "Peoria SD 150",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123006199",
    },
    {
        "school": "Rochester Elem 2-3",
        "district": "Rochester CUSD 3A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173432006197",
    },
    {
        "school": "Summerdale Early Childhood Center",
        "district": "Rockford SD 205",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451006164",
    },
    {
        "school": "Warrensburg-Latham Middle Sch",
        "district": "Warrensburg-Latham CUSD 11",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174083006189",
    },
    {
        "school": "Career Academy High School",
        "district": "Career Academy High School",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180010102521",
    },
    {
        "school": "RISE Learning Center",
        "district": "Southside Sp Srvs Of Marion Co",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180010502502",
    },
    {
        "school": "LaCrosse School",
        "district": "Tri-Township Cons School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180010702511",
    },
    {
        "school": "Wanatah School",
        "district": "Tri-Township Cons School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180010702520",
    },
    {
        "school": "Damar Charter Academy",
        "district": "Damar Charter Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180010802503",
    },
    {
        "school": "Richard L Johnson Early Educ Cntr",
        "district": "Bartholomew Con School Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180036002506",
    },
    {
        "school": "Bloomington Graduation School",
        "district": "Monroe County Community Sch Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063002498",
    },
    {
        "school": "Paul Harding Jr High School",
        "district": "East Allen County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285002509",
    },
    {
        "school": "Woodlan Elementary School",
        "district": "East Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285002514",
    },
    {
        "school": "Prince Chapman Academy",
        "district": "East Allen County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285002519",
    },
    {
        "school": "East Allen University",
        "district": "East Allen County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180285002532",
    },
    {
        "school": "Early Childhood Center",
        "district": "Eastbrook Community Sch Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180303002505",
    },
    {
        "school": "Impact Institutue",
        "district": "DeKalb Co Eastern Com Sch Dist",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "180306000842",
    },
    {
        "school": "North Junior High School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345002504",
    },
    {
        "school": "Oak Hill Elementary",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345002507",
    },
    {
        "school": "Lillie Idella Kitley Elementary",
        "district": "Franklin Township Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180375002499",
    },
    {
        "school": "Center for Inquiry School 27",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002510",
    },
    {
        "school": "Northwest Community Middle School",
        "district": "Indianapolis Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002528",
    },
    {
        "school": "Oakland High School",
        "district": "Lafayette School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540002518",
    },
    {
        "school": "North White Elementary School",
        "district": "North White School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180813002500",
    },
    {
        "school": "North White Middle School",
        "district": "North White School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180813002522",
    },
    {
        "school": "Wyandotte Elementary",
        "district": "Tippecanoe School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181134002501",
    },
    {
        "school": "Warrick County Preschool",
        "district": "Warrick County School Corp",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "181239002512",
    },
    {
        "school": "Achieve Virtual Education Academy",
        "district": "M S D Wayne Township",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181281002516",
    },
    {
        "school": "North Butler Jr/Sr High School",
        "district": "North Butler Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190345000785",
    },
    {
        "school": "Andrew Middle School",
        "district": "Andrew Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190363002136",
    },
    {
        "school": "Prairie Ridge Middle School",
        "district": "Ankeny Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369002139",
    },
    {
        "school": "CAM North Elementary",
        "district": "CAM Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190594000069",
    },
    {
        "school": "CAM High School",
        "district": "CAM Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190594000070",
    },
    {
        "school": "Center Point-Urbana Intermediate School",
        "district": "Center Point-Urbana Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190666002150",
    },
    {
        "school": "Central DeWitt Intermediate School",
        "district": "Central DeWitt School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190681002144",
    },
    {
        "school": "College View Elementary",
        "district": "Council Bluffs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190822002146",
    },
    {
        "school": "Woodlawn Early Childhood Center",
        "district": "Des Moines Independent Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897002140",
    },
    {
        "school": "Mitchell Early Childhood Center",
        "district": "Des Moines Independent Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897002166",
    },
    {
        "school": "IKM-Manning High School",
        "district": "IKM-Manning Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191488001050",
    },
    {
        "school": "East Mills Elementary School",
        "district": "East Mills Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191824001230",
    },
    {
        "school": "Midland Elementary",
        "district": "Midland Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191920002162",
    },
    {
        "school": "Central Springs Elem. School - Nora Springs",
        "district": "Central Springs Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192076001235",
    },
    {
        "school": "Central Springs Middle School",
        "district": "Central Springs Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192076001236",
    },
    {
        "school": "Hopewell Elementary",
        "district": "Pleasant Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192311002164",
    },
    {
        "school": "West Fork Elementary at Rockwell",
        "district": "West Fork Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192592001419",
    },
    {
        "school": "West Fork Middle School",
        "district": "West Fork Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192592002101",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640002165",
    },
    {
        "school": "East Sac County Elementary Sac Building",
        "district": "East Sac County Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192958001438",
    },
    {
        "school": "East Sac County Middle School",
        "district": "East Sac County Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192958001511",
    },
    {
        "school": "Waverly-Shell Rock Middle School",
        "district": "Waverly-Shell Rock Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193054002163",
    },
    {
        "school": "Central Plains Jr. Sr. High School",
        "district": "Central Plains",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200034902043",
    },
    {
        "school": "Central Plains Elementary School - Holyrood",
        "district": "Central Plains",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200034902044",
    },
    {
        "school": "Riverside Virtual High School",
        "district": "Riverside",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035102051",
    },
    {
        "school": "Nemaha Central Elementary and Middle School",
        "district": "Nemaha Central",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035302048",
    },
    {
        "school": "Nemaha Central High School",
        "district": "Nemaha Central",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035302050",
    },
    {
        "school": "Andover eCademy",
        "district": "Andover",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200336002040",
    },
    {
        "school": "Erie High School",
        "district": "Erie-Galesburg",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200600002046",
    },
    {
        "school": "Eisenhower High School",
        "district": "Goddard",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200654002052",
    },
    {
        "school": "21st Century Learning Academy/Kiowa County",
        "district": "Kiowa County",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200672002055",
    },
    {
        "school": "Jefferson School",
        "district": "Independence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200765002054",
    },
    {
        "school": "Piper East Elementary School",
        "district": "Piper-Kansas City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201068002041",
    },
    {
        "school": "Aubry Bend Middle School",
        "district": "Blue Valley",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200002045",
    },
    {
        "school": "Valley Center Intermediate School",
        "district": "Valley Center Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201251002038",
    },
    {
        "school": "Bartlett Educational Center",
        "district": "Erlanger-Elsmere Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210174002313",
    },
    {
        "school": "Thelma B. Johnson Early Learning Center",
        "district": "Henderson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210271002306",
    },
    {
        "school": "Farristown Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372002311",
    },
    {
        "school": "Owensboro Innovation Middle School",
        "district": "Owensboro Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210459002304",
    },
    {
        "school": "Owensboro Middle School",
        "district": "Owensboro Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210459002305",
    },
    {
        "school": "Shelby County Summer School",
        "district": "Shelby County",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532002307",
    },
    {
        "school": "Jackson Academy High School",
        "district": "Warren County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210573002302",
    },
    {
        "school": "Williamstown Sr. High",
        "district": "Williamstown Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210594002308",
    },
    {
        "school": "Sorrento Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009002326",
    },
    {
        "school": "University View Academy Inc. (FRM LA Connections)",
        "district": "University View Academy Inc. (FRM LA Connections)",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015702322",
    },
    {
        "school": "Lake Charles Charter Academy",
        "district": "Lake Charles Charter Academy Foundation Inc.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015802319",
    },
    {
        "school": "Lycee Francais de la Nouvelle-Orleans",
        "district": "Lycee Francais de la Nouvelle-Orleans",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220015902331",
    },
    {
        "school": "New Orleans Military & Maritime Academy",
        "district": "New Orleans Military & Maritime Academy",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220016002327",
    },
    {
        "school": "Slaughter Community Charter School",
        "district": "East Feliciana Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220060002321",
    },
    {
        "school": "Bayou Community Academy Charter School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090002330",
    },
    {
        "school": "Sterlington Middle School",
        "district": "Ouachita Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120002325",
    },
    {
        "school": "Abney Elementary Early Childhood Center",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165002317",
    },
    {
        "school": "Henry Mayfield Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165002328",
    },
    {
        "school": "Joseph B. Lancaster Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165002329",
    },
    {
        "school": "Brewer Community School",
        "district": "Brewer Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230351023130",
    },
    {
        "school": "Harriet Beecher Stowe Elementary",
        "district": "Brunswick Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230378023129",
    },
    {
        "school": "Falmouth Elementary School",
        "district": "Falmouth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230567023132",
    },
    {
        "school": "Great Falls Elementary School",
        "district": "Gorham Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230606023126",
    },
    {
        "school": "Greenville Consolidated School",
        "district": "Greenville Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230625023138",
    },
    {
        "school": "Ocean Avenue",
        "district": "Portland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230993023131",
    },
    {
        "school": "Valley Rivers Middle School",
        "district": "MSAD 27",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231110023137",
    },
    {
        "school": "Eric L Knowlton School",
        "district": "RSU 60/MSAD 60",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231470023135",
    },
    {
        "school": "Spruce Mountain Middle School",
        "district": "RSU 73",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480523133",
    },
    {
        "school": "So Aroostook School",
        "district": "RSU 50",
        "level": "Other",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480600590",
    },
    {
        "school": "Cornville Regional Charter School",
        "district": "Cornville Regional Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480723136",
    },
    {
        "school": "Maine Academy of Natural Sciences",
        "district": "Maine Academy of Natural Sciences",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480823134",
    },
    {
        "school": "Baltimore Design School",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001703",
    },
    {
        "school": "Red Pump Elementary School",
        "district": "Harford County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240039001698",
    },
    {
        "school": "Cradlerock Elementary",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001699",
    },
    {
        "school": "Lake Elkhorn Middle",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001700",
    },
    {
        "school": "Imagine Andrews Public Charter",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001701",
    },
    {
        "school": "Academy of Health Sciences at PGCC",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001704",
    },
    {
        "school": "Imagine Foundations at Morningside PCS",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001706",
    },
    {
        "school": "Chesapeake Math and IT Public Charter",
        "district": "Prince George's County Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001708",
    },
    {
        "school": "Ruth Ann Monroe Primary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001707",
    },
    {
        "school": "Community Day Charter Public School - R. Kingman Webster",
        "district": "Community Day Charter Public School - R. Kingman Webster (Di",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250053502719",
    },
    {
        "school": "Veritas Preparatory Charter School",
        "district": "Veritas Preparatory Charter School (District)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250053602714",
    },
    {
        "school": "KIPP Academy Boston Charter School",
        "district": "KIPP Academy Boston Charter School (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250053702716",
    },
    {
        "school": "Community Day Charter Public School - Gateway",
        "district": "Community Day Charter Public School - Gateway (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250053802717",
    },
    {
        "school": "Somerset Berkley Regional High School",
        "district": "Somerset Berkley Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054102728",
    },
    {
        "school": "Lura A. White Elementary School",
        "district": "Ayer Shirley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054202731",
    },
    {
        "school": "Page Hilltop Elementary School",
        "district": "Ayer Shirley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054202736",
    },
    {
        "school": "Ayer Shirley Regional Middle School",
        "district": "Ayer Shirley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054202737",
    },
    {
        "school": "Ayer Shirley Regional High School",
        "district": "Ayer Shirley School District",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054202738",
    },
    {
        "school": "Abington Early Education Program",
        "district": "Abington",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250165002727",
    },
    {
        "school": "Mario Umana Academy",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002721",
    },
    {
        "school": "TechBoston Academy",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002725",
    },
    {
        "school": "West Roxbury Academy",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002729",
    },
    {
        "school": "Freetown Elementary School",
        "district": "Freetown-Lakeville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250507002735",
    },
    {
        "school": "Assawompset Elementary School",
        "district": "Freetown-Lakeville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250507002739",
    },
    {
        "school": "Laura Lee Therapeutic Day School",
        "district": "Lowell",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702002726",
    },
    {
        "school": "Leblanc Therapeutic Day School",
        "district": "Lowell",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702002732",
    },
    {
        "school": "Mary K. Goode Elementary School",
        "district": "Middleborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250777002741",
    },
    {
        "school": "Springfield Public Day Elementary School",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002723",
    },
    {
        "school": "Springfield High School",
        "district": "Springfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002724",
    },
    {
        "school": "South End Middle School",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002733",
    },
    {
        "school": "Liberty Preparatory Academy",
        "district": "Springfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002734",
    },
    {
        "school": "Springfield Public Day Middle School",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002740",
    },
    {
        "school": "Springfield Public Day High School",
        "district": "Springfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002742",
    },
    {
        "school": "Gateway to College at Holyoke Community College",
        "district": "Springfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002743",
    },
    {
        "school": "Balliet Middle School",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002744",
    },
    {
        "school": "Early Childhood Center",
        "district": "Wachusett",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251188002730",
    },
    {
        "school": "Ascent High School",
        "district": "Bad Axe Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260001708240",
    },
    {
        "school": "Bridge Academy West",
        "district": "Bridge Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260030608288",
    },
    {
        "school": "Relevant Academy of Eaton County",
        "district": "Relevant Academy of Eaton County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260098208243",
    },
    {
        "school": "The Greenspire School",
        "district": "The Greenspire School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260098308281",
    },
    {
        "school": "FlexTech High School",
        "district": "FlexTech High School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260098408257",
    },
    {
        "school": "Regent Park Scholars Charter Academy",
        "district": "Regent Park Scholars Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260098508272",
    },
    {
        "school": "American International Academy  Elementary",
        "district": "American International Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260098608231",
    },
    {
        "school": "Hope Academy of West Michigan",
        "district": "Hope Academy of West Michigan",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260098808264",
    },
    {
        "school": "Arbor Preparatory High School",
        "district": "Arbor Preparatory High School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260098908273",
    },
    {
        "school": "Forest Academy",
        "district": "Forest Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260099008277",
    },
    {
        "school": "Blue Water Middle College Academy",
        "district": "Blue Water Middle College",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260099208258",
    },
    {
        "school": "Jalen Rose Leadership Academy",
        "district": "Jalen Rose Leadership Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260099308233",
    },
    {
        "school": "Noor International Academy",
        "district": "Noor International Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260099508260",
    },
    {
        "school": "East Arbor Charter Academy",
        "district": "East Arbor Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260099608237",
    },
    {
        "school": "South Canton Scholars Charter Academy",
        "district": "South Canton Scholars Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260099708216",
    },
    {
        "school": "New Paradigm Loving Academy",
        "district": "New Paradigm Glazer-Loving Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260099804837",
    },
    {
        "school": "Detroit Innovation Academy",
        "district": "Detroit Innovation Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260100308307",
    },
    {
        "school": "Armada Continuing Education Center",
        "district": "Armada Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260324008269",
    },
    {
        "school": "Academy 21",
        "district": "Center Line Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260858008255",
    },
    {
        "school": "Charlotte Upper Elementary School",
        "district": "Charlotte Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260877008247",
    },
    {
        "school": "Creative Learning Center  Dearborn",
        "district": "Clintondale Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261008008235",
    },
    {
        "school": "Creative Learning Center  Highland Park",
        "district": "Clintondale Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261008008252",
    },
    {
        "school": "Forest Park Elementary School",
        "district": "Eastpointe Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261245008234",
    },
    {
        "school": "Crescentwood Elementary School",
        "district": "Eastpointe Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261245008244",
    },
    {
        "school": "Greyhound Central Elementary School",
        "district": "Eaton Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261269008236",
    },
    {
        "school": "Escanaba Junior High",
        "district": "Escanaba Area Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261350008294",
    },
    {
        "school": "Fowlerville Online Learning Academy",
        "district": "Fowlerville Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261473008221",
    },
    {
        "school": "Lathers Early Childhood and Kindergarten Center",
        "district": "Garden City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261554008140",
    },
    {
        "school": "Grand Rapids Learning Center",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261644008226",
    },
    {
        "school": "Gull Lake Gateway Academy",
        "district": "Gull Lake Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261725008228",
    },
    {
        "school": "Gull Lake Virtual Partnership",
        "district": "Gull Lake Community Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261725008242",
    },
    {
        "school": "Harper Academy",
        "district": "Harper Woods The School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261776008223",
    },
    {
        "school": "Gier Elementary School",
        "district": "Hillsdale Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261839008143",
    },
    {
        "school": "Bailey Early Childhood Center",
        "district": "Hillsdale Community Schools",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261839008186",
    },
    {
        "school": "Hudson Tech Alternative",
        "district": "Hudson Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261881008227",
    },
    {
        "school": "Jenison International Academy",
        "district": "Jenison Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261983008230",
    },
    {
        "school": "Kent City Alternative High School",
        "district": "Kent City Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262031008219",
    },
    {
        "school": "Dwight Rich School of the Arts",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115008263",
    },
    {
        "school": "Lake Huron Virtual  Hybrid High School",
        "district": "New Haven Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262523008215",
    },
    {
        "school": "WAY Niles",
        "district": "Niles Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262556008282",
    },
    {
        "school": "Eastside Connections School",
        "district": "Niles Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262556008289",
    },
    {
        "school": "Niles Virtual School",
        "district": "Niles Community Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262556008297",
    },
    {
        "school": "Oxford Virtual Academy",
        "district": "Oxford Community Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262724008274",
    },
    {
        "school": "Suttons Bay Virtual School",
        "district": "Suttons Bay Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263336008250",
    },
    {
        "school": "WAY  Watervliet High School",
        "district": "Watervliet School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263546008276",
    },
    {
        "school": "Dunes Alternative High School",
        "district": "West Ottawa Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263591008224",
    },
    {
        "school": "Maple Grove Alternative High School",
        "district": "Woodhaven-Brownstown School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263648508308",
    },
    {
        "school": "Zeeland Quest",
        "district": "Zeeland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263666008295",
    },
    {
        "school": "Adams Elementary School",
        "district": "Zeeland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263666008300",
    },
    {
        "school": "The Early College  Lansing Community College",
        "district": "Ingham ISD",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268052008246",
    },
    {
        "school": "Great Lakes Bay Early College",
        "district": "Saginaw ISD",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268093008290",
    },
    {
        "school": "NORTH WOODS ELEMENTARY",
        "district": "ST. LOUIS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000804456",
    },
    {
        "school": "NORTH WOODS SECONDARY",
        "district": "ST. LOUIS COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000804459",
    },
    {
        "school": "SOUTH RIDGE ELEMENTARY",
        "district": "ST. LOUIS COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000804509",
    },
    {
        "school": "SOUTH RIDGE SECONDARY",
        "district": "ST. LOUIS COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270000804544",
    },
    {
        "school": "WARREN-ALVARADO-OLSO ALP",
        "district": "WARREN-ALVARADO-OSLO SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002404493",
    },
    {
        "school": "PRAIRIE CARE EDINA - PHP",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504467",
    },
    {
        "school": "WEST ACADEMY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504471",
    },
    {
        "school": "4126 - PRAIRIE SEEDS ACADEMY - IS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504476",
    },
    {
        "school": "Prairie Care Brooklyn Park - IHP",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504532",
    },
    {
        "school": "HEADWAY ACADEMY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504533",
    },
    {
        "school": "PraIrie Care Brooklyn Park Day Prg",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504537",
    },
    {
        "school": "OPTIONS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002604516",
    },
    {
        "school": "ANTHONY LOUIS CENTER",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002604519",
    },
    {
        "school": "SAIL PROGRAM",
        "district": "HIAWATHA VALLEY ED. DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270005504535",
    },
    {
        "school": "SWWC ELC - Belview",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270008604438",
    },
    {
        "school": "PIPESTONE LEARNING CENTER",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270008604547",
    },
    {
        "school": "PARNASSUS PREP SCH-GRAMMAR",
        "district": "PARNASSUS PREPARATORY CHARTER SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270033304524",
    },
    {
        "school": "HENNEPIN ELEMENTARY SCHOOL",
        "district": "HENNEPIN ELEMENTARY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270033504554",
    },
    {
        "school": "STEP ACADEMY CHARTER SCHOOL",
        "district": "STEP ACADEMY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036704507",
    },
    {
        "school": "CORNERSTONE MONTESSORI ELEMENTARY",
        "district": "CORNERSTONE MONTESSORI ELEMENTARY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036804523",
    },
    {
        "school": "Discovery Woods",
        "district": "Discovery Woods",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036904444",
    },
    {
        "school": "ROCHESTER STEM ACADEMY",
        "district": "ROCHESTER STEM ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270037004515",
    },
    {
        "school": "VERMILION COUNTRY SCHOOL",
        "district": "VERMILION COUNTRY SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270037204555",
    },
    {
        "school": "PAUL BUNYAN CENTER",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270444004454",
    },
    {
        "school": "Choice Alternative High School IS",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270579004481",
    },
    {
        "school": "BEACON ALP IS",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270579004483",
    },
    {
        "school": "Choice Alternative High School",
        "district": "BLOOMINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270579004531",
    },
    {
        "school": "FLOODWOOD ALT. LEARNING PROGRAM",
        "district": "FLOODWOOD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271221004469",
    },
    {
        "school": "HENDRICKS SENIOR HIGH",
        "district": "HENDRICKS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271368004530",
    },
    {
        "school": "Empower Learning Center",
        "district": "HINCKLEY-FINLAYSON SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271407004489",
    },
    {
        "school": "LINCOLN ELEMENTARY - IVANHOE",
        "district": "IVANHOE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271554004539",
    },
    {
        "school": "EMINNESOTA ONLINE ACADEMY",
        "district": "MADELIA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271857004463",
    },
    {
        "school": "MANKATO AREA NIGHT SCHOOL",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271878004517",
    },
    {
        "school": "MANKATO AREA SUMMER SCHOOL",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271878004540",
    },
    {
        "school": "MORA MIDDLE LEVEL ALC",
        "district": "MORA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272148004472",
    },
    {
        "school": "ANTHONY LOUIS CENTER",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272385004453",
    },
    {
        "school": "ALC INDEPENDENT STUDY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272520004441",
    },
    {
        "school": "ALC CREDIT RECOVERY",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272520004496",
    },
    {
        "school": "Osseo ALC Alternative Programs",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272520004501",
    },
    {
        "school": "ALC SENIOR HIGH",
        "district": "OSSEO PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272520004529",
    },
    {
        "school": "PELICAN RAPIDS ALT LEARNING CENTER",
        "district": "PELICAN RAPIDS PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272817004484",
    },
    {
        "school": "PELICAN RAPIDS ALT CENTER MID-LEVEL",
        "district": "PELICAN RAPIDS PUBLIC SCHOOL DIST.",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272817004487",
    },
    {
        "school": "RAILS ACADEMY",
        "district": "PROCTOR PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273009004477",
    },
    {
        "school": "SCHOOL OF ENGINEERING-ARTS AT OLSON",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178004548",
    },
    {
        "school": "ROSEAU DIST. AREA LEARNING PROGRAM",
        "district": "ROSEAU PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273225004520",
    },
    {
        "school": "OPEN WORLD LEARNING SECONDARY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384004443",
    },
    {
        "school": "HAZEL PARK PREPARATORY ACADEMY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384004457",
    },
    {
        "school": "SAINT PAUL MUSIC ACADEMY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384004491",
    },
    {
        "school": "ALC SECONDARY SPECIAL SITES",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384004553",
    },
    {
        "school": "UNDERWOOD ALP",
        "district": "UNDERWOOD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274083004498",
    },
    {
        "school": "TRANSITIONS 110",
        "district": "WACONIA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274146004448",
    },
    {
        "school": "EARLY CHILDHOOD LEARNING CENTER",
        "district": "WINDOM PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274278004510",
    },
    {
        "school": "GERMANTOWN HIGH SCHOOL",
        "district": "MADISON CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001381",
    },
    {
        "school": "EARLY HEAD START NICHOLSON",
        "district": "PICAYUNE SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280363001383",
    },
    {
        "school": "NORTH PONTOTOC UPPER ELEMENTARY",
        "district": "PONTOTOC CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280366001384",
    },
    {
        "school": "HOGAN PREPARATORY ACAD MIDDLE",
        "district": "HOGAN PREPARATORY ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290001403196",
    },
    {
        "school": "BROOKSIDE CHARTER MIDDLE SCHL",
        "district": "BROOKSIDE CHARTER SCH.",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002403184",
    },
    {
        "school": "LIFT FOR LIFE ACADEMY HIGH SCH",
        "district": "LIFT FOR LIFE ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290057403183",
    },
    {
        "school": "FRONTIER SCHL OF EXCELLENCE-M",
        "district": "FRONTIER SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059003180",
    },
    {
        "school": "FRONTIER SCHL OF EXCELLENCE-U",
        "district": "FRONTIER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059003181",
    },
    {
        "school": "FRONTIER SCHL OF INNOVATION-M",
        "district": "FRONTIER SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059003182",
    },
    {
        "school": "Ewing Marion Kauffman Middle",
        "district": "EWING MARION KAUFFMAN SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059703195",
    },
    {
        "school": "HOPE LEADERSHIP ACADEMY",
        "district": "HOPE LEADERSHIP ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060103194",
    },
    {
        "school": "CROSSROADS - CENTRAL STREET",
        "district": "CROSSROADS CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060303201",
    },
    {
        "school": "BRENTWOOD EARLY CHILDHD CENTER",
        "district": "BRENTWOOD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290588003190",
    },
    {
        "school": "TRUMAN MIDDLE SCHOOL",
        "district": "LINDBERGH SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291869003200",
    },
    {
        "school": "MARION C. EARLY JUNIOR HIGH",
        "district": "MARION C. EARLY R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292016003187",
    },
    {
        "school": "BARACK OBAMA ELEMENTARY SCHOOL",
        "district": "NORMANDY SCHOOLS COLLABORATIVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292265003189",
    },
    {
        "school": "WOODRIDGE MIDDLE SCHOOL",
        "district": "NORTHWEST R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292289003191",
    },
    {
        "school": "HOUSE SPRINGS EARLY CHILD CTR",
        "district": "NORTHWEST R-I",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292289003192",
    },
    {
        "school": "EARLY CHILDHOOD LEARNING CTR",
        "district": "SAVANNAH R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292757003186",
    },
    {
        "school": "BLACKHURST ELEMENTARY",
        "district": "ST. CHARLES R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292892003199",
    },
    {
        "school": "HUMBOLDT ACAD OF HIGHER LRNING",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928003193",
    },
    {
        "school": "MAPLE GROVE ELEMENTARY",
        "district": "WARRENSBURG R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293102003185",
    },
    {
        "school": "Zenith Elementary",
        "district": "Cut Bank Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000301104",
    },
    {
        "school": "Fortine 7-8",
        "district": "Fortine Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301134001103",
    },
    {
        "school": "Rosebud School",
        "district": "Rosebud K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302292000671",
    },
    {
        "school": "Rosebud 7-8",
        "district": "Rosebud K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302292001050",
    },
    {
        "school": "WEST POINT - BEEMER MIDDLE SCHOOL",
        "district": "WEST POINT PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310000602249",
    },
    {
        "school": "WEST HOLT LITTLE PAWS PRESCHOOL",
        "district": "WEST HOLT PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310017202260",
    },
    {
        "school": "HOWELLS-DODGE ELEMENTARY SCHOOL/DODGE",
        "district": "HOWELLS-DODGE CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018300908",
    },
    {
        "school": "HOWELLS-DODGE ELEMENTARY SCHOOL/HOWELLS",
        "district": "HOWELLS-DODGE CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018301088",
    },
    {
        "school": "HOWELLS SENIOR HIGH SCHOOL",
        "district": "HOWELLS-DODGE CONSOLIDATED SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018301090",
    },
    {
        "school": "HERITAGE ELEMENTARY",
        "district": "BENNINGTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310399002261",
    },
    {
        "school": "JOHNSON CROSSING ACADEMIC CENTER (5-6)",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071002246",
    },
    {
        "school": "KEARNEY EDUCATION CENTER",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239002253",
    },
    {
        "school": "GATEWAY TO COLLEGE",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482002247",
    },
    {
        "school": "SECONDARY SUCCESS PROGRAM",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482002248",
    },
    {
        "school": "WILSON FOCUS SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482002251",
    },
    {
        "school": "ACCELERE",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482002255",
    },
    {
        "school": "ESL TEEN LITERACY PROGRAM",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482002258",
    },
    {
        "school": "INDEPENDENT STUDY PROGRAM",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482002259",
    },
    {
        "school": "SHELBY - RISING CITY MIDDLE SCHOOL",
        "district": "SHELBY - RISING CITY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317659002257",
    },
    {
        "school": "UNDERWOOD HILLS EARLY CHILDHOOD LEARNING CENTER",
        "district": "WESTSIDE COMMUNITY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317866002254",
    },
    {
        "school": "Oasis Academy",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100817",
    },
    {
        "school": "Discovery Charter School HillPointe",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100818",
    },
    {
        "school": "Somerset Academy Sky Pointe",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100820",
    },
    {
        "school": "Imagine School Mountain View",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100821",
    },
    {
        "school": "Washoe Inspire Academy",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320048000822",
    },
    {
        "school": "Early Childhood Learning Center",
        "district": "Barrington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330165000700",
    },
    {
        "school": "Mill Falls Charter School",
        "district": "Mill Falls Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330328000699",
    },
    {
        "school": "The Birches Academy of Academics - Art A Public Charter Sch",
        "district": "The Birches Academy for Academics & Art:A Public Charter Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330328600704",
    },
    {
        "school": "Robert Frost Charter School",
        "district": "Robert Frost Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330328700703",
    },
    {
        "school": "Making Community Connections Charter School (H)",
        "district": "Making Community Connections Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330328900705",
    },
    {
        "school": "Polaris Charter School",
        "district": "Polaris Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330329000706",
    },
    {
        "school": "Next Charter School",
        "district": "Next Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330329100707",
    },
    {
        "school": "Highbridge Hill Elementary School",
        "district": "Mascenic Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330467000697",
    },
    {
        "school": "Millville Public Charter School",
        "district": "Millville Public Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340074903184",
    },
    {
        "school": "Great Oaks Legacy Charter School",
        "district": "Great Oaks Legacy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340075103180",
    },
    {
        "school": "M.E.T.S. Charter School",
        "district": "M.E.T.S. CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340075303183",
    },
    {
        "school": "Peoples Preparatory Charter School",
        "district": "Peoples Preparatory Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340075403181",
    },
    {
        "school": "Roseville Community Charter School",
        "district": "Roseville Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340075503187",
    },
    {
        "school": "Dr Lena Edwards Academic Charter School",
        "district": "Dr Lena Edwards Academic Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340075603185",
    },
    {
        "school": "Atlantic County Alternative High School",
        "district": "Atlantic County Vocational School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340099003175",
    },
    {
        "school": "Edison Early Learning Center",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003179",
    },
    {
        "school": "Hackensack Middle School",
        "district": "Hackensack School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340627003191",
    },
    {
        "school": "Middlesex Co Voc School East Bruns. School of Career Develop",
        "district": "Middlesex County Vocational and Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341008003176",
    },
    {
        "school": "Luis Mu?oz Marin Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134003150",
    },
    {
        "school": "Early Childhood School - South",
        "district": "Newark Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134003153",
    },
    {
        "school": "Bard Early College High School",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134003158",
    },
    {
        "school": "Orange Early Childhood Center",
        "district": "ORANGE BOARD OF EDUCATION School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341227003148",
    },
    {
        "school": "School of Education and Training",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003168",
    },
    {
        "school": "School of Science Technology Engineering and Mathematics",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003169",
    },
    {
        "school": "School of Business Technology Marketing and Finance",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003170",
    },
    {
        "school": "School of Architecture and Construction Trades",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003171",
    },
    {
        "school": "Pemberton Early Childhood Education Center",
        "district": "Pemberton Township School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341281003167",
    },
    {
        "school": "Kindergarten Success Academy",
        "district": "ROSELLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341428003166",
    },
    {
        "school": "Cumberland Campus",
        "district": "Salem County Special Services School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348036103161",
    },
    {
        "school": "Alternative Middle & High School",
        "district": "Salem County Special Services School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "348036103163",
    },
    {
        "school": "HIGHLAND AUTISM CENTER",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Special education school",
        "state": "NM",
        "nces_id": "350006001079",
    },
    {
        "school": "THE GREAT ACADEMY",
        "district": "THE GREAT ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350014201077",
    },
    {
        "school": "RED RIVER VALLEY CHARTER SCHOOL",
        "district": "RED RIVER VALLEY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350014300845",
    },
    {
        "school": "MESILLA VALLEY ALTERNATIVE MIDDLE SCHOOL",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350150001078",
    },
    {
        "school": "FORSYTHE SATELLITE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 1",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007606296",
    },
    {
        "school": "URBAN ASSEMBLY GATEWAY SCHOOL FOR TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007706251",
    },
    {
        "school": "TEACHERS COLLEGE COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008106256",
    },
    {
        "school": "NEW DESIGN MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008106257",
    },
    {
        "school": "BRONX DESIGN AND CONSTRUCTION ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360008406253",
    },
    {
        "school": "BRONX ARENA HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506258",
    },
    {
        "school": "CROTONA INTERNATIONAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360008706247",
    },
    {
        "school": "ACADEMY FOR PERSONAL LEADERSHIP AND EXCELLENCE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008706297",
    },
    {
        "school": "HIGH SCHOOL FOR LANGUAGE AND INNOVATION",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806245",
    },
    {
        "school": "BAYCHESTER MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806249",
    },
    {
        "school": "ONE WORLD MIDDLE SCHOOL AT EDENWALD",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806259",
    },
    {
        "school": "BRONXDALE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806270",
    },
    {
        "school": "PS 536",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006261",
    },
    {
        "school": "ARCHER ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006266",
    },
    {
        "school": "BRONX ENVISION ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006275",
    },
    {
        "school": "METROPOLITAN SOUNDVIEW HIGH SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006276",
    },
    {
        "school": "BROOKLYN FRONTIERS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009206279",
    },
    {
        "school": "MILLENNIUM BROOKLYN HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009206292",
    },
    {
        "school": "ACADEMY FOR HEALTH CAREERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360009506200",
    },
    {
        "school": "PATHWAYS IN TECHNOLOGY EARLY COLLEGE HIGH SCHOOL (P-TECH)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360009506273",
    },
    {
        "school": "BROOKLYN SCHOOL FOR MATH AND RESEARCH (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009706274",
    },
    {
        "school": "MASPETH HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806278",
    },
    {
        "school": "JAMAICA GATEWAY TO THE SCIENCES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006283",
    },
    {
        "school": "JERMAINE L GREEN STEM INSTITUTE IN QUEENS (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006284",
    },
    {
        "school": "COLLABORATIVE ARTS MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010106285",
    },
    {
        "school": "COMMUNITY VOICES MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010106286",
    },
    {
        "school": "FRESH CREEK SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006280",
    },
    {
        "school": "CHRISTOPHER AVENUE COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012106288",
    },
    {
        "school": "ROCKAWAY COLLEGIATE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306277",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-UPPER WEST",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-UPPER WEST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360103906260",
    },
    {
        "school": "TRUE NORTH ROCHESTER  PREP-WEST CAMP",
        "district": "TRUE NORTH ROCHESTER  PREP-WEST CAMP",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360104006243",
    },
    {
        "school": "NEW VISIONS CHARTER HIGH SCHOOL FOR THE HUMANITIES",
        "district": "NEW VISIONS CHARTER HIGH SCHOOL FOR THE HUMANITIES",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360104106263",
    },
    {
        "school": "EAST HARLEM SCHOLARS ACADEMY CHARTER SCHOOL",
        "district": "EAST HARLEM SCHOLARS ACADEMY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360104206252",
    },
    {
        "school": "BROOME STREET ACADEMY CHARTER HIGH SCHOOL",
        "district": "BROOME STREET ACADEMY CHARTER HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360104306268",
    },
    {
        "school": "NEW YORK CITY MONTESSORI CHARTER SCHOOL",
        "district": "NEW YORK CITY MONTESSORI CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360104406248",
    },
    {
        "school": "DISCOVERY CHARTER SCHOOL",
        "district": "DISCOVERY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360104606269",
    },
    {
        "school": "NEW VISIONS CHARTER HS-ADV MATH/SCIE",
        "district": "NEW VISIONS CHARTER HS-ADV MATH/SCIE",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360104706254",
    },
    {
        "school": "EMBER CHARTER SCHOOL",
        "district": "EMBER CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360104806255",
    },
    {
        "school": "ICAHN CHARTER SCHOOL 5",
        "district": "ICAHN CHARTER SCHOOL 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360104906265",
    },
    {
        "school": "AMANI PUBLIC CHARTER SCHOOL",
        "district": "AMANI PUBLIC CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360105106291",
    },
    {
        "school": "EXPLORE EXCEL CHARTER SCHOOL",
        "district": "EXPLORE EXCEL CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360105206271",
    },
    {
        "school": "ACADEMY OF THE CITY CHARTER SCHOOL",
        "district": "ACADEMY OF THE CITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360105306289",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL - BED STUY 1",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL - BED STUY 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360105406295",
    },
    {
        "school": "ACADEMY SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360585006262",
    },
    {
        "school": "RANDOLPH ACADEMYHAMBURG CAMPUS",
        "district": "RANDOLPH ACADEMY UNION FREE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360744006294",
    },
    {
        "school": "CLYDE-SAVANNAH MIDDLE SCHOOL",
        "district": "CLYDE-SAVANNAH CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360786006290",
    },
    {
        "school": "LEADERSHIP ACADEMY FOR YOUNG MEN",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475006250",
    },
    {
        "school": "SALMON RIVER MIDDLE SCHOOL",
        "district": "SALMON RIVER CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362550006264",
    },
    {
        "school": "SILAS WOOD 6TH GRADE CENTER",
        "district": "SOUTH HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362730006282",
    },
    {
        "school": "ROSCOE CONKLING ELEMENTARY SCHOOL",
        "district": "UTICA CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362937006287",
    },
    {
        "school": "THOMAS CORNELL ACADEMY",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192006281",
    },
    {
        "school": "Reid Ross Classical Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001103247",
    },
    {
        "school": "New Century International Middle",
        "district": "Cumberland County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001103248",
    },
    {
        "school": "NC School for the Deaf",
        "district": "Deaf and Blind Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370032003234",
    },
    {
        "school": "Eastern NC School for the Deaf",
        "district": "Deaf and Blind Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370032003235",
    },
    {
        "school": "Gov. Morehead School f/t Blind",
        "district": "Deaf and Blind Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370032003236",
    },
    {
        "school": "Northeast Regional School - Biotech/Agri",
        "district": "Northeast Regional School - Biotech/Agri",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NC",
        "nces_id": "370032103254",
    },
    {
        "school": "Bear Grass Charter School",
        "district": "Bear Grass Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370032203260",
    },
    {
        "school": "North East Carolina Prep",
        "district": "North East Carolina Preparatory School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370032303256",
    },
    {
        "school": "Triangle Math and Science Academy",
        "district": "Triangle Math and Science Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370032403259",
    },
    {
        "school": "College Prep and Leadership Academy",
        "district": "The College Preparatory and Leadership A",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370032503265",
    },
    {
        "school": "Research Triangle High School",
        "district": "Research Triangle High School",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370032603261",
    },
    {
        "school": "Corvian Community School",
        "district": "Corvian Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370032703258",
    },
    {
        "school": "Cornerstone Charter Academy-CFA",
        "district": "Cornerstone Charter Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370032803255",
    },
    {
        "school": "Water's Edge Village School",
        "district": "Water's Edge Village School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370032903264",
    },
    {
        "school": "Oak Grove Middle",
        "district": "Davidson County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114003251",
    },
    {
        "school": "Yadkin Valley Regional Career Academy",
        "district": "Davidson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114003257",
    },
    {
        "school": "Lucas Middle",
        "district": "Durham Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370126003250",
    },
    {
        "school": "Stuart W Cramer High",
        "district": "Gaston County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162003246",
    },
    {
        "school": "Greene County Intermediate",
        "district": "Greene County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370183003244",
    },
    {
        "school": "STEM Early College @ NC A&T SU",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192003242",
    },
    {
        "school": "Ronald E. McNair Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192003243",
    },
    {
        "school": "Sandy Grove Middle",
        "district": "Hoke County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370225003249",
    },
    {
        "school": "Garinger High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003245",
    },
    {
        "school": "Gaston Middle",
        "district": "Northampton County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370342003263",
    },
    {
        "school": "Poplar Springs Elementary",
        "district": "Stokes County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370438003252",
    },
    {
        "school": "Wake Young Women's Leadership Academy",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003237",
    },
    {
        "school": "Richland Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003238",
    },
    {
        "school": "Wake Young Men's Leadership Academy",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003239",
    },
    {
        "school": "Rolesville Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003240",
    },
    {
        "school": "Abbotts Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003241",
    },
    {
        "school": "Weldon STEM High School Career Academies",
        "district": "Weldon City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370489003262",
    },
    {
        "school": "TINY TURTLES PRESCHOOL",
        "district": "BELCOURT 7",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380253000856",
    },
    {
        "school": "FARGO DAVIES HIGH SCHOOL",
        "district": "FARGO 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000855",
    },
    {
        "school": "BRAVE CENTER ACADEMY",
        "district": "MANDAN 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381182000858",
    },
    {
        "school": "FREEDOM ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000857",
    },
    {
        "school": "LIBERTY MIDDLE SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000859",
    },
    {
        "school": "MCVAY ELEMENTARY SCHOOL",
        "district": "WILLISTON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381988000860",
    },
    {
        "school": "Hardin Community School",
        "district": "Hardin Community School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390142905652",
    },
    {
        "school": "Broadway Academy",
        "district": "Broadway Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390143005665",
    },
    {
        "school": "Constellation Schools: Eastside Arts Academy",
        "district": "Constellation Schools: Eastside Arts Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390143205676",
    },
    {
        "school": "The Academy for Urban Scholars",
        "district": "The Academy for Urban Scholars",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390143305688",
    },
    {
        "school": "STEAM Academy of Warren",
        "district": "STEAM Academy of Warren",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390143405697",
    },
    {
        "school": "Citizens Leadership Academy",
        "district": "Citizens Leadership Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390144405673",
    },
    {
        "school": "Townsend North Community School",
        "district": "Townsend North Community School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390145005693",
    },
    {
        "school": "Focus North High School",
        "district": "Focus North High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390145105687",
    },
    {
        "school": "STEAM Academy of Akron",
        "district": "STEAM Academy of Akron",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390145405664",
    },
    {
        "school": "University of Cleveland Preparatory School",
        "district": "University of Cleveland Preparatory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390145705678",
    },
    {
        "school": "Beacon Hill Academy",
        "district": "Beacon Hill Academy",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390146305666",
    },
    {
        "school": "Global Village Academy",
        "district": "Global Village Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390146505658",
    },
    {
        "school": "Early Learning Center",
        "district": "Westerville City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450405682",
    },
    {
        "school": "Shawnee Middle School",
        "district": "Clark-Shawnee Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390462805696",
    },
    {
        "school": "Big Walnut Intermediate School",
        "district": "Big Walnut Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467405691",
    },
    {
        "school": "Reynoldsburg HS Business Education Leadership & Law Academy",
        "district": "Reynoldsburg City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470005653",
    },
    {
        "school": "Summit Road Elementary",
        "district": "Reynoldsburg City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470005654",
    },
    {
        "school": "Reynoldsburg Health Sciences & Human Services STEM Academy",
        "district": "Reynoldsburg City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470005655",
    },
    {
        "school": "Reynoldsburg HS Encore: Arts Communication & Design Academy",
        "district": "Reynoldsburg City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470005656",
    },
    {
        "school": "Madison-Plains Elementary School",
        "district": "Madison-Plains Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482705662",
    },
    {
        "school": "Madison-Plains Intermediate School",
        "district": "Madison-Plains Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390482705675",
    },
    {
        "school": "Crestview Middle School",
        "district": "Crestview Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503505701",
    },
    {
        "school": "Van Wert Early Childhood Center",
        "district": "Van Wert City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391002305672",
    },
    {
        "school": "CHEROKEE IMMERSION CHARTER SCH",
        "district": "CHEROKEE IMMERSION CHARTER SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400075502720",
    },
    {
        "school": "CATALAYAH ES",
        "district": "CLAREMORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400774002725",
    },
    {
        "school": "EMPIRE MS",
        "district": "EMPIRE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401089002718",
    },
    {
        "school": "PRAIRIE VIEW ES",
        "district": "ENID",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092002717",
    },
    {
        "school": "FAIRLAND MS",
        "district": "FAIRLAND",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401125002721",
    },
    {
        "school": "GERONIMO MS",
        "district": "GERONIMO",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401263002732",
    },
    {
        "school": "HERITAGE ELEMENTARY",
        "district": "KINGFISHER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401656002724",
    },
    {
        "school": "CESAR CHAVEZ ES",
        "district": "OKLAHOMA CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002722",
    },
    {
        "school": "HOLMES PARK ES",
        "district": "SAPULPA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402691002726",
    },
    {
        "school": "HERITAGE ES",
        "district": "TAHLEQUAH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402938002727",
    },
    {
        "school": "DUAL LANGUAGE ACADEMY",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002730",
    },
    {
        "school": "CENTRAL JHS",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002731",
    },
    {
        "school": "WILL ROGERS COLLEGE JHS",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002733",
    },
    {
        "school": "TRAICE MS",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002736",
    },
    {
        "school": "PROJECT ACCEPT TRAICE ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002738",
    },
    {
        "school": "MONROE DEMONSTRATION MS",
        "district": "TULSA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002739",
    },
    {
        "school": "WESTERN HEIGHTS 9TH GRADE CTR",
        "district": "WESTERN HEIGHTS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403237002728",
    },
    {
        "school": "BRIDGESTONE ES",
        "district": "WESTERN HEIGHTS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403237002729",
    },
    {
        "school": "YUKON MS",
        "district": "YUKON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403348002723",
    },
    {
        "school": "Eagle Charter School",
        "district": "Oregon Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410000901808",
    },
    {
        "school": "Winter Lakes School",
        "district": "Coquille SD 8",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410339001804",
    },
    {
        "school": "Falcon Heights",
        "district": "Klamath County SD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410702001807",
    },
    {
        "school": "Rivers Edge Academy Charter School",
        "district": "Rogue River SD 35",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411068001811",
    },
    {
        "school": "Straub Middle School",
        "district": "Salem-Keizer SD 24J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001805",
    },
    {
        "school": "Kalapuya Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001809",
    },
    {
        "school": "Mastery CS-Clymer Elementary",
        "district": "Mastery CS-Clymer Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420084007400",
    },
    {
        "school": "Gillingham Charter School",
        "district": "Gillingham Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420084107420",
    },
    {
        "school": "Olney Charter High School",
        "district": "Olney Charter High School",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420084307386",
    },
    {
        "school": "Stone Valley Community CS",
        "district": "Stone Valley Community CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420084407371",
    },
    {
        "school": "Young Scholars of Western Pennsylvania C",
        "district": "Young Scholars of Western Pennsylvania CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420084507424",
    },
    {
        "school": "York Academy Regional Charter School",
        "district": "York Academy Regional Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420084607383",
    },
    {
        "school": "Urban Pathways K-5 College Charter Schoo",
        "district": "Urban Pathways K-5 College Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420084707425",
    },
    {
        "school": "I-LEAD Charter School",
        "district": "I-LEAD Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420084807413",
    },
    {
        "school": "Propel CS-Northside",
        "district": "Propel CS-Northside",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420084907380",
    },
    {
        "school": "Lindley Academy CS at Birney",
        "district": "Lindley Academy CS at Birney",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420085007405",
    },
    {
        "school": "Mastery CS-Gratz Campus",
        "district": "Mastery CS-Gratz Campus",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420085107414",
    },
    {
        "school": "HOPE for Hyndman CS",
        "district": "HOPE for Hyndman CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420085207384",
    },
    {
        "school": "Penn Hills Charter School of Entrepreneu",
        "district": "Penn Hills Charter School of Entrepreneurship",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420085307381",
    },
    {
        "school": "Erie Rise Leadership Academy Charter Sch",
        "district": "Erie Rise Leadership Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420085407394",
    },
    {
        "school": "Universal Vare Charter School",
        "district": "Universal Vare Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420085507421",
    },
    {
        "school": "Universal Audenried Charter School",
        "district": "Universal Audenried Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420085607402",
    },
    {
        "school": "Annville-Cleona MS",
        "district": "Annville-Cleona SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420249007417",
    },
    {
        "school": "Willow Dale El Sch",
        "district": "Centennial SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420519007388",
    },
    {
        "school": "Danville Primary Sch",
        "district": "Danville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420732007406",
    },
    {
        "school": "Downingtown STEM Academy",
        "district": "Downingtown Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771007401",
    },
    {
        "school": "Bear Creek School",
        "district": "Elizabethtown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420912007385",
    },
    {
        "school": "Perry Lower Intrmd Sch",
        "district": "Ellwood City Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420924007372",
    },
    {
        "school": "Hartman Intrmd Sch",
        "district": "Ellwood City Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420924007373",
    },
    {
        "school": "North Side Primary School",
        "district": "Ellwood City Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420924007375",
    },
    {
        "school": "Franklin Twp El Sch",
        "district": "Gettysburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421071007382",
    },
    {
        "school": "Grove City Area MS",
        "district": "Grove City Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421122007389",
    },
    {
        "school": "Hanover Green El Sch",
        "district": "Hanover Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421142007403",
    },
    {
        "school": "Bancroft El Sch",
        "district": "Kennett Consolidated SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421269007387",
    },
    {
        "school": "Mary D Lang Kdg Ctr",
        "district": "Kennett Consolidated SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421269007390",
    },
    {
        "school": "Indian Valley Intrmd Sch",
        "district": "Mifflin County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421529007391",
    },
    {
        "school": "Lewistown Intrmd Sch",
        "district": "Mifflin County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421529007392",
    },
    {
        "school": "Indian Valley El Sch",
        "district": "Mifflin County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421529007396",
    },
    {
        "school": "Mifflin Co JHS",
        "district": "Mifflin County SD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421529007397",
    },
    {
        "school": "Mifflin Co HS",
        "district": "Mifflin County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421529007398",
    },
    {
        "school": "Mifflin Co MS",
        "district": "Mifflin County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421529007399",
    },
    {
        "school": "David E Williams MS",
        "district": "Montour SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421572007410",
    },
    {
        "school": "Riverside MS",
        "district": "Riverside Beaver County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421743007419",
    },
    {
        "school": "Riverside El Sch",
        "district": "Riverside Beaver County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421743007423",
    },
    {
        "school": "Northside El Sch",
        "district": "Palmyra Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421839007374",
    },
    {
        "school": "Lingle Avenue El Sch",
        "district": "Palmyra Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421839007376",
    },
    {
        "school": "Pittsburgh Faison K-5",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917007411",
    },
    {
        "school": "Academy at Westinghouse",
        "district": "Pittsburgh SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917007412",
    },
    {
        "school": "Redbank Valley Intrmd Sch",
        "district": "Redbank Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422013007378",
    },
    {
        "school": "Redbank Valley Primary School",
        "district": "Redbank Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422013007379",
    },
    {
        "school": "Ringgold El Sch South",
        "district": "Ringgold SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422040007407",
    },
    {
        "school": "Sullivan Co El Sch",
        "district": "Sullivan County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422292007418",
    },
    {
        "school": "Troy Intrmd Sch",
        "district": "Troy Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422379007393",
    },
    {
        "school": "EverGreen El Sch",
        "district": "Western Wayne SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422607007404",
    },
    {
        "school": "Wyalusing Valley El Sch",
        "district": "Wyalusing Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422670007377",
    },
    {
        "school": "Yorkshire El Sch",
        "district": "York Suburban SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422685007416",
    },
    {
        "school": "Blackstone Valley Prep E. 2",
        "district": "Blackstone Valley Prep  A RI Mayoral Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440001500480",
    },
    {
        "school": "RINI Middle College",
        "district": "Rhode Island Nurses Institute Middle College",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440001900479",
    },
    {
        "school": "Powdersville High",
        "district": "Anderson 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450078001567",
    },
    {
        "school": "Robert Anderson Middle",
        "district": "Anderson 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090001573",
    },
    {
        "school": "Southwood Academy for the Arts",
        "district": "Anderson 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090001574",
    },
    {
        "school": "Glenview Middle",
        "district": "Anderson 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090001575",
    },
    {
        "school": "North Pointe Elementary",
        "district": "Anderson 05",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090001576",
    },
    {
        "school": "Colleton County Middle",
        "district": "Colleton 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450183001586",
    },
    {
        "school": "Lake View Elementary",
        "district": "Dillon 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450192000378",
    },
    {
        "school": "Lake View High",
        "district": "Dillon 04",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450192000380",
    },
    {
        "school": "Joseph R. Pye Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001568",
    },
    {
        "school": "Monarch Elementary",
        "district": "Greenville 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001593",
    },
    {
        "school": "Academy of Hope Charter",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001585",
    },
    {
        "school": "Meadow Glen Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001569",
    },
    {
        "school": "Meadow Glen Middle",
        "district": "Lexington 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001578",
    },
    {
        "school": "Swansea High Freshman Academy",
        "district": "Lexington 04",
        "level": "Secondary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450279001587",
    },
    {
        "school": "Chastain Road Elementary",
        "district": "Pickens 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450333001565",
    },
    {
        "school": "Muller Road Middle",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001566",
    },
    {
        "school": "Catawba Trail Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001572",
    },
    {
        "school": "Spartanburg School District 7 Early Childhood Center",
        "district": "Spartanburg 07",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450366001583",
    },
    {
        "school": "Harold C. Johnson Elementary",
        "district": "York 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450381001577",
    },
    {
        "school": "Banks Trail Middle",
        "district": "York 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001564",
    },
    {
        "school": "SC Whitmore School",
        "district": "SC Public Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101581",
    },
    {
        "school": "East Point Academy",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101582",
    },
    {
        "school": "Cape Romain Environmental Education Charter School",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101588",
    },
    {
        "school": "Youth Leadership Academy",
        "district": "SC Public Charter School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101589",
    },
    {
        "school": "Crestwood High",
        "district": "Sumter 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390200217",
    },
    {
        "school": "Lakewood High",
        "district": "Sumter 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390200223",
    },
    {
        "school": "Chestnut Oaks Middle",
        "district": "Sumter 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390200511",
    },
    {
        "school": "Alice Drive Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201057",
    },
    {
        "school": "Crosswell Drive Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201058",
    },
    {
        "school": "Lemira Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201059",
    },
    {
        "school": "Millwood Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201060",
    },
    {
        "school": "Wilder Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201061",
    },
    {
        "school": "Willow Drive Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201062",
    },
    {
        "school": "Alice Drive Middle",
        "district": "Sumter 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201063",
    },
    {
        "school": "Bates Middle",
        "district": "Sumter 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201064",
    },
    {
        "school": "Sumter High",
        "district": "Sumter 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201065",
    },
    {
        "school": "Cherryvale Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201066",
    },
    {
        "school": "R. E. Davis College Preparatory Academy",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201068",
    },
    {
        "school": "Manchester Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201069",
    },
    {
        "school": "Oakland Primary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201071",
    },
    {
        "school": "Rafting Creek Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201072",
    },
    {
        "school": "Shaw Heights Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201073",
    },
    {
        "school": "Ebenezer Middle",
        "district": "Sumter 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201077",
    },
    {
        "school": "Furman Middle",
        "district": "Sumter 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201078",
    },
    {
        "school": "Hillcrest Middle",
        "district": "Sumter 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201079",
    },
    {
        "school": "High Hills Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201317",
    },
    {
        "school": "Sumter Career and Technology Center",
        "district": "Sumter 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450390201388",
    },
    {
        "school": "Pocalla Springs Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201452",
    },
    {
        "school": "Kingsbury Elementary",
        "district": "Sumter 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390201453",
    },
    {
        "school": "SC Governor's School for Arts and Humanities",
        "district": "Governor's School for the Arts and Humanities",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390401580",
    },
    {
        "school": "SC Governor's School for Science and Mathematics",
        "district": "Governor' School for Science and Mathematics",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390701579",
    },
    {
        "school": "Silver Lake Colony - 07",
        "district": "Clark School District 12-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461294001319",
    },
    {
        "school": "Freedom Elementary - 06",
        "district": "Harrisburg School District 41-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463135001318",
    },
    {
        "school": "Red Willow Colony School - 09",
        "district": "Deubrook Area School District 05-6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467830001320",
    },
    {
        "school": "Cascade Middle School",
        "district": "Bedford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470018002276",
    },
    {
        "school": "Prospect Elementary School",
        "district": "Blount County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030002266",
    },
    {
        "school": "Chattanooga Charter School of Excellence",
        "district": "Hamilton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159002284",
    },
    {
        "school": "Hamilton County Virtual School",
        "district": "Hamilton County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159002285",
    },
    {
        "school": "Liberty Bell Middle School",
        "district": "Johnson City",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470213002268",
    },
    {
        "school": "L N STEM Academy",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222002269",
    },
    {
        "school": "Winfree Bryant Middle School",
        "district": "Lebanon",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470237002283",
    },
    {
        "school": "North Parkway Middle School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258002254",
    },
    {
        "school": "Andrew Jackson Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258002259",
    },
    {
        "school": "East Elementary School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258002261",
    },
    {
        "school": "Jackson Career Technology Magnet Elementary",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258002265",
    },
    {
        "school": "MNPS Virtual School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002256",
    },
    {
        "school": "STEM Prep Academy",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002257",
    },
    {
        "school": "East End Preparatory School",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002258",
    },
    {
        "school": "LEAD Cameron",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002260",
    },
    {
        "school": "Liberty Collegiate Academy",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002263",
    },
    {
        "school": "Nashville Prep",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002264",
    },
    {
        "school": "VITAL:  Upper Cumberland e-Learning Network",
        "district": "Putnam County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348002281",
    },
    {
        "school": "Elementary Middle Alternative",
        "district": "Union County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470429002278",
    },
    {
        "school": "Paulette Elementary School",
        "district": "Union County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470429002279",
    },
    {
        "school": "Tennessee Virtual Academy",
        "district": "Union County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470429002280",
    },
    {
        "school": "Summit High School",
        "district": "Williamson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002275",
    },
    {
        "school": "Clovercroft Elementary School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002277",
    },
    {
        "school": "Barry Tatum Academy",
        "district": "Wilson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455002262",
    },
    {
        "school": "WALLACE ACCELERATED H S",
        "district": "BLACKWELL CISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480000512671",
    },
    {
        "school": "UPLIFT EDUCATION - INFINITY PREPARATORY PRI",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012686",
    },
    {
        "school": "UPLIFT EDUCATION - INFINITY PREPARATORY MIDDLE SCH",
        "district": "UPLIFT EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012689",
    },
    {
        "school": "WAYSIDE REAL LEARNING ACADEMY",
        "district": "WAYSIDE SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480004412758",
    },
    {
        "school": "HOUSTON GATEWAY ACADEMY INC ELITE COLLEGE PREP",
        "district": "HOUSTON GATEWAY ACADEMY INC",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480011812767",
    },
    {
        "school": "FOUNDERS CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312670",
    },
    {
        "school": "JUBILEE HARLINGEN",
        "district": "JUBILEE ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017912723",
    },
    {
        "school": "JUBILEE KINGSVILLE",
        "district": "JUBILEE ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017912724",
    },
    {
        "school": "JUBILEE LIVING WAY",
        "district": "JUBILEE ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017912747",
    },
    {
        "school": "NOVA ACADEMY PRICHARD",
        "district": "NOVA ACADEMY SOUTHEAST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020112713",
    },
    {
        "school": "PREMIER H S SAN ANTONIO EAST",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708110",
    },
    {
        "school": "PREMIER H S OF BROWNSVILLE",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708136",
    },
    {
        "school": "PREMIER H S OF PHARR",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708282",
    },
    {
        "school": "PREMIER H S OF LUBBOCK",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708327",
    },
    {
        "school": "PREMIER H S OF WACO",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708331",
    },
    {
        "school": "PREMIER H S OF MIDLAND",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708337",
    },
    {
        "school": "PREMIER H S OF TYLER",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708357",
    },
    {
        "school": "PREMIER H S OF FORT WORTH",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708366",
    },
    {
        "school": "PREMIER H S OF ABILENE",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708378",
    },
    {
        "school": "PREMIER H S OF DEL RIO",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708396",
    },
    {
        "school": "PREMIER H S OF LAREDO",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020708404",
    },
    {
        "school": "PREMIER H S OF AUSTIN",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020709350",
    },
    {
        "school": "PREMIER H S OF MISSION",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020710815",
    },
    {
        "school": "PREMIER H S OF PALMVIEW",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020711464",
    },
    {
        "school": "PREMIER H S OF NORTH AUSTIN",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020712092",
    },
    {
        "school": "PREMIER H S OF EL PASO",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020712102",
    },
    {
        "school": "PREMIER H S OF SAN JUAN",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020712127",
    },
    {
        "school": "PREMIER H S OF NEW BRAUNFELS",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020712268",
    },
    {
        "school": "PREMIER H S OF ARLINGTON",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020712402",
    },
    {
        "school": "PREMIER H S OF HUNTSVILLE",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020712412",
    },
    {
        "school": "PREMIER H S OF GRANBURY",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020712540",
    },
    {
        "school": "YES PREP - NORTHSIDE",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020912692",
    },
    {
        "school": "YES PREP - 5TH WARD",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020912693",
    },
    {
        "school": "IDEA MCALLEN COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112679",
    },
    {
        "school": "IDEA BROWNSVILLE COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112683",
    },
    {
        "school": "IDEA BROWNSVILLE ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112684",
    },
    {
        "school": "IDEA MCALLEN ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112688",
    },
    {
        "school": "RIPLEY HOUSE MIDDLE CAMPUS",
        "district": "PROMISE COMMUNITY SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024012682",
    },
    {
        "school": "NEW NEIGHBOR CAMPUS",
        "district": "PROMISE COMMUNITY SCHOOL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024012687",
    },
    {
        "school": "HARMONY SCHOOL OF ENDEAVOR AUSTIN",
        "district": "HARMONY SCIENCE ACADEMY (AUSTIN)",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024112787",
    },
    {
        "school": "SEASHORE LEARNING CENTER",
        "district": "SEASHORE CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480028907412",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION-SUGAR LAND",
        "district": "HARMONY SCHOOL OF SCIENCE - HOUSTON",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140512741",
    },
    {
        "school": "ARROW ACADEMY - SAVE OUR STREETS CENTER",
        "district": "ARROW ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141612753",
    },
    {
        "school": "ARROW ACADEMY - HARVEST PREPARATORY ACADEMY",
        "district": "ARROW ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141612757",
    },
    {
        "school": "UME PREPARATORY ACADEMY",
        "district": "UME PREPARATORY ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142512685",
    },
    {
        "school": "UT TYLER UNIVERSITY ACADEMY AT TYLER",
        "district": "UT TYLER UNIVERSITY ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142712768",
    },
    {
        "school": "LEGACY PREP CHARTER ACADEMY MESQUITE WEST CAMPUS",
        "district": "LEGACY PREPARATORY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142812649",
    },
    {
        "school": "IMAGINE INTERNATIONAL ACADEMY OF NORTH TEXAS",
        "district": "IMAGINE INTERNATIONAL ACADEMY OF NORTH TEXAS",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142912752",
    },
    {
        "school": "AUSTIN ACHIEVE MIDDLE",
        "district": "AUSTIN ACHIEVE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143112775",
    },
    {
        "school": "MARTINEZ EL",
        "district": "ABILENE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744012705",
    },
    {
        "school": "DAEP",
        "district": "ANTON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480846012651",
    },
    {
        "school": "HILL CO JJAEP",
        "district": "BYNUM ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481236012714",
    },
    {
        "school": "DAEP",
        "district": "CALLISBURG ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481251012652",
    },
    {
        "school": "CENTRAL HEIGHTS MIDDLE",
        "district": "CENTRAL HEIGHTS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481344012666",
    },
    {
        "school": "AGUIRRE J H",
        "district": "CHANNELVIEW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481359012711",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "CHANNELVIEW ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481359012716",
    },
    {
        "school": "COLUMBUS ALTERNATIVE SCHOOL",
        "district": "COLUMBUS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481470012678",
    },
    {
        "school": "KOLDA EL",
        "district": "CORPUS CHRISTI ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527012727",
    },
    {
        "school": "HAROLD T BRANCH ACADEMY FOR CAREER & TECHNICAL ED",
        "district": "CORPUS CHRISTI ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527012733",
    },
    {
        "school": "ADKINS MIDDLE",
        "district": "CORPUS CHRISTI ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527012737",
    },
    {
        "school": "CROSBY EL",
        "district": "CROSBY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481575012765",
    },
    {
        "school": "CROSBY CROSSROADS ACADEMY",
        "district": "CROSBY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481575012769",
    },
    {
        "school": "ROSEMONT UPPER",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012781",
    },
    {
        "school": "DEVINE DAEP SCHOOL",
        "district": "DEVINE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481695012708",
    },
    {
        "school": "DONNA NORTH H S",
        "district": "DONNA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739012761",
    },
    {
        "school": "CHISHOLM TRAIL H S",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770012760",
    },
    {
        "school": "GEORGE H W BUSH NEW TECH ODESSA",
        "district": "ECTOR COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800012779",
    },
    {
        "school": "ELKHART INT",
        "district": "ELKHART ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481839012739",
    },
    {
        "school": "ROY JOHNSON SIXTH GRADE CAMPUS",
        "district": "EVERMAN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481881012664",
    },
    {
        "school": "YOUNG MEN'S LEADERSHIP ACADEMY",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970012717",
    },
    {
        "school": "YWLA AT BILL ARNOLD",
        "district": "GRAND PRAIRIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142012690",
    },
    {
        "school": "YMLA AT JOHN F KENNEDY MIDDLE",
        "district": "GRAND PRAIRIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142012691",
    },
    {
        "school": "HALLSVILLE NORTH EL",
        "district": "HALLSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482217012770",
    },
    {
        "school": "DR ABRAHAM P CANO FRESHMAN ACADEMY",
        "district": "HARLINGEN CISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253012777",
    },
    {
        "school": "SECONDARY DAEP",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482364012655",
    },
    {
        "school": "EL DAEP",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482364012656",
    },
    {
        "school": "MANDARIN IMMERSION MAGNET SCHOOL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012659",
    },
    {
        "school": "HUMBLE COMMUNITY LEARNING CENTER",
        "district": "HUMBLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482391012774",
    },
    {
        "school": "DR JOSEPH A FOWLER EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566012780",
    },
    {
        "school": "ZWINK EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574012662",
    },
    {
        "school": "THE GRACE ENGLAND EARLY CHILDHOOD/PRE-K CENTER",
        "district": "KLEIN ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574012663",
    },
    {
        "school": "BERNSHAUSEN EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574012667",
    },
    {
        "school": "G W CARVER 6TH GRADE STEM LEARNING CENTER",
        "district": "LANCASTER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482667012788",
    },
    {
        "school": "MIDLAND ALTERNATIVE PROGRAM",
        "district": "MIDLAND ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483057012704",
    },
    {
        "school": "VINEYARD RANCH EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294012657",
    },
    {
        "school": "LAS LOMAS EL",
        "district": "NORTH EAST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294012658",
    },
    {
        "school": "LOS REYES EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012643",
    },
    {
        "school": "TRUETT WILSON MIDDLE",
        "district": "NORTHWEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318012707",
    },
    {
        "school": "CARL E SCHLUTER EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318012709",
    },
    {
        "school": "J C THOMPSON EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318012710",
    },
    {
        "school": "DR KIRK LEWIS CAREER AND TECHNICAL H S",
        "district": "PASADENA ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432012697",
    },
    {
        "school": "MARSHALL KENDRICK MIDDLE",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432012701",
    },
    {
        "school": "FRED ROBERTS MIDDLE",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432012702",
    },
    {
        "school": "NELDA SULLIVAN MIDDLE",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432012706",
    },
    {
        "school": "RUTH BARRON EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483012751",
    },
    {
        "school": "BUELL CENTRAL DAEP",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483486012654",
    },
    {
        "school": "BERTA S PALACIOS EL",
        "district": "PHARR-SAN JUAN-ALAMO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483486012660",
    },
    {
        "school": "PLANO ISD ACADEMY H S",
        "district": "PLANO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510012675",
    },
    {
        "school": "SNYDER INT",
        "district": "SNYDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484065012778",
    },
    {
        "school": "SNYDER PRI",
        "district": "SNYDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484065012784",
    },
    {
        "school": "NEW H S",
        "district": "SPRING ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122012718",
    },
    {
        "school": "SPRING EARLY COLLEGE ACADEMY",
        "district": "SPRING ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122012719",
    },
    {
        "school": "DALLAS COUNTY JJAEP",
        "district": "SUNNYVALE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484188012644",
    },
    {
        "school": "JP COWEN ACHIEVEMENT CENTER",
        "district": "SWEETWATER ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484203012703",
    },
    {
        "school": "TH JOHNSON EL",
        "district": "TAYLOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484228012661",
    },
    {
        "school": "WEST RUSK EL",
        "district": "WEST RUSK COUNTY CONSOLIDATED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484515012715",
    },
    {
        "school": "COLORADO ISD DAEP",
        "district": "WESTBROOK ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484521012668",
    },
    {
        "school": "American Preparatory Academy - Draper #2",
        "district": "American Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490000501446",
    },
    {
        "school": "Riverview School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001405",
    },
    {
        "school": "Thunder Ridge School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001413",
    },
    {
        "school": "Horizon School",
        "district": "Alpine District",
        "level": "Other",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490003001419",
    },
    {
        "school": "Polaris High School",
        "district": "Alpine District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490003001435",
    },
    {
        "school": "East Shore Online",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001436",
    },
    {
        "school": "Entheos Academy Magna",
        "district": "Entheos Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004101437",
    },
    {
        "school": "Corner Canyon High",
        "district": "Canyons District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014201428",
    },
    {
        "school": "Endeavor Hall",
        "district": "Endeavor Hall",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015501407",
    },
    {
        "school": "Highmark Charter School",
        "district": "Highmark Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015601415",
    },
    {
        "school": "Promontory School of Expeditionary Learning",
        "district": "Promontory School of Expeditionary Learning",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015701416",
    },
    {
        "school": "Valley Academy",
        "district": "Valley Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015801421",
    },
    {
        "school": "Pacific Heritage Academy",
        "district": "Pacific Heritage Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490015901406",
    },
    {
        "school": "Voyage Academy",
        "district": "Voyage Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490016001442",
    },
    {
        "school": "Esperanza School",
        "district": "Esperanza School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490016101440",
    },
    {
        "school": "Leadership Learning Academy",
        "district": "Leadership Learning Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490016201438",
    },
    {
        "school": "Mana Academy Charter School",
        "district": "Mana Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490016501439",
    },
    {
        "school": "Utah International Charter School",
        "district": "Utah International Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490016601433",
    },
    {
        "school": "Weber State University Charter Academy",
        "district": "Weber State University Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490016701447",
    },
    {
        "school": "Winter Sports School",
        "district": "Winter Sports School",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490016801444",
    },
    {
        "school": "Youth Educational Support School",
        "district": "Granite District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490036001399",
    },
    {
        "school": "Elk Run Elementary",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036001412",
    },
    {
        "school": "Fox Hollow School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001411",
    },
    {
        "school": "Southpointe Adult High",
        "district": "Jordan District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490042001427",
    },
    {
        "school": "Bridges Nebo Transition Center",
        "district": "Nebo District",
        "level": "High",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490063001424",
    },
    {
        "school": "Parley's Park Preschool",
        "district": "Park City District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490075001409",
    },
    {
        "school": "Trailside Preschool",
        "district": "Park City District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490075001410",
    },
    {
        "school": "Jeremy Ranch Preschool",
        "district": "Park City District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490075001423",
    },
    {
        "school": "Innovations High School",
        "district": "Salt Lake District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087001422",
    },
    {
        "school": "Tse'Bii'Nidzisgai School",
        "district": "San Juan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490090001426",
    },
    {
        "school": "South Sanpete Education Support Center",
        "district": "South Sanpete District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490096001425",
    },
    {
        "school": "Wasatch Learning Academy",
        "district": "Wasatch District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490111001420",
    },
    {
        "school": "Utah Online 7-12",
        "district": "Washington District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001432",
    },
    {
        "school": "Weber Online K-6",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120001414",
    },
    {
        "school": "NEW DIRECTIONS ALTERNATIVE H.S. PROGRAM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510027002860",
    },
    {
        "school": "ALC AT BURKE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510126002862",
    },
    {
        "school": "NEW BRIDGE LEARNING CTR",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510189002856",
    },
    {
        "school": "J MICHAEL LUNSFORD MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002853",
    },
    {
        "school": "FREDERICK DOUGLASS ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002864",
    },
    {
        "school": "JOHN CHAMPE HS",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002865",
    },
    {
        "school": "JOHN MARSHALL EARLY CHILDHOOD CTR",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510264002857",
    },
    {
        "school": "LOCUST GROVE PRIMARY SCHOOL",
        "district": "ORANGE CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510282002854",
    },
    {
        "school": "OLIVE BRANCH PRESCHOOL CTR",
        "district": "PORTSMOUTH CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510300002859",
    },
    {
        "school": "PRINCE EDWARD CO. VOC. TECH.",
        "district": "PRINCE EDWARD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510306002863",
    },
    {
        "school": "PINEY BRANCH ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002851",
    },
    {
        "school": "T CLAY WOOD ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002852",
    },
    {
        "school": "RONALD WILSON REAGAN MIDDLE",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002858",
    },
    {
        "school": "WAYNE HILLS CTR",
        "district": "WAYNESBORO CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510393002855",
    },
    {
        "school": "Bellevue Big Picture School",
        "district": "Bellevue School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530039003354",
    },
    {
        "school": "Cordata Elementary School",
        "district": "Bellingham School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530042003358",
    },
    {
        "school": "Easton Secondary School",
        "district": "Easton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530234003355",
    },
    {
        "school": "Gateway to College",
        "district": "Federal Way School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282003374",
    },
    {
        "school": "WINDWARD HIGH SCHOOL",
        "district": "Ferndale School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530285003362",
    },
    {
        "school": "Gateway to College",
        "district": "Highline School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530354003373",
    },
    {
        "school": "Benton County Jail",
        "district": "Kennewick School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393003352",
    },
    {
        "school": "Choice",
        "district": "Riverview School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530456003375",
    },
    {
        "school": "Park Orchard Elementary School",
        "district": "Moses Lake School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522003368",
    },
    {
        "school": "Northwest Career & Technical Academy",
        "district": "Mount Vernon School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530540003297",
    },
    {
        "school": "North Franklin Virtual Academy",
        "district": "North Franklin School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530573003364",
    },
    {
        "school": "Connell Preschool",
        "district": "North Franklin School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530573003366",
    },
    {
        "school": "Northport Homelink Program",
        "district": "Northport School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530588003370",
    },
    {
        "school": "Olympia Regional Learning Academy - Montessori School",
        "district": "Olympia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618003377",
    },
    {
        "school": "PEARL",
        "district": "Quilcene School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530699003353",
    },
    {
        "school": "Viewlands Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003356",
    },
    {
        "school": "Rainier View Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003361",
    },
    {
        "school": "Pacific Virtual Learning",
        "district": "South Bend School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530810003365",
    },
    {
        "school": "Pacific County Jail",
        "district": "South Bend School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530810003372",
    },
    {
        "school": "Sacred Heart Hospital",
        "district": "Spokane School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530825003367",
    },
    {
        "school": "On Track Academy",
        "district": "Spokane School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530825003378",
    },
    {
        "school": "Lewis River Academy",
        "district": "Woodland School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "531005003371",
    },
    {
        "school": "SPRING MILLS HIGH SCHOOL",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001487",
    },
    {
        "school": "DODDRIDGE COUNTY PRESCHOOL CENTER",
        "district": "DODDRIDGE COUNTY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540027001493",
    },
    {
        "school": "HARTS PK-8",
        "district": "LINCOLN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540066001484",
    },
    {
        "school": "MINGO CENTRAL COMPREHENSIVE HIGH SCHOOL",
        "district": "MINGO COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540090001485",
    },
    {
        "school": "MINGO COUNTY EXTENDED LEARNING CENTER",
        "district": "MINGO COUNTY SCHOOLS",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540090001488",
    },
    {
        "school": "GILBERT MIDDLE SCHOOL",
        "district": "MINGO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540090001491",
    },
    {
        "school": "BURCH PK8",
        "district": "MINGO COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540090001492",
    },
    {
        "school": "EASTWOOD ELEMENTARY SCHOOL",
        "district": "MONONGALIA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540093001490",
    },
    {
        "school": "Link2Learn Virtual Charter School",
        "district": "Chetek-Weyerhaeuser Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006102897",
    },
    {
        "school": "Milwaukee Scholars Charter School",
        "district": "Milwaukee Scholars Charter School Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006502894",
    },
    {
        "school": "Dr Howard Fuller Collegiate Academy",
        "district": "Dr Howard Fuller Collegiate Academy Agency",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006602865",
    },
    {
        "school": "Milwaukee Math and Science Academy",
        "district": "Milwaukee Math and Science Academy Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006702898",
    },
    {
        "school": "Appleton Bilingual School",
        "district": "Appleton Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002880",
    },
    {
        "school": "Advanced Learning Academy of Wisconsin",
        "district": "Barron Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550087002864",
    },
    {
        "school": "Beloit Early Learning",
        "district": "Beloit School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105002855",
    },
    {
        "school": "Cornell Middle",
        "district": "Cornell School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550288002896",
    },
    {
        "school": "Island City Virtual Academy",
        "district": "Cumberland School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550309002871",
    },
    {
        "school": "School for Arts and Performance",
        "district": "Kettle Moraine School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550351002861",
    },
    {
        "school": "KM Global Sch",
        "district": "Kettle Moraine School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550351002876",
    },
    {
        "school": "Fond du Lac STEM Academy",
        "district": "Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468002862",
    },
    {
        "school": "John Dewey Academy of Learning",
        "district": "Green Bay Area Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582002857",
    },
    {
        "school": "Northern Waters Environmental School",
        "district": "Hayward Community School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550627002867",
    },
    {
        "school": "Fox West Academy",
        "district": "Hortonville Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550660002854",
    },
    {
        "school": "New Directions Learning Community",
        "district": "Kaukauna Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550729002878",
    },
    {
        "school": "La Crosse Design Institute",
        "district": "La Crosse School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753002887",
    },
    {
        "school": "Little Chute Intermediate",
        "district": "Little Chute Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550816002858",
    },
    {
        "school": "Little Chute Career Pathways Academy",
        "district": "Little Chute Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550816002905",
    },
    {
        "school": "Badger Rock Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550852002866",
    },
    {
        "school": "Marathon Venture Academy",
        "district": "Marathon City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550867002893",
    },
    {
        "school": "iLEAD Charter Sch",
        "district": "Mauston School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550885002863",
    },
    {
        "school": "4K McFarland",
        "district": "McFarland School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550891002902",
    },
    {
        "school": "Clark Street Community School",
        "district": "Middleton-Cross Plains Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951002882",
    },
    {
        "school": "Middleton-Cross Plains Area School District 4K",
        "district": "Middleton-Cross Plains Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550951002888",
    },
    {
        "school": "Milwaukee College Preparatory School -- 38th Street",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002853",
    },
    {
        "school": "Milwaukee College Preparatory School -- Lloyd Street",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002860",
    },
    {
        "school": "Daniels University Preparatory Academy",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002870",
    },
    {
        "school": "Creative Minds",
        "district": "Minocqua J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550969002873",
    },
    {
        "school": "NorthStar Community Charter School",
        "district": "Northwood School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550972002877",
    },
    {
        "school": "4K Community-Based",
        "district": "Reedsburg School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551266002889",
    },
    {
        "school": "D C Everest Idea School",
        "district": "D C Everest Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317002885",
    },
    {
        "school": "Etude High",
        "district": "Sheboygan Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365002859",
    },
    {
        "school": "Sheboygan Leadership Academy",
        "district": "Sheboygan Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365002872",
    },
    {
        "school": "Central High",
        "district": "Sheboygan Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365002879",
    },
    {
        "school": "Etude Middle",
        "district": "Sheboygan Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365002899",
    },
    {
        "school": "George D Warriner Middle",
        "district": "Sheboygan Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551365002900",
    },
    {
        "school": "Verona Area K4",
        "district": "Verona Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533002890",
    },
    {
        "school": "Waunakee Community 4K School",
        "district": "Waunakee Community School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551581002869",
    },
    {
        "school": "School for Agricultural and Environmental Studies",
        "district": "Waupun School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551587002903",
    },
    {
        "school": "Wauwatosa Montessori School",
        "district": "Wauwatosa School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002884",
    },
    {
        "school": "Laramie Montessori Charter School",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000542",
    },
    {
        "school": "Rawlins Elementary",
        "district": "Carbon County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560103000541",
    },
    {
        "school": "Buffalo Ridge Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000546",
    },
    {
        "school": "Wind River High School",
        "district": "Fremont County School District # 6",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560283000544",
    },
    {
        "school": "Wind River Middle School",
        "district": "Fremont County School District # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560283000545",
    },
    {
        "school": "Gannett Peak Elementary",
        "district": "Fremont County School District # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560287000452",
    },
    {
        "school": "Baldwin Creek Elementary",
        "district": "Fremont County School District # 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560287000539",
    },
    {
        "school": "NUEVA ESCUELA URBANA DE CIALES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001912",
    },
    {
        "school": "Asbury Elementary School",
        "district": "Marshall County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000602209",
    },
    {
        "school": "James Clemens High School",
        "district": "Madison City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10000802198",
    },
    {
        "school": "Satsuma High School",
        "district": "Satsuma City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018902195",
    },
    {
        "school": "Robert E Lee Elementary",
        "district": "Satsuma City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018902196",
    },
    {
        "school": "Bush Hills STEAM Academy",
        "district": "Birmingham City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039002204",
    },
    {
        "school": "Hayes K8",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039002206",
    },
    {
        "school": "Central Jr High School of Clay County",
        "district": "Clay County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10075002205",
    },
    {
        "school": "Central High School of Clay County",
        "district": "Clay County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10075002210",
    },
    {
        "school": "Lawrence County Developmental",
        "district": "Lawrence County",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10204002211",
    },
    {
        "school": "Smith Station Freshman Center",
        "district": "Lee County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10207002197",
    },
    {
        "school": "Taylor White Elementary School",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237002202",
    },
    {
        "school": "EicholdMertz School of Math and Science",
        "district": "Mobile County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10237002208",
    },
    {
        "school": "McKee PreK Center",
        "district": "Montgomery County",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10243002207",
    },
    {
        "school": "Calera Intermediate School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10303002199",
    },
    {
        "school": "Sumter Central High School",
        "district": "Sumter County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10309002201",
    },
    {
        "school": "The New Path High School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AK",
        "nces_id": "20018000399",
    },
    {
        "school": "Mat-Su Middle College School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000747",
    },
    {
        "school": "NWABSD Home School",
        "district": "Northwest Arctic Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20062500748",
    },
    {
        "school": "LEAD Correspondence",
        "district": "Yakutat School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20084000749",
    },
    {
        "school": "The Learning Center Developmental Preschool",
        "district": "Cave Creek Unified District (4244)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40000103334",
    },
    {
        "school": "Bennett Academy - Venture Site",
        "district": "Twenty First Century Charter School Inc. Bennett  (4310)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40003703168",
    },
    {
        "school": "STEP UP SCHOOL",
        "district": "STEP UP Schools Inc. (4313)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40004003343",
    },
    {
        "school": "ALA QC  Elem",
        "district": "American Leadership Academy Inc. (4348)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011203328",
    },
    {
        "school": "American Leadership Academy Mesa K-6",
        "district": "American Leadership Academy Inc. (4348)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011203340",
    },
    {
        "school": "Lee Williams High School",
        "district": "Kingman Unified School District (79598)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40029503325",
    },
    {
        "school": "Aspire  High School",
        "district": "Yavapai Accommodation School District (79379)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40031503318",
    },
    {
        "school": "La Paloma Academy-South",
        "district": "Arizona Community Development Corporation (79947)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40036103312",
    },
    {
        "school": "Leading Edge Academy Online",
        "district": "LEAD Charter Schools (79967)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40039503335",
    },
    {
        "school": "Arizona Insight Academy",
        "district": "Portable Practical Educational Preparation Inc. ( (87405)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40043203324",
    },
    {
        "school": "Tucson VIP",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046303358",
    },
    {
        "school": "FBC-Preschool",
        "district": "Arizona State Schools for the Deaf and the Blind (6393)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40046303359",
    },
    {
        "school": "NATIVE Central Campus",
        "district": "Northeast Arizona Technological Institute of Vocat (81114)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061203311",
    },
    {
        "school": "Amphi Academy at Donaldson",
        "district": "Amphitheater Unified District (4406)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068003314",
    },
    {
        "school": "Amphi Academy Online",
        "district": "Amphitheater Unified District (4406)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068003330",
    },
    {
        "school": "EDUPRIZE SCHOOL Gilbert",
        "district": "Eduprize Schools LLC (89412)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40074600717",
    },
    {
        "school": "PCJTED - San Manuel High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203319",
    },
    {
        "school": "PCJTED - TAPP High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203322",
    },
    {
        "school": "PCJTED - Andrada Polytechnic High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203337",
    },
    {
        "school": "Odyssey Institute for Advanced and International Studies",
        "district": "The Odyssey Preparatory Academy Inc. (90287)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40080003317",
    },
    {
        "school": "BASIS Phoenix",
        "district": "BASIS Charter Schools Inc. (91280)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40084303351",
    },
    {
        "school": "Reid Traditional Schools' Painted Rock Academy",
        "district": "Reid Traditional Schools' Painted Rock Academy Inc (91317)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40085003341",
    },
    {
        "school": "Great Hearts Academies - North Phoenix Prep",
        "district": "North Phoenix Preparatory Academy (90879)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40086103344",
    },
    {
        "school": "Arizona College Prep Academy",
        "district": "Collaborative Pathways Inc. (91773)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40086201783",
    },
    {
        "school": "The Paideia Academy of South Phoenix",
        "district": "The Paideia Academies Inc (91250)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40086303355",
    },
    {
        "school": "Happy Valley School East Campus",
        "district": "Happy Valley East (90906)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40086403315",
    },
    {
        "school": "Great Hearts Academies - Archway Glendale",
        "district": "Archway Classical Academy Glendale (91878)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40086603356",
    },
    {
        "school": "Ball Charter Schools (Val Vista)",
        "district": "Ball Charter Schools (Val Vista) (90885)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40086703342",
    },
    {
        "school": "Open Doors Community School",
        "district": "Open Doors Community School Inc. (91238)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40086803332",
    },
    {
        "school": "Legacy Traditional School ? Laveen Village",
        "district": "Legacy Traditional School ? Laveen Village (91763)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40087103310",
    },
    {
        "school": "Changemaker High School",
        "district": "Institute for Transformative Education Inc. (90876)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40087203346",
    },
    {
        "school": "Great Hearts Academies - Archway North Phoenix",
        "district": "Archway Classical Academy North Phoenix (91758)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40087303353",
    },
    {
        "school": "Great Hearts Academies - Maryvale Prep",
        "district": "Maryvale Preparatory Academy (90861)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40087503345",
    },
    {
        "school": "George Gervin Prep Academy",
        "district": "George Gervin Youth Center Inc. (90884)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40087603352",
    },
    {
        "school": "Empower College Prep",
        "district": "Empower College Prep (91277)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40087703354",
    },
    {
        "school": "BASIS Tucson North",
        "district": "BASIS Charter Schools Inc. (91309)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40087803350",
    },
    {
        "school": "BUHSD Institute of Online Learning",
        "district": "Buckeye Union High School District (4284)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40141003320",
    },
    {
        "school": "John & Carol Carlson Elementary",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187003321",
    },
    {
        "school": "Gowan Science Academy",
        "district": "Crane Elementary District (4501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240003323",
    },
    {
        "school": "Flowing Wells Digital Campus",
        "district": "Flowing Wells Unified District (4405)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40301003331",
    },
    {
        "school": "Rogers Ranch School",
        "district": "Laveen Elementary District (4276)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40429003336",
    },
    {
        "school": "Franklin at Brimhall Elementary",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497003348",
    },
    {
        "school": "Fireside Elementary School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40593003313",
    },
    {
        "school": "Copper View Elementary School",
        "district": "Sahuarita Unified District (4411)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40730003339",
    },
    {
        "school": "Sunnyside Online Success Academy",
        "district": "Sunnyside Unified District (4407)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817003316",
    },
    {
        "school": "ARK CONSOLIDATED HIGH SCHOOL",
        "district": "ARKANSAS YOUTH SERVICES SCHOOL SYSTEM",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039001561",
    },
    {
        "school": "COLLEGE PREP ACADEMY",
        "district": "JACKSONVILLE LIGHTHOUSE CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040201560",
    },
    {
        "school": "LITTLE PREP ACADEMY ELEMENTARY",
        "district": "LITTLE ROCK PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040301567",
    },
    {
        "school": "PINE BLUFF LIGHTHOUSE COLLEGE PREP ACADEMY HIGH SCHOOL",
        "district": "PINE BLUFF LIGHTHOUSE ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040601551",
    },
    {
        "school": "WILLOWBROOK ELEMENTARY SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001543",
    },
    {
        "school": "BRIGHT FIELD MIDDLE SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001544",
    },
    {
        "school": "HILL FARM ELEMENTARY SCHOOL",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369001563",
    },
    {
        "school": "CABOT FRESHMAN ACADEMY",
        "district": "CABOT SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50375001553",
    },
    {
        "school": "SALLIE CONE PRESCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459001548",
    },
    {
        "school": "CAROLYN LEWIS ELEMENTARY SCHOOL",
        "district": "CONWAY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50459001550",
    },
    {
        "school": "LINCOLN NEW TECH HIGH SCHOOL",
        "district": "LINCOLN SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50894001569",
    },
    {
        "school": "ANNA STRONG INTERMEDIATE SCHOOL",
        "district": "LEE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50936001554",
    },
    {
        "school": "NORTH LITTLE ROCK HIGH SCHOOL",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068001566",
    },
    {
        "school": "OSCEOLA STEM CHARTER",
        "district": "OSCEOLA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51095001555",
    },
    {
        "school": "MAUMELLE HIGH SCHOOL",
        "district": "PULASKI CO. SPEC. SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51185001559",
    },
    {
        "school": "LAKESIDE JUNIOR HIGH SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001562",
    },
    {
        "school": "SONORA MIDDLE SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001565",
    },
    {
        "school": "GREENE CTY TECH INTERMEDIATE",
        "district": "GREENE CO. TECH SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51308001546",
    },
    {
        "school": "Twin Ridges Special Education Preschool",
        "district": "Twin Ridges Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001213453",
    },
    {
        "school": "Apple Valley Unified Preschool Special Education",
        "district": "Apple Valley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001713290",
    },
    {
        "school": "Eleanor Murray Fallon",
        "district": "Dublin Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001913169",
    },
    {
        "school": "Harvest Park Preschool Center",
        "district": "Pleasanton Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002013494",
    },
    {
        "school": "Manhattan Beach Preschool",
        "district": "Manhattan Beach Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002513480",
    },
    {
        "school": "Preschool",
        "district": "Lake Elsinore Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002713213",
    },
    {
        "school": "Dos Palos Carver Center",
        "district": "Dos Palos Oro Loma Joint Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003313609",
    },
    {
        "school": "Leroy Greene Academy",
        "district": "Natomas Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003613189",
    },
    {
        "school": "Winship Middle",
        "district": "Eureka City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005213158",
    },
    {
        "school": "Francis J. White Learning Center",
        "district": "Woodlake Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141806994",
    },
    {
        "school": "Woodlake Valley Middle",
        "district": "Woodlake Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141806995",
    },
    {
        "school": "Woodlake High",
        "district": "Woodlake Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141806996",
    },
    {
        "school": "Bravo Lake High",
        "district": "Woodlake Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60141806997",
    },
    {
        "school": "Woodlake Community Day",
        "district": "Woodlake Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60141808664",
    },
    {
        "school": "Castle Rock Elementary",
        "district": "Woodlake Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141809659",
    },
    {
        "school": "Fortuna Middle",
        "district": "Fortuna Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142001617",
    },
    {
        "school": "South Fortuna Elementary",
        "district": "Fortuna Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142001618",
    },
    {
        "school": "Norman G. Ambrosini Elementary",
        "district": "Fortuna Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142005171",
    },
    {
        "school": "Toddy Thomas Middle",
        "district": "Fortuna Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142005172",
    },
    {
        "school": "Pine Grove Youth Conservation Camp",
        "district": "California Education Authority (CEA) Headquarters",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60142207486",
    },
    {
        "school": "Johanna Boss High",
        "district": "California Education Authority (CEA) Headquarters",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60142207737",
    },
    {
        "school": "N.A. Chaderjian High",
        "district": "California Education Authority (CEA) Headquarters",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60142207739",
    },
    {
        "school": "Mary B. Perry High",
        "district": "California Education Authority (CEA) Headquarters",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60142207920",
    },
    {
        "school": "Gus Franklin Jr. School",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171013092",
    },
    {
        "school": "El Mirage",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171013193",
    },
    {
        "school": "Maya Lin",
        "district": "Alameda Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177013107",
    },
    {
        "school": "Monte Bella Elementary",
        "district": "Alisal Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195013182",
    },
    {
        "school": "Renaissance at Mathson",
        "district": "Alum Rock Union Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60231013126",
    },
    {
        "school": "Alvord Alternative Continuation High",
        "district": "Alvord Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60243013134",
    },
    {
        "school": "Hillcrest High",
        "district": "Alvord Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243013184",
    },
    {
        "school": "Academies of the Antelope Valley",
        "district": "Antelope Valley Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60282013154",
    },
    {
        "school": "Bellevue Senior Elementary",
        "district": "Atwater Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60342013051",
    },
    {
        "school": "Alta Vista Community Charter",
        "district": "Auburn Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60348013170",
    },
    {
        "school": "Longfellow",
        "district": "Azusa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60360013521",
    },
    {
        "school": "Florida Street Discovery Center",
        "district": "Banning Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60384013223",
    },
    {
        "school": "Renu Hope Preschool",
        "district": "Banning Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60384013269",
    },
    {
        "school": "Beaumont USD Preschool",
        "district": "Beaumont Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60429013598",
    },
    {
        "school": "Mary Casey Black Elementary",
        "district": "Brentwood Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60591013420",
    },
    {
        "school": "Sage Creek High",
        "district": "Carlsbad Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60750013058",
    },
    {
        "school": "Carmel Child Development Center",
        "district": "Carmel Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60753013242",
    },
    {
        "school": "Non-RIS Preschool CMS",
        "district": "Castaic Union",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60774013468",
    },
    {
        "school": "Pathway Elementary Community Day",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60797013042",
    },
    {
        "school": "Lucas Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813013637",
    },
    {
        "school": "Chaffey District Online High",
        "district": "Chaffey Joint Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60816013110",
    },
    {
        "school": "Camarena (Enrique S.) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861013096",
    },
    {
        "school": "Cinnabar Elementary",
        "district": "Cinnabar Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60870013043",
    },
    {
        "school": "Vincent Children's Center",
        "district": "Covina-Valley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61005013207",
    },
    {
        "school": "Davis Special Education Pre-School",
        "district": "Davis Joint Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61062013626",
    },
    {
        "school": "Pioneer",
        "district": "Delano Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61089013246",
    },
    {
        "school": "El Centro District Wide Preschool",
        "district": "El Centro Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61203013544",
    },
    {
        "school": "Alpha Charter",
        "district": "Elverta Joint Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61260013554",
    },
    {
        "school": "Emeryville Preschool Students",
        "district": "Emery Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61263013526",
    },
    {
        "school": "Del Lago Academy - Campus of Applied Science",
        "district": "Escondido Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61291013061",
    },
    {
        "school": "Bend Elementary",
        "district": "Evergreen Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61317000421",
    },
    {
        "school": "Public Safety Academy",
        "district": "Fairfield-Suisun Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61336013081",
    },
    {
        "school": "Cordova Lane Center",
        "district": "Folsom-Cordova Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61389013490",
    },
    {
        "school": "Fowler Academy Community Day",
        "district": "Fowler Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61425013163",
    },
    {
        "school": "College Connection Academy",
        "district": "Franklin-McKinley Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61437013199",
    },
    {
        "school": "Young Adult Program",
        "district": "Fremont Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61440013083",
    },
    {
        "school": "Fresno City and Fresno State Preschools",
        "district": "Fresno Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455013479",
    },
    {
        "school": "Pacific Avenue - Early Bird Preschool",
        "district": "Glendale Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61524013437",
    },
    {
        "school": "Learning Tree Preschool",
        "district": "Goleta Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61551013306",
    },
    {
        "school": "Bell Hill Academy",
        "district": "Grass Valley Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61578013165",
    },
    {
        "school": "Grass Valley Preschool",
        "district": "Grass Valley Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61578013228",
    },
    {
        "school": "Gravenstein First",
        "district": "Gravenstein Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61584013100",
    },
    {
        "school": "Pioneer Headstart",
        "district": "Gustine Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632313509",
    },
    {
        "school": "Special Education-Preschool-Laurel",
        "district": "Hayward Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61674013405",
    },
    {
        "school": "Freedom Academy of Imperial Valley",
        "district": "Holtville Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61743013071",
    },
    {
        "school": "Jurupa Unified Pre-K Readiness Center",
        "district": "Jurupa Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926013411",
    },
    {
        "school": "Special Education Preschool",
        "district": "King City Union",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61968013451",
    },
    {
        "school": "Reedley Middle College High",
        "district": "Kings Canyon Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970013141",
    },
    {
        "school": "KC KIDS Pre-School",
        "district": "Kings Canyon Joint Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970013511",
    },
    {
        "school": "Kings Canyon Unified School District Wide Preschools",
        "district": "Kings Canyon Joint Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61970013620",
    },
    {
        "school": "Konocti Preschool",
        "district": "Konocti Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62007013500",
    },
    {
        "school": "Special Education Preschool DIS",
        "district": "Lincoln Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169013335",
    },
    {
        "school": "Special Education Preschool",
        "district": "Live Oak Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62199013374",
    },
    {
        "school": "Livingston Stepping Stones Preschool",
        "district": "Livingston Union",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62217013575",
    },
    {
        "school": "Ernest S. McBride Sr. High",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250013105",
    },
    {
        "school": "LASD Preschool",
        "district": "Los Altos Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62265013549",
    },
    {
        "school": "Michelle Obama Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013045",
    },
    {
        "school": "Augustus F. Hawkins High A Critical Design and Gaming",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013065",
    },
    {
        "school": "Mervyn M. Dymally High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013079",
    },
    {
        "school": "Dr. Lawrence H. Moore Math Science Technology Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013082",
    },
    {
        "school": "Linda Esperanza Marquez High C School of Social Justice",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013086",
    },
    {
        "school": "Lucille Roybal-Allard Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013089",
    },
    {
        "school": "Willow Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013090",
    },
    {
        "school": "Augustus F. Hawkins High B Community Health Advocates",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013095",
    },
    {
        "school": "Hilda L. Solis Lrng Acad Sch of Tech Business and Ed",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013101",
    },
    {
        "school": "Academy of Medical Arts at Carson High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013104",
    },
    {
        "school": "San Fernando Institute of Applied Media",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013108",
    },
    {
        "school": "Marguerite Poindexter LaMotte Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013119",
    },
    {
        "school": "Visual and Performing Arts at Legacy High School Complex",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013133",
    },
    {
        "school": "Walnut Park Mid B Sci Tech Engr and Math Acad",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013138",
    },
    {
        "school": "STEM Academy at Bernstein High",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013139",
    },
    {
        "school": "Gerald A. Lawson Acad of the Arts Math and Sci",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013147",
    },
    {
        "school": "Sci Tech Engr Arts and Math at Legacy High Sch Complex",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013162",
    },
    {
        "school": "Augustus F. Hawkins High C Rspnsbl Indigenous Soc Entrepr",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013166",
    },
    {
        "school": "Linda Esperanza Marquez High A Hntngtn Park Inst of Appl Med",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013173",
    },
    {
        "school": "Porter Ranch Community",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013175",
    },
    {
        "school": "Harry Bridges Span",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013177",
    },
    {
        "school": "Walnut Park Mid A Sch of Soc Just and Service Lrng",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013187",
    },
    {
        "school": "Sally Ride Elementary: A SMArT Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013194",
    },
    {
        "school": "Playa Vista Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013195",
    },
    {
        "school": "Sylmar Leadership Academy",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013198",
    },
    {
        "school": "Linda Esperanza Marquez High B LIBRA Academy",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013203",
    },
    {
        "school": "Contreras Learning Center-School of Social Justice",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013271",
    },
    {
        "school": "Early College Academy-LA Trade Tech College",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013434",
    },
    {
        "school": "Humanities and Arts (HARTS) Academy of Los Angeles",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013579",
    },
    {
        "school": "Mercey Springs Elementary",
        "district": "Los Banos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274013433",
    },
    {
        "school": "Los Banos Special Education Preschool",
        "district": "Los Banos Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274013550",
    },
    {
        "school": "be.tech",
        "district": "Manteca Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62361013153",
    },
    {
        "school": "Herk Bouris Elementary",
        "district": "Menifee Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454013172",
    },
    {
        "school": "Menifee Preschool",
        "district": "Menifee Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454013619",
    },
    {
        "school": "El Capitan High",
        "district": "Merced Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62466013098",
    },
    {
        "school": "Canyon Early Learning Center",
        "district": "Monrovia Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62532013522",
    },
    {
        "school": "Marina Childrens Center",
        "district": "Monterey Peninsula Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553013547",
    },
    {
        "school": "Preschool",
        "district": "Morongo Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62586013375",
    },
    {
        "school": "Camp Lockett Middle",
        "district": "Mountain Empire Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62610013049",
    },
    {
        "school": "Pine Valley Middle",
        "district": "Mountain Empire Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62610013109",
    },
    {
        "school": "Mountain Empire Special Education Preschool",
        "district": "Mountain Empire Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62610013510",
    },
    {
        "school": "Decoto School for Independent Study",
        "district": "New Haven Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62691013202",
    },
    {
        "school": "Whiteford (June) Special Education Preschool",
        "district": "Newark Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62706013459",
    },
    {
        "school": "Ramona Head Start/State Preschool",
        "district": "Norwalk-La Mirada Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62769013602",
    },
    {
        "school": "Novato Early Intervention",
        "district": "Novato Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62772013229",
    },
    {
        "school": "Oak Park Neighborhood Learning",
        "district": "Oak Park Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62785013539",
    },
    {
        "school": "Fremont High",
        "district": "Oakland Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805013062",
    },
    {
        "school": "Burbank Preschool Center",
        "district": "Oakland Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805013483",
    },
    {
        "school": "Pleasant View",
        "district": "Ocean View",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62814013419",
    },
    {
        "school": "Ocean View Early Education",
        "district": "Ocean View",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62817013219",
    },
    {
        "school": "A Place to Grow",
        "district": "Ojai Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62827013394",
    },
    {
        "school": "Loma Vista Immersion Academy",
        "district": "Old Adobe Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62832013259",
    },
    {
        "school": "Sierra Del Oro",
        "district": "Oroville City Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62910013250",
    },
    {
        "school": "Palermo Special Education Preschool",
        "district": "Palermo Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62954013463",
    },
    {
        "school": "Rancho Mirage High",
        "district": "Palm Springs Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62955013149",
    },
    {
        "school": "David G. Millen Law and Government Magnet Academy",
        "district": "Palmdale Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958013052",
    },
    {
        "school": "Blythe District Preschool",
        "district": "Palo Verde Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62964013346",
    },
    {
        "school": "Sunrise Pre-School",
        "district": "Palos Verdes Peninsula Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62970013461",
    },
    {
        "school": "Sierra Madre Middle",
        "district": "Pasadena Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62994013343",
    },
    {
        "school": "Rob Reiner Children & Families Center",
        "district": "Perris Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63018013280",
    },
    {
        "school": "Gateway to College Academy",
        "district": "Petaluma Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63025013360",
    },
    {
        "school": "Piedmont Preschool",
        "district": "Piedmont City Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63033013442",
    },
    {
        "school": "Pleasant Ridge Special Education Preschool",
        "district": "Pleasant Ridge Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63093013599",
    },
    {
        "school": "Los Robles-Ronald McNair Academy",
        "district": "Ravenswood City Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63186013130",
    },
    {
        "school": "Redlands eAcademy",
        "district": "Redlands Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63207013458",
    },
    {
        "school": "Riverside STEM Academy",
        "district": "Riverside Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315013103",
    },
    {
        "school": "Robla Preschool",
        "district": "Robla Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63324013464",
    },
    {
        "school": "Boulder Ridge Elementary",
        "district": "Romoland Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63339013596",
    },
    {
        "school": "Barbara Chilton Middle",
        "district": "Roseville City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360013046",
    },
    {
        "school": "Fiddyment Farm",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360013287",
    },
    {
        "school": "Farjardo - La Seda Preschool",
        "district": "Rowland Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63375013361",
    },
    {
        "school": "La Tierra Early Childhood Center",
        "district": "Saddleback Valley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63386013659",
    },
    {
        "school": "Bob Holcomb Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417013056",
    },
    {
        "school": "Dr. Mildred Dalton Henry Elementary",
        "district": "San Bernardino City Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417013080",
    },
    {
        "school": "George Brown Jr. Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417013112",
    },
    {
        "school": "Graciano Gomez Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417013143",
    },
    {
        "school": "San Carlos Student Services Preschool",
        "district": "San Carlos Elementary",
        "level": "Not reported",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63429013091",
    },
    {
        "school": "Home & Hosp/Transition Support",
        "district": "San Diego Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432013144",
    },
    {
        "school": "Noriega Children Center",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441013231",
    },
    {
        "school": "Weill (Raphael) Children Center",
        "district": "San Francisco Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441013244",
    },
    {
        "school": "Mahler (Theresa S.) Children Center",
        "district": "San Francisco Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441013281",
    },
    {
        "school": "Las Americas Children Center",
        "district": "San Francisco Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441013328",
    },
    {
        "school": "Cooper (Sarah B.) Children Center",
        "district": "San Francisco Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441013393",
    },
    {
        "school": "McLaren (John) Children Centers",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441013456",
    },
    {
        "school": "Presidio Early Ed.",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441013488",
    },
    {
        "school": "San Miguel Children Center",
        "district": "San Francisco Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441013548",
    },
    {
        "school": "Havard (Leola M.) Early Education",
        "district": "San Francisco Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441013585",
    },
    {
        "school": "Stockton (Commodore) Children Center",
        "district": "San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63441013621",
    },
    {
        "school": "San Jacinto Early Childhood Education Center",
        "district": "San Jacinto Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63444013260",
    },
    {
        "school": "General Davie Jr. Primary Center",
        "district": "San Juan Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63462013156",
    },
    {
        "school": "Ludlow Preschool",
        "district": "San Lorenzo Valley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63474013589",
    },
    {
        "school": "San Mateo-Foster City Special Education Preschool",
        "district": "San Mateo-Foster City",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492013289",
    },
    {
        "school": "Peninsula High",
        "district": "San Mateo Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63498013476",
    },
    {
        "school": "INFANT Pre",
        "district": "San Ramon Valley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513013249",
    },
    {
        "school": "Cesar Chavez Language Academy",
        "district": "Santa Rosa Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63581013339",
    },
    {
        "school": "Sierra Vista Education Center",
        "district": "Sierra Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63680013291",
    },
    {
        "school": "Soledad Preschool Center",
        "district": "Soledad Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63705013613",
    },
    {
        "school": "Opal Cliffs",
        "district": "Soquel Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63729013055",
    },
    {
        "school": "VIP Village Preschool",
        "district": "South Bay Union",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63738013370",
    },
    {
        "school": "Community Day",
        "district": "South San Francisco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63753013304",
    },
    {
        "school": "LAUNCH Preschool",
        "district": "Torrance Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63942013629",
    },
    {
        "school": "Alpine Vista",
        "district": "Tulare City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63987013286",
    },
    {
        "school": "Academy Performing Preschool",
        "district": "Victor Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104013396",
    },
    {
        "school": "Shannon Ranch Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116013106",
    },
    {
        "school": "Vista Visions Academy",
        "district": "Vista Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64119013151",
    },
    {
        "school": "Toro Preschool",
        "district": "Washington Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64161013503",
    },
    {
        "school": "Weaver Preschool",
        "district": "Weaver Union",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64188013305",
    },
    {
        "school": "Gregg Anderson Academy",
        "district": "Westside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64212013142",
    },
    {
        "school": "Jeffrey Trail Middle",
        "district": "Irvine Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450013238",
    },
    {
        "school": "Kings County SELPA Preschool",
        "district": "Kings County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69101313429",
    },
    {
        "school": "Placer County Pathways Charter",
        "district": "Placer County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102513072",
    },
    {
        "school": "Preschool Grasp",
        "district": "Riverside County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102613302",
    },
    {
        "school": "Tuolumne County Special Education Preschool",
        "district": "Tuolumne County Superintendent of Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69104613617",
    },
    {
        "school": "El Potrero Pre-School",
        "district": "Val Verde Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113513435",
    },
    {
        "school": "COLORADO EARLY COLLEGE FORT COLLINS",
        "district": "State Charter School Institute",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006542",
    },
    {
        "school": "BRANTNER ELEMENTARY SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006549",
    },
    {
        "school": "Astravo Online Academy High School",
        "district": "Byers School District No. 32J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80270006548",
    },
    {
        "school": "BLACK FOREST HILLS ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006544",
    },
    {
        "school": "OPTIONS SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80291006563",
    },
    {
        "school": "STRIVE PREP - MONTBELLO",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006537",
    },
    {
        "school": "STRIVE PREP - SMART ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006543",
    },
    {
        "school": "ROCKY MOUNTAIN PREP: CREEKSIDE",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006545",
    },
    {
        "school": "DSST: GREEN VALLEY RANCH MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006546",
    },
    {
        "school": "WEST LEADERSHIP ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006547",
    },
    {
        "school": "WEST EARLY COLLEGE",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006551",
    },
    {
        "school": "DSST: COLLEGE VIEW MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006554",
    },
    {
        "school": "MONARCH MONTESSORI",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006555",
    },
    {
        "school": "STRIVE Prep - Green Valley Ranch",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006556",
    },
    {
        "school": "CREATIVITY CHALLENGE COMMUNITY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006559",
    },
    {
        "school": "MCAULIFFE INTERNATIONAL SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006562",
    },
    {
        "school": "DSST: Montview Middle School",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006566",
    },
    {
        "school": "PSD OPTIONS SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399006564",
    },
    {
        "school": "APEX HOME SCHOOL ENRICHMENT PROGRAM",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006539",
    },
    {
        "school": "LEAP SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540006558",
    },
    {
        "school": "MANCOS EARLY LEARNING CENTER",
        "district": "Mancos School District Re-6",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80546006540",
    },
    {
        "school": "SOAR ACADEMY",
        "district": "Sheridan School District No. 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80654006565",
    },
    {
        "school": "PATHWAYS FUTURE CENTER",
        "district": "Adams 12 Five Star Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80690006550",
    },
    {
        "school": "STEM LAUNCH",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690006561",
    },
    {
        "school": "INNOVATIVE CONNECTIONS HIGH SCHOOL",
        "district": "CENTENNIAL BOCES",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CO",
        "nces_id": "89920006560",
    },
    {
        "school": "Global Experience Magnet School",
        "district": "BLOOMFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90033001615",
    },
    {
        "school": "Learning Academy at Bloomfield",
        "district": "BLOOMFIELD SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CT",
        "nces_id": "90033001619",
    },
    {
        "school": "West Bristol School",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90051001624",
    },
    {
        "school": "Ana Grace Academy of the Arts Elementary School",
        "district": "Capitol Region Education Council",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001623",
    },
    {
        "school": "Greater Hartford Academy of the Arts Magnet Middle",
        "district": "Capitol Region Education Council",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001625",
    },
    {
        "school": "Great Path Academy at MCC",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001403",
    },
    {
        "school": "Betances STEM Magnet School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001616",
    },
    {
        "school": "Quinnipiac Real World Math STEM School",
        "district": "NEW HAVEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90279001612",
    },
    {
        "school": "Three Rivers Middle College Magnet School",
        "district": "LEARN",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90345001617",
    },
    {
        "school": "Reed School",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483001613",
    },
    {
        "school": "Beecher Road School",
        "district": "WOODBRIDGE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90531001611",
    },
    {
        "school": "Academia Antonia Alonso",
        "district": "Academia Antonia Alonso",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100005300359",
    },
    {
        "school": "First State Montessori Academy",
        "district": "First State Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100005400362",
    },
    {
        "school": "Early College High School at Del State",
        "district": "Early College High School at Del State",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100005500363",
    },
    {
        "school": "School-Within-School at Goding",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000466",
    },
    {
        "school": "KIPP DC - Lead Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100463",
    },
    {
        "school": "KIPP DC - Connect Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100468",
    },
    {
        "school": "KIPP DC - Spring Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100469",
    },
    {
        "school": "Capital City PCS - MS",
        "district": "Capital City PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003500464",
    },
    {
        "school": "MEADOWBROOK ELEMENTARY SCHOOL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003008203",
    },
    {
        "school": "EMMA JEWEL CHARTER ACADEMY",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015008175",
    },
    {
        "school": "SOMERSET ACADEMY RIVERSIDE",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008190",
    },
    {
        "school": "SOMERSET ACADEMY RIVERSIDE CHARTER MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008195",
    },
    {
        "school": "COLLIER VIRTUAL INSTRUCTION COURSE OFFERINGS",
        "district": "COLLIER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033008211",
    },
    {
        "school": "BELMONT ACADEMY",
        "district": "COLUMBIA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120036008184",
    },
    {
        "school": "PALM GLADES PREPARATORY ACADEMY HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008183",
    },
    {
        "school": "CHARTER HIGH SCHOOL OF THE AMERICAS",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008206",
    },
    {
        "school": "ACADEMIR CHARTER SCHOOL MIDDLE",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008218",
    },
    {
        "school": "ESCAMBIA VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "ESCAMBIA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051008207",
    },
    {
        "school": "BROOKSVILLE ENGINEERING SCIENCE AND TECHNOLOGY (B.E.S.T.) A",
        "district": "HERNANDO",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120081008214",
    },
    {
        "school": "HILLSBOROUGH ACADEMY OF MATH AND SCIENCE",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008188",
    },
    {
        "school": "BELL CREEK ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008198",
    },
    {
        "school": "RIVERHILLS ELEMENTARY MAGNET SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008200",
    },
    {
        "school": "LAFAYETTE VIRTUAL INSTRUCTION COURSE OFFERINGS",
        "district": "LAFAYETTE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120102008178",
    },
    {
        "school": "LAKE VIRTUAL INSTRUCTION COURSE OFFERINGS",
        "district": "LAKE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105008201",
    },
    {
        "school": "LEVY VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "LEVY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114008221",
    },
    {
        "school": "MARION ELEARNING",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126008216",
    },
    {
        "school": "SUN BLAZE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008170",
    },
    {
        "school": "SUNRIDGE MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008196",
    },
    {
        "school": "PINECREST CREEK CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008204",
    },
    {
        "school": "ORLANDO SCIENCE ELEMENTARY CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008215",
    },
    {
        "school": "SOMERSET ACADEMY BOCA EAST",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008220",
    },
    {
        "school": "ACHIEVE CENTER OF PASCO",
        "district": "PASCO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120153008219",
    },
    {
        "school": "BARTOW YOUTH ACADEMY",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159008173",
    },
    {
        "school": "PUTNAM EDGE HIGH SCHOOL",
        "district": "PUTNAM",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162008194",
    },
    {
        "school": "SARASOTA ACADEMY OF THE ARTS",
        "district": "SARASOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168008202",
    },
    {
        "school": "PALENCIA ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174008177",
    },
    {
        "school": "SUWANNEE VIRTUAL SCHOOL",
        "district": "SUWANNEE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120183008171",
    },
    {
        "school": "SUWANNEE VIRTUAL FRANCHISE",
        "district": "SUWANNEE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120183008180",
    },
    {
        "school": "WAKULLA VIRTUAL FRANCHISE",
        "district": "WAKULLA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195008187",
    },
    {
        "school": "Atlanta Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "High",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130002604089",
    },
    {
        "school": "KIPP Strive Primary",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004091",
    },
    {
        "school": "Calhoun County High School",
        "district": "Calhoun County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130075004081",
    },
    {
        "school": "Calhoun County Middle School",
        "district": "Calhoun County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130075004098",
    },
    {
        "school": "New Hampstead High School",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102004088",
    },
    {
        "school": "Clark Creek Elementary School",
        "district": "Cherokee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130111004072",
    },
    {
        "school": "DeKalb Preparatory Academy Charter",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174004071",
    },
    {
        "school": "Paul J. Blackwell Learning Center",
        "district": "Elbert County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130201004085",
    },
    {
        "school": "Elbert County Elementary School",
        "district": "Elbert County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130201004097",
    },
    {
        "school": "Elbert County Primary School",
        "district": "Elbert County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130201004100",
    },
    {
        "school": "Kelly Mill Elementary",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222004084",
    },
    {
        "school": "Cambridge High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004099",
    },
    {
        "school": "Clear Creek Elementary School",
        "district": "Gilmer County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130234004093",
    },
    {
        "school": "Risley Middle School",
        "district": "Glynn County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130240004076",
    },
    {
        "school": "Monroe County Middle School- Banks Stephens Campus",
        "district": "Monroe County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130372004065",
    },
    {
        "school": "P. B. Ritch Middle School",
        "district": "Paulding County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130402004074",
    },
    {
        "school": "Richmond County Technical Career Magnet School",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438004069",
    },
    {
        "school": "Puu Kukui Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000297",
    },
    {
        "school": "RICHARD MCKENNA CHARTER SCHOOL - ONLINE ALTERNATIVE",
        "district": "IDAHO VIRTUAL HIGH SCHOOL INC.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160000501056",
    },
    {
        "school": "AMERICAN HERITAGE CHARTER SCHOOL",
        "district": "AMERICAN HERITAGE CHARTER SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160016201044",
    },
    {
        "school": "CHIEF TAHGEE ELEMENTARY ACADEMY",
        "district": "CHIEF TAHGEE ELEMENTARY ACADEMY INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160016301040",
    },
    {
        "school": "BONNEVILLE ONLINE SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093001050",
    },
    {
        "school": "SUMMIT HILLS ELEMENTARY SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093001062",
    },
    {
        "school": "TECHNICAL CAREERS HIGH SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160093001063",
    },
    {
        "school": "SOUTHEAST IDAHO PROFESSIONAL TECHNICAL SCHOOL",
        "district": "PRESTON JOINT DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160096001045",
    },
    {
        "school": "COMPASS ACADEMY",
        "district": "IDAHO FALLS DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160153001043",
    },
    {
        "school": "RIGBY MIDDLE SCHOOL",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160157001061",
    },
    {
        "school": "PHILO T FARNSWORTH ELEMENTARY SCHOOL",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160157001064",
    },
    {
        "school": "Kuna Professional Technical",
        "district": "KUNA JOINT DISTRICT",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160177001052",
    },
    {
        "school": "WILLOW CREEK ELEMENTARY SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210001060",
    },
    {
        "school": "BENNETT MOUNTAIN HIGH SCHOOL",
        "district": "MOUNTAIN HOME DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160225001041",
    },
    {
        "school": "IDAHO YOUTH CHALLENGE ACADEMY FALL",
        "district": "OROFINO JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160252001057",
    },
    {
        "school": "IDAHO YOUTH CHALLENGE ACADEMY SPRING",
        "district": "OROFINO JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160252001059",
    },
    {
        "school": "ALAMEDA MIDDLE SCHOOL",
        "district": "POCATELLO DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160264001047",
    },
    {
        "school": "INDIANHEAD ACADEMY HIGH SCHOOL",
        "district": "WEISER DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160333001049",
    },
    {
        "school": "WEST JEFFERSON MIDDLE SCHOOL",
        "district": "WEST JEFFERSON DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160340001053",
    },
    {
        "school": "Forest Elem-D/HH EC Program",
        "district": "NW Suburban Spec Educ Org",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003206204",
    },
    {
        "school": "MacArthur MS-D/HH MS Program",
        "district": "NW Suburban Spec Educ Org",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003206216",
    },
    {
        "school": "Hersey HS-D/HH HS Program",
        "district": "NW Suburban Spec Educ Org",
        "level": "Secondary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003206222",
    },
    {
        "school": "LEARN Chtr Sch 6 N Chicago Campus",
        "district": "North Chicago SD 187",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011006217",
    },
    {
        "school": "Transition Learning Center",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206206",
    },
    {
        "school": "ASSIST RSSP 12",
        "district": "Clay/Cwford/Jsper/Lwrnce/Rhland",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017306215",
    },
    {
        "school": "FLEX Program",
        "district": "Grundy/Kendall ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018406225",
    },
    {
        "school": "New Directions Program",
        "district": "Kane ROE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106239",
    },
    {
        "school": "Wauconda CUSD 118 ALOP",
        "district": "Lake ROE",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019306229",
    },
    {
        "school": "ALOP Academic Learning Program",
        "district": "Region 06 West Cook ISC 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170022106212",
    },
    {
        "school": "Journeys School",
        "district": "Region III Spec Ed Coop",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170032506220",
    },
    {
        "school": "Lovington Grade School",
        "district": "Arthur CUSD 305",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170426002588",
    },
    {
        "school": "Oak Brook Park District",
        "district": "Butler SD 53",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170798006228",
    },
    {
        "school": "8th Grade Academy",
        "district": "Cahokia CUSD 187",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170804006210",
    },
    {
        "school": "7th Grade Academy",
        "district": "Cahokia CUSD 187",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170804006232",
    },
    {
        "school": "Shields Middle School",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006207",
    },
    {
        "school": "Chicago Excel Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006219",
    },
    {
        "school": "Montessori of Englewood Chtr ES",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006221",
    },
    {
        "school": "Goode STEM Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006223",
    },
    {
        "school": "IJLA Charter High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006238",
    },
    {
        "school": "Legal Prep Academy Charter HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006241",
    },
    {
        "school": "Catalyst Charter - Maria ES",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006243",
    },
    {
        "school": "School of Fine Arts",
        "district": "Dolton SD 149",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171242006209",
    },
    {
        "school": "Creative Communications Acad",
        "district": "Dolton SD 149",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171242006230",
    },
    {
        "school": "S T E M Academy",
        "district": "Dolton SD 149",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171242006240",
    },
    {
        "school": "Hickory Grove Elementary School",
        "district": "Dunlap CUSD 323",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171270006224",
    },
    {
        "school": "Bernard Long Elem Sch",
        "district": "Madison CUSD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172397006213",
    },
    {
        "school": "Madison Jr High School",
        "district": "Madison CUSD 12",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172397006234",
    },
    {
        "school": "McElvain School",
        "district": "Murphysboro CUSD 186",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172761006218",
    },
    {
        "school": "Murphy Junior High School",
        "district": "CUSD 308",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027006236",
    },
    {
        "school": "Riverdale PreSchool Center",
        "district": "Rock Falls ESD 13",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173435006211",
    },
    {
        "school": "Thurgood Marshall School",
        "district": "Rockford SD 205",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451006242",
    },
    {
        "school": "Educare of West DuPage",
        "district": "West Chicago ESD 33",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174155006205",
    },
    {
        "school": "Trinity School",
        "district": "West Chicago ESD 33",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174155006233",
    },
    {
        "school": "South School",
        "district": "CUSD 201",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174198006227",
    },
    {
        "school": "Gary Middle College",
        "district": "Gary Middle College",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180010202535",
    },
    {
        "school": "Emmerich Manual High School",
        "district": "CSUSA Manual",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180011200825",
    },
    {
        "school": "Neighbors' New Vistas High School",
        "district": "Neighbors' New Vistas High School",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180011302544",
    },
    {
        "school": "Excel Center - Anderson",
        "district": "Excel Center - Anderson",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180011602533",
    },
    {
        "school": "Theodore Roosevelt Car & Tech Acad",
        "district": "Edison Learning Roosevelt",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180011900645",
    },
    {
        "school": "Christel House DORS",
        "district": "Christel House DORS",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180012202538",
    },
    {
        "school": "Thomas Carr Howe Comm High School",
        "district": "CSUSA Howe",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180012601445",
    },
    {
        "school": "Emma Donnan Middle School",
        "district": "CSUSA Donnan",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180012700823",
    },
    {
        "school": "Canaan Community Academy",
        "district": "Canaan Community Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180012902534",
    },
    {
        "school": "Smith Academy for Excellence",
        "district": "Smith Academy for Excellence",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180013102539",
    },
    {
        "school": "Ripley-Ohio-Dearborn Sp Ed Coop",
        "district": "Ripley-Ohio-Dearborn Sp Ed Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "180013301804",
    },
    {
        "school": "Promise Road Elementary",
        "district": "Noblesville Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180765002546",
    },
    {
        "school": "South Putnam Middle School",
        "district": "South Putnam Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181050002542",
    },
    {
        "school": "FOCUS Program",
        "district": "Hamilton Southeastern Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "IN",
        "nces_id": "181065002543",
    },
    {
        "school": "Southwestern Middle School",
        "district": "Southwestern-Jefferson Co Con",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181080002547",
    },
    {
        "school": "Prairie Trail Elementary",
        "district": "Ankeny Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369002183",
    },
    {
        "school": "Ar-We-Va Elementary Community School",
        "district": "Ar-We-Va Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190378002177",
    },
    {
        "school": "Fremont Elementary",
        "district": "Eddyville-Blakesburg- Fremont CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190495000743",
    },
    {
        "school": "Iowa Connections Academy High School",
        "district": "CAM Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190594002169",
    },
    {
        "school": "Iowa Connections Academy Middle School",
        "district": "CAM Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190594002176",
    },
    {
        "school": "Iowa Connections Academy Elementary",
        "district": "CAM Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190594002180",
    },
    {
        "school": "DC-G Meadows",
        "district": "Dallas Center-Grimes Comm School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190852002174",
    },
    {
        "school": "Riverside ELC",
        "district": "Fort Dodge Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191182002171",
    },
    {
        "school": "Norman Borlaug Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470002168",
    },
    {
        "school": "MVAO Middle School",
        "district": "Maple Valley-Anthon Oto Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191848000079",
    },
    {
        "school": "Anthon Elementary",
        "district": "Maple Valley-Anthon Oto Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191848000080",
    },
    {
        "school": "North Union Middle School",
        "district": "North Kossuth Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192083002179",
    },
    {
        "school": "Spalding Park Elementary",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640002178",
    },
    {
        "school": "Johnson Elementary",
        "district": "Spencer Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192691002170",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Spencer Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192691002182",
    },
    {
        "school": "Fairview Park Elementary",
        "district": "Spencer Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192691002184",
    },
    {
        "school": "Treynor Middle School",
        "district": "Treynor Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192796002175",
    },
    {
        "school": "Skelly Elementary School",
        "district": "El Dorado",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200573002059",
    },
    {
        "school": "Garnett Elementary School",
        "district": "Garnett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200645002060",
    },
    {
        "school": "LTG Richard J. Seitz Elementary",
        "district": "Geary County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200789002061",
    },
    {
        "school": "Vermillion Elementary School",
        "district": "Maize",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200914002057",
    },
    {
        "school": "Christa McAuliffe Academy",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299002056",
    },
    {
        "school": "Ortiz Elementary School",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299002062",
    },
    {
        "school": "Wichita Virtual School",
        "district": "Wichita",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299002063",
    },
    {
        "school": "Christian County Home/Hospital",
        "district": "Christian County",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115002330",
    },
    {
        "school": "High School Homebound",
        "district": "Corbin Independent",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210132002329",
    },
    {
        "school": "Elementary Homebound",
        "district": "Corbin Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210132002333",
    },
    {
        "school": "Panther Academy",
        "district": "Elizabethtown Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210165002319",
    },
    {
        "school": "The Stables",
        "district": "Fayette County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210186002320",
    },
    {
        "school": "Carter G. Woodson Academy",
        "district": "Fayette County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210186002323",
    },
    {
        "school": "Family Care Center",
        "district": "Fayette County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210186002325",
    },
    {
        "school": "Letcher Middle School",
        "district": "Letcher County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210336002318",
    },
    {
        "school": "Hugh C. Spalding Academy",
        "district": "Marion County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210378002328",
    },
    {
        "school": "McCracken County High School",
        "district": "McCracken County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210396002332",
    },
    {
        "school": "The Sterling School",
        "district": "Montgomery County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210425002317",
    },
    {
        "school": "Thomas Nelson High School",
        "district": "Nelson County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210441002324",
    },
    {
        "school": "Jody Richards Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573002327",
    },
    {
        "school": "Rollins Place Elementary",
        "district": "Zachary Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003902347",
    },
    {
        "school": "South Beauregard Upper Elementary School",
        "district": "Beauregard Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018002332",
    },
    {
        "school": "J. S. Clark Elementary School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030002336",
    },
    {
        "school": "Academic Recovery Ombudsman",
        "district": "Caddo Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030002343",
    },
    {
        "school": "Lee High School",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002342",
    },
    {
        "school": "Virtual Academy of Lafourche",
        "district": "Lafourche Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090002339",
    },
    {
        "school": "Caroline Dormon Junior High School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129002344",
    },
    {
        "school": "Lacoste Elementary School",
        "district": "St. Bernard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141002338",
    },
    {
        "school": "Foster Regional Applied Tech Ctr",
        "district": "RSU 09",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "ME",
        "nces_id": "231480900157",
    },
    {
        "school": "Cape Cod Hill Elem School",
        "district": "RSU 09",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480900163",
    },
    {
        "school": "Gerald D Cushing School",
        "district": "RSU 09",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480900548",
    },
    {
        "school": "Mt Blue High School",
        "district": "RSU 09",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480900549",
    },
    {
        "school": "Mt Blue Middle School",
        "district": "RSU 09",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480900550",
    },
    {
        "school": "W G Mallett School",
        "district": "RSU 09",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480900553",
    },
    {
        "school": "Academy Hill School",
        "district": "RSU 09",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480900933",
    },
    {
        "school": "Cascade Brook School",
        "district": "RSU 09",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480901050",
    },
    {
        "school": "BCDC Educational Center",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012001711",
    },
    {
        "school": "Carroll Creek Montessori Public Charter",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001712",
    },
    {
        "school": "Dudley Street Neighborhood Charter School",
        "district": "Dudley Street Neighborhood Charter School (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054302763",
    },
    {
        "school": "Chatham Elementary School",
        "district": "Monomoy Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054400469",
    },
    {
        "school": "Harwich Elementary School",
        "district": "Monomoy Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054400840",
    },
    {
        "school": "Barnstable United Elementary School",
        "district": "Barnstable",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250231002748",
    },
    {
        "school": "Margarita Muniz Academy",
        "district": "Boston",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002753",
    },
    {
        "school": "Edison Academy",
        "district": "Brockton",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309002752",
    },
    {
        "school": "Brookline Early Education Program at Beacon",
        "district": "Brookline",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315002776",
    },
    {
        "school": "Rindge Avenue Upper School",
        "district": "Cambridge",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327002746",
    },
    {
        "school": "Vassal Lane Upper School",
        "district": "Cambridge",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327002756",
    },
    {
        "school": "Cambridge Street Upper School",
        "district": "Cambridge",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327002759",
    },
    {
        "school": "Putnam Avenue Upper School",
        "district": "Cambridge",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250327002768",
    },
    {
        "school": "McKay Arts Academy",
        "district": "Fitchburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250489002775",
    },
    {
        "school": "Georgetown Middle School",
        "district": "Georgetown",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250522002764",
    },
    {
        "school": "North Street Elementary School",
        "district": "Grafton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250537002754",
    },
    {
        "school": "Spark Academy",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002758",
    },
    {
        "school": "UP Academy Leonard Middle School",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002766",
    },
    {
        "school": "Community Day Arlington",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002777",
    },
    {
        "school": "Rogers STEM Academy",
        "district": "Lowell",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702002761",
    },
    {
        "school": "RISE PreSchool",
        "district": "Reading",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250999002751",
    },
    {
        "school": "Salem Prep High School",
        "district": "Salem",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251038002774",
    },
    {
        "school": "Cowing Early Childhood",
        "district": "West Springfield",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251251002757",
    },
    {
        "school": "Anne T. Dunphy School",
        "district": "Williamsburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251299002767",
    },
    {
        "school": "Lighthouse Academy  North Campus",
        "district": "Lighthouse Academy",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260094908334",
    },
    {
        "school": "Lighthouse Academy  Waalkes",
        "district": "Lighthouse Academy",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260094908355",
    },
    {
        "school": "Lighthouse Academy  St Johns",
        "district": "Lighthouse Academy",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260094908360",
    },
    {
        "school": "University Preparatory Science and Math  Elementary",
        "district": "University Preparatory Science and Math (PSAD)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095208401",
    },
    {
        "school": "LincolnKing Academy",
        "district": "Washington-Parks Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095808009",
    },
    {
        "school": "University Preparatory Art  Design Elementary",
        "district": "University Prepararatory Art & Design",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260096108416",
    },
    {
        "school": "North Central Academy Campus",
        "district": "Bay City Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260100001050",
    },
    {
        "school": "Bay City Academy  Farragut Campus",
        "district": "Bay City Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260100008333",
    },
    {
        "school": "WSC Academy  Ypsilanti Campus",
        "district": "WSC Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260100608389",
    },
    {
        "school": "MadisonCarver Academy",
        "district": "Madison-Carver Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260100808372",
    },
    {
        "school": "Trix Academy",
        "district": "Michigan Educational Choice Center",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101004846",
    },
    {
        "school": "Innocademy",
        "district": "Innocademy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101108354",
    },
    {
        "school": "Rutherford Winans Academy",
        "district": "Rutherford Winans Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101201297",
    },
    {
        "school": "Capstone Academy Charter School SDA  South Campus",
        "district": "Capstone Academy Charter School (SDA)",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101308336",
    },
    {
        "school": "Barber Elementary School",
        "district": "Highland Park Public School Academy System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101405502",
    },
    {
        "school": "Evergreen Academy",
        "district": "Evergreen Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101508351",
    },
    {
        "school": "Caniff Liberty Academy",
        "district": "Caniff Liberty Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101608313",
    },
    {
        "school": "NexTech High School",
        "district": "NexTech High School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101708383",
    },
    {
        "school": "The New Standard Academy",
        "district": "The New Standard Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101808324",
    },
    {
        "school": "NexTech High School of Lansing",
        "district": "NexTech High School of Lansing",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101908370",
    },
    {
        "school": "Plymouth Scholars Charter Academy",
        "district": "Plymouth Scholars Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260102008377",
    },
    {
        "school": "South Pointe Scholars Charter Academy",
        "district": "South Pointe Scholars Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260102108332",
    },
    {
        "school": "WAY Academy  Vernor Site",
        "district": "W-A-Y Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260102308403",
    },
    {
        "school": "Faxon Academy",
        "district": "Faxon Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260102708373",
    },
    {
        "school": "Charlton Heston Academy",
        "district": "Charlton Heston Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260102808329",
    },
    {
        "school": "Muskegon Heights Academy",
        "district": "Muskegon Heights Public School Academy System",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260102906170",
    },
    {
        "school": "Cornerstone Health and Technology School",
        "district": "Cornerstone Health and Technology School",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260103008322",
    },
    {
        "school": "River City Scholars Charter Academy",
        "district": "River City Scholars Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260103108338",
    },
    {
        "school": "Escuela Avancemos",
        "district": "Escuela Avancemos",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260103208398",
    },
    {
        "school": "MacDowell Preparatory Academy",
        "district": "MacDowell Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260103304769",
    },
    {
        "school": "Alternative Educational Academy of Iosco County",
        "district": "Alternative Educational Academy of Iosco County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260103408339",
    },
    {
        "school": "Addison Middle School",
        "district": "Addison Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260192008311",
    },
    {
        "school": "Berrien County Truancy Academy",
        "district": "Berrien Springs Public Schools",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008402",
    },
    {
        "school": "Capac Virtual Education Program",
        "district": "Capac Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260780008331",
    },
    {
        "school": "Sunrise Academy",
        "district": "Elk Rapids Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261305008321",
    },
    {
        "school": "Tri County Educational Center",
        "district": "Ferndale Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261428008350",
    },
    {
        "school": "GalesburgAugusta Alternative Education",
        "district": "Galesburg-Augusta Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261545008314",
    },
    {
        "school": "Gobles Virtual Academy",
        "district": "Gobles Public School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261605008357",
    },
    {
        "school": "Grand Haven Cyber School",
        "district": "Grand Haven Area Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261638008318",
    },
    {
        "school": "Diploma Success Community School",
        "district": "Harper Woods The School District of the City of",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261776008328",
    },
    {
        "school": "Hartland Virtual Academy",
        "district": "Hartland Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261791008404",
    },
    {
        "school": "Hazel Park ACCESS Alternative School",
        "district": "Hazel Park School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261803008345",
    },
    {
        "school": "Invest Roosevelt Alternative High School",
        "district": "Hazel Park School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261803008393",
    },
    {
        "school": "Sheridan Road",
        "district": "Lansing Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115008330",
    },
    {
        "school": "Lewton School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115008340",
    },
    {
        "school": "Attwood School",
        "district": "Lansing Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115008348",
    },
    {
        "school": "Mt Hope School",
        "district": "Lansing Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115008378",
    },
    {
        "school": "Pattengill School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115008414",
    },
    {
        "school": "Academy of Science Math and Technology Early College High Sc",
        "district": "Mason County Central Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262313008413",
    },
    {
        "school": "Meridian Early College High School",
        "district": "Meridian Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262358008394",
    },
    {
        "school": "Millington Junior High School",
        "district": "Millington Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262391008309",
    },
    {
        "school": "Muskegon Middle School",
        "district": "Muskegon Public Schools of the City of",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262484008353",
    },
    {
        "school": "Lakeside Elementary",
        "district": "Muskegon Public Schools of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262484008365",
    },
    {
        "school": "Muskegon Community Education Center",
        "district": "Muskegon Public Schools of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262484008375",
    },
    {
        "school": "Richardson Elementary School",
        "district": "Oscoda Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262697008344",
    },
    {
        "school": "Pennsylvania Elementary School",
        "district": "Reeths-Puffer Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262954008356",
    },
    {
        "school": "The Success Academy",
        "district": "Saginaw School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263039008391",
    },
    {
        "school": "Taylor Virtual Learning Academy",
        "district": "Taylor School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263354008364",
    },
    {
        "school": "Vicksburg Pathways High School",
        "district": "Vicksburg Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263495008342",
    },
    {
        "school": "Career Connections Academy",
        "district": "Wayland Union Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263555008315",
    },
    {
        "school": "Rose City School",
        "district": "West Branch-Rose City Area Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263585008312",
    },
    {
        "school": "Virtual Learning Academy Consortium",
        "district": "Oakland Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268088008361",
    },
    {
        "school": "WADENA-DEER CREEK 5TH AND 6TH GRADE",
        "district": "WADENA-DEER CREEK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270002204587",
    },
    {
        "school": "270 - HAP - IS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504573",
    },
    {
        "school": "WEST EDUCATION CENTER ALTERNATIVE",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504603",
    },
    {
        "school": "HENNEPIN GATEWAY TO COLLEGE",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504618",
    },
    {
        "school": "SOUTHERN PLAINS BRIDGES",
        "district": "SOUTHERN PLAINS EDUCATION COOP.",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004604627",
    },
    {
        "school": "Benton-Stearns Education - ASD",
        "district": "Benton-Stearns Education District",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007104581",
    },
    {
        "school": "YELLOW MEDICINE EAST MIDDLE SCHOOL",
        "district": "YELLOW MEDICINE EAST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009904609",
    },
    {
        "school": "Hiawatha College Prep - Kingfield",
        "district": "HIAWATHA ACADEMIES",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028804599",
    },
    {
        "school": "MASTERY SCHOOL",
        "district": "MASTERY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270037304602",
    },
    {
        "school": "NASHA SHKOLA CHARTER SCHOOL",
        "district": "NASHA SHKOLA CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270037804635",
    },
    {
        "school": "TRI-CITY UNITED HIGH SCHOOL",
        "district": "TRI-CITY UNITED SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270037904578",
    },
    {
        "school": "LONSDALE PRE K-6",
        "district": "TRI-CITY UNITED SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270037904606",
    },
    {
        "school": "MONTGOMERY PRE K-8",
        "district": "TRI-CITY UNITED SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270037904625",
    },
    {
        "school": "LE CENTER PRE K-8",
        "district": "TRI-CITY UNITED SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270037904626",
    },
    {
        "school": "PRODEO ACADEMY",
        "district": "PRODEO ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038004642",
    },
    {
        "school": "KARNER BLUE EDUCATION CENTER",
        "district": "NORTHEAST METRO 916",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270226404643",
    },
    {
        "school": "I.J. HOLTON INTERMEDIATE SCHOOL",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270345004638",
    },
    {
        "school": "PINES SCHOOL DAY PROGRAM",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270810004616",
    },
    {
        "school": "PINES SCHOOL - RJC",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270810004620",
    },
    {
        "school": "LA ACADEMIA",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819004598",
    },
    {
        "school": "112 ALC MIDDLE SCHOOL",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270819004622",
    },
    {
        "school": "ROCORI ALC",
        "district": "ROCORI PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270944004629",
    },
    {
        "school": "EDEN VALLEY-WATKINS ALP",
        "district": "EDEN VALLEY-WATKINS SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271119004637",
    },
    {
        "school": "C.O.M.P.A.S.S.",
        "district": "Elk River School District",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271137004608",
    },
    {
        "school": "NORTH ACADEMY SENIOR HIGH",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004557",
    },
    {
        "school": "Justice Page Middle School",
        "district": "Minneapolis Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004574",
    },
    {
        "school": "NEW PRAGUE SUMMER CREDIT RECOVERY",
        "district": "NEW PRAGUE AREA SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272343004560",
    },
    {
        "school": "Compass Learning Center",
        "district": "NEW PRAGUE AREA SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272343004568",
    },
    {
        "school": "NEW PRAGUE CREDIT RECOVERY",
        "district": "NEW PRAGUE AREA SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272343004610",
    },
    {
        "school": "COOPER CREDIT RECOVERY",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273178004569",
    },
    {
        "school": "ISD 281 Credit Recovery",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273178004580",
    },
    {
        "school": "ADULT ACADEMICS",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273178004585",
    },
    {
        "school": "ROBBINSDALE ACADEMIC SUMMER PROGRAM",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273178004612",
    },
    {
        "school": "HIGHVIEW ALC",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273178004613",
    },
    {
        "school": "HIGHVIEW INDEPENDENT STUDY",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273178004623",
    },
    {
        "school": "ARMSTRONG CREDIT RECOVERY",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273178004628",
    },
    {
        "school": "ROBBINSDALE TASC ALC",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273178004630",
    },
    {
        "school": "ROYALTON MIDDLE SCHOOL",
        "district": "ROYALTON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273252004640",
    },
    {
        "school": "SARTELL EC SERVICE CENTER",
        "district": "SARTELL-ST. STEPHEN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273282004593",
    },
    {
        "school": "SHAKOPEE SR ALC",
        "district": "SHAKOPEE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273300004583",
    },
    {
        "school": "Waconia Learning Center SS/AS",
        "district": "WACONIA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274146004586",
    },
    {
        "school": "Waconia Learning Center",
        "district": "WACONIA PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274146004597",
    },
    {
        "school": "Learning Center Night",
        "district": "WORTHINGTON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274416004636",
    },
    {
        "school": "DESOTO CO CAREER CENTER EAST",
        "district": "DESOTO CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280132001391",
    },
    {
        "school": "BAILEY MIDDLE APAC SCHOOL",
        "district": "JACKSON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280219001385",
    },
    {
        "school": "OCEAN SPRINGS UPPER ELEMENTARY SCHO",
        "district": "OCEAN SPRINGS SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280336001392",
    },
    {
        "school": "LAKE ELEMENTARY SCHOOL",
        "district": "SCOTT CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280390001387",
    },
    {
        "school": "LAKE HIGH SCHOOL",
        "district": "SCOTT CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280390001389",
    },
    {
        "school": "HOGAN PREPARATORY ACADEMY ELEM",
        "district": "HOGAN PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290001403222",
    },
    {
        "school": "GUADALUPE CENTERS ELEMENTARY",
        "district": "GUADALUPE CENTERS SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002903216",
    },
    {
        "school": "GATEWAY SCIENCE ACADEMY HIGH",
        "district": "GATEWAY SCIENCE ACAD/ST LOUIS",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059203205",
    },
    {
        "school": "ACADEMY FOR INTEGRATED ARTS",
        "district": "ACADEMY FOR INTEGRATED ARTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060403209",
    },
    {
        "school": "COMMUNITY FOR KIDS",
        "district": "FAIRFAX R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291176003217",
    },
    {
        "school": "WEST EARLY CHILDHOOD CENTER",
        "district": "HAZELWOOD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383003204",
    },
    {
        "school": "EAST EARLY CHILDHOOD CENTER",
        "district": "HAZELWOOD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383003208",
    },
    {
        "school": "CENTRAL EARLY CHILDHOOD CENTER",
        "district": "HAZELWOOD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291383003218",
    },
    {
        "school": "ABRAHAM MALLINSON ELEMENTARY",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548003210",
    },
    {
        "school": "LITTLE BLUE ELEMENTARY",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548003213",
    },
    {
        "school": "SUCCESS ACADEMY",
        "district": "KANSAS CITY 33",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640003220",
    },
    {
        "school": "LEARNING INITIATIVE NEOSHO/CR",
        "district": "NEOSHO SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MO",
        "nces_id": "292181003212",
    },
    {
        "school": "JOHN THOMAS SCHOOL OF DISCOVER",
        "district": "Nixa Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292253003202",
    },
    {
        "school": "TIFFANY RIDGE ELEMENTARY SCHL",
        "district": "PARK HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355003221",
    },
    {
        "school": "GEORGE WASHINGTON CARVER ELEM",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928003211",
    },
    {
        "school": "ACAD OF ENTRE STDY@LOUVERTURE",
        "district": "ST. LOUIS CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928003215",
    },
    {
        "school": "6TH GRADE CENTER",
        "district": "WAYNESVILLE R-VI",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293144003207",
    },
    {
        "school": "H C Davis Elementary",
        "district": "Cut Bank Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000301106",
    },
    {
        "school": "Horizon Elementary",
        "district": "Cut Bank Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300000301107",
    },
    {
        "school": "Frenchtown Intermediate School",
        "district": "Frenchtown K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301152001105",
    },
    {
        "school": "Geraldine School",
        "district": "Geraldine K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301221000332",
    },
    {
        "school": "Geraldine Middle School",
        "district": "Geraldine K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301221000948",
    },
    {
        "school": "Hot Springs School",
        "district": "Hot Springs K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301464000448",
    },
    {
        "school": "Hot Springs 7-8",
        "district": "Hot Springs K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301464001054",
    },
    {
        "school": "NEW DISCOVERIES PRESCHOOL",
        "district": "BROKEN BOW PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001102271",
    },
    {
        "school": "BOYS TOWN INTERVENTION AND ASSESSMENT SCHOOL",
        "district": "BOYS TOWN INTERIM PRG SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310014602263",
    },
    {
        "school": "INTERMEDIATE SCHOOL AT JR/SR HIGH SCHOOL",
        "district": "RAYMOND CENTRAL PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310495002262",
    },
    {
        "school": "WHITETAIL CREEK ELEMENTARY",
        "district": "GRETNA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317122002264",
    },
    {
        "school": "BUFFALO HILLS ELEMENTARY",
        "district": "KEARNEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317239002265",
    },
    {
        "school": "KLOEFKORN ELEMENTARY",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002268",
    },
    {
        "school": "UNO/OPS MIDDLE COLLEGE PROGRAM",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482002272",
    },
    {
        "school": "PAPILLION LA VISTA EARLY CHILDHOOD CENTER (PLECC)",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527002270",
    },
    {
        "school": "WAYNE ELEMENTARY SCHOOL",
        "district": "WAYNE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317852002267",
    },
    {
        "school": "CENTRAL LEARNING CENTER  SOUTH",
        "district": "EDUCATIONAL SERVICE UNIT 08",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "318008002269",
    },
    {
        "school": "Pinecrest Academy of Nevada Cadence",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100825",
    },
    {
        "school": "Honors Academy of Literature",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100826",
    },
    {
        "school": "Sparks Integrated Preschool",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000827",
    },
    {
        "school": "Making Community Connections Charter School (M)",
        "district": "Making Community Connections Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330328900710",
    },
    {
        "school": "PACE Career Academy Charter School",
        "district": "PACE Career Academy Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330329200701",
    },
    {
        "school": "Manchester School of Technology (High School)",
        "district": "Manchester School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330459000708",
    },
    {
        "school": "Maple Street Magnet School",
        "district": "Rochester School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330594000709",
    },
    {
        "school": "BelovED Community Charter School",
        "district": "BelovED Community Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340075903196",
    },
    {
        "school": "Dr. J.P. Cleary Elementary School",
        "district": "Buena Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340240003221",
    },
    {
        "school": "George Washington School",
        "district": "Edgewater School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340444003211",
    },
    {
        "school": "Franklin D Roosevelt School",
        "district": "Edison Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340450003237",
    },
    {
        "school": "iPrep Academy School No 8",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459003197",
    },
    {
        "school": "Academy of Technology Design",
        "district": "Hudson County Schools of Technology School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340757003198",
    },
    {
        "school": "Bayonne Academy",
        "district": "Hudson County Schools of Technology School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340757003233",
    },
    {
        "school": "Knowledge Advanced Skills",
        "district": "Hudson County Schools of Technology School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340757003241",
    },
    {
        "school": "Robert C. Wood Sr Early Childhood Center",
        "district": "Little Egg Harbor Township School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340870003199",
    },
    {
        "school": "Logan Middle School",
        "district": "Logan Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340888003231",
    },
    {
        "school": "Godwin Elementary School",
        "district": "Midland Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341014003209",
    },
    {
        "school": "Applegarth Elementary School",
        "district": "Monroe Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341050003229",
    },
    {
        "school": "Early Childhood School - West",
        "district": "Newark Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134003193",
    },
    {
        "school": "Eagle Academy for Young Men of Newark",
        "district": "Newark Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134003227",
    },
    {
        "school": "Career and Innovation Academy of Orange",
        "district": "ORANGE BOARD OF EDUCATION School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "341227003217",
    },
    {
        "school": "Colin Powell Elementary School",
        "district": "Union City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341638003215",
    },
    {
        "school": "Academy of Law & Public Safety",
        "district": "Monmouth County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341750003219",
    },
    {
        "school": "MISSION ACHIEVEMENT AND SUCCESS 1.0",
        "district": "MISSION ACHIEVEMENT AND SUCCESS",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350014801089",
    },
    {
        "school": "SW AERONAUTICS MATHEMATICS AND SCIENCE ACADEMY",
        "district": "SW AERONAUTICS MATHEMATICS AND SCIENCE ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015101088",
    },
    {
        "school": "ESTANCIA VALLEY CLASSICAL ACADEMY",
        "district": "ESTANCIA VALLEY CLASSICAL ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015201085",
    },
    {
        "school": "MCCURDY CHARTER SCHOOL",
        "district": "MCCURDY CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015301083",
    },
    {
        "school": "LA TIERRA MONTESSORI SCHOOL OF THE ARTS AND SCIENCES",
        "district": "LA TIERRA MONTESSORI SCHOOL OF THE ARTS AND SCIENCES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015501084",
    },
    {
        "school": "NEW AMERICA SCHOOL - LAS CRUCES",
        "district": "NEW AMERICA SCHOOL - LAS CRUCES",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015601082",
    },
    {
        "school": "WALATOWA CHARTER HIGH",
        "district": "WALATOWA CHARTER HIGH",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350015800883",
    },
    {
        "school": "FARMINGTON PRESCHOOL ACADEMY WEST",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099001091",
    },
    {
        "school": "CENTENNIAL HIGH SCHOOL",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150001090",
    },
    {
        "school": "PS 527 EAST SIDE SCHOOL FOR SOCIAL ACTION",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706304",
    },
    {
        "school": "UNION SQUARE ACADEMY FOR HEALTH SCIENCES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007706309",
    },
    {
        "school": "PECK SLIP SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706334",
    },
    {
        "school": "HARVEST COLLEGIATE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706361",
    },
    {
        "school": "ACADEMY FOR SOFTWARE ENGINEERING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007706363",
    },
    {
        "school": "CASTLE BRIDGE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008306330",
    },
    {
        "school": "MOTT HAVEN COMMUNITY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008406352",
    },
    {
        "school": "BLUEPRINT MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506302",
    },
    {
        "school": "WESTCHESTER SQUARE ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506326",
    },
    {
        "school": "SCHOOL FOR TOURISM AND HOSPITALITY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360008506348",
    },
    {
        "school": "BRONX COMPASS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506357",
    },
    {
        "school": "MOUNT EDEN CHILDREN'S ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606312",
    },
    {
        "school": "CLAREMONT INTERNATIONAL HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606329",
    },
    {
        "school": "YOUNG WOMEN'S LEADERSHIP SCHOOL OF THE BRONX",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606345",
    },
    {
        "school": "HIGH SCHOOL FOR ENERGY AND TECHNOLOGY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360008706364",
    },
    {
        "school": "BRONX PARK MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806314",
    },
    {
        "school": "PELHAM GARDENS MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806322",
    },
    {
        "school": "LINDEN TREE ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806338",
    },
    {
        "school": "URBAN ASSEMBLY UNISON SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009106366",
    },
    {
        "school": "MADIBA PREP MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009406306",
    },
    {
        "school": "BROOKLYN INSTITUTE FOR LIBERAL ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009506300",
    },
    {
        "school": "NEW HEIGHTS MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009506335",
    },
    {
        "school": "BROOKLYN ARTS AND SCIENCE ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009506340",
    },
    {
        "school": "EVERGREEN MIDDLE SCHOOL FOR URBAN EXPLORATION",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #32",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009706331",
    },
    {
        "school": "PS 110",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806323",
    },
    {
        "school": "PS 78",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306362",
    },
    {
        "school": "BROOKLYN ARBOR ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #14",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360011906350",
    },
    {
        "school": "ACADEMY FOR YOUNG WRITERS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012005884",
    },
    {
        "school": "SPRING CREEK COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006339",
    },
    {
        "school": "RIVERDALE AVENUE COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012106313",
    },
    {
        "school": "BROWNSVILLE COLLABORATIVE MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012106351",
    },
    {
        "school": "WAVE PREPARATORY ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306360",
    },
    {
        "school": "WEST BUFFALO CHARTER SCHOOL",
        "district": "WEST BUFFALO CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360105506298",
    },
    {
        "school": "CENTRAL QUEENS ACADEMY CHARTER SCHOOL",
        "district": "CENTRAL QUEENS ACADEMY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360105606317",
    },
    {
        "school": "NEW VISIONS AIM CHARTER HIGH SCHOOL I",
        "district": "NEW VISIONS AIM CHARTER HIGH SCHOOL I",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360105706324",
    },
    {
        "school": "EXPLORE EXCEED CHARTER SCHOOL",
        "district": "EXPLORE EXCEED CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360105806354",
    },
    {
        "school": "LAUNCH EXPEDITIONARY LEARNING CHARTER SCHOOL",
        "district": "LAUNCH EXPEDITIONARY LEARNING CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360105906349",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-COBBLE HILL",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-COBBLE HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360106006359",
    },
    {
        "school": "NEW DAWN CHARTER HIGH SCHOOL",
        "district": "NEW DAWN CHARTER HIGH SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360106106343",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-WILLIAMSBURG",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-WILLIAMSBURG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360106206346",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-BED STUY 2",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-BED STUY 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360106306327",
    },
    {
        "school": "BEGINNING WITH CHILDREN CHARTER SCHOOL II",
        "district": "BEGINNING WITH CHILDREN CHARTER SCHOOL II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360106406305",
    },
    {
        "school": "URBAN DOVE TEAM CHARTER SCHOOL",
        "district": "URBAN DOVE TEAM CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360106506342",
    },
    {
        "school": "CHILDREN'S AID COLLEGE PREPARATORY CHARTER SCHOOL",
        "district": "CHILDREN'S AID COLLEGE PREPARATORY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360106606303",
    },
    {
        "school": "NEW VISIONS AIM CHARTER HIGH SCHOOL II",
        "district": "NEW VISIONS AIM CHARTER HIGH SCHOOL II",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360106706319",
    },
    {
        "school": "ICAHN CHARTER SCHOOL 6",
        "district": "ICAHN CHARTER SCHOOL 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360106906355",
    },
    {
        "school": "FAMILY LIFE ACADEMY CHARTER SCHOOL II",
        "district": "FAMILY LIFE ACADEMY CHARTER SCHOOL II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360107006318",
    },
    {
        "school": "MOTT HALL CHARTER SCHOOL",
        "district": "MOTT HALL CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360107106328",
    },
    {
        "school": "NEW VISIONS CHTR HS-ADV MA/SCI II",
        "district": "NEW VISIONS CHTR HS-ADV MA/SCI II",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360107206365",
    },
    {
        "school": "NEW VISIONS CHARTER HIGH SCHOOL FOR THE HUMANITIES II",
        "district": "NEW VISIONS CHARTER HIGH SCHOOL FOR THE HUMANITIES II",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360107306320",
    },
    {
        "school": "HEKETI COMMUNITY CHARTER SCHOOL",
        "district": "HEKETI COMMUNITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360107406336",
    },
    {
        "school": "KIPP NYC WASHINGTON HEIGHTS ACADEMY CHARTER SCHOOL",
        "district": "KIPP NYC WASHINGTON HEIGHTS ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360107506307",
    },
    {
        "school": "GLOBAL COMMUNITY CHARTER SCHOOL",
        "district": "GLOBAL COMMUNITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360107606315",
    },
    {
        "school": "NEIGHBORHOOD CHARTER SCHOOL OF HARLEM",
        "district": "NEIGHBORHOOD CHARTER SCHOOL OF HARLEM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360107706308",
    },
    {
        "school": "DEMOCRACY PREP ENDURANCE CHARTER SCHOOL",
        "district": "DEMOCRACY PREP ENDURANCE CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360107806310",
    },
    {
        "school": "MANHATTAN CHARTER SCHOOL II",
        "district": "MANHATTAN CHARTER SCHOOL II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360107906341",
    },
    {
        "school": "YOUNG WOMEN'S COLLEGE PREP CHARTER",
        "district": "YOUNG WOMEN'S COLLEGE PREP CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108006316",
    },
    {
        "school": "ALTMAR-PARISH-WILLIAMSTOWN ELEMENTARY SCHOOL",
        "district": "ALTMAR-PARISH-WILLIAMSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360282006344",
    },
    {
        "school": "MIDDLE EARLY COLLEGE HIGH SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585006353",
    },
    {
        "school": "DEAUVILLE GARDENS WEST ELEMENTARY SCHOOL",
        "district": "COPIAGUE UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360831006333",
    },
    {
        "school": "GERMANTOWN ELEMENTARY SCHOOL",
        "district": "GERMANTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361203006321",
    },
    {
        "school": "GERMANTOWN JUNIOR-SENIOR HIGH SCHOOL",
        "district": "GERMANTOWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361203006337",
    },
    {
        "school": "RONDOUT VALLEY JUNIOR HIGH SCHOOL",
        "district": "RONDOUT VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362496006325",
    },
    {
        "school": "RONDOUT VALLEY INTERMEDIATE SCHOOL",
        "district": "RONDOUT VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362496006347",
    },
    {
        "school": "SCHUYLERVILLE MIDDLE SCHOOL",
        "district": "SCHUYLERVILLE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362616006311",
    },
    {
        "school": "KAPLAN CAREER ACADEMY",
        "district": "GREENBURGH-NORTH CASTLE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "362798006356",
    },
    {
        "school": "Blue Ridge Academy",
        "district": "Avery County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370030003294",
    },
    {
        "school": "Langtree Charter Academy",
        "district": "Langtree Charter Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033103287",
    },
    {
        "school": "Island Montessori Charter School",
        "district": "Island Montessori Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033203283",
    },
    {
        "school": "Invest Collegiate Transform",
        "district": "Invest Collegiate",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033303305",
    },
    {
        "school": "Uwharrie Charter Academy",
        "district": "Uwharrie Charter Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033403303",
    },
    {
        "school": "Falls Lake Academy",
        "district": "Falls Lake Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033603304",
    },
    {
        "school": "Longleaf School of the Arts",
        "district": "Longleaf School of the Arts",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033703282",
    },
    {
        "school": "Oxford Preparatory",
        "district": "Oxford Preparatory School",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033803292",
    },
    {
        "school": "Charlotte Choice Charter",
        "district": "Charlotte Choice Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370033903293",
    },
    {
        "school": "Douglass Academy",
        "district": "Douglass Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370034003290",
    },
    {
        "school": "Willow Oak Montessori",
        "district": "Willow Oak Montessori",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370034103301",
    },
    {
        "school": "NC Leadership Charter Academy",
        "district": "NC Leadership Charter Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370034303289",
    },
    {
        "school": "Summerfield Charter Academy",
        "district": "Summerfield Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370034403286",
    },
    {
        "school": "Southeastern Academy",
        "district": "Southeastern Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370034603302",
    },
    {
        "school": "Cabarrus Charter Academy",
        "district": "Cabarrus Charter Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370034703281",
    },
    {
        "school": "Z.E.C.A. School of Arts and Technology",
        "district": "Z.E.C.A. School of Arts and Technology",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370034803278",
    },
    {
        "school": "Thomas Academy",
        "district": "Thomas Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370034903299",
    },
    {
        "school": "Aristotle Preparatory Academy",
        "district": "Aristotle Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370035003296",
    },
    {
        "school": "Paul R Brown Leadership Academy",
        "district": "Paul R Brown Leadership Academy",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370035103285",
    },
    {
        "school": "The Institute Development Young Leaders",
        "district": "The Institute for the Development of You",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370035203284",
    },
    {
        "school": "Pinnacle Classical Academy",
        "district": "Pinnacle Classical Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370035303291",
    },
    {
        "school": "Northside Elementary",
        "district": "Chapel Hill-Carrboro City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370072003275",
    },
    {
        "school": "Smith Farm Elementary",
        "district": "Winston Salem / Forsyth County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370150003274",
    },
    {
        "school": "Franklinton Middle",
        "district": "Franklin County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370153003297",
    },
    {
        "school": "Allen Jay Middle - A Preparatory Academy",
        "district": "Guilford County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192003295",
    },
    {
        "school": "Grand Oak Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003273",
    },
    {
        "school": "Rocky Mount Middle",
        "district": "Nash-Rocky Mount Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327003272",
    },
    {
        "school": "Fairview Elementary",
        "district": "Nash-Rocky Mount Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327003298",
    },
    {
        "school": "Rolesville High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003276",
    },
    {
        "school": "LINCOLN ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400864",
    },
    {
        "school": "LIBERTY ELEMENTARY SCHOOL",
        "district": "BISMARCK 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400865",
    },
    {
        "school": "LEGACY HIGH SCHOOL",
        "district": "BISMARCK 1",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380001400866",
    },
    {
        "school": "HAZEN MIDDLE SCHOOL",
        "district": "HAZEN 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003100863",
    },
    {
        "school": "PRAIRIE ROSE ELEMENTARY SCHOOL",
        "district": "DICKINSON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003800869",
    },
    {
        "school": "EDMORE ELEMENTARY SCHOOL",
        "district": "EDMORE 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380595000868",
    },
    {
        "school": "INDEPENDENCE ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000867",
    },
    {
        "school": "Canton College Preparatory School",
        "district": "Canton College Preparatory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390147005705",
    },
    {
        "school": "Academy for Urban Scholars Youngstown",
        "district": "Academy for Urban Scholars Youngstown",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390147205727",
    },
    {
        "school": "Hope Academy for Autism",
        "district": "Hope Academy for Autism",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390147305721",
    },
    {
        "school": "SunBridge Schools",
        "district": "SunBridge Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390147505738",
    },
    {
        "school": "Columbus Collegiate Academy - West",
        "district": "Columbus Collegiate Academy - West",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390147805737",
    },
    {
        "school": "A+ Children's Academy",
        "district": "A+ Children's Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390148005718",
    },
    {
        "school": "STEAM Academy of Warrensville Heights",
        "district": "STEAM Academy of Warrensville Heights",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390148205756",
    },
    {
        "school": "Citizens Academy East",
        "district": "Citizens Academy East",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390148605709",
    },
    {
        "school": "Ohio College Preparatory School",
        "district": "Ohio College Preparatory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390148705729",
    },
    {
        "school": "Imagine Hill Avenue",
        "district": "Imagine Hill Avenue",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390148805715",
    },
    {
        "school": "Metro Early College High School",
        "district": "Metro Early College High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390149005710",
    },
    {
        "school": "Cleveland Preparatory Academy",
        "district": "Cleveland Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390149605746",
    },
    {
        "school": "Stepstone Academy",
        "district": "Stepstone Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390149805759",
    },
    {
        "school": "Lake Erie College Preparatory School",
        "district": "Lake Erie College Preparatory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390149905712",
    },
    {
        "school": "Academy of Educational Excellence",
        "district": "Academy of Educational Excellence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390150205733",
    },
    {
        "school": "Akron Preparatory School",
        "district": "Akron Preparatory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390150305726",
    },
    {
        "school": "Village Preparatory School Woodland Hills",
        "district": "Village Preparatory School Woodland Hills",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390150505720",
    },
    {
        "school": "DECA PREP",
        "district": "DECA PREP",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390150805714",
    },
    {
        "school": "Akron STEM High School",
        "district": "Akron City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434805731",
    },
    {
        "school": "Chauncey Early-Learning Center",
        "district": "Athens City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435205725",
    },
    {
        "school": "Hyde Park School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505713",
    },
    {
        "school": "Euclid Schools Early Learning Village",
        "district": "Euclid City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390439505717",
    },
    {
        "school": "Massillon Intermediate School",
        "district": "Massillon City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443505734",
    },
    {
        "school": "Crossgates Pre-School",
        "district": "Toledo City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449005708",
    },
    {
        "school": "Wickliffe Elementary School",
        "district": "Upper Arlington City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449305751",
    },
    {
        "school": "Westbrooke Village",
        "district": "Trotwood-Madison City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486905707",
    },
    {
        "school": "Kleptz Early Childhood Learning Center",
        "district": "Northmont City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487205742",
    },
    {
        "school": "Robert H Studebaker",
        "district": "Huber Heights City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487505762",
    },
    {
        "school": "Western Primary",
        "district": "Western Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491505749",
    },
    {
        "school": "Harlan-Butlerville Elementary School",
        "district": "Little Miami Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504405750",
    },
    {
        "school": "Red Raider Preschool",
        "district": "Painesville City Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391001505728",
    },
    {
        "school": "BELFONTE BELL ES (ADAIR CNTY)",
        "district": "BELFONTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400384002750",
    },
    {
        "school": "CENTRAL INTERMEDIATE SCHOOL",
        "district": "BIXBY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400450002748",
    },
    {
        "school": "CACHE 5TH AND 6TH GRADE MS",
        "district": "CACHE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400612002757",
    },
    {
        "school": "CENTRAL HIGH JHS",
        "district": "CENTRAL HIGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400717002756",
    },
    {
        "school": "CHEROKEE MS",
        "district": "CHEROKEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400741002745",
    },
    {
        "school": "DEER CREEK INTERMEDIATE SCHOOL",
        "district": "DEER CREEK",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400957002749",
    },
    {
        "school": "ELMORE CITY JHS",
        "district": "ELMORE CITY-PERNELL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401086002746",
    },
    {
        "school": "NEWCASTLE EARLY CHILDHOOD CTR",
        "district": "NEWCASTLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402151002751",
    },
    {
        "school": "RONALD REAGAN ES",
        "district": "NORMAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402172002752",
    },
    {
        "school": "PIEDMONT INTERMEDIATE ES",
        "district": "PIEDMONT",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402397002759",
    },
    {
        "school": "VERDIGRIS UPPER ES",
        "district": "VERDIGRIS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403111002758",
    },
    {
        "school": "WEWOKA MS",
        "district": "WEWOKA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403246002762",
    },
    {
        "school": "Hillsboro Online Academy",
        "district": "Hillsboro SD 1J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410002301824",
    },
    {
        "school": "Hope Chinese Charter School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001823",
    },
    {
        "school": "Woodland Charter School",
        "district": "Three Rivers/Josephine County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410690001812",
    },
    {
        "school": "Le Monde French Immersion Public Charter School",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001814",
    },
    {
        "school": "Roosevelt High School",
        "district": "Portland SD 1J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001821",
    },
    {
        "school": "Ridgeview High School",
        "district": "Redmond SD 2J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035001820",
    },
    {
        "school": "Battle Creek Elementary School",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001819",
    },
    {
        "school": "Cesar E Chavez Elem",
        "district": "Salem-Keizer SD 24J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411082001826",
    },
    {
        "school": "Willamette Leadership Academy",
        "district": "Springfield SD 19",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167001525",
    },
    {
        "school": "Two Rivers Dos Rios Elementary",
        "district": "Springfield SD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411167001815",
    },
    {
        "school": "Lowrie Primary School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317001822",
    },
    {
        "school": "Trillium Creek Primary School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317001825",
    },
    {
        "school": "Chester Charter Scholars Academy CS",
        "district": "Chester Charter Scholars Academy CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420085707437",
    },
    {
        "school": "Esperanza Cyber CS",
        "district": "Esperanza Cyber CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420085807447",
    },
    {
        "school": "Propel CS-Pitcairn",
        "district": "Propel CS-Pitcairn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420085907427",
    },
    {
        "school": "Arts Academy CS",
        "district": "Arts Academy CS",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420086007470",
    },
    {
        "school": "Baden Academy CS",
        "district": "Baden Academy CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420086107428",
    },
    {
        "school": "Mastery CS-Cleveland Elementary",
        "district": "Mastery CS-Cleveland Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420086207474",
    },
    {
        "school": "The Philadelphia CS for Arts and Science",
        "district": "The Philadelphia CS for Arts and Sciences at HR Edmunds",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420086307473",
    },
    {
        "school": "Universal Creighton Charter School",
        "district": "Universal Creighton Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420086607457",
    },
    {
        "school": "Howard Gardner Multiple Intelligence CS",
        "district": "Howard Gardner Multiple Intelligence CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420086707435",
    },
    {
        "school": "Memphis Street Academy CS @ JP Jones",
        "district": "Memphis Street Academy CS @ JP Jones",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420087007454",
    },
    {
        "school": "SRU El Sch",
        "district": "Athens Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420267007453",
    },
    {
        "school": "Harlan Rowe MS",
        "district": "Athens Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420267007466",
    },
    {
        "school": "Davis El Sch",
        "district": "Centennial SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420519007451",
    },
    {
        "school": "Chambersburg Area Career Magnet Sch",
        "district": "Chambersburg Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555007449",
    },
    {
        "school": "Conneaut Valley MS",
        "district": "Conneaut SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420659007431",
    },
    {
        "school": "Conneaut Lake MS",
        "district": "Conneaut SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420659007434",
    },
    {
        "school": "Conneaut Area Senior High",
        "district": "Conneaut SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420659007439",
    },
    {
        "school": "Donegal Intermediate School",
        "district": "Donegal SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420765007461",
    },
    {
        "school": "Dover Area El Sch",
        "district": "Dover Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420768007448",
    },
    {
        "school": "McAdoo-Kelayres El/MS",
        "district": "Hazleton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421170007456",
    },
    {
        "school": "Landis Run Intermediate School",
        "district": "Manheim Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421458007467",
    },
    {
        "school": "West Snyder El Sch",
        "district": "Midd-West SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421521007441",
    },
    {
        "school": "Moon Area Upper MS",
        "district": "Moon Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421583007430",
    },
    {
        "school": "Moon Area Lower MS",
        "district": "Moon Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421583007462",
    },
    {
        "school": "Seventh Street Sch",
        "district": "Oil City Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421809007455",
    },
    {
        "school": "Pittsburgh Langley K-8",
        "district": "Pittsburgh SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917007468",
    },
    {
        "school": "Clear Run Intrmd Sch",
        "district": "Pocono Mountain SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421950007471",
    },
    {
        "school": "Millmont El Sch",
        "district": "Reading SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004007458",
    },
    {
        "school": "State El Ctr",
        "district": "Wyoming Valley West SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422595007450",
    },
    {
        "school": "Penn Wood HS",
        "district": "William Penn SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422639007452",
    },
    {
        "school": "Shiloh Hills El Sch",
        "district": "Wilson SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422658007429",
    },
    {
        "school": "Green Valley El Sch",
        "district": "Wilson SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422658007465",
    },
    {
        "school": "Devers Sch",
        "district": "York City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422682007432",
    },
    {
        "school": "Ferguson Sch",
        "district": "York City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422682007440",
    },
    {
        "school": "Goode Sch",
        "district": "York City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422682007442",
    },
    {
        "school": "Davis Sch",
        "district": "York City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422682007460",
    },
    {
        "school": "Jackson Sch",
        "district": "York City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422682007463",
    },
    {
        "school": "McKinley Sch",
        "district": "York City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422682007469",
    },
    {
        "school": "Harleyville-Ridgeville Middle",
        "district": "Dorchester 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450000201597",
    },
    {
        "school": "Clay Hill Elementary",
        "district": "Dorchester 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450000201600",
    },
    {
        "school": "Anderson  Five Charter School",
        "district": "Anderson 05",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450090001602",
    },
    {
        "school": "Richard Carroll Elementary",
        "district": "Bamberg 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450093001609",
    },
    {
        "school": "Cane Bay Middle",
        "district": "Berkeley 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001608",
    },
    {
        "school": "Montessori Community School",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001610",
    },
    {
        "school": "North Charleston Creative Arts Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001611",
    },
    {
        "school": "Dillon Middle",
        "district": "Dillon 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450192001596",
    },
    {
        "school": "Lucy T. Davis Elementary",
        "district": "Florence 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213001601",
    },
    {
        "school": "Coastal Montessori Charter",
        "district": "Georgetown 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450228001607",
    },
    {
        "school": "Palmetto Academy of Learning Motorsports (PALM)",
        "district": "Horry 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001595",
    },
    {
        "school": "River Oaks Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001603",
    },
    {
        "school": "Center for Advanced Technical Studies",
        "district": "Lexington 05",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450282001599",
    },
    {
        "school": "Bennettsville Intermediate",
        "district": "Marlboro 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450297001605",
    },
    {
        "school": "Westwood High",
        "district": "Richland 02",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001606",
    },
    {
        "school": "Union County Career and Technology Center",
        "district": "Union 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450375001612",
    },
    {
        "school": "Fox Creek High",
        "district": "SC Public Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101176",
    },
    {
        "school": "Lowcountry Leadership Charter School",
        "district": "SC Public Charter School District",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101613",
    },
    {
        "school": "Midlands Middle College",
        "district": "SC Public Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101614",
    },
    {
        "school": "Marion Intermediate",
        "district": "Marion 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390800053",
    },
    {
        "school": "Easterling Primary",
        "district": "Marion 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390800761",
    },
    {
        "school": "Johnakin Middle",
        "district": "Marion 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390800764",
    },
    {
        "school": "Marion High",
        "district": "Marion 10",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390800765",
    },
    {
        "school": "McCormick Elementary",
        "district": "Marion 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390800768",
    },
    {
        "school": "North Mullins Primary",
        "district": "Marion 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390800771",
    },
    {
        "school": "Palmetto Middle",
        "district": "Marion 10",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390800772",
    },
    {
        "school": "Mullins High",
        "district": "Marion 10",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390800773",
    },
    {
        "school": "Avon Preschool - 06",
        "district": "Avon School District 04-1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460427001325",
    },
    {
        "school": "Bon Homme PK - 08",
        "district": "Bon Homme School District 04-2",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460740001328",
    },
    {
        "school": "Viborg-Hurley Middle School - 03",
        "district": "Viborg-Hurley School District 60-6",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467452000961",
    },
    {
        "school": "Wakpala Middle School - 04",
        "district": "Smee School District 15-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467560001326",
    },
    {
        "school": "Clinch River Community School",
        "district": "Anderson County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470009002291",
    },
    {
        "school": "Corning Achievement Elementary",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702289",
    },
    {
        "school": "Cornerstone Prep - Lester Campus",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702295",
    },
    {
        "school": "Humes Preparatory Academy Middle  School",
        "district": "Achievement School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702304",
    },
    {
        "school": "Brick Church: A LEAD Public School",
        "district": "Achievement School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702309",
    },
    {
        "school": "Frayser Achievement Elementary",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702314",
    },
    {
        "school": "Westside Middle School",
        "district": "Achievement School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702315",
    },
    {
        "school": "Bradley County Virtual School",
        "district": "Bradley County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470033002312",
    },
    {
        "school": "Tennessee Online Public School",
        "district": "Bristol",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470036002308",
    },
    {
        "school": "STEM School Chattanooga",
        "district": "Hamilton County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159002298",
    },
    {
        "school": "Mount Horeb Elementary School",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470210002313",
    },
    {
        "school": "Coulter Grove Intermediate School",
        "district": "Maryville",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470270002306",
    },
    {
        "school": "Carmel Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303002310",
    },
    {
        "school": "LEAD Southeast",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002286",
    },
    {
        "school": "Cane Ridge Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002288",
    },
    {
        "school": "Knowledge Academy",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002294",
    },
    {
        "school": "Transitions at Bass",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002297",
    },
    {
        "school": "The Academy at Hickory Hollow",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002303",
    },
    {
        "school": "KIPP Nashville Collegiate High School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002305",
    },
    {
        "school": "Dyllis Springs Elementary",
        "district": "Roane County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470359002302",
    },
    {
        "school": "Robertson Co. Virtual School",
        "district": "Robertson County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360002311",
    },
    {
        "school": "Ketron Elementary School",
        "district": "Sullivan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399002301",
    },
    {
        "school": "North Middle School",
        "district": "Sullivan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399002307",
    },
    {
        "school": "CUMBERLAND ACADEMY MIDDLE",
        "district": "CUMBERLAND ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003412826",
    },
    {
        "school": "LIFE SCHOOL MOUNTAIN CREEK",
        "district": "LIFE SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480005512794",
    },
    {
        "school": "GEORGETOWN CHARTER ACADEMY",
        "district": "PRIORITY CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007612905",
    },
    {
        "school": "VISTA ACADEMY OF AUSTIN-MUELLER",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312790",
    },
    {
        "school": "VISTA ACADEMY OF EDINBURG",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312800",
    },
    {
        "school": "VISTA ACADEMY OF BEAUMONT",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312821",
    },
    {
        "school": "VISTA ACADEMY OF CROCKETT",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312827",
    },
    {
        "school": "QUEST MIDDLE OF COPPELL",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312841",
    },
    {
        "school": "TYLER CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312859",
    },
    {
        "school": "ISCHOOL HIGH AT UNIVERSITY PARK",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312903",
    },
    {
        "school": "VISTA ACADEMY OF THE WOODLANDS",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312909",
    },
    {
        "school": "VANGUARD PICASSO",
        "district": "VANGUARD ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480019512828",
    },
    {
        "school": "PREMIER H S OF SOUTH IRVING",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020712816",
    },
    {
        "school": "PREMIER H S OF DAYTON",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020712902",
    },
    {
        "school": "IDEA CARVER COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112829",
    },
    {
        "school": "IDEA CARVER ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112883",
    },
    {
        "school": "GOLDEN RULE GRAND PRAIRIE",
        "district": "GOLDEN RULE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023712866",
    },
    {
        "school": "KIPP AUSTIN BEACON PREP",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412837",
    },
    {
        "school": "KIPP AUSTIN VISTA MIDDLE SCHOOLS",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412849",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - LAREDO",
        "district": "HARMONY SCIENCE ACAD (SAN ANTONIO)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026612090",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - DALLAS",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029212871",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY CORPUS CHRISTI",
        "district": "SCHOOL OF SCIENCE AND TECHNOLOGY DISCOVERY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140012144",
    },
    {
        "school": "THE EAST AUSTIN COLLEGE PREP AT MLK",
        "district": "PROMESA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141412881",
    },
    {
        "school": "UT TYLER UNIVERSITY ACADEMY AT LONGVIEW",
        "district": "UT TYLER UNIVERSITY ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142712830",
    },
    {
        "school": "UT TYLER UNIVERSITY ACADEMY AT PALESTINE",
        "district": "UT TYLER UNIVERSITY ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142712863",
    },
    {
        "school": "LEGACY PREPARATORY CHARTER ACADEMY PLANO",
        "district": "LEGACY PREPARATORY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142812855",
    },
    {
        "school": "LONE STAR H S WEST",
        "district": "TEXAS JUVENILE JUSTICE DEPARTMENT",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143208458",
    },
    {
        "school": "LONE STAR H S NORTH",
        "district": "TEXAS JUVENILE JUSTICE DEPARTMENT",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143208500",
    },
    {
        "school": "LONE STAR H S SOUTH",
        "district": "TEXAS JUVENILE JUSTICE DEPARTMENT",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143208662",
    },
    {
        "school": "LONE STAR H S SOUTHEAST",
        "district": "TEXAS JUVENILE JUSTICE DEPARTMENT",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143208968",
    },
    {
        "school": "LONE STAR H S CENTRAL",
        "district": "TEXAS JUVENILE JUSTICE DEPARTMENT",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143209576",
    },
    {
        "school": "EXCELLENCE IN LEADERSHIP ACADEMY",
        "district": "EXCELLENCE IN LEADERSHIP ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143312793",
    },
    {
        "school": "LOIS LINDSEY EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789012806",
    },
    {
        "school": "ADAMS EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870012797",
    },
    {
        "school": "GRADUATION PREP ACADEMY NAVARRO",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894012824",
    },
    {
        "school": "WEBB PRI CENTER",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894012842",
    },
    {
        "school": "DOBIE PK CENTER",
        "district": "AUSTIN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894012846",
    },
    {
        "school": "GRADUATION PREP ACADEMY TRAVIS",
        "district": "AUSTIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894012864",
    },
    {
        "school": "AZLE HORNET ACADEMY",
        "district": "AZLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480920012892",
    },
    {
        "school": "FAIRVIEW ACCELERATED (DAEP)",
        "district": "BALLINGER ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480930012897",
    },
    {
        "school": "NORTH BELTON MIDDLE",
        "district": "BELTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986012801",
    },
    {
        "school": "CHISHOLM TRAIL EL",
        "district": "BELTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986012875",
    },
    {
        "school": "HIGH POINT EL",
        "district": "BELTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986012898",
    },
    {
        "school": "CLINT ISD EARLY COLLEGE ACADEMY",
        "district": "CLINT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443012799",
    },
    {
        "school": "POPE EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611012882",
    },
    {
        "school": "SEAGOVILLE NORTH EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012792",
    },
    {
        "school": "ANN RICHARDS STEAM ACADEMY",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012796",
    },
    {
        "school": "YOUNG WOMEN'S STEAM ACADEMY AT BALCH SPRINGS MIDDL",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012835",
    },
    {
        "school": "ZAN WESLEY HOLMES JR MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012869",
    },
    {
        "school": "ADELFA BOTELLO CALLEJO EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623012890",
    },
    {
        "school": "BETTYE MYERS MIDDLE",
        "district": "DENTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674012894",
    },
    {
        "school": "H G TEMPLE INT",
        "district": "DIBOLL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481704012889",
    },
    {
        "school": "W A TODD MIDDLE",
        "district": "DONNA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739012877",
    },
    {
        "school": "EVERMAN ACADEMY H S",
        "district": "EVERMAN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481881012891",
    },
    {
        "school": "WHISPERING HILLS ACHIEVEMENT CENTER",
        "district": "FLATONIA ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481928012888",
    },
    {
        "school": "NICHOLS EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012815",
    },
    {
        "school": "VANDEVENTER MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012858",
    },
    {
        "school": "PHILLIPS EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012899",
    },
    {
        "school": "COMSTOCK EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012907",
    },
    {
        "school": "GRAPE CREEK PRI",
        "district": "GRAPE CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482160012805",
    },
    {
        "school": "HEREFORD PREPARATORY ACADEMY",
        "district": "HEREFORD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482301012851",
    },
    {
        "school": "RIDGE CREEK EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391012850",
    },
    {
        "school": "JOURDANTON DAEP",
        "district": "JOURDANTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482496012836",
    },
    {
        "school": "JAMES E RANDOLPH EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517012839",
    },
    {
        "school": "KEIKO DAVIDSON EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517012854",
    },
    {
        "school": "THELMA ROSA SALINAS STEM EARLY COLLEGE H S",
        "district": "LA JOYA ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613012880",
    },
    {
        "school": "JUDGE JAMES C ADOLPHUS EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658012853",
    },
    {
        "school": "PLAYING FOR KEEPS EARLY CHILDHOOD CENTER",
        "district": "LONGVIEW ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811012817",
    },
    {
        "school": "SLOAN CREEK INT",
        "district": "LOVEJOY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482838012908",
    },
    {
        "school": "MILLER EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850012803",
    },
    {
        "school": "ALDERSON EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850012804",
    },
    {
        "school": "ERVIN EL",
        "district": "LUBBOCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482850012852",
    },
    {
        "school": "MIDLOTHIAN HERITAGE H S",
        "district": "MIDLOTHIAN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060012896",
    },
    {
        "school": "MISSION COLLEGIATE H S",
        "district": "MISSION CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104012901",
    },
    {
        "school": "NEW BRAUNFELS H S NINTH GRADE CENTER",
        "district": "NEW BRAUNFELS ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237012886",
    },
    {
        "school": "WOODRIDGE FOREST MIDDLE",
        "district": "NEW CANEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240012876",
    },
    {
        "school": "HILL MIDDLE",
        "district": "NORTH EAST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294012865",
    },
    {
        "school": "MCANDREW EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012811",
    },
    {
        "school": "FOLKS MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012838",
    },
    {
        "school": "FRANKLIN EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012860",
    },
    {
        "school": "WAYNE A COX EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318012906",
    },
    {
        "school": "ROBERT TURNER COLLEGE AND CAREER H S",
        "district": "PEARLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483444012910",
    },
    {
        "school": "CELE MIDDLE",
        "district": "PFLUGERVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483012818",
    },
    {
        "school": "REFUGIO J H",
        "district": "REFUGIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483678012861",
    },
    {
        "school": "SHARYLAND PIONEER H S",
        "district": "SHARYLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993012825",
    },
    {
        "school": "JAMES P BUTLER EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071012820",
    },
    {
        "school": "SSG MANUEL R PUENTES",
        "district": "SOCORRO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071012872",
    },
    {
        "school": "SOUTHWEST LEGACY H S",
        "district": "SOUTHWEST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095012867",
    },
    {
        "school": "JUDITH A RESNIK MIDDLE",
        "district": "SOUTHWEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095012873",
    },
    {
        "school": "SULPHUR SPRINGS EL",
        "district": "SULPHUR SPRINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484182012791",
    },
    {
        "school": "COASTAL ALTERNATIVE PROGRAM (CAP)",
        "district": "TEXAS CITY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484251012819",
    },
    {
        "school": "VAN INT",
        "district": "VAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484392012822",
    },
    {
        "school": "INDIAN SPRING MIDDLE",
        "district": "WACO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484428012823",
    },
    {
        "school": "WARREN JJAEP",
        "district": "WARREN ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484458012904",
    },
    {
        "school": "WESLACO 21ST CENTURY CTE EARLY COLLEGE H S",
        "district": "WESLACO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496012878",
    },
    {
        "school": "ELDER COOP ALTERNATIVE SCHOOL",
        "district": "WEST RUSK COUNTY CONSOLIDATED ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484515012832",
    },
    {
        "school": "Neil Armstrong Academy",
        "district": "Granite District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036001449",
    },
    {
        "school": "Pleasant Creek High School",
        "district": "North Sanpete District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490066001431",
    },
    {
        "school": "Innovations K-8",
        "district": "Salt Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490087001448",
    },
    {
        "school": "N.W. ( NORTHWESTERN) REGIONAL JUVENILE DETENTION HOME",
        "district": "DOE SOP EDUC PROGRAMS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510004202890",
    },
    {
        "school": "BRIDGING COMMUNITIES REG CTE CENTER",
        "district": "BRIDGING COMMUNITIES REG CTE CENTER",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510025502950",
    },
    {
        "school": "ARLINGTON COMMUNITY HIGH",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027002875",
    },
    {
        "school": "LANGSTON HIGH  CONTINUATION PRGM.",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510027002944",
    },
    {
        "school": "BUCKINGHAM CO PRE SCH CTR",
        "district": "BUCKINGHAM CO PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510054002867",
    },
    {
        "school": "BUCKINGHAM CO PRIMARY",
        "district": "BUCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510054002869",
    },
    {
        "school": "BUCKINGHAM CO ELEM",
        "district": "BUCKINGHAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510054002870",
    },
    {
        "school": "COLONIAL HEIGHTS TECH CTR",
        "district": "COLONIAL HEIGHTS CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510096002941",
    },
    {
        "school": "THE NORTHSIDE PRESCHOOL",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111002872",
    },
    {
        "school": "SOUTH COUNTY MIDDLE",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002871",
    },
    {
        "school": "MASON CREST ELEM",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002873",
    },
    {
        "school": "PIMMIT EC RESOURCE CTR",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126002874",
    },
    {
        "school": "CHANTILLY HIGH SCHOOL ACADEMY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510126002939",
    },
    {
        "school": "FAIRFAX HIGH SCHOOL ACADEMY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510126002942",
    },
    {
        "school": "WEST POTOMAC HIGH SCHOOL ACADEMY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510126002945",
    },
    {
        "school": "FALLS CHURCH HIGH SCHOOL ACADEMY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510126002946",
    },
    {
        "school": "MARSHALL HIGH SCHOOL ACADEMY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510126002947",
    },
    {
        "school": "EDISON HIGH SCHOOL ACADEMY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510126002951",
    },
    {
        "school": "CENTRAL ELEM",
        "district": "FLUVANNA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510138002868",
    },
    {
        "school": "WEST CENTRAL PRIMARY SCHOOL",
        "district": "FLUVANNA CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510138002956",
    },
    {
        "school": "GENERATING RECOVERY OF ACADEMIC DIRECTION",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510189002940",
    },
    {
        "school": "EMPOWERMENT ACADEMY",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510189002952",
    },
    {
        "school": "KAECHELE ELEM",
        "district": "HENRICO CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510189002953",
    },
    {
        "school": "MOOREFIELD STATION ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002954",
    },
    {
        "school": "DISCOVERY ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002955",
    },
    {
        "school": "NORFOLK ALTERNATIVE HIGH",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510267002943",
    },
    {
        "school": "NORFOLK ALTERNATIVE MIDDLE",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510267002948",
    },
    {
        "school": "GREEN RUN COLLEGIATE",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002957",
    },
    {
        "school": "Clark County Juvenile Detention School",
        "district": "Educational Service District 112",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000503407",
    },
    {
        "school": "GRAVITY High School",
        "district": "Capital Region ESD 113",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530001103422",
    },
    {
        "school": "Open Doors at LWIT",
        "district": "Lake Washington Institute of Technology",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530031303403",
    },
    {
        "school": "Central Educational Services",
        "district": "Bellevue School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039003434",
    },
    {
        "school": "Brewster Alternative School",
        "district": "Brewster School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530069003381",
    },
    {
        "school": "Spokane Valley Tech",
        "district": "Central Valley School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530111003387",
    },
    {
        "school": "Phil Snowdon Elementary",
        "district": "Cheney School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530123003413",
    },
    {
        "school": "Westwood Middle School",
        "district": "Cheney School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530123003428",
    },
    {
        "school": "Transition Day Students",
        "district": "Clover Park School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141003396",
    },
    {
        "school": "Oakridge Group Home",
        "district": "Clover Park School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141003402",
    },
    {
        "school": "Columbia Alternative School",
        "district": "Columbia (Stevens) School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530156003404",
    },
    {
        "school": "Deer Park Early Learning Center",
        "district": "Deer Park School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530207003423",
    },
    {
        "school": "Mt. Rainier Parent Partnership",
        "district": "Eatonville School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530237003389",
    },
    {
        "school": "Sno Co Jail",
        "district": "Everett School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267003435",
    },
    {
        "school": "Southwest Youth and Family Services",
        "district": "Highline School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354003384",
    },
    {
        "school": "iGrad",
        "district": "Kent School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530396003382",
    },
    {
        "school": "Tesla STEM High School",
        "district": "Lake Washington School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530423003432",
    },
    {
        "school": "Lind-Ritzville Middle School",
        "district": "Lind School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530441003416",
    },
    {
        "school": "Mabton Jr. Sr. High",
        "district": "Mabton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530465003406",
    },
    {
        "school": "Manson Middle School",
        "district": "Manson School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530474003427",
    },
    {
        "school": "Columbia Basin Technical Skills Center",
        "district": "Moses Lake School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530522003392",
    },
    {
        "school": "Touchstone",
        "district": "Olympia School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530618003386",
    },
    {
        "school": "Wahitis Elementary School",
        "district": "Othello School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530648003393",
    },
    {
        "school": "Talley High School",
        "district": "Renton School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530723003400",
    },
    {
        "school": "Lind Ritzville Middle School",
        "district": "Ritzville School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530738003418",
    },
    {
        "school": "Cascadia Elementary",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003390",
    },
    {
        "school": "Seattle Skills Center",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530771003414",
    },
    {
        "school": "Louisa Boren STEM K-8",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003426",
    },
    {
        "school": "Snoqualmie Parent Partnership Program",
        "district": "Snoqualmie Valley School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530804003394",
    },
    {
        "school": "Gateway",
        "district": "Tukwila School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530813003429",
    },
    {
        "school": "Shrine Hospital",
        "district": "Spokane School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530825003417",
    },
    {
        "school": "Spokane County Jail",
        "district": "Spokane School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825003425",
    },
    {
        "school": "NW Allprep",
        "district": "Toppenish School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530897003385",
    },
    {
        "school": "Vancouver Contracted Programs",
        "district": "Vancouver School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927003383",
    },
    {
        "school": "Vancouver iTech Preparatory",
        "district": "Vancouver School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530927003415",
    },
    {
        "school": "Yakima Adult Jail",
        "district": "Yakima School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011003399",
    },
    {
        "school": "Ridgeview Group Home",
        "district": "Yakima School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531011003420",
    },
    {
        "school": "MOUNTAIN RIDGE MIDDLE SCHOOL.",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001497",
    },
    {
        "school": "GAULEY RIVER ELEMENTARY SCHOOL",
        "district": "NICHOLAS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540102001496",
    },
    {
        "school": "FORT GAY PRE K-8",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001495",
    },
    {
        "school": "Escuela Verde",
        "district": "Escuela Verde Agency",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550006902920",
    },
    {
        "school": "Altoona Intermediate",
        "district": "Altoona School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550027002925",
    },
    {
        "school": "Lake Superior Learning Community",
        "district": "Ashland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550051002928",
    },
    {
        "school": "Birchwood Public Montessori",
        "district": "Birchwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550117002937",
    },
    {
        "school": "Kettle Moraine Explore",
        "district": "Kettle Moraine School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550351002914",
    },
    {
        "school": "Denmark Community School",
        "district": "Denmark School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550366002936",
    },
    {
        "school": "School of Options & Applied Research Middle",
        "district": "Northland Pines School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550386002938",
    },
    {
        "school": "Gilmanton Middle",
        "district": "Gilmanton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550537002907",
    },
    {
        "school": "Hartland Fine Arts Leadership Academy",
        "district": "Hartland-Lakeside J3 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550614002913",
    },
    {
        "school": "Kenosha eSchool K-12",
        "district": "Kenosha School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732002910",
    },
    {
        "school": "Edward Bain School - Dual Language",
        "district": "Kenosha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550732002923",
    },
    {
        "school": "Ouisconsing School of Collaboration",
        "district": "Lodi School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550819002915",
    },
    {
        "school": "Innovative & Alternative Middle",
        "district": "Madison Metropolitan School District",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550852002909",
    },
    {
        "school": "Maple Grove School",
        "district": "Merrill Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550921002917",
    },
    {
        "school": "Bridges Virtual Academy",
        "district": "Merrill Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550921002927",
    },
    {
        "school": "Bay View Montessori School",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002911",
    },
    {
        "school": "MacDowell Montessori School K3-12",
        "district": "Milwaukee School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002931",
    },
    {
        "school": "Northwood High/Middle",
        "district": "Northwood School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550972002934",
    },
    {
        "school": "New Glarus Middle",
        "district": "New Glarus School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551050002929",
    },
    {
        "school": "Catalyst Charter Middle",
        "district": "Ripon Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551302002930",
    },
    {
        "school": "River Falls 4 Children",
        "district": "River Falls School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551305002924",
    },
    {
        "school": "LEADS Primary Charter School",
        "district": "Shawano School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551362002908",
    },
    {
        "school": "Stratford Middle",
        "district": "Stratford School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551458002939",
    },
    {
        "school": "Exploration Academy",
        "district": "Verona Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551533002919",
    },
    {
        "school": "White Rock Campus",
        "district": "Waukesha School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578002926",
    },
    {
        "school": "Wauwatosa Virtual Academy",
        "district": "Wauwatosa School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551599002921",
    },
    {
        "school": "Shared Journeys",
        "district": "West Allis-West Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551626002918",
    },
    {
        "school": "Rolf's Early Childhood Center",
        "district": "West Bend School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "551629002912",
    },
    {
        "school": "PODER Academy",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000547",
    },
    {
        "school": "Wyoming Behavioral Institute",
        "district": "Wyoming Behavioral Institute - Administration Office",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WY",
        "nces_id": "568025300548",
    },
    {
        "school": "Jones Academy",
        "district": "Jones Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "BI",
        "nces_id": "590020000201",
    },
    {
        "school": "ESPECIALIZADA DE BELLAS ARTES",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001921",
    },
    {
        "school": "HARLEM HEBREW LANGUAGE ACADEMY CHARTER SCHOOL",
        "district": "HARLEM HEBREW LANGUAGE ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360109706377",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-HELL'S KITCHEN",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-HELL'S KITCHEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360109906375",
    },
    {
        "school": "BROOKLYN URBAN GARDEN CHARTER SCHOOL",
        "district": "BROOKLYN URBAN GARDEN CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360110006402",
    },
    {
        "school": "CANARSIE ASCEND CHARTER SCHOOL",
        "district": "CANARSIE ASCEND CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360110206414",
    },
    {
        "school": "NEW VISIONS CHARTER HIGH SCHOOL FOR THE HUMANITIES III",
        "district": "NEW VISIONS CHARTER HIGH SCHOOL FOR THE HUMANITIES III",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360110306424",
    },
    {
        "school": "SOUTH BRONX CLASSICAL CHARTER SCHOOL II",
        "district": "SOUTH BRONX CLASSICAL CHARTER SCHOOL II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360110506385",
    },
    {
        "school": "LEADERSHIP PREPARATORY CANARSIE CHARTER SCHOOL",
        "district": "LEADERSHIP PREPARATORY CANARSIE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360110606410",
    },
    {
        "school": "OPPENHEIM-EPHRATAH-ST JOHNSVILLE ELEMENTARY SCHOOL",
        "district": "OPPENHEIM-EPHRATAH-ST. JOHNSVILLE CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360110703106",
    },
    {
        "school": "OPPENHEIM-EPHRATAH-ST JOHNSVILLE JUNIOR/SENIOR HIGH SCHOOL",
        "district": "OPPENHEIM-EPHRATAH-ST. JOHNSVILLE CSD",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360110703789",
    },
    {
        "school": "BRILLA COLLEGE PREPARATORY CHARTER SCHOOL",
        "district": "BRILLA COLLEGE PREPARATORY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360110806384",
    },
    {
        "school": "ACHIEVEMENT FIRST ASPIRE CHARTER SCHOOL",
        "district": "ACHIEVEMENT FIRST ASPIRE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360110906421",
    },
    {
        "school": "THOMAS C BRUNSON ELEMENTARY  SCHOOL",
        "district": "WARREN SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50000601570",
    },
    {
        "school": "PARAGOULD PRIMARY SCHOOL",
        "district": "PARAGOULD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001701576",
    },
    {
        "school": "ADDENBROOKE CLASSICAL ACADEMY",
        "district": "Jefferson County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006587",
    },
    {
        "school": "LONGLEAF ELEMENTARY",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001395",
    },
    {
        "school": "BRADLEY ELEMENTARY SCHOOL",
        "district": "EMERSON-TAYLOR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006800108",
    },
    {
        "school": "BRADLEY HIGH SCHOOL",
        "district": "EMERSON-TAYLOR SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006800109",
    },
    {
        "school": "Tempe Academy of International Studies McKemy Campus",
        "district": "Tempe School District (4258)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831003397",
    },
    {
        "school": "Arizona City Elementary School",
        "district": "Toltec School District (4450)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40855003405",
    },
    {
        "school": "North Allegheny HS",
        "district": "North Allegheny SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421701007482",
    },
    {
        "school": "HUEY L. PORTER MIDDLE SCHOOL",
        "district": "CANTON PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280090001394",
    },
    {
        "school": "JIMMIE M. GOODLOE ELEMENTARY SCHOOL",
        "district": "CANTON PUBLIC SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280090001396",
    },
    {
        "school": "Copper Mountain Middle",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001459",
    },
    {
        "school": "JUNIPER RIDGE COMMUNITY SCHOOL",
        "district": "Mesa County Valley School District No. 51",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80435006581",
    },
    {
        "school": "Roosevelt Theodore MS",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007477",
    },
    {
        "school": "ORIGINS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015306422",
    },
    {
        "school": "PROFESSIONAL PATHWAYS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015306423",
    },
    {
        "school": "GOAL ACADEMY",
        "district": "El Paso County Colorado School District 49",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80387006393",
    },
    {
        "school": "MOUNTAIN SAGE COMMUNITY SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399006573",
    },
    {
        "school": "Nebo Advanced Learning Center",
        "district": "Nebo District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "UT",
        "nces_id": "490063001458",
    },
    {
        "school": "MIDDLE VILLAGE PREPARATORY CHARTER SCHOOL",
        "district": "MIDDLE VILLAGE PREPARATORY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108206433",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-UNION SQUARE",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-UNION SQUARE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108306374",
    },
    {
        "school": "UTICA ACADEMY OF SCIENCE CHARTER SCHOOL",
        "district": "UTICA ACADEMY OF SCIENCE CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108406447",
    },
    {
        "school": "GREAT OAKS CHARTER SCHOOL",
        "district": "GREAT OAKS CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108506376",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-FORT GREENE",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-FORT GREENE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108606403",
    },
    {
        "school": "BARRINGER ROAD ELEMENTARY SCHOOL",
        "district": "CENTRAL VALLEY CSD AT ILION-MOHAWK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108701282",
    },
    {
        "school": "CENTRAL VALLEY ACADEMY",
        "district": "CENTRAL VALLEY CSD AT ILION-MOHAWK",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108701283",
    },
    {
        "school": "HARRY M FISHER ELEMENTARY SCHOOL",
        "district": "CENTRAL VALLEY CSD AT ILION-MOHAWK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108701786",
    },
    {
        "school": "GREGORY B JARVIS MIDDLE SCHOOL",
        "district": "CENTRAL VALLEY CSD AT ILION-MOHAWK",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108701787",
    },
    {
        "school": "NEW VISIONS CHTR HS-ADV MA/SCI III",
        "district": "NEW VISIONS CHTR HS-ADV MA/SCI III",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108806425",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-PROSPECT HEIGHTS",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-PROSPECT HEIGHTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360108906412",
    },
    {
        "school": "EAST HARLEM SCHOLARS ACADEMY CHARTER SCHOOL II",
        "district": "EAST HARLEM SCHOLARS ACADEMY CHARTER SCHOOL II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360109006378",
    },
    {
        "school": "ICAHN CHARTER SCHOOL 7",
        "district": "ICAHN CHARTER SCHOOL 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360109106389",
    },
    {
        "school": "NEW AMERICAN ACADEMY CHARTER SCHOOL (THE)",
        "district": "NEW AMERICAN ACADEMY CHARTER SCHOOL (THE)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360109206415",
    },
    {
        "school": "MATH ENGINEERING AND SCIENCE ACADEMY CHARTER HIGH SCHOOL",
        "district": "MATH ENGINEERING AND SCIENCE ACADEMY CHARTER HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360109306429",
    },
    {
        "school": "UNITY PREPARATORY CHARTER SCHOOL OF BROOKLYN",
        "district": "UNITY PREPARATORY CHARTER SCHOOL OF BROOKLYN",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360109406404",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-CROWN HEIGHTS",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-CROWN HEIGHTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360109506413",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-BRONX 3",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-BRONX 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360109606390",
    },
    {
        "school": "SouthWinds Academy",
        "district": "Otis-Bison",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200402002066",
    },
    {
        "school": "CLOUGH PREK CENTER",
        "district": "ROME CITY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362490006446",
    },
    {
        "school": "IRVING ELEMENTARY",
        "district": "JOPLIN SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291635003240",
    },
    {
        "school": "ODYSSEY PREPARATORY CHARTER ACADEMY",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015008230",
    },
    {
        "school": "VIERA CHARTER SCHOOL",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015008240",
    },
    {
        "school": "Garden City Alternate Education Center",
        "district": "Garden City",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200639002067",
    },
    {
        "school": "Grand Star Elementary",
        "district": "Gardner Edgerton",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200642002070",
    },
    {
        "school": "Hickory Tavern Elementary/Middle",
        "district": "Laurens 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450261001622",
    },
    {
        "school": "Tilden William T MS",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007496",
    },
    {
        "school": "Penn Treaty Sch",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007502",
    },
    {
        "school": "The SD of Philadelphia Virtual Academy",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007506",
    },
    {
        "school": "Vare-Washington El Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007511",
    },
    {
        "school": "Rhodes E Washington Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007517",
    },
    {
        "school": "Philipsburg-Osceola Area MS",
        "district": "Philipsburg-Osceola Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421902007475",
    },
    {
        "school": "TIMBERLINE PK-8",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006594",
    },
    {
        "school": "SPARK! DISCOVERY PRESCHOOL",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006598",
    },
    {
        "school": "Crimson View School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001451",
    },
    {
        "school": "Swiftwater Interm Sch",
        "district": "Pocono Mountain SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421950007503",
    },
    {
        "school": "Fayette Elementary",
        "district": "North Fayette Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190000602191",
    },
    {
        "school": "Alburnett Middle School",
        "district": "Alburnett Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190330002193",
    },
    {
        "school": "Windsor Manor El Sch",
        "district": "Red Lion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422010007500",
    },
    {
        "school": "Southview Middle School",
        "district": "Ankeny Comm School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369002186",
    },
    {
        "school": "Ankeny Centennial High School",
        "district": "Ankeny Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369002187",
    },
    {
        "school": "Rochester MS",
        "district": "Rochester Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422046007516",
    },
    {
        "school": "South Fayette Intermediate Sch",
        "district": "South Fayette Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422058007479",
    },
    {
        "school": "Somerset Area Jr-Sr HS",
        "district": "Somerset Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422184007509",
    },
    {
        "school": "Salford Hills El Sch",
        "district": "Souderton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422187007497",
    },
    {
        "school": "PROSPECT ELEMENTARY SCHOOL",
        "district": "HEMPSTEAD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361413006370",
    },
    {
        "school": "Academy of Aerospace and Engineering Elementary",
        "district": "Capitol Region Education Council",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90070001629",
    },
    {
        "school": "Easton Valley High School",
        "district": "Easton Valley Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191013002201",
    },
    {
        "school": "Fort Dodge Middle School",
        "district": "Fort Dodge Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191182002197",
    },
    {
        "school": "DPS Early Childhood Center",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102001634",
    },
    {
        "school": "JACK ABRAMS STEM MAGNET SCHOOL",
        "district": "HUNTINGTON UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361509006451",
    },
    {
        "school": "Gilbert Intermediate School",
        "district": "Gilbert Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191251002192",
    },
    {
        "school": "ALLEN VILLAGE HIGH SCHOOL",
        "district": "ALLEN VILLAGE",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002503233",
    },
    {
        "school": "FRONTIER STEM HIGH SCHOOL",
        "district": "FRONTIER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059003232",
    },
    {
        "school": "GATEWAY SCIENCE ACAD-SOUTH ELE",
        "district": "GATEWAY SCIENCE ACAD/ST LOUIS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059203241",
    },
    {
        "school": "EAGLE TOWER GROVE SOUTH",
        "district": "EAGLE COLLEGE PREP ENDEAVOR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060503224",
    },
    {
        "school": "Gray Court-Owings Elementary/Middle",
        "district": "Laurens 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450261001623",
    },
    {
        "school": "Humboldt Elementary School",
        "district": "Humboldt",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200759002071",
    },
    {
        "school": "River Bluff High",
        "district": "Lexington 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001626",
    },
    {
        "school": "TRAILSIDE MIDDLE",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002965",
    },
    {
        "school": "Plum Valley Elementary",
        "district": "Antelope Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60276004817",
    },
    {
        "school": "Spring Hill High",
        "district": "Lexington 05",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282001621",
    },
    {
        "school": "SOMERSET ACADEMY KEY MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008232",
    },
    {
        "school": "SOUTH BROWARD MONTESSORI CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008237",
    },
    {
        "school": "ACADEMIC SOLUTIONS HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018008260",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOLS AT PINES",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008297",
    },
    {
        "school": "GREENTREE PREPARATORY CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008312",
    },
    {
        "school": "BROWARD YOUTH TREATMENT CENTER",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018008326",
    },
    {
        "school": "PANACEA PREP CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008329",
    },
    {
        "school": "CROSSROADS HOPE ACADEMY",
        "district": "CHARLOTTE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120024008327",
    },
    {
        "school": "Las Flores Home Education Independent Study Academy",
        "district": "Bellflower Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60444013706",
    },
    {
        "school": "NORTHAMPTON MIDDLE",
        "district": "NORTHAMPTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510271002963",
    },
    {
        "school": "GULF COAST CHARTER ACADEMY SOUTH",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033008257",
    },
    {
        "school": "MASON CLASSICAL ACADEMY",
        "district": "COLLIER",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033008322",
    },
    {
        "school": "LAFAYETTE PREPARATORY ACADEMY",
        "district": "LAFAYETTE PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060603223",
    },
    {
        "school": "MOCAP ELEM.SCHOOL",
        "district": "MO VIRTUAL INSTRUCTION PROGRAM",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290060703225",
    },
    {
        "school": "MOCAP HIGH SCHOOL",
        "district": "MO VIRTUAL INSTRUCTION PROGRAM",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290060703228",
    },
    {
        "school": "Iowa Virtual Academy",
        "district": "Clayton Ridge Comm School District",
        "level": "Other",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191335002206",
    },
    {
        "school": "HARRISBURG JTC SCHOOL",
        "district": "ARKANSAS YOUTH SERVICES SCHOOL SYSTEM",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039001575",
    },
    {
        "school": "MANSFIELD JTC SCHOOL",
        "district": "ARKANSAS YOUTH SERVICES SCHOOL SYSTEM",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039001577",
    },
    {
        "school": "LEWISVILLE JTC SCHOOL",
        "district": "ARKANSAS YOUTH SERVICES SCHOOL SYSTEM",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039001583",
    },
    {
        "school": "DERMOTT JTC SCHOOL",
        "district": "ARKANSAS YOUTH SERVICES SCHOOL SYSTEM",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039001589",
    },
    {
        "school": "ESTEM MIDDLE SCHOOL",
        "district": "ESTEM HIGH CHARTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039801467",
    },
    {
        "school": "ESTEM ELEMENTARY SCHOOL",
        "district": "ESTEM HIGH CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039801468",
    },
    {
        "school": "COSSATOT RIVER HIGH SCHOOL",
        "district": "COSSATOT RIVER SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040501591",
    },
    {
        "school": "PREMIER HIGH SCHOOL OF LITTLE ROCK",
        "district": "RESPONSIVE ED SOLUTIONS PREMIER HIGH SCHOOL OF LITTLE ROCK",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040801579",
    },
    {
        "school": "NORTHWEST ARKANSAS CLASSICAL ACADEMY",
        "district": "RESPONSIVE ED SOLUTIONS NORTHWEST ARK CLASSICAL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040901574",
    },
    {
        "school": "Pittsburgh Online Academy",
        "district": "Pittsburgh SD",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421917007505",
    },
    {
        "school": "NATCHEZ FRESHMAN ACADEMY",
        "district": "NATCHEZ-ADAMS SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280303001397",
    },
    {
        "school": "MINER ACADEMY",
        "district": "BAUXITE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50279001590",
    },
    {
        "school": "J WILLIAM FULBRIGHT JUNIOR HIGH SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001571",
    },
    {
        "school": "BLYTHEVILLE HIGH SCHOOL-A NEW TECH SCHOOL",
        "district": "BLYTHEVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50332001578",
    },
    {
        "school": "COLORADO STEM ACADEMY",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723006567",
    },
    {
        "school": "Shamokin Area Intermediate Sch",
        "district": "Shamokin Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422124007514",
    },
    {
        "school": "ZICCOLELLA MIDDLE SCHOOL",
        "district": "GREENBURGH-GRAHAM UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361240006299",
    },
    {
        "school": "Colo-Nesco Elementary School",
        "district": "Colo-NESCO Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190792002204",
    },
    {
        "school": "Brass City Charter School",
        "district": "Brass City Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90021501644",
    },
    {
        "school": "Bridgeport Military Academy",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045001631",
    },
    {
        "school": "Information Technology & Software Engineering Magnet High Sc",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045001633",
    },
    {
        "school": "Biotechnology Research & Zoological Studies Magnet High Scho",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045001636",
    },
    {
        "school": "Aerospace/Hydrospace Engineering and Physical Sciences Magne",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045001639",
    },
    {
        "school": "YVONNE B. MILLER HIGH SCHOOL",
        "district": "DEPARTMENT OF JUVENILE JUSTICE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510007002967",
    },
    {
        "school": "Sheffield Area El Sch",
        "district": "Warren County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422482007476",
    },
    {
        "school": "Montessori Magnet at Batchelder School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001641",
    },
    {
        "school": "Hartford PreKindergarten Magnet School",
        "district": "HARTFORD SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001643",
    },
    {
        "school": "Interstate 35 Secondary School",
        "district": "Interstate 35 Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191467002196",
    },
    {
        "school": "Torrence Elementary",
        "district": "Keokuk Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191563002198",
    },
    {
        "school": "BEDFORD COUNTY ALTERNATIVE EDUCATION CENTER",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510036002961",
    },
    {
        "school": "New Cumberland MS",
        "district": "West Shore SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422583007490",
    },
    {
        "school": "VALLEY VIEW JUNIOR HIGH SCHOOL",
        "district": "VALLEY VIEW SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51338001580",
    },
    {
        "school": "VALLEY VIEW INTERMEDIATE SCHOOL",
        "district": "VALLEY VIEW SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51338001587",
    },
    {
        "school": "Hannah Penn",
        "district": "York City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422682007492",
    },
    {
        "school": "MURIEL W. BATTLE HIGH SCHOOL",
        "district": "COLUMBIA 93",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100003239",
    },
    {
        "school": "Blackstone Valley Prep High",
        "district": "Blackstone Valley Prep  A RI Mayoral Academy",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440001500488",
    },
    {
        "school": "Achievement First Providence",
        "district": "Achievement First Rhode Island",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440002100486",
    },
    {
        "school": "Sheila Skip Nowell (Capital)",
        "district": "Sheila Skip Nowell Leadership Academy",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440002400483",
    },
    {
        "school": "Sheila Skip Nowell (Central)",
        "district": "Sheila Skip Nowell Leadership Academy",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440002400484",
    },
    {
        "school": "Village Green Virtual",
        "district": "Village Green Virtual",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440002500487",
    },
    {
        "school": "PRESIDENTIAL PARK ELEMENTARY SCHOOL",
        "district": "MIDDLETOWN CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361932006448",
    },
    {
        "school": "Chatfield-LoPresti School",
        "district": "SEYMOUR SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90399001642",
    },
    {
        "school": "Claiborne Pell Elementary",
        "district": "Newport",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440072000485",
    },
    {
        "school": "Waterbury Career Academy",
        "district": "WATERBURY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90483001638",
    },
    {
        "school": "Southwest Valley Middle School",
        "district": "Villisca Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192928002207",
    },
    {
        "school": "E. A. GIBSON ELEM",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111002960",
    },
    {
        "school": "Woodland Hills Elementary School",
        "district": "Waukee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051002190",
    },
    {
        "school": "West Monona Elementary",
        "district": "West Monona Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193111002195",
    },
    {
        "school": "Friendship PCS - Blow Pierce MS",
        "district": "Friendship PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800478",
    },
    {
        "school": "Friendship PCS - Blow Pierce ES",
        "district": "Friendship PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800479",
    },
    {
        "school": "McKinley MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000470",
    },
    {
        "school": "Capital City PCS - HS",
        "district": "Capital City PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003500475",
    },
    {
        "school": "Paul PCS - International HS",
        "district": "Paul PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003900477",
    },
    {
        "school": "E.L. Haynes PCS - ES",
        "district": "E.L. Haynes PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004300472",
    },
    {
        "school": "DC Prep PCS - Benning MS",
        "district": "DC Prep PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004800474",
    },
    {
        "school": "Achievement Preparatory Academy PCS - Wahler Place ES",
        "district": "Achievement Preparatory Academy PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110007200473",
    },
    {
        "school": "Lee Montessori PCS - Brookland",
        "district": "Lee Montessori PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110009300476",
    },
    {
        "school": "ALACHUA VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003008285",
    },
    {
        "school": "Mountain House High",
        "district": "Lammersville Joint Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141013692",
    },
    {
        "school": "Barbara Webster Elementary",
        "district": "Santa Paula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142106105",
    },
    {
        "school": "Blanchard Elementary",
        "district": "Santa Paula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142106106",
    },
    {
        "school": "Glen City Elementary",
        "district": "Santa Paula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142106107",
    },
    {
        "school": "Grace Thille Elementary",
        "district": "Santa Paula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142106108",
    },
    {
        "school": "Isbell Middle",
        "district": "Santa Paula Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142106109",
    },
    {
        "school": "McKevett Elementary",
        "district": "Santa Paula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142106110",
    },
    {
        "school": "Thelma Bedell Elementary",
        "district": "Santa Paula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142106112",
    },
    {
        "school": "Renaissance High",
        "district": "Santa Paula Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60142106113",
    },
    {
        "school": "Santa Paula High",
        "district": "Santa Paula Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142106114",
    },
    {
        "school": "Lincoln Elementary",
        "district": "Exeter Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142301501",
    },
    {
        "school": "Rocky Hill Elementary",
        "district": "Exeter Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142301502",
    },
    {
        "school": "Exeter Union High",
        "district": "Exeter Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142301504",
    },
    {
        "school": "Kaweah High",
        "district": "Exeter Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60142301505",
    },
    {
        "school": "Exeter Independent Study (Alternative)",
        "district": "Exeter Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60142307466",
    },
    {
        "school": "Exeter Community Day",
        "district": "Exeter Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60142308662",
    },
    {
        "school": "Wilson Middle",
        "district": "Exeter Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142310336",
    },
    {
        "school": "BAY VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "BAY",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009008287",
    },
    {
        "school": "LADUE FIFTH GRADE CENTER",
        "district": "LADUE",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291782003236",
    },
    {
        "school": "DISCOVERY MIDDLE SCHOOL",
        "district": "LIBERTY 53",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854003226",
    },
    {
        "school": "HERITAGE MIDDLE SCHOOL",
        "district": "LIBERTY 53",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854003238",
    },
    {
        "school": "Williamsport Area MS",
        "district": "Williamsport Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422646007508",
    },
    {
        "school": "ROGERS NEW TECHNOLOGY HIGH SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197001586",
    },
    {
        "school": "JANIE DARR ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197001588",
    },
    {
        "school": "SILOAM SPRINGS INTERMEDIATE SCHOOL",
        "district": "SILOAM SPRINGS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51245001584",
    },
    {
        "school": "CEDAR RIDGE INTERMEDIATE",
        "district": "BRANSON R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290576003235",
    },
    {
        "school": "BUCHANAN ELEMENTARY",
        "district": "BRANSON R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290576003237",
    },
    {
        "school": "Riverside Magnet School at Goodwin College",
        "district": "LEARN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90345001627",
    },
    {
        "school": "Shepaug Valley School",
        "district": "REGIONAL SCHOOL DISTRICT 12",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353001632",
    },
    {
        "school": "Rocklin Independent Charter Academy",
        "district": "Rocklin Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001313722",
    },
    {
        "school": "Liberty Elementary School",
        "district": "Ottumwa Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192211002185",
    },
    {
        "school": "Douma Elementary School",
        "district": "Ottumwa Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192211002200",
    },
    {
        "school": "Charles H. Barrows STEM Academy",
        "district": "WINDHAM SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90519001640",
    },
    {
        "school": "First State Military Academy",
        "district": "First State Military Academy",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100005700368",
    },
    {
        "school": "New Castle Elementary School",
        "district": "Colonial School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100023000366",
    },
    {
        "school": "Laurel Elementary School",
        "district": "Laurel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100081000364",
    },
    {
        "school": "Laurel Middle School",
        "district": "Laurel School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100081000365",
    },
    {
        "school": "Friendship PCS - Chamberlain ES",
        "district": "Friendship PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800480",
    },
    {
        "school": "Friendship PCS - Woodridge MS",
        "district": "Friendship PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800481",
    },
    {
        "school": "Friendship PCS - Woodridge ES",
        "district": "Friendship PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800482",
    },
    {
        "school": "Friendship PCS - Chamberlain MS",
        "district": "Friendship PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800483",
    },
    {
        "school": "STEAM Academy",
        "district": "Fayette County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210186002341",
    },
    {
        "school": "Locust Trace AgriScience Center",
        "district": "Fayette County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210186002362",
    },
    {
        "school": "UK Early Childhood Lab",
        "district": "Fayette County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002385",
    },
    {
        "school": "Mountain View Elementary - 08",
        "district": "Spearfish School District 40-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466693001342",
    },
    {
        "school": "LIBERTY HIGH SCHOOL",
        "district": "WENTZVILLE R-IV",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165003227",
    },
    {
        "school": "Frankfort Early Learning Academy",
        "district": "Frankfort Independent",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210198002334",
    },
    {
        "school": "Washington Youth Academy",
        "district": "Washington Military Department",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530032403412",
    },
    {
        "school": "Grayson County Area Vocational Ed Center",
        "district": "Grayson County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210230002381",
    },
    {
        "school": "Early College and Career Center",
        "district": "Hardin County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210249002373",
    },
    {
        "school": "Whitney Achievement Elementary School",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702321",
    },
    {
        "school": "Aspire Hanley Elementary",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702324",
    },
    {
        "school": "Pathways in Education - TN",
        "district": "Achievement School District",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702325",
    },
    {
        "school": "KIPP Memphis Academy Elementary",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702349",
    },
    {
        "school": "KIPP Memphis Preparatory Middle",
        "district": "Achievement School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702351",
    },
    {
        "school": "Aspire Hanley Middle School",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702356",
    },
    {
        "school": "Georgian Hills Achievement Elementary School",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702359",
    },
    {
        "school": "Highland Oaks Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014800164",
    },
    {
        "school": "Cordova Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014800176",
    },
    {
        "school": "Oak Forest Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014800179",
    },
    {
        "school": "BISCAYNE HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048008264",
    },
    {
        "school": "DUVAL CHARTER SCHOOL AT WESTSIDE",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008266",
    },
    {
        "school": "Jing Mei Elementary School",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039003455",
    },
    {
        "school": "Grad Alliance Program",
        "district": "Bellevue School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530039003462",
    },
    {
        "school": "Shelby Oaks Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014800499",
    },
    {
        "school": "Macon-Hall Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014800857",
    },
    {
        "school": "Ida B. Wells Academy ES/MS",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014800861",
    },
    {
        "school": "A. B. Hill Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801011",
    },
    {
        "school": "Alton Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801014",
    },
    {
        "school": "Avon School",
        "district": "Shelby County",
        "level": "High",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470014801015",
    },
    {
        "school": "B. T. Washington High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801016",
    },
    {
        "school": "Bellevue Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801018",
    },
    {
        "school": "Berclair Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801019",
    },
    {
        "school": "Bethel Grove Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801020",
    },
    {
        "school": "Brownsville Road Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801022",
    },
    {
        "school": "Bruce Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801023",
    },
    {
        "school": "Campus Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801025",
    },
    {
        "school": "Central High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801028",
    },
    {
        "school": "Charjean Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801029",
    },
    {
        "school": "Cherokee Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801030",
    },
    {
        "school": "Chickasaw Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801032",
    },
    {
        "school": "Colonial Middle",
        "district": "Shelby County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801036",
    },
    {
        "school": "Craigmont High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801040",
    },
    {
        "school": "Cromwell Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801042",
    },
    {
        "school": "Cummings Elementary/Middle",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801043",
    },
    {
        "school": "Delano Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801045",
    },
    {
        "school": "Double Tree Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801047",
    },
    {
        "school": "Douglass Elementary/Middle",
        "district": "Shelby County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801048",
    },
    {
        "school": "East High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801053",
    },
    {
        "school": "Egypt Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801055",
    },
    {
        "school": "Evans Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801056",
    },
    {
        "school": "Ford Road Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801061",
    },
    {
        "school": "Gardenview Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801065",
    },
    {
        "school": "Georgian Hills Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801069",
    },
    {
        "school": "Goodlett Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801070",
    },
    {
        "school": "Grahamwood Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801074",
    },
    {
        "school": "Hamilton High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801080",
    },
    {
        "school": "Havenview Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801083",
    },
    {
        "school": "Hawkins Mill Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801084",
    },
    {
        "school": "Idlewild Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801088",
    },
    {
        "school": "Jackson Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801089",
    },
    {
        "school": "Kingsbury Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801092",
    },
    {
        "school": "Kingsbury High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801093",
    },
    {
        "school": "Kingsbury Career  Technology Center",
        "district": "Shelby County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "TN",
        "nces_id": "470014801095",
    },
    {
        "school": "Knight Road Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801097",
    },
    {
        "school": "Larose Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801100",
    },
    {
        "school": "Levi Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801105",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801112",
    },
    {
        "school": "Manassas High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801113",
    },
    {
        "school": "Melrose High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801115",
    },
    {
        "school": "Mitchell High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801122",
    },
    {
        "school": "Newberry Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801123",
    },
    {
        "school": "Oakhaven Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801126",
    },
    {
        "school": "Oakhaven High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801127",
    },
    {
        "school": "Oakshire Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801128",
    },
    {
        "school": "Overton High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801130",
    },
    {
        "school": "Peabody Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801132",
    },
    {
        "school": "Raleigh-Bartlett Meadows Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801137",
    },
    {
        "school": "Raleigh-Egypt High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801138",
    },
    {
        "school": "Richland Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801139",
    },
    {
        "school": "Balmoral/Ridgeway Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801141",
    },
    {
        "school": "Ridgeway High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801142",
    },
    {
        "school": "Riverview Elementary/Middle",
        "district": "Shelby County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801144",
    },
    {
        "school": "Rozelle Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801145",
    },
    {
        "school": "Scenic Hills Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801146",
    },
    {
        "school": "Shady Grove Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801149",
    },
    {
        "school": "Sharpe Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801151",
    },
    {
        "school": "Sheffield Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801152",
    },
    {
        "school": "Sheffield High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801153",
    },
    {
        "school": "Sheffield Career  Technology Center",
        "district": "Shelby County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "TN",
        "nces_id": "470014801154",
    },
    {
        "school": "Sherwood Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801155",
    },
    {
        "school": "Sherwood Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801156",
    },
    {
        "school": "Shrine School",
        "district": "Shelby County",
        "level": "Other",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470014801157",
    },
    {
        "school": "Snowden Elementary/Middle",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801158",
    },
    {
        "school": "South Park Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801159",
    },
    {
        "school": "Springdale Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801162",
    },
    {
        "school": "Treadwell Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801164",
    },
    {
        "school": "Trezevant High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801166",
    },
    {
        "school": "Vollentine Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801169",
    },
    {
        "school": "Wells Station Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801171",
    },
    {
        "school": "Westside Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801172",
    },
    {
        "school": "Westwood High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801176",
    },
    {
        "school": "White Station Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801177",
    },
    {
        "school": "White Station High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801178",
    },
    {
        "school": "Whitehaven Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801180",
    },
    {
        "school": "Whitehaven High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801181",
    },
    {
        "school": "Barnabus Home Middle School",
        "district": "Jackson County",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210294002375",
    },
    {
        "school": "Saddle Peak Elementary",
        "district": "Belgrade Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300329001111",
    },
    {
        "school": "Meadowlark Elementary",
        "district": "Bozeman Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300456001108",
    },
    {
        "school": "Highland Middle",
        "district": "Harnett County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201003309",
    },
    {
        "school": "FOCUS ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120087008244",
    },
    {
        "school": "THOMPSON ELEMENTARY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008286",
    },
    {
        "school": "LAKE ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120087008319",
    },
    {
        "school": "LAMB ELEMENTARY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008324",
    },
    {
        "school": "HOLMES VIRTUAL-DISTRICT INSTRUCTION PROGRAM",
        "district": "HOLMES",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120090008313",
    },
    {
        "school": "University Elementary at La Fiesta",
        "district": "Cotati-Rohnert Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60994013725",
    },
    {
        "school": "Culver City Unified School District iAcademy",
        "district": "Culver City Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61026013708",
    },
    {
        "school": "Willow Oaks Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801184",
    },
    {
        "school": "Winchester Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801185",
    },
    {
        "school": "Wooddale High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801186",
    },
    {
        "school": "Fox Meadows Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801565",
    },
    {
        "school": "Barret's Chapel Elementary/Middle",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801568",
    },
    {
        "school": "Bolton High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801571",
    },
    {
        "school": "E.E. Jeter Elementary/Middle",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801577",
    },
    {
        "school": "Germantown Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801581",
    },
    {
        "school": "Germantown High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801582",
    },
    {
        "school": "Germantown Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801583",
    },
    {
        "school": "Lucy Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801584",
    },
    {
        "school": "Mt. Pisgah Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801590",
    },
    {
        "school": "Ross Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801592",
    },
    {
        "school": "Woodstock Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801595",
    },
    {
        "school": "Germanshire Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801597",
    },
    {
        "school": "Getwell Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801605",
    },
    {
        "school": "Hickory Ridge Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801606",
    },
    {
        "school": "Hickory Ridge Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801615",
    },
    {
        "school": "LAFAYETTE VIRTUAL INSTRUCTION K-5 FULLTIME",
        "district": "LAFAYETTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120102008316",
    },
    {
        "school": "LAKE VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "LAKE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105008311",
    },
    {
        "school": "Holmes Road Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801616",
    },
    {
        "school": "Ridgeway Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801625",
    },
    {
        "school": "Robert R. Church Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801626",
    },
    {
        "school": "Winridge Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801627",
    },
    {
        "school": "Woodburn Elementary",
        "district": "Camas School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081003460",
    },
    {
        "school": "CVSD Open Doors Programs",
        "district": "Central Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530111003437",
    },
    {
        "school": "Lewis County Jail",
        "district": "Chehalis School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530117003464",
    },
    {
        "school": "Southwest Career  Technology Center",
        "district": "Shelby County",
        "level": "Secondary",
        "type": "Career and Technical School",
        "state": "TN",
        "nces_id": "470014801853",
    },
    {
        "school": "Trezevant Career and Technology Center",
        "district": "Shelby County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "TN",
        "nces_id": "470014801854",
    },
    {
        "school": "Crump Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801857",
    },
    {
        "school": "Kirby High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801859",
    },
    {
        "school": "Northaven Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801860",
    },
    {
        "school": "Dexter Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801907",
    },
    {
        "school": "Dexter Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801910",
    },
    {
        "school": "Cordova Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801911",
    },
    {
        "school": "Craigmont Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801927",
    },
    {
        "school": "KIPP Memphis Collegiate Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801928",
    },
    {
        "school": "A. Maceo Walker Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801939",
    },
    {
        "school": "White Station Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801960",
    },
    {
        "school": "Dunbar Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801972",
    },
    {
        "school": "Middle College High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801974",
    },
    {
        "school": "J. P. Freeman Elementary/Middle",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014801983",
    },
    {
        "school": "Chimneyrock Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802017",
    },
    {
        "school": "Southwind Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802019",
    },
    {
        "school": "Keystone Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802025",
    },
    {
        "school": "Sea Isle Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802026",
    },
    {
        "school": "American Way Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802040",
    },
    {
        "school": "Downtown Elementary",
        "district": "Shelby County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802041",
    },
    {
        "school": "Lucie E. Campbell Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802043",
    },
    {
        "school": "Circles Of Success Learning Academy",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802044",
    },
    {
        "school": "Memphis Academy Of Science  Engineering Middle/High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802045",
    },
    {
        "school": "Memphis Academy Of Health Sciences",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802046",
    },
    {
        "school": "Kate Bond Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802079",
    },
    {
        "school": "Cordova High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802080",
    },
    {
        "school": "Hollis F. Price Middle College",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802081",
    },
    {
        "school": "City University School Of Liberal Arts",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802083",
    },
    {
        "school": "Memphis Business Academy Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802084",
    },
    {
        "school": "Promise Academy",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802085",
    },
    {
        "school": "Southern Avenue Charter School Of Academic Excellence  Creat",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802086",
    },
    {
        "school": "Star Academy",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802087",
    },
    {
        "school": "Soulsville Charter School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802088",
    },
    {
        "school": "William Herbert Brewster Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802112",
    },
    {
        "school": "Kingsbury Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802126",
    },
    {
        "school": "Southwind High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802137",
    },
    {
        "school": "Oakhaven Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802148",
    },
    {
        "school": "Douglass High",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802150",
    },
    {
        "school": "Power Center Academy Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802171",
    },
    {
        "school": "Primary Prepatory",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802172",
    },
    {
        "school": "Early Childhood Programs",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802177",
    },
    {
        "school": "Memphis Business Academy High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802178",
    },
    {
        "school": "Memphis Academy of Health Sciences High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802179",
    },
    {
        "school": "Campus Kids Corner",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802184",
    },
    {
        "school": "Northwest Prep Academy",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802188",
    },
    {
        "school": "Highland Oaks Middle",
        "district": "Shelby County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802199",
    },
    {
        "school": "Lowrance Elementary/Middle",
        "district": "Shelby County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802200",
    },
    {
        "school": "Freedom Preparatory Academy",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802208",
    },
    {
        "school": "Ridgeway Early Learning Center",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802210",
    },
    {
        "school": "Treadwell Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802217",
    },
    {
        "school": "Carver College and Career Academy",
        "district": "Shelby County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802221",
    },
    {
        "school": "Riverwood Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802236",
    },
    {
        "school": "Memphis School of Excellence",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802245",
    },
    {
        "school": "Veritas College Preparatory",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802248",
    },
    {
        "school": "Memphis College Preparatory",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802250",
    },
    {
        "school": "Power Center Academy High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802270",
    },
    {
        "school": "Memphis Virtual School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802271",
    },
    {
        "school": "Kate Bond Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802272",
    },
    {
        "school": "KIPP Memphis Collegiate High School",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802273",
    },
    {
        "school": "Memphis Business Academy Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802274",
    },
    {
        "school": "Grandview Heights Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802287",
    },
    {
        "school": "Aurora Collegiate Academy",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802290",
    },
    {
        "school": "KIPP Memphis Collegiate Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802296",
    },
    {
        "school": "KIPP Memphis Middle Academy",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802299",
    },
    {
        "school": "Memphis Grizzlies Preparatory Charter School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802300",
    },
    {
        "school": "Nat Burning Orange Mound Day Nursery Learning Inc.",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802316",
    },
    {
        "school": "Arrow Academy of Excellence",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802317",
    },
    {
        "school": "Belle Forest Community School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802326",
    },
    {
        "school": "Bluebird Learning Center",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802333",
    },
    {
        "school": "DuBois Elementary School of Entrepreneurship",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802334",
    },
    {
        "school": "Memphis Learning Academy",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802335",
    },
    {
        "school": "Kids School Early Childhood Development Center",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802340",
    },
    {
        "school": "Ernestine Rivers Child Care Center",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802342",
    },
    {
        "school": "Jessie Mahan Day Care Center",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802348",
    },
    {
        "school": "Hooks Dimmick Child Care Center",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802350",
    },
    {
        "school": "City University School Girls Preparatory",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802352",
    },
    {
        "school": "Early Childhood Education",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802354",
    },
    {
        "school": "Horn Lake Road Learning Center",
        "district": "Shelby County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802358",
    },
    {
        "school": "George Unseld Early Childhood Center",
        "district": "Jefferson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299002376",
    },
    {
        "school": "Red Oak Elementary School",
        "district": "Jessamine County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210303002388",
    },
    {
        "school": "Hillcrest Colony Elementary",
        "district": "Vaughn Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300585001109",
    },
    {
        "school": "DONNA J. BEASLEY TECHNICAL ACADEMY",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108008229",
    },
    {
        "school": "Knox County Day Treatment",
        "district": "Knox County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210315002357",
    },
    {
        "school": "Letcher County Alternative Education Ctr",
        "district": "Letcher County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210336002344",
    },
    {
        "school": "Foster Meade Career & Technical Center",
        "district": "Lewis County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210339002377",
    },
    {
        "school": "Palisades Park Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003310",
    },
    {
        "school": "Trillium Springs Montessori",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003311",
    },
    {
        "school": "Harper Middle College High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003313",
    },
    {
        "school": "Charlotte Engineering Early College-UNCC",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003315",
    },
    {
        "school": "Levine Middle College High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003318",
    },
    {
        "school": "New Beginnings",
        "district": "Eatonville School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530237003461",
    },
    {
        "school": "JAMES MADISON PREPARATORY HIGH SCHOOL",
        "district": "MADISON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120120008247",
    },
    {
        "school": "VISIBLE MEN ACADEMY",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123008256",
    },
    {
        "school": "Highwood School",
        "district": "Highwood K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301407000436",
    },
    {
        "school": "Highwood Middle School",
        "district": "Highwood K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301407000947",
    },
    {
        "school": "Martin County Middle School",
        "district": "Martin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210384002386",
    },
    {
        "school": "Lone Oak Intermediate School",
        "district": "McCracken County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210396002374",
    },
    {
        "school": "Metcalfe County Elementary School",
        "district": "Metcalfe County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210414002383",
    },
    {
        "school": "MCSO ADULTS",
        "district": "MARION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120126008314",
    },
    {
        "school": "LEGACY ELEMENTARY SCHOOL",
        "district": "MARION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126008321",
    },
    {
        "school": "Ohio County Alternative Learning Program",
        "district": "Ohio County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210450002353",
    },
    {
        "school": "Ohio County Day Treatment",
        "district": "Ohio County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210450002361",
    },
    {
        "school": "MONROE VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "MONROE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132008298",
    },
    {
        "school": "NASSAU VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "NASSAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135008277",
    },
    {
        "school": "OKALOOSA ONLINE NON FRANCHISED",
        "district": "OKALOOSA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138008315",
    },
    {
        "school": "Choices Educational Center",
        "district": "Paducah Independent",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210465002364",
    },
    {
        "school": "East Perry County Elementary School",
        "district": "Perry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210477002354",
    },
    {
        "school": "Perry County Alternative School",
        "district": "Perry County",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210477002387",
    },
    {
        "school": "Powell County Academy",
        "district": "Powell County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210489002360",
    },
    {
        "school": "Everett Reengagement Academy",
        "district": "Everett School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530267003452",
    },
    {
        "school": "Henrietta Lacks Health and Bioscience High School",
        "district": "Evergreen School District (Clark)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270003463",
    },
    {
        "school": "Birth to Three Development Center",
        "district": "Federal Way School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530282003408",
    },
    {
        "school": "Dynamic Family Services",
        "district": "Federal Way School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530282003430",
    },
    {
        "school": "Lake Roosevelt Alternative School",
        "district": "Grand Coulee Dam School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530313003448",
    },
    {
        "school": "Bluegrass Discovery Academy Middle",
        "district": "Rowan County",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210510002336",
    },
    {
        "school": "Bluegrass Discovery Academy High",
        "district": "Rowan County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210510002342",
    },
    {
        "school": "Lemons Mill Elementary School",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526002349",
    },
    {
        "school": "West Side Elementary",
        "district": "Sidney Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302420001110",
    },
    {
        "school": "Commander Academy",
        "district": "Washington County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210576002358",
    },
    {
        "school": "Monticello Elementary School",
        "district": "Wayne County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210579002346",
    },
    {
        "school": "Webster County Middle School",
        "district": "Webster County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210582002348",
    },
    {
        "school": "Hockinson Heights Elementary School",
        "district": "Hockinson School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530357003440",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT HUNTERS CREEK",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008225",
    },
    {
        "school": "MILLENNIA GARDENS ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008283",
    },
    {
        "school": "OCVS DIGITAL ACADEMY",
        "district": "ORANGE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008328",
    },
    {
        "school": "INDEPENDENCE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008330",
    },
    {
        "school": "VICTORY CHARTER SCHOOL",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008236",
    },
    {
        "school": "OASIS RESIDENTIAL CENTER",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120147008295",
    },
    {
        "school": "Northshore Elementary School",
        "district": "Knox County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222002328",
    },
    {
        "school": "Success Academy",
        "district": "Wolfe County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210597002369",
    },
    {
        "school": "Dessie Scott School",
        "district": "Wolfe County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210597002380",
    },
    {
        "school": "Glankler Early Learning Center",
        "district": "Fremont Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61440013675",
    },
    {
        "school": "NORRIS INTERMEDIATE SCHOOL",
        "district": "NORRIS SCHOOL DIST 160",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008802295",
    },
    {
        "school": "LOGAN VIEW ELEMENTARY",
        "district": "LOGAN VIEW PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011402274",
    },
    {
        "school": "SANDY CREEK MIDDLE SCHOOL",
        "district": "SOUTH CENTRAL NEBRASKA UNIFIED 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012202285",
    },
    {
        "school": "STEM Early High",
        "district": "Vance County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465003308",
    },
    {
        "school": "La Center Home School Academy",
        "district": "La Center School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530417003451",
    },
    {
        "school": "Discovery High School",
        "district": "Longview School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530447003454",
    },
    {
        "school": "SOMERSET ACADEMY CANYONS HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008231",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT SUMMIT",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008233",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT PALMS WEST",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008238",
    },
    {
        "school": "FRANKLIN ACADEMY - BOYNTON BEACH",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008241",
    },
    {
        "school": "SOUTH TECH PREPARATORY ACADEMY",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008242",
    },
    {
        "school": "SOMERSET ACADEMY CANYONS MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008251",
    },
    {
        "school": "SOMERSET ACADEMY BOCA MIDDLE SCHOOL",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008275",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT WELLINGTON",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008299",
    },
    {
        "school": "PALM BEACH VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "PALM BEACH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008306",
    },
    {
        "school": "Northfield Academy",
        "district": "Maury County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276002360",
    },
    {
        "school": "Pisgah Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303002341",
    },
    {
        "school": "Magnolia School of Excellence",
        "district": "Caddo Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030002377",
    },
    {
        "school": "REACH Academy",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61623013677",
    },
    {
        "school": "MERIT Academy",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61623013711",
    },
    {
        "school": "Purpose Prep",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002319",
    },
    {
        "school": "Nashville Classical",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002332",
    },
    {
        "school": "Intrepid College Preparatory Charter School",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002343",
    },
    {
        "school": "KIPP Nashville College Prep",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002347",
    },
    {
        "school": "Johnson Alternative Learning Center",
        "district": "Davidson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470318002361",
    },
    {
        "school": "Northshore Online School",
        "district": "Northshore School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530591003453",
    },
    {
        "school": "COMMUNITY HAVEN FOR ADULTS AND CHILDREN WITH DISABILITIES I",
        "district": "SARASOTA",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120168008288",
    },
    {
        "school": "RED TRAIL ELEMENTARY SCHOOL",
        "district": "MANDAN 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381182000870",
    },
    {
        "school": "George C Simkins Jr Elementary",
        "district": "Guilford County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192003312",
    },
    {
        "school": "C Joyner Greene Education Center",
        "district": "Guilford County Schools",
        "level": "High",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370192003314",
    },
    {
        "school": "Technology Middle",
        "district": "Cotati-Rohnert Park Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60994013686",
    },
    {
        "school": "Vernon Malone College and Career Academy",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003345",
    },
    {
        "school": "Skill Source Learning Center",
        "district": "Moses Lake School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530522003443",
    },
    {
        "school": "PLATO ACADEMY OF ST.PETERSBURG",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008258",
    },
    {
        "school": "DISCOVERY ACADEMY OF SCIENCE",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008262",
    },
    {
        "school": "PATHWAYS BEYOND/EARLY STEPS TO SUCCESS BUILDING",
        "district": "COLUMBUS PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310534002282",
    },
    {
        "school": "SAGEWOOD ELEMENTARY SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011002277",
    },
    {
        "school": "WEST BAY ELEMENTARY SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011002292",
    },
    {
        "school": "PARK RIVER AREA ELEMENTARY SCHOOL",
        "district": "PARK RIVER AREA 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380040100145",
    },
    {
        "school": "PARK RIVER AREA HIGH SCHOOL",
        "district": "PARK RIVER AREA 8",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380040100526",
    },
    {
        "school": "Mayfair Laboratory School",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002353",
    },
    {
        "school": "Delmont Pre-K and Kindergarten Center",
        "district": "East Baton Rouge Parish",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002360",
    },
    {
        "school": "North Banks Middle School of Excellence",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002363",
    },
    {
        "school": "MAGNOLIA MONTESSORI ACADEMY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159008234",
    },
    {
        "school": "POLK STATE LAKELAND GATEWAY TO COLLEGE CHARTER HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159008246",
    },
    {
        "school": "POLK FULL TIME ESCHOOL",
        "district": "POLK",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159008317",
    },
    {
        "school": "Rhea Central Elementary",
        "district": "Rhea County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470351002353",
    },
    {
        "school": "Rhea Middle School",
        "district": "Rhea County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470351002355",
    },
    {
        "school": "Stewarts Creek High School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002318",
    },
    {
        "school": "EDUCARE OF LINCOLN",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002276",
    },
    {
        "school": "MADISON PRESCHOOL",
        "district": "MADISON PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317323002287",
    },
    {
        "school": "Puyallup Open Doors/POD",
        "district": "Puyallup School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530696003442",
    },
    {
        "school": "Puyallup Parent Partnership Program",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530696003449",
    },
    {
        "school": "Beekman Charter School",
        "district": "Morehouse Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220111002359",
    },
    {
        "school": "Homer A. Plessy Community School",
        "district": "Orleans Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220117002373",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT TRADITION",
        "district": "ST. LUCIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177008226",
    },
    {
        "school": "CONTRACTED RESIDENTIAL SERVICES",
        "district": "SUMTER",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120180008309",
    },
    {
        "school": "Rapides Alternative Positive Program for Students",
        "district": "Rapides Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129002374",
    },
    {
        "school": "Eucalyptus Hills Elementary",
        "district": "Lakeside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62079013731",
    },
    {
        "school": "Bridges Academy",
        "district": "Lemoore Union Elementary",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62136013720",
    },
    {
        "school": "WAYSIDE SCI-TECH MIDDLE AND H S",
        "district": "WAYSIDE SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480004412927",
    },
    {
        "school": "SOUTHWEST PREP NORTHWEST EL",
        "district": "SOUTHWEST PREPARATORY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006313011",
    },
    {
        "school": "UT - UNIVERSITY CHARTER SCHOOL AT HIGH POINT",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007112956",
    },
    {
        "school": "CEDAR PARK CHARTER ACADEMY",
        "district": "PRIORITY CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007612994",
    },
    {
        "school": "COVE CHARTER ACADEMY",
        "district": "PRIORITY CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007613035",
    },
    {
        "school": "Main Preparatory Academy",
        "district": "Main Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390151105765",
    },
    {
        "school": "Bio-Med Science Academy STEM School",
        "district": "Bio-Med Science Academy STEM School",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390151205794",
    },
    {
        "school": "West Park Academy",
        "district": "West Park Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390151405778",
    },
    {
        "school": "Cincinnati Technology Academy",
        "district": "Cincinnati Technology Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390151605812",
    },
    {
        "school": "Hope Learning Academy of Toledo",
        "district": "Hope Learning Academy of Toledo",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390152005819",
    },
    {
        "school": "Imagine Columbus Primary School",
        "district": "Imagine Columbus Primary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390152105801",
    },
    {
        "school": "Winton Preparatory Academy",
        "district": "Winton Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390152405786",
    },
    {
        "school": "East Academy",
        "district": "East Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390152605779",
    },
    {
        "school": "Chapelside Cleveland Academy",
        "district": "Chapelside Cleveland Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390152705773",
    },
    {
        "school": "United Preparatory Academy",
        "district": "United Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390152905782",
    },
    {
        "school": "Ohio Construction Academy",
        "district": "Ohio Construction Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390153005808",
    },
    {
        "school": "Franklinton Preparatory Academy",
        "district": "Franklinton Preparatory Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390153305789",
    },
    {
        "school": "Global Impact STEM Academy",
        "district": "Global Impact STEM Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390153505818",
    },
    {
        "school": "Dayton SMART Elementary School",
        "district": "Dayton SMART Elementary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390153605813",
    },
    {
        "school": "Albert Einstein Academy for Letters Arts and Sciences-Ohio",
        "district": "Albert Einstein Academy for Letters Arts and Sciences-Ohio",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390153905804",
    },
    {
        "school": "Lincoln Park Academy",
        "district": "Lincoln Park Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390154305770",
    },
    {
        "school": "SELAH ACADEMY REENGAGEMENT PROGRAM",
        "district": "Selah School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530777003457",
    },
    {
        "school": "ESU 2 INDEPENDENT SCHOOL",
        "district": "EDUCATIONAL SERVICE UNIT 02",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "318002002283",
    },
    {
        "school": "Northview Senior Academy",
        "district": "Sevier County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378002336",
    },
    {
        "school": "Innovation Academy",
        "district": "Sullivan County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399002344",
    },
    {
        "school": "SCPS EARLY LEARNING CENTER",
        "district": "SEMINOLE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171008303",
    },
    {
        "school": "VALLEY RIDGE ACADEMY",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174008280",
    },
    {
        "school": "ALFONZA W DAVIS MIDDLE SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482002278",
    },
    {
        "school": "GATEWAY ELEMENTARY",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482002280",
    },
    {
        "school": "Meadow Crest Early Childhood Education Center",
        "district": "Renton School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723003447",
    },
    {
        "school": "Open Door Youth Reengagement Renton",
        "district": "Renton School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530723003450",
    },
    {
        "school": "TEXANS CAN ACADEMY - HOUSTON NORTH",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001607910",
    },
    {
        "school": "TEXANS CAN ACADEMY - SAN ANTONIO",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001608434",
    },
    {
        "school": "TEXANS CAN ACADEMY - FORT WORTH WESTCREEK",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001608908",
    },
    {
        "school": "TEXANS CAN ACADEMY - FORT WORTH LANCASTER AVENUE",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001609028",
    },
    {
        "school": "TEXANS CAN ACADEMY - AUSTIN",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001609410",
    },
    {
        "school": "TEXANS CAN ACADEMY - HOUSTON HOBBY",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001609602",
    },
    {
        "school": "TEXANS CAN ACADEMY - GRANT EAST",
        "district": "TEXANS CAN ACADEMIES",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001612961",
    },
    {
        "school": "Rockdale RYDC",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130002604141",
    },
    {
        "school": "E N SWETT ELEMENTARY SCHOOL",
        "district": "SO SIOUX CITY COMMUNITY SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317686002273",
    },
    {
        "school": "Youthsource",
        "district": "Tukwila School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530813003439",
    },
    {
        "school": "KIPP Vision Primary",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004124",
    },
    {
        "school": "Westside Atlanta Charter School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004139",
    },
    {
        "school": "Union Parish Alternative Center",
        "district": "Union Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220177002358",
    },
    {
        "school": "Discovery Academy",
        "district": "Discovery Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390154505793",
    },
    {
        "school": "Imagine Leadership Academy",
        "district": "Imagine Leadership Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390154905797",
    },
    {
        "school": "Eastland Preparatory Academy",
        "district": "Eastland Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390155005772",
    },
    {
        "school": "Liberty Preparatory School",
        "district": "Liberty Preparatory School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390155105783",
    },
    {
        "school": "East Preparatory Academy",
        "district": "East Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390155405766",
    },
    {
        "school": "Rise & Shine Academy",
        "district": "Rise & Shine Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390155505806",
    },
    {
        "school": "University Academy",
        "district": "University Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390155605795",
    },
    {
        "school": "VISTA ACADEMY OF HUMBLE",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312923",
    },
    {
        "school": "ISCHOOL HIGH AT THE WOODLANDS",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016312926",
    },
    {
        "school": "VISTA ACADEMY OF PASADENA",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313028",
    },
    {
        "school": "JUBILEE WELLS BRANCH",
        "district": "JUBILEE ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017912987",
    },
    {
        "school": "TEXAS PREPARATORY SCHOOL - AUSTIN CAMPUS",
        "district": "TEXAS PREPARATORY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480019412933",
    },
    {
        "school": "VANGUARD MOZART",
        "district": "VANGUARD ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480019513037",
    },
    {
        "school": "The Community School",
        "district": "Spokane School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825003401",
    },
    {
        "school": "Open Doors Youth Reengagement Sultan",
        "district": "Sultan School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530855003446",
    },
    {
        "school": "Fresh Start",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530870003444",
    },
    {
        "school": "HARMONY SCHOOL OF EXPLORATION- HOUSTON",
        "district": "HARMONY SCIENCE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021012974",
    },
    {
        "school": "IDEA MONTOPOLIS ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112928",
    },
    {
        "school": "IDEA MONTOPOLIS COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112940",
    },
    {
        "school": "IDEA SOUTH FLORES COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021112969",
    },
    {
        "school": "IDEA SOUTH FLORES ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113025",
    },
    {
        "school": "Tybee Island Maritime Academy School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102004117",
    },
    {
        "school": "Savannah Classical Academy Charter School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102004135",
    },
    {
        "school": "THE RHODES SCHOOL - NORTHSHORE",
        "district": "THE RHODES SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480028313010",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY- BEAUMONT",
        "district": "HARMONY SCHOOL OF SCIENCE - HOUSTON",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140512934",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY-KATY",
        "district": "HARMONY SCHOOL OF SCIENCE - HOUSTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140513062",
    },
    {
        "school": "TEXAS LEADERSHIP OF MIDLAND",
        "district": "TEXAS LEADERSHIP",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140912979",
    },
    {
        "school": "THE PRO-VISION ACADEMY",
        "district": "THE PRO-VISION ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480143412920",
    },
    {
        "school": "PRO-VISION MIDDLE",
        "district": "THE PRO-VISION ACADEMY",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480143412953",
    },
    {
        "school": "ELEANOR KOLITZ HEBREW LANGUAGE ACADEMY",
        "district": "ELEANOR KOLITZ HEBREW LANGUAGE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143513053",
    },
    {
        "school": "VILLAGE TECH SCHOOLS",
        "district": "VILLAGE TECH SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143613030",
    },
    {
        "school": "BASIS SAN ANTONIO- SHAVANO CAMPUS",
        "district": "BASIS TEXAS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143813036",
    },
    {
        "school": "EL PASO LEADERSHIP ACADEMY",
        "district": "EL PASO LEADERSHIP ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143913023",
    },
    {
        "school": "ILTEXAS GARLAND H S",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144012917",
    },
    {
        "school": "ILTEXAS GARLAND EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144012955",
    },
    {
        "school": "ILTEXAS GARLAND MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013007",
    },
    {
        "school": "ILTEXAS ARLINGTON MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013016",
    },
    {
        "school": "ILTEXAS ARLINGTON EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013020",
    },
    {
        "school": "GREAT HEARTS MONTE VISTA",
        "district": "GREAT HEARTS TEXAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144112996",
    },
    {
        "school": "MAGNOLIA MONTESSORI FOR ALL",
        "district": "MONTESSORI FOR ALL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144212915",
    },
    {
        "school": "Open Doors  Re-Engagement Wenatchee",
        "district": "Wenatchee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530966003459",
    },
    {
        "school": "ASPIRE Academy High School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320009000832",
    },
    {
        "school": "Early Childhood School - GBC",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320012000829",
    },
    {
        "school": "Early Childhood School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "NV",
        "nces_id": "320012000836",
    },
    {
        "school": "GLOBE Academy Charter School I",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174004142",
    },
    {
        "school": "RED DUKE EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809012913",
    },
    {
        "school": "RICHARD J LEE EL",
        "district": "COPPELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521012980",
    },
    {
        "school": "Harpswell Coastal Academy Division 1",
        "district": "Harpswell Coastal Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481623139",
    },
    {
        "school": "Athens Community School",
        "district": "Athens Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481700742",
    },
    {
        "school": "Stratton Elementary School",
        "district": "Eustis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481801035",
    },
    {
        "school": "Collegiate Charter School of Lowell",
        "district": "Collegiate Charter School of Lowell (District)",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054502785",
    },
    {
        "school": "Pioneer Charter School of Science II (PCSS-II)",
        "district": "Pioneer Charter School of Science II (PCSS-II) (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054602780",
    },
    {
        "school": "Paulo Freire Social Justice Charter School",
        "district": "Paulo Freire Social Justice Charter School (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054702782",
    },
    {
        "school": "City on a Hill Charter Public School Dudley Square",
        "district": "City on a Hill Charter Public School Dudley Square (District",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054802781",
    },
    {
        "school": "UP Academy Charter School of Dorchester",
        "district": "UP Academy Charter School of Dorchester (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054902783",
    },
    {
        "school": "Baystate Academy Charter Public School",
        "district": "Baystate Academy Charter Public School (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250055002784",
    },
    {
        "school": "Doral Academy Red Rock",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100830",
    },
    {
        "school": "Learning Bridge",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100833",
    },
    {
        "school": "The Davidson Academy of Nevada",
        "district": "DAVIDSON ACADEMY  SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320002100680",
    },
    {
        "school": "Methodist Home for Children of Greater New Orleans",
        "district": "Special School District",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010002351",
    },
    {
        "school": "Pinehill Alternative High School",
        "district": "Special School District",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010002355",
    },
    {
        "school": "Northlake Youth Academy",
        "district": "Special School District",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010002356",
    },
    {
        "school": "River Oaks Hospital",
        "district": "Special School District",
        "level": "Other",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "228010002372",
    },
    {
        "school": "PREMIER H S OF AMARILLO",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020712986",
    },
    {
        "school": "YES PREP - WHITE OAK",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020912924",
    },
    {
        "school": "YES PREP NORTH FOREST",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020912959",
    },
    {
        "school": "EVOLUTION ACADEMY HOUSTON",
        "district": "EVOLUTION ACADEMY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480023612916",
    },
    {
        "school": "EVOLUTION ACADEMY BEAUMONT",
        "district": "EVOLUTION ACADEMY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480023613008",
    },
    {
        "school": "PEGASUS SCHOOL",
        "district": "TRINITY CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480025912947",
    },
    {
        "school": "KIPP AUSTIN OBRAS",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412954",
    },
    {
        "school": "KIPP AUSTIN LEADERSHIP EL",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413044",
    },
    {
        "school": "Willard School",
        "district": "Sanford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231050023143",
    },
    {
        "school": "Smyrna Elementary School",
        "district": "Cobb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129004134",
    },
    {
        "school": "Wiregrass Regional College and Career Academy",
        "district": "Coffee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130135004131",
    },
    {
        "school": "College Park Academy",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001718",
    },
    {
        "school": "Spruce Mountain High School",
        "district": "RSU 73",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480523142",
    },
    {
        "school": "Baxter Academy for Tech & Sciences",
        "district": "Baxter Academy for Technology and Science",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481223141",
    },
    {
        "school": "Fiddlehead School of Arts & Science",
        "district": "Fiddlehead School of Arts and Sciences",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481323140",
    },
    {
        "school": "Cherryfield Elementary",
        "district": "Cherryfield Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481400461",
    },
    {
        "school": "Samuel L Wagner Middle School",
        "district": "RSU 22",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481500030",
    },
    {
        "school": "Reeds Brook Middle School",
        "district": "RSU 22",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481500164",
    },
    {
        "school": "Earl C McGraw School",
        "district": "RSU 22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481500385",
    },
    {
        "school": "George B Weatherbee School",
        "district": "RSU 22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481500386",
    },
    {
        "school": "Hampden Academy",
        "district": "RSU 22",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481500387",
    },
    {
        "school": "Leroy H Smith School",
        "district": "RSU 22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481500388",
    },
    {
        "school": "Newburgh Elementary School",
        "district": "RSU 22",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481500389",
    },
    {
        "school": "Kettering Early Childhood Education Center",
        "district": "Kettering City School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441805784",
    },
    {
        "school": "Dorothy Lemelson STEM Academy Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000834",
    },
    {
        "school": "Sparks HS Preschool",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000835",
    },
    {
        "school": "Kendyl Depoali Preschool",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000838",
    },
    {
        "school": "ARLINGTON COLLEGIATE H S",
        "district": "ARLINGTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480870013043",
    },
    {
        "school": "Higginson",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002806",
    },
    {
        "school": "Monatiquot Kindergarten Center",
        "district": "Braintree",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250294002789",
    },
    {
        "school": "Eisenhower Intermediate School",
        "district": "Oregon City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446005802",
    },
    {
        "school": "WOODARD EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611012935",
    },
    {
        "school": "ANTHONY MIDDLE",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611013026",
    },
    {
        "school": "Granite State Arts Academy Charter School",
        "district": "Granite State Arts Academy Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330329600711",
    },
    {
        "school": "Mountain Village Charter School",
        "district": "Mountain Village Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330329700715",
    },
    {
        "school": "The Founders Academy Charter School (E)",
        "district": "The Founders Academy Charter School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330329800713",
    },
    {
        "school": "Greenfield Commonwealth Virtual School",
        "district": "Greenfield Commonwealth Virtual District",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250055102808",
    },
    {
        "school": "Phoenix Academy",
        "district": "Anne Arundel County Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240006001714",
    },
    {
        "school": "Creative City Public Charter School",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001716",
    },
    {
        "school": "Red Bud Middle School",
        "district": "Gordon County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130243004118",
    },
    {
        "school": "Barrett Russell Early Childhood Center",
        "district": "Brockton",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250309002792",
    },
    {
        "school": "Brookline Early Education Program at Putterham",
        "district": "Brookline",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315002793",
    },
    {
        "school": "EDGEWOOD ELEMENTARY",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540060001499",
    },
    {
        "school": "THELMA ELIZABETH PAGE RICHARDSON EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013038",
    },
    {
        "school": "B MCDANIEL INT",
        "district": "DENISON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481671013045",
    },
    {
        "school": "Devens School",
        "district": "Everett",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250477002787",
    },
    {
        "school": "Adams School",
        "district": "Everett",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250477002804",
    },
    {
        "school": "DELL CHILDREN'S MEDICAL CENTER",
        "district": "AUSTIN ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480894013004",
    },
    {
        "school": "BARBERS HILL EL SOUTH",
        "district": "BARBERS HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480945012919",
    },
    {
        "school": "BARBERS HILL EL NORTH",
        "district": "BARBERS HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480945012941",
    },
    {
        "school": "BARBERS HILL MIDDLE SOUTH",
        "district": "BARBERS HILL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480945012964",
    },
    {
        "school": "BARBERS HILL MIDDLE NORTH",
        "district": "BARBERS HILL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480945013042",
    },
    {
        "school": "Smith Middle School",
        "district": "Vandalia-Butler City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449505791",
    },
    {
        "school": "H.B. Lawrence School",
        "district": "Holyoke",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627002795",
    },
    {
        "school": "Lee County Middle School East",
        "district": "Lee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130327004128",
    },
    {
        "school": "Long County Middle School",
        "district": "Long County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130336004120",
    },
    {
        "school": "Dr. Sammy Lee Medical and Health Science Magnet Elementary",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013726",
    },
    {
        "school": "Frederick Classical Charter",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001715",
    },
    {
        "school": "Aaron Cohn Middle School",
        "district": "Muscogee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387004127",
    },
    {
        "school": "Rabun County Primary School",
        "district": "Rabun County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130432004136",
    },
    {
        "school": "WORLD LANGUAGES INSTITUTE",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970012991",
    },
    {
        "school": "Woodlands School - State Street Campus",
        "district": "Woodlands School - State Street Campus Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550007002942",
    },
    {
        "school": "Tomorrow River Community Charter",
        "district": "Tomorrow River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550033002968",
    },
    {
        "school": "HOSP EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012931",
    },
    {
        "school": "NEWMAN EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001012937",
    },
    {
        "school": "MCSPEDDEN EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013002",
    },
    {
        "school": "REEDY H S",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013003",
    },
    {
        "school": "INDEPENDENCE H S",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013005",
    },
    {
        "school": "SCOTT EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013017",
    },
    {
        "school": "Moreno Valley Online Academy",
        "district": "Moreno Valley Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62580013683",
    },
    {
        "school": "School for Examining Essential Questions of Sustainability",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000298",
    },
    {
        "school": "Malama Honua Learning Center PCS",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000299",
    },
    {
        "school": "Indian Creek Middle School Grades 5 & 6",
        "district": "Indian Creek Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390478005768",
    },
    {
        "school": "GRAND PRAIRIE FINE ARTS ACADEMY",
        "district": "GRAND PRAIRIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142012982",
    },
    {
        "school": "Gate City Charter School for the Arts",
        "district": "Gate City Charter School For the Arts District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330329900712",
    },
    {
        "school": "N H Wixon Innovation School",
        "district": "Dennis-Yarmouth",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250414002803",
    },
    {
        "school": "Douglas Middle School",
        "district": "Douglas",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250423002788",
    },
    {
        "school": "Douglas Elementary School",
        "district": "Douglas",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250423002791",
    },
    {
        "school": "Douglas Primary School",
        "district": "Douglas",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250423002798",
    },
    {
        "school": "Habersham Success Academy",
        "district": "Habersham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130258004144",
    },
    {
        "school": "Nashua Title I Preschool",
        "district": "Nashua School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330498000714",
    },
    {
        "school": "DOROTHY P ADKINS EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674012946",
    },
    {
        "school": "Oliver Partnership School",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002799",
    },
    {
        "school": "UP Academy Oliver Middle School",
        "district": "Lawrence",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002805",
    },
    {
        "school": "Leominster Center for Excellence",
        "district": "Leominster",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250678002779",
    },
    {
        "school": "KEYSER PRIMARY SCHOOL",
        "district": "MINERAL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540087001498",
    },
    {
        "school": "BOSQUEVILLE MIDDLE",
        "district": "BOSQUEVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481091012988",
    },
    {
        "school": "EDCOUCH-ELSA H S ACADEMY",
        "district": "EDCOUCH-ELSA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481806013006",
    },
    {
        "school": "Renaissance Community Innovation School",
        "district": "New Bedford",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250843002802",
    },
    {
        "school": "Ducketts Lane",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001717",
    },
    {
        "school": "ACE Program",
        "district": "Oxford",
        "level": "High",
        "type": "Special education school",
        "state": "MA",
        "nces_id": "250927002810",
    },
    {
        "school": "Amelio Della Chiesa Early Childhood Center",
        "district": "Quincy",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250987002807",
    },
    {
        "school": "Hope Community Charter School",
        "district": "Hope Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340076303247",
    },
    {
        "school": "Philip's Academy Charter School",
        "district": "Phillip's Academy  Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340076403256",
    },
    {
        "school": "Paterson Arts and Science Charter School",
        "district": "Paterson Arts and Science Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340076503254",
    },
    {
        "school": "Compass Academy Charter School",
        "district": "Compass Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340076603265",
    },
    {
        "school": "Jersey City Global Charter School",
        "district": "Jersey City Global Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340076703251",
    },
    {
        "school": "Brighton Avenue School",
        "district": "Atlantic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340096003259",
    },
    {
        "school": "Gateway to College at Springfield Technical Community Colleg",
        "district": "Springfield",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "251113002809",
    },
    {
        "school": "Taunton Alternative High School",
        "district": "Taunton",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "251152002778",
    },
    {
        "school": "Appleton Technical Academy",
        "district": "Appleton Area School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WI",
        "nces_id": "550039002964",
    },
    {
        "school": "Appleton Community 4K",
        "district": "Appleton Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550039002976",
    },
    {
        "school": "Saddle Ridge Elementary and Middle School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130537004121",
    },
    {
        "school": "Quaboag Regional Middle Innovation School",
        "district": "Quaboag Regional",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251210002794",
    },
    {
        "school": "LEGACY EL",
        "district": "FRENSHIP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983012950",
    },
    {
        "school": "Murdock High School",
        "district": "Winchendon",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251308002786",
    },
    {
        "school": "Murdock Middle School",
        "district": "Winchendon",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251308002796",
    },
    {
        "school": "Trebein Elementary School",
        "district": "Beavercreek City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472405774",
    },
    {
        "school": "Beloit Learning Academy",
        "district": "Beloit School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550105002974",
    },
    {
        "school": "Cesar Chavez Academy Elementary East",
        "district": "Cesar Chavez Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260013908488",
    },
    {
        "school": "Oakland International Academy  High School",
        "district": "Oakland International Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021708533",
    },
    {
        "school": "BANUELOS EL",
        "district": "GOOSE CREEK CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115013012",
    },
    {
        "school": "GRAND PRAIRIE COLLEGIATE INSTITUTE",
        "district": "GRAND PRAIRIE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142013031",
    },
    {
        "school": "IUNIVERSITY PREP",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166013033",
    },
    {
        "school": "H O WHITEHURST EL",
        "district": "GROESBECK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482181012942",
    },
    {
        "school": "Island City Academy",
        "district": "Cumberland School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WI",
        "nces_id": "550309002962",
    },
    {
        "school": "WAY Academy  Chicago Site",
        "district": "W-A-Y Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260102308423",
    },
    {
        "school": "Macomb Montessori Academy",
        "district": "Macomb Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260103508448",
    },
    {
        "school": "Tipton Academy  PK3",
        "district": "Tipton Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260103608432",
    },
    {
        "school": "Greater Heights Academy",
        "district": "Greater Heights Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260103708453",
    },
    {
        "school": "Genesee STEM Academy",
        "district": "Genesee STEM Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260103908567",
    },
    {
        "school": "ICademy Global",
        "district": "ICademy Global",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260104008512",
    },
    {
        "school": "Sarah J Webber Media Arts Academy",
        "district": "Sarah J. Webber Media Arts Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260104108481",
    },
    {
        "school": "Branch Line School",
        "district": "Branch Line School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260104208555",
    },
    {
        "school": "FlexTech High School  Novi",
        "district": "FlexTech High School - Novi",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260104308495",
    },
    {
        "school": "Jackson Preparatory  Early College",
        "district": "Jackson Preparatory & Early College",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260104408497",
    },
    {
        "school": "Momentum Academy",
        "district": "Momentum Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260104508573",
    },
    {
        "school": "Kingsbury Country Day School",
        "district": "Kingsbury Country Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260104608517",
    },
    {
        "school": "Rising Stars Academy",
        "district": "Rising Stars Academy",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260104708578",
    },
    {
        "school": "Detroit Achievement Academy",
        "district": "Detroit Achievement Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260104808503",
    },
    {
        "school": "Great Lakes Cyber Academy  MSHS",
        "district": "Great Lakes Cyber Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260105008571",
    },
    {
        "school": "The James and Grace Lee Boggs School",
        "district": "The James and Grace Lee Boggs School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260105108518",
    },
    {
        "school": "Waterford Montessori Academy",
        "district": "Waterford Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260105308562",
    },
    {
        "school": "Battle Creek Montessori Academy",
        "district": "Battle Creek Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260105508473",
    },
    {
        "school": "WAY Academy  Flint Flint Campus",
        "district": "WAY Academy - Flint",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260105608577",
    },
    {
        "school": "LifeTech Academy",
        "district": "LifeTech Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260105808544",
    },
    {
        "school": "Taylor Preparatory High School",
        "district": "Taylor Preparatory High School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260106108531",
    },
    {
        "school": "Detroit Public Safety Academy",
        "district": "Detroit Public Safety Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260106208462",
    },
    {
        "school": "Lakeside Charter School  Kalamazoo",
        "district": "Lakeside Charter School - Kalamazoo",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260106308558",
    },
    {
        "school": "Global Tech Academy",
        "district": "Global Tech Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260106408523",
    },
    {
        "school": "Covenant House Academy Grand Rapids",
        "district": "Covenant House Academy Grand Rapids",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260106608474",
    },
    {
        "school": "Muskegon Montessori Academy for Environmental Change",
        "district": "Muskegon Montessori Academy for Environmental Change",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260106708568",
    },
    {
        "school": "Oakside Scholars Charter Academy",
        "district": "Oakside Scholars Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260106808546",
    },
    {
        "school": "Michigan Great Lakes Virtual Academy",
        "district": "Michigan Great Lakes Virtual Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260107008516",
    },
    {
        "school": "Airport Center for Education",
        "district": "Airport Community Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260198008428",
    },
    {
        "school": "Trotwood-Madison Middle School",
        "district": "Trotwood-Madison City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390486905769",
    },
    {
        "school": "Leonardo da Vinci School for Gifted Learners",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582002955",
    },
    {
        "school": "Friedrich Froebel Garden of Early Learning",
        "district": "Green Bay Area Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582002965",
    },
    {
        "school": "Bloomfield Hills High School",
        "district": "Bloomfield Hills Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260609008480",
    },
    {
        "school": "ELMORE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012912",
    },
    {
        "school": "FONWOOD EARLY CHILDHOOD CTR",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012945",
    },
    {
        "school": "HILLIARD EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012966",
    },
    {
        "school": "SHADYDALE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012972",
    },
    {
        "school": "BAYLOR COLLEGE OF MEDICINE ACADEMY AT RYAN",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364012992",
    },
    {
        "school": "MARSHALL EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364013015",
    },
    {
        "school": "NORTH FOREST H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364013022",
    },
    {
        "school": "SOUTH EARLY COLLEGE H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364013032",
    },
    {
        "school": "ENERGY INSTITUTE H S",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364013046",
    },
    {
        "school": "FOREST BROOK MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364013060",
    },
    {
        "school": "Mott Middle College High School",
        "district": "Carman-Ainsworth Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260789000507",
    },
    {
        "school": "BendleCarmanAinsworth Alternative Education",
        "district": "Carman-Ainsworth Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260789001811",
    },
    {
        "school": "Genesee Early College",
        "district": "Carman-Ainsworth Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260789007793",
    },
    {
        "school": "Carson CityCrystal Alternative Academy",
        "district": "Carson City-Crystal Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260813008553",
    },
    {
        "school": "North Greenville Elementary",
        "district": "Hortonville Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550660002958",
    },
    {
        "school": "Youth Services Center",
        "district": "Janesville School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550702002948",
    },
    {
        "school": "Rock University High",
        "district": "Janesville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702002952",
    },
    {
        "school": "Dodgeland Middle",
        "district": "Dodgeland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550726002983",
    },
    {
        "school": "COPPERFIELD EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499012962",
    },
    {
        "school": "VETERANS MEMORIAL H S",
        "district": "JUDSON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499012976",
    },
    {
        "school": "San Joaquin Valley High",
        "district": "Parlier Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62991013666",
    },
    {
        "school": "Downriver Virtual Academy",
        "district": "Ecorse Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261293008570",
    },
    {
        "school": "Kohler Middle",
        "district": "Kohler School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550750002946",
    },
    {
        "school": "7 Rivers Community High",
        "district": "La Crosse School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550753002950",
    },
    {
        "school": "Gateway to CollegeMott Community College",
        "district": "Flint School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261452008443",
    },
    {
        "school": "Holmes STEM Academy",
        "district": "Flint School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261452008471",
    },
    {
        "school": "Brownell STEM Academy",
        "district": "Flint School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261452008539",
    },
    {
        "school": "Wisconsin Virtual Academy K-8 (WIVA)",
        "district": "McFarland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550891002973",
    },
    {
        "school": "Wisconsin Virtual Academy High (WIVA)",
        "district": "McFarland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550891002975",
    },
    {
        "school": "Mellen Public School",
        "district": "Mellen School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550897002941",
    },
    {
        "school": "School District of the Menomonie Area 4K",
        "district": "Menomonie Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550909002940",
    },
    {
        "school": "Campus Elementary",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008521",
    },
    {
        "school": "Gerald R Ford Academic Center",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008528",
    },
    {
        "school": "Sherwood Global Studies Academy",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008530",
    },
    {
        "school": "Mulick Park Elementary School",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008536",
    },
    {
        "school": "Harrison Park Academy",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008537",
    },
    {
        "school": "Innovation Central High",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008543",
    },
    {
        "school": "Stocking Elementary",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008559",
    },
    {
        "school": "Aberdeen Academy",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008574",
    },
    {
        "school": "Alger Middle School",
        "district": "Grand Rapids Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008575",
    },
    {
        "school": "Elcho Middle",
        "district": "Elcho School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550417002947",
    },
    {
        "school": "Crescent Academy Elementary",
        "district": "Crescent Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260029508444",
    },
    {
        "school": "Covenant House Academy Detroit  Southwest Site",
        "district": "Covenant House Academy Detroit",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260032201947",
    },
    {
        "school": "Covenant House Academy Detroit  East Site",
        "district": "Covenant House Academy Detroit",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260032201948",
    },
    {
        "school": "Detroit Leadership Academy MiddleHigh",
        "district": "Detroit Leadership Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260097408496",
    },
    {
        "school": "TEXAS VIRTUAL ACADEMY AT HALLSVILLE",
        "district": "HALLSVILLE ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482217012918",
    },
    {
        "school": "HARLANDALE ISD STEM ECHS-ALAMO COLLEGES AT PAC",
        "district": "HARLANDALE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482247012943",
    },
    {
        "school": "HARLINGEN SCHOOL OF HEALTH PROFESSIONS",
        "district": "HARLINGEN CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482253013014",
    },
    {
        "school": "SYRINGA MOUNTAIN CHARTER SCHOOL",
        "district": "SYRINGA MOUNTAIN SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160016601066",
    },
    {
        "school": "KTEC School",
        "district": "KTEC - Kootenai Tech Ed Campus",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160016701068",
    },
    {
        "school": "BINGHAM ACADEMY",
        "district": "IDAHO STEM ACADEMY INC.",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160016901067",
    },
    {
        "school": "Fond du Lac STEM Institute",
        "district": "Fond du Lac School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468002966",
    },
    {
        "school": "Bentley Middle School",
        "district": "Bentley Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260480008465",
    },
    {
        "school": "Bentley High School BOLD Academy",
        "district": "Bentley Community School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260480008508",
    },
    {
        "school": "Success  EdmoreMontabellaVestaburg",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008467",
    },
    {
        "school": "West Michigan Virtual  Battle Creek HS",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008470",
    },
    {
        "school": "West Michigan Virtual  Battle Creek MS",
        "district": "Berrien Springs Public Schools",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008475",
    },
    {
        "school": "Success  StantonCentral Montcalm",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008478",
    },
    {
        "school": "Success  Escanaba",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008485",
    },
    {
        "school": "Success  Howard CityTri County",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008529",
    },
    {
        "school": "TEXAS ONLINE PREPARATORY EL",
        "district": "HUNTSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482403012936",
    },
    {
        "school": "TEXAS ONLINE PREPARATORY H S",
        "district": "HUNTSVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482403012951",
    },
    {
        "school": "TEXAS ONLINE PREPARATORY MIDDLE",
        "district": "HUNTSVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482403012952",
    },
    {
        "school": "VIRIDIAN EL",
        "district": "HURST-EULESS-BEDFORD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482406012960",
    },
    {
        "school": "PAYETTE ALTERNATIVE CENTER",
        "district": "PAYETTE JOINT DISTRICT",
        "level": "Not reported",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160258001051",
    },
    {
        "school": "Clinton Virtual JrSr High School",
        "district": "Clinton Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261005008502",
    },
    {
        "school": "STEM Academy",
        "district": "Comstock Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261059008526",
    },
    {
        "school": "Lakewood Early Childhood Center",
        "district": "Lakewood Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340822003249",
    },
    {
        "school": "PAEC Academy",
        "district": "Proviso Area Exceptional Child",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003006266",
    },
    {
        "school": "Ulysses S Grant Intermediate Sch",
        "district": "Marengo-Union E Cons D 165",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170007706246",
    },
    {
        "school": "PAETOW H S",
        "district": "KATY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517012984",
    },
    {
        "school": "Flex Academy",
        "district": "Little Chute Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550816002959",
    },
    {
        "school": "Regl Learning Academy Star Boone",
        "district": "Boone/Winnebago ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016606300",
    },
    {
        "school": "POGUE OPTIONS ALTERNATIVE ACADEMY",
        "district": "KINGSVILLE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482568012921",
    },
    {
        "school": "Washington Preschool",
        "district": "Findlay City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000005803",
    },
    {
        "school": "Thome Ed School",
        "district": "Bi-County Special Educ Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706292",
    },
    {
        "school": "Harper Woods Virtual Academy",
        "district": "Harper Woods The School District of the City of",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261776008490",
    },
    {
        "school": "WEST CYPRESS HILLS EL",
        "district": "LAKE TRAVIS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482647013021",
    },
    {
        "school": "TULSA LEGACY CHARTER SCHL INC",
        "district": "LIGHTHOUSE ACADEMY (CHARTER)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400076902742",
    },
    {
        "school": "SANKOFA MIDDLE SCHOOL",
        "district": "SANKOFA MIDDLE SCHL (CHARTER)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400077202769",
    },
    {
        "school": "HARDING FINE ARTS ACADEMY",
        "district": "HARDING FINE ARTS (CHARTER)",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400077302385",
    },
    {
        "school": "HUPFELD ACAD./WESTERN VILLAGE",
        "district": "HUPFELD/W VILLAGE (CHARTER)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400077502307",
    },
    {
        "school": "EPIC ONE ON ONE CHARTER ES",
        "district": "EPIC ONE ON ONE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400077702741",
    },
    {
        "school": "OKLA. VIRTUAL CHARTER ACAD ES",
        "district": "OKLAHOMA VIRTUAL CHARTER ACAD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400077802719",
    },
    {
        "school": "KIPP TULSA ACAD. COLLEGE PREP.",
        "district": "KIPP (CHARTER)",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078002744",
    },
    {
        "school": "INDEPENDENCE CHARTER MS",
        "district": "INDEPENDENCE MIDDLE SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078102305",
    },
    {
        "school": "DUSTIN ES",
        "district": "GRAHAM-DUSTIN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078200462",
    },
    {
        "school": "GRAHAM ES",
        "district": "GRAHAM-DUSTIN",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078200608",
    },
    {
        "school": "GRAHAM HS",
        "district": "GRAHAM-DUSTIN",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078200609",
    },
    {
        "school": "ASTEC CHARTER MS",
        "district": "ASTEC CHARTERS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078302308",
    },
    {
        "school": "ASTEC CHARTER HS",
        "district": "ASTEC CHARTERS",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078302399",
    },
    {
        "school": "HARDING CHARTER PREPARATORY HS",
        "district": "HARDING (CHARTER)",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078402376",
    },
    {
        "school": "Michigan Cyber Academy",
        "district": "Hazel Park School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261803008563",
    },
    {
        "school": "Holton Virtual Academy",
        "district": "Holton Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261851008459",
    },
    {
        "school": "East Elementary School",
        "district": "Iron Mountain Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261941008446",
    },
    {
        "school": "Design 39 Campus",
        "district": "Poway Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63153013729",
    },
    {
        "school": "Sigwalt CLS Center",
        "district": "Township HSD 214",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170417006268",
    },
    {
        "school": "PRESTWICK K-8 STEM ACADEMY",
        "district": "LITTLE ELM ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482772012971",
    },
    {
        "school": "CEDAR GROVE EL",
        "district": "LIVINGSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482778012990",
    },
    {
        "school": "Milwaukee Environmental Science Academy",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002949",
    },
    {
        "school": "King International Baccalaureate Middle",
        "district": "Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002961",
    },
    {
        "school": "HAPA-Hmong American Peace Academy K3-12",
        "district": "Milwaukee School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002979",
    },
    {
        "school": "Carmen Mid/Hi Northwest Campus",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002980",
    },
    {
        "school": "Fred Rodgers Magnet Acad",
        "district": "Aurora East USD 131",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468006248",
    },
    {
        "school": "Ocean County Vocational Technical School Culinary Center",
        "district": "Ocean County Vocational Technical School District",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341198003255",
    },
    {
        "school": "NORTHEAST ES AND IS",
        "district": "BIXBY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400450002772",
    },
    {
        "school": "BOISE CITY JHS",
        "district": "BOISE CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400486002779",
    },
    {
        "school": "ASPEN CREEK EC CENTER",
        "district": "BROKEN ARROW",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002763",
    },
    {
        "school": "ONETA RIDGE MS",
        "district": "BROKEN ARROW",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002770",
    },
    {
        "school": "CREEKWOOD ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002771",
    },
    {
        "school": "PARKLANE EARLY CHILDHOOD CTR",
        "district": "BROKEN ARROW",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002773",
    },
    {
        "school": "ASPEN CREEK ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002777",
    },
    {
        "school": "CREEKWOOD EARLY CHILDHOOD CTR",
        "district": "BROKEN ARROW",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002781",
    },
    {
        "school": "LULING PRI",
        "district": "LULING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482859013051",
    },
    {
        "school": "Don Bosco Academy",
        "district": "Paterson Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003263",
    },
    {
        "school": "SHADOWGLEN EL",
        "district": "MANOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889012922",
    },
    {
        "school": "CYRIL JHS",
        "district": "CYRIL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400930002776",
    },
    {
        "school": "SPRING CREEK ES",
        "district": "DEER CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400957002775",
    },
    {
        "school": "Central Wisconsin STEM Academy",
        "district": "Nekoosa School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551038002957",
    },
    {
        "school": "Bayshore Community Academy",
        "district": "Oconto Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551092002977",
    },
    {
        "school": "Carterville Intermediate Sch",
        "district": "Carterville CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170864006279",
    },
    {
        "school": "Harvest High",
        "district": "Ripon Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63288013703",
    },
    {
        "school": "Thompson Intermediate School",
        "district": "Alabaster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019001182",
    },
    {
        "school": "Thompson High School",
        "district": "Alabaster City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019001183",
    },
    {
        "school": "Thompson Middle School",
        "district": "Alabaster City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019001184",
    },
    {
        "school": "Meadow View  Elementary School",
        "district": "Alabaster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019001460",
    },
    {
        "school": "Creek View Elementary School",
        "district": "Alabaster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019001815",
    },
    {
        "school": "FRONTIER ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059002766",
    },
    {
        "school": "MCGREGOR PRI",
        "district": "MCGREGOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482982012948",
    },
    {
        "school": "DR LINDA HENRIE EL",
        "district": "MESQUITE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039013041",
    },
    {
        "school": "Career Preparation",
        "district": "Novi Community School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262613008494",
    },
    {
        "school": "Oak Park Virtual Academy",
        "district": "Oak Park School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262619008452",
    },
    {
        "school": "Portage Partnering Preschool",
        "district": "Portage Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551206002945",
    },
    {
        "school": "Mighty River Academy of Virtual Education",
        "district": "Prairie du Chien Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551215002944",
    },
    {
        "school": "HOMINY EARLY CHILDHOOD CENTER",
        "district": "HOMINY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401497002783",
    },
    {
        "school": "HUGO ES",
        "district": "HUGO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401521002768",
    },
    {
        "school": "HUGO INTERMEDIATE",
        "district": "HUGO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401521002774",
    },
    {
        "school": "MULLIN OAKS",
        "district": "MULLIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483192013019",
    },
    {
        "school": "PECAN RIDGE H S",
        "district": "MULLIN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483192013057",
    },
    {
        "school": "Veritas",
        "district": "Redford Union Schools District No. 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262946008560",
    },
    {
        "school": "D C Everest 4K Community Partnership",
        "district": "D C Everest Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317002963",
    },
    {
        "school": "W B BIZZELL ACADEMY",
        "district": "NAVASOTA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483219012965",
    },
    {
        "school": "Hedgepeth Williams Middle School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003267",
    },
    {
        "school": "Sandusky Elementary School",
        "district": "Sandusky Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263084008424",
    },
    {
        "school": "MUSTANG HORIZON IES",
        "district": "MUSTANG",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100002767",
    },
    {
        "school": "CANYON RIDGE IES",
        "district": "MUSTANG",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100002782",
    },
    {
        "school": "ELLISON EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012911",
    },
    {
        "school": "BERNAL MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012944",
    },
    {
        "school": "HARLAN H S",
        "district": "NORTHSIDE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012985",
    },
    {
        "school": "BOLDT EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312012989",
    },
    {
        "school": "MORA EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312013050",
    },
    {
        "school": "Horizon Science Acad-McKinley Pk",
        "district": "Horizon Science Acad-McKinley Pk",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141006254",
    },
    {
        "school": "East Coloma - Nelson Elem Sch",
        "district": "East Coloma - Nelson CESD 20",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141106256",
    },
    {
        "school": "Horizon Science Acad-Belmont",
        "district": "Horizon Science Acad-Belmont",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141206309",
    },
    {
        "school": "Abingdon-Avon Middle Sch",
        "district": "Abingdon-Avon CUSD 276",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141306247",
    },
    {
        "school": "Abingdon-Avon High Sch",
        "district": "Abingdon-Avon CUSD 276",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141306274",
    },
    {
        "school": "Avon Elem Sch",
        "district": "Abingdon-Avon CUSD 276",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141306276",
    },
    {
        "school": "Hedding Grade Sch",
        "district": "Abingdon-Avon CUSD 276",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141306296",
    },
    {
        "school": "Paakuma K-8",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417013674",
    },
    {
        "school": "San Bernardino City Community Day",
        "district": "San Bernardino City Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63417013680",
    },
    {
        "school": "H. Frank Dominguez Elementary",
        "district": "San Bernardino City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63417013699",
    },
    {
        "school": "Journey",
        "district": "Ripon Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551302002978",
    },
    {
        "school": "TAVOLA EL",
        "district": "NEW CANEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240012930",
    },
    {
        "school": "NEW CANEY MIDDLE",
        "district": "NEW CANEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240012981",
    },
    {
        "school": "INFINITY EARLY COLLEGE H S",
        "district": "NEW CANEY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240013059",
    },
    {
        "school": "Excel Academy - Englewood HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006249",
    },
    {
        "school": "Disney II Magnet HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006250",
    },
    {
        "school": "Little Black Pearl Arts Acad HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006257",
    },
    {
        "school": "Crane Medical Prep HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006260",
    },
    {
        "school": "Back of The Yards IB HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006282",
    },
    {
        "school": "Chicago Collegiate Charter School",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006285",
    },
    {
        "school": "Intrinsic Charter High School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006293",
    },
    {
        "school": "Camelot Safe Academy School",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006297",
    },
    {
        "school": "Frazier Prep Acad Charter ES",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006306",
    },
    {
        "school": "Christopher House Chrt ES",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006311",
    },
    {
        "school": "CCSD 93 Early Childhood Cntr",
        "district": "CCSD 93",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171047006290",
    },
    {
        "school": "Three Lakes Junior High",
        "district": "Three Lakes School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551485002954",
    },
    {
        "school": "Viroqua Area Montessori School",
        "district": "Viroqua Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551536002972",
    },
    {
        "school": "Endeavor Charter School",
        "district": "Watertown Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551575002981",
    },
    {
        "school": "WAY South Haven",
        "district": "South Haven Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263230008492",
    },
    {
        "school": "University Middle School Academy",
        "district": "Southfield Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263231008426",
    },
    {
        "school": "ASPIRE Leadership Academy",
        "district": "Southfield Public School District",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263231008576",
    },
    {
        "school": "POND CREEK-HUNTER MS",
        "district": "POND CREEK-HUNTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402472002764",
    },
    {
        "school": "Hollywood Heights",
        "district": "Collinsville CUSD 10",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171065006302",
    },
    {
        "school": "THOMAS HANCOCK EL",
        "district": "PASADENA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432012958",
    },
    {
        "school": "Little Rails Early Learning",
        "district": "Spooner Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551422002956",
    },
    {
        "school": "St Charles Virtual School",
        "district": "St. Charles Community Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263264008549",
    },
    {
        "school": "Tecumseh Virtual Academy",
        "district": "Tecumseh Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263372008469",
    },
    {
        "school": "PANAMA ES",
        "district": "PANAMA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402337002780",
    },
    {
        "school": "Kenneth D Bailey Academy",
        "district": "Danville CCSD 118",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179006288",
    },
    {
        "school": "Waukesha Transition Academy",
        "district": "Waukesha School District",
        "level": "High",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "551578002960",
    },
    {
        "school": "Haggerty School",
        "district": "Van Buren Public Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263456008486",
    },
    {
        "school": "DEARING EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483012957",
    },
    {
        "school": "Notch Peak Elementary",
        "district": "Albany County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560073000550",
    },
    {
        "school": "Douglas Intermediate School",
        "district": "Converse County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560214000553",
    },
    {
        "school": "Middle School Mathematics Science Technology Center",
        "district": "Warren Consolidated Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519008550",
    },
    {
        "school": "Macomb Math Science Technology Center",
        "district": "Warren Consolidated Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263519008566",
    },
    {
        "school": "Academy West Alternative Education",
        "district": "Westwood Heights Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263597008491",
    },
    {
        "school": "Ypsilanti Community Middle School",
        "district": "Ypsilanti Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263663001709",
    },
    {
        "school": "Holmes Elementary",
        "district": "Ypsilanti Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263663007233",
    },
    {
        "school": "Park Crossing High School",
        "district": "Montgomery County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10243002214",
    },
    {
        "school": "ECADEMY VIRTUAL HIGH SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001099",
    },
    {
        "school": "COLLEGE AND CAREER HIGH SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001100",
    },
    {
        "school": "NEW MEXICO CONNECTIONS ACADEMY",
        "district": "NEW MEXICO CONNECTIONS ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350016001096",
    },
    {
        "school": "TAOS INTERNATIONAL SCHOOL",
        "district": "TAOS INTERNATIONAL SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350016301094",
    },
    {
        "school": "Ford Early Learning Center",
        "district": "Ypsilanti Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263663008220",
    },
    {
        "school": "ACTech High School",
        "district": "Ypsilanti Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263663008476",
    },
    {
        "school": "Washtenaw International Middle Academy",
        "district": "Ypsilanti Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263663008534",
    },
    {
        "school": "Ypsilanti STEMM Middle College",
        "district": "Ypsilanti Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263663008572",
    },
    {
        "school": "Project SEARCH",
        "district": "Ingham ISD",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268052008522",
    },
    {
        "school": "Ingham ISD ASD Programs",
        "district": "Ingham ISD",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268052008551",
    },
    {
        "school": "Early College at Montcalm Community College",
        "district": "Montcalm Area ISD",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268083008434",
    },
    {
        "school": "Progress Park",
        "district": "Washtenaw ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268099000277",
    },
    {
        "school": "Washtenaw Deaf and Hard of Hearing Program",
        "district": "Washtenaw ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268099008435",
    },
    {
        "school": "Lincoln School",
        "district": "Hawthorn CCSD 73",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171857006295",
    },
    {
        "school": "Ft. Washakie High School",
        "district": "Fremont County School District #21",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560282000552",
    },
    {
        "school": "CORONADO MIDDLE",
        "district": "PLAINVIEW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483507012968",
    },
    {
        "school": "ESTACADO MIDDLE",
        "district": "PLAINVIEW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483507012978",
    },
    {
        "school": "GARZA COUNTY REGIONAL JUVENILE CENTER",
        "district": "POST ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483549012914",
    },
    {
        "school": "W D GATTIS MIDDLE SCHOOL",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057001097",
    },
    {
        "school": "Saint Stephen's Indian School",
        "district": "Saint Stephen's Indian School Admin Office",
        "level": "Other",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "568025400549",
    },
    {
        "school": "PROSPER DAEP",
        "district": "PROSPER ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600012929",
    },
    {
        "school": "Big Sandy Elementary",
        "district": "Tuscaloosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10339002350",
    },
    {
        "school": "MN RIVER VALLEY ED-ONLINE LEARNING",
        "district": "MN RIVER VALLEY EDUCATION DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270005804709",
    },
    {
        "school": "ASD PROGRAM",
        "district": "MN VALLEY EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270006304710",
    },
    {
        "school": "PROJECT SEARCH-AVERA MARSHALL",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270008604723",
    },
    {
        "school": "SWWC ELC - Willmar",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270008604724",
    },
    {
        "school": "KMS LEARNING CENTER",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270008604725",
    },
    {
        "school": "MINNESOTA NEW COUNTRY ELEMENTARY",
        "district": "MINNESOTA NEW COUNTRY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270009204748",
    },
    {
        "school": "BILLIE STEVENSON EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765013047",
    },
    {
        "school": "VETERANS MEMORIAL EL",
        "district": "ROMA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483774012938",
    },
    {
        "school": "Cordova School District Innovative Learning",
        "district": "Cordova City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20006000750",
    },
    {
        "school": "HIGHER GROUND SECONDARY ACADEMY",
        "district": "HIGHER GROUND ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270014004749",
    },
    {
        "school": "LA CRESCENT SEC MONTESSORI/STEM",
        "district": "LA CRESCENT MONTESSORI & STEM SCHOO",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270017804750",
    },
    {
        "school": "AVALON MIDDLE SCHOOL",
        "district": "AVALON SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018704664",
    },
    {
        "school": "Hiawatha Leadership Acdy-Northrop",
        "district": "HIAWATHA ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028804669",
    },
    {
        "school": "RTR ALP",
        "district": "RTR PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270029404732",
    },
    {
        "school": "Kids Unlimited Academy",
        "district": "Medford SD 549C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804001829",
    },
    {
        "school": "RUM RIVER EAST EDUCATION PROGRAM",
        "district": "RUM RIVER SPECIAL EDUCATION COOP",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270031804708",
    },
    {
        "school": "GREAT RIVER ELEMENTARY SCHOOL",
        "district": "GREAT RIVER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034404665",
    },
    {
        "school": "TREK NORTH MIDDLE SCHOOL",
        "district": "TREKNORTH HIGH SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034504666",
    },
    {
        "school": "VOYAGEURS EXPEDITIONARY MS",
        "district": "VOYAGEURS EXPEDITIONARY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034604667",
    },
    {
        "school": "Kaleidoscope Charter High School",
        "district": "KALEIDOSCOPE CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036004668",
    },
    {
        "school": "UPPER MISSISSIPPI MIDDLE ACADEMY",
        "district": "UPPER MISSISSIPPI ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270037604693",
    },
    {
        "school": "UPPER MISSISSIPPI HIGH ACADEMY",
        "district": "UPPER MISSISSIPPI ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270037604694",
    },
    {
        "school": "BRANDON ELEMENTARY",
        "district": "BRANDON-EVANSVILLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038204738",
    },
    {
        "school": "EVANSVILLE ELEMENTARY",
        "district": "BRANDON-EVANSVILLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038204739",
    },
    {
        "school": "BRANDON-EVANSVILLE MIDDLE SCHOOL",
        "district": "BRANDON-EVANSVILLE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038204740",
    },
    {
        "school": "BRANDON-EVANSVILLE HIGH SCHOOL",
        "district": "BRANDON-EVANSVILLE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038204741",
    },
    {
        "school": "MORRIS AREA SECONDARY",
        "district": "MORRIS AREA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038304728",
    },
    {
        "school": "MORRIS AREA ELEMENTARY",
        "district": "MORRIS AREA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038304729",
    },
    {
        "school": "VENTURE ACADEMY",
        "district": "VENTURE ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038404697",
    },
    {
        "school": "RLCC ELEMENTARY AT OKLEE",
        "district": "RED LAKE COUNTY CENTRAL PUBLIC SCH",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038504733",
    },
    {
        "school": "RED LAKE COUNTY CENTRAL ELEMENTARY",
        "district": "RED LAKE COUNTY CENTRAL PUBLIC SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038504734",
    },
    {
        "school": "RED LAKE COUNTY CENTRAL HIGH SCHOOL",
        "district": "RED LAKE COUNTY CENTRAL PUBLIC SCH",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038504735",
    },
    {
        "school": "SEJONG ACADEMY OF MINNESOTA",
        "district": "SEJONG ACADEMY OF MINNESOTA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038604695",
    },
    {
        "school": "ROUND LAKE-BREWSTER ELEMENTARY",
        "district": "ROUND LAKE-BREWSTER PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038804736",
    },
    {
        "school": "Round Lake-Brewster Middle School",
        "district": "ROUND LAKE-BREWSTER PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038804737",
    },
    {
        "school": "DREAM TECHNICAL ACADEMY",
        "district": "TECHNICAL ACADEMIES OF MINNESOTA",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038904696",
    },
    {
        "school": "STAR OF THE NORTH ACADEMY CHARTER S",
        "district": "STAR OF THE NORTH ACADEMY CHARTER S",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039004759",
    },
    {
        "school": "DISCOVERY CHARTER ELEMENTARY SCHOOL",
        "district": "DISCOVERY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039104764",
    },
    {
        "school": "UNIVERSAL ACADEMY CHARTER SCHOOL",
        "district": "UNIVERSAL ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039304758",
    },
    {
        "school": "AGAMIM CLASSICAL ACADEMY",
        "district": "AGAMIM CLASSICAL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039404751",
    },
    {
        "school": "SAINT CLOUD MATH AND SCIENCE ACADEM",
        "district": "SAINT CLOUD MATH AND SCIENCE ACADEM",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039504752",
    },
    {
        "school": "BDOTE LEARNING CENTER",
        "district": "BDOTE LEARNING CENTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039604763",
    },
    {
        "school": "ART AND SCIENCE ACADEMY",
        "district": "ART AND SCIENCE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039704766",
    },
    {
        "school": "NORTHEAST COLLEGE PREP CHARTER SCHO",
        "district": "NORTHEAST COLLEGE PREP",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039804757",
    },
    {
        "school": "METRO HEIGHTS ACADEMY",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270226404746",
    },
    {
        "school": "UNADILLA VALLEY ELEMENTARY SCHOOL",
        "district": "UNADILLA VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360001906369",
    },
    {
        "school": "Heritage Academy Queen Creek",
        "district": "Heritage Academy Inc. (4336)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40005303402",
    },
    {
        "school": "Benjamin Franklin High School",
        "district": "Benjamin Franklin Charter School - Queen Creek (4355)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40006503395",
    },
    {
        "school": "STEP AHEAD HIGH SCHOOL",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318004654",
    },
    {
        "school": "American Leadership Academy Anthem K-6",
        "district": "American Leadership Academy Inc. (4348)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011203365",
    },
    {
        "school": "Glenview College Preparatory High School",
        "district": "Kaizen Education Foundation dba El Dorado High Sch (4342)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40014903386",
    },
    {
        "school": "Mexicayotl Academy",
        "district": "Mexicayotl Academy Inc. (4463)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40015003403",
    },
    {
        "school": "RIVER SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706371",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL FOR EMERGENCY MANAGEMENT (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007706372",
    },
    {
        "school": "STEPHEN T MATHER BUILDING ARTS AND CRAFTMANSHIP HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007706373",
    },
    {
        "school": "PINES SCHOOL - ACS",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270810004655",
    },
    {
        "school": "PINES SCHOOL - NSP",
        "district": "CENTENNIAL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270810004656",
    },
    {
        "school": "DEER RIVER SCHOOLS SPED",
        "district": "DEER RIVER PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271014004672",
    },
    {
        "school": "DOS PUENTES ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008306381",
    },
    {
        "school": "MISSION RIDGE",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071012963",
    },
    {
        "school": "ACADEMY OF CHOICE",
        "district": "SPRING BRANCH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484110012995",
    },
    {
        "school": "MEMORIAL MIDDLE SCHOOL",
        "district": "ELY PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271152004645",
    },
    {
        "school": "PELHAM LAB HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506386",
    },
    {
        "school": "SCHUYLERVILLE PREPARATORY HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506387",
    },
    {
        "school": "BRONX RIVER HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506388",
    },
    {
        "school": "NEW AMERICAN ACADEMY AT ROBERTO CLEMENTE STATE PARK (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606391",
    },
    {
        "school": "WALTON AVENUE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606392",
    },
    {
        "school": "LUCERO ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606393",
    },
    {
        "school": "HIGHBRIDGE GREEN SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606394",
    },
    {
        "school": "NEW DIRECTIONS SECONDARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606395",
    },
    {
        "school": "Wood-Ridge Intermediate School",
        "district": "Wood-Ridge School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341830003257",
    },
    {
        "school": "William Roper Early Childhood Learning Center",
        "district": "Woodstown-Pilesgrove Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341833003250",
    },
    {
        "school": "CIBOLO VALLEY EL",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483948012975",
    },
    {
        "school": "Ukiah Independent Study Academy",
        "district": "Ukiah Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64030013714",
    },
    {
        "school": "Union Hill Middle",
        "district": "Union Hill Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64038013728",
    },
    {
        "school": "BOLD ALC",
        "district": "BIRD ISLAND-OLIVIA-LAKE LILLIAN",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270566004726",
    },
    {
        "school": "Canyon View Prep Academy",
        "district": "Park View School Inc. (10970)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40020903364",
    },
    {
        "school": "SHARYLAND ADVANCED ACADEMIC ACADEMY",
        "district": "SHARYLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483993013048",
    },
    {
        "school": "CTD - Bisbee High School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034503384",
    },
    {
        "school": "CTD - Buena High School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034503390",
    },
    {
        "school": "EAGLE ACADEMY FOR YOUNG MEN OF HARLEM",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008106379",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL FOR GLOBAL COMMERCE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 5",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360008106380",
    },
    {
        "school": "Dillard Alternative High School",
        "district": "Winston-Dillard SD 116",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "411349001828",
    },
    {
        "school": "Desert Heights Preparatory Academy",
        "district": "Desert Heights Charter Schools (81099)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40061003363",
    },
    {
        "school": "CONCOURSE VILLAGE ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008406382",
    },
    {
        "school": "HERO HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360008406383",
    },
    {
        "school": "MINERAL WELLS/PALO PINTO COUNTY DAEP",
        "district": "STRAWN ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484170012949",
    },
    {
        "school": "Universal Alcorn CS",
        "district": "Universal Alcorn CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420087207491",
    },
    {
        "school": "Premier Arts and Science Charter School",
        "district": "Premier Arts and Science Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420087307504",
    },
    {
        "school": "Mastery CS-Francis D. Pastorius Elementa",
        "district": "Mastery CS-Francis D. Pastorius Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420087407515",
    },
    {
        "school": "Circle of Seasons Charter School",
        "district": "Circle of Seasons Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420087507507",
    },
    {
        "school": "Capital Area School for the Arts Charter",
        "district": "Capital Area School for the Arts Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420087607493",
    },
    {
        "school": "Penn-Lincoln El Sch",
        "district": "Altoona Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420234007486",
    },
    {
        "school": "Belle Vernon Area MS",
        "district": "Belle Vernon Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420321007513",
    },
    {
        "school": "OAKCREST INT",
        "district": "TOMBALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296012993",
    },
    {
        "school": "CREEKSIDE PARK J H",
        "district": "TOMBALL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296012997",
    },
    {
        "school": "CREEKVIEW EL",
        "district": "TOMBALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296013029",
    },
    {
        "school": "WILDWOOD EL",
        "district": "TOMBALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296013049",
    },
    {
        "school": "Clearlake Creativity",
        "district": "Lake County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69101413724",
    },
    {
        "school": "Come Back Kids",
        "district": "Riverside County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102613694",
    },
    {
        "school": "San Diego County Community",
        "district": "San Diego County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103013682",
    },
    {
        "school": "San Diego County Court",
        "district": "San Diego County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69103013693",
    },
    {
        "school": "Legacy Traditional School ? Gilbert",
        "district": "Legacy Traditional School - Gilbert (92047)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089903392",
    },
    {
        "school": "Great Hearts Academies - Cicero Prep",
        "district": "Cicero Preparatory Academy (92316)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40090003404",
    },
    {
        "school": "TEAGUE LION ACADEMY",
        "district": "TEAGUE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484230013009",
    },
    {
        "school": "HILL CITY MIDDLE SCHOOL",
        "district": "HILL CITY PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271401004653",
    },
    {
        "school": "XINXING ACADEMY",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271426004662",
    },
    {
        "school": "West-MEC - West View High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503366",
    },
    {
        "school": "West-MEC - La Joya High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503371",
    },
    {
        "school": "West-MEC - Sierra Linda High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503372",
    },
    {
        "school": "West-MEC - Tolleson Union High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503373",
    },
    {
        "school": "West-MEC - Copper Canyon High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503391",
    },
    {
        "school": "Edkey Inc. - Pathfinder Academy - Sequoia Lehi",
        "district": "Edkey Inc. - Pathfinder Academy (81045)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40063803360",
    },
    {
        "school": "BRONX ACADEMY FOR SOFTWARE ENGINEERING (BASE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360008706396",
    },
    {
        "school": "BRONX COLLABORATIVE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008706397",
    },
    {
        "school": "C. E. Murray Middle",
        "district": "Williamsburg 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450378001624",
    },
    {
        "school": "Kansas Virtual Academy (KSVA)",
        "district": "Spring Hill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201185002068",
    },
    {
        "school": "Wolf Creek Elementary School",
        "district": "Spring Hill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201185002072",
    },
    {
        "school": "RICHMOND CAREER EDUCATION & EMPLOYMENT (CHARTER SCHOOL)",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324002966",
    },
    {
        "school": "Bridges Preparatory School",
        "district": "SC Public Charter School District",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101617",
    },
    {
        "school": "Pee Dee Math Science and Technology Academy",
        "district": "SC Public Charter School District",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101619",
    },
    {
        "school": "GREEN Charter School",
        "district": "SC Public Charter School District",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101620",
    },
    {
        "school": "Academy for Careers and Technology",
        "district": "Marion 10",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450390800767",
    },
    {
        "school": "SWEENY ELEMENTARY",
        "district": "REPUBLIC R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292622003234",
    },
    {
        "school": "The Expedition School",
        "district": "The Expedition School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370035403319",
    },
    {
        "school": "NCVPS",
        "district": "NC Virtual Public School",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370035503306",
    },
    {
        "school": "Bradford Preparatory School",
        "district": "Bradford Preparatory School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370035603329",
    },
    {
        "school": "Cardinal Charter Academy",
        "district": "Cardinal Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370035803325",
    },
    {
        "school": "Pioneer Springs Community School",
        "district": "Pioneer Springs Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370035903337",
    },
    {
        "school": "Adair County Primary Center",
        "district": "Adair County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210003002345",
    },
    {
        "school": "APEX Academy",
        "district": "Anderson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210012002371",
    },
    {
        "school": "Bardstown Alternative School",
        "district": "Bardstown Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210027002359",
    },
    {
        "school": "Paducah Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902040",
    },
    {
        "school": "Garrard County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902042",
    },
    {
        "school": "Spring Lake Colony High School - 05",
        "district": "Oldham - Ramona School District 39-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460102701339",
    },
    {
        "school": "The Franklin School of Innovation",
        "district": "The Franklin School of Innovation",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036103332",
    },
    {
        "school": "Envision Science Academy",
        "district": "Envision Science Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036203331",
    },
    {
        "school": "Reaching All Minds Academy",
        "district": "Reaching All Minds Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036303346",
    },
    {
        "school": "Wake Forest Charter Academy",
        "district": "Wake Forest Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036403326",
    },
    {
        "school": "Three Rivers Academy",
        "district": "Three Rivers Academy (fka Heritage Coll)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036503328",
    },
    {
        "school": "United Community School",
        "district": "United Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036703327",
    },
    {
        "school": "WORLD VIEW HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008706398",
    },
    {
        "school": "BRONX ALLIANCE MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806399",
    },
    {
        "school": "YOUNG VOICES ACADEMY OF THE BRONX",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806400",
    },
    {
        "school": "CALVIN VINCENT PRE-K HEAD START",
        "district": "TEXAS CITY ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251012983",
    },
    {
        "school": "The Odyssey Preparatory Academy - Sienna Hills",
        "district": "The Odyssey Preparatory Academy Inc. (90287)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40080003368",
    },
    {
        "school": "Scottsdale Country Day School",
        "district": "Scottsdale Country Day School (91110)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40087903400",
    },
    {
        "school": "Southwest Leadership Academy",
        "district": "Southwest Leadership Academy (92043)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40088003398",
    },
    {
        "school": "BASIS Phoenix Central Primary",
        "district": "BASIS Charter Schools Inc. (92349)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40088103394",
    },
    {
        "school": "South Mountain Preparatory Academy",
        "district": "Kaizen Education Foundation dba Advance U (91329)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40088203409",
    },
    {
        "school": "Great Hearts Academies - Archway Cicero",
        "district": "Archway Classical Academy Cicero (92314)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40088603407",
    },
    {
        "school": "ASU Preparatory Academy - Phoenix Middle School",
        "district": "ASU Preparatory Academy (92325)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089003367",
    },
    {
        "school": "Academy of Mathematics and Science South",
        "district": "Academy of Mathematics and Science South Inc. (90878)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089103399",
    },
    {
        "school": "Hirsch Academy A Challenge Foundation",
        "district": "Hirsch Academy A Challenge Foundation (91275)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089303382",
    },
    {
        "school": "Desert Mirage Preparatory Academy",
        "district": "Kaizen Education Foundation dba Discover U Element (91328)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089403379",
    },
    {
        "school": "Reyes Maria Ruiz Leadership Academy",
        "district": "Espiritu Community Development Corp. (92250)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089502450",
    },
    {
        "school": "BASIS Ahwatukee",
        "district": "BASIS Charter Schools Inc. (91339)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089703376",
    },
    {
        "school": "BASIS Mesa",
        "district": "BASIS Charter Schools Inc. (91949)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089803393",
    },
    {
        "school": "FAIRMONT NEIGHBORHOOD SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006401",
    },
    {
        "school": "MAURICE SENDAK COMMUNITY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009206406",
    },
    {
        "school": "SUNSET PARK AVENUES ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009206407",
    },
    {
        "school": "Carmichael Elementary Preschool",
        "district": "Sierra Vista Unified District (4175)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40146003380",
    },
    {
        "school": "Southview Preschool Center",
        "district": "Anderson Community School Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180015002557",
    },
    {
        "school": "HOWE ELEMENTARY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004742",
    },
    {
        "school": "Brown County Intermediate School",
        "district": "Brown County School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180096002556",
    },
    {
        "school": "Brownsburg Early Childhood Center",
        "district": "Brownsburg Community School Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180102002562",
    },
    {
        "school": "NEW BRIDGES ELEMENTARY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009506409",
    },
    {
        "school": "ELM TREE ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806430",
    },
    {
        "school": "CORONA ARTS AND SCIENCES ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806431",
    },
    {
        "school": "INTERNATIONAL HIGH SCHOOL FOR HEALTH SCIENCES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806432",
    },
    {
        "school": "MAPLETON EARLY CHILDHOOD CENTER",
        "district": "Boulder Valley School District No. Re2",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249006571",
    },
    {
        "school": "BOLT ACADEMY",
        "district": "School District 27J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006575",
    },
    {
        "school": "NEW CONNECTIONS",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273239004661",
    },
    {
        "school": "SPECIAL SERVICES",
        "district": "SHAKOPEE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273300004646",
    },
    {
        "school": "EMERSON SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006438",
    },
    {
        "school": "QUEENS UNITED MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010106439",
    },
    {
        "school": "INSTITUTE FOR HEALTH PROFESSIONS AT CAMBRIA HEIGHTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360010106440",
    },
    {
        "school": "HUNTERS POINT COMMUNITY MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010206441",
    },
    {
        "school": "EAST ELMHURST COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010206442",
    },
    {
        "school": "ENERGY TECH HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360010206443",
    },
    {
        "school": "Santa Rosa Preschool",
        "district": "Maricopa Unified School District (4441)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40472003378",
    },
    {
        "school": "Saddleback Preschool",
        "district": "Maricopa Unified School District (4441)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40472003396",
    },
    {
        "school": "ELEMENTARY LIGHTHOUSE",
        "district": "SPRING LAKE PARK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273333004657",
    },
    {
        "school": "SECONDARY LIGHTHOUSE",
        "district": "SPRING LAKE PARK PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273333004658",
    },
    {
        "school": "Roosevelt Education Center",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273351004648",
    },
    {
        "school": "ST CLOUD HOSPITAL PROGS-RESIDENTIAL",
        "district": "ST. CLOUD PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273351004649",
    },
    {
        "school": "PLACE",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273381004652",
    },
    {
        "school": "THE VANGUARD SCHOOL (HIGH)",
        "district": "Cheyenne Mountain School District No. 12 in the county of E",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80294006370",
    },
    {
        "school": "THE VANGUARD SCHOOL (MIDDLE)",
        "district": "Cheyenne Mountain School District No. 12 in the county of E",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80294006402",
    },
    {
        "school": "ODYSSEY EARLY COLLEGE AND CAREER OPTIONS",
        "district": "Colorado Springs School District No. 11 in the county of E",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80306006580",
    },
    {
        "school": "Melrose Sch",
        "district": "Harrisburg City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158007483",
    },
    {
        "school": "Camp Curtin Academy",
        "district": "Harrisburg City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158007485",
    },
    {
        "school": "Downey Sch",
        "district": "Harrisburg City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158007488",
    },
    {
        "school": "Marshall Academy",
        "district": "Harrisburg City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158007498",
    },
    {
        "school": "Benjamin Franklin Sch",
        "district": "Harrisburg City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158007501",
    },
    {
        "school": "Frontier Middle School",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001454",
    },
    {
        "school": "NAPLES STREET ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306444",
    },
    {
        "school": "HARBOR VIEW SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306445",
    },
    {
        "school": "BROOKLYN GARDENS ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006416",
    },
    {
        "school": "VAN SICLEN COMMUNITY MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006417",
    },
    {
        "school": "VISTA ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006418",
    },
    {
        "school": "LIBERTY AVENUE MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006419",
    },
    {
        "school": "SCHOOL OF THE FUTURE BROOKLYN",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006420",
    },
    {
        "school": "Jordan Center for Early Education",
        "district": "Mesa Unified District (4235)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40497003377",
    },
    {
        "school": "Fairbanks Middle School",
        "district": "Morenci Unified District (4230)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40532003369",
    },
    {
        "school": "CREATIVE ARTS SECONDARY SCHOOL",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384004680",
    },
    {
        "school": "PARKWAY MONTESSORI/COMMUNITY MIDDLE",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384004681",
    },
    {
        "school": "L'ETOILE DU NORD FRENCH IMMERSION L",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384004682",
    },
    {
        "school": "JIE MING MANDARIN IMMERSION ACADEMY",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384004683",
    },
    {
        "school": "NOKOMIS MONTESSORI SOUTH CAMPUS",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384004684",
    },
    {
        "school": "EARLY EDUCATION COMO",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384004685",
    },
    {
        "school": "EARLY EDUCATION FOUR SEASONS",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384004686",
    },
    {
        "school": "EARLY EDUCATION HEIGHTS COMM",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384004687",
    },
    {
        "school": "ALC Online School",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384004692",
    },
    {
        "school": "WAUBUN ALC",
        "district": "WAUBUN-OGEMA-WHITE EARTH PUBLIC SCH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274212004754",
    },
    {
        "school": "George Washington Carver School 87",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002555",
    },
    {
        "school": "Kiski Area Upper El Sch",
        "district": "Kiski Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421284007487",
    },
    {
        "school": "Dixie Montessori Academy",
        "district": "Dixie Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490016901452",
    },
    {
        "school": "Scholar Academy",
        "district": "Scholar Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017001456",
    },
    {
        "school": "Utah Career Path High School",
        "district": "Utah Career Path High School",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017101460",
    },
    {
        "school": "Ascent Academies of Utah Farmington",
        "district": "Ascent Academies of Utah",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017401453",
    },
    {
        "school": "Mountain West Montessori Academy",
        "district": "Mountain West Montessori Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017501455",
    },
    {
        "school": "Line Mountain MS",
        "district": "Line Mountain SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421446007494",
    },
    {
        "school": "BROOKLYN LANDMARK ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012106426",
    },
    {
        "school": "BROOKLYN ENVIRONMENTAL EXPLORATION SCHOOL (BEES)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012106427",
    },
    {
        "school": "RIVERDALE AVENUE MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #23",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012106428",
    },
    {
        "school": "VERITAS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012206434",
    },
    {
        "school": "QUEENS HIGH SCHOOL FOR LANGUAGE STUDIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012206435",
    },
    {
        "school": "HAWTREE CREEK MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306436",
    },
    {
        "school": "VOYAGES PREP-SOUTH QUEENS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306437",
    },
    {
        "school": "Gila Valley Learning Center",
        "district": "Pima Unified District (4220)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40644003362",
    },
    {
        "school": "Mid Valley Secondary Center",
        "district": "Mid Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421517007518",
    },
    {
        "school": "PRAIRIE LAKES EDUCATION CENTER",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274272004673",
    },
    {
        "school": "LAKE PARK SCHOOL",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274272004674",
    },
    {
        "school": "WORTHINGTON 518 (VIRTUAL INSTRUCT",
        "district": "WORTHINGTON PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274416004676",
    },
    {
        "school": "ZUMBROTA-MAZEPPA PRIMARY SCHOOL",
        "district": "ZUMBROTA-MAZEPPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274573504730",
    },
    {
        "school": "EC & HK SUMMER",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279144304711",
    },
    {
        "school": "Pathways Program Grades 6-7",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279144304717",
    },
    {
        "school": "CANNON FALLS ALC HIGH SCHOOL",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279144304718",
    },
    {
        "school": "TOWER VIEW ALTERNATIVE HIGH SCHOOL",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279144304719",
    },
    {
        "school": "Zumbrota-Mazeppa Credit Recovery",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279144304721",
    },
    {
        "school": "ISABEL ALVARADO ALVARADO",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001932",
    },
    {
        "school": "DENVER MONTESSORI JUNIOR/SENIOR HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006568",
    },
    {
        "school": "NORTH HIGH SCHOOL ENGAGEMENT CENTER",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006569",
    },
    {
        "school": "ISABELLA BIRD COMMUNITY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006570",
    },
    {
        "school": "DSST: BYERS MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006572",
    },
    {
        "school": "DENVER CENTER FOR INTERNATIONAL STUDIES AT FAIRMON",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006574",
    },
    {
        "school": "STRIVE PREP - EXCEL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006576",
    },
    {
        "school": "PASCUAL LEDOUX ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006582",
    },
    {
        "school": "COMPASSION ROAD ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006583",
    },
    {
        "school": "DOWNTOWN DENVER EXPEDITIONARY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006584",
    },
    {
        "school": "RESPECT ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006590",
    },
    {
        "school": "MONTBELLO CAREER AND TECHNICAL HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006591",
    },
    {
        "school": "ACADEMY 360",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006592",
    },
    {
        "school": "EXCEL ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006599",
    },
    {
        "school": "New Castle JHS",
        "district": "New Castle Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421662007480",
    },
    {
        "school": "HOPE ONLINE LEARNING ACADEMY ELEMENTARY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006577",
    },
    {
        "school": "HOPE ONLINE LEARNING ACADEMY MIDDLE SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006578",
    },
    {
        "school": "ASPEN VIEW ACADEMY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006588",
    },
    {
        "school": "DURANGO BIG PICTURE HIGH SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80348006597",
    },
    {
        "school": "PRAIRIE HARBOR ALTERNATIVE SCHOOL",
        "district": "BRAZOS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484447013001",
    },
    {
        "school": "Rockville Elementary School",
        "district": "North Central Parke Comm Schl Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180011801578",
    },
    {
        "school": "Turkey Run Elementary School",
        "district": "North Central Parke Comm Schl Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180011801857",
    },
    {
        "school": "Inspire Academy - A Sch of Inquiry",
        "district": "Inspire Academy - A Sch of Inquiry",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180012302560",
    },
    {
        "school": "Phalen Leadership Academy - IN Inc",
        "district": "Phalen Leadership Academy - IN Inc",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180012402550",
    },
    {
        "school": "Excel Center - Richmond",
        "district": "Excel Center - Richmond",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180013402549",
    },
    {
        "school": "Excel Center - Kokomo",
        "district": "Excel Center - Kokomo",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180013502553",
    },
    {
        "school": "Enlace Academy",
        "district": "Enlace Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180013702551",
    },
    {
        "school": "Excel Center - Lafayette Square",
        "district": "Excel Center - Lafayette Square",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180013802554",
    },
    {
        "school": "Excel Center - Lafayette",
        "district": "Excel Center - Lafayette",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180014202548",
    },
    {
        "school": "Avondale Middle School",
        "district": "Avondale Elementary District (4272)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096003387",
    },
    {
        "school": "Orangedale Early Learning Center",
        "district": "Balsz Elementary District (4268)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40105003374",
    },
    {
        "school": "Sawtooth Ridge Community",
        "district": "Mono County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69105213701",
    },
    {
        "school": "TIOGA Community",
        "district": "Mono County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69105213710",
    },
    {
        "school": "OPTIONS",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272295004678",
    },
    {
        "school": "NICOLLET MIDDLE SCHOOL",
        "district": "NICOLLET PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272358004675",
    },
    {
        "school": "STEM at Showalter",
        "district": "Chester-Upland SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420586007499",
    },
    {
        "school": "Toby Farms Intermediate School",
        "district": "Chester-Upland SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420586007510",
    },
    {
        "school": "Mountain Vista Academy",
        "district": "Florence Unified School District (4437)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40292003389",
    },
    {
        "school": "Daniel Boone Area Intermediate Cntr",
        "district": "Daniel Boone Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420729007519",
    },
    {
        "school": "VICTORY PREPARATORY ACADEMY MIDDLE STATE CHARTER S",
        "district": "State Charter School Institute",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006579",
    },
    {
        "school": "VICTORY PREPARATORY ACADEMY HIGH STATE CHARTER SCH",
        "district": "State Charter School Institute",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006585",
    },
    {
        "school": "Colorado International Language Academy",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006586",
    },
    {
        "school": "MOUNTAIN SONG COMMUNITY SCHOOL",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006589",
    },
    {
        "school": "JAMES IRWIN CHARTER ACADEMY",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006595",
    },
    {
        "school": "COLORADO PREPARATORY ACADEMY HIGH SCHOOL",
        "district": "EDUCATION REENVISIONED BOCES",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80028206600",
    },
    {
        "school": "CENTURY MIDDLE SCHOOL WITHIN A SCH",
        "district": "PARK RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272808004671",
    },
    {
        "school": "Sue Sossaman Early Childhood Development Center",
        "district": "Higley Unified School District (4248)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40378003361",
    },
    {
        "school": "Cooley Middle School",
        "district": "Higley Unified School District (4248)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378003381",
    },
    {
        "school": "Sossaman Middle School",
        "district": "Higley Unified School District (4248)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378003401",
    },
    {
        "school": "IC Imagine",
        "district": "Invest Collegiate - Imagine",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370036903340",
    },
    {
        "school": "The Capitol Encore Academy",
        "district": "The Capitol Encore Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370037003341",
    },
    {
        "school": "Lakeside Charter Academy",
        "district": "Lakeside Charter Acad  fka Thunderbird",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370037103335",
    },
    {
        "school": "A.C.E. Academy",
        "district": "A.C.E. Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370037203324",
    },
    {
        "school": "Stewart Creek High",
        "district": "Stewart Creek High School",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370037403333",
    },
    {
        "school": "KIPP Halifax College Prep",
        "district": "KIPP Halifax College Preparatory",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370037503344",
    },
    {
        "school": "Wayne Preparatory Academy",
        "district": "Wayne Preparatory",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370037703321",
    },
    {
        "school": "South Brunswick Charter",
        "district": "South Brunswick Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370037803334",
    },
    {
        "school": "Wilson Preparatory Academy",
        "district": "Wilson Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370037903323",
    },
    {
        "school": "Anderson Creek Academy",
        "district": "Anderson Creek Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370038103322",
    },
    {
        "school": "Commonwealth High",
        "district": "Commonwealth High School",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370038203336",
    },
    {
        "school": "Nesbitt Discovery Academy",
        "district": "Buncombe County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045003320",
    },
    {
        "school": "Morgan County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902043",
    },
    {
        "school": "Caldwell County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902057",
    },
    {
        "school": "Leslie County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902059",
    },
    {
        "school": "Clark County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902062",
    },
    {
        "school": "Marion County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902064",
    },
    {
        "school": "Lake Cumberland Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902069",
    },
    {
        "school": "Clay County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902070",
    },
    {
        "school": "Pulaski County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902072",
    },
    {
        "school": "Green County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902078",
    },
    {
        "school": "Mason County Career Magnet School",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902088",
    },
    {
        "school": "Floyd County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902090",
    },
    {
        "school": "Trailblazer Academy",
        "district": "Kentucky Tech System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902091",
    },
    {
        "school": "Breckinridge County Area Technology Ctr",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902094",
    },
    {
        "school": "Webster County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902095",
    },
    {
        "school": "Ohio County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902096",
    },
    {
        "school": "Carroll County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902097",
    },
    {
        "school": "Southern Kentucky Early CCA",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902102",
    },
    {
        "school": "Corbin Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902104",
    },
    {
        "school": "Casey County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902105",
    },
    {
        "school": "Jackson Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902106",
    },
    {
        "school": "Belfry Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902107",
    },
    {
        "school": "Knox County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902114",
    },
    {
        "school": "Montgomery County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902115",
    },
    {
        "school": "Butler Co. Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902116",
    },
    {
        "school": "Lee County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902118",
    },
    {
        "school": "Madison County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902123",
    },
    {
        "school": "Meade County College and Career Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902126",
    },
    {
        "school": "Murray/Calloway County Area Tech Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902134",
    },
    {
        "school": "Letcher County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902136",
    },
    {
        "school": "Mayfield/Graves County Area Tech Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902138",
    },
    {
        "school": "Warren Co. Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902141",
    },
    {
        "school": "Campbell County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902142",
    },
    {
        "school": "Harrison County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902143",
    },
    {
        "school": "Lincoln County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902145",
    },
    {
        "school": "Martin County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902147",
    },
    {
        "school": "Shelby County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902152",
    },
    {
        "school": "Breathitt County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902153",
    },
    {
        "school": "Nelson County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902154",
    },
    {
        "school": "Wayne County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902156",
    },
    {
        "school": "Logan County Career and Technical Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902160",
    },
    {
        "school": "Barren County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902161",
    },
    {
        "school": "IMATER ACADEMY MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008223",
    },
    {
        "school": "SPORTS LEADERSHIP AND MANAGEMENT (SLAM) CHARTER MIDDLE SCHOO",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008248",
    },
    {
        "school": "MATER VIRTUAL ACADEMY CHARTER MIDDLE/HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008270",
    },
    {
        "school": "IMATER ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008272",
    },
    {
        "school": "MAST@FIU",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008302",
    },
    {
        "school": "Rockcastle County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902163",
    },
    {
        "school": "Boone County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902164",
    },
    {
        "school": "Greenup County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902170",
    },
    {
        "school": "Four Rivers Career Academy",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902172",
    },
    {
        "school": "Monroe County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902173",
    },
    {
        "school": "Knott County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902174",
    },
    {
        "school": "Bullitt County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902176",
    },
    {
        "school": "Russell Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902177",
    },
    {
        "school": "Millard Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902182",
    },
    {
        "school": "Bell County Area Technology Center",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902183",
    },
    {
        "school": "Second Chance Academy",
        "district": "Bath County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210033002335",
    },
    {
        "school": "Bridges School",
        "district": "Carteret County Public Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370063003317",
    },
    {
        "school": "Harrisburg North Middle School - 08",
        "district": "Harrisburg School District 41-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463135001334",
    },
    {
        "school": "Endeavor Elementary - 07",
        "district": "Harrisburg School District 41-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463135001335",
    },
    {
        "school": "Calloway County Day Treatment",
        "district": "Calloway County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210087002366",
    },
    {
        "school": "Calloway County Alternative Program",
        "district": "Calloway County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210087002370",
    },
    {
        "school": "FLORIDA CYBER CHARTER ACADEMY",
        "district": "DUVAL",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008228",
    },
    {
        "school": "SAN JOSE PREPARATORY HIGH SCHOOL",
        "district": "DUVAL",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008243",
    },
    {
        "school": "SEASIDE COMMUNITY CHARTER SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008250",
    },
    {
        "school": "SAN JOSE ACADEMY",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008252",
    },
    {
        "school": "RIVER CITY SCIENCE ACADEMY INNOVATION SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008253",
    },
    {
        "school": "SUSSEX CENTRAL ELEM",
        "district": "SUSSEX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510378002959",
    },
    {
        "school": "SUSSEX CENTRAL MIDDLE",
        "district": "SUSSEX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510378002962",
    },
    {
        "school": "Tygart Creek Elementary School",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210102002340",
    },
    {
        "school": "Carter City Elementary School",
        "district": "Carter County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210102002356",
    },
    {
        "school": "Corbin School of Innovation",
        "district": "Corbin Independent",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210132002367",
    },
    {
        "school": "Chapman Vocational Education Center",
        "district": "Covington Independent",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210135002338",
    },
    {
        "school": "Abbott House High School - 07",
        "district": "Mitchell School District 17-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464839001337",
    },
    {
        "school": "Abbott House Elementary - 06",
        "district": "Mitchell School District 17-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464839001338",
    },
    {
        "school": "COLLEGIATE SCHOOL OF MED/BIO",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928003231",
    },
    {
        "school": "CLAUDE BROWN ELEMENTARY",
        "district": "TROY R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293045003229",
    },
    {
        "school": "ESCAMBIA VIRTUAL INSTRUCTIONAL PROGRAM (DISTRICT PROVIDED)",
        "district": "ESCAMBIA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051008310",
    },
    {
        "school": "Rapid City High School - 45",
        "district": "Rapid City Area School District 51-4",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "465982001340",
    },
    {
        "school": "Lincoln Building - 44",
        "district": "Rapid City Area School District 51-4",
        "level": "High",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "465982001341",
    },
    {
        "school": "Snohomish Detention Center",
        "district": "Northwest Educational Service District 189",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000802095",
    },
    {
        "school": "Pass Program",
        "district": "Northwest Educational Service District 189",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530000802755",
    },
    {
        "school": "Valley View Education Center",
        "district": "Elizabethtown Independent",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210165002355",
    },
    {
        "school": "Fayette County Preschool Center",
        "district": "Fayette County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002337",
    },
    {
        "school": "Crossroads School",
        "district": "Hoover City",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10000702359",
    },
    {
        "school": "Magnolia Elementary School",
        "district": "Trussville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001302401",
    },
    {
        "school": "Cahaba Elementary School",
        "district": "Trussville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001302402",
    },
    {
        "school": "Pelham Oaks",
        "district": "Pelham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019402395",
    },
    {
        "school": "Pelham Ridge",
        "district": "Pelham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019402396",
    },
    {
        "school": "Pelham Park Middle School",
        "district": "Pelham City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019402398",
    },
    {
        "school": "Pelham High School",
        "district": "Pelham City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019402399",
    },
    {
        "school": "Pike Road Elementary School",
        "district": "Pike Road City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019502407",
    },
    {
        "school": "Pick Elementary School",
        "district": "Auburn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021002363",
    },
    {
        "school": "Oxmoor K5",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039002354",
    },
    {
        "school": "Cleburne County Alternative School",
        "district": "Cleburne County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10078002361",
    },
    {
        "school": "Crossville Middle School",
        "district": "DeKalb County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10114002357",
    },
    {
        "school": "Sardis Middle School",
        "district": "Etowah County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138002351",
    },
    {
        "school": "Hale County Middle School",
        "district": "Hale County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10171002411",
    },
    {
        "school": "Hartselle Intermediate School",
        "district": "Hartselle City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10173002356",
    },
    {
        "school": "Hope High School",
        "district": "Houston County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10177002358",
    },
    {
        "school": "Ronald McNair 78",
        "district": "Huntsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180002379",
    },
    {
        "school": "Macon County Area Vocational School",
        "district": "Macon County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10219002353",
    },
    {
        "school": "Moores Mill Intermediate School",
        "district": "Madison County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222002376",
    },
    {
        "school": "Montgomery Preparatory Academy for Career Technologies",
        "district": "Montgomery County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10243002413",
    },
    {
        "school": "Oneonta Middle School",
        "district": "Oneonta City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10255002355",
    },
    {
        "school": "Success Academy",
        "district": "Phenix City",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10270002414",
    },
    {
        "school": "Edward Bell Career Technical Center",
        "district": "Tallapoosa County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10321002364",
    },
    {
        "school": "Sumiton Elementary School",
        "district": "Walker County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10345002377",
    },
    {
        "school": "Bristol Bay Correspondence",
        "district": "Bristol Bay Borough School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20003000751",
    },
    {
        "school": "Soldotna Prep School",
        "district": "Kenai Peninsula Borough School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20039000754",
    },
    {
        "school": "Valdez Home School",
        "district": "Valdez City School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20078000753",
    },
    {
        "school": "Cottonwood Elementary",
        "district": "Colorado City Unified District (4370)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40002103446",
    },
    {
        "school": "Foothills Academy Connected",
        "district": "Foothills Academy (4309)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40003603421",
    },
    {
        "school": "Champion Chandler",
        "district": "Fit Kids Inc. dba Champion Schools (78783)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40019103434",
    },
    {
        "school": "SACA Online",
        "district": "Southern Arizona Community Academy Inc. (79000)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40025403420",
    },
    {
        "school": "Harvest Preparatory Academy Goodyear",
        "district": "Harvest Power Community Development Group Inc. (79501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40028203457",
    },
    {
        "school": "CAVIAT - Flagstaff Central Campus",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034703425",
    },
    {
        "school": "Westland School Brighton Campus",
        "district": "Cholla Academy (5186)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40040203429",
    },
    {
        "school": "Aguila Pre-School",
        "district": "Aguila Elementary District (4249)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40048003445",
    },
    {
        "school": "Edkey Inc. - Pathfinder Academy at Eastmark",
        "district": "Edkey Inc. - Pathfinder Academy (81045)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40063803456",
    },
    {
        "school": "Learning Foundation and Performing Arts Warner",
        "district": "CAFA Inc. dba Learning Foundation and Performing  (90327)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40080303416",
    },
    {
        "school": "Jefferson Preparatory High School",
        "district": "Choice Academies Inc. (90138)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40080503444",
    },
    {
        "school": "ASU Preparatory Academy-Polytechnic Middle School",
        "district": "ASU Preparatory Academy (92327)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40088403264",
    },
    {
        "school": "Incito Schools",
        "district": "Incito Schools (91326)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40088503410",
    },
    {
        "school": "Vista College Preparatory",
        "district": "Vista College Preparatory Inc. (91948)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40088703415",
    },
    {
        "school": "Great Hearts Academies - Archway Arete",
        "district": "Archway Classical Academy Arete (92312)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40088803412",
    },
    {
        "school": "Legacy Traditional School - Casa Grande",
        "district": "Legacy Traditional School - Casa Grande (92199)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089203012",
    },
    {
        "school": "The Farm at Mission Montessori Academy",
        "district": "The Farm at Mission Montessori Academy (91340)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40090203413",
    },
    {
        "school": "BASIS Prescott",
        "district": "BASIS Charter Schools Inc. (92320)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40090303418",
    },
    {
        "school": "Sequoia Pathway Academy",
        "district": "Edkey Inc. - Sequoia Pathway Academy (92226)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40090403048",
    },
    {
        "school": "BASIS Oro Valley Primary",
        "district": "BASIS Charter Schools Inc. (92318)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40090503419",
    },
    {
        "school": "Las Puertas Community School",
        "district": "StrengthBuilding Partners (91992)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40090703427",
    },
    {
        "school": "Madison Highland Prep",
        "district": "Madison Highland Prep (91935)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40090903461",
    },
    {
        "school": "Heritage Academy Queen Creek",
        "district": "Heritage Academy Queen Creek Inc. (92519)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40091103440",
    },
    {
        "school": "EAGLE College Preparatory School- Mesa",
        "district": "EAGLE College Prep Mesa LLC. (91939)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40091203443",
    },
    {
        "school": "Arizona Autism Charter School",
        "district": "Arizona Autism Charter Schools Inc. (91958)",
        "level": "Elementary",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40091303455",
    },
    {
        "school": "Franklin Phonetic Primary School-Sunnyslope",
        "district": "Franklin Phonetic Primary School Inc. (92596)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40091403452",
    },
    {
        "school": "CASA Academy",
        "district": "CASA Academy (91934)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40091503422",
    },
    {
        "school": "EAGLE College Prep Maryvale",
        "district": "EAGLE College Prep Maryvale LLC (91938)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40091603437",
    },
    {
        "school": "Arizona Language Preparatory",
        "district": "Arizona Language Preparatory (92566)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40091803426",
    },
    {
        "school": "Horizon Honors Elementary School",
        "district": "Horizon Community Learning Center Inc. (92620)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40092103428",
    },
    {
        "school": "Desert Star Academy",
        "district": "Desert Star Academy (92302)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40092203458",
    },
    {
        "school": "Western School of Science and Technology",
        "district": "Western School of Science and Technology Inc. (91937)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40092403436",
    },
    {
        "school": "Heritage Academy Laveen",
        "district": "Heritage Academy Laveen Inc. (92520)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40092603451",
    },
    {
        "school": "Legacy Traditional School - Queen Creek",
        "district": "Legacy Traditional School - Queen Creek (92610)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40092703190",
    },
    {
        "school": "Noah Webster Schools-Pima",
        "district": "Noah Webster Schools-Pima (92374)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40092903406",
    },
    {
        "school": "Great Hearts Academies - Archway Trivium East",
        "district": "Archway Classical Academy Trivium East (92704)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40093003462",
    },
    {
        "school": "Coolidge Alternative Program",
        "district": "Coolidge Unified District (4442)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40232003449",
    },
    {
        "school": "Mt. Turnbull Elementary School",
        "district": "Fort Thomas Unified District (4221)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40320003460",
    },
    {
        "school": "Elona P. Cooley Early Child Development Center",
        "district": "Higley Unified School District (4248)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40378003417",
    },
    {
        "school": "Rancho Santa Fe Preschool",
        "district": "Litchfield Elementary District (4281)",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438003424",
    },
    {
        "school": "Palm Valley Preschool",
        "district": "Litchfield Elementary District (4281)",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438003435",
    },
    {
        "school": "Litchfield Preschool",
        "district": "Litchfield Elementary District (4281)",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438003450",
    },
    {
        "school": "Sweetwater Community School",
        "district": "Paradise Valley Unified District (4241)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40593003431",
    },
    {
        "school": "Sunset Heights Elementary School",
        "district": "Peoria Unified School District (4237)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625003441",
    },
    {
        "school": "Sunflower School",
        "district": "Peoria Unified School District (4237)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40625003447",
    },
    {
        "school": "Queen Creek Virtual Academy",
        "district": "Queen Creek Unified District (4245)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681003438",
    },
    {
        "school": "White Mountain Academy",
        "district": "Round Valley Unified District (4155)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40713003442",
    },
    {
        "school": "Vista Peak",
        "district": "Deer Valley Unified District (4246)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40775003454",
    },
    {
        "school": "ECambridge",
        "district": "Toltec School District (4450)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40855003423",
    },
    {
        "school": "Morgan Maxwell School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880003414",
    },
    {
        "school": "Esmond Station School",
        "district": "Vail Unified District (4413)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885003432",
    },
    {
        "school": "Yuma District One Digital Learning Academy",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960003430",
    },
    {
        "school": "RIVERCREST ELEMENTARY SCHOOL",
        "district": "RIVERCREST SCHOOL DISTRICT #57",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004501600",
    },
    {
        "school": "KIPP BLYTHEVILLE COLLEGIATE HIGH SCHOOL",
        "district": "KIPP DELTA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006201595",
    },
    {
        "school": "LISA ACADEMY NORTH MIDDLE CHARTER SCHOOL",
        "district": "LISA ACADEMY CHARTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007401473",
    },
    {
        "school": "LISA ACADEMY NORTH ELEMENTARY CHARTER SCHOOL",
        "district": "LISA ACADEMY CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007401485",
    },
    {
        "school": "LISA ACADEMY NORTH HIGH CHARTER SCHOOL",
        "district": "LISA ACADEMY CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007401501",
    },
    {
        "school": "ARKANSAS VIRTUAL ACADEMY HIGH SCHOOL",
        "district": "ARKANSAS VIRTUAL ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039401604",
    },
    {
        "school": "NORTHWEST ARKANSAS CLASSICAL ACADEMY HIGH",
        "district": "RESPONSIVE ED SOLUTIONS NORTHWEST ARK CLASSICAL ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040901606",
    },
    {
        "school": "EXALT ACADEMY OF SOUTHWEST LITTLE ROCK",
        "district": "EXALT ACADEMY OF SOUTHWEST LITTLE ROCK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041101599",
    },
    {
        "school": "DECATUR MIDDLE SCHOOL",
        "district": "DECATUR SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50498001602",
    },
    {
        "school": "FOUNTAIN LAKE MIDDLE SCHOOL COBRA DIGITAL PREP ACADEMY",
        "district": "FOUNTAIN LAKE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50642001605",
    },
    {
        "school": "THE ACADEMIES OF WEST MEMPHIS CHARTER SCHOOL",
        "district": "WEST MEMPHIS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50804001594",
    },
    {
        "school": "FOREST HEIGHTS STEM ACADEMY",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001601",
    },
    {
        "school": "J. M. Amador Elementary",
        "district": "Dublin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001913862",
    },
    {
        "school": "Mendota Elementary",
        "district": "Mendota Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002213773",
    },
    {
        "school": "Cox Bar Elementary",
        "district": "Trinity Alps Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60133101109",
    },
    {
        "school": "Altamont Elementary",
        "district": "Lammersville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141013781",
    },
    {
        "school": "Bonsall Elementary",
        "district": "Bonsall Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142600516",
    },
    {
        "school": "Vivian Banks Charter",
        "district": "Bonsall Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142606481",
    },
    {
        "school": "Norman L. Sullivan Middle",
        "district": "Bonsall Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142609519",
    },
    {
        "school": "Bonsall West Elementary",
        "district": "Bonsall Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142611749",
    },
    {
        "school": "Bonsall High",
        "district": "Bonsall Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142613751",
    },
    {
        "school": "Williams Ranch Elementary",
        "district": "Penn Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142700722",
    },
    {
        "school": "Vantage Point Charter",
        "district": "Penn Valley Union Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142702295",
    },
    {
        "school": "Ready Springs Elementary",
        "district": "Penn Valley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142704919",
    },
    {
        "school": "Penn Valley Union Special Education Preschool",
        "district": "Penn Valley Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142713239",
    },
    {
        "school": "Juan De Anza Elementary",
        "district": "Wiseburn Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142806990",
    },
    {
        "school": "Juan Cabrillo Elementary",
        "district": "Wiseburn Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142806992",
    },
    {
        "school": "Richard Henry Dana Middle",
        "district": "Wiseburn Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142806993",
    },
    {
        "school": "Peter Burnett Elementary",
        "district": "Wiseburn Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60142807146",
    },
    {
        "school": "Paul L. Cato Middle",
        "district": "Bakersfield City",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363013744",
    },
    {
        "school": "Dr. Douglas K. Fletcher Elementary",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60363013792",
    },
    {
        "school": "Barstow STEM Academy",
        "district": "Barstow Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60402013771",
    },
    {
        "school": "21st Century Learning Institute",
        "district": "Beaumont Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60429013779",
    },
    {
        "school": "Jim?nez Roberto and Dr. Francisco Elementary",
        "district": "Santa Maria-Bonita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60558013869",
    },
    {
        "school": "Adult Transition Program",
        "district": "Bonita Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60561013847",
    },
    {
        "school": "Burbank Unified Independent Learning Academy (BUILA)",
        "district": "Burbank Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60645013886",
    },
    {
        "school": "Hanh Phan Tilley Elementary",
        "district": "Central Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60797013825",
    },
    {
        "school": "Phoenix Rising High",
        "district": "Central Union High",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60801013807",
    },
    {
        "school": "Patricia Kay Beaver Elementary",
        "district": "Ceres Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60813013777",
    },
    {
        "school": "Ronald Reagan Elementary",
        "district": "Corona-Norco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985013855",
    },
    {
        "school": "Denair Elementary Charter Academy",
        "district": "Denair Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61104013930",
    },
    {
        "school": "Creekview Ranch",
        "district": "Dry Creek Joint Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61149013755",
    },
    {
        "school": "Enterprise Elementary",
        "district": "Eastside Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61191013759",
    },
    {
        "school": "Marion Mix Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233013865",
    },
    {
        "school": "Quantum Academy",
        "district": "Escondido Union",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61288013863",
    },
    {
        "school": "Evergreen Institute of Excellence",
        "district": "Evergreen Union",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61317013933",
    },
    {
        "school": "Zephyr Lane Elementary",
        "district": "Fairfax Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61329013766",
    },
    {
        "school": "Maie Ellis Elementary",
        "district": "Fallbrook Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61350013914",
    },
    {
        "school": "Rutherford B. Gaston Sr. Middle",
        "district": "Fresno Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455013767",
    },
    {
        "school": "Phillip J Patino School of Entrepreneurship",
        "district": "Fresno Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455013893",
    },
    {
        "school": "Geyserville New Tech Academy",
        "district": "Geyserville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61515013780",
    },
    {
        "school": "Williams Educational Center",
        "district": "Glendora Unified",
        "level": "Not reported",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61527013812",
    },
    {
        "school": "IDEA Center",
        "district": "Grossmont Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61623013915",
    },
    {
        "school": "Highland",
        "district": "Hayward Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "61674013823",
    },
    {
        "school": "Independence Charter Academy",
        "district": "Helendale Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61686013836",
    },
    {
        "school": "ASPIRE Community Day",
        "district": "Hemet Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61692013907",
    },
    {
        "school": "Phoenix Academy Community Day",
        "district": "King City Union",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61968013809",
    },
    {
        "school": "Konocti Education Center",
        "district": "Konocti Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62007013894",
    },
    {
        "school": "Pacifica Independent Home Study",
        "district": "Pacifica",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62046013922",
    },
    {
        "school": "Cove",
        "district": "Larkspur-Corte Madera",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62091013739",
    },
    {
        "school": "John McCandless Charter",
        "district": "Lincoln Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169013919",
    },
    {
        "school": "Dr Bob Forinash Community Day",
        "district": "Lompoc Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62241013924",
    },
    {
        "school": "Eunice Sato Academy of Math & Science",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250013896",
    },
    {
        "school": "NAVA College Preparatory Academy",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013737",
    },
    {
        "school": "Boyle Heights Sci Tech Engr and Math Magnet",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013775",
    },
    {
        "school": "Sylmar Biotech Health and Engineering Magnet",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013831",
    },
    {
        "school": "Eastin Arcola",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334013804",
    },
    {
        "school": "Ripperdan Community Day",
        "district": "Madera Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62334013848",
    },
    {
        "school": "Marysville Community Day",
        "district": "Marysville Joint Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62409013879",
    },
    {
        "school": "Rudolph Rivera Elementary",
        "district": "Merced City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62460013885",
    },
    {
        "school": "Dual Language Academy of the Monterey Peninsula",
        "district": "Monterey Peninsula Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553013758",
    },
    {
        "school": "Latimer",
        "district": "Moreland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62577013806",
    },
    {
        "school": "Gabriela Mistral Elementary",
        "district": "Mountain View Whisman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628013928",
    },
    {
        "school": "Chemehuevi Valley Elementary",
        "district": "Needles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62676013880",
    },
    {
        "school": "Needles Community Day",
        "district": "Needles Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62676013912",
    },
    {
        "school": "Delta Home Charter",
        "district": "New Jerusalem Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62703013736",
    },
    {
        "school": "Delta Bridges Charter",
        "district": "New Jerusalem Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62703013884",
    },
    {
        "school": "Almond Grove Elementary",
        "district": "Oakley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62808013786",
    },
    {
        "school": "Rancho Campana High",
        "district": "Oxnard Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62927013876",
    },
    {
        "school": "Rising Sun",
        "district": "Patterson Joint Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63003013822",
    },
    {
        "school": "South County Consortium",
        "district": "Petaluma City Elementary",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63023013936",
    },
    {
        "school": "Petaluma Accelerated Charter",
        "district": "Petaluma Joint Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63025013937",
    },
    {
        "school": "Ramona Community Montessori",
        "district": "Ramona City Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63171013846",
    },
    {
        "school": "Jonas Salk Elementary",
        "district": "San Diego Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63432013916",
    },
    {
        "school": "Pacific Trails Middle",
        "district": "San Dieguito Union High",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63438013861",
    },
    {
        "school": "Solana Ranch Elementary",
        "district": "Solana Beach Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63699013801",
    },
    {
        "school": "Hillside Elementary",
        "district": "South San Francisco Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63753013873",
    },
    {
        "school": "Miranda Junior High",
        "district": "Southern Humboldt Joint Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63759013805",
    },
    {
        "school": "Tice Creek",
        "district": "Walnut Creek Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64125013866",
    },
    {
        "school": "Cypress Village Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450013794",
    },
    {
        "school": "Portola Springs Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450013796",
    },
    {
        "school": "Butte County Community",
        "district": "Butte County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69100213783",
    },
    {
        "school": "Success One!",
        "district": "Glenn County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69100813810",
    },
    {
        "school": "Valley Academy",
        "district": "Imperial County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69101013814",
    },
    {
        "school": "Pinnacles Community",
        "district": "San Benito County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69102813911",
    },
    {
        "school": "John B Allard",
        "district": "Stanislaus County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104113818",
    },
    {
        "school": "Trinity County Community",
        "district": "Trinity County Office of Education",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104413934",
    },
    {
        "school": "ACADEMY OF CHARTER SCHOOLS",
        "district": "State Charter School Institute",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002000727",
    },
    {
        "school": "NEW AMERICA SCHOOL - LOWRY",
        "district": "State Charter School Institute",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80002001882",
    },
    {
        "school": "MONTESSORI DEL MUNDO CHARTER SCHOOL",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006602",
    },
    {
        "school": "COLORADO EARLY COLLEGES - Douglas County",
        "district": "State Charter School Institute",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006634",
    },
    {
        "school": "TWO RIVERS COMMUNITY SCHOOL",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006635",
    },
    {
        "school": "DISCOVERY CANYON CAMPUS MIDDLE SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006616",
    },
    {
        "school": "BRIARGATE PRESCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006619",
    },
    {
        "school": "DISCOVERY CANYON CAMPUS ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006631",
    },
    {
        "school": "VANGUARD CLASSICAL SCHOOL - EAST",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006611",
    },
    {
        "school": "APS EARLY BEGINNINGS - A ZOOM SITE",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006625",
    },
    {
        "school": "Colorado Virtual Academy High School",
        "district": "Byers School District No. 32J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80270001944",
    },
    {
        "school": "Astravo Academy High School",
        "district": "Byers School District No. 32J",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80270006605",
    },
    {
        "school": "Colorado Virtual Academy Middle School",
        "district": "Byers School District No. 32J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80270006620",
    },
    {
        "school": "Colorado Virtual Academy",
        "district": "Byers School District No. 32J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80270006630",
    },
    {
        "school": "MOUNTAIN VISTA ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006607",
    },
    {
        "school": "OUTBACK PRESCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006617",
    },
    {
        "school": "THE COTTAGE AT HOLLY RIDGE",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006632",
    },
    {
        "school": "CHILDREN'S KIVA MONTESSORI SCHOOL",
        "district": "Montezuma-Cortez School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80309006622",
    },
    {
        "school": "Willow Elementary School",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006603",
    },
    {
        "school": "HIGHLINE ACADEMY NORTHEAST",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006609",
    },
    {
        "school": "DSST: CONSERVATORY GREEN MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006618",
    },
    {
        "school": "DENVER DISCOVERY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006624",
    },
    {
        "school": "GIRLS ATHLETIC LEADERSHIP SCHOOL HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006626",
    },
    {
        "school": "STRIVE PREP - RUBY HILL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006627",
    },
    {
        "school": "DSST: COLE HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006636",
    },
    {
        "school": "CANTRIL",
        "district": "Douglas County School District No. Re 1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006621",
    },
    {
        "school": "DISTRICT 9-R SHARED SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348006614",
    },
    {
        "school": "FORT COLLINS MONTESSORI SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399006613",
    },
    {
        "school": "KENNETH HOMYAK PK-8",
        "district": "Weld re-8 schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80402006606",
    },
    {
        "school": "SALIDA DEL SOL ACADEMY",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441006638",
    },
    {
        "school": "CRESTED BUTTE ELEMENTARY SCHOOL",
        "district": "Gunnison Watershed School District Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80447006629",
    },
    {
        "school": "SPRING CREEK YOUTH SERVICES CENTER",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80453006342",
    },
    {
        "school": "HOLYOKE ALTERNATIVE SCHOOL",
        "district": "Holyoke School District No. Re-1J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80471006610",
    },
    {
        "school": "NORTH CONEJOS ALTERNATIVE PROGRAM",
        "district": "North Conejos School District No. Re1J",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80510006601",
    },
    {
        "school": "J. M. Wright Technical High School",
        "district": "Connecticut Technical Education and Career System",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CT",
        "nces_id": "90000201672",
    },
    {
        "school": "Elm City Montessori School",
        "district": "Elm City Montessori School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90021601683",
    },
    {
        "school": "Booker T. Washington Academy",
        "district": "Booker T. Washington Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90021701750",
    },
    {
        "school": "Great Oaks Charter School",
        "district": "Great Oaks Charter School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90021901782",
    },
    {
        "school": "Bristol Early Childhood Center-BECC",
        "district": "BRISTOL SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "CT",
        "nces_id": "90051001774",
    },
    {
        "school": "Westside Middle School Academy",
        "district": "DANBURY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90102001691",
    },
    {
        "school": "Griswold Alternative School",
        "district": "GRISWOLD SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CT",
        "nces_id": "90174001721",
    },
    {
        "school": "Harbor Elementary School",
        "district": "NEW LONDON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90282001685",
    },
    {
        "school": "Freire Charter School",
        "district": "Freire Charter School Wilmington",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100005900372",
    },
    {
        "school": "Great Oaks Charter School",
        "district": "Great Oaks Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100006200373",
    },
    {
        "school": "William F. Cooke Jr. Elementary",
        "district": "Red Clay Consolidated School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100130000371",
    },
    {
        "school": "Phillis Wheatley Elementary School",
        "district": "Woodbridge School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100185000370",
    },
    {
        "school": "Friendship PCS - Online",
        "district": "Friendship PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800495",
    },
    {
        "school": "Friendship PCS - Technology Preparatory HS",
        "district": "Friendship PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800496",
    },
    {
        "school": "Friendship PCS - Armstrong Elementary",
        "district": "Friendship PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800497",
    },
    {
        "school": "Brookland MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000494",
    },
    {
        "school": "Dorothy I. Height ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000504",
    },
    {
        "school": "KIPP DC - Valor Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100486",
    },
    {
        "school": "KIPP DC - Northeast Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100487",
    },
    {
        "school": "KIPP DC - Quest Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100488",
    },
    {
        "school": "KIPP DC - Arts and Technology Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100489",
    },
    {
        "school": "Two Rivers PCS - Young",
        "district": "Two Rivers PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004500498",
    },
    {
        "school": "Harmony DC PCS - School of Excellence",
        "district": "Harmony DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110009600491",
    },
    {
        "school": "District of Columbia International School",
        "district": "District of Columbia International School",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110009700492",
    },
    {
        "school": "Kingsman Academy PCS",
        "district": "Kingsman Academy PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110009900502",
    },
    {
        "school": "Monument Academy PCS",
        "district": "Monument Academy PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110010000500",
    },
    {
        "school": "The Children's Guild PCS",
        "district": "The Children's Guild DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110010100499",
    },
    {
        "school": "Washington Global PCS",
        "district": "Washington Global PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110010200503",
    },
    {
        "school": "BOULWARE SPRINGS CHARTER",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003008358",
    },
    {
        "school": "BRIDGEPREP ACADEMY OF HOLLYWOOD HILLS",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008355",
    },
    {
        "school": "AVANT GARDE ACADEMY OF BROWARD",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008361",
    },
    {
        "school": "BROWARD MATH AND SCIENCE SCHOOLS",
        "district": "BROWARD",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008373",
    },
    {
        "school": "SUNED HIGH SCHOOL OF NORTH BROWARD",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018008386",
    },
    {
        "school": "AVANT GARDE ACADEMY K-8 BROWARD",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008405",
    },
    {
        "school": "NEW LIFE CHARTER ACADEMY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008414",
    },
    {
        "school": "RENAISSANCE CHARTER MIDDLE SCHOOL AT PINES",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008422",
    },
    {
        "school": "CALHOUN VIRTUAL  INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "CALHOUN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120021008404",
    },
    {
        "school": "PACE CENTER FOR GIRLS CLAY",
        "district": "CLAY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120030008344",
    },
    {
        "school": "FLORIDA CYBER CHARTER ACADEMY AT CLAY",
        "district": "CLAY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030008391",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039008332",
    },
    {
        "school": "BIOTECH@RICHMOND HEIGHTS 9-12 HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008336",
    },
    {
        "school": "THE SEED SCHOOL OF MIAMI",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039008345",
    },
    {
        "school": "METRO WEST DETENTION FACILITY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039008362",
    },
    {
        "school": "INTERNATIONAL STUDIES VIRTUAL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008379",
    },
    {
        "school": "CENTER FOR INTERNATIONAL EDUCATION A CAMBRIDGE ASSOCIATE SCH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008388",
    },
    {
        "school": "SOMERSET VIRTUAL ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008402",
    },
    {
        "school": "TRUE NORTH CLASSICAL ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008409",
    },
    {
        "school": "ITECH@THOMAS A EDISON EDUCATIONAL CENTER",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008412",
    },
    {
        "school": "BEACON COLLEGE PREPARATORY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008423",
    },
    {
        "school": "DOWNTOWN DORAL CHARTER ELEMENTARY SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008425",
    },
    {
        "school": "DUVAL CHARTER SCHOOL AT SOUTHSIDE",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008371",
    },
    {
        "school": "DUVAL CHARTER SCHOOL AT MANDARIN",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008421",
    },
    {
        "school": "GADSDEN VIRTUAL FRANCHISE",
        "district": "GADSDEN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060008398",
    },
    {
        "school": "VILLAGE OF EXCELLENCE ACADEMY MIDDLE SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008342",
    },
    {
        "school": "BRIDGEPREP ACADEMY OF TAMPA",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008428",
    },
    {
        "school": "JACKSON VIRTUAL INSTRUCTION COURSE OFFERINGS",
        "district": "JACKSON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096008364",
    },
    {
        "school": "PRICE HALFWAY HOUSE",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108008349",
    },
    {
        "school": "PALM ACRES CHARTER HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108008375",
    },
    {
        "school": "ISLAND PARK HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108008392",
    },
    {
        "school": "OCALI CHARTER MIDDLE SCHOOL",
        "district": "MARION",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120126008427",
    },
    {
        "school": "MONROE VIRTUAL ACADEMY  (COURSE OFFERINGS)",
        "district": "MONROE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120132008395",
    },
    {
        "school": "OKEECHOBEE VIRTUAL FRANCHISE",
        "district": "OKEECHOBEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120141008363",
    },
    {
        "school": "LEGENDS ACADEMY CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008333",
    },
    {
        "school": "WEDGEFIELD SCHOOL",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008416",
    },
    {
        "school": "ORANGE COUNTY PREPARATORY ACADEMY CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008418",
    },
    {
        "school": "MATER BRIGHTON LAKES",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008352",
    },
    {
        "school": "ST. CLOUD PREPARATORY ACADEMY",
        "district": "OSCEOLA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008372",
    },
    {
        "school": "VICTORY K8 OF OSCEOLA",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008377",
    },
    {
        "school": "OSCEOLA TECHNICAL COLLEGE ST CLOUD CAMPUS",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120147008401",
    },
    {
        "school": "OSCEOLA TECHNICAL COLLEGE POINCIANA CAMPUS",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120147008430",
    },
    {
        "school": "PALM BEACH MARITIME ACADEMY HIGH SCHOOL",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008354",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT CYPRESS",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008367",
    },
    {
        "school": "GLADES CONSTRUCTION ACADEMY AT WEST TECH",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Career and Technical School",
        "state": "FL",
        "nces_id": "120150008378",
    },
    {
        "school": "FRANKLIN ACADEMY- PALM BEACH GARDENS",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008413",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT CENTRAL PALM",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008420",
    },
    {
        "school": "SANDERS MEMORIAL ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008337",
    },
    {
        "school": "PEPIN ACADEMIES OF PASCO COUNTY",
        "district": "PASCO",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120153008339",
    },
    {
        "school": "CLASSICAL PREPARATORY SCHOOL",
        "district": "PASCO",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008347",
    },
    {
        "school": "LEARNING LODGE ACADEMY",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008374",
    },
    {
        "school": "QUAIL HOLLOW ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008406",
    },
    {
        "school": "PLATO ACADEMY PINELLAS PARK CHARTER SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008338",
    },
    {
        "school": "GULF BEACHES ELEMENTARY MAGNET SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008365",
    },
    {
        "school": "EAST LAKE MIDDLE SCHOOL ACADEMY OF ENGINEERING",
        "district": "PINELLAS",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008380",
    },
    {
        "school": "AMI KIDS CENTER FOR PERSONAL GROWTH",
        "district": "PINELLAS",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156008383",
    },
    {
        "school": "PINELLAS GULF COAST ACADEMY",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156008410",
    },
    {
        "school": "KINGS HIGHWAY ELEMENTARY MAGNET SCHOOL",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008432",
    },
    {
        "school": "CITRUS RIDGE A CIVICS ACADEMY",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159008417",
    },
    {
        "school": "SARASOTA VIRTUAL ACADEMY (VIRTUAL FRANCHISE)",
        "district": "SARASOTA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168008394",
    },
    {
        "school": "ST. JOHNS VIRTUAL INSTRUCTIONAL PROGRAM",
        "district": "ST. JOHNS",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174008331",
    },
    {
        "school": "PATRIOT OAKS ACADEMY",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174008389",
    },
    {
        "school": "MOSAIC DIGITAL ACADEMY (ST. LUCIE VIRTUAL FRANCHISE)",
        "district": "ST. LUCIE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177008340",
    },
    {
        "school": "FAMU DRS VIRTUAL FRANCHISE",
        "district": "FAMU LAB SCH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120201408346",
    },
    {
        "school": "Atlanta Classical Academy",
        "district": "Atlanta Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004145",
    },
    {
        "school": "Kipp WAYS Primary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004155",
    },
    {
        "school": "Charles Drew Charter School JA/SA",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004161",
    },
    {
        "school": "Booker T. Washington High School",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004174",
    },
    {
        "school": "Georgia Cyber Academy",
        "district": "State Charter Schools- Georgia Cyber Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130023204148",
    },
    {
        "school": "Utopian Academy for the Arts Charter School",
        "district": "State Charter Schools- Utopian Academy for the Arts Charter",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130023304164",
    },
    {
        "school": "International Charter School of Atlanta",
        "district": "State Charter Schools- International Charter School of Atlan",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130023404179",
    },
    {
        "school": "Bleckley County Success Academy",
        "district": "Bleckley County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130044004162",
    },
    {
        "school": "Martha Ellen Stilwell School for the Performing Arts",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123004154",
    },
    {
        "school": "Crisp County Primary School",
        "district": "Crisp County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130156004157",
    },
    {
        "school": "Westchester Elementary School",
        "district": "City Schools of Decatur",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130168004156",
    },
    {
        "school": "New Beginning Learning Center",
        "district": "Decatur County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130171004170",
    },
    {
        "school": "Tapestry Public Charter School",
        "district": "DeKalb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174004159",
    },
    {
        "school": "Chattahoochee Hills Charter School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004147",
    },
    {
        "school": "Northbrook Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004149",
    },
    {
        "school": "North Metro Academy of Performing Arts",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004169",
    },
    {
        "school": "Hampton High School",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282004172",
    },
    {
        "school": "Houston County WIN Academy",
        "district": "Houston County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288004150",
    },
    {
        "school": "Langston Road Elementary School",
        "district": "Houston County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130288004166",
    },
    {
        "school": "Dorothy Height Elementary School",
        "district": "Muscogee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387004146",
    },
    {
        "school": "The Renaissance Center for Academic and Career Development",
        "district": "Thomas County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130489004152",
    },
    {
        "school": "Hookele Elementary School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000300",
    },
    {
        "school": "JCC - LEWISTON",
        "district": "IDAHO DEPARTMENT OF JUVENILE CORRECTIONS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160001600990",
    },
    {
        "school": "FORREST M BIRD CHARTER SCHOOL",
        "district": "SANDPOINT CHARTER SCHOOL INC.",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160016500772",
    },
    {
        "school": "UPPER CARMEN PUBLIC CHARTER SCHOOL",
        "district": "UPPER CARMEN PUBLIC CHARTER SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160017000847",
    },
    {
        "school": "IDAHO TECHNICAL CAREER ACADEMY",
        "district": "IDAHO COLLEGE AND CAREER READINESS ACADEMY INC.",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160017101069",
    },
    {
        "school": "GEM PREP: ONLINE SCHOOL",
        "district": "GEM PREP: ONLINE LLC",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160017200846",
    },
    {
        "school": "COEUR D'ALENE CHARTER ACADEMY SCHOOL",
        "district": "COEUR D'ALENE CHARTER ACADEMY INC.",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160017300765",
    },
    {
        "school": "NORTH STAR CHARTER SCHOOL",
        "district": "NORTH STAR CHARTER SCHOOL INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160017400803",
    },
    {
        "school": "CASSIA COUNTY DAY TREATMENT CENTER",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Not reported",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160066001072",
    },
    {
        "school": "VIRTUAL SCHOOL HOUSE",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210001070",
    },
    {
        "school": "IDAHO FINE ARTS ACADEMY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210001071",
    },
    {
        "school": "Acad for Lifelong Learning",
        "district": "Speed SEJA #802",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002906337",
    },
    {
        "school": "SEDOL Sector Programs",
        "district": "Spec Educ Dist Lake County/Sedol",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005906317",
    },
    {
        "school": "Black Hawk Area Special Ed Ctr",
        "district": "Black Hawk Area Sp Ed District",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170008406326",
    },
    {
        "school": "The Lafayette Academy",
        "district": "Adam/Brwn/Cass/Morgn/Pik/Sctt ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016203204",
    },
    {
        "school": "ARC",
        "district": "Adam/Brwn/Cass/Morgn/Pik/Sctt ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016203208",
    },
    {
        "school": "Starquest Acad RSSP South",
        "district": "Frankln/Johnsn/Massc/Willimsn ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018202270",
    },
    {
        "school": "ROYALS Academy Canton",
        "district": "Hancck/Fultn/Schuylr/McDonogh ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018602681",
    },
    {
        "school": "ROYALS RSSP Canton",
        "district": "Hancck/Fultn/Schuylr/McDonogh ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170018602685",
    },
    {
        "school": "Five County Regional Alternative",
        "district": "Alxndr/Jcksn/Pulsk/Prry/Union ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019002265",
    },
    {
        "school": "Jackson/Perry MS TAOEP",
        "district": "Alxndr/Jcksn/Pulsk/Prry/Union ROE",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019006321",
    },
    {
        "school": "Project SOAR",
        "district": "Alxndr/Jcksn/Pulsk/Prry/Union ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019006336",
    },
    {
        "school": "RAES West",
        "district": "Henderson/Knox/Mercer/Warren ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019202826",
    },
    {
        "school": "RAES West Alt Ed",
        "district": "Henderson/Knox/Mercer/Warren ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019204060",
    },
    {
        "school": "LMP ROE TAOEP",
        "district": "La Salle/Marshall/Putnam ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019406330",
    },
    {
        "school": "Regional Center for Change",
        "district": "Lee/Ogle/Whiteside ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019503325",
    },
    {
        "school": "Proviso THSD 209 Dream School",
        "district": "Region 06 West Cook ISC 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170022106319",
    },
    {
        "school": "TAPESTRY ALOP",
        "district": "Region 06 West Cook ISC 2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170022106356",
    },
    {
        "school": "SESE School",
        "district": "South Eastern Sp Ed Program",
        "level": "Secondary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170031106351",
    },
    {
        "school": "STEM Partnership School",
        "district": "STEM Partnership School",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170141506333",
    },
    {
        "school": "Milford Grade School West Campus",
        "district": "Milford Area PSD 124",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141602789",
    },
    {
        "school": "Milford High School Campus",
        "district": "Milford Area PSD 124",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141602790",
    },
    {
        "school": "Milford Grade School East Campus",
        "district": "Milford Area PSD 124",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141606312",
    },
    {
        "school": "Atwood-Hammond Grade School",
        "district": "Arthur CUSD 305",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170426000140",
    },
    {
        "school": "Benavides Steam Academy",
        "district": "Aurora East USD 131",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170468006318",
    },
    {
        "school": "International Prep Academy",
        "district": "Champaign CUSD 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942006339",
    },
    {
        "school": "ACTIONS Program",
        "district": "Champaign CUSD 4",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170942006352",
    },
    {
        "school": "Great Lakes Academy Charter ES",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006328",
    },
    {
        "school": "Horizon Sci Acad - Southwest Chtr",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006331",
    },
    {
        "school": "Excel Academy - Southwest HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006341",
    },
    {
        "school": "Excel Academy - Woodlawn HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006346",
    },
    {
        "school": "DeKalb Early Lrng and Dev Ctr",
        "district": "DeKalb CUSD 428",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200006340",
    },
    {
        "school": "HSD 86 Adult Opportunties Pgm",
        "district": "Hinsdale Twp HSD 86",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171932006342",
    },
    {
        "school": "Mannheim Early Childhood Ctr",
        "district": "Mannheim SD 83",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172433006324",
    },
    {
        "school": "Algonquin Primary Center",
        "district": "Park Forest SD 163",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173081006355",
    },
    {
        "school": "Connor Shaw Center",
        "district": "Peotone CUSD 207U",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173129006314",
    },
    {
        "school": "Douglas Elementary School",
        "district": "Princeton ESD 115",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173267006325",
    },
    {
        "school": "The District 54 Early Lrning Ctr",
        "district": "Schaumburg CCSD 54",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173474006316",
    },
    {
        "school": "Early Childhood Facility",
        "district": "Round Lake CUSD 116",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173499006334",
    },
    {
        "school": "Round Lake Transition Center",
        "district": "Round Lake CUSD 116",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173499006335",
    },
    {
        "school": "Wesclin Middle School",
        "district": "Wesclin CUSD 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173942006347",
    },
    {
        "school": "Vision Academy",
        "district": "Vision Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180014602566",
    },
    {
        "school": "KIPP Indy Unite Elementary",
        "district": "KIPP Indy Unite Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180014702571",
    },
    {
        "school": "Tindley Summit Academy",
        "district": "Tindley Summit Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180014802563",
    },
    {
        "school": "Christel House Academy West",
        "district": "Christel House Academy West",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180014902568",
    },
    {
        "school": "Carroll Junior High School",
        "district": "Carroll Consolidated School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180129002573",
    },
    {
        "school": "Northeastern Middle School",
        "district": "Northeastern Wayne Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180819002567",
    },
    {
        "school": "Little Quakers Academy",
        "district": "Plainfield Community School Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180897002569",
    },
    {
        "school": "Studebaker Center",
        "district": "South Bend Community School Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181029002574",
    },
    {
        "school": "Area 31 Career & Tech Center",
        "district": "M S D Wayne Township",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "181281002565",
    },
    {
        "school": "South Central Calhoun Elementary Building",
        "district": "South Central Calhoun Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002401417",
    },
    {
        "school": "South Central Calhoun Middle School",
        "district": "South Central Calhoun Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002402153",
    },
    {
        "school": "AGWSR Elementary at Wellsburg",
        "district": "AGWSR Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190306002212",
    },
    {
        "school": "Rock Creek Elementary",
        "district": "Ankeny Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190369002213",
    },
    {
        "school": "North Union Elementary",
        "district": "North Union Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190385001458",
    },
    {
        "school": "Morris Elementary",
        "district": "Bondurant-Farrar Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190507002209",
    },
    {
        "school": "Clinton Middle School",
        "district": "Clinton Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190771002219",
    },
    {
        "school": "Prairie Hill Elementary School",
        "district": "College Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190786002216",
    },
    {
        "school": "Jessie Franklin Taylor",
        "district": "Des Moines Independent Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897002218",
    },
    {
        "school": "ExiraElk Horn-Kimballton High School",
        "district": "Exira-Elk Horn- Kimballton Comm Sch Dist",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191125000674",
    },
    {
        "school": "Exira-Elk Horn-Kimballton Elementary",
        "district": "Exira-Elk Horn- Kimballton Comm Sch Dist",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191125002143",
    },
    {
        "school": "Loess Hills Elementary",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640002211",
    },
    {
        "school": "Fredericksburg Elem School",
        "district": "Sumner-Fredericksburg Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192760000741",
    },
    {
        "school": "Sumner-Fredericksburg Middle School",
        "district": "Sumner-Fredericksburg Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192760000742",
    },
    {
        "school": "Southeast Webster-Grand Southeast Valley Middle",
        "district": "Southeast Webster Grand Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "199901902217",
    },
    {
        "school": "Axtell Elementary School",
        "district": "Prairie Hills",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200035002073",
    },
    {
        "school": "Plum Creek Elementary",
        "district": "Buhler",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200420002075",
    },
    {
        "school": "Trail Ridge Middle School",
        "district": "Gardner Edgerton",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200642002076",
    },
    {
        "school": "North Elementary",
        "district": "Goodland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200658002078",
    },
    {
        "school": "Millbrooke Elementary",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014002077",
    },
    {
        "school": "Damar Elementary School",
        "district": "Palco",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201047002074",
    },
    {
        "school": "Ballard County Career and Technology Ctr",
        "district": "Ballard County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210021002404",
    },
    {
        "school": "Burgin Independent School",
        "district": "Burgin Independent",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210078002407",
    },
    {
        "school": "Rev. Henry E. Baker Sr. Interm. School",
        "district": "Clark County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210120002389",
    },
    {
        "school": "William G. Conkwright Elementary",
        "district": "Clark County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210120002391",
    },
    {
        "school": "Strode Station Elementary School",
        "district": "Clark County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210120002395",
    },
    {
        "school": "Shearer Elementary School",
        "district": "Clark County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210120002397",
    },
    {
        "school": "Robert D. Campbell Jr. High",
        "district": "Clark County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210120002402",
    },
    {
        "school": "Willis H. Justice Elementary School",
        "district": "Clark County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210120002405",
    },
    {
        "school": "Estill County Success Academy",
        "district": "Estill County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210176002406",
    },
    {
        "school": "Barnabus Home High School",
        "district": "Jackson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210294002390",
    },
    {
        "school": "Bellewood",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299002394",
    },
    {
        "school": "Brooklawn",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299002399",
    },
    {
        "school": "Laurel Co Schools Center for Innovation",
        "district": "Laurel County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210321002400",
    },
    {
        "school": "Logan County Alternative School",
        "district": "Logan County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210354002396",
    },
    {
        "school": "Madison Kindergarten Academy",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372002392",
    },
    {
        "school": "Newport Regional School",
        "district": "Newport Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210444002401",
    },
    {
        "school": "Learning Academy",
        "district": "Perry County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210477002398",
    },
    {
        "school": "Pineville Independent School",
        "district": "Pineville Independent",
        "level": "Other",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210486002393",
    },
    {
        "school": "Wayne County Learning Academy",
        "district": "Wayne County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210579002403",
    },
    {
        "school": "Southern University Laboratory Virtual School",
        "district": "Southern University Lab School",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220002302402",
    },
    {
        "school": "AMIKids Acadiana",
        "district": "Acadia Parish",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220003002381",
    },
    {
        "school": "Pathways in Education-Louisiana Inc.",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030002382",
    },
    {
        "school": "Maplewood Elementary",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033002387",
    },
    {
        "school": "Brookstown Middle",
        "district": "East Baton Rouge Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002379",
    },
    {
        "school": "South Baton Rouge Charter Academy",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002404",
    },
    {
        "school": "Tangipahoa Alternative Solutions Program",
        "district": "Tangipahoa Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220168002399",
    },
    {
        "school": "North Vermilion Middle School",
        "district": "Vermilion Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220180002398",
    },
    {
        "school": "Ellsworth Elementary-Middle School",
        "district": "Ellsworth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230550023117",
    },
    {
        "school": "Maine Connections Academy",
        "district": "Maine Connections Academy",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481923145",
    },
    {
        "school": "Monarch Global Academy PCS Laurel Campus",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001724",
    },
    {
        "school": "Mays Chapel Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001722",
    },
    {
        "school": "St. Charles High School",
        "district": "Charles County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027001727",
    },
    {
        "school": "Thomas Viaduct",
        "district": "Howard County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001720",
    },
    {
        "school": "Wilson Wims Elementary School",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001721",
    },
    {
        "school": "Edward M. Felegy ES",
        "district": "Prince George's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001723",
    },
    {
        "school": "Chesapeake Math and IT South Public Charter",
        "district": "Prince George's County Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001726",
    },
    {
        "school": "Monomoy Regional Middle School",
        "district": "Monomoy Regional School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054402832",
    },
    {
        "school": "Monomoy Regional High School",
        "district": "Monomoy Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250054402836",
    },
    {
        "school": "Argosy Collegiate Charter School",
        "district": "Argosy Collegiate Charter School (District)",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250055202827",
    },
    {
        "school": "City on a Hill Charter Public School New Bedford",
        "district": "City on a Hill Charter Public School New Bedford (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250055302814",
    },
    {
        "school": "Essex North Shore Agricultural and Technical School",
        "district": "Essex North Shore Agricultural and Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MA",
        "nces_id": "250055402833",
    },
    {
        "school": "Phoenix Academy Public Charter High School Springfield",
        "district": "Phoenix Academy Public Charter High School Springfield (Dist",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250055502821",
    },
    {
        "school": "TEC Connections Academy Commonwealth Virtual School",
        "district": "TEC Connections Academy Commonwealth Virtual School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250055602817",
    },
    {
        "school": "C.T. Douglas Elementary School",
        "district": "Acton-Boxborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250171000007",
    },
    {
        "school": "Paul P Gates Elementary School",
        "district": "Acton-Boxborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250171000008",
    },
    {
        "school": "Luther Conant School",
        "district": "Acton-Boxborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250171000009",
    },
    {
        "school": "McCarthy-Towne School",
        "district": "Acton-Boxborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250171000010",
    },
    {
        "school": "Merriam School",
        "district": "Acton-Boxborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250171000029",
    },
    {
        "school": "Blanchard Memorial School",
        "district": "Acton-Boxborough",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250171000356",
    },
    {
        "school": "Attleboro Community Academy",
        "district": "Attleboro",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250219002831",
    },
    {
        "school": "Dante Alighieri Montessori School",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002835",
    },
    {
        "school": "Pauline Agassiz Shaw Elementary School",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002839",
    },
    {
        "school": "George H. Englesby Elementary School",
        "district": "Dracut",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250432002822",
    },
    {
        "school": "Henry Lord Community School",
        "district": "Fall River",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483002811",
    },
    {
        "school": "Juniper Hill School",
        "district": "Framingham",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498002820",
    },
    {
        "school": "King Elementary School",
        "district": "Framingham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250498002823",
    },
    {
        "school": "Hillcrest Elementary School",
        "district": "Gill-Montague",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250527002816",
    },
    {
        "school": "Lawrence Family Public Academy",
        "district": "Lawrence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002815",
    },
    {
        "school": "Lexington Children's Place",
        "district": "Lexington",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250684002829",
    },
    {
        "school": "Sandwich STEM Academy",
        "district": "Sandwich",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251047002824",
    },
    {
        "school": "Conservatory of the Arts",
        "district": "Springfield",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002818",
    },
    {
        "school": "Chestnut Academy",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002830",
    },
    {
        "school": "Impact Prep at Chestnut",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002837",
    },
    {
        "school": "Chestnut Accelerated Middle School (Talented and Gifted)",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002840",
    },
    {
        "school": "Early Childhood Center at the Doyle School",
        "district": "Wakefield",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251191002826",
    },
    {
        "school": "Graveraet Elementary School",
        "district": "Marquette Area Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260001308583",
    },
    {
        "school": "Redford Service Learning Academy Campus",
        "district": "Detroit Service Learning Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260023908656",
    },
    {
        "school": "George Washington Carver Elementary School",
        "district": "George Washington Carver Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260024908580",
    },
    {
        "school": "George Washington Carver Middle School",
        "district": "George Washington Carver Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260024908630",
    },
    {
        "school": "Edgewood Elementary Academy",
        "district": "Muskegon Heights Public School Academy System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260102908649",
    },
    {
        "school": "Dr Martin Luther King Academy",
        "district": "Muskegon Heights Public School Academy System",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260102908671",
    },
    {
        "school": "Innocademy Allegan Campus",
        "district": "Innocademy Allegan Campus",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260107108603",
    },
    {
        "school": "Blended Learning Academies Credit Recovery High School",
        "district": "Blended Learning Academies Credit Recovery High School",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260107208593",
    },
    {
        "school": "WAY Michigan",
        "district": "WAY Michigan",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260107408589",
    },
    {
        "school": "New Paradigm College Prep",
        "district": "New Paradigm College Prep",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260107508633",
    },
    {
        "school": "Pathways Academy",
        "district": "Pathways Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260107608613",
    },
    {
        "school": "Insight School of Michigan",
        "district": "Insight School of Michigan",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260107708627",
    },
    {
        "school": "Canton Preparatory High School",
        "district": "Canton Preparatory High School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260108008635",
    },
    {
        "school": "Grand River Academy",
        "district": "Grand River Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260108208597",
    },
    {
        "school": "Eagles Nest Academy",
        "district": "Eagle's Nest Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260108308634",
    },
    {
        "school": "Muskegon Covenant Academy",
        "district": "Muskegon Covenant Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260108808645",
    },
    {
        "school": "New School High",
        "district": "New School High",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260108908646",
    },
    {
        "school": "East Shore Leadership Academy",
        "district": "East Shore Leadership Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260109008657",
    },
    {
        "school": "Alternative Educational Academy of Ogemaw County",
        "district": "Alternative Educational Academy of Ogemaw County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260109208670",
    },
    {
        "school": "Lake Superior Academy",
        "district": "Lake Superior Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260109308687",
    },
    {
        "school": "Wagar 56 Middle School",
        "district": "Airport Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260198008660",
    },
    {
        "school": "Airport Middle College",
        "district": "Airport Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260198008678",
    },
    {
        "school": "Algonac Alternative Education",
        "district": "Algonac Community School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260219008684",
    },
    {
        "school": "Millside Elementary School",
        "district": "Algonac Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260219008689",
    },
    {
        "school": "Algonquin Elementary School",
        "district": "Algonac Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260219008693",
    },
    {
        "school": "Au GresSims Middle School",
        "district": "Au Gres-Sims School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260360008664",
    },
    {
        "school": "Success  Three Rivers",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008584",
    },
    {
        "school": "Success  Lakeview",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008607",
    },
    {
        "school": "SUCCESS  Grand Rapids Alger Heights",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008617",
    },
    {
        "school": "Success  Menominee",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008642",
    },
    {
        "school": "Flat Rock Academic Virtual Academy 612",
        "district": "Flat Rock Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260708008605",
    },
    {
        "school": "Buchanan Virtual Academy",
        "district": "Buchanan Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260714008624",
    },
    {
        "school": "Buchanan Step Up",
        "district": "Buchanan Community Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260714008702",
    },
    {
        "school": "CarmanAinsworth Baker Career Academy",
        "district": "Carman-Ainsworth Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260789008695",
    },
    {
        "school": "Phoenix Alternative High School",
        "district": "Carney-Nadeau Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260801008629",
    },
    {
        "school": "Nellie Reed Elementary",
        "district": "Corunna Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261086008582",
    },
    {
        "school": "Great Lakes Online Education",
        "district": "Crawford AuSable Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261103008598",
    },
    {
        "school": "Pioneer High School",
        "district": "Croswell-Lexington Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261114008699",
    },
    {
        "school": "Dearborn STEM Middle School",
        "district": "Dearborn City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160008626",
    },
    {
        "school": "Henry Ford Early CollegeAdvanced Manufacturing",
        "district": "Dearborn City School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261160008706",
    },
    {
        "school": "Westwood North Academy",
        "district": "Westwood Community School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261164008604",
    },
    {
        "school": "WAY East Jackson",
        "district": "East Jackson Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261254008667",
    },
    {
        "school": "Escanaba Student Success Center",
        "district": "Escanaba Area Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261350008581",
    },
    {
        "school": "Fitzgerald Virtual Academy",
        "district": "Fitzgerald Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261446008625",
    },
    {
        "school": "George D Gilbert Elementary School",
        "district": "Gwinn Area Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261469008707",
    },
    {
        "school": "Eaton County Youth Facility",
        "district": "Grand Ledge Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261641008658",
    },
    {
        "school": "Grand Rapids Public Museum High",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008677",
    },
    {
        "school": "Fourth Street Learning Center",
        "district": "Jackson Public Schools",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261962008688",
    },
    {
        "school": "JPS Montessori Center",
        "district": "Jackson Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261962008691",
    },
    {
        "school": "54th Street Academy",
        "district": "Kelloggsville Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262016008622",
    },
    {
        "school": "Lakewood Early Childhood Center",
        "district": "Lakewood Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262098008686",
    },
    {
        "school": "NijiIro Japanese Immersion Elementary School",
        "district": "Livonia Public Schools School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262184008662",
    },
    {
        "school": "Livonia Transition Program",
        "district": "Livonia Public Schools School District",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262184008708",
    },
    {
        "school": "Madison Elementary School",
        "district": "Madison District Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262229008591",
    },
    {
        "school": "Maplewood School",
        "district": "Maple Valley Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262262008644",
    },
    {
        "school": "Oxford Crossroads Day School",
        "district": "Oxford Community Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262724008586",
    },
    {
        "school": "Liberty Middle School",
        "district": "Plymouth-Canton Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262856008704",
    },
    {
        "school": "River Rouge Stem Academy at Dunn",
        "district": "River Rouge School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262976008698",
    },
    {
        "school": "Arthur Eddy Academy",
        "district": "Saginaw School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263039008612",
    },
    {
        "school": "SOAR Academic Institute",
        "district": "South Redford School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263228008631",
    },
    {
        "school": "Kennedy Learning Center",
        "district": "Southfield Public School District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263231008709",
    },
    {
        "school": "Success Academy",
        "district": "Van Dyke Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263468008651",
    },
    {
        "school": "Grayson Elementary",
        "district": "Waterford School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263531008620",
    },
    {
        "school": "Wyoming Regional Center",
        "district": "Wyoming Public Schools",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263657008601",
    },
    {
        "school": "Muskegon County Juvenile Transition Center",
        "district": "Muskegon Area ISD",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268085008615",
    },
    {
        "school": "International Academy",
        "district": "Oakland Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268088001588",
    },
    {
        "school": "ELM TREE ACADEMY",
        "district": "Freshwater Education District",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270001404821",
    },
    {
        "school": "4122 - EAGLE RIDGE ACADEMY - IS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504823",
    },
    {
        "school": "MN ONLINE HIGH SCHOOL - I.S.",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504833",
    },
    {
        "school": "Paragon Academy",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504880",
    },
    {
        "school": "NEW CHANCE",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002604798",
    },
    {
        "school": "BENTON-STEARNS ED DISTRICT EC",
        "district": "Benton-Stearns Education District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007104772",
    },
    {
        "school": "MSED PAES LAB",
        "district": "MID STATE EDUCATION DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007304864",
    },
    {
        "school": "AFSA K-8",
        "district": "AFSA HIGH SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018604854",
    },
    {
        "school": "CROSSLAKE COMMUNITY HIGH SCHOOL",
        "district": "CROSSLAKE COMMUNITY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270021804782",
    },
    {
        "school": "PRAIRIE SEEDS MIDDLE SCHOOL ACADEMY",
        "district": "PRAIRIE SEEDS ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270024004805",
    },
    {
        "school": "PRAIRIE SEEDS HIGH SCHOOL ACADEMY",
        "district": "PRAIRIE SEEDS ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270024004810",
    },
    {
        "school": "METRO SCHOOLS MIDDLE CHARTER",
        "district": "METRO SCHOOLS CHARTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270024504857",
    },
    {
        "school": "Spectrum Middle School - Grade 6",
        "district": "SPECTRUM HIGH SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270027604835",
    },
    {
        "school": "SEVEN HILLS PREP ACADEMY UPPER",
        "district": "SEVEN HILLS PREPARATORY ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028404804",
    },
    {
        "school": "HIAWATHA COLLEGIATE HIGH SCHOOL",
        "district": "HIAWATHA ACADEMIES",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028804862",
    },
    {
        "school": "LIONSGATE ACADEMY AIM",
        "district": "LIONSGATE ACADEMY",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270031504846",
    },
    {
        "school": "LIONSGATE ACADEMY - LYNX PROGRAM",
        "district": "LIONSGATE ACADEMY",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270031504868",
    },
    {
        "school": "PARNASSUS PREP SCHOOL-RHETORIC",
        "district": "PARNASSUS PREPARATORY CHARTER SCH",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270033304817",
    },
    {
        "school": "PARNASSUS PREPARATORY SCHOOL-LOGIC",
        "district": "PARNASSUS PREPARATORY CHARTER SCH",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270033304837",
    },
    {
        "school": "New City School",
        "district": "NEW CITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270035404849",
    },
    {
        "school": "LAKES INTL LANGUAGE ACAD-HEADWATERS",
        "district": "LAKES INTERNATIONAL LANGUAGE ACADEM",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270035804828",
    },
    {
        "school": "BEACON ACADEMY ESY",
        "district": "BEACON ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036604879",
    },
    {
        "school": "MMSA Elementary School",
        "district": "MINNESOTA MATH AND SCIENCE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039904788",
    },
    {
        "school": "WOODBURY LEADERSHIP ACADEMY",
        "district": "WOODBURY LEADERSHIP ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270040104812",
    },
    {
        "school": "Career Pathways",
        "district": "Career Pathways",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270040204836",
    },
    {
        "school": "JANE GOODALL ENVIRONMENTAL SCIENCE",
        "district": "JANE GOODALL ENVIRONMENTAL SCIENCE",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270040304850",
    },
    {
        "school": "Success Academy",
        "district": "Success Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270040404790",
    },
    {
        "school": "Minnesota Excellence in Learning Ac",
        "district": "Minnesota Excellence in Learning Ac",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270040604843",
    },
    {
        "school": "LEVEL UP ACADEMY",
        "district": "LEVEL UP ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270040804800",
    },
    {
        "school": "New Century School",
        "district": "New Century School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270041004873",
    },
    {
        "school": "ROCHESTER BEACON ACADEMY",
        "district": "ROCHESTER BEACON ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270041204878",
    },
    {
        "school": "PINEWOOD ELEMENTARY - SNW",
        "district": "SHERBURNE AND NORTHERN WRIGHT SPECI",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041304872",
    },
    {
        "school": "TESFA INTERNATIONAL SCHOOL",
        "district": "TESFA INTERNATIONAL SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270041504876",
    },
    {
        "school": "Assessment Center",
        "district": "NORTHEAST METRO 916",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270226404818",
    },
    {
        "school": "EARLY CHILDHOOD SPECIAL EDUCATION (",
        "district": "BROOKLYN CENTER SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270624004783",
    },
    {
        "school": "BROOKLYN CENTER INDEPENDENT STUDY",
        "district": "BROOKLYN CENTER SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270624004806",
    },
    {
        "school": "Brooklyn Center Early College Acad",
        "district": "BROOKLYN CENTER SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270624004824",
    },
    {
        "school": "BROOKLYN CENTER SUMMER SCHOOL",
        "district": "BROOKLYN CENTER SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270624004853",
    },
    {
        "school": "THE ANICCA PROGRAM",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270819004774",
    },
    {
        "school": "ACADEMIC EXCELLENCE ONLINE",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104004777",
    },
    {
        "school": "ONLINE 728",
        "district": "Elk River School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137004861",
    },
    {
        "school": "STAARS",
        "district": "HASTINGS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271353004830",
    },
    {
        "school": "HENDRICKS ALC",
        "district": "HENDRICKS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271368004793",
    },
    {
        "school": "HENDRICKS MIDDLE SCHOOL",
        "district": "HENDRICKS PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271368004839",
    },
    {
        "school": "LYND MIDDLE SCHOOL",
        "district": "LYND PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271839004845",
    },
    {
        "school": "CITYVIEW COMMUNITY",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004778",
    },
    {
        "school": "Franklin Middle School",
        "district": "Minneapolis Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004882",
    },
    {
        "school": "FAIR Senior High",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004884",
    },
    {
        "school": "Webster Elementary",
        "district": "Minneapolis Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004885",
    },
    {
        "school": "REACH ACADEMY",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272295004787",
    },
    {
        "school": "PIKE LAKE KINDERGARTEN CENTER",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295004813",
    },
    {
        "school": "SNAIL LAKE KINDERGARTEN CENTER",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272295004815",
    },
    {
        "school": "PRAIRIE MEADOWS LEARNING CENTER",
        "district": "NEW LONDON-SPICER SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272340004770",
    },
    {
        "school": "ALC NIGHT SCHOOL",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272805004831",
    },
    {
        "school": "PILLAGER MIDDLE SCHOOL",
        "district": "PILLAGER PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272835004841",
    },
    {
        "school": "PINE ISLAND HIGH SCHOOL ALP",
        "district": "Pine Island Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272895004803",
    },
    {
        "school": "PRINCETON EDUCATIONAL OPTIONS",
        "district": "PRINCETON PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273003004863",
    },
    {
        "school": "RED LAKE EC SPECIAL EDUCATION EXT",
        "district": "RED LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273051004840",
    },
    {
        "school": "PRAIRIECARE",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273180004784",
    },
    {
        "school": "ECSE Community",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273180004859",
    },
    {
        "school": "HARAMBEE ELEMENTARY SCHOOL",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273243004842",
    },
    {
        "school": "ARMSTRONG SCHOOL",
        "district": "ST. JAMES PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273360004814",
    },
    {
        "school": "ALC GATEWAY TO COLLEGE",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384004792",
    },
    {
        "school": "EARLY ED BATTLE CREEK",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384004819",
    },
    {
        "school": "EARLY EDUCATION MISSISSIPPI CA",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384004848",
    },
    {
        "school": "BRITTANY'S PLACE",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384004858",
    },
    {
        "school": "BRIDGE TRANSITION PROGRAM",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273819004781",
    },
    {
        "school": "Meadow Ridge Elementary School",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216004847",
    },
    {
        "school": "Pathways Program Grades 8-12",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279144304796",
    },
    {
        "school": "WEST BOLIVAR DIST HIGH SCHOOL",
        "district": "WEST BOLIVAR CONS SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018501401",
    },
    {
        "school": "RAY BROOKS SCHOOL",
        "district": "WEST BOLIVAR CONS SCHOOL DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018501402",
    },
    {
        "school": "MCEVANS SCHOOL",
        "district": "WEST BOLIVAR CONS SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018501409",
    },
    {
        "school": "SHAW HIGH SCHOOL",
        "district": "WEST BOLIVAR CONS SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018501419",
    },
    {
        "school": "JOE BARNES VOCATIONAL CENTER",
        "district": "WEST BOLIVAR CONS SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280018501420",
    },
    {
        "school": "WEST BOLIVAR ELEM",
        "district": "WEST BOLIVAR CONS SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018501426",
    },
    {
        "school": "WEST BOLIVAR DISTRICT MIDDLE SCHOOL",
        "district": "WEST BOLIVAR CONS SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018501432",
    },
    {
        "school": "BROOKS ELEM SCHOOL",
        "district": "NORTH BOLIVAR CONS SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018601404",
    },
    {
        "school": "NORTHSIDE HIGH SCHOOL",
        "district": "NORTH BOLIVAR CONS SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018601411",
    },
    {
        "school": "I T MONTGOMERY ELEMENTARY SCHOOL",
        "district": "NORTH BOLIVAR CONS SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018601416",
    },
    {
        "school": "RULEVILLE MIDDLE SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701398",
    },
    {
        "school": "LOCKARD ELEMENTARY SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701399",
    },
    {
        "school": "DREW HUNTER MIDDLE SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701403",
    },
    {
        "school": "A W JAMES ELEMENTARY SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701410",
    },
    {
        "school": "INDIANOLA ACADEMIC ACHIEVEMENT",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280018701413",
    },
    {
        "school": "EAST SUNFLOWER SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701418",
    },
    {
        "school": "ROBERT L MERRITT JUNIOR HIGH SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701421",
    },
    {
        "school": "THOMAS E. EDWARDS SR. HIGH SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701422",
    },
    {
        "school": "GENTRY HIGH SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701425",
    },
    {
        "school": "INDIANOLA CAREER & TECH CENTER",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280018701427",
    },
    {
        "school": "RULEVILLE CENTRAL ELEM SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701428",
    },
    {
        "school": "INVERNESS SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701430",
    },
    {
        "school": "CARVER ELEMENTARY SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701433",
    },
    {
        "school": "RIVER OAKS ELEMENTARY SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177001431",
    },
    {
        "school": "LAUDERDALE CO EDUCATIONAL & SKILLS",
        "district": "LAUDERDALE CO SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280243001429",
    },
    {
        "school": "LOWNDES COUNTY ALTERNATIVE SCHOOL",
        "district": "LOWNDES CO SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280273001434",
    },
    {
        "school": "NATCHEZ EARLY COLLEGE@CO-LIN",
        "district": "NATCHEZ-ADAMS SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280303001414",
    },
    {
        "school": "NORTH PIKE CAREER & TECHNICAL CENTE",
        "district": "NORTH PIKE SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280324001436",
    },
    {
        "school": "OXFORD INTERMEDIATE SCHOOL",
        "district": "OXFORD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280345001407",
    },
    {
        "school": "PUCKETT ELEMENTARY SCHOOL",
        "district": "RANKIN CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280383001424",
    },
    {
        "school": "ACADEMIE LAFAYETTE-CHERRY",
        "district": "ACADEMIE LAFAYETTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290001703259",
    },
    {
        "school": "KIPP VICTORY ACADEMY",
        "district": "KIPP ST LOUIS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059103245",
    },
    {
        "school": "GATEWAY SCIENCE ACADEMY MIDDLE",
        "district": "GATEWAY SCIENCE ACAD/ST LOUIS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059203244",
    },
    {
        "school": "THE BIOME",
        "district": "THE BIOME",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060903262",
    },
    {
        "school": "EARLY CHILDHOOD AND PAT CENTER",
        "district": "CARTHAGE R-IX",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290746003243",
    },
    {
        "school": "COLE CAMP PRESCHOOL",
        "district": "COLE CAMP R-I",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290990003248",
    },
    {
        "school": "ERVIN ELEMENTARY SCHOOL",
        "district": "HICKMAN MILLS C-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434003246",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "CLARK CO. R-I",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291638003254",
    },
    {
        "school": "CENTRAL MIDDLE SCHOOL",
        "district": "KANSAS CITY 33",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640003251",
    },
    {
        "school": "HALE COOK ELEMENTARY",
        "district": "KANSAS CITY 33",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640003257",
    },
    {
        "school": "NORTHEAST MIDDLE SCHOOL",
        "district": "KANSAS CITY 33",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640003258",
    },
    {
        "school": "EPIC ELEMENTARY",
        "district": "LIBERTY 53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291854003253",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "Nixa Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292253003242",
    },
    {
        "school": "CARDEN PARK ELEM",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706003250",
    },
    {
        "school": "OAK GROVE ELEM",
        "district": "ST. JOSEPH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292706003255",
    },
    {
        "school": "SPARTA PK CENTER",
        "district": "SPARTA R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292874003260",
    },
    {
        "school": "GRISCOM JUVENILE DETENTION CTR",
        "district": "ST. LOUIS CITY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292928003252",
    },
    {
        "school": "Riverview Elementary",
        "district": "Liberty Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009300325",
    },
    {
        "school": "Cool Spring Colony School",
        "district": "Chester-Joplin-Inverness El",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009801113",
    },
    {
        "school": "CAMBRIDGE MIDDLE SCHOOL",
        "district": "CAMBRIDGE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310001502316",
    },
    {
        "school": "INDRA HOUSE",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "310001602317",
    },
    {
        "school": "CAREER PATHWAYS INSTITUTE",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310001602324",
    },
    {
        "school": "NORTH BEND CENTRAL MIDDLE SCHOOL",
        "district": "NORTH BEND CENTRAL PUBLIC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310011502304",
    },
    {
        "school": "LAWRENCE - NELSON MIDDLE SCHOOL",
        "district": "SOUTH CENTRAL NEBRASKA UNIFIED 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310012202321",
    },
    {
        "school": "RIVERSIDE ELEMENTARY - CEDAR RAPIDS",
        "district": "RIVERSIDE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018402296",
    },
    {
        "school": "RIVERSIDE ELEMENTARY - SPALDING",
        "district": "RIVERSIDE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018402297",
    },
    {
        "school": "RIVERSIDE MIDDLE SCHOOL",
        "district": "RIVERSIDE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018402300",
    },
    {
        "school": "RIVERSIDE HIGH SCHOOL",
        "district": "RIVERSIDE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018402308",
    },
    {
        "school": "CENTRAL VALLEY ELEM - SCOTIA",
        "district": "CENTRAL VALLEY PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018502299",
    },
    {
        "school": "CENTRAL VALLEY PK - GREELEY",
        "district": "CENTRAL VALLEY PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018502302",
    },
    {
        "school": "CENTRAL VALLEY PK - WOLBACH",
        "district": "CENTRAL VALLEY PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018502303",
    },
    {
        "school": "CENTRAL VALLEY HIGH SCHOOL",
        "district": "CENTRAL VALLEY PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018502310",
    },
    {
        "school": "OMAHA HOME FOR BOYS SCHOOLS",
        "district": "OMAHA HOME FOR BOYS SCHOOL",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310018602312",
    },
    {
        "school": "CODY-KILGORE MIDDLE SCHOOL",
        "district": "CODY-KILGORE PUBLIC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310528002306",
    },
    {
        "school": "ELKHORN GRANDVIEW MIDDLE SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011002305",
    },
    {
        "school": "HARTINGTON-NEWCASTLE ELEM AT NEWCASTLE",
        "district": "HARTINGTON NEWCASTLE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317152001297",
    },
    {
        "school": "HOLDREGE ELEMENTARY SCHOOL",
        "district": "HOLDREGE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317194002323",
    },
    {
        "school": "LPS CAREER ACADEMY",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317284002320",
    },
    {
        "school": "PRAIRIE VIEW SCHOOL",
        "district": "OGALLALA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317476002298",
    },
    {
        "school": "TRANSITION PROGRAM AT UNMC NEBRASKA MEDICINE",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317482002314",
    },
    {
        "school": "TRANSITION PROGRAM SOUTH",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317482002315",
    },
    {
        "school": "PRAIRIE QUEEN ELEMENTARY",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527002322",
    },
    {
        "school": "WAYNE EARLY LEARNING CENTER",
        "district": "WAYNE COMMUNITY SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317852002319",
    },
    {
        "school": "WEEPING WATER MIDDLE SCHOOL",
        "district": "WEEPING WATER PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317854002318",
    },
    {
        "school": "Freedom Classical Academy",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100842",
    },
    {
        "school": "Founders Academy of Nevada",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100843",
    },
    {
        "school": "American Preparatory Academy LV",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100848",
    },
    {
        "school": "Mater Academy Mountain Vista",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100851",
    },
    {
        "school": "Nevada Learning Academy at CCSD",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000845",
    },
    {
        "school": "Youthful Offender Program at High Desert State Prison",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000847",
    },
    {
        "school": "Northeastern Nevada Virtual Academy",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000839",
    },
    {
        "school": "Lincoln County Adult Correction",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320027000850",
    },
    {
        "school": "Pathways Elementary (Alternative)",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320036000852",
    },
    {
        "school": "North Star Online School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320048000844",
    },
    {
        "school": "Derry Early Education Program",
        "district": "Derry School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330261000716",
    },
    {
        "school": "The Founders Academy Charter School (H)",
        "district": "The Founders Academy Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330329800717",
    },
    {
        "school": "UNION REGIONAL SCHOOL",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008503315",
    },
    {
        "school": "ESSEX REGIONAL SCHOOL",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008503316",
    },
    {
        "school": "WANAQUE REGIONAL SCHOOL",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008503317",
    },
    {
        "school": "MERCER REGIONAL SCHOOL",
        "district": "OFFICE OF EDUCATION DEPARTMENT OF CHILDREN AND FAMILIES",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008503320",
    },
    {
        "school": "Vineland Preparatory Academy",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008903269",
    },
    {
        "school": "WARREN RCH",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008903319",
    },
    {
        "school": "SOUTHERN RCH",
        "district": "OFFICE OF EDUCATION JUVENILE JUSTICE COMMISSION",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340008903322",
    },
    {
        "school": "Lambertville Public School",
        "district": "South Hunterdon Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340076903010",
    },
    {
        "school": "Trenton Stem-to-Civics Charter School",
        "district": "Trenton Stem-to-Civics Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340077003291",
    },
    {
        "school": "Atlantic Community Charter School",
        "district": "Atlantic Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340077103287",
    },
    {
        "school": "Mastery Schools of Camden Inc.",
        "district": "Mastery Schools of Camden Inc.",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340077203313",
    },
    {
        "school": "Link Community Charter School",
        "district": "Link Community Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340077303275",
    },
    {
        "school": "Camden Prep Inc.",
        "district": "Camden Prep Inc.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340077603299",
    },
    {
        "school": "KIPP: Cooper Norcross A New Jersey Nonprofit Corporation",
        "district": "KIPP: Cooper Norcross A New Jersey Nonprofit Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340077703307",
    },
    {
        "school": "Marie H Katzenbach High School",
        "district": "Marie H. Katzenbach School for the Deaf",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340077803329",
    },
    {
        "school": "Barack Obama Elementary School",
        "district": "Asbury Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340093003301",
    },
    {
        "school": "Burlington County Alternative High School",
        "district": "Burlington County Special Services School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340244003303",
    },
    {
        "school": "Clark Preschool Annex",
        "district": "Clark Township Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340315003295",
    },
    {
        "school": "Jerome Dunn Academy No 9",
        "district": "Elizabeth Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459003293",
    },
    {
        "school": "Lindenwold Preschool Building",
        "district": "Lindenwold Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340864003271",
    },
    {
        "school": "George L Catrambone",
        "district": "LONG BRANCH PUBLIC SCHOOL District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340894003325",
    },
    {
        "school": "Memorial Campus",
        "district": "Lyndhurst School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340921003279",
    },
    {
        "school": "Early Childhood School - Central",
        "district": "Newark Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134003281",
    },
    {
        "school": "Early Childhood School - North",
        "district": "Newark Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134003327",
    },
    {
        "school": "Paulsboro Junior High Sschhol",
        "district": "Paulsboro School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341272003289",
    },
    {
        "school": "Mohawk Avenue School",
        "district": "SPARTA TOWNSHIP PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341551003243",
    },
    {
        "school": "Reaching Individual Student Excellence",
        "district": "Woodbridge Township School District",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341812003273",
    },
    {
        "school": "The Career Center of the SCESC",
        "district": "Somerset County Educational Services Commission",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348028003292",
    },
    {
        "school": "Salem Campus",
        "district": "Salem County Special Services School District",
        "level": "Other",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348036103297",
    },
    {
        "school": "CAMINO NUEVO YOUTH",
        "district": "JUVENILE JUSTICE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001101108",
    },
    {
        "school": "LA ACADEMIA DOLORES HUERTA",
        "district": "LA ACADEMIA DOLORES HUERTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350016600901",
    },
    {
        "school": "EXPLORE ACADEMY",
        "district": "EXPLORE ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350016701103",
    },
    {
        "school": "CARLSBAD EARLY COLLEGE HIGH",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030001109",
    },
    {
        "school": "ALTA VISTA EARLY COLLEGE HIGH SCHOOL",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108001104",
    },
    {
        "school": "ARROWHEAD PARK MEDICAL ACADEMY",
        "district": "LAS CRUCES PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350150001105",
    },
    {
        "school": "MANDELA INTERNATIONAL MAGNET (MIMS)",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237001106",
    },
    {
        "school": "NINA OTERO COMMUNITY SCHOOL",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237001107",
    },
    {
        "school": "SANTA FE ENGAGE",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237001110",
    },
    {
        "school": "CHAUTAUQUA COUNTY JAIL",
        "district": "CHAUTAUQUA LAKE CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360001806526",
    },
    {
        "school": "YORKVILLE EAST MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706461",
    },
    {
        "school": "CITY KNOLL MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706462",
    },
    {
        "school": "URBAN ASSEMBLY MAKER ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007706463",
    },
    {
        "school": "MANHATTAN EARLY COLLEGE SCHOOL FOR ADVERTISING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360007706466",
    },
    {
        "school": "SIXTH AVENUE ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706523",
    },
    {
        "school": "INWOOD EARLY COLLEGE FOR HEALTH AND INFORMATION TECHNOLOGIES",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360008306490",
    },
    {
        "school": "HAMILTON GRANGE MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008306530",
    },
    {
        "school": "BRONX DELTA SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506506",
    },
    {
        "school": "BEDFORD PARK ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008706507",
    },
    {
        "school": "SAMARA COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006474",
    },
    {
        "school": "RESEARCH AND SERVICE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009406408",
    },
    {
        "school": "NELSON MANDELA HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009406509",
    },
    {
        "school": "BROOKLYN SCIENCE AND ENGINEERING ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #18",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009606455",
    },
    {
        "school": "CHILDREN'S LAB SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009806485",
    },
    {
        "school": "BUSINESS TECHNOLOGY EARLY COLLEGE HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360009906468",
    },
    {
        "school": "JAMAICA CHILDREN'S SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006518",
    },
    {
        "school": "REDWOOD MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006533",
    },
    {
        "school": "BENJAMIN FRANKLIN HS-FINANCE-INFO",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360010106508",
    },
    {
        "school": "30TH AVENUE SCHOOL (THE) (G & T CITYWIDE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010206477",
    },
    {
        "school": "FORT HILL COLLABORATIVE ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306458",
    },
    {
        "school": "EAGLE ACADEMY FOR YOUNG MEN OF STATEN ISLAND (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306522",
    },
    {
        "school": "HIGHLAND PARK COMMUNITY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006483",
    },
    {
        "school": "URBAN ASSEMBLY SCHOOL FOR COLLABORATIVE HEALTHCARE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NY",
        "nces_id": "360012006484",
    },
    {
        "school": "QUEENS EXPLORERS ELEMENTARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306525",
    },
    {
        "school": "EPIC HIGH SCHOOL - NORTH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306528",
    },
    {
        "school": "EPIC HIGH SCHOOL-SOUTH",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306535",
    },
    {
        "school": "TUTTLE AVENUE SCHOOL",
        "district": "EASTPORT-SOUTH MANOR CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012506504",
    },
    {
        "school": "NYS DEPT OF CORRECTIONS PLACEMENT",
        "district": "NEW YORK STATE DEPARTMENT OF CORRECTIONS",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360012606464",
    },
    {
        "school": "GREATER BINGHAMTON HEALTH CENTER",
        "district": "NEW YORK STATE OFFICE MENTAL HEALTH (OMH)",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360012706473",
    },
    {
        "school": "SAGAMORE CHILDREN'S PSYCHIATRIC CENTER",
        "district": "NEW YORK STATE OFFICE MENTAL HEALTH (OMH)",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360012706478",
    },
    {
        "school": "MOHAWK VALLEY PSYCHIATRIC CENTER FOR CHILDREN & YOUTH",
        "district": "NEW YORK STATE OFFICE MENTAL HEALTH (OMH)",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360012706487",
    },
    {
        "school": "ROCKLAND CHILDREN'S PSYCHIATRIC CENTER",
        "district": "NEW YORK STATE OFFICE MENTAL HEALTH (OMH)",
        "level": "High",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360012706488",
    },
    {
        "school": "ELMIRA PSYCHIATRIC CENTER",
        "district": "NEW YORK STATE OFFICE MENTAL HEALTH (OMH)",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360012706505",
    },
    {
        "school": "SOUTH BEACH PSYCHIATRIC CENTER",
        "district": "NEW YORK STATE OFFICE MENTAL HEALTH (OMH)",
        "level": "Secondary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360012706515",
    },
    {
        "school": "WESTERN PSYCHIATRIC CENTER",
        "district": "NEW YORK STATE OFFICE MENTAL HEALTH (OMH)",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360012706520",
    },
    {
        "school": "SAINT LAWRENCE CHILDREN & YOUTH SERVICES",
        "district": "NEW YORK STATE OFFICE MENTAL HEALTH (OMH)",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360012706521",
    },
    {
        "school": "HUTCHINGS CHILD & YOUTH SERVICES",
        "district": "NEW YORK STATE OFFICE MENTAL HEALTH (OMH)",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360012706524",
    },
    {
        "school": "NEW YORK CITY CHILDREN'S CENTER",
        "district": "NEW YORK STATE OFFICE MENTAL HEALTH (OMH)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360012706536",
    },
    {
        "school": "RED HOOK RESIDENTIAL CENTER",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106453",
    },
    {
        "school": "HIGHLAND RESIDENTIAL CENTER",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106465",
    },
    {
        "school": "MACCORMICK SECURE CENTER",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106472",
    },
    {
        "school": "GOSHEN SECURE CENTER",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106475",
    },
    {
        "school": "COLUMBIA SECURE CENTER FOR GIRLS",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106492",
    },
    {
        "school": "INDUSTRY LIMITED SECURE SCHOOL",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106497",
    },
    {
        "school": "BRENTWOOD RESIDENTIAL CENTER",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106498",
    },
    {
        "school": "YOUTH LEADERSHIP ACADEMY",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106502",
    },
    {
        "school": "TABERG RESIDENTIAL CENTER",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106513",
    },
    {
        "school": "FINGER LAKES RESIDENTIAL CENTER",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106514",
    },
    {
        "school": "BROOKWOOD SECURE CENTER",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106519",
    },
    {
        "school": "RIVERVIEW SCHOOL (THE)",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Other",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013506368",
    },
    {
        "school": "SUNMOUNT DEVELOPMENTAL CENTER",
        "district": "NYS OFFICE FOR PEOPLE WITH DEVELOPMENTAL DISABILITIES",
        "level": "Secondary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360094706500",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL - WASHINGTON HEIGHTS",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL - WASHINGTON HEIGHTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360111006501",
    },
    {
        "school": "BROOKLYN LABORATORY CHARTER SCHOOL",
        "district": "BROOKLYN LABORATORY CHARTER SCHOOL",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360111106493",
    },
    {
        "school": "ACHIEVEMENT FIRST LINDEN CHARTER SCHOOL",
        "district": "ACHIEVEMENT FIRST LINDEN CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360111206517",
    },
    {
        "school": "RENAISSANCE ACADEMY CHARTER SCHOOL OF THE ARTS",
        "district": "RENAISSANCE ACADEMY CHARTER SCHOOL OF THE ARTS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360111306503",
    },
    {
        "school": "CENTRAL BROOKLYN ASCEND CHARTER SCHOOL",
        "district": "CENTRAL BROOKLYN ASCEND CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360111406511",
    },
    {
        "school": "BOYS PREPARATORY CHARTER SCHOOL OF NEW YORK",
        "district": "BOYS PREPARATORY CHARTER SCHOOL OF NEW YORK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360111506454",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL - ROSEDALE",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL - ROSEDALE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360111606476",
    },
    {
        "school": "VERTUS CHARTER SCHOOL",
        "district": "VERTUS CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360111706470",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL - SPRINGFIELD GARDENS",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL - SPRINGFIELD GARDENS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360111806486",
    },
    {
        "school": "AMERICAN DREAM CHARTER SCHOOL",
        "district": "AMERICAN DREAM CHARTER SCHOOL",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360111906495",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL - BRONX 4",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL - BRONX 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360112006529",
    },
    {
        "school": "COMPASS CHARTER SCHOOL",
        "district": "COMPASS CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360112106516",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL - BENSONHURST",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL - BENSONHURST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360112206469",
    },
    {
        "school": "SUCCESS ACADEMY CS - BERGEN BEACH",
        "district": "SUCCESS ACADEMY CS - BERGEN BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360112306534",
    },
    {
        "school": "ACHIEVEMENT FIRST NORTH BROOKLYN PREPARATORY CHARTER SCHOOL",
        "district": "ACHIEVEMENT FIRST NORTH BROOKLYN PREPARATORY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360112406457",
    },
    {
        "school": "FAMILY LIFE ACADEMY CHARTER SCHOOL III",
        "district": "FAMILY LIFE ACADEMY CHARTER SCHOOL III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360112506479",
    },
    {
        "school": "CLINTON COUNTY SHERIFFS DEPARTMENT",
        "district": "BEEKMANTOWN CENTRAL SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360429006452",
    },
    {
        "school": "ERIE COUNTY HOLDING CENTER",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360585006460",
    },
    {
        "school": "ST LAWRENCE CORRECTIONAL FACILITY",
        "district": "CANTON CENTRAL SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360647006482",
    },
    {
        "school": "PUTNAM COUNTY CORRECTIONAL FACILITY",
        "district": "CARMEL CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360657006489",
    },
    {
        "school": "CORNING-PAINTED POST MIDDLE SCHOOL",
        "district": "CORNING CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360840006459",
    },
    {
        "school": "COUNTY OF NASSAU/CORRECTIONAL CENTER",
        "district": "EAST MEADOW UNION FREE SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360984006471",
    },
    {
        "school": "FLOYD HARWOOD ELEMENTARY SCHOOL",
        "district": "HARTFORD CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361383006527",
    },
    {
        "school": "ROCKLAND COUNTY SHERIFFS DEPARTMENT",
        "district": "CLARKSTOWN CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "362034006499",
    },
    {
        "school": "SUFFOLK COUNTY SHERIFFS OFFICE",
        "district": "RIVERHEAD CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "362469006531",
    },
    {
        "school": "MONROE CORRECTIONAL FACILITY",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "362475006532",
    },
    {
        "school": "ONONDAGA CNTY SHERIFF'S DEPT",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "362859006467",
    },
    {
        "school": "PUBLIC SERVICE LEADERSHIP ACADEMY AT FOWLER",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859006480",
    },
    {
        "school": "DELAWARE PRIMARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859006481",
    },
    {
        "school": "SYRACUSE LATIN SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859006510",
    },
    {
        "school": "RENSSELAER COUNTY JAIL",
        "district": "TROY CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "362895006491",
    },
    {
        "school": "WYOMING COUNTY JAIL",
        "district": "WARSAW CENTRAL SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "362994006496",
    },
    {
        "school": "NASSAU CO JUVENILE DETENTION CENTER",
        "district": "WESTBURY UNION FREE SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "363096006494",
    },
    {
        "school": "TECH VALLEY HIGH SCHOOL",
        "district": "RENSSELAER-COLUMBIA-GREENE BOCES",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "368070006512",
    },
    {
        "school": "Early College High School",
        "district": "Pitt County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001203359",
    },
    {
        "school": "Excelsior Classical Academy",
        "district": "Excelsior Classical Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370038403355",
    },
    {
        "school": "KIPP Durham College Preparatory",
        "district": "KIPP Durham College Preparatory",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370038503372",
    },
    {
        "school": "North Carolina Cyber Academy",
        "district": "North Carolina Cyber Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370038603361",
    },
    {
        "school": "Youngsville Academy",
        "district": "Youngsville Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370038703371",
    },
    {
        "school": "Piedmont Classical High School",
        "district": "Piedmont Classical High School",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370038803373",
    },
    {
        "school": "Shining Rock Classical Academy: CFA",
        "district": "Shining Rock Classical Academy: CFA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370038903358",
    },
    {
        "school": "Charlotte Lab School",
        "district": "Charlotte Lab School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039103375",
    },
    {
        "school": "Queen City STEM School",
        "district": "Queen City STEM School",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039203365",
    },
    {
        "school": "VERITAS Community School CFA",
        "district": "VERITAS Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039303366",
    },
    {
        "school": "Northeast Academy of Aerospace & AdvTech",
        "district": "Northeast Academy of Aerospace & AdvTech",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039403360",
    },
    {
        "school": "Ignite Innovation Academy - Pitt",
        "district": "Ignite Innovation Academy - Pitt",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039503367",
    },
    {
        "school": "Winterville Charter Academy",
        "district": "Winterville Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039603370",
    },
    {
        "school": "PAVE Southeast Raleigh Charter",
        "district": "PAVE Southeast Raleigh Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039703374",
    },
    {
        "school": "NC Virtual Academy",
        "district": "NC Virtual Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039803362",
    },
    {
        "school": "W A Pattillo Middle",
        "district": "Edgecombe County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132003349",
    },
    {
        "school": "Martin Millennium Academy",
        "district": "Edgecombe County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370132003350",
    },
    {
        "school": "Foothills Community School",
        "district": "McDowell County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294003353",
    },
    {
        "school": "Starmount Acad of Excellence",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003356",
    },
    {
        "school": "Lawrence Orr Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003363",
    },
    {
        "school": "Oakhurst STEAM Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003368",
    },
    {
        "school": "Parkside Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003369",
    },
    {
        "school": "College Road Early Childhood Center",
        "district": "New Hanover County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333003348",
    },
    {
        "school": "Apex Friendship High",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003351",
    },
    {
        "school": "Scotts Ridge Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003352",
    },
    {
        "school": "Watauga Innovation Academy",
        "district": "Watauga County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370483003376",
    },
    {
        "school": "Grantham Middle",
        "district": "Wayne County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488003357",
    },
    {
        "school": "Spring Creek Middle",
        "district": "Wayne County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370488003364",
    },
    {
        "school": "ED CLAPP ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000873",
    },
    {
        "school": "DISCOVERY ELEMENTARY SCHOOL",
        "district": "GRAND FORKS 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380813000874",
    },
    {
        "school": "SPRUCE LANE COLONY SCHOOL",
        "district": "HILLSBORO 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380957000871",
    },
    {
        "school": "NEDROSE ELEMENTARY SCHOOL 4-8",
        "district": "NEDROSE 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381366000876",
    },
    {
        "school": "NEDROSE HIGH SCHOOL",
        "district": "NEDROSE 4",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381366000877",
    },
    {
        "school": "SOUTH PRAIRIE HIGH SCHOOL",
        "district": "SOUTH PRAIRIE 70",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381717000875",
    },
    {
        "school": "LEGACY ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000872",
    },
    {
        "school": "Lakeshore Intergenerational School",
        "district": "Lakeshore Intergenerational School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390156405843",
    },
    {
        "school": "Valley STEM+ME2 Academy",
        "district": "Valley STEM+ME2 Academy",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390156505820",
    },
    {
        "school": "Utica Shale Academy of Ohio",
        "district": "Utica Shale Academy of Ohio",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390156605837",
    },
    {
        "school": "Steel Academy",
        "district": "Steel Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390156705827",
    },
    {
        "school": "T2 Honors Academy",
        "district": "T2 Honors Academy",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390156805832",
    },
    {
        "school": "Bard Early College Cleveland",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805821",
    },
    {
        "school": "E3agle Academy",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805829",
    },
    {
        "school": "Cleveland High School for the Digital Arts",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805831",
    },
    {
        "school": "PACT @ JFK",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805840",
    },
    {
        "school": "Rosa Parks Early Learning Center",
        "district": "Dayton City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438405825",
    },
    {
        "school": "School of Innovation",
        "district": "Willoughby-Eastlake City",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451005822",
    },
    {
        "school": "Marysville STEM Early College High School",
        "district": "Marysville Exempted Village",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454705841",
    },
    {
        "school": "Mechanicsburg Middle School",
        "district": "Mechanicsburg Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454805826",
    },
    {
        "school": "Harrison Street Elementary School",
        "district": "Big Walnut Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467405836",
    },
    {
        "school": "Miller Elementary School",
        "district": "Aurora City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390491705823",
    },
    {
        "school": "Millstream Career Center",
        "district": "Findlay City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "391000005842",
    },
    {
        "school": "EPIC ONE ON ONE CHARTER HS",
        "district": "EPIC ONE ON ONE CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400077702789",
    },
    {
        "school": "EPIC ONE ON ONE CHARTER MS",
        "district": "EPIC ONE ON ONE CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400077702797",
    },
    {
        "school": "OKLA. VIRTUAL CHARTER ACAD MS",
        "district": "OKLAHOMA VIRTUAL CHARTER ACAD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400077802784",
    },
    {
        "school": "OKLA. VIRTUAL CHARTER ACAD HS",
        "district": "OKLAHOMA VIRTUAL CHARTER ACAD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400077802788",
    },
    {
        "school": "INSIGHT SCHOOL OF OKLAHOMA HS",
        "district": "INSIGHT SCHOOL OF OKLAHOMA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078502792",
    },
    {
        "school": "INSIGHT SCHOOL OF OKLAHOMA MS",
        "district": "INSIGHT SCHOOL OF OKLAHOMA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078502799",
    },
    {
        "school": "OKLAHOMA CONNECTIONS ACAD ES",
        "district": "OKLAHOMA CONNECTIONS ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078602793",
    },
    {
        "school": "OKLAHOMA CONNECTIONS ACAD MS",
        "district": "OKLAHOMA CONNECTIONS ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078602800",
    },
    {
        "school": "OKLAHOMA CONNECTIONS ACAD HS",
        "district": "OKLAHOMA CONNECTIONS ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078602804",
    },
    {
        "school": "JOHN W REX CHARTER ELEMENTARY",
        "district": "JOHN W REX CHARTER ELEMENTARY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078702787",
    },
    {
        "school": "ARKOMA JHS",
        "district": "ARKOMA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400321002798",
    },
    {
        "school": "BROKEN ARROW HS",
        "district": "BROKEN ARROW",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002795",
    },
    {
        "school": "BROKEN ARROW FRESHMAN ACADEMY",
        "district": "BROKEN ARROW",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002796",
    },
    {
        "school": "OAK CREST ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002801",
    },
    {
        "school": "ARROW SPRINGS EARLY CHILDHOOD",
        "district": "BROKEN ARROW",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002803",
    },
    {
        "school": "DEWAR MS",
        "district": "DEWAR",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400978002785",
    },
    {
        "school": "CARVER EARLY CHILDHOOD CTR",
        "district": "ENID",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401092002805",
    },
    {
        "school": "FORT TOWSON JHS",
        "district": "FORT TOWSON",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401230002790",
    },
    {
        "school": "MIDWEST CITY ES",
        "district": "MIDWEST CITY-DEL CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401995002791",
    },
    {
        "school": "SOUTH LAKE ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025002794",
    },
    {
        "school": "PRAIRIE VIEW ES",
        "district": "MUSTANG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100002786",
    },
    {
        "school": "Wahtonka Community School",
        "district": "North Wasco County SD 21",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410004801833",
    },
    {
        "school": "Dallas Community Charter",
        "district": "Dallas SD 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410386001835",
    },
    {
        "school": "Crater Lake Charter Academy",
        "district": "Eagle Point SD 9",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410450001831",
    },
    {
        "school": "Mountain View Academy",
        "district": "Lowell SD 71",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410759001834",
    },
    {
        "school": "Kairos PDX",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001830",
    },
    {
        "school": "Mifflin County Academy of Science and Te",
        "district": "Mifflin County Academy of Science and Technology",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PA",
        "nces_id": "420087807536",
    },
    {
        "school": "Executive Education Academy Charter Scho",
        "district": "Executive Education Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420087907523",
    },
    {
        "school": "Propel CS-Hazelwood",
        "district": "Propel CS-Hazelwood",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420088007543",
    },
    {
        "school": "Passport Academy CS",
        "district": "Passport Academy CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420088207549",
    },
    {
        "school": "Avonworth Primary Center",
        "district": "Avonworth SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420282007520",
    },
    {
        "school": "New Franklin El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555007530",
    },
    {
        "school": "Clearfield Area El Sch",
        "district": "Clearfield Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420615007535",
    },
    {
        "school": "Columbia MS",
        "district": "Columbia Borough SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420636007526",
    },
    {
        "school": "Corry Area Primary Sch",
        "district": "Corry Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420686007537",
    },
    {
        "school": "Marsh Creek Sixth Grade Center",
        "district": "Downingtown Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420771007539",
    },
    {
        "school": "Dunmore JSHS",
        "district": "Dunmore SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420798007540",
    },
    {
        "school": "Greater Johnstown School District's Cybe",
        "district": "Greater Johnstown SD",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421095007529",
    },
    {
        "school": "Harmony Area JSHS",
        "district": "Harmony Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421152007545",
    },
    {
        "school": "Maple Manor El/MS",
        "district": "Hazleton Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421170007527",
    },
    {
        "school": "Hazle Township Early Learning Center",
        "district": "Hazleton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421170007542",
    },
    {
        "school": "Harry W Lockley Early Learning Center",
        "district": "New Castle Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421662007541",
    },
    {
        "school": "Berkey Sch",
        "district": "New Kensington-Arnold SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421674007533",
    },
    {
        "school": "Roy A. Hunt El Sch",
        "district": "New Kensington-Arnold SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421674007538",
    },
    {
        "school": "Valley JSHS",
        "district": "New Kensington-Arnold SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421674007544",
    },
    {
        "school": "Ray S. Musselman Learning Center",
        "district": "Norristown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421698007528",
    },
    {
        "school": "Northern Lebanon MS",
        "district": "Northern Lebanon SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421764007522",
    },
    {
        "school": "Penn Hills El Sch",
        "district": "Penn Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421859007532",
    },
    {
        "school": "The Science Leadership Academy at Beeber",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007524",
    },
    {
        "school": "The Linc",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007525",
    },
    {
        "school": "Building 21",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007534",
    },
    {
        "school": "The U School: Innovative Lab",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007547",
    },
    {
        "school": "The Workshop School",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007548",
    },
    {
        "school": "Seneca Valley HS",
        "district": "Seneca Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422244007521",
    },
    {
        "school": "Eisenhower El Sch",
        "district": "Warren County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422482007531",
    },
    {
        "school": "The Hope Academy",
        "district": "The Hope Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440002700489",
    },
    {
        "school": "SouthSide Elementary Charter",
        "district": "SouthSide Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440002800490",
    },
    {
        "school": "West Broadway Middle School",
        "district": "Providence",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000491",
    },
    {
        "school": "Robert Smalls International Academy",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001630",
    },
    {
        "school": "Carolina Voyager Charter",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001628",
    },
    {
        "school": "Meeting Street Elementary School",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001648",
    },
    {
        "school": "Allegro Charter School of Music",
        "district": "Charleston 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001655",
    },
    {
        "school": "Lake City Early Childhood Center",
        "district": "Florence 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450219001641",
    },
    {
        "school": "Ronald E. McNair Jr. High",
        "district": "Florence 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450219001647",
    },
    {
        "school": "Dr. Phinnize J. Fisher Middle",
        "district": "Greenville 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450231001633",
    },
    {
        "school": "Ocean Drive Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001635",
    },
    {
        "school": "Riverside Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001644",
    },
    {
        "school": "Harrisburg Elementary",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258001634",
    },
    {
        "school": "Deerfield Elementary",
        "district": "Lexington 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001627",
    },
    {
        "school": "Chapin Middle",
        "district": "Lexington 05",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450282001654",
    },
    {
        "school": "Lake Carolina Elementary Upper Campus",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001653",
    },
    {
        "school": "Doby's Bridge Elementary",
        "district": "York 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001649",
    },
    {
        "school": "Tega Cay Elementary",
        "district": "York 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001652",
    },
    {
        "school": "Lead Academy",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101545",
    },
    {
        "school": "High Point Academy",
        "district": "SC Public Charter School District",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101639",
    },
    {
        "school": "Riverwalk Academy",
        "district": "SC Public Charter School District",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101645",
    },
    {
        "school": "Lowcountry Montessori School",
        "district": "SC Public Charter School District",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101646",
    },
    {
        "school": "NEXT High",
        "district": "SC Public Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101656",
    },
    {
        "school": "Teachwell Academy Middle School - 04",
        "district": "East Dakota Educational Cooperative",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "460002701361",
    },
    {
        "school": "Sunset Colony High School - 06",
        "district": "Britton-Hecla School District 45-4",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460004101364",
    },
    {
        "school": "Tea Area Frontier Elementary - 05",
        "district": "Tea Area School District 41-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460005201358",
    },
    {
        "school": "Brandon Valley Intermediate - 07",
        "district": "Brandon Valley School District 49-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460795001355",
    },
    {
        "school": "Dakota Prairie Elementary - 07",
        "district": "Brookings School District 05-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460852001356",
    },
    {
        "school": "Hillside Colony High School - 07",
        "district": "Doland School District 56-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461917001359",
    },
    {
        "school": "E.A.G.L.E. Center - 09",
        "district": "Eagle Butte School District 20-1",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "462010001360",
    },
    {
        "school": "Sequel Transition Academy - 07",
        "district": "West Central School District 49-7",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "463171001343",
    },
    {
        "school": "Lennox Intermediate - 09",
        "district": "Lennox School District 41-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "464155001363",
    },
    {
        "school": "Kennedy Elementary - 08",
        "district": "Pierre School District 32-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465526001353",
    },
    {
        "school": "George S Mickelson Alternative Elementary - 06",
        "district": "Redfield School District 56-4",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "466045001362",
    },
    {
        "school": "Camridge Colony School - 04",
        "district": "Rutland School District 39-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466414001348",
    },
    {
        "school": "George McGovern Middle School -09",
        "district": "Sioux Falls School District 49-5",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001333",
    },
    {
        "school": "Sonia Sotomayor Elementary - 65",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001344",
    },
    {
        "school": "Susan B. Anthony Elementary - 66",
        "district": "Sioux Falls School District 49-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466627001351",
    },
    {
        "school": "Spearfish Academy at Canyon Hills Elementary - 09",
        "district": "Spearfish School District 40-2",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "466693001346",
    },
    {
        "school": "Spearfish Academy at Canyon Hills High School - 10",
        "district": "Spearfish School District 40-2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "466693001347",
    },
    {
        "school": "Todd County Elementary - 16",
        "district": "Todd County School District 66-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467209001349",
    },
    {
        "school": "Corsica-Stickney Jr. High - 03",
        "district": "Corsica-Stickney 21-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468044501352",
    },
    {
        "school": "Corsica-Stickney Elementary - 02",
        "district": "Corsica-Stickney 21-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468044501354",
    },
    {
        "school": "Corsica-Stickney High School - 01",
        "district": "Corsica-Stickney 21-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468044501357",
    },
    {
        "school": "Aspire Coleman",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014701034",
    },
    {
        "school": "Fairley High School",
        "district": "Achievement School District",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014701058",
    },
    {
        "school": "Martin Luther King Preparatory High School",
        "district": "Achievement School District",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014701064",
    },
    {
        "school": "Freedom Preparatory Academy Charter Elementary School",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702368",
    },
    {
        "school": "Pathways in Education - Whitehaven",
        "district": "Achievement School District",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702369",
    },
    {
        "school": "Lester Prep",
        "district": "Achievement School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702370",
    },
    {
        "school": "Promise Academy - Spring Hill",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702398",
    },
    {
        "school": "Maxine Smith STEAM Academy",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802379",
    },
    {
        "school": "Vision Preparatory Charter School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802390",
    },
    {
        "school": "City University School of Independence",
        "district": "Shelby County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802400",
    },
    {
        "school": "Memphis Rise Academy",
        "district": "Shelby County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802418",
    },
    {
        "school": "Crosswind Elementary School",
        "district": "Collierville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014900147",
    },
    {
        "school": "Tara Oaks Elementary School",
        "district": "Collierville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014900420",
    },
    {
        "school": "West Collierville Middle School",
        "district": "Collierville",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014901134",
    },
    {
        "school": "Sycamore Elementary School",
        "district": "Collierville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014901359",
    },
    {
        "school": "Collierville Elementary School",
        "district": "Collierville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014901573",
    },
    {
        "school": "Collierville High School",
        "district": "Collierville",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014901574",
    },
    {
        "school": "Collierville Middle School",
        "district": "Collierville",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014901575",
    },
    {
        "school": "Bailey Station Elementary School",
        "district": "Collierville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014902076",
    },
    {
        "school": "Millington Central High School",
        "district": "Millington Municipal Schools",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015001587",
    },
    {
        "school": "Millington Middle School",
        "district": "Millington Municipal Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015001588",
    },
    {
        "school": "E.A. Harrold Elementary School",
        "district": "Millington Municipal Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015001858",
    },
    {
        "school": "Millington Elementary School",
        "district": "Millington Municipal Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015002078",
    },
    {
        "school": "Dogwood Elementary School",
        "district": "Germantown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015101576",
    },
    {
        "school": "Farmington Elementary School",
        "district": "Germantown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015101580",
    },
    {
        "school": "Riverdale Elementary School",
        "district": "Germantown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015101591",
    },
    {
        "school": "Houston High School",
        "district": "Germantown",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015102001",
    },
    {
        "school": "Houston Middle School",
        "district": "Germantown",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015102018",
    },
    {
        "school": "Arlington Middle",
        "district": "Arlington",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015201358",
    },
    {
        "school": "Arlington Elementary",
        "district": "Arlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015201567",
    },
    {
        "school": "Arlington High",
        "district": "Arlington",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015202075",
    },
    {
        "school": "Donelson Elementary",
        "district": "Arlington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015202197",
    },
    {
        "school": "Appling Middle School",
        "district": "Bartlett",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015300415",
    },
    {
        "school": "Rivercrest Elementary",
        "district": "Bartlett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015300972",
    },
    {
        "school": "Altruria Elementary",
        "district": "Bartlett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015301566",
    },
    {
        "school": "Bartlett Elementary School",
        "district": "Bartlett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015301569",
    },
    {
        "school": "Bartlett High School",
        "district": "Bartlett",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015301570",
    },
    {
        "school": "Ellendale Elementary",
        "district": "Bartlett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015301578",
    },
    {
        "school": "Elmore Park Middle School",
        "district": "Bartlett",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015301579",
    },
    {
        "school": "Oak Elementary",
        "district": "Bartlett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015301979",
    },
    {
        "school": "Bon Lin Elementary School",
        "district": "Bartlett",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015302077",
    },
    {
        "school": "Bon Lin Middle School",
        "district": "Bartlett",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015302161",
    },
    {
        "school": "Lakeland Elementary School",
        "district": "Lakeland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015401547",
    },
    {
        "school": "Jellico Learning Academy",
        "district": "Campbell County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470042002399",
    },
    {
        "school": "East Lafollette Learning Academy",
        "district": "Campbell County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470042002416",
    },
    {
        "school": "Coffee County Raider Academy",
        "district": "Coffee County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470078002420",
    },
    {
        "school": "Buckley-Carpenter Elementary School",
        "district": "Fayette County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470117002364",
    },
    {
        "school": "Career Magnet Academy",
        "district": "Knox County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222002388",
    },
    {
        "school": "Central Prep Academy",
        "district": "Marion County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470264002415",
    },
    {
        "school": "Reeves-Rogers Elementary",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315002425",
    },
    {
        "school": "Overall Creek Elementary",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315002426",
    },
    {
        "school": "Ivanetta H. Davis Learning Center at Bordeaux",
        "district": "Davidson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002377",
    },
    {
        "school": "Ross Early Learning Center",
        "district": "Davidson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002386",
    },
    {
        "school": "The Cohn Learning Center",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002392",
    },
    {
        "school": "Rocketship Nashville Northeast Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002422",
    },
    {
        "school": "Valor Flagship Academy",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002423",
    },
    {
        "school": "Nashville Academy of Computer Science",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002424",
    },
    {
        "school": "Sumner County Middle College High School",
        "district": "Sumner County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402002408",
    },
    {
        "school": "Tennessee Virtual Learning Academy",
        "district": "Washington County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438002403",
    },
    {
        "school": "Watertown Middle School",
        "district": "Wilson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455002383",
    },
    {
        "school": "SYCAMORE SPRINGS EL",
        "district": "DRIPPING SPRINGS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000813086",
    },
    {
        "school": "SYCAMORE SPRINGS MIDDLE",
        "district": "DRIPPING SPRINGS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000813151",
    },
    {
        "school": "DR T C MCCORMICK JR MIDDLE",
        "district": "HAYS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001013113",
    },
    {
        "school": "ARISTOI CLASSICAL UPPER SCHOOL",
        "district": "ARISTOI CLASSICAL ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001913071",
    },
    {
        "school": "UPLIFT EDUCATION - UPLIFT GRAND PREPARATORY",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013157",
    },
    {
        "school": "ANNE FRANK INSPIRE ACADEMY",
        "district": "INSPIRE ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480005313163",
    },
    {
        "school": "JHW INSPIRE ACADEMY - MERIDELL",
        "district": "INSPIRE ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480005313204",
    },
    {
        "school": "LIFE H S WAXAHACHIE",
        "district": "LIFE SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480005513098",
    },
    {
        "school": "FRANK L MADLA EARLY COLLEGE H S",
        "district": "NEW FRONTIERS PUBLIC SCHOOLS INC",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006113123",
    },
    {
        "school": "UNIVERSAL ACADEMY - DALLAS",
        "district": "UNIVERSAL ACADEMY",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007013179",
    },
    {
        "school": "RICHARD MILBURN ACADEMY LUBBOCK",
        "district": "RICHARD MILBURN ALTER HIGH SCHOOL (KILLEEN)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007508324",
    },
    {
        "school": "RICHARD MILBURN ACADEMY CORPUS CHRISTI",
        "district": "RICHARD MILBURN ALTER HIGH SCHOOL (KILLEEN)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007508344",
    },
    {
        "school": "RICHARD MILBURN ACADEMY AMARILLO",
        "district": "RICHARD MILBURN ALTER HIGH SCHOOL (KILLEEN)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007509009",
    },
    {
        "school": "RICHARD MILBURN ACADEMY FORT WORTH",
        "district": "RICHARD MILBURN ALTER HIGH SCHOOL (KILLEEN)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007509507",
    },
    {
        "school": "RICHARD MILBURN ACADEMY ODESSA",
        "district": "RICHARD MILBURN ALTER HIGH SCHOOL (KILLEEN)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007509647",
    },
    {
        "school": "RICHARD MILBURN ACADEMY HOUSTON (SUBURBAN)",
        "district": "RICHARD MILBURN ALTER HIGH SCHOOL (KILLEEN)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007513173",
    },
    {
        "school": "FOUNDERS CLASSICAL ACADEMY OF LEANDER",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313068",
    },
    {
        "school": "RICHARDSON CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313120",
    },
    {
        "school": "DENTON CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313181",
    },
    {
        "school": "IDEA WALZEM ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113074",
    },
    {
        "school": "IDEA WESLACO PIKE COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113085",
    },
    {
        "school": "IDEA WESLACO PIKE ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113127",
    },
    {
        "school": "IDEA WALZEM COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113148",
    },
    {
        "school": "IDEA MONTERREY PARK COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113183",
    },
    {
        "school": "IDEA MONTERREY PARK ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113195",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - AUSTIN",
        "district": "HARMONY SCIENCE ACADEMY (AUSTIN)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024113063",
    },
    {
        "school": "LIGHTHOUSE CHARTER SCHOOL - B CAMPUS",
        "district": "LIGHTHOUSE CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024613089",
    },
    {
        "school": "AZLEWAY - CHAPEL HILL",
        "district": "TRINITY CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480025913126",
    },
    {
        "school": "CARSON PARKE",
        "district": "TRINITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480025913143",
    },
    {
        "school": "AZLEWAY - BIG SANDY",
        "district": "TRINITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480025913178",
    },
    {
        "school": "AZLEWAY - WILLOW BEND",
        "district": "TRINITY CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480025913198",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - BROWNSVILLE",
        "district": "HARMONY SCIENCE ACAD (SAN ANTONIO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026612119",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - LAREDO",
        "district": "HARMONY SCIENCE ACAD (SAN ANTONIO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026613147",
    },
    {
        "school": "BROOKS COLLEGIATE ACADEMY",
        "district": "BROOKS ACADEMIES OF TEXAS",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026813064",
    },
    {
        "school": "BROOKS ACADEMY LONESTAR",
        "district": "BROOKS ACADEMIES OF TEXAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026813121",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - LUBBOCK",
        "district": "HARMONY SCIENCE ACAD (EL PASO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027211497",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - ODESSA",
        "district": "HARMONY SCIENCE ACAD (EL PASO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027212534",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY- FORT WORTH",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029211328",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - GRAND PRAIRIE",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029212050",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - EULESS",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029212379",
    },
    {
        "school": "HARMONY SCHOOL OF EXCELLENCE - DALLAS",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029212606",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - FORT WORTH",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029212847",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION- EULESS",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029212939",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - GARLAND",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029213199",
    },
    {
        "school": "TEXAS LEADERSHIP OF ARLINGTON",
        "district": "TEXAS LEADERSHIP",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140913171",
    },
    {
        "school": "MANARA STEM ACADEMY - ARLINGTON",
        "district": "MANARA ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141513108",
    },
    {
        "school": "ARROW ACADEMY - CHAMPIONS ACADEMY",
        "district": "ARROW ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141613152",
    },
    {
        "school": "BASIS SAN ANTONIO- PRI NORTH CENTRAL CAMPUS",
        "district": "BASIS TEXAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143813202",
    },
    {
        "school": "ILTEXAS KELLER MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013149",
    },
    {
        "school": "ILTEXAS KELLER EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013155",
    },
    {
        "school": "ILTEXAS ARLINGTON-GRAND PRAIRIE H S",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013191",
    },
    {
        "school": "GREAT HEARTS MONTE VISTA NORTH",
        "district": "GREAT HEARTS TEXAS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144113102",
    },
    {
        "school": "UTPB STEM ACADEMY",
        "district": "UTPB STEM ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144313129",
    },
    {
        "school": "BETA ACADEMY",
        "district": "BETA ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144613188",
    },
    {
        "school": "KI CHARTER ACADEMY",
        "district": "KI CHARTER ACADEMY",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480144713122",
    },
    {
        "school": "THE EXCEL CENTER (FOR ADULTS)",
        "district": "THE EXCEL CENTER (FOR ADULTS)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480144813141",
    },
    {
        "school": "HIGH POINT ACADEMY",
        "district": "HIGH POINT ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145013162",
    },
    {
        "school": "SPRING CREEK EL",
        "district": "COLLEGE STATION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735013081",
    },
    {
        "school": "SHADOW CREEK H S",
        "district": "ALVIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809013109",
    },
    {
        "school": "TRAVIS 6TH GRADE CAMPUS",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813013070",
    },
    {
        "school": "BOWIE 6TH GRADE CAMPUS",
        "district": "AMARILLO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480813013083",
    },
    {
        "school": "DISCIPLINARY ALTERNATIVE EDUCATION PROGRAM",
        "district": "ANAHUAC ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480819013185",
    },
    {
        "school": "SADLER MEANS YWLA",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894013132",
    },
    {
        "school": "GARCIA YMLA",
        "district": "AUSTIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894013169",
    },
    {
        "school": "COLORADO RIVER COLLEGIATE ACADEMY",
        "district": "BASTROP ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480957013111",
    },
    {
        "school": "BELTON EARLY CHILDHOOD SCHOOL",
        "district": "BELTON ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986013112",
    },
    {
        "school": "BIG SPRING INT",
        "district": "BIG SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481020013082",
    },
    {
        "school": "SHANNON H S",
        "district": "BIRDVILLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481023013066",
    },
    {
        "school": "CEDAR HILL COLLEGIATE ACADEMY",
        "district": "CEDAR HILL ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323013150",
    },
    {
        "school": "CEDAR HILL COLLEGIATE PREP",
        "district": "CEDAR HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481323013164",
    },
    {
        "school": "GRAND OAKS H S",
        "district": "CONROE ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500013065",
    },
    {
        "school": "VETERANS MEMORIAL H S",
        "district": "CORPUS CHRISTI ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527013128",
    },
    {
        "school": "DODSON PRI",
        "district": "DENVER CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481677013130",
    },
    {
        "school": "ADULT TRANSITION SERVICES",
        "district": "EANES ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481776013184",
    },
    {
        "school": "LEE BUICE EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800013117",
    },
    {
        "school": "EDWARD K DOWNING EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800013140",
    },
    {
        "school": "ODESSA CAREER AND TECHNICAL EARLY COLLEGE H S",
        "district": "ECTOR COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800013176",
    },
    {
        "school": "G E 'BUDDY' WEST EL",
        "district": "ECTOR COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800013189",
    },
    {
        "school": "EDNA ALTERNATIVE",
        "district": "EDNA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481821013097",
    },
    {
        "school": "ANNE MCCORMICK SULLIVAN EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965013166",
    },
    {
        "school": "MARINE CREEK COLLEGIATE H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970013114",
    },
    {
        "school": "PEARSON MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013090",
    },
    {
        "school": "LEBANON TRAIL H S",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013095",
    },
    {
        "school": "TRENT MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013136",
    },
    {
        "school": "NORRIS EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013186",
    },
    {
        "school": "GONZALES PRI ACADEMY",
        "district": "GONZALES ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482106013103",
    },
    {
        "school": "SCHOOL FOR THE HIGHLY GIFTED",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142013172",
    },
    {
        "school": "GRAPEVINE-COLLEYVILLE COLLEGIATE ACADEMY AT TCC NE",
        "district": "GRAPEVINE-COLLEYVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482166013073",
    },
    {
        "school": "HEREFORD CENTER FOR ACCELERATED LEARNING",
        "district": "HEREFORD ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482301013100",
    },
    {
        "school": "MARK WHITE EL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364013067",
    },
    {
        "school": "MIDDLE COLLEGE H S AT HCC GULFTON",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482364013076",
    },
    {
        "school": "ARABIC IMMERSION MAGNET SCHOOL",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364013165",
    },
    {
        "school": "MIDDLE COLLEGE H S AT HCC FRAGA",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482364013180",
    },
    {
        "school": "HIGHPOINT EAST",
        "district": "HUMBLE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482391013167",
    },
    {
        "school": "VETERANS HILL EL",
        "district": "HUTTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482410013156",
    },
    {
        "school": "INGRAM MIDDLE",
        "district": "INGRAM ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482421013075",
    },
    {
        "school": "JENKS EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517013093",
    },
    {
        "school": "BETHKE EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517013138",
    },
    {
        "school": "STOCKDICK J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517013145",
    },
    {
        "school": "FRENCH EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574013092",
    },
    {
        "school": "FULSHEAR H S",
        "district": "LAMAR CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658013110",
    },
    {
        "school": "DEAN LEAMAN J H SCHOOL",
        "district": "LAMAR CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658013153",
    },
    {
        "school": "JOHN ARREDONDO EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658013158",
    },
    {
        "school": "CHRISTINE CAMACHO EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703013077",
    },
    {
        "school": "BARBARA FASKEN EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057013087",
    },
    {
        "school": "BARBARA YARBROUGH EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057013104",
    },
    {
        "school": "RALPH BUNCHE EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057013200",
    },
    {
        "school": "DOLORES MCCLATCHEY EL",
        "district": "MIDLOTHIAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060013079",
    },
    {
        "school": "V R EATON H S",
        "district": "NORTHWEST ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318013139",
    },
    {
        "school": "TRAVIS H S OF CHOICE",
        "district": "PARIS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483429013196",
    },
    {
        "school": "WEST GROVES EARLY LEARNING CENTER",
        "district": "PORT NECHES-GROVES ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483543013088",
    },
    {
        "school": "SMITH EL",
        "district": "PRINCETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483585013174",
    },
    {
        "school": "LIGHT FARMS EL",
        "district": "PROSPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013096",
    },
    {
        "school": "SOUTH TEXAS ISD RISING SCHOLARS ACADEMY",
        "district": "SOUTH TEXAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483715013137",
    },
    {
        "school": "SALAZAR CROSSROADS ACADEMY",
        "district": "ROBSTOWN ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483744013203",
    },
    {
        "school": "ST PHILIP'S COLLEGE EARLY COLLEGE H S WITH SAISD",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013084",
    },
    {
        "school": "SAISD - PK 4 SA",
        "district": "SAN ANTONIO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013105",
    },
    {
        "school": "YOUNG MEN'S LEADERSHIP ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013107",
    },
    {
        "school": "NELSON EARLY CHILDHOOD CAMPUS",
        "district": "SAN ANTONIO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013131",
    },
    {
        "school": "BONHAM PRE-K SCHOOL",
        "district": "SAN MARCOS CISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483897013080",
    },
    {
        "school": "PEBBLE HILLS H S",
        "district": "SOCORRO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071013099",
    },
    {
        "school": "PURPLE HEART EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071013106",
    },
    {
        "school": "SHIRLEEN ZACHARIAS EARLY CLGE LEADERSHIP ACADEMY",
        "district": "SOMERSET ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484074013194",
    },
    {
        "school": "GREGG COUNTY SHARED SERVICES DAEP",
        "district": "SPRING HILL ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484119013142",
    },
    {
        "school": "FAIRVIEW AEP",
        "district": "WATER VALLEY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484471013069",
    },
    {
        "school": "FAIRVIEW DAEP",
        "district": "WATER VALLEY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484471013192",
    },
    {
        "school": "MARVIN EL",
        "district": "WAXAHACHIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473013161",
    },
    {
        "school": "JJAEP",
        "district": "WEBB CISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484481013091",
    },
    {
        "school": "BARWISE MIDDLE",
        "district": "WICHITA FALLS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578013133",
    },
    {
        "school": "ZUNDELOWITZ EL",
        "district": "WICHITA FALLS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578013182",
    },
    {
        "school": "American Preparatory Academy - Draper #3",
        "district": "American Preparatory Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490000501471",
    },
    {
        "school": "Black Ridge School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001461",
    },
    {
        "school": "Dry Creek School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001462",
    },
    {
        "school": "River Rock School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001481",
    },
    {
        "school": "Skyridge High School",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001486",
    },
    {
        "school": "Success DSU",
        "district": "Success Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003701470",
    },
    {
        "school": "Spectrum Academy - Pleasant Grove",
        "district": "Spectrum Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004201464",
    },
    {
        "school": "Syracuse Arts Academy - North",
        "district": "Syracuse Arts Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004401494",
    },
    {
        "school": "Freedom Preparatory Academy - Vineyard",
        "district": "Freedom Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006201492",
    },
    {
        "school": "Summit Academy - Independence",
        "district": "Summit Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006601469",
    },
    {
        "school": "Ridgeline High School",
        "district": "Cache District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012001487",
    },
    {
        "school": "Hawthorn Academy South Jordan",
        "district": "Hawthorn Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490013701493",
    },
    {
        "school": "Ascent Academies of Utah West Jordan",
        "district": "Ascent Academies of Utah",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017401472",
    },
    {
        "school": "Ascent Academies of Utah Lehi",
        "district": "Ascent Academies of Utah",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017401490",
    },
    {
        "school": "Utah Military Academy",
        "district": "Utah Military Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017601463",
    },
    {
        "school": "Greenwood Charter School",
        "district": "Greenwood Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017701468",
    },
    {
        "school": "Roots Charter High School",
        "district": "Roots Charter High School",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017801477",
    },
    {
        "school": "Terra Academy",
        "district": "Terra Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017901476",
    },
    {
        "school": "Athenian eAcademy",
        "district": "Athenian eAcademy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018101473",
    },
    {
        "school": "Lumen Scholar Institute",
        "district": "Lumen Scholar Institute",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018201467",
    },
    {
        "school": "Vanguard Academy",
        "district": "Vanguard Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018301475",
    },
    {
        "school": "Wallace Stegner Academy",
        "district": "Wallace Stegner Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018401489",
    },
    {
        "school": "Wasatch Waldorf Charter School",
        "district": "Wasatch Waldorf Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018501491",
    },
    {
        "school": "American Academy of Innovation",
        "district": "American Academy of Innovation",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018601483",
    },
    {
        "school": "Franklin Discovery Academy",
        "district": "Franklin Discovery Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018701488",
    },
    {
        "school": "St. George Academy",
        "district": "St. George Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018801485",
    },
    {
        "school": "Odyssey School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001474",
    },
    {
        "school": "Granite Preschool",
        "district": "Granite District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490036001478",
    },
    {
        "school": "Blackridge School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001480",
    },
    {
        "school": "Jordan Academy for Technology & Careers South",
        "district": "Jordan District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "UT",
        "nces_id": "490042001495",
    },
    {
        "school": "Maple Ridge School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001479",
    },
    {
        "school": "Sevier Career and Technical Education Center",
        "district": "Sevier District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "UT",
        "nces_id": "490093001465",
    },
    {
        "school": "Water Canyon School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001466",
    },
    {
        "school": "Weber Innovation High School",
        "district": "Weber District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120001482",
    },
    {
        "school": "Burch Creek School",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120001484",
    },
    {
        "school": "GREATER PENINSULA GOVERNOR'S STEM ACADEMY",
        "district": "NEW HORIZONS CAREER & TECH CTR",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510000903010",
    },
    {
        "school": "NORTHERN NECK GOV STEM  ACADEMY/AGRIC & MARITIME STUDIES",
        "district": "NORTHERN NECK TECHNICAL CENTER",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510001202978",
    },
    {
        "school": "MONTICELLO GOVERNOR'S HEALTH SCIENCES ACADEMY",
        "district": "ALBEMARLE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510009002974",
    },
    {
        "school": "GEORGE WASHINGTON MIDDLE",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012002999",
    },
    {
        "school": "FRANCIS C. HAMMOND MIDDLE",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012003016",
    },
    {
        "school": "BRIDGING COMMUNITIES STEM ACADEMY",
        "district": "BRIDGING COMMUNITIES REG CTE CENTER",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510025503014",
    },
    {
        "school": "GOVERNOR'S ACADEMY FOR CTE IN ARLINGTON",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510027003003",
    },
    {
        "school": "DISCOVERY ELEM",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027003006",
    },
    {
        "school": "GOVERNOR'S HEALTH SCIENCES ACADEMY",
        "district": "BEDFORD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510036003004",
    },
    {
        "school": "BLAND COUNTY ELEM",
        "district": "BLAND CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510039003002",
    },
    {
        "school": "BLAND COUNTY HIGH",
        "district": "BLAND CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510039003009",
    },
    {
        "school": "BLUE RIDGE CROSSROADS GOV ACAD FOR TECHNICAL ED",
        "district": "CARROLL CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510069002985",
    },
    {
        "school": "GRASSFIELD HIGH SCHOOL GOVERNOR'S STEM ACADEMY",
        "district": "CHESAPEAKE CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510081002998",
    },
    {
        "school": "CHESTERFIELD CAREER & TECHNICAL CENTER AT HULL",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510084002972",
    },
    {
        "school": "ACADEMY 360",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510084002983",
    },
    {
        "school": "GOVERNORS CAREER AND TECHNICAL ACADEMY FOR ENGINEERING STUDI",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510084002990",
    },
    {
        "school": "CHESTERFIELD CO GOV'S HEALTH/SCIENCE ACADEMY",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510084003013",
    },
    {
        "school": "SUPT'S REGION 8 GOV'S HEALTH/SCIENCE ACADEMY",
        "district": "CUMBERLAND CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510108002995",
    },
    {
        "school": "RIDGEVIEW HIGH",
        "district": "DICKENSON CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510114002981",
    },
    {
        "school": "RIDGEVIEW MIDDLE",
        "district": "DICKENSON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510114002982",
    },
    {
        "school": "MARSHALL GOVERNOR'S STEM ACADEMY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510126002993",
    },
    {
        "school": "FALLS CHURCH GOVERNOR'S HEALTH SCIENCES ACADEMY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510126003000",
    },
    {
        "school": "CHANTILLY GOVERNOR'S STEM ACADEMY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510126003008",
    },
    {
        "school": "HARDISON GOVERNOR'S HEALTH SCIENCES ACADEMY",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510126003012",
    },
    {
        "school": "JESSIE THACKREY PRESCHOOL",
        "district": "FALLS CHURCH CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510129002971",
    },
    {
        "school": "GLOUCESTER & MATHEWS COUNTIES GOV'S HEALTH SCIENCE ACADEMY",
        "district": "GLOUCESTER CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510162002975",
    },
    {
        "school": "PAGE MIDDLE",
        "district": "GLOUCESTER CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510162003022",
    },
    {
        "school": "HAMPTON CITY PUBLIC SCHOOLS GOV HEALTH SCIENCES ACADEMY",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510180002973",
    },
    {
        "school": "HAMPTON PUB.SCHS ARCHITECTURE & APPLIED ARTS GOV. STEM ACAD",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510180003007",
    },
    {
        "school": "HARRISONBURG HS GOVERNOR'S STEM ACADEMY",
        "district": "HARRISONBURG CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510186003005",
    },
    {
        "school": "ROCK RIDGE HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Other",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002969",
    },
    {
        "school": "MIDDLEBURG COMMUNITY CHARTER",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002970",
    },
    {
        "school": "CARDINAL RIDGE ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225002980",
    },
    {
        "school": "THE LOUDOUN GOVERNOR'S CAREER & TECHNICAL ACADEMY",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510225002989",
    },
    {
        "school": "RIVERSIDE HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225003001",
    },
    {
        "school": "LYNCHBURG REGIONAL GOVERNOR'S STEM ACADEMY",
        "district": "LYNCHBURG CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510234002976",
    },
    {
        "school": "MONTGOMERY COUNTY GOVERNOR'S STEM ACADEMY",
        "district": "MONTGOMERY CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510252002994",
    },
    {
        "school": "NEWPORT NEWS & YORK COUNTY GOV'S HEALTH SCIENCES ACADEMY",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510264002987",
    },
    {
        "school": "HERITAGE HIGH SCHOOL GOVERNOR'S STEM ACADEMY",
        "district": "NEWPORT NEWS CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510264003015",
    },
    {
        "school": "ACADEMY FOR DISCOVERY AT LAKEWOOD",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267003018",
    },
    {
        "school": "HAYMARKET ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313002968",
    },
    {
        "school": "CHRIS YUNG ELEM",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313003021",
    },
    {
        "school": "PULASKI  GOVERNOR'S STEM ACADEMY",
        "district": "PULASKI CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510315003017",
    },
    {
        "school": "THE GOVENORS CAREER AND TECHNICAL EDUCATION ACADEMY FOR STEM",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510324002988",
    },
    {
        "school": "ELKHARDT THOMPSON MIDDLE",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324003019",
    },
    {
        "school": "ASPIRE ACADEMY",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510324003020",
    },
    {
        "school": "MARTIN LUTHER KING JR EARLY LEARNING CENTER",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324003023",
    },
    {
        "school": "GOV STEM ACADEMY AT THE BURTON CENTER",
        "district": "ROANOKE CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510333002996",
    },
    {
        "school": "STEM FOR LIFE GOVERNOR'S ACADEMY",
        "district": "RUSSELL CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510342002997",
    },
    {
        "school": "SUGAR GROVE ELEM",
        "district": "SMYTH CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510352003011",
    },
    {
        "school": "STAFFORD ACADEMY FOR TECHNOLGY (STAT)",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510366002984",
    },
    {
        "school": "BAYSIDE 6TH GRADE CAMPUS",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510384002979",
    },
    {
        "school": "GOV STEM ACADEMY AT LANDSTOWN HIGH",
        "district": "VA BEACH CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510384002986",
    },
    {
        "school": "JOHN KERR ELEM",
        "district": "WINCHESTER CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510405003024",
    },
    {
        "school": "Chief Kitsap Academy",
        "district": "Suquamish Tribal Education Department",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530032803493",
    },
    {
        "school": "Open Doors Battle Ground",
        "district": "Battle Ground School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530038003501",
    },
    {
        "school": "Bellingham Family Partnership Program",
        "district": "Bellingham School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530042003476",
    },
    {
        "school": "Bellingham Re-Engagement Program",
        "district": "Bellingham School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530042003488",
    },
    {
        "school": "Acceleration Academy",
        "district": "Bethel School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530048003466",
    },
    {
        "school": "Futurus High School",
        "district": "Centralia School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530114003492",
    },
    {
        "school": "Lewis County Alternative School",
        "district": "Chehalis School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530117003486",
    },
    {
        "school": "Rainier Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141003472",
    },
    {
        "school": "Meriwether Elementary School",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141003473",
    },
    {
        "school": "College Place High School",
        "district": "College Place School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530147003489",
    },
    {
        "school": "East Valley Middle School",
        "district": "East Valley School District (Spokane)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530228003494",
    },
    {
        "school": "Edmonds Career Access Program",
        "district": "Edmonds School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530240003490",
    },
    {
        "school": "Open Doors Youth Reengagement (1418)",
        "district": "Federal Way School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530282003479",
    },
    {
        "school": "Granite Falls Open Doors",
        "district": "Granite Falls School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530321003485",
    },
    {
        "school": "Highline Open Doors 1418",
        "district": "Highline School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530354003484",
    },
    {
        "school": "Highline Home School Center",
        "district": "Highline School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530354003496",
    },
    {
        "school": "Quil Ceda Tulalip Elementary",
        "district": "Marysville School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486003480",
    },
    {
        "school": "Youth Re-Engagement",
        "district": "Monroe School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530513003468",
    },
    {
        "school": "Endeavor Middle School",
        "district": "Moses Lake School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530522003482",
    },
    {
        "school": "iGrad Academy",
        "district": "Oak Harbor School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530594003474",
    },
    {
        "school": "Desert Oasis High School",
        "district": "Othello School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530648003470",
    },
    {
        "school": "Rosalind Franklin STEM Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657003499",
    },
    {
        "school": "Forks Intermediate School",
        "district": "Quillayute Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530702003483",
    },
    {
        "school": "Jane Addams Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003467",
    },
    {
        "school": "Fairmount Park Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003497",
    },
    {
        "school": "Interagency Open Doors",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530771003505",
    },
    {
        "school": "SVSD OPEN DOORS",
        "district": "Snoqualmie Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530804003503",
    },
    {
        "school": "Open Doors Youth Re-Engagement Spokane",
        "district": "Spokane School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530825003491",
    },
    {
        "school": "Spokane Public Montessori",
        "district": "Spokane School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530825003502",
    },
    {
        "school": "SHS Graduation Alliance",
        "district": "Sunnyside School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530867003504",
    },
    {
        "school": "Valley Early Learning Center",
        "district": "Valley School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530924003475",
    },
    {
        "school": "Open Doors Vancouver",
        "district": "Vancouver School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530927003477",
    },
    {
        "school": "SE AREA TECHNICAL SKILLS CENTER",
        "district": "Walla Walla Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530945003481",
    },
    {
        "school": "re-engagement",
        "district": "West Valley School District (Spokane)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530969003469",
    },
    {
        "school": "White River Reengagement Program",
        "district": "White River School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530978003465",
    },
    {
        "school": "Wallace & Priscilla Stevenson Intermediate School",
        "district": "White Salmon Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530981003500",
    },
    {
        "school": "Yakima Open Doors",
        "district": "Yakima School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "531011003487",
    },
    {
        "school": "EXPLORER ACADEMY",
        "district": "CABELL COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540018001517",
    },
    {
        "school": "WEIRTON ELEMENTARY",
        "district": "HANCOCK COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540045001513",
    },
    {
        "school": "HARRISON CO EVOLUTION MIDDLE SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051001514",
    },
    {
        "school": "MASON COUNTY SCHOOL FOR SUCCESS",
        "district": "MASON COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540078001516",
    },
    {
        "school": "Grow Academy",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003503005",
    },
    {
        "school": "Oregon Correctional Center",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003503023",
    },
    {
        "school": "McNaughton Correctional Center",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003503025",
    },
    {
        "school": "La Casa de Esperanza Charter School",
        "district": "La Casa de Esperanza Charter School Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550007303031",
    },
    {
        "school": "Appleview",
        "district": "Appleton Area School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "550039003021",
    },
    {
        "school": "Oredocker Project School",
        "district": "Ashland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550051002986",
    },
    {
        "school": "Lake Superior High",
        "district": "Ashland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550051003017",
    },
    {
        "school": "Fran Fruzen Intermediate",
        "district": "Beloit School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550105003011",
    },
    {
        "school": "Bobcat Virtual Academy",
        "district": "Birchwood School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550117003020",
    },
    {
        "school": "4K Community School",
        "district": "Burlington Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550189002987",
    },
    {
        "school": "De Soto Virtual School",
        "district": "De Soto Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550324003022",
    },
    {
        "school": "High School of Health Sciences",
        "district": "Kettle Moraine School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550351002988",
    },
    {
        "school": "Northland Pines Montessori Learning Center (NPMLC)",
        "district": "Northland Pines School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550386003008",
    },
    {
        "school": "School of Options & Applied Research High",
        "district": "Northland Pines School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550386003013",
    },
    {
        "school": "Fennimore Middle",
        "district": "Fennimore Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550459003012",
    },
    {
        "school": "Dr Rosa Minoka-Hill School",
        "district": "Green Bay Area Public School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550582003009",
    },
    {
        "school": "Saint Croix Virtual Academy Inc",
        "district": "Saint Croix Central School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550606002989",
    },
    {
        "school": "Independence Middle",
        "district": "Independence School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550681002990",
    },
    {
        "school": "ARISE Virtual Academy",
        "district": "Janesville School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550702002991",
    },
    {
        "school": "4K Center for Literacy",
        "district": "Kimberly Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550747003029",
    },
    {
        "school": "Mauston Montessori Charter School",
        "district": "Mauston School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550885003030",
    },
    {
        "school": "Obama School of Career and Technical Education",
        "district": "Milwaukee School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002993",
    },
    {
        "school": "Northwood Elementary",
        "district": "Northwood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550972003015",
    },
    {
        "school": "Northwood Virtual Charter School",
        "district": "Northwood School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550972003018",
    },
    {
        "school": "Montello Virtual Charter School",
        "district": "Montello School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550987003016",
    },
    {
        "school": "Mount Horeb Area Community 4K",
        "district": "Mount Horeb Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550999002994",
    },
    {
        "school": "District 4K",
        "district": "Mukwonago School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551006003024",
    },
    {
        "school": "Taft Elementary",
        "district": "Neenah Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551032002995",
    },
    {
        "school": "Nekoosa 4K",
        "district": "Nekoosa School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551038003014",
    },
    {
        "school": "Catalyst Academy",
        "district": "New London School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551059002996",
    },
    {
        "school": "Peshtigo Middle",
        "district": "Peshtigo School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551161003026",
    },
    {
        "school": "Richland Online Academy",
        "district": "Richland School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551296002998",
    },
    {
        "school": "Innovations STEM Academy",
        "district": "Sparta Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551416003001",
    },
    {
        "school": "Point of Discovery School",
        "district": "Stevens Point Area Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551449003019",
    },
    {
        "school": "Tomah Area Montessori School",
        "district": "Tomah Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551491003028",
    },
    {
        "school": "Laker Online",
        "district": "Turtle Lake School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551506003032",
    },
    {
        "school": "eAchieve Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578003003",
    },
    {
        "school": "Waupaca Community 4-Year Old Kindergarten",
        "district": "Waupaca School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551584003007",
    },
    {
        "school": "Wausau Area Virtual Education",
        "district": "Wausau School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551590003027",
    },
    {
        "school": "Lane Intermediate",
        "district": "West Allis-West Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551626003004",
    },
    {
        "school": "Canyon Elementary School",
        "district": "Lincoln County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560403000555",
    },
    {
        "school": "Kemmerer Junior Senior High School",
        "district": "Lincoln County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560403000557",
    },
    {
        "school": "Mountain View K-8",
        "district": "Uinta County School District #4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560450000558",
    },
    {
        "school": "Skyline High School",
        "district": "Sublette County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560486000559",
    },
    {
        "school": "The Bridge School",
        "district": "Sheridan County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560569000554",
    },
    {
        "school": "ADACAO ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200041",
    },
    {
        "school": "AGANA HEIGHTS ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200042",
    },
    {
        "school": "ASTUMBO ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200043",
    },
    {
        "school": "B.P. CARBULLIDO ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200044",
    },
    {
        "school": "C.L. TAITANO ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200045",
    },
    {
        "school": "CHIEF BRODIE ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200046",
    },
    {
        "school": "D.L. PEREZ ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200047",
    },
    {
        "school": "FINEGAYAN ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200048",
    },
    {
        "school": "H.S. TRUMAN ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200049",
    },
    {
        "school": "INARAJAN ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200050",
    },
    {
        "school": "JUAN M. GUERRERO ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200051",
    },
    {
        "school": "J.Q. SAN MIGUEL ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200052",
    },
    {
        "school": "LIGUAN ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200053",
    },
    {
        "school": "L.B. JOHNSON ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200054",
    },
    {
        "school": "MARIA ULLOA ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200055",
    },
    {
        "school": "M.U. LUJAN ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200056",
    },
    {
        "school": "MARCIAL SABLAN ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200057",
    },
    {
        "school": "MERIZO MARTYRS ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200058",
    },
    {
        "school": "MACHANANAO ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200059",
    },
    {
        "school": "ORDOT CHALAN PAGO ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200060",
    },
    {
        "school": "PEDRO C. LUJAN ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200061",
    },
    {
        "school": "H.B. PRICE ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200062",
    },
    {
        "school": "TALOFOFO ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200063",
    },
    {
        "school": "TAMUNING ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200064",
    },
    {
        "school": "UPI ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200065",
    },
    {
        "school": "WETTENGEL ELEMENTARY SCHOOL",
        "district": "Guam Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200066",
    },
    {
        "school": "AGUEDA JOHNSTON MIDDLE SCHOOL",
        "district": "Guam Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200067",
    },
    {
        "school": "ASTUMBO MIDDLE SCHOOL",
        "district": "Guam Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200068",
    },
    {
        "school": "F.B. LEON GUERRERO MIDDLE SCHOOL",
        "district": "Guam Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200069",
    },
    {
        "school": "INARAJAN MIDDLE SCHOOL",
        "district": "Guam Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200070",
    },
    {
        "school": "JOSE RIOS MIDDLE SCHOOL",
        "district": "Guam Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200071",
    },
    {
        "school": "LUIS P. UNTALAN MIDDLE SCHOOL",
        "district": "Guam Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200072",
    },
    {
        "school": "OCEANVIEW MIDDLE SCHOOL",
        "district": "Guam Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200073",
    },
    {
        "school": "VICENTE BENAVENTE MIDDLE SCHOOL",
        "district": "Guam Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200074",
    },
    {
        "school": "GEORGE WASHINGTON HIGH SCHOOL",
        "district": "Guam Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200075",
    },
    {
        "school": "JOHN F. KENNEDY HIGH SCHOOL",
        "district": "Guam Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200076",
    },
    {
        "school": "OKKODO HIGH SCHOOL",
        "district": "Guam Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200077",
    },
    {
        "school": "SIMON SANCHEZ HIGH SCHOOL",
        "district": "Guam Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200078",
    },
    {
        "school": "SOUTHERN HIGH SCHOOL",
        "district": "Guam Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200079",
    },
    {
        "school": "TIYAN HIGH SCHOOL",
        "district": "Guam Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000200080",
    },
    {
        "school": "Genesis School",
        "district": "Conecuh County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10087002360",
    },
    {
        "school": "PAIDEIA Cooperative School",
        "district": "Anchorage School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000756",
    },
    {
        "school": "Homestead Elementary",
        "district": "Anchorage School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018010080",
    },
    {
        "school": "Goldenview Middle School",
        "district": "Anchorage School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018010162",
    },
    {
        "school": "Montessori Borealis Public Alternative School",
        "district": "Juneau Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20021000755",
    },
    {
        "school": "Joe Redington Senior Jr/Sr High School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000758",
    },
    {
        "school": "American Leadership Academy Ironwood K12",
        "district": "American Leadership Academy Inc. (4348)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011203475",
    },
    {
        "school": "AUHS Online Acadamy",
        "district": "Antelope Union High School District (4506)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40072003466",
    },
    {
        "school": "WAVE-Central Campus",
        "district": "Western Arizona Vocational District #50 (90123)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40079403471",
    },
    {
        "school": "Great Hearts Academies - Lincoln Prep",
        "district": "Lincoln Preparatory Academy (92657)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40091903472",
    },
    {
        "school": "STEDY- Vista HS Satellite",
        "district": "Southwest Technical Education District of Yuma (ST (92705)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40092003465",
    },
    {
        "school": "STEDY- Cibola High School Satellite",
        "district": "Southwest Technical Education District of Yuma (ST (92705)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40092003469",
    },
    {
        "school": "STEDY- Antelope HS Satellite",
        "district": "Southwest Technical Education District of Yuma (ST (92705)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40092003470",
    },
    {
        "school": "STEDY- Yuma HS Satellite",
        "district": "Southwest Technical Education District of Yuma (ST (92705)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40092003473",
    },
    {
        "school": "STEDY- Kofa HS Satellite",
        "district": "Southwest Technical Education District of Yuma (ST (92705)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40092003481",
    },
    {
        "school": "STEDY- San Luis HS Satellite",
        "district": "Southwest Technical Education District of Yuma (ST (92705)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40092003486",
    },
    {
        "school": "STEDY- Gila Ridge HS Satellite",
        "district": "Southwest Technical Education District of Yuma (ST (92705)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40092003488",
    },
    {
        "school": "Great Hearts Academies - Archway Lincoln",
        "district": "Archway Classical Academy Lincoln (92656)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40092503464",
    },
    {
        "school": "Seneca Preparatory Academy",
        "district": "Seneca Preparatory Academy Foundation (91237)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40093203474",
    },
    {
        "school": "Legacy Traditional School - Surprise",
        "district": "Legacy Traditional School - Surprise (92879)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40093303496",
    },
    {
        "school": "Self Development Academy-Phoenix",
        "district": "Self Development Academy-Phoenix (92381)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40093403493",
    },
    {
        "school": "BASIS Chandler Primary- South Campus",
        "district": "BASIS Charter Schools Inc. (92865)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40093603484",
    },
    {
        "school": "BASIS Scottsdale Primary - East Campus",
        "district": "BASIS Charter Schools Inc. (92863)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40093703482",
    },
    {
        "school": "Create Academy",
        "district": "Create Academy (92369)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40093803476",
    },
    {
        "school": "AIM Higher College Prep Academy",
        "district": "Espiritu Schools (92902)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40093903495",
    },
    {
        "school": "Academy of Math and Science Camelback",
        "district": "Academy of Mathematics and Science Inc. (92768)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094003499",
    },
    {
        "school": "BASIS Goodyear",
        "district": "BASIS Charter Schools Inc. (92734)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094103502",
    },
    {
        "school": "Ethos Academy- A Challenge Foundation Academy",
        "district": "Ethos Academy - A Challenge Foundation Academy (92379)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094203497",
    },
    {
        "school": "BASIS Goodyear Primary",
        "district": "BASIS Charter Schools Inc. (92736)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094303498",
    },
    {
        "school": "Leman Academy of Excellence",
        "district": "Leman Academy of Excellence Inc. (92730)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094403503",
    },
    {
        "school": "Dr. Gary and Annette Auxier Elementary School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187003479",
    },
    {
        "school": "Dr. Camille Casteel High School",
        "district": "Chandler Unified District #80 (4242)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40187003483",
    },
    {
        "school": "Bridges Elementary School",
        "district": "Higley Unified School District (4248)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40378003490",
    },
    {
        "school": "Las Brisas Academy",
        "district": "Liberty Elementary District (4266)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40432003480",
    },
    {
        "school": "Verrado Heritage Elementary School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438003478",
    },
    {
        "school": "Manson Mesa High School",
        "district": "Page Unified District (4196)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40582003492",
    },
    {
        "school": "Gateway Polytechnic Academy",
        "district": "Queen Creek Unified District (4245)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681003477",
    },
    {
        "school": "Maricopa Institute of Technology (MIT)",
        "district": "Riverside Elementary District (4257)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40702003485",
    },
    {
        "school": "Sonoran Foothills School",
        "district": "Deer Valley Unified District (4246)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40775003463",
    },
    {
        "school": "Gallego Intermediate Fine Arts Magnet School",
        "district": "Sunnyside Unified District (4407)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40817003500",
    },
    {
        "school": "Copper Ridge Elementary",
        "district": "Vail Unified District (4413)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885003489",
    },
    {
        "school": "EVIT - Arizona College Prep Erie Campus",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973103468",
    },
    {
        "school": "EVIT - Casteel High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973103487",
    },
    {
        "school": "CAPITOL CITY LIGHTHOUSE LOWER ACADEMY",
        "district": "CAPITOL CITY LIGHTHOUSE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041301613",
    },
    {
        "school": "HAAS HALL ACADEMY BENTONVILLE",
        "district": "HAAS HALL BENTONVILLE",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041601611",
    },
    {
        "school": "FARMINGTON FRESHMAN ACADEMY",
        "district": "FARMINGTON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50609001608",
    },
    {
        "school": "HARMONY GROVE JUNIOR HIGH SCHOOL",
        "district": "HARMONY GROVE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50732001616",
    },
    {
        "school": "NORPHLET MIDDLE SCHOOL",
        "district": "SMACKOVER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51251001607",
    },
    {
        "school": "FRANK MITCHELL INTERMEDIATE SCHOOL",
        "district": "VILONIA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51353001617",
    },
    {
        "school": "Melva Davis Academy of Excellence",
        "district": "Adelanto Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171013994",
    },
    {
        "school": "Hoover Elementary",
        "district": "Burlingame Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60648013999",
    },
    {
        "school": "Steindorf STEAM K-8 Magnet",
        "district": "Cambrian",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60714013993",
    },
    {
        "school": "Virginia R. Boris Elementary",
        "district": "Clovis Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60903013977",
    },
    {
        "school": "Compton Early College High",
        "district": "Compton Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60962013944",
    },
    {
        "school": "Ellen Ochoa Prep Academy",
        "district": "El Rancho Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61218013988",
    },
    {
        "school": "Dover Academy for International Studies",
        "district": "Fairfield-Suisun Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336013984",
    },
    {
        "school": "Dolores Huerta International Academy",
        "district": "Fontana Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61392014002",
    },
    {
        "school": "Trust Blended Learning",
        "district": "La Mesa-Spring Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62025013954",
    },
    {
        "school": "Fulton and Alsbury Academy of Arts and Engineering",
        "district": "Lancaster Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62088013989",
    },
    {
        "school": "Helen Keller Middle",
        "district": "Long Beach Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250013943",
    },
    {
        "school": "Girls Academic Leadership Acad Dr. Michelle King Sch STEM",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013968",
    },
    {
        "school": "Fourth Street Primary Center",
        "district": "Los Angeles Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013969",
    },
    {
        "school": "Science Academy STEM Magnet",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271013971",
    },
    {
        "school": "Creekside Junior High",
        "district": "Los Banos Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274013964",
    },
    {
        "school": "Maxwell Middle",
        "district": "Maxwell Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62415013945",
    },
    {
        "school": "Horizon Elementary",
        "district": "McFarland Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62423013991",
    },
    {
        "school": "Desert Learning Academy",
        "district": "Palm Springs Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62955013957",
    },
    {
        "school": "Innovations Academy of Palmdale",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62958013949",
    },
    {
        "school": "Palmdale Discovery Center",
        "district": "Palmdale Elementary",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "62958013975",
    },
    {
        "school": "Open Valley Independent Study",
        "district": "Patterson Joint Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63003013962",
    },
    {
        "school": "Clearwater Elementary",
        "district": "Perris Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63018013981",
    },
    {
        "school": "Rim Virtual",
        "district": "Rim of the World Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63261013953",
    },
    {
        "school": "Arroyo",
        "district": "San Carlos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63429013998",
    },
    {
        "school": "Double Peak",
        "district": "San Marcos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63488013965",
    },
    {
        "school": "Bella Vista Elementary",
        "district": "San Ramon Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63513013980",
    },
    {
        "school": "Central Park Elementary",
        "district": "Santa Clara Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63543013982",
    },
    {
        "school": "Justin Early Learners Academy",
        "district": "Simi Valley Unified",
        "level": "Not reported",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63684013955",
    },
    {
        "school": "Accelerated Charter High",
        "district": "Tulare Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63993013976",
    },
    {
        "school": "Heritage Elementary",
        "district": "Tustin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64015014003",
    },
    {
        "school": "Ridgeview Middle",
        "district": "Visalia Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116013978",
    },
    {
        "school": "Portola High",
        "district": "Irvine Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450013995",
    },
    {
        "school": "Beacon Park",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450013996",
    },
    {
        "school": "College and Career Preparatory Academy",
        "district": "Orange County Department of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102413959",
    },
    {
        "school": "Orange Vista High",
        "district": "Val Verde Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69113513992",
    },
    {
        "school": "CROWN POINTE CHARTER ACADEMY",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002001569",
    },
    {
        "school": "SALIDA MONTESSORI CHARTER SCHOOL",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006651",
    },
    {
        "school": "EARLY LEARNING CENTER AT NEW LEGACY CHARTER SCHOOL",
        "district": "State Charter School Institute",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006653",
    },
    {
        "school": "NEW LEGACY CHARTER SCHOOL",
        "district": "State Charter School Institute",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80002006661",
    },
    {
        "school": "PIKES PEAK ONLINE SCHOOL",
        "district": "EDUCATION REENVISIONED BOCES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80028206664",
    },
    {
        "school": "ZEBULON PIKE",
        "district": "DIVISION OF YOUTH SERVICES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80028606659",
    },
    {
        "school": "LOOKOUT MOUNTAIN",
        "district": "DIVISION OF YOUTH SERVICES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80028606668",
    },
    {
        "school": "JOURNEY K8",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006478",
    },
    {
        "school": "EDNA AND JOHN W. MOSLEY P-8",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006644",
    },
    {
        "school": "ENDEAVOR ACADEMY",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80291006649",
    },
    {
        "school": "NORTH FORK SCHOOL OF INTEGRATED STUDIES",
        "district": "Delta County Joint District No. 50",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80333006667",
    },
    {
        "school": "DENVER SCHOOL OF INNOVATION AND SUSTAINABLE DESIGN",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006640",
    },
    {
        "school": "REACH CHARTER SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006641",
    },
    {
        "school": "COMPASS ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006645",
    },
    {
        "school": "ROCKY MOUNTAIN PREP: SOUTHWEST",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006646",
    },
    {
        "school": "RISEUP COMMUNITY SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006647",
    },
    {
        "school": "KIPP NORTHEAST ELEMENTARY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006652",
    },
    {
        "school": "DSST: COLLEGE VIEW HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006658",
    },
    {
        "school": "NORTHFIELD HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006660",
    },
    {
        "school": "JOE SHOEMAKER SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006662",
    },
    {
        "school": "LEGACY OPTIONS HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006669",
    },
    {
        "school": "KIPP NORTHEAST DENVER LEADERSHIP ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006670",
    },
    {
        "school": "GLOBAL VILLAGE ACADEMY - DOUGLAS COUNTY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006656",
    },
    {
        "school": "World Compass Academy",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006666",
    },
    {
        "school": "EDISON PREP",
        "district": "Edison Joint District No. 54 of the counties of El Paso and",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80363006648",
    },
    {
        "school": "EARLY COLLEGE ACADEMY",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441006657",
    },
    {
        "school": "MOUNTAIN VISTA HOMESCHOOL ACADEMY",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453006663",
    },
    {
        "school": "ADDENBROOKE CLASSICAL GRAMMAR SCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006643",
    },
    {
        "school": "STEAMBOAT SPRINGS EARLY CHILDHOOD CENTER",
        "district": "Steamboat Springs School District No. Re 2",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80666006665",
    },
    {
        "school": "Windsor Charter Academy Early College High School",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735006650",
    },
    {
        "school": "Andover Elementary School",
        "district": "ANDOVER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90003010001",
    },
    {
        "school": "Ansonia High School",
        "district": "ANSONIA SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90006010002",
    },
    {
        "school": "Ansonia Middle School",
        "district": "ANSONIA SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90006010008",
    },
    {
        "school": "Pine Grove School",
        "district": "AVON SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90012010010",
    },
    {
        "school": "Stamford Charter School for Excellence",
        "district": "Stamford Charter School for Excellence District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90022001807",
    },
    {
        "school": "Capital Preparatory Harbor School",
        "district": "Capital Preparatory Harbor School District",
        "level": "Other",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90022101803",
    },
    {
        "school": "Darcey School",
        "district": "CHESHIRE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90075011188",
    },
    {
        "school": "Little Raiders University",
        "district": "DERBY SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90111001806",
    },
    {
        "school": "Litchfield Middle School",
        "district": "LITCHFIELD SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90222001809",
    },
    {
        "school": "Prospect Elementary School",
        "district": "REGIONAL SCHOOL DISTRICT 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353801811",
    },
    {
        "school": "Southington Public Schools Preschool Program at Hatton Schoo",
        "district": "SOUTHINGTON SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90423001808",
    },
    {
        "school": "Stratford Academy - Victoria Soto School",
        "district": "STRATFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90444001805",
    },
    {
        "school": "The Woodstock Academy",
        "district": "The Woodstock Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90537311223",
    },
    {
        "school": "Van Ness ES",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000505",
    },
    {
        "school": "River Terrace Education Campus",
        "district": "District of Columbia Public Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "DC",
        "nces_id": "110003000506",
    },
    {
        "school": "DC Prep PCS - Anacostia ES",
        "district": "DC Prep PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110004800501",
    },
    {
        "school": "Washington Leadership Academy PCS",
        "district": "Washington Leadership Academy PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110010300510",
    },
    {
        "school": "Breakthrough Montessori PCS",
        "district": "Breakthrough Montessori PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110010400507",
    },
    {
        "school": "Goodwill Excel Center PCS",
        "district": "Goodwill Excel Center PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110010500508",
    },
    {
        "school": "Rocketship DC PCS - Rise Academy",
        "district": "Rocketship DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110010600509",
    },
    {
        "school": "EARLY LEARNING ACADEMY AT DUVAL",
        "district": "ALACHUA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003008485",
    },
    {
        "school": "WEST BAY ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009008453",
    },
    {
        "school": "CENTRAL HIGH SCHOOL",
        "district": "BAY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120009008471",
    },
    {
        "school": "PINEAPPLE COVE CLASSICAL ACADEMY",
        "district": "BREVARD",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015008446",
    },
    {
        "school": "FRANKLIN ACADEMY PEMBROKE PINES HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008456",
    },
    {
        "school": "ATLANTIC MONTESSORI CHARTER SCHOOL WEST CAMPUS",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008462",
    },
    {
        "school": "ASCEND CAREER ACADEMY",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018008473",
    },
    {
        "school": "THE BEN GAMLA PREPARATORY ACADEMY",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008476",
    },
    {
        "school": "INNOVATION CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008489",
    },
    {
        "school": "HOSPITAL HOMEBOUND SERVICES",
        "district": "BROWARD",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120018008492",
    },
    {
        "school": "CLAY CHARTER ACADEMY",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030008437",
    },
    {
        "school": "AMIKIDS CLAY COUNTY",
        "district": "CLAY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120030008486",
    },
    {
        "school": "MATER INTERNATIONAL ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008463",
    },
    {
        "school": "ACADEMIR PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008481",
    },
    {
        "school": "SOMERSET PREPARATORY ACADEMY SUNSET",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008502",
    },
    {
        "school": "DOROTHY M. WALLACE COPE CENTER",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039010618",
    },
    {
        "school": "YOUNG MENS/WOMENS LEADERSHIP ACADEMY AT EUGENE J BUTLER",
        "district": "DUVAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008436",
    },
    {
        "school": "GRASP ACADEMY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048008447",
    },
    {
        "school": "RIVER CITY SCIENCE ACADEMY AT MANDARIN",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008497",
    },
    {
        "school": "DUVAL CHARTER SCHOOL AT FLAGLER CENTER",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008500",
    },
    {
        "school": "FLAGLER VIRTUAL INSTRUCTION(COURSE OFFERINGS)",
        "district": "FLAGLER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054008470",
    },
    {
        "school": "PREK ESE",
        "district": "GULF",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120069008466",
    },
    {
        "school": "MYDISTRICT VIRTUAL SCHOOL",
        "district": "HENDRY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078008458",
    },
    {
        "school": "EXCELSIOR PREP CHARTER SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008438",
    },
    {
        "school": "SUNLAKE ACADEMY OF MATH AND SCIENCES",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008460",
    },
    {
        "school": "JACKSON VIRTUAL FRANCHISE",
        "district": "JACKSON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096008478",
    },
    {
        "school": "NORTHERN PALMS CHARTER HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108008490",
    },
    {
        "school": "THE SCHOOL OF ARTS & SCIENCES CENTRE",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111008449",
    },
    {
        "school": "TALLAHASSEE SCHOOL OF MATH & SCIENCES",
        "district": "LEON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111008482",
    },
    {
        "school": "MADISON VIRTUAL INSTRUCTION PROGRAM",
        "district": "MADISON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120120008444",
    },
    {
        "school": "SCHOOL OF ACADEMIC AND BEHAVIORAL LEARNING EXCELLENCE (SABLE",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120123008501",
    },
    {
        "school": "WILDLIGHT ELEMENTARY",
        "district": "NASSAU",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120135008440",
    },
    {
        "school": "OKALOOSA VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120138008504",
    },
    {
        "school": "INNOVATION MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008443",
    },
    {
        "school": "BAY LAKE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008457",
    },
    {
        "school": "UCP WEST ORANGE CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144008474",
    },
    {
        "school": "EAGLE CREEK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008479",
    },
    {
        "school": "WESTPOINTE ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008480",
    },
    {
        "school": "LAUREATE PARK ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008493",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT GOLDENROD",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008503",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT TAPESTRY",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008498",
    },
    {
        "school": "FLORIDA FUTURES ACADEMY NORTH CAMPUS",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150008496",
    },
    {
        "school": "UNIVERSITY PREPARATORY ACADEMY PALM BEACH",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008499",
    },
    {
        "school": "PLATO ACADEMY TRINITY CHARTER SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008448",
    },
    {
        "school": "SHADY HILLS ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008450",
    },
    {
        "school": "REAL ACADEMY (REACHING EVERY ADOLESCENT LEARNER)",
        "district": "POLK",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159008455",
    },
    {
        "school": "POLK GRAD ACADEMY",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159008461",
    },
    {
        "school": "SKY ACADEMY ENGLEWOOD",
        "district": "SARASOTA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168008488",
    },
    {
        "school": "SEMINOLE SCIENCE CHARTER SCHOOL",
        "district": "SEMINOLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120171008494",
    },
    {
        "school": "LEGACY SCHOLARS ACADEMY",
        "district": "VOLUSIA",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120192008468",
    },
    {
        "school": "HOSPITAL HOMEBOUND",
        "district": "VOLUSIA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120192008483",
    },
    {
        "school": "Millegeville ITU",
        "district": "Department of Juvenile Justice",
        "level": "High",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130002604194",
    },
    {
        "school": "Therrell High School",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004215",
    },
    {
        "school": "Foothills Charter High School (Central Office - Athens)",
        "district": "State Charter Schools- Foothills Charter High School (Madiso",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130023504203",
    },
    {
        "school": "Scintilla Charter Academy",
        "district": "State Charter Schools- Scintilla Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130023604192",
    },
    {
        "school": "Dubois Integrity Academy",
        "district": "State Charter Schools- Dubois Integrity Academy I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130023704193",
    },
    {
        "school": "Georgia School for Innovation and the Classics",
        "district": "State Charter Schools- Georgia School for Innovation and the",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130023804205",
    },
    {
        "school": "Martin Luther King Jr Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042004198",
    },
    {
        "school": "Southfield Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042004204",
    },
    {
        "school": "McAllister Elementary School",
        "district": "Bryan County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130057004189",
    },
    {
        "school": "Rice Creek School",
        "district": "Savannah-Chatham County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102004185",
    },
    {
        "school": "Savannah Early College High School",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102004196",
    },
    {
        "school": "Peachcrest Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174004199",
    },
    {
        "school": "DAC (Dodge County Achievement Center)",
        "district": "Dodge County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130177004186",
    },
    {
        "school": "RISE Prep School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004187",
    },
    {
        "school": "College Park Elementary",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004201",
    },
    {
        "school": "RISE Grammar School",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004218",
    },
    {
        "school": "Baggett Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004181",
    },
    {
        "school": "Jordan Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004184",
    },
    {
        "school": "Graves Elementary School",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004210",
    },
    {
        "school": "Discovery High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004212",
    },
    {
        "school": "EXCEL Academy",
        "district": "Henry County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130282004214",
    },
    {
        "school": "Performance Learning Center",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438004221",
    },
    {
        "school": "Anna K. Davie Elementary",
        "district": "Rome City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130444004206",
    },
    {
        "school": "Stephens County Fifth Grade Academy",
        "district": "Stephens County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130456004209",
    },
    {
        "school": "Furlow Charter School",
        "district": "Sumter County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130462004197",
    },
    {
        "school": "ALTURAS INTERNATIONAL ACADEMY",
        "district": "FORRESTER ACADEMY INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160017501082",
    },
    {
        "school": "POCATELLO COMMUNITY CHARTER",
        "district": "THE POCATELLO COMMUNITY CHARTER SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160017600760",
    },
    {
        "school": "RIDGEVUE HIGH SCHOOL",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060001078",
    },
    {
        "school": "HILLSDALE ELEMENTARY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210001081",
    },
    {
        "school": "VICTORY MIDDLE SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210001084",
    },
    {
        "school": "GEM PREP: NAMPA",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234001080",
    },
    {
        "school": "GREENSFERRY ELEMENTARY SCHOOL",
        "district": "POST FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160267001085",
    },
    {
        "school": "PILLAR FALLS ELEMENTARY",
        "district": "TWIN FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324001075",
    },
    {
        "school": "ROCK CREEK ELEMENTARY",
        "district": "TWIN FALLS DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324001076",
    },
    {
        "school": "Social-Emotional Alt Program",
        "district": "Macon-Piatt Spec Educ Jnt Agr",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170006906364",
    },
    {
        "school": "Green Bay Early Childhood Center",
        "district": "North Chicago SD 187",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011006357",
    },
    {
        "school": "Mt Vernon Alternative School",
        "district": "Clintn/Jeffrsn/Marin/Washngtn ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017402806",
    },
    {
        "school": "Safe School Program",
        "district": "Clintn/Jeffrsn/Marin/Washngtn ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017402811",
    },
    {
        "school": "SUCCESS Academy",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106387",
    },
    {
        "school": "RAES East Alt Ed",
        "district": "Henderson/Knox/Mercer/Warren ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019206383",
    },
    {
        "school": "Morrison Alt Learning Program",
        "district": "Lee/Ogle/Whiteside ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019506388",
    },
    {
        "school": "Journeys South",
        "district": "Region III Spec Ed Coop",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170032506369",
    },
    {
        "school": "Bluford Grade School",
        "district": "Bluford Unit School District 318",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141706362",
    },
    {
        "school": "Webber High School",
        "district": "Bluford Unit School District 318",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141706393",
    },
    {
        "school": "Salt Fork North Elementary School",
        "district": "Salt Fork CUSD 512",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141806358",
    },
    {
        "school": "Salt Fork South Elementary School",
        "district": "Salt Fork CUSD 512",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141806372",
    },
    {
        "school": "Salt Fork Junior High School",
        "district": "Salt Fork CUSD 512",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141806384",
    },
    {
        "school": "Salt Fork High School",
        "district": "Salt Fork CUSD 512",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141806385",
    },
    {
        "school": "Spring Garden Elementary School",
        "district": "Spring Garden CCSD 178",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141906359",
    },
    {
        "school": "Spring Garden Middle School",
        "district": "Spring Garden CCSD 178",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170141906371",
    },
    {
        "school": "Northwest Academy",
        "district": "Northwest Sp Ed Cooperative",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142106382",
    },
    {
        "school": "Woodlawn Grade School",
        "district": "Woodlawn Unit School District 209",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170142206363",
    },
    {
        "school": "Woodlawn High School",
        "district": "Woodlawn Unit School District 209",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170142206373",
    },
    {
        "school": "LEARN Chtr  9 Campus in Waukegan",
        "district": "LEARN 9 Chtr  Campus in Waukegan",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170142306386",
    },
    {
        "school": "Addison Early Learning Center",
        "district": "Addison SD 4",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170315006390",
    },
    {
        "school": "Barrington Early Learning Center",
        "district": "Barrington CUSD 220",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170505006366",
    },
    {
        "school": "Washington School",
        "district": "Belleville SD 118",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170561006367",
    },
    {
        "school": "Gladness V Player ECC",
        "district": "Indian Springs SD 109",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170717006392",
    },
    {
        "school": "Moving Everest Charter School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006380",
    },
    {
        "school": "Southeast Learning Center",
        "district": "Decatur SD 61",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171185006370",
    },
    {
        "school": "Harmony Intermediate Center",
        "district": "Harmony Emge SD 175",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171422006379",
    },
    {
        "school": "Flora Elementary School",
        "district": "Flora CUSD 35",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171540006376",
    },
    {
        "school": "Washington Elem School",
        "district": "Harvard CUSD 50",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171842006365",
    },
    {
        "school": "Wingate Elementary School",
        "district": "Mascoutah CUD 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172494006381",
    },
    {
        "school": "Unity Middle School",
        "district": "CUSD 4",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172559006360",
    },
    {
        "school": "Lincoln Elem School",
        "district": "Mundelein ESD 75",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172754006361",
    },
    {
        "school": "Neoga Early Childhood Center",
        "district": "Neoga CUSD 3",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172784006389",
    },
    {
        "school": "Cherry Hill Elem and EC Center",
        "district": "New Lenox SD 122",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172814006375",
    },
    {
        "school": "Jefferson School",
        "district": "Park Ridge CCSD 64",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173084006374",
    },
    {
        "school": "Behavior Disorder Program Coop",
        "district": "Princeton ESD 115",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173267006377",
    },
    {
        "school": "Vandalia Junior High School",
        "district": "Vandalia CUSD 203",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174014006378",
    },
    {
        "school": "PALS",
        "district": "Belleville Area Special Services",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "174396306391",
    },
    {
        "school": "Tindley Genesis Academy",
        "district": "Tindley Genesis Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180014502595",
    },
    {
        "school": "Excel Center - University Heights",
        "district": "Excel Center - University Heights",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180015902592",
    },
    {
        "school": "Success Academy Primary School",
        "district": "Success Academy Primary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180016102583",
    },
    {
        "school": "Excel Center - Noblesville",
        "district": "Excel Center - Noblesville",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180016302576",
    },
    {
        "school": "Career Academy Middle School",
        "district": "Career Academy Middle School",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180016402593",
    },
    {
        "school": "Dugger Union Community School Corp",
        "district": "Dugger Union Community School Corp",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180016502590",
    },
    {
        "school": "Mays Community Academy",
        "district": "Mays Community Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180016802582",
    },
    {
        "school": "Excel Center - South Bend",
        "district": "Excel Center - South Bend",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180016902596",
    },
    {
        "school": "Eastern Middle School",
        "district": "Eastern Howard School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180315002589",
    },
    {
        "school": "Elkhart Alternative Education",
        "district": "Elkhart Community Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180327002585",
    },
    {
        "school": "Huntington Schools Preschool",
        "district": "Huntington Co Com Sch Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180471002598",
    },
    {
        "school": "Emma Donnan Elementary School",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002577",
    },
    {
        "school": "Arlington Community Middle School",
        "district": "Indianapolis Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002597",
    },
    {
        "school": "Oakland Elementary School",
        "district": "Lafayette School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180540002581",
    },
    {
        "school": "Ohio County Middle School",
        "district": "Rising Sun-Ohio Co Com",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180960002591",
    },
    {
        "school": "Fall Creek Junior High",
        "district": "Hamilton Southeastern Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065002580",
    },
    {
        "school": "Carlisle Middle School",
        "district": "Southwest School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181086002584",
    },
    {
        "school": "Riverside Elementary",
        "district": "Riverside Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190002710279",
    },
    {
        "school": "Keystone Elementary School",
        "district": "Benton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190483002227",
    },
    {
        "school": "Norway Elementary School",
        "district": "Benton Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190483002230",
    },
    {
        "school": "Washington Elementary School",
        "district": "Charles City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190708002221",
    },
    {
        "school": "Tiffin Elementary",
        "district": "Clear Creek Amana Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190759002229",
    },
    {
        "school": "Moore Elementary School",
        "district": "Des Moines Independent Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897002228",
    },
    {
        "school": "Garner-Hayfield-Ventura Middle School",
        "district": "Garner-Hayfield-Ventura Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191233002181",
    },
    {
        "school": "Alexander Elementary",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470002224",
    },
    {
        "school": "MMCRU Marcus Elementary",
        "district": "Marcus-Meriden-Cleghorn Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191863002226",
    },
    {
        "school": "Morningside Elementary",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640002220",
    },
    {
        "school": "Timberline School",
        "district": "Waukee Comm School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051002222",
    },
    {
        "school": "Woodward-Granger Early Learning Center",
        "district": "Woodward-Granger Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193201002223",
    },
    {
        "school": "Derby North Middle School",
        "district": "Derby",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200546002079",
    },
    {
        "school": "Guardian Angel",
        "district": "Beechwood Independent",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210036002409",
    },
    {
        "school": "Freedom Elementary School",
        "district": "Christian County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210115002415",
    },
    {
        "school": "Regional Programs School",
        "district": "Dayton Independent",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210153002413",
    },
    {
        "school": "Henry County Early Childhood",
        "district": "Henry County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210276002418",
    },
    {
        "school": "Hopkins Co Career & Technology Center",
        "district": "Hopkins County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210286002425",
    },
    {
        "school": "Minor Daniels Academy",
        "district": "Jefferson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299002412",
    },
    {
        "school": "Alex R. Kennedy Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299002421",
    },
    {
        "school": "Summit View Academy",
        "district": "Kenton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210309002420",
    },
    {
        "school": "Reidland Intermediate School",
        "district": "McCracken County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210396002419",
    },
    {
        "school": "Owensboro Innovation Academy",
        "district": "Owensboro Independent",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210459002411",
    },
    {
        "school": "Buckhorn Childrens Center",
        "district": "Perry County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210477002422",
    },
    {
        "school": "Beacon Academy",
        "district": "Warren County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210573002410",
    },
    {
        "school": "Sophie B. Wright Institute of Academic Excellence",
        "district": "Sophie B. Wright Institute of Academic Excellence",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018600981",
    },
    {
        "school": "Success Preparatory Academy",
        "district": "Success Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018702283",
    },
    {
        "school": "The NET Charter High School",
        "district": "The NET Charter High School",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018802340",
    },
    {
        "school": "Southwest Louisiana Charter Academy",
        "district": "Southwest Louisiana Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220018902349",
    },
    {
        "school": "Impact Charter School",
        "district": "Impact Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220019002386",
    },
    {
        "school": "Arthur Ashe Charter School",
        "district": "Arthur Ashe Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220019200947",
    },
    {
        "school": "ReNEW Dolores T. Aaron Elementary",
        "district": "ReNEW Dolores T. Aaron Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220019502021",
    },
    {
        "school": "Celerity Dalton Charter School",
        "district": "Celerity Dalton Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220019602383",
    },
    {
        "school": "KIPP Renaissance",
        "district": "KIPP Renaissance",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220019700953",
    },
    {
        "school": "Lake Charles College Prep",
        "district": "Lake Charles College Prep",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220019802388",
    },
    {
        "school": "James M. Singleton Charter School",
        "district": "James M. Singleton Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220019901208",
    },
    {
        "school": "Morris Jeff Community School",
        "district": "Morris Jeff Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220020302297",
    },
    {
        "school": "Langston Hughes Charter Academy",
        "district": "Langston Hughes Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220020600976",
    },
    {
        "school": "Lord Beaconsfield Landry-Oliver Perry Walker High",
        "district": "Lord Beaconsfield Landry-Oliver Perry Walker High",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220020700972",
    },
    {
        "school": "Akili Academy of New Orleans",
        "district": "Akili Academy of New Orleans",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220020802071",
    },
    {
        "school": "KIPP Leadership",
        "district": "KIPP Leadership",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021102307",
    },
    {
        "school": "Arise Academy",
        "district": "Arise Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021202278",
    },
    {
        "school": "Louisiana Key Academy",
        "district": "Louisiana Key Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021302366",
    },
    {
        "school": "JS Clark Leadership Academy",
        "district": "JS Clark Leadership Academy",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021502348",
    },
    {
        "school": "KIPP Believe",
        "district": "KIPP Believe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021600958",
    },
    {
        "school": "Dr. Martin Luther King Charter School for Sci Tech",
        "district": "Dr Martin Luther King Charter School for Sci Tech",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021700414",
    },
    {
        "school": "Iberville Charter Academy",
        "district": "Iberville Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220021902395",
    },
    {
        "school": "Harriet Tubman Charter School",
        "district": "Harriet Tubman Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220022000946",
    },
    {
        "school": "ReNew Accelerated High School",
        "district": "ReNEW Accelerated High School",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220022102323",
    },
    {
        "school": "Lafayette Academy",
        "district": "Lafayette Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220022400914",
    },
    {
        "school": "Pierre A. Capdau Charter School at Avery Alexander",
        "district": "Pierre A. Capdau Charter School at Avery Alexander",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220022500860",
    },
    {
        "school": "Celerity Lanier Charter School",
        "district": "Celerity Lanier Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220022602391",
    },
    {
        "school": "Mary D. Coghill Charter School",
        "district": "Mary D. Coghill Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220022802357",
    },
    {
        "school": "GEO Prep Academy of Greater Baton Rouge",
        "district": "GEO Prep Academy of Greater Baton Rouge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220023002420",
    },
    {
        "school": "Acadiana Renaissance Charter Academy",
        "district": "Acadiana Renaissance Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220023102392",
    },
    {
        "school": "Louisiana Virtual Charter Academy",
        "district": "Louisiana Virtual Charter Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220023302320",
    },
    {
        "school": "Lafayette Renaissance Charter Academy",
        "district": "Lafayette Charter Foundation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220023502396",
    },
    {
        "school": "Martin Behrman Charter Acad of Creative Arts & Sci",
        "district": "Martin Behrman Charter Acad of Creative Arts & Sci",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220023600853",
    },
    {
        "school": "Abramson Sci Academy",
        "district": "Abramson Sci Academy",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220023702068",
    },
    {
        "school": "Walter L. Cohen College Prep",
        "district": "Walter L. Cohen College Prep",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220023802341",
    },
    {
        "school": "JCFA-East",
        "district": "JCFA-East",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024102370",
    },
    {
        "school": "ReNEW SciTech Academy at Laurel",
        "district": "ReNEW SciTech Academy at Laurel",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024200917",
    },
    {
        "school": "Paul Habans Charter School",
        "district": "Paul Habans Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024302362",
    },
    {
        "school": "Joseph A. Craig Charter School",
        "district": "Joseph A. Craig Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024500870",
    },
    {
        "school": "KIPP Central City",
        "district": "KIPP Central City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024602079",
    },
    {
        "school": "Delta Charter School MST",
        "district": "Delta Charter Group",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024702354",
    },
    {
        "school": "KIPP East Community",
        "district": "KIPP East Community",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024802401",
    },
    {
        "school": "Mildred Osborne Charter School",
        "district": "Mildred Osborne Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024902367",
    },
    {
        "school": "Esperanza Charter School",
        "district": "Esperanza Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220025000872",
    },
    {
        "school": "Northeast Claiborne Charter",
        "district": "Northeast Claiborne Charter",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220025202397",
    },
    {
        "school": "Phillis Wheatley Community School",
        "district": "Phillis Wheatley Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220025300877",
    },
    {
        "school": "Democracy Prep Baton Rouge",
        "district": "Democracy Prep Baton Rouge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220025402408",
    },
    {
        "school": "ReNEW Schaumburg Elementary",
        "district": "ReNEW Schaumburg Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220025502376",
    },
    {
        "school": "Kenilworth Science and Technology Charter School",
        "district": "Kenilworth Science and Technology Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220025800389",
    },
    {
        "school": "Samuel J. Green Charter School",
        "district": "Samuel J. Green Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220025900897",
    },
    {
        "school": "Baton Rouge University Preparatory Elementary",
        "district": "Baton Rouge University Preparatory Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220026002390",
    },
    {
        "school": "John F. Kennedy High School",
        "district": "John F. Kennedy High School",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220026102277",
    },
    {
        "school": "KIPP Morial",
        "district": "KIPP Morial",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220026200932",
    },
    {
        "school": "Willow Charter Academy",
        "district": "Willow Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220026302405",
    },
    {
        "school": "G W Carver High School",
        "district": "G W Carver High School",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220026502334",
    },
    {
        "school": "Lawrence D. Crocker College Prep",
        "district": "Lawrence D. Crocker College Prep",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220026602352",
    },
    {
        "school": "Fannie C. Williams Charter School",
        "district": "Fannie C. Williams Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220026702062",
    },
    {
        "school": "Advantage Charter Academy",
        "district": "Advantage Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220026802385",
    },
    {
        "school": "Kingston Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027002409",
    },
    {
        "school": "Pathways in Education - North market",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030002413",
    },
    {
        "school": "Vincent Settlement Elementary School",
        "district": "Calcasieu Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220033010320",
    },
    {
        "school": "Laureate Academy Charter School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002411",
    },
    {
        "school": "Frederick Douglass Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002416",
    },
    {
        "school": "Bonella A. St. Ville Elementary School",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002417",
    },
    {
        "school": "Jefferson RISE Charter School",
        "district": "Jefferson Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002419",
    },
    {
        "school": "Springfield Middle School",
        "district": "Livingston Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102010339",
    },
    {
        "school": "Christian Acres Alternative School",
        "district": "Madison Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220105010412",
    },
    {
        "school": "Foundation Preparatory",
        "district": "Orleans Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220117002412",
    },
    {
        "school": "Phoenix Magnet Elementary School",
        "district": "Rapides Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220129010374",
    },
    {
        "school": "Pontchartrain Elementary School",
        "district": "St. Tammany Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165010400",
    },
    {
        "school": "Tchefuncte Middle School",
        "district": "St. Tammany Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220165010403",
    },
    {
        "school": "Florida Parishes Juvenile Detention Cntr.",
        "district": "Tangipahoa Parish",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "LA",
        "nces_id": "220168010414",
    },
    {
        "school": "Wiscasset Middle/High School",
        "district": "Wiscasset Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231398023146",
    },
    {
        "school": "Wiscasset Elementary School",
        "district": "Wiscasset Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231398023148",
    },
    {
        "school": "St George School",
        "district": "St George Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231482000710",
    },
    {
        "school": "Maine Virtual Academy",
        "district": "Maine Virtual Academy",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231482123147",
    },
    {
        "school": "Troy A Howard Middle School",
        "district": "RSU 71",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231482200048",
    },
    {
        "school": "Belfast Area High School",
        "district": "RSU 71",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231482200440",
    },
    {
        "school": "East Belfast School",
        "district": "RSU 71",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231482200443",
    },
    {
        "school": "Gladys Weymouth Elem School",
        "district": "RSU 71",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231482200446",
    },
    {
        "school": "Kermit S Nickerson School",
        "district": "RSU 71",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231482200448",
    },
    {
        "school": "Ames Elementary School",
        "district": "RSU 71",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231482200450",
    },
    {
        "school": "Captain Albert W. Stevens School",
        "district": "RSU 71",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231482200556",
    },
    {
        "school": "Andover Elementary School",
        "district": "Andover Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231482300505",
    },
    {
        "school": "Edna Drinkwater School",
        "district": "Northport Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231482400444",
    },
    {
        "school": "Studio 39",
        "district": "Anne Arundel County Public Schools",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240006001728",
    },
    {
        "school": "Mary Moss at Adams Academy",
        "district": "Anne Arundel County Public Schools",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240006001729",
    },
    {
        "school": "Lillie May Carroll Jackson School",
        "district": "Baltimore City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001734",
    },
    {
        "school": "Bard High School Early College",
        "district": "Baltimore City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001735",
    },
    {
        "school": "Baltimore Collegiate School for Boys",
        "district": "Baltimore City Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001736",
    },
    {
        "school": "Lyons Mill Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001730",
    },
    {
        "school": "Sparrows Point Middle",
        "district": "Baltimore County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012010500",
    },
    {
        "school": "Daniel of St. Thomas Jenifer Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027010501",
    },
    {
        "school": "S. Christa McAuliffe Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048010502",
    },
    {
        "school": "Jones Lane Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048010503",
    },
    {
        "school": "Kenmoor Early Childhood Center",
        "district": "Prince George's County Public Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MD",
        "nces_id": "240051001731",
    },
    {
        "school": "International High school @ Largo",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001737",
    },
    {
        "school": "International High School @ Langley Park",
        "district": "Prince George's County Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240051001738",
    },
    {
        "school": "Captain Walter Francis Duke Elementary",
        "district": "St. Mary's County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240060001732",
    },
    {
        "school": "Powder Mill School",
        "district": "Southwick-Tolland-Granville Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250001302845",
    },
    {
        "school": "Springfield Preparatory Charter School",
        "district": "Springfield Preparatory Charter School (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250055702842",
    },
    {
        "school": "Bentley Academy Charter School",
        "district": "Bentley Academy Charter School (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250055802844",
    },
    {
        "school": "Amesbury Innovation High School",
        "district": "Amesbury",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250186002841",
    },
    {
        "school": "Swanson Road Intermediate School",
        "district": "Auburn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250222002846",
    },
    {
        "school": "Enoch Cobb Early Learning Center",
        "district": "Barnstable",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250231002851",
    },
    {
        "school": "McKeown School",
        "district": "Beverly",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250264002854",
    },
    {
        "school": "Boston Collaborative High School",
        "district": "Boston",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250279002848",
    },
    {
        "school": "Stone PK-12 School",
        "district": "Fall River",
        "level": "Other",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250483002852",
    },
    {
        "school": "Lawrence High School",
        "district": "Lawrence",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250666002856",
    },
    {
        "school": "Forestdale School",
        "district": "Sandwich",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251047002857",
    },
    {
        "school": "Early Childhood Education Center",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002853",
    },
    {
        "school": "Van Sickle Academy",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002855",
    },
    {
        "school": "Rise Academy at Van Sickle",
        "district": "Springfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002859",
    },
    {
        "school": "Webster Middle School",
        "district": "Webster",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251224002849",
    },
    {
        "school": "Murdock Academy for Success",
        "district": "Winchendon",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "251308002843",
    },
    {
        "school": "R. H. Conwell",
        "district": "Worthington",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251326002850",
    },
    {
        "school": "Black River Public School Elementary",
        "district": "Black River Public School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260011408728",
    },
    {
        "school": "Detroit Edison Public School Academy  High School",
        "district": "Detroit Edison Public School Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260023208742",
    },
    {
        "school": "Tipton Academy  48",
        "district": "Tipton Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260103608745",
    },
    {
        "school": "Grand River Preparatory High  School",
        "district": "Grand River Preparatory High School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260109507913",
    },
    {
        "school": "Light of the World Academy",
        "district": "Light of the World Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260109608751",
    },
    {
        "school": "Gateway To Success Academy",
        "district": "Gateway To Success Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260109708715",
    },
    {
        "school": "Augusta Academy",
        "district": "Augusta Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260109808720",
    },
    {
        "school": "Kalamazoo Covenant Academy",
        "district": "Kalamazoo Covenant Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260109908744",
    },
    {
        "school": "Keys Grace Academy",
        "district": "Keys Grace Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110008739",
    },
    {
        "school": "Cornerstone JeffersonDouglass Academy",
        "district": "Cornerstone Jefferson-Douglass Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110108714",
    },
    {
        "school": "Bangor Township Virtual School",
        "district": "Bangor Township Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260390008729",
    },
    {
        "school": "Success  Grand Rapids Fuller Ave",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008711",
    },
    {
        "school": "Success  Belding",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008730",
    },
    {
        "school": "Success  St Louis",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008736",
    },
    {
        "school": "Charlotte Early Middle College",
        "district": "Charlotte Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260877008723",
    },
    {
        "school": "Galewood Early Elementary School",
        "district": "Charlotte Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260877008737",
    },
    {
        "school": "Clintondale Virtual Academy",
        "district": "Clintondale Community Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261008008749",
    },
    {
        "school": "Satterlee School",
        "district": "Greenville Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261716008750",
    },
    {
        "school": "Hartford Alternative Education",
        "district": "Hartford Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261788008746",
    },
    {
        "school": "South Central Michigan Virtual",
        "district": "Jackson Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261962008719",
    },
    {
        "school": "Milan Alternative Education",
        "district": "Milan Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262385008718",
    },
    {
        "school": "Romulus Virtual Learning Center",
        "district": "Romulus Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263012008721",
    },
    {
        "school": "UCS Alternative Learning Center",
        "district": "Utica Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263447008727",
    },
    {
        "school": "Wolverine Education Center",
        "district": "Tuscola ISD",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268098008716",
    },
    {
        "school": "SOAR",
        "district": "RUNESTONE AREA ED. DISTRICT",
        "level": "Middle",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270001604931",
    },
    {
        "school": "ALC - Gateway - EY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504887",
    },
    {
        "school": "ALC - W-ALT - EY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504901",
    },
    {
        "school": "ALC - NECA - EY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504922",
    },
    {
        "school": "Headway Academy North",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504929",
    },
    {
        "school": "Oak Hills High School",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504941",
    },
    {
        "school": "ALC - SECA - EY",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002504957",
    },
    {
        "school": "Red Rock Ridge Mid-Level ALC",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270008604895",
    },
    {
        "school": "NSEC Transition Program",
        "district": "NORTHLAND LEARNING CENTER",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270022404892",
    },
    {
        "school": "ISD 361 - ALC Program",
        "district": "NORTHLAND LEARNING CENTER",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270022404905",
    },
    {
        "school": "KIPP North Star Primary",
        "district": "KIPP MINNESOTA CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270030804898",
    },
    {
        "school": "CHOICE Technical Academy",
        "district": "TECHNICAL ACADEMIES OF MINNESOTA",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038904954",
    },
    {
        "school": "Monticello High School - SNW",
        "district": "SHERBURNE AND NORTHERN WRIGHT SPECI",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041304890",
    },
    {
        "school": "Monticello Middle School - SNW",
        "district": "SHERBURNE AND NORTHERN WRIGHT SPECI",
        "level": "Middle",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041304909",
    },
    {
        "school": "Eastview Elementary School - SNW",
        "district": "SHERBURNE AND NORTHERN WRIGHT SPECI",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041304919",
    },
    {
        "school": "North Metro Flex Academy",
        "district": "North Metro Flex Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270042304942",
    },
    {
        "school": "Alexander Learning Academy",
        "district": "Cannon Valley Special Education Coo",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270042404938",
    },
    {
        "school": "FIT Academy",
        "district": "FIT Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270042504902",
    },
    {
        "school": "Pankalo Education Center",
        "district": "NORTHEAST METRO 916",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270226404951",
    },
    {
        "school": "Belle Plaine Transitions/Work Exper",
        "district": "BELLE PLAINE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270405004955",
    },
    {
        "school": "BYRON PRIMARY SCHOOL",
        "district": "BYRON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270735004958",
    },
    {
        "school": "Prairie View Elementary School",
        "district": "Elk River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137004932",
    },
    {
        "school": "Kennedy Middle School",
        "district": "FERGUS FALLS PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271188004944",
    },
    {
        "school": "MNVSS",
        "district": "HENDRICKS PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271368004925",
    },
    {
        "school": "Litchfield Early Childhood Special",
        "district": "LITCHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271821004888",
    },
    {
        "school": "LUVERNE ALTERNATIVE PROGRAM",
        "district": "LUVERNE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271833012683",
    },
    {
        "school": "Marshall Learning Center",
        "district": "MARSHALL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271894004914",
    },
    {
        "school": "Wellstone High School - SWS",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004889",
    },
    {
        "school": "Plymouth Youth Center Extended",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004900",
    },
    {
        "school": "Heritage STEM Academy",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004903",
    },
    {
        "school": "Roosevelt High School - SWS",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004907",
    },
    {
        "school": "MERC Extended",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004924",
    },
    {
        "school": "Henry High School - SWS",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004928",
    },
    {
        "school": "American Indian OIC Extended",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004930",
    },
    {
        "school": "Loring Nicollet Extended",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004934",
    },
    {
        "school": "Center School Extended",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004937",
    },
    {
        "school": "Volunteers of America Extended",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004945",
    },
    {
        "school": "Menlo Park Academy Extended",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004948",
    },
    {
        "school": "Red River ALC - Barnesville 146",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272142004915",
    },
    {
        "school": "PrairieCare Maplewood",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272385004943",
    },
    {
        "school": "Princeton Online Academy",
        "district": "PRINCETON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273003004927",
    },
    {
        "school": "The FAIR School - Crystal",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178004952",
    },
    {
        "school": "Project Search Mayo Clinic",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273180004899",
    },
    {
        "school": "Saints Online",
        "district": "St. Francis Area Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273354004917",
    },
    {
        "school": "Early Ed Frost Lake",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384004891",
    },
    {
        "school": "Laketown Elementary",
        "district": "WACONIA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274146004916",
    },
    {
        "school": "Cannon Falls HS Credit Recovery",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279144304886",
    },
    {
        "school": "Red Wing HS Credit Recovery",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279144304908",
    },
    {
        "school": "Goodhue High School Credit Recovery",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279144304913",
    },
    {
        "school": "REIMAGINE PREP",
        "district": "REIMAGINE PREP",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018801442",
    },
    {
        "school": "HENDERSON/WARD-STEWART ELEMENTARY",
        "district": "STARKVILLE- OKTIBBEHA CONS DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018901438",
    },
    {
        "school": "SUDDUTH ELEMENTARY SCHOOL",
        "district": "STARKVILLE- OKTIBBEHA CONS DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018901440",
    },
    {
        "school": "WEST ELEMENTARY SCHOOL",
        "district": "STARKVILLE- OKTIBBEHA CONS DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018901446",
    },
    {
        "school": "STARKVILLE HIGH SCHOOL",
        "district": "STARKVILLE- OKTIBBEHA CONS DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018901451",
    },
    {
        "school": "ARMSTRONG MIDDLE SCHOOL",
        "district": "STARKVILLE- OKTIBBEHA CONS DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018901453",
    },
    {
        "school": "MILLSAPS CAREER & TECH CENTER",
        "district": "STARKVILLE- OKTIBBEHA CONS DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280018901458",
    },
    {
        "school": "THE LEARNING CENTER ALTERNATIVE",
        "district": "STARKVILLE- OKTIBBEHA CONS DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280018901459",
    },
    {
        "school": "MIDTOWN PUBLIC CHARTER SCHOOL",
        "district": "MIDTOWN PUBLIC CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019001448",
    },
    {
        "school": "WEST POINT HIGH SCHOOL",
        "district": "WEST POINT CONSOLIDATED SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019101441",
    },
    {
        "school": "EAST SIDE ELEMENTARY SCHOOL",
        "district": "WEST POINT CONSOLIDATED SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019101443",
    },
    {
        "school": "FIFTH STREET SCHOOL",
        "district": "WEST POINT CONSOLIDATED SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019101445",
    },
    {
        "school": "WEST CLAY ELEMENTARY SCHOOL",
        "district": "WEST POINT CONSOLIDATED SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019101447",
    },
    {
        "school": "SOUTH SIDE ELEMENTARY SCHOOL",
        "district": "WEST POINT CONSOLIDATED SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019101449",
    },
    {
        "school": "CHURCH HILL ELEMENTARY SCHOOL",
        "district": "WEST POINT CONSOLIDATED SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019101455",
    },
    {
        "school": "WEST POINT VOC COMP",
        "district": "WEST POINT CONSOLIDATED SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280019101457",
    },
    {
        "school": "WEST POINT LEARNING CENTER",
        "district": "WEST POINT CONSOLIDATED SCHOOL DIST",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280019101461",
    },
    {
        "school": "CANTON PUBLIC 9TH GRADE SCHOOL",
        "district": "CANTON PUBLIC SCHOOL DIST",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280090001465",
    },
    {
        "school": "LILLIE BURNEY STEAM ACADEMY",
        "district": "HATTIESBURG PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280180001444",
    },
    {
        "school": "HAZLEHURST ELEMENTARY SCHOOL",
        "district": "HAZLEHURST CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280183001464",
    },
    {
        "school": "GOLDEN TRIANGLE EARLY COLLEGE",
        "district": "LOWNDES CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280273001460",
    },
    {
        "school": "MANNSDALE UPPER ELEMENTARY",
        "district": "MADISON CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280279001439",
    },
    {
        "school": "SUMMIT ELEMENTARY SCHOOL",
        "district": "MCCOMB SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280288001456",
    },
    {
        "school": "TAC ALTERNATIVE SCHOOL",
        "district": "MCCOMB SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280288001463",
    },
    {
        "school": "PONTOTOC CO ALTERNATIVE PROGRAM",
        "district": "PONTOTOC CO SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280366001466",
    },
    {
        "school": "GROVE STREET ACADEMIES",
        "district": "VICKSBURG WARREN SCHOOL DIST",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280447001462",
    },
    {
        "school": "KIPP WISDOM ACADEMY",
        "district": "KIPP ST LOUIS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059103266",
    },
    {
        "school": "KIPP TRIUMPH ACADEMY",
        "district": "KIPP ST LOUIS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059103270",
    },
    {
        "school": "EWING MARION KAUFFMAN HIGH",
        "district": "EWING MARION KAUFFMAN SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059703277",
    },
    {
        "school": "EAGLE FOX PARK",
        "district": "EAGLE COLLEGE PREP ENDEAVOR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060503272",
    },
    {
        "school": "HAWTHORN MIDDLE",
        "district": "HAWTHORN LEADERSHIP SCHL GIRLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060803274",
    },
    {
        "school": "LA SALLE CHARTER SCHOOL",
        "district": "LA SALLE CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290061103281",
    },
    {
        "school": "PRIMARY GRADES CAMPUS",
        "district": "CITIZENS OF THE WORLD CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290061203286",
    },
    {
        "school": "ELIOT BATTLE ELEMENTARY",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100003271",
    },
    {
        "school": "CALHOUN EARLY CHILDHOOD CTR.",
        "district": "CALHOUN R-VIII",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290648003284",
    },
    {
        "school": "CAMERON INTERMEDIATE SCHOOL",
        "district": "CAMERON R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290702003267",
    },
    {
        "school": "MIKE CLEMENS CENTER ADAPT LRNG",
        "district": "FT. ZUMWALT R-II",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "290837003282",
    },
    {
        "school": "EAST ELEMENTARY",
        "district": "JACKSON R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291560003265",
    },
    {
        "school": "LADUE EARLY CHILDHOOD CENTER",
        "district": "LADUE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291782003279",
    },
    {
        "school": "EARLY CHILDHOOD ED CENTER WEST",
        "district": "LINDBERGH SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291869003278",
    },
    {
        "school": "LOCKWOOD MIDDLE SCHOOL",
        "district": "LOCKWOOD R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291914003283",
    },
    {
        "school": "NORMANDY EARLY LEARNING CENTER",
        "district": "NORMANDY SCHOOLS COLLABORATIVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292265003269",
    },
    {
        "school": "NAHED CHAPMAN NEW AMERICAN ACA",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292928003276",
    },
    {
        "school": "EDUC THERAP SUPPORT AT MADISON",
        "district": "ST. LOUIS CITY",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292928003280",
    },
    {
        "school": "WRIGHT START PRESCHOOL",
        "district": "WRIGHT CITY R-II OF WARREN CO.",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293231003273",
    },
    {
        "school": "White Sulphur Springs El",
        "district": "White Sulphur Spgs K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302877000802",
    },
    {
        "school": "White Sulphur Springs 7-8",
        "district": "White Sulphur Spgs K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302877001006",
    },
    {
        "school": "Yellowstone Academy 7-8",
        "district": "Yellowstone Academy Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302886001114",
    },
    {
        "school": "Equipo Academy",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100856",
    },
    {
        "school": "Rainbow Dreams Academy Secondary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000855",
    },
    {
        "school": "Eleanor Lemaire Junior High School",
        "district": "LANDER COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320024000866",
    },
    {
        "school": "Innovations High School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320048000869",
    },
    {
        "school": "Mason Elementary School",
        "district": "Mason School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330327610027",
    },
    {
        "school": "Making Community Connections Charter School - Monadnock",
        "district": "Making Community Connections Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330328900720",
    },
    {
        "school": "Compass Classical Academy Charter School (E)",
        "district": "Compass Classical Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330330100718",
    },
    {
        "school": "MicroSociety Academy Charter School Foundation",
        "district": "MicroSociety Academy Charter School of Southern NH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330330200721",
    },
    {
        "school": "Lempster Community School",
        "district": "Lempster School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330330300719",
    },
    {
        "school": "South Hunterdon Regional High School",
        "district": "South Hunterdon Regional School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340076903036",
    },
    {
        "school": "West Amwell Township School",
        "district": "South Hunterdon Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340076903048",
    },
    {
        "school": "College Achieve Central Charter School",
        "district": "College Achieve Central Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340077903353",
    },
    {
        "school": "Empowerment Academy Charter School",
        "district": "Empowerment Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340078103335",
    },
    {
        "school": "Bridgeton Public Charter School",
        "district": "Bridgeton Public Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340078203371",
    },
    {
        "school": "Principle Academy Charter School",
        "district": "Principle Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340078303345",
    },
    {
        "school": "Applied Technology High School",
        "district": "Bergen County Vocational Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340147003341",
    },
    {
        "school": "Smalley Elementary School",
        "district": "Bound Brook School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340210003331",
    },
    {
        "school": "Community Middle School",
        "district": "Bound Brook School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340210003340",
    },
    {
        "school": "Lafayette Elementary School",
        "district": "Bound Brook School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340210003360",
    },
    {
        "school": "Piner Elementary School",
        "district": "Lakewood Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340822003357",
    },
    {
        "school": "North Plainfield Middle School",
        "district": "North Plainfield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341164003337",
    },
    {
        "school": "Northern Valley Central",
        "district": "Northern Valley Regional High School District",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341176003359",
    },
    {
        "school": "Passaic Gifted and Talented Academy School No. 20",
        "district": "Passaic City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254003365",
    },
    {
        "school": "Garrett Morgan Academy",
        "district": "Paterson Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003370",
    },
    {
        "school": "Montrose Early Childhood Center",
        "district": "South Orange-Maplewood School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341533003339",
    },
    {
        "school": "Raymond J. Lesniak Experience Strength & Hope Recovery HS",
        "district": "Union County Vocational-Technical School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "341804003363",
    },
    {
        "school": "GEORGE I SANCHEZ",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001114",
    },
    {
        "school": "LAS MONTANAS CHARTER",
        "district": "LAS MONTANAS CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350016801019",
    },
    {
        "school": "MONTE DEL SOL CHARTER",
        "district": "MONTE DEL SOL CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350017000816",
    },
    {
        "school": "TURQUOISE TRAIL CHARTER SCHOOL",
        "district": "TURQUOISE TRAIL CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350017130008",
    },
    {
        "school": "SANDOVAL ACADEMY OF BILINGUAL EDUCATION",
        "district": "SANDOVAL ACADEMY OF BILINGUAL EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350017201116",
    },
    {
        "school": "TIERRA ENCANTADA CHARTER SCHOOL",
        "district": "TIERRA ENCANTADA CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350017300950",
    },
    {
        "school": "DZIT DIT LOOL SCHOOL OF EMPOWERMENT ACTION AND PERSEVERANCE",
        "district": "DZIT DIT LOOL SCHOOL OF EMPOWERMENT ACTION AND PERSEVERANCE",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350017401113",
    },
    {
        "school": "JUDY NELSON ELEMENTARY",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039001115",
    },
    {
        "school": "MURRAY ELEMENTARY",
        "district": "HOBBS MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350126001111",
    },
    {
        "school": "ALLEGANY CO SHERIFF C/O TREASURER",
        "district": "GENESEE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360001706539",
    },
    {
        "school": "WEST END SECONDARY SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007806547",
    },
    {
        "school": "MATILDA AVENUE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806559",
    },
    {
        "school": "STEAM BRIDGE SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #11",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008806562",
    },
    {
        "school": "MS 839",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009206567",
    },
    {
        "school": "ROSE M SINGER CENTER",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #24",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360009806544",
    },
    {
        "school": "MS 358",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006548",
    },
    {
        "school": "QUEENS SCHOOL FOR LEADERSHIP AND EXCELLENCE (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #28",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010006564",
    },
    {
        "school": "PS 360",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #29",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010106550",
    },
    {
        "school": "WOODSIDE COMMUNITY SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010206554",
    },
    {
        "school": "KATHLEEN GRIMM SCHOOL FOR LEADERSHIP",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306546",
    },
    {
        "school": "BRONX CHARTER SCHOOL FOR BETTER LEARNING II",
        "district": "BRONX CHARTER SCHOOL FOR BETTER LEARNING II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360112706551",
    },
    {
        "school": "FINN ACADEMY: AN ELMIRA CHARTER SCHOOL",
        "district": "FINN ACADEMY: AN ELMIRA CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360112806541",
    },
    {
        "school": "ROSALYN YALOW CHARTER SCHOOL",
        "district": "ROSALYN YALOW CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360112906566",
    },
    {
        "school": "NEW VENTURES CHARTER SCHOOL",
        "district": "NEW VENTURES CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360113006565",
    },
    {
        "school": "SOUTH BRONX EARLY COLLEGE ACADEMY CHARTER SCHOOL",
        "district": "SOUTH BRONX EARLY COLLEGE ACADEMY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360113106555",
    },
    {
        "school": "SOUTH BRONX CLASSICAL CHARTER SCHOOL III",
        "district": "SOUTH BRONX CLASSICAL CHARTER SCHOOL III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360113206570",
    },
    {
        "school": "CHARTER HIGH SCHOOL FOR LAW AND SOCIAL JUSTICE",
        "district": "CHARTER HIGH SCHOOL FOR LAW AND SOCIAL JUSTICE",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360113306569",
    },
    {
        "school": "INTERNATIONAL CHARTER SCHOOL OF NEW YORK (THE)",
        "district": "INTERNATIONAL CHARTER SCHOOL OF NEW YORK (THE)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360113406558",
    },
    {
        "school": "CHARTER SCHOOL OF INQUIRY",
        "district": "CHARTER SCHOOL OF INQUIRY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360113506543",
    },
    {
        "school": "NEW VISIONS CHTR HS-ADV MA/SCI IV",
        "district": "NEW VISIONS CHTR HS-ADV MA/SCI IV",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360113606549",
    },
    {
        "school": "STOREFRONT ACADEMY CHARTER SCHOOL",
        "district": "STOREFRONT ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360113706552",
    },
    {
        "school": "ATMOSPHERE ACADEMY PUBLIC CHARTER SCHOOL",
        "district": "ATMOSPHERE ACADEMY PUBLIC CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360113806563",
    },
    {
        "school": "CAP DIST JUVENILE SECURE DETENTION",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360246006537",
    },
    {
        "school": "WARREN STREET ACADEMY",
        "district": "BERKSHIRE UNION FREE SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360459006542",
    },
    {
        "school": "FORT ANN ELEMENTARY SCHOOL",
        "district": "FORT ANN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361128006545",
    },
    {
        "school": "LIVINGSTON COUNTY JAIL",
        "district": "GENESEO CENTRAL SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "361194006556",
    },
    {
        "school": "A MACARTHUR BARR MIDDLE SCHOOL 5-6 ACADEMY FOR EXCELLENCE",
        "district": "NANUET UNION FREE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362019006553",
    },
    {
        "school": "RICHFIELD SPRINGS JUNIOR/SENIOR HIGH SCHOOL",
        "district": "RICHFIELD SPRINGS CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362457006560",
    },
    {
        "school": "EAST LOWER SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475006561",
    },
    {
        "school": "YONKERS EARLY CHILDHOOD ACADEMY",
        "district": "YONKERS CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "363192006557",
    },
    {
        "school": "Alexander Early College",
        "district": "Alexander County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370009003396",
    },
    {
        "school": "Concord Lake STEAM Academy",
        "district": "Concord Lake STEAM Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039903387",
    },
    {
        "school": "Iredell Charter Academy",
        "district": "Iredell Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370040003398",
    },
    {
        "school": "Union Prep Academy at Indian Trail",
        "district": "Union Preparatory Academy at Indian Trai",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370040103400",
    },
    {
        "school": "Peak Charter Academy",
        "district": "Peak Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370040203386",
    },
    {
        "school": "Union Day School",
        "district": "Union Day School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370040303399",
    },
    {
        "school": "FernLeaf Community Charter School",
        "district": "FernLeaf Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370040403401",
    },
    {
        "school": "Matthews Charter Academy",
        "district": "Matthews Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370040503392",
    },
    {
        "school": "Central Wake High School",
        "district": "Central Wake Charter High School",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370040603403",
    },
    {
        "school": "Girls Leadership Academy of Wilmington",
        "district": "Girls Leadership Academy of Wilmington",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370040703397",
    },
    {
        "school": "Gate City Charter",
        "district": "Gate City Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370040803404",
    },
    {
        "school": "Unity Classical Charter",
        "district": "Unity Classical Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370040903393",
    },
    {
        "school": "Mallard Creek STEM Academy",
        "district": "Mallard Creek STEM Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370041003390",
    },
    {
        "school": "Enka Intermediate",
        "district": "Buncombe County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045003383",
    },
    {
        "school": "W R Odell Elementary",
        "district": "Cabarrus County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053003384",
    },
    {
        "school": "Cabarrus Early College of Technology",
        "district": "Cabarrus County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053003407",
    },
    {
        "school": "Camden Early College High",
        "district": "Camden County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370060003391",
    },
    {
        "school": "Chatham School of Science & Engineering",
        "district": "Chatham County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075003406",
    },
    {
        "school": "Oak Grove High",
        "district": "Davidson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370114003389",
    },
    {
        "school": "South Granville High",
        "district": "Granville County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180003385",
    },
    {
        "school": "Micro Elementary",
        "district": "Johnston County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237003395",
    },
    {
        "school": "Johnston County Schools Career Technical",
        "district": "Johnston County Public Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NC",
        "nces_id": "370237003408",
    },
    {
        "school": "Charlotte-Mecklenburg Virtual HS",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003405",
    },
    {
        "school": "Northampton Early College",
        "district": "Northampton County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370342003388",
    },
    {
        "school": "Person Early College Innovation & Ldrshp",
        "district": "Person County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370363003394",
    },
    {
        "school": "White Oak Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003377",
    },
    {
        "school": "Pleasant Grove Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003378",
    },
    {
        "school": "Pine Hollow Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003379",
    },
    {
        "school": "Oakview Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003380",
    },
    {
        "school": "Beaverdam Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003381",
    },
    {
        "school": "Crossroads FLEX",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003402",
    },
    {
        "school": "Wilson Academy of Applied Technology",
        "district": "Wilson County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370502003382",
    },
    {
        "school": "GRANT COLONY SCHOOL",
        "district": "ENDERLIN AREA 24",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380006100884",
    },
    {
        "school": "EAGLES ELEMENTARY SCHOOL",
        "district": "FARGO 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380678000881",
    },
    {
        "school": "JOHN HOEVEN ELEMENTARY SCHOOL",
        "district": "MINOT 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381303000879",
    },
    {
        "school": "BROOKS HARBOR ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000885",
    },
    {
        "school": "BAKKEN ELEMENTARY SCHOOL",
        "district": "WILLISTON 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381988000882",
    },
    {
        "school": "Citizens Academy Southeast",
        "district": "Citizens Academy Southeast",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390157005844",
    },
    {
        "school": "Stonebrook Montessori",
        "district": "Stonebrook Montessori",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390157105849",
    },
    {
        "school": "Flex High School",
        "district": "Flex High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390157405852",
    },
    {
        "school": "iSTEM Geauga Early College High School",
        "district": "iSTEM Geauga Early College High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390157505858",
    },
    {
        "school": "Zenith Academy West",
        "district": "Zenith Academy West",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390157605848",
    },
    {
        "school": "Tri-State STEM+M Early College High School",
        "district": "Tri-State STEM+M Early College High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390157705854",
    },
    {
        "school": "John Marshall School of Information Technology",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805865",
    },
    {
        "school": "John Marshall School of Business and Civic Leadership",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805867",
    },
    {
        "school": "John Marshall School of Engineering",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805868",
    },
    {
        "school": "Stevenson Elementary School",
        "district": "Heath City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441110729",
    },
    {
        "school": "Lincoln Pre-Kindergarten School",
        "district": "Tiffin City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448905860",
    },
    {
        "school": "Willoughby-Eastlake Preschool",
        "district": "Willoughby-Eastlake City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451005869",
    },
    {
        "school": "Barnesville Middle School",
        "district": "Barnesville Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390452010822",
    },
    {
        "school": "New Albany Intermediate School",
        "district": "New Albany-Plain Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469905847",
    },
    {
        "school": "Ledgemont Elementary",
        "district": "Berkshire Local",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471605861",
    },
    {
        "school": "Beavercreek City School Preschool",
        "district": "Beavercreek City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472405851",
    },
    {
        "school": "Woodmore Middle School",
        "district": "Woodmore Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390495705855",
    },
    {
        "school": "Tuscarawas Valley Middle School",
        "district": "Tuscarawas Valley Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390503010724",
    },
    {
        "school": "Kings Mills Educational Center",
        "district": "Kings Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504305862",
    },
    {
        "school": "Butler Tech Bioscience Center",
        "district": "Butler Technology & Career Development Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390508805845",
    },
    {
        "school": "Instructional Resource Center",
        "district": "Great Oaks Career Campuses",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390510605846",
    },
    {
        "school": "Knox County Career Center 4",
        "district": "Knox County JVSD",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390511405870",
    },
    {
        "school": "Findlay Learning Center",
        "district": "Findlay City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000005863",
    },
    {
        "school": "OYA CHARTER MANITOU 6TH-8TH",
        "district": "OKLAHOMA YOUTH ACADEMY",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "OK",
        "nces_id": "400078902806",
    },
    {
        "school": "OYA CHARTER MANITOU 9TH-12TH",
        "district": "OKLAHOMA YOUTH ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OK",
        "nces_id": "400078902808",
    },
    {
        "school": "OYA CHARTER TECUMSEH 9TH-12TH",
        "district": "OKLAHOMA YOUTH ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OK",
        "nces_id": "400078902813",
    },
    {
        "school": "OYA CHARTER TECUMSEH 6TH-8TH",
        "district": "OKLAHOMA YOUTH ACADEMY",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "OK",
        "nces_id": "400078902815",
    },
    {
        "school": "COLLEGE BOUND ACADEMY CHARTER",
        "district": "COLLEGE BOUND(CHARTER)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079102827",
    },
    {
        "school": "TULSA HONOR ACADEMY CHARTER",
        "district": "HONOR ACADEMY(CHARTER)",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079202822",
    },
    {
        "school": "COLLEGIATE HALL CHARTER SCHOOL",
        "district": "COLLEGIATE HALL(CHARTER)",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079302818",
    },
    {
        "school": "CASHION MS",
        "district": "CASHION",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400681002816",
    },
    {
        "school": "CAVE SPRINGS MS",
        "district": "CAVE SPRINGS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400693002823",
    },
    {
        "school": "CLINTON HS",
        "district": "CLINTON",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400807010335",
    },
    {
        "school": "WILSON 6TH GRADE CENTER",
        "district": "COLLINSVILLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400837002807",
    },
    {
        "school": "COLLINSVILLE UPPER ES",
        "district": "COLLINSVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400837002809",
    },
    {
        "school": "HERALD ES",
        "district": "COLLINSVILLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400837002824",
    },
    {
        "school": "CUSHING UPPER ES",
        "district": "CUSHING",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400924002810",
    },
    {
        "school": "CUSHING LOWER ES",
        "district": "CUSHING",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400924002825",
    },
    {
        "school": "HERITAGE ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059002819",
    },
    {
        "school": "CROSS TIMBERS ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059010484",
    },
    {
        "school": "WASHINGTON IRVING ES",
        "district": "EDMOND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059010485",
    },
    {
        "school": "FREEDOM ES",
        "district": "LAWTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401725002828",
    },
    {
        "school": "TIMBER CREEK ES",
        "district": "MOORE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025002817",
    },
    {
        "school": "SOUTHRIDGE JHS",
        "district": "MOORE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402025002821",
    },
    {
        "school": "SKIATOOK ES",
        "district": "SKIATOOK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402775002812",
    },
    {
        "school": "Sexton Mountain Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192011348",
    },
    {
        "school": "Pacific Crest Middle School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001839",
    },
    {
        "school": "Silver Rail Elementary School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001844",
    },
    {
        "school": "Bend International School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001845",
    },
    {
        "school": "Barnes Butte Elementary",
        "district": "Crook County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410372001840",
    },
    {
        "school": "Brothers Elementary School",
        "district": "Crook County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410372001841",
    },
    {
        "school": "The Valley School of Southern Oregon",
        "district": "Medford SD 549C",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410804001843",
    },
    {
        "school": "Oregon Connections Academy",
        "district": "Santiam Canyon SD 129J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410810001680",
    },
    {
        "school": "Ferndale Elementary School",
        "district": "Milton-Freewater Unified SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410816001842",
    },
    {
        "school": "Insight School of Oregon Painted Hills",
        "district": "Mitchell SD 55",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410828001813",
    },
    {
        "school": "Pendleton Early Learning Center",
        "district": "Pendleton SD 16",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410951001838",
    },
    {
        "school": "Arts Academy Elementary Charter School",
        "district": "Arts Academy Elementary Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420088307561",
    },
    {
        "school": "Young Scholars of McKeesport Charter Sch",
        "district": "Young Scholars of McKeesport Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420088407552",
    },
    {
        "school": "Vision Academy Charter School",
        "district": "Vision Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420088507564",
    },
    {
        "school": "KIPP DuBois Charter School",
        "district": "KIPP DuBois Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420088607568",
    },
    {
        "school": "Armstrong JSHS",
        "district": "Armstrong SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420259007569",
    },
    {
        "school": "Butler Area SHS",
        "district": "Butler Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420459007554",
    },
    {
        "school": "Butler MS",
        "district": "Butler Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420459007555",
    },
    {
        "school": "Carmichaels Area MS",
        "district": "Carmichaels Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420507007550",
    },
    {
        "school": "Logan El Sch",
        "district": "East Allegheny SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420806007558",
    },
    {
        "school": "East Allegheny JSHS",
        "district": "East Allegheny SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420806007559",
    },
    {
        "school": "Easton Area MS",
        "district": "Easton Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420885007563",
    },
    {
        "school": "Freedom Area MS",
        "district": "Freedom Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421038007565",
    },
    {
        "school": "Freedom Area El Sch",
        "district": "Freedom Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421038007570",
    },
    {
        "school": "Freeport Area MS",
        "district": "Freeport Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421044007566",
    },
    {
        "school": "J.A. Allard El Sch",
        "district": "Moon Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421583007556",
    },
    {
        "school": "Panther Valley JSHS",
        "district": "Panther Valley SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421845007560",
    },
    {
        "school": "Panther Valley Intermediate Sch",
        "district": "Panther Valley SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421845007567",
    },
    {
        "school": "Holiday Park El Sch",
        "district": "Plum Borough SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421935007557",
    },
    {
        "school": "Hamilton Twp El Sch",
        "district": "Stroudsburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422286007571",
    },
    {
        "school": "West Greene El Ctr",
        "district": "West Greene SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422544007551",
    },
    {
        "school": "Wallace El Sch",
        "district": "West York Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422598007572",
    },
    {
        "school": "Founders Academy",
        "district": "Beacon Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440000800493",
    },
    {
        "school": "Blackstone Valley Prep Element",
        "district": "Blackstone Valley Prep  A RI Mayoral Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440001500496",
    },
    {
        "school": "Achievement First Iluminar",
        "district": "Achievement First Rhode Island",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440002100495",
    },
    {
        "school": "RISE Prep Mayoral Academy",
        "district": "RISE Prep Mayoral Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440002900494",
    },
    {
        "school": "The Pell Annex @ John F. Kenne",
        "district": "Newport",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440072000500",
    },
    {
        "school": "360 High School",
        "district": "Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000492",
    },
    {
        "school": "Evolutions High School",
        "district": "Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000497",
    },
    {
        "school": "Westerly Inclusion Preschool P",
        "district": "Westerly",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440117000499",
    },
    {
        "school": "Fairfax Elementary",
        "district": "Allendale 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450075001661",
    },
    {
        "school": "River Ridge Academy",
        "district": "Beaufort 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001662",
    },
    {
        "school": "May River High",
        "district": "Beaufort 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450111001666",
    },
    {
        "school": "Nexton Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001658",
    },
    {
        "school": "Philip Simmons Middle",
        "district": "Berkeley 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001670",
    },
    {
        "school": "Philip Simmons Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001671",
    },
    {
        "school": "Simmons Pinckney Middle",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001660",
    },
    {
        "school": "Deer Park Middle",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001667",
    },
    {
        "school": "Dr. Eugene Sires Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001673",
    },
    {
        "school": "Alston-Bailey Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001674",
    },
    {
        "school": "Sand Hill Elementary",
        "district": "Dorchester 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450201001675",
    },
    {
        "school": "Child Development Center at Woods Road",
        "district": "Florence 01",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213001657",
    },
    {
        "school": "Shoally Creek Elementary",
        "district": "Spartanburg 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450351001669",
    },
    {
        "school": "Meeting Street Academy-Spartanburg",
        "district": "Spartanburg 07",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450366001664",
    },
    {
        "school": "Oakridge Elementary",
        "district": "York 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450384001672",
    },
    {
        "school": "Tall Pines STEM Academy",
        "district": "SC Public Charter School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101665",
    },
    {
        "school": "Mike Miller Elementary - 07",
        "district": "Aberdeen School District 06-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460207001367",
    },
    {
        "school": "Arlington Preschool - 04",
        "district": "Arlington School District 38-1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460372001381",
    },
    {
        "school": "Graceville Colony - 07",
        "district": "Chester Area School District 39-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461230001377",
    },
    {
        "school": "Elk Mountain High School - 04",
        "district": "Elk Mountain School District 16-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462130001371",
    },
    {
        "school": "Bridgewater-Emery Elementary - 02",
        "district": "Bridgewater-Emery 30-3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462142010071",
    },
    {
        "school": "Horizon Elementary - 09",
        "district": "Harrisburg School District 41-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463135001375",
    },
    {
        "school": "Madison 2-3 Center - 19",
        "district": "Huron School District 02-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463548001369",
    },
    {
        "school": "Buchanan K-1 Center - 18",
        "district": "Huron School District 02-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463548001370",
    },
    {
        "school": "Washington 4-5 Center - 20",
        "district": "Huron School District 02-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463548001373",
    },
    {
        "school": "ARISE Shelter Care - 71",
        "district": "Sioux Falls School District 49-5",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "466627001368",
    },
    {
        "school": "Todd County Achievement High School - 17",
        "district": "Todd County School District 66-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "467209001376",
    },
    {
        "school": "Watertown Intermediate School - 13",
        "district": "Watertown School District 14-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467662001378",
    },
    {
        "school": "Wessington Springs Middle School Cyber School - 93",
        "district": "Wessington Springs School District 36-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467746001372",
    },
    {
        "school": "Wessington Springs High School Cyber School - 92",
        "district": "Wessington Springs School District 36-2",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467746001374",
    },
    {
        "school": "Wessington Springs Elementary Cyber School - 94",
        "district": "Wessington Springs School District 36-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467746001380",
    },
    {
        "school": "Black Hills Academy at Canyon Hills - 08",
        "district": "Black Hills Special Services Cooperative",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "468012001366",
    },
    {
        "school": "Yankton Middle School - 02",
        "district": "Yankton School District 63-3",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043010799",
    },
    {
        "school": "Alcoa Intermediate School",
        "district": "Alcoa",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470006002445",
    },
    {
        "school": "Cornerstone Prep Denver Campus",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014701046",
    },
    {
        "school": "Memphis Scholars Florida Kansas",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014701140",
    },
    {
        "school": "Wooddale Middle School",
        "district": "Achievement School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014701187",
    },
    {
        "school": "KIPP Memphis Preparatory Elementary",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702436",
    },
    {
        "school": "Libertas School",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702437",
    },
    {
        "school": "Neely's Bend: A LEAD Public School",
        "district": "Achievement School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702456",
    },
    {
        "school": "Power Center Academy Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802429",
    },
    {
        "school": "Exceptional Children Special Placements",
        "district": "Shelby County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802430",
    },
    {
        "school": "The Excel Center",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802443",
    },
    {
        "school": "Granville T. Woods Academy of Innovation Charter School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802452",
    },
    {
        "school": "Leadership Preparatory Charter School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802455",
    },
    {
        "school": "Riverside Academy",
        "district": "Cheatham County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470057002454",
    },
    {
        "school": "Chattanooga Charter School of Excellence Middle",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159002434",
    },
    {
        "school": "Emerald Academy",
        "district": "Knox County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222002448",
    },
    {
        "school": "Delk-Henson Intermediate School",
        "district": "Marshall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470267002440",
    },
    {
        "school": "Oakland Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303002444",
    },
    {
        "school": "Kenwood Middle",
        "district": "Montgomery County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470303010361",
    },
    {
        "school": "Cason Lane Academy",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315010374",
    },
    {
        "school": "STEM Prep High School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002431",
    },
    {
        "school": "Valor Voyager Academy",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002432",
    },
    {
        "school": "Smith Springs Elementary School",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002435",
    },
    {
        "school": "Strive Collegiate Academy",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002439",
    },
    {
        "school": "Knowledge Academies High School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002442",
    },
    {
        "school": "RePublic High School",
        "district": "Davidson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002446",
    },
    {
        "school": "Explore Community School",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002449",
    },
    {
        "school": "KIPP Academy Nashville Elementary School",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002451",
    },
    {
        "school": "Rocketship United",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002453",
    },
    {
        "school": "Waverly-Belmont Elementary School",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002457",
    },
    {
        "school": "Crestview Elementary School",
        "district": "Robertson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360002450",
    },
    {
        "school": "Northview Junior Academy",
        "district": "Sevier County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378002438",
    },
    {
        "school": "Greenbrier Alternative Learning Center",
        "district": "Sevier County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470378010389",
    },
    {
        "school": "Whites Adult High School",
        "district": "Sevier County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470378010397",
    },
    {
        "school": "Dr. William Burrus Elementary at Drakes Creek",
        "district": "Sumner County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470402002427",
    },
    {
        "school": "Sumner County Middle Technical College High School at Portla",
        "district": "Sumner County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "TN",
        "nces_id": "470402002433",
    },
    {
        "school": "Tipton County Alternative Learning Center",
        "district": "Tipton County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470408010410",
    },
    {
        "school": "Warren County Alternative Academy",
        "district": "Warren County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TN",
        "nces_id": "470435010412",
    },
    {
        "school": "Nolensville High School",
        "district": "Williamson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002428",
    },
    {
        "school": "Woodland Middle School",
        "district": "Williamson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453010413",
    },
    {
        "school": "Wilson Co Adult High School",
        "district": "Wilson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455010415",
    },
    {
        "school": "GEORGE I SANCHEZ NORTH",
        "district": "GEORGE I SANCHEZ CHARTER",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480002013387",
    },
    {
        "school": "UPLIFT PEAK PREPARATORY PRI",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003011186",
    },
    {
        "school": "UPLIFT PEAK PREPARATORY MIDDLE",
        "district": "UPLIFT EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003011187",
    },
    {
        "school": "UPLIFT WILLIAMS PREPARATORY H S",
        "district": "UPLIFT EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012012",
    },
    {
        "school": "UPLIFT WILLIAMS PREPARATORY PRI",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012026",
    },
    {
        "school": "UPLIFT WILLIAMS PREPARATORY MIDDLE",
        "district": "UPLIFT EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012035",
    },
    {
        "school": "UPLIFT PEAK PREPARATORY H S",
        "district": "UPLIFT EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012139",
    },
    {
        "school": "UPLIFT SUMMIT INTERNATIONAL H S",
        "district": "UPLIFT EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012175",
    },
    {
        "school": "UPLIFT HAMPTON PREPARATORY PRI",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012185",
    },
    {
        "school": "UPLIFT HAMPTON PREPARATORY MIDDLE",
        "district": "UPLIFT EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012188",
    },
    {
        "school": "UPLIFT HAMPTON PREPARATORY H S",
        "district": "UPLIFT EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012200",
    },
    {
        "school": "UPLIFT SUMMIT INTERNATIONAL PRI",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012231",
    },
    {
        "school": "UPLIFT SUMMIT INTERNATIONAL MIDDLE",
        "district": "UPLIFT EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012239",
    },
    {
        "school": "UPLIFT HEIGHTS PREPARATORY MIDDLE",
        "district": "UPLIFT EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012270",
    },
    {
        "school": "UPLIFT LUNA PREPARATORY PRI",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012457",
    },
    {
        "school": "UPLIFT MIGHTY SCHOOL",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012645",
    },
    {
        "school": "UPLIFT MERIDIAN SCHOOL",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012646",
    },
    {
        "school": "UPLIFT HEIGHTS PREPARATORY PRI",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012647",
    },
    {
        "school": "UPLIFT PINNACLE PREPARATORY PRI",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012700",
    },
    {
        "school": "UPLIFT TRIUMPH PREPARATORY SCHOOL",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003012998",
    },
    {
        "school": "UPLIFT HEIGHTS PREPARATORY H S",
        "district": "UPLIFT EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013058",
    },
    {
        "school": "UPLIFT LUNA PREPARATORY H S",
        "district": "UPLIFT EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013197",
    },
    {
        "school": "UPLIFT GRADUS PREPARATORY",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013275",
    },
    {
        "school": "CUMBERLAND H S",
        "district": "CUMBERLAND ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003413330",
    },
    {
        "school": "WAYSIDE ALTAMIRA ACADEMY",
        "district": "WAYSIDE SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480004413290",
    },
    {
        "school": "EXCEL ACADEMY EDUCATION TRANSITION CENTER",
        "district": "EXCEL ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480004913289",
    },
    {
        "school": "JHW INSPIRE ACADEMY - WILLIAMS HOUSE",
        "district": "INSPIRE ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480005313326",
    },
    {
        "school": "JHW INSPIRE ACADEMY - LEGACY RANCH",
        "district": "INSPIRE ACADEMIES",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480005313328",
    },
    {
        "school": "LIFE MIDDLE WAXAHACHIE",
        "district": "LIFE SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480005513347",
    },
    {
        "school": "UNLIMITED VISIONS AFTERCARE",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007113286",
    },
    {
        "school": "AUSTIN OAKS",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007113287",
    },
    {
        "school": "UNIVERSITY H S",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007113292",
    },
    {
        "school": "GEORGETOWN BEHAVIORAL HEALTH INSTITUTE",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007113297",
    },
    {
        "school": "SHRINERS HOSPITALS FOR CHILDREN",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007113298",
    },
    {
        "school": "OAK CLIFF FAITH FAMILY ACADEMY",
        "district": "WAXAHACHIE FAITH FAMILY ACADEMY",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480010513356",
    },
    {
        "school": "ODYSSEY ACADEMY - BAY AREA",
        "district": "ODYSSEY ACADEMY INC",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480010813274",
    },
    {
        "school": "FOUNDERS CLASSICAL ACADEMY OF FLOWER MOUND",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313318",
    },
    {
        "school": "CORINTH CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313320",
    },
    {
        "school": "MAINLAND PREPARATORY ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313322",
    },
    {
        "school": "FOUNDERS CLASSICAL ACADEMY OF MESQUITE",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313327",
    },
    {
        "school": "PREMIER H S OF PFLUGERVILLE",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020713281",
    },
    {
        "school": "PREMIER HIGH SCHOOLS CAREER & TECHNICAL ED CENTER",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020713282",
    },
    {
        "school": "PREMIER H S OF EAST EL PASO",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020713288",
    },
    {
        "school": "PREMIER H S ONLINE",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020713294",
    },
    {
        "school": "YES PREP - SOUTHSIDE",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020913206",
    },
    {
        "school": "IDEA RUNDBERG ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113220",
    },
    {
        "school": "IDEA RUNDBERG COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113223",
    },
    {
        "school": "IDEA RIVERVIEW ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113225",
    },
    {
        "school": "IDEA NORTH MISSION ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113230",
    },
    {
        "school": "IDEA EASTSIDE COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113231",
    },
    {
        "school": "IDEA NORTH MISSION COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113237",
    },
    {
        "school": "IDEA EASTSIDE ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113238",
    },
    {
        "school": "IDEA RIVERVIEW COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113239",
    },
    {
        "school": "CEDARS ACADEMY NEXT GENERATION H S AT HIGHLAND",
        "district": "CEDARS INTERNATIONAL ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023213382",
    },
    {
        "school": "HARMONY SCHOOL OF EXCELLENCE - SAN ANTONIO",
        "district": "HARMONY SCIENCE ACAD (SAN ANTONIO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026613261",
    },
    {
        "school": "HARMONY SCHOOL OF ACHIEVEMENT - HOUSTON",
        "district": "HARMONY SCHOOL OF EXCELLENCE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027413269",
    },
    {
        "school": "THE RHODES SCHOOL - SOUTHEAST",
        "district": "THE RHODES SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480028313323",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - CARROLLTON",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029213362",
    },
    {
        "school": "TEXAS LEADERSHIP OF ABILENE",
        "district": "TEXAS LEADERSHIP",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140913213",
    },
    {
        "school": "NEWMAN INTERNATIONAL AT CEDAR HILL",
        "district": "NEWMAN INTERNATIONAL ACADEMY OF ARLINGTON",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142113295",
    },
    {
        "school": "ILTEXAS NORTH RICHLAND HILLS MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013257",
    },
    {
        "school": "ILTEXAS NORTH RICHLAND HILLS EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013258",
    },
    {
        "school": "ILTEXAS KATY EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013259",
    },
    {
        "school": "ILTEXAS KELLER SAGINAW H S",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013260",
    },
    {
        "school": "ILTEXAS GRAND PRAIRIE MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013262",
    },
    {
        "school": "ILTEXAS WESTPARK EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013264",
    },
    {
        "school": "ILTEXAS GRAND PRAIRIE EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013266",
    },
    {
        "school": "ILTEXAS WESTPARK MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013267",
    },
    {
        "school": "ILTEXAS KATY MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013268",
    },
    {
        "school": "GREAT HEARTS IRVING",
        "district": "GREAT HEARTS TEXAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144113211",
    },
    {
        "school": "GREAT HEARTS NORTHERN OAKS",
        "district": "GREAT HEARTS TEXAS",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144113216",
    },
    {
        "school": "PIONEER TECHNOLOGY (PTAA) MESQUITE",
        "district": "PIONEER TECHNOLOGY & ARTS ACADEMY",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145113251",
    },
    {
        "school": "LONE STAR LANGUAGE ACADEMY",
        "district": "LONE STAR LANGUAGE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145213339",
    },
    {
        "school": "A+ UNLIMITED POTENTIAL - UNIVERSITY",
        "district": "A+ UNLIMITED POTENTIAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145313369",
    },
    {
        "school": "A+ UNLIMITED POTENTIAL - MUSEUM DISTRICT",
        "district": "A+ UNLIMITED POTENTIAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145313374",
    },
    {
        "school": "SAM HOUSTON STATE UNIVERSITY CHARTER SCHOOL",
        "district": "SAM HOUSTON STATE UNIVERSITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145413263",
    },
    {
        "school": "KAUFFMAN LEADERSHIP ACADEMY",
        "district": "KAUFFMAN LEADERSHIP ACADEMY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480145513372",
    },
    {
        "school": "ACADEMY EL",
        "district": "ACADEMY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480747013381",
    },
    {
        "school": "DREW ACADEMY",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771017014",
    },
    {
        "school": "KERR H S",
        "district": "ALIEF ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480783015742",
    },
    {
        "school": "BRAZORIA CO ALTER ED CTR",
        "district": "ANGLETON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480831016825",
    },
    {
        "school": "MCNUTT EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870013241",
    },
    {
        "school": "PATRICK EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870013242",
    },
    {
        "school": "PEACH EL",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870013249",
    },
    {
        "school": "JONES FINE ARTS / DUAL LANGUAGE ACADEMY",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870013254",
    },
    {
        "school": "AUSTIN ISD CHILD DEVELOPMENT CENTER",
        "district": "AUSTIN ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894013344",
    },
    {
        "school": "DAVIS EL",
        "district": "AUSTIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894022775",
    },
    {
        "school": "HIGHPOINT",
        "district": "BARBERS HILL ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480945013300",
    },
    {
        "school": "VINCENT MIDDLE",
        "district": "BEAUMONT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967017011",
    },
    {
        "school": "RASCO MIDDLE",
        "district": "BRAZOSPORT ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119016928",
    },
    {
        "school": "STEAM MIDDLE",
        "district": "BURLESON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218013317",
    },
    {
        "school": "CLARENDON J H",
        "district": "CLARENDON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481416016942",
    },
    {
        "school": "NORTH POINTE EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428017006",
    },
    {
        "school": "MONTANA VISTA EL",
        "district": "CLINT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481443016990",
    },
    {
        "school": "COLLINSVILLE EL",
        "district": "COLLINSVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481458013265",
    },
    {
        "school": "COMANCHE EARLY CHILDHOOD CENTER",
        "district": "COMANCHE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481476013272",
    },
    {
        "school": "CONNALLY EARLY CHILDHOOD CENTER",
        "district": "CONNALLY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481497013354",
    },
    {
        "school": "SUCHMA EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500013346",
    },
    {
        "school": "DONALD J STOCKTON JH",
        "district": "CONROE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500013348",
    },
    {
        "school": "CLARK INT",
        "district": "CONROE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500013349",
    },
    {
        "school": "BRADLEY EL",
        "district": "CONROE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500013352",
    },
    {
        "school": "JJAEP",
        "district": "CONROE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481500017045",
    },
    {
        "school": "GRANT MIDDLE",
        "district": "CORPUS CHRISTI ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481527017052",
    },
    {
        "school": "HILL COUNTY JJAEP",
        "district": "COVINGTON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481548013380",
    },
    {
        "school": "ZAVALA EL",
        "district": "CRYSTAL CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481593013378",
    },
    {
        "school": "CYPRESS PARK H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611013325",
    },
    {
        "school": "AULT EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611016970",
    },
    {
        "school": "D A HULCY STEAM MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013316",
    },
    {
        "school": "SOLAR PREPARATORY SCHOOL FOR GIRLS AT BONHAM",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013321",
    },
    {
        "school": "N W HARLLEE EARLY CHILDHOOD CENTER",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013324",
    },
    {
        "school": "INNOVATION DESIGN ENTREPRENEURSHIP ACADEMY",
        "district": "DALLAS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013331",
    },
    {
        "school": "ARLINGTON PARK EARLY CHILDHOOD CENTER",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013333",
    },
    {
        "school": "PREK PARTNERSHIP CENTER",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013334",
    },
    {
        "school": "FAIRMONT J H",
        "district": "DEER PARK ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481653016972",
    },
    {
        "school": "CATHERINE BELL EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674013270",
    },
    {
        "school": "RAY BRASWELL H S",
        "district": "DENTON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674013273",
    },
    {
        "school": "AMBER TERRACE DISCOVERY & DESIGN EARLY CHILDHOOD",
        "district": "DESOTO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686013368",
    },
    {
        "school": "DESOTO ALTERNATIVE EDUCATION CENTER (DAEP)",
        "district": "DESOTO ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481686013373",
    },
    {
        "school": "LOUIS G LOBIT EL",
        "district": "DICKINSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707013371",
    },
    {
        "school": "ELVA C LOBIT MIDDLE",
        "district": "DICKINSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707013376",
    },
    {
        "school": "A P SOLIS MIDDLE",
        "district": "DONNA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739017037",
    },
    {
        "school": "NORTH PLAINS OPPORTUNITY CENTER",
        "district": "DUMAS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481761017047",
    },
    {
        "school": "DOZIER EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770013221",
    },
    {
        "school": "ODESSA COLLEGIATE ACADEMY EARLY COLLEGE H S",
        "district": "ECTOR COUNTY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481800013377",
    },
    {
        "school": "ECTOR CO YOUTH CTR",
        "district": "ECTOR COUNTY ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481800016986",
    },
    {
        "school": "JAMES C NEILL EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965013335",
    },
    {
        "school": "JAMES PATTERSON EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965013336",
    },
    {
        "school": "DONALD LEONETTI EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965013337",
    },
    {
        "school": "EDGAR GLOVER JR EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965016954",
    },
    {
        "school": "ARIZONA FLEMING EL",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965016956",
    },
    {
        "school": "TARRANT CO COLLEGE SOUTH/FORT WORTH COLLEGIATE H S",
        "district": "FORT WORTH ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970013383",
    },
    {
        "school": "IM TERRELL ACADEMY FOR STEM AND VPA",
        "district": "FORT WORTH ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970013388",
    },
    {
        "school": "UPLAND HEIGHTS EL",
        "district": "FRENSHIP ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481983013345",
    },
    {
        "school": "VAUGHN EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013306",
    },
    {
        "school": "MILLER EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013307",
    },
    {
        "school": "NELSON MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013314",
    },
    {
        "school": "VERNAL LISTER EL",
        "district": "GARLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034016969",
    },
    {
        "school": "WILLIAM B TRAVIS WORLD LANGUAGE ACADEMY",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142013226",
    },
    {
        "school": "UPLIFT LEE",
        "district": "GRAND PRAIRIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142013228",
    },
    {
        "school": "CROCKETT EARLY EDUCATION SCHOOL",
        "district": "GRAND PRAIRIE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142013233",
    },
    {
        "school": "RICE SCH /LA ESCUELA RICE",
        "district": "HOUSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364016978",
    },
    {
        "school": "HCC LIFE SKILLS PROGRAM",
        "district": "HOUSTON ISD",
        "level": "High",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "482364016982",
    },
    {
        "school": "PROJECT CHRYSALIS MIDDLE",
        "district": "HOUSTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482364017019",
    },
    {
        "school": "MIDDLE #10",
        "district": "HUMBLE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391013302",
    },
    {
        "school": "WESTLAKE MIDDLE",
        "district": "HUMBLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391013303",
    },
    {
        "school": "EL #30",
        "district": "HUMBLE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391013305",
    },
    {
        "school": "EL #29",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391013308",
    },
    {
        "school": "H S #7",
        "district": "HUMBLE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391013309",
    },
    {
        "school": "GROVES EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391013313",
    },
    {
        "school": "QUEST EARLY COLLEGE H S",
        "district": "HUMBLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391017028",
    },
    {
        "school": "OAK FOREST EL",
        "district": "HUMBLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391017030",
    },
    {
        "school": "HOWARD NORMAN EL",
        "district": "HUTTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482410013207",
    },
    {
        "school": "LYNDON B JOHNSON EL",
        "district": "JOHNSON CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482484012776",
    },
    {
        "school": "TOM AND NITA NICHOLS MIDDLE",
        "district": "JOSHUA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482493013255",
    },
    {
        "school": "KARNES CITY PRI",
        "district": "KARNES CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482514013279",
    },
    {
        "school": "TAYS J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517013350",
    },
    {
        "school": "BRYANT EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517013351",
    },
    {
        "school": "SUNSET VALLEY EL",
        "district": "KELLER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526013310",
    },
    {
        "school": "KELLER EARLY LEARNING CENTER - SOUTH",
        "district": "KELLER ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526013311",
    },
    {
        "school": "VISTA RIDGE MIDDLE",
        "district": "KELLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526013312",
    },
    {
        "school": "KILLEEN ISD EARLY COLLEGE H S",
        "district": "KILLEEN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566013234",
    },
    {
        "school": "ALICE W DOUSE EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566013235",
    },
    {
        "school": "ROY J SMITH MIDDLE",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566013236",
    },
    {
        "school": "VENABLE VILLAGE EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566015929",
    },
    {
        "school": "MAHAFFEY EL",
        "district": "KLEIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574013385",
    },
    {
        "school": "MEMORIAL MIDDLE",
        "district": "LA JOYA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613017001",
    },
    {
        "school": "HIGHPOINT - DAEP",
        "district": "LA PORTE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482619017032",
    },
    {
        "school": "ARBOR CREEK MIDDLE",
        "district": "LEWISVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730016940",
    },
    {
        "school": "OLD SETTLERS EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730016941",
    },
    {
        "school": "LIVINGSTON H S ACADEMY",
        "district": "LIVINGSTON ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482778013296",
    },
    {
        "school": "ALMA BREWER STRAWN EL",
        "district": "LOCKHART ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482787013361",
    },
    {
        "school": "LAGOS EL",
        "district": "MANOR ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889013218",
    },
    {
        "school": "NEW PRE-K CENTER",
        "district": "MANOR ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889013222",
    },
    {
        "school": "MARLIN EL",
        "district": "MARLIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482913013360",
    },
    {
        "school": "MARLIN MIDDLE",
        "district": "MARLIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482913013367",
    },
    {
        "school": "MARTINS MILL EL",
        "district": "MARTINS MILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482922017091",
    },
    {
        "school": "MCDADE H S",
        "district": "MCDADE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482976013256",
    },
    {
        "school": "DOWELL MIDDLE",
        "district": "MCKINNEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482985016952",
    },
    {
        "school": "MENARD ELEMENTARY/JH",
        "district": "MENARD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483021017043",
    },
    {
        "school": "BARBARA CULVER JUVENILE DETENTION CENTER",
        "district": "MIDLAND ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483057013277",
    },
    {
        "school": "FAIRVIEW ACCELERATED",
        "district": "MILES ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483075017097",
    },
    {
        "school": "KEENAN EL",
        "district": "MONTGOMERY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483126013384",
    },
    {
        "school": "LAKE CREEK H S",
        "district": "MONTGOMERY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483126013386",
    },
    {
        "school": "OAK HILLS J H",
        "district": "MONTGOMERY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483126013389",
    },
    {
        "school": "CHILD DEVELOPMENT CENTER",
        "district": "MOUNT PLEASANT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483176017078",
    },
    {
        "school": "PARKVIEW SCHOOL - LEVELLAND",
        "district": "MULLIN ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483192013338",
    },
    {
        "school": "PARKVIEW SCHOOL - LUBBOCK",
        "district": "MULLIN ISD",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483192013340",
    },
    {
        "school": "BRULE EL",
        "district": "NAVASOTA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483219013359",
    },
    {
        "school": "HOMEBASED COMP ED",
        "district": "NORTH EAST ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483294015799",
    },
    {
        "school": "COLE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312013245",
    },
    {
        "school": "KALLISON EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312013247",
    },
    {
        "school": "FIELDS EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312013250",
    },
    {
        "school": "TEGELER CAREER CENTER",
        "district": "PASADENA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483432017033",
    },
    {
        "school": "ROSE HAGGAR EL",
        "district": "PLANO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510016955",
    },
    {
        "school": "WINDSONG RANCH EL",
        "district": "PROSPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013227",
    },
    {
        "school": "JIM AND BETTY HUGHES EL",
        "district": "PROSPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013232",
    },
    {
        "school": "RUSSELL P SCHUPMANN EL",
        "district": "RED OAK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483666013243",
    },
    {
        "school": "RICE CHALLENGE ACADEMY",
        "district": "RICE CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483697013214",
    },
    {
        "school": "FAIRVIEW ACCELERATED",
        "district": "ROBERT LEE ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483738016035",
    },
    {
        "school": "LINDA LYON EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765013341",
    },
    {
        "school": "GENE BURTON COLLEGE AND CAREER ACADEMY",
        "district": "ROCKWALL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765013342",
    },
    {
        "school": "AMY PARKS-HEATH EL",
        "district": "ROCKWALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765017096",
    },
    {
        "school": "ROBERTO BOBBY BARRERA EL STEM MAGNET",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890013244",
    },
    {
        "school": "BLENDED ACADEMY",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483890013253",
    },
    {
        "school": "MILLER MIDDLE",
        "district": "SAN MARCOS CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483897017035",
    },
    {
        "school": "SANTA MARIA JJAEP",
        "district": "SANTA MARIA ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483933013285",
    },
    {
        "school": "SAVOY EL",
        "district": "SAVOY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483945016951",
    },
    {
        "school": "ALLISON L STEELE E L C",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483948016965",
    },
    {
        "school": "KEYS ACAD",
        "district": "SOCORRO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484071016996",
    },
    {
        "school": "HELEN BALL EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071016997",
    },
    {
        "school": "SPRING BRANCH ACADEMIC INSTITUTE",
        "district": "SPRING BRANCH ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484110013209",
    },
    {
        "school": "RICHEY ACADEMY",
        "district": "SPRING ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484122013248",
    },
    {
        "school": "CLARK PRI",
        "district": "SPRING ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122013252",
    },
    {
        "school": "WAGGONER CREEK EL",
        "district": "TEXARKANA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248013224",
    },
    {
        "school": "THREE LAKES MIDDLE",
        "district": "TYLER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347013379",
    },
    {
        "school": "NEW EL",
        "district": "UNITED ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365013301",
    },
    {
        "school": "VETERANS MEMORIAL EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365013304",
    },
    {
        "school": "VENUS MIDDLE",
        "district": "VENUS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484401017015",
    },
    {
        "school": "FAIRVIEW ACCELERATED",
        "district": "WALL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484441017083",
    },
    {
        "school": "21ST CENTURY EARLY LEARNING FOUNDATIONS ACADEMY",
        "district": "WESLACO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484496013299",
    },
    {
        "school": "CAREER EDUCATION CENTER",
        "district": "WICHITA FALLS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484578013205",
    },
    {
        "school": "GEORGE W BUSH EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484653013375",
    },
    {
        "school": "YOUNG WOMEN'S LEADERSHIP ACADEMY",
        "district": "YSLETA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668013208",
    },
    {
        "school": "THOMAS MANOR",
        "district": "YSLETA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668013212",
    },
    {
        "school": "BEL AIR MIDDLE",
        "district": "YSLETA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668013215",
    },
    {
        "school": "DEL VALLE MIDDLE",
        "district": "YSLETA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668013217",
    },
    {
        "school": "Springside School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001515",
    },
    {
        "school": "Summit Academy - Bluffdale",
        "district": "Summit Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006601499",
    },
    {
        "school": "Green Canyon High School",
        "district": "Cache District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012001512",
    },
    {
        "school": "Diamond Ridge High School",
        "district": "Canyons District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490014201504",
    },
    {
        "school": "Utah Military Academy - Camp Williams",
        "district": "Utah Military Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017601501",
    },
    {
        "school": "Athlos Academy of Utah",
        "district": "Athlos Academy of Utah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490018901503",
    },
    {
        "school": "Treeside Charter School",
        "district": "Treeside Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490019201514",
    },
    {
        "school": "The Center for Creativity Innovation and Discovery",
        "district": "The Center for Creativity Innovation and Discovery",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490019301513",
    },
    {
        "school": "Ignite Entrepreneurship Academy",
        "district": "Ignite Entrepreneurship Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490019401509",
    },
    {
        "school": "Bonneville Academy",
        "district": "Bonneville Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490019501507",
    },
    {
        "school": "Leadership Academy of Utah",
        "district": "Leadership Academy of Utah",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490019601516",
    },
    {
        "school": "Kay's Creek Elementary",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001505",
    },
    {
        "school": "Canyon Creek School",
        "district": "Davis District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001511",
    },
    {
        "school": "Centennial School",
        "district": "Duchesne District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490024001496",
    },
    {
        "school": "Bastian School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001498",
    },
    {
        "school": "Golden Fields School",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001502",
    },
    {
        "school": "Meadow Brook School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001500",
    },
    {
        "school": "New Bridge School",
        "district": "Ogden City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490072001506",
    },
    {
        "school": "Sterling School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105001497",
    },
    {
        "school": "Dugway",
        "district": "Tooele District",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105001508",
    },
    {
        "school": "CODERVA REGIONAL HIGH",
        "district": "CODE RVA HIGH",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510025603031",
    },
    {
        "school": "MADISON'S TRUST ELEM",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225003026",
    },
    {
        "school": "HILLSBORO CHARTER ACADEMY",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225003028",
    },
    {
        "school": "CHARLES J COLGAN SR HIGH",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "High",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313003025",
    },
    {
        "school": "RICHMOND COUNTY LEARNING CENTER",
        "district": "RICHMOND CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510327003030",
    },
    {
        "school": "Cowlitz County Youth Services Center",
        "district": "Educational Service District 112",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000502917",
    },
    {
        "school": "ESD 112 Open Doors Reengagement",
        "district": "Educational Service District 112",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530000503538",
    },
    {
        "school": "NEWESD 101 Open Doors",
        "district": "Educational Service District 101",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530001003583",
    },
    {
        "school": "Ugrad – ESD123 Re-Engagement Program",
        "district": "Educational Service District 123",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530001203521",
    },
    {
        "school": "Bates Technical College - Open Doors",
        "district": "Bates Technical College",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530001403585",
    },
    {
        "school": "Summit Public School: Olympus",
        "district": "Summit Public School: Olympus",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033303541",
    },
    {
        "school": "Summit Public School: Sierra",
        "district": "Summit Public School: Sierra",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033403510",
    },
    {
        "school": "Rainier Prep",
        "district": "Rainier Prep Charter School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033503533",
    },
    {
        "school": "Spokane International Academy",
        "district": "Spokane International Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033703539",
    },
    {
        "school": "PRIDE Prep School",
        "district": "PRIDE Prep Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530033903495",
    },
    {
        "school": "Blaine Re-Engagement",
        "district": "Blaine School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530057003574",
    },
    {
        "school": "Career & Academic Re-engagement Center",
        "district": "Bremerton School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530066003527",
    },
    {
        "school": "Cascade Home-Link",
        "district": "Cascade School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530095003528",
    },
    {
        "school": "Early Learning Center",
        "district": "Centralia School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530114003580",
    },
    {
        "school": "Cheney Open Doors",
        "district": "Cheney School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530123003507",
    },
    {
        "school": "Open Doors Reengagement Program",
        "district": "Chimacum School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530129003532",
    },
    {
        "school": "Educational Opportunity Center Reengagement",
        "district": "Clarkston School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530132003506",
    },
    {
        "school": "Four Heroes Elementary",
        "district": "Clover Park School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141003516",
    },
    {
        "school": "CPSD Open Doors Program",
        "district": "Clover Park School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530141003535",
    },
    {
        "school": "Clover Park Early Learning Program",
        "district": "Clover Park School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530141003549",
    },
    {
        "school": "Open Den",
        "district": "Coupeville School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530180003514",
    },
    {
        "school": "EV Online",
        "district": "East Valley School District (Spokane)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530228003581",
    },
    {
        "school": "EV Parent Partnership",
        "district": "East Valley School District (Spokane)",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530228003582",
    },
    {
        "school": "East Grays Harbor Open Doors",
        "district": "Elma School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530249003530",
    },
    {
        "school": "Other Schools",
        "district": "Everett School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267003551",
    },
    {
        "school": "Open Doors Evergreen",
        "district": "Evergreen School District (Clark)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530270003567",
    },
    {
        "school": "FERNDALE RE-ENGAGEMENT",
        "district": "Ferndale School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530285003576",
    },
    {
        "school": "Early Learning Center",
        "district": "Franklin Pierce School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530294003589",
    },
    {
        "school": "Step Up to College Open Doors High School",
        "district": "Grandview School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530315003550",
    },
    {
        "school": "Gibson Ek High School",
        "district": "Issaquah School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375003588",
    },
    {
        "school": "Sage Crest Elementary",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393003584",
    },
    {
        "school": "Chinook Middle School",
        "district": "Kennewick School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393003586",
    },
    {
        "school": "The Outreach Program",
        "district": "Kent School District",
        "level": "High",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530396003564",
    },
    {
        "school": "Early Learning Center",
        "district": "Lake Stevens School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420003561",
    },
    {
        "school": "Outcomes for Academic Resilience",
        "district": "Lake Stevens School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530420003562",
    },
    {
        "school": "Discovery High School-Achieve",
        "district": "Longview School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530447003511",
    },
    {
        "school": "Mabton Step Up To College",
        "district": "Mabton School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530465003558",
    },
    {
        "school": "Washington Connections Academy",
        "district": "Mary M Knight School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530480003569",
    },
    {
        "school": "Mary M. Knight School",
        "district": "Mary M Knight School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530480003571",
    },
    {
        "school": "Mary Walker Promise",
        "district": "Mary Walker School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530483003591",
    },
    {
        "school": "Marysville NWESD 189 Youth Engagement",
        "district": "Marysville School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530486003534",
    },
    {
        "school": "Mead Open Doors",
        "district": "Mead School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530492003515",
    },
    {
        "school": "Northwood Elementary School",
        "district": "Mercer Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530498003566",
    },
    {
        "school": "Meridian Impact Re-Engagement",
        "district": "Meridian School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530501003563",
    },
    {
        "school": "Mossyrock Academy",
        "district": "Mossyrock School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530525003537",
    },
    {
        "school": "Mount Vernon Open Doors",
        "district": "Mount Vernon School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530540003579",
    },
    {
        "school": "Lake Stickney Elementary School",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543003577",
    },
    {
        "school": "Naches Valley Elementary School",
        "district": "Naches Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530546003559",
    },
    {
        "school": "Re-Engagement School (Nine Mile Falls)",
        "district": "Nine Mile Falls School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530564003523",
    },
    {
        "school": "Salish Middle School",
        "district": "North Thurston Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530585003587",
    },
    {
        "school": "Ocean Beach Alternative School",
        "district": "Ocean Beach School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530606003565",
    },
    {
        "school": "Barbara McClintock STEM Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657003520",
    },
    {
        "school": "Marie Curie STEM Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657003542",
    },
    {
        "school": "Internet Pasco Academy of Learning",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530657003547",
    },
    {
        "school": "Captain Gray STEM Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657003552",
    },
    {
        "school": "Orchard Elementary",
        "district": "Richland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732003540",
    },
    {
        "school": "Royal Intermediate School",
        "district": "Royal School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530762003526",
    },
    {
        "school": "Bridges Transition",
        "district": "Seattle School District No. 1",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530771003555",
    },
    {
        "school": "Connections Academy",
        "district": "Sedro-Woolley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530774003568",
    },
    {
        "school": "John Campbell Primary School",
        "district": "Selah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530777003513",
    },
    {
        "school": "Selah Intermediate School",
        "district": "Selah School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530777003546",
    },
    {
        "school": "Selah Middle School",
        "district": "Selah School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530777003554",
    },
    {
        "school": "Timber Ridge Elementary School",
        "district": "Snoqualmie Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530804003560",
    },
    {
        "school": "Futures Program",
        "district": "Steilacoom Hist. School District",
        "level": "High",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530846003522",
    },
    {
        "school": "Birth to Three",
        "district": "Steilacoom Hist. School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530846003524",
    },
    {
        "school": "Industrial Design Engineering and Art",
        "district": "Tacoma School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870003575",
    },
    {
        "school": "Hoyt Early Learning Center",
        "district": "Tacoma School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870003578",
    },
    {
        "school": "Walla Walla Open Doors",
        "district": "Walla Walla Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530945003590",
    },
    {
        "school": "Wellpinit Fort Simcoe SEA",
        "district": "Wellpinit School District #49",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530963003572",
    },
    {
        "school": "West Valley Early Learning Center",
        "district": "West Valley School District (Spokane)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530969003570",
    },
    {
        "school": "White River Homeschool",
        "district": "White River School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530978003544",
    },
    {
        "school": "Woodland Middle School",
        "district": "Woodland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531005003509",
    },
    {
        "school": "GILMER COUNTY ELEMENTARY SCHOOL",
        "district": "GILMER COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540033001521",
    },
    {
        "school": "GREENBRIER SCHOOL OF PRACTICAL NURSING",
        "district": "GREENBRIER COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540039001523",
    },
    {
        "school": "PRESSLEY RIDGE AT LAUREL PARK",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101519",
    },
    {
        "school": "GARNET CAREER CENTER",
        "district": "KANAWHA COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540060001535",
    },
    {
        "school": "LEADING CREEK ELEMENTARY",
        "district": "LEWIS COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540063001518",
    },
    {
        "school": "MARION CO. ADULT & COMMUNITY ED. CENTER",
        "district": "MARION COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540072001541",
    },
    {
        "school": "JOHN MARSHALL ADULT PREP",
        "district": "MARSHALL COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540075001536",
    },
    {
        "school": "WEST PRESTON SCHOOL",
        "district": "PRESTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540117001520",
    },
    {
        "school": "SOUTH PRESTON SCHOOL",
        "district": "PRESTON COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540117001522",
    },
    {
        "school": "CAPERTON CENTER FOR APPLIED TECHNOLOGY",
        "district": "WOOD COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540162001530",
    },
    {
        "school": "Veritas High",
        "district": "Seeds of Health Inc",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550007402496",
    },
    {
        "school": "Tenor High",
        "district": "Seeds of Health Inc",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550007402637",
    },
    {
        "school": "Seeds of Health Elementary Program",
        "district": "Seeds of Health Inc",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550007402692",
    },
    {
        "school": "Honor Elementary",
        "district": "Herman-Neosho-Rubicon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550007503033",
    },
    {
        "school": "Honor Intermediate",
        "district": "Herman-Neosho-Rubicon School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550007503034",
    },
    {
        "school": "Stellar Collegiate Charter School",
        "district": "Stellar Collegiate Charter School Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550007603046",
    },
    {
        "school": "United Community Center Acosta Middle School",
        "district": "United Community Center Acosta Middle School Agency",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550007703047",
    },
    {
        "school": "Penfield Montessori Academy",
        "district": "Penfield Montessori Academy Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550007803048",
    },
    {
        "school": "Arcadia Elementary",
        "district": "Arcadia School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550042003040",
    },
    {
        "school": "Arcadia Middle",
        "district": "Arcadia School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550042003041",
    },
    {
        "school": "North Star Academy",
        "district": "Cameron School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550213002500",
    },
    {
        "school": "Elkhorn Options Virtual School",
        "district": "Elkhorn Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550429003038",
    },
    {
        "school": "Early Learning in Fond du Lac",
        "district": "Fond du Lac School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550468003042",
    },
    {
        "school": "Destinations Career Academy of Wisconsin High",
        "district": "McFarland School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WI",
        "nces_id": "550891003039",
    },
    {
        "school": "Milwaukee Excellence Charter School",
        "district": "Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960003036",
    },
    {
        "school": "Forest Ridge Elementary",
        "district": "Oak Creek-Franklin Joint School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551083003043",
    },
    {
        "school": "RUSD Montessori",
        "district": "Racine Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551236003044",
    },
    {
        "school": "Racine Alternative Learning",
        "district": "Racine Unified School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551236003045",
    },
    {
        "school": "Lighthouse Learning Academy",
        "district": "Two Rivers Public School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551512003037",
    },
    {
        "school": "West Bend School District 4K",
        "district": "West Bend School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551629003035",
    },
    {
        "school": "Prairie Wind Elementary",
        "district": "Laramie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000563",
    },
    {
        "school": "Heart Mountain Academy",
        "district": "Park County School District # 6",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560207000560",
    },
    {
        "school": "Moorcroft K-8",
        "district": "Crook County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560237000564",
    },
    {
        "school": "Moorcroft High School",
        "district": "Crook County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560237000566",
    },
    {
        "school": "Wind River Learning Academy",
        "district": "Fremont County School District # 6",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560283000561",
    },
    {
        "school": "Frontier Academy",
        "district": "Fremont County School District #25",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560522000562",
    },
    {
        "school": "Stagecoach Elementary",
        "district": "Sweetwater County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560530200565",
    },
    {
        "school": "J.P. TORRES SUCCESS ACADEMY",
        "district": "Guam Department of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GU",
        "nces_id": "660000200082",
    },
    {
        "school": "CENTRO RES DE OPORTUNIDADES EDUCATIVAS DE VILLALBA (CROEV)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001939",
    },
    {
        "school": "VOC WILLIAM RIVERA BETANCOURT (BO SAN ISIDRO VOCACIONAL)",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "High",
        "type": "Career and Technical School",
        "state": "PR",
        "nces_id": "720003001942",
    },
    {
        "school": "Leeds Primary School",
        "district": "Leeds City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10001102430",
    },
    {
        "school": "Athens Renaissance School",
        "district": "Athens City",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10012002417",
    },
    {
        "school": "Saraland Early Education Center",
        "district": "Saraland City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018502427",
    },
    {
        "school": "Chickasaw Middle School",
        "district": "Chickasaw City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10018802428",
    },
    {
        "school": "Pike Road Intermediate School",
        "district": "Pike Road City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019502424",
    },
    {
        "school": "Pike Road High School",
        "district": "Pike Road City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019502441",
    },
    {
        "school": "Acceleration Day and Evening Academy",
        "district": "Acceleration Day and Evening Academy",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019702432",
    },
    {
        "school": "East Samford School",
        "district": "Auburn City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021002440",
    },
    {
        "school": "Alexandria Middle School",
        "district": "Calhoun County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10054002429",
    },
    {
        "school": "Jemison Intermediate School",
        "district": "Chilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10066002437",
    },
    {
        "school": "Opportunity Academy",
        "district": "Dale County",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "AL",
        "nces_id": "10105002426",
    },
    {
        "school": "Geneva Regional Career Technical Center",
        "district": "Geneva County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10166002418",
    },
    {
        "school": "Jemison High School",
        "district": "Huntsville City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180002419",
    },
    {
        "school": "Sonnie Hereford Elementary School",
        "district": "Huntsville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180002425",
    },
    {
        "school": "Jasper Junior High School",
        "district": "Jasper City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10189002434",
    },
    {
        "school": "Jefferson County International Baccalaureate School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10192002421",
    },
    {
        "school": "Tanner Elementary School",
        "district": "Limestone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210002422",
    },
    {
        "school": "Creekside Primary School",
        "district": "Limestone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210002423",
    },
    {
        "school": "Elkmont Elementary School",
        "district": "Limestone County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210002431",
    },
    {
        "school": "Woodland Elementary School",
        "district": "Randolph County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10282002438",
    },
    {
        "school": "Russellville City Career Tech Center",
        "district": "Russellville City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10291002435",
    },
    {
        "school": "Reeltown Elementary School",
        "district": "Tallapoosa County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10321002433",
    },
    {
        "school": "Anchorage STrEaM Academy",
        "district": "Anchorage School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000760",
    },
    {
        "school": "Dena?ina Elementary School",
        "district": "Matanuska-Susitna Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20051000759",
    },
    {
        "school": "Rampart School",
        "district": "Yukon-Koyukuk School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20086200757",
    },
    {
        "school": "Sequoia Village High School",
        "district": "Edkey Inc. - Sequoia Village School (79211)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40024603028",
    },
    {
        "school": "George Washington Academy",
        "district": "Edkey Inc. - Sequoia Village School (79211)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40024603494",
    },
    {
        "school": "Pima Prevention Partnership-Tucson",
        "district": "Pima Prevention Partnership dba Pima Partnership S (79959)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40036703531",
    },
    {
        "school": "Paulo Freire Freedom School - University",
        "district": "CITY Center for Collaborative Learning (85448)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40040702558",
    },
    {
        "school": "Paulo Freire Freedom School - Downtown",
        "district": "CITY Center for Collaborative Learning (85448)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40040703448",
    },
    {
        "school": "Start Campus",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503515",
    },
    {
        "school": "Southwest Campus",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503525",
    },
    {
        "school": "Northeast Campus",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503528",
    },
    {
        "school": "Leman Academy of Excellence Sierra Vista",
        "district": "Edkey Inc. - Pathfinder Academy (81045)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40063803511",
    },
    {
        "school": "The Innovation Academy",
        "district": "Amphitheater Unified District (4406)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40068003517",
    },
    {
        "school": "Pima County JTED at Star",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203529",
    },
    {
        "school": "Astravo Online Academy",
        "district": "Arizona Education Solutions (90758)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40082703252",
    },
    {
        "school": "Empower College Prep High School",
        "district": "Empower College Prep (91277)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40087703522",
    },
    {
        "school": "Arizona Autism Charter School Upper School Campus",
        "district": "Arizona Autism Charter Schools Inc. (91958)",
        "level": "High",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40091303512",
    },
    {
        "school": "Leman Academy of Excellence-Oro Valley Arizona",
        "district": "Leman Academy of Excellence Inc. (92730)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094403504",
    },
    {
        "school": "Pensar Academy",
        "district": "Pensar Academy (92972)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094503518",
    },
    {
        "school": "ASU Preparatory Academy - South Phoenix High School",
        "district": "ASU Preparatory Academy (346763)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094603375",
    },
    {
        "school": "ASU Preparatory Academy - Casa Grande HS",
        "district": "ASU Preparatory Academy - Casa Grande (92987)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094703526",
    },
    {
        "school": "Legacy Traditional School ? Glendale",
        "district": "Legacy Traditional School - Glendale (850100)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094803523",
    },
    {
        "school": "Painted Desert Montessori LLC",
        "district": "Painted Desert Montessori LLC (123733)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094903520",
    },
    {
        "school": "Pathways in Education",
        "district": "Pathways In Education-Arizona Inc. (92983)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40095003508",
    },
    {
        "school": "Legacy Traditional School ? Peoria",
        "district": "Legacy Traditional School - Peoria (850099)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40095103532",
    },
    {
        "school": "Colegio Petite Arizona",
        "district": "Kaizen Education Foundation dba Colegio Petite Pho (92989)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40095203514",
    },
    {
        "school": "The Grande Innovation",
        "district": "The Grande Innovation Academy (92978)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40095303527",
    },
    {
        "school": "Legacy Traditional School ? North Chandler",
        "district": "Legacy Traditional School - North Chandler (850101)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40095403513",
    },
    {
        "school": "Maricopa Institute of Technology",
        "district": "Estrella Educational Foundation (92988)",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40095503519",
    },
    {
        "school": "ASU Preparatory Academy - South Phoenix Primary",
        "district": "ASU Preparatory Academy (92716)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40095603505",
    },
    {
        "school": "BASIS Chandler Primary - North Campus",
        "district": "BASIS Charter Schools Inc. (92997)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40095803534",
    },
    {
        "school": "Sierra Vista Online",
        "district": "Sierra Vista Unified District (4175)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40146003524",
    },
    {
        "school": "South Verde Technology Magnet",
        "district": "Camp Verde Unified District (4470)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40160003053",
    },
    {
        "school": "Crane iLearning Academy",
        "district": "Crane Elementary District (4501)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40240003521",
    },
    {
        "school": "Northern Arizona Distance Learning",
        "district": "Flagstaff Unified District (4192)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286003506",
    },
    {
        "school": "San Tan Foothills High School",
        "district": "Florence Unified School District (4437)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292002896",
    },
    {
        "school": "San Tan Heights Elementary",
        "district": "Florence Unified School District (4437)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40292003079",
    },
    {
        "school": "Glendale Union Online",
        "district": "Glendale Union High School District (4285)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40345003510",
    },
    {
        "school": "Paseo Pointe School",
        "district": "Laveen Elementary District (4276)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40429003530",
    },
    {
        "school": "Fine Arts Academy",
        "district": "Littleton Elementary District (4278)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40444003533",
    },
    {
        "school": "Gladden Farms Elementary",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463003516",
    },
    {
        "school": "Phoenix Coding Academy",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633003509",
    },
    {
        "school": "Henry Dunkerson Pathways Academy",
        "district": "Safford Unified District (4218)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40724003507",
    },
    {
        "school": "SCOTT CHARTER SCHOOL",
        "district": "ACADEMICS PLUS CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50005901619",
    },
    {
        "school": "DEER K-12 SCHOOL",
        "district": "DEER/MT. JUDEA SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007201621",
    },
    {
        "school": "MT. JUDEA K-12 SCHOOL",
        "district": "DEER/MT. JUDEA SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007201630",
    },
    {
        "school": "LISA ACADEMY CHENAL",
        "district": "LISA ACADEMY CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007401624",
    },
    {
        "school": "UMPIRE K-12 SCHOOL",
        "district": "COSSATOT RIVER SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040501620",
    },
    {
        "school": "ARKANSAS CONNECTIONS ACADEMY HIGH",
        "district": "ARKANSAS CONNECTIONS ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041701632",
    },
    {
        "school": "FURTURE SCHOOL OF FORT SMITH",
        "district": "FUTURE SCHOOL OF FORT SMITH",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041801627",
    },
    {
        "school": "BAYOU METO ELEMENTARY SCHOOL",
        "district": "JACKSONVILLE NORTH PULASKI SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041900905",
    },
    {
        "school": "WARREN DUPREE ELEM. SCHOOL",
        "district": "JACKSONVILLE NORTH PULASKI SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041900912",
    },
    {
        "school": "JACKSONVILLE HIGH SCHOOL",
        "district": "JACKSONVILLE NORTH PULASKI SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041900919",
    },
    {
        "school": "PINEWOOD ELEMENTARY SCHOOL",
        "district": "JACKSONVILLE NORTH PULASKI SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041900935",
    },
    {
        "school": "MURRELL TAYLOR ELEM. SCHOOL",
        "district": "JACKSONVILLE NORTH PULASKI SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041901256",
    },
    {
        "school": "JACKSONVILLE MIDDLE SCHOOL",
        "district": "JACKSONVILLE NORTH PULASKI SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041901510",
    },
    {
        "school": "BENTONVILLE WEST HIGH SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001618",
    },
    {
        "school": "FAYETTEVILLE VIRTUAL ACADEMY- DIST CONVERSION CHARTER SCH",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612001636",
    },
    {
        "school": "GREENBRIER SPRINGHILL ELEMENTARY SCHOOL",
        "district": "GREENBRIER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50690001623",
    },
    {
        "school": "GREENWOOD FRESHMAN CENTER",
        "district": "GREENWOOD SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50699001634",
    },
    {
        "school": "GEYER SPRINGS EARLY CHILDHOOD CENTER",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001626",
    },
    {
        "school": "PINNACLE VIEW MIDDLE SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001628",
    },
    {
        "school": "LINDA CHILDERS KNAPP ELEMENTARY SCHOOL",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001622",
    },
    {
        "school": "SPRINGDALE SCHOOL OF INNOVATIONS",
        "district": "SPRINGDALE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51266001633",
    },
    {
        "school": "VAN BUREN FRESHMAN ACADEMY",
        "district": "VAN BUREN SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51341001631",
    },
    {
        "school": "Natomas Pacific Pathways Prep Elementary",
        "district": "Natomas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003614043",
    },
    {
        "school": "Freedom Home",
        "district": "Golden Valley Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60006814039",
    },
    {
        "school": "CA Advancing Pathways for Students in Los Angeles Co",
        "district": "CA Advancing Pathways for Students in Los Angeles Co ROC/P",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CA",
        "nces_id": "60144014016",
    },
    {
        "school": "Upper Lake Elementary",
        "district": "Upper Lake Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60144206694",
    },
    {
        "school": "Clover Valley High (Continuation)",
        "district": "Upper Lake Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60144206695",
    },
    {
        "school": "Upper Lake High",
        "district": "Upper Lake Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60144206696",
    },
    {
        "school": "Upper Lake Middle",
        "district": "Upper Lake Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60144210121",
    },
    {
        "school": "Upper Lake Community Day",
        "district": "Upper Lake Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60144211287",
    },
    {
        "school": "Summit Elementary",
        "district": "Alvord Unified",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60243014022",
    },
    {
        "school": "Summit Secondary",
        "district": "Alvord Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60243014032",
    },
    {
        "school": "Lassen-Antelope Volcanic Academy (LAVA)",
        "district": "Antelope Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60276014049",
    },
    {
        "school": "Castro Valley Virtual Academy",
        "district": "Castro Valley Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60780014010",
    },
    {
        "school": "Ceres Special Education",
        "district": "Ceres Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60813014023",
    },
    {
        "school": "Pinnacle Academy Charter - Independent Study",
        "district": "South Monterey County Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61965014041",
    },
    {
        "school": "Old River Elementary",
        "district": "Knightsen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62004014006",
    },
    {
        "school": "Lennox Virtual Academy",
        "district": "Lennox",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62142014005",
    },
    {
        "school": "Virginia Lee Rose Elementary",
        "district": "Madera Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334014058",
    },
    {
        "school": "Harvest Hill S.T.E.A.M. Academy",
        "district": "Menifee Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454014053",
    },
    {
        "school": "Scholar Plus Online Learning",
        "district": "Perris Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63021014047",
    },
    {
        "school": "Preschool Early Education Program PEEP",
        "district": "Pleasant Valley",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63099014026",
    },
    {
        "school": "Washington Elementary",
        "district": "Sacramento City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63384014056",
    },
    {
        "school": "Mildred Perkins Elementary",
        "district": "Salida Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63390014035",
    },
    {
        "school": "Sequoia Union Elementary",
        "district": "Sequoia Union Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63636014008",
    },
    {
        "school": "Sierra Vista K-8",
        "district": "Vacaville Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059014012",
    },
    {
        "school": "Ernest Kimme Charter Academy for Independent Learning",
        "district": "Vacaville Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64059014015",
    },
    {
        "school": "Come Back Butte Charter",
        "district": "Butte County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69100214048",
    },
    {
        "school": "Imperial Pathways Charter",
        "district": "Imperial County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69101014014",
    },
    {
        "school": "Opportunity Youth Academy",
        "district": "Santa Clara County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69103514054",
    },
    {
        "school": "GLOBAL VILLAGE ACADEMY - NORTHGLENN",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006503",
    },
    {
        "school": "LAUNCH HIGH SCHOOL",
        "district": "State Charter School Institute",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006700",
    },
    {
        "school": "MOUNTAIN VILLAGE MONTESSORI CHARTER SCHOOL",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006701",
    },
    {
        "school": "GRAND MESA YOUTH SERVICES CENTER",
        "district": "DIVISION OF YOUTH SERVICES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80028606702",
    },
    {
        "school": "MOUNT VIEW YOUTH SERVICES CENTER",
        "district": "DIVISION OF YOUTH SERVICES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80028606703",
    },
    {
        "school": "PLATTE VALLEY YOUTH SERVICES CENTER",
        "district": "DIVISION OF YOUTH SERVICES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80028606704",
    },
    {
        "school": "Rocky Mountain Prep: Fletcher",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006677",
    },
    {
        "school": "HERITAGE HEIGHTS ACADEMY",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006676",
    },
    {
        "school": "BEAR VALLEY INTERNATIONAL SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006682",
    },
    {
        "school": "DSST: HENRY MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006683",
    },
    {
        "school": "DSST: BYERS HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006684",
    },
    {
        "school": "SANDRA TODD-WILLIAMS ACADEMY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006685",
    },
    {
        "school": "KEPNER BEACON MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006686",
    },
    {
        "school": "MCAULIFFE MANUAL MIDDLE SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006687",
    },
    {
        "school": "STRIVE PREP - KEPNER",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006688",
    },
    {
        "school": "STRIVE PREP - RISE",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006689",
    },
    {
        "school": "PARKER PERFORMING ARTS",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006690",
    },
    {
        "school": "COLORADO CONNECTIONS ACADEMY @ DURANGO",
        "district": "Durango School District No. 9-R",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348006696",
    },
    {
        "school": "POWER TECHNICAL EARLY COLLEGE",
        "district": "El Paso County Colorado School District 49",
        "level": "High",
        "type": "Career and Technical School",
        "state": "CO",
        "nces_id": "80387006693",
    },
    {
        "school": "PIKES PEAK EARLY COLLEGE",
        "district": "El Paso County Colorado School District 49",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387006694",
    },
    {
        "school": "BAKER ELEMENTARY SCHOOL",
        "district": "School District No. Re-3 Fort Morgan",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80405006698",
    },
    {
        "school": "ATLAS PREPARATORY MIDDLE SCHOOL",
        "district": "Harrison School District No. 2 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80453006691",
    },
    {
        "school": "DORAL ACADEMY OF COLORADO",
        "district": "Jefferson County School District No. R-1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006695",
    },
    {
        "school": "AIM GLOBAL",
        "district": "Las Animas School District No. Re-1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80525006678",
    },
    {
        "school": "IMMERSION SCHOOLS SCIENCE TECHNOLOGY ARTS",
        "district": "Las Animas School District No. Re-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80525006679",
    },
    {
        "school": "HIGH PLAINS SCHOOL",
        "district": "Thompson School District R-2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80540006697",
    },
    {
        "school": "BIG PICTURE COLLEGE AND CAREER ACADEMY",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555006671",
    },
    {
        "school": "GLOBAL INTERMEDIATE ACADEMY",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555006672",
    },
    {
        "school": "GLOBAL PRIMARY ACADEMY",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555006673",
    },
    {
        "school": "PEYTON ONLINE ACADEMY",
        "district": "Peyton School District No. 23 in the county of El Paso and",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80606006692",
    },
    {
        "school": "TELLURIDE ELEMENTARY SCHOOL",
        "district": "Telluride School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80687006699",
    },
    {
        "school": "WESTMINSTER ACADEMY FOR INTERNATIONAL STUDIES",
        "district": "Westminster Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723006675",
    },
    {
        "school": "Science and Technology Magnet School of Southeastern Connect",
        "district": "NEW LONDON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90282001913",
    },
    {
        "school": "New London Visual and Performing Arts Magnet School",
        "district": "NEW LONDON SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90282001919",
    },
    {
        "school": "Norwalk Early Childhood Center",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309001914",
    },
    {
        "school": "Center for Global Studies",
        "district": "NORWALK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309001917",
    },
    {
        "school": "Strawberry Hill an ext. of Rogers International",
        "district": "STAMFORD SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90432001916",
    },
    {
        "school": "Lorewood Grove Elementary School",
        "district": "Appoquinimink School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000380",
    },
    {
        "school": "Love Creek Elementary School",
        "district": "Cape Henlopen School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100017000382",
    },
    {
        "school": "The Wallace Wallin School",
        "district": "Colonial School District",
        "level": "High",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100023000378",
    },
    {
        "school": "Indian River Intensive Learning Center",
        "district": "Indian River School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100068000384",
    },
    {
        "school": "Delaware Early Childhood Center",
        "district": "Lake Forest School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100079000383",
    },
    {
        "school": "MacFarland MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000511",
    },
    {
        "school": "Ron Brown College Preparatory HS",
        "district": "District of Columbia Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000512",
    },
    {
        "school": "RESILIENCE CHARTER SCHOOL INC",
        "district": "ALACHUA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120003008516",
    },
    {
        "school": "CONTRACTED RESIDENTIAL SERVICES",
        "district": "BREVARD",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120015008505",
    },
    {
        "school": "LEGACY ACADEMY CHARTER",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015008530",
    },
    {
        "school": "CHAMPIONSHIP ACADEMY OF DISTINCTION MIDDLE SCHOOL",
        "district": "BROWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008513",
    },
    {
        "school": "CHAMPIONSHIP ACADEMY OF DISTINCTION HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008531",
    },
    {
        "school": "ACADEMIC SOLUTIONS ACADEMY A",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018008534",
    },
    {
        "school": "SOMERSET ACADEMY KEY CHARTER HIGH SCHOOL",
        "district": "BROWARD",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008546",
    },
    {
        "school": "THE ACADEMY",
        "district": "CHARLOTTE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120024008540",
    },
    {
        "school": "COLLIER CHARTER ACADEMY",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033008510",
    },
    {
        "school": "BRIDGEPREP ACADEMY COLLIER",
        "district": "COLLIER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033008522",
    },
    {
        "school": "WEST LAKES PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008514",
    },
    {
        "school": "ACADEMIR CHARTER SCHOOL PREPARATORY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008518",
    },
    {
        "school": "TRUE NORTH CLASSICAL ACADEMY HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008519",
    },
    {
        "school": "MATER ACADEMY BAY ELEMENTARY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008524",
    },
    {
        "school": "PATH ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039008541",
    },
    {
        "school": "SCHOOL FOR ADVANCED STUDIES",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008558",
    },
    {
        "school": "PINECREST GLADES ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008574",
    },
    {
        "school": "PINECREST GLADES PREPARATORY ACADEMY MIDDLE HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008576",
    },
    {
        "school": "DESOTO VIRTUAL FRANCHISE",
        "district": "DESOTO",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120042008570",
    },
    {
        "school": "THE BRIDGE",
        "district": "DUVAL",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120048008523",
    },
    {
        "school": "R L BROWN GIFTED AND TALENTED ACADEMY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008536",
    },
    {
        "school": "BRIDGEPREP ACADEMY DUVAL COUNTY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008557",
    },
    {
        "school": "OAK HILL ACADEMY",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120048008567",
    },
    {
        "school": "BEULAH MIDDLE SCHOOL",
        "district": "ESCAMBIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051008511",
    },
    {
        "school": "KINGSFIELD ELEMENTARY SCHOOL",
        "district": "ESCAMBIA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120051008560",
    },
    {
        "school": "TAP PK BABIES",
        "district": "ESCAMBIA",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120051008573",
    },
    {
        "school": "KIDS COMMUNITY COLLEGE CHARTER HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008507",
    },
    {
        "school": "SOUTHSHORE CHARTER ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008520",
    },
    {
        "school": "SPORTS LEADERSHIP AND MANAGEMENT ACADEMY (TAMPA)",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008549",
    },
    {
        "school": "WATERSET CHARTER SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008556",
    },
    {
        "school": "AVANT GARDE ACADEMY WESTCHASE",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008563",
    },
    {
        "school": "PLATO ACADEMY TAMPA CHARTER SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008566",
    },
    {
        "school": "BRIDGEPREP ACADEMY OF RIVERVIEW",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008568",
    },
    {
        "school": "CREEKSIDE CHARTER ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008571",
    },
    {
        "school": "JEFFERSON VIRTUAL FRANCHISE",
        "district": "JEFFERSON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120099008525",
    },
    {
        "school": "JEFFERSON VIRTUAL INSTRUCTION COURSE OFFERINGS",
        "district": "JEFFERSON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120099008551",
    },
    {
        "school": "HARLEM HEIGHTS COMMUNITY CHARTER SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108008528",
    },
    {
        "school": "MADISON CREATIVE ARTS ACADEMY INC",
        "district": "MADISON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120120008526",
    },
    {
        "school": "JUST FOR GIRLS ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120123008533",
    },
    {
        "school": "AMIKIDS MANATEE",
        "district": "MANATEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120123008548",
    },
    {
        "school": "SELBY PRESCHOOL",
        "district": "MANATEE",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120123008578",
    },
    {
        "school": "ECON RIVER HIGH CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120144008508",
    },
    {
        "school": "BRIDGEPREP ACADEMY CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008550",
    },
    {
        "school": "ESE TRANSITION",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008559",
    },
    {
        "school": "RENAISSANCE CHARTER AT CROWN POINT",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008564",
    },
    {
        "school": "LUCIOUS AND EMMA NIXON ACADEMY CHARTER",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008565",
    },
    {
        "school": "LINCOLN-MARTI CHARTER SCHOOLS(OSCEOLA CAMPUS)",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008554",
    },
    {
        "school": "OSCEOLA SCIENCE CHARTER SCHOOL",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008561",
    },
    {
        "school": "CONNECTIONS EDUCATION CENTER OF THE PALM BEACHES",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150008509",
    },
    {
        "school": "SOMERSET ACADEMY LAKES",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008535",
    },
    {
        "school": "SPORTS LEADERSHIP AND MANAGEMENT (SLAM) MIDDLE SCHOOL PALM B",
        "district": "PALM BEACH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008562",
    },
    {
        "school": "CYPRESS CREEK MIDDLE/HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008517",
    },
    {
        "school": "WIREGRASS ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008542",
    },
    {
        "school": "DISCOVERY HIGH SCHOOL",
        "district": "POLK",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159008515",
    },
    {
        "school": "CYPRESS JUNCTION MONTESSORI",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159008572",
    },
    {
        "school": "FREEDOM CROSSING ACADEMY",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174008529",
    },
    {
        "school": "PICOLATA CROSSING ELEMENTARY SCHOOL",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174008537",
    },
    {
        "school": "PALM VALLEY ACADEMY",
        "district": "ST. JOHNS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120174008569",
    },
    {
        "school": "ACCELERATION ACADEMY",
        "district": "ST. LUCIE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120177008545",
    },
    {
        "school": "VOLUSIA VIRTUAL INSTRUCTION PROGRAM DISTRICT PROVIDED",
        "district": "VOLUSIA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192008555",
    },
    {
        "school": "Carver High School",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004223",
    },
    {
        "school": "Woodson Park Academy",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004224",
    },
    {
        "school": "Michael R. Hollis Innovation Academy",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004237",
    },
    {
        "school": "South Atlanta High School",
        "district": "Atlanta Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004240",
    },
    {
        "school": "Tuskegee Airman Global Academy",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004244",
    },
    {
        "school": "Cirrus Charter Academy",
        "district": "Commission Charter Schools- Cirrus Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130023904226",
    },
    {
        "school": "Liberty Tech Charter Academy",
        "district": "Commission Charter Schools- Liberty Tech Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024104229",
    },
    {
        "school": "Brookhaven Innovation Academy",
        "district": "Commission Charter Schools- Brookhaven Innovation Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024204249",
    },
    {
        "school": "Southwest Georgia S.T.E.M. Charter Academy",
        "district": "Commission Charter Schools- Southwest Georgia S.T.E.M. Chart",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024304253",
    },
    {
        "school": "Veterans Elementary School",
        "district": "Bibb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130042004245",
    },
    {
        "school": "Parkway Elementary School",
        "district": "Columbia County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130141004246",
    },
    {
        "school": "Barack H. Obama Elementary Magnet School of Technology",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174004248",
    },
    {
        "school": "DeSana Middle School",
        "district": "Forsyth County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222004228",
    },
    {
        "school": "Brandywine Elementary School",
        "district": "Forsyth County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222004233",
    },
    {
        "school": "Skyview High School",
        "district": "Fulton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004225",
    },
    {
        "school": "Vickery Mill Elementary",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004243",
    },
    {
        "school": "Wolf Creek Elementary",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004247",
    },
    {
        "school": "Fulton Academy of Science and Technology",
        "district": "Fulton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004259",
    },
    {
        "school": "Wellspring Living",
        "district": "Fulton County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130228004261",
    },
    {
        "school": "Coleman Middle School",
        "district": "Gwinnett County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004234",
    },
    {
        "school": "Baldwin Elementary",
        "district": "Gwinnett County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004251",
    },
    {
        "school": "International Transition Center",
        "district": "Gwinnett County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004257",
    },
    {
        "school": "Greenville Middle School",
        "district": "Meriwether County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130363004238",
    },
    {
        "school": "Zebulon High School",
        "district": "Pike County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130417004235",
    },
    {
        "school": "W.S. Hornsby Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438004230",
    },
    {
        "school": "Wheeler County Middle School",
        "district": "Wheeler County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130564004241",
    },
    {
        "school": "Worth County Achievement Center",
        "district": "Worth County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130585004231",
    },
    {
        "school": "Kapolei Charter School by Goodwill Hawaii",
        "district": "Hawaii Department of Education",
        "level": "Secondary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000302",
    },
    {
        "school": "Kamalani Academy",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000303",
    },
    {
        "school": "RICHARD MCKENNA CHARTER SCHOOL - MONTESSORI",
        "district": "IDAHO VIRTUAL HIGH SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000501087",
    },
    {
        "school": "SKYWAY ELEMENTARY",
        "district": "VALLIVUE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160060001092",
    },
    {
        "school": "JOHN V EVANS ELEMENTARY",
        "district": "CASSIA COUNTY JOINT DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160066001088",
    },
    {
        "school": "NORTHWEST EXPEDITION ACADEMY",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160078001089",
    },
    {
        "school": "TREASURE VALLEY LEADERSHIP ACADEMY",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234001090",
    },
    {
        "school": "IDAHO HOME LEARNING ACADEMY",
        "district": "ONEIDA COUNTY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160249001094",
    },
    {
        "school": "SOUTH HILLS MIDDLE SCHOOL",
        "district": "TWIN FALLS DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324001093",
    },
    {
        "school": "WILDER MIDDLE SCHOOL",
        "district": "WILDER DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160348001091",
    },
    {
        "school": "The Communications Program",
        "district": "Kankakee Area Spec Educ Coop",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005606397",
    },
    {
        "school": "Educational Daycare",
        "district": "Four Rivers Spec Educ Dist",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170008006405",
    },
    {
        "school": "LEARN 10 Charter School",
        "district": "North Chicago SD 187",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170011006401",
    },
    {
        "school": "DREAM Academy",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106416",
    },
    {
        "school": "PAWS",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106417",
    },
    {
        "school": "Success Academy",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106418",
    },
    {
        "school": "Success Academy HS",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106435",
    },
    {
        "school": "Betty Shabazz Internl Charter Sch",
        "district": "Betty Shabazz  Internl Chrtr Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170142406394",
    },
    {
        "school": "Barbara A Sizemore Campus",
        "district": "Betty Shabazz  Internl Chrtr Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170142406396",
    },
    {
        "school": "Visually Impaired Programs",
        "district": "School Assn For Special Educ",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142506406",
    },
    {
        "school": "STARS Autism Program",
        "district": "School Assn For Special Educ",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142506407",
    },
    {
        "school": "Deaf/Hard of Hearing Programs",
        "district": "School Assn For Special Educ",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142506408",
    },
    {
        "school": "Multi Needs Program",
        "district": "School Assn For Special Educ",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142506409",
    },
    {
        "school": "Directions Program",
        "district": "School Assn For Special Educ",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142506411",
    },
    {
        "school": "Transition Program",
        "district": "School Assn For Special Educ",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142506412",
    },
    {
        "school": "Southeast Alternative School",
        "district": "School Assn For Special Educ",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142506413",
    },
    {
        "school": "Amandla Charter School",
        "district": "Amandla Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170142606424",
    },
    {
        "school": "Newark CHSD 18",
        "district": "Plano Area Special Ed Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142806429",
    },
    {
        "school": "Plano CUSD 88",
        "district": "Plano Area Special Ed Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142806430",
    },
    {
        "school": "Newark CCSD 66",
        "district": "Plano Area Special Ed Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142806431",
    },
    {
        "school": "Lisbon CCSD 90",
        "district": "Plano Area Special Ed Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170142806432",
    },
    {
        "school": "Bronzeville Academy Charter Sch",
        "district": "Bronzeville Academy Chtr School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170143106434",
    },
    {
        "school": "Richardson Middle School",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006398",
    },
    {
        "school": "Southeast Area Elementary School",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006399",
    },
    {
        "school": "Walter Henri Dyett HS for Arts",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006400",
    },
    {
        "school": "District 99 Early Childhood Ctr",
        "district": "Cicero SD 99",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171020006414",
    },
    {
        "school": "Galatia Grade School Annex",
        "district": "Galatia CUSD 1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171602006419",
    },
    {
        "school": "Crossroad Learning Center",
        "district": "Jacksonville SD 117",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172028006395",
    },
    {
        "school": "Avis Huff Student Support Service",
        "district": "Kankakee SD 111",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172076006402",
    },
    {
        "school": "Irving Middle School",
        "district": "Maywood-Melrose Park-Broadview 89",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172511006426",
    },
    {
        "school": "Stevenson Middle School",
        "district": "Maywood-Melrose Park-Broadview 89",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172511006427",
    },
    {
        "school": "Morton Academy",
        "district": "Morton CUSD 709",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172680006423",
    },
    {
        "school": "Eugene Field School",
        "district": "McLean County USD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862006428",
    },
    {
        "school": "East View Academy School",
        "district": "CUSD 308",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173027006410",
    },
    {
        "school": "Trewyn Primary School",
        "district": "Peoria SD 150",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123006420",
    },
    {
        "school": "PEACE Center",
        "district": "Thornton Twp HSD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173897006421",
    },
    {
        "school": "Outlook Academy",
        "district": "Thornton Twp HSD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173897006422",
    },
    {
        "school": "ELC Winfield Primary Annex",
        "district": "West Chicago ESD 33",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174155006433",
    },
    {
        "school": "Global Preparatory Academy",
        "district": "Global Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180017002610",
    },
    {
        "school": "Steel City Academy",
        "district": "Steel City Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180017102614",
    },
    {
        "school": "ACE Preparatory Academy",
        "district": "ACE Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180017202604",
    },
    {
        "school": "Excel Center - Shelbyville",
        "district": "Excel Center - Shelbyville",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180017502606",
    },
    {
        "school": "Seven Oaks Classical School",
        "district": "Seven Oaks Classical School",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180017602603",
    },
    {
        "school": "Kindezi Academy",
        "district": "Kindezi Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180017702608",
    },
    {
        "school": "Higher Institute of Arts & Tech",
        "district": "Higher Institute of Arts & Tech",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180017802602",
    },
    {
        "school": "Insight School of Indiana",
        "district": "Insight School of Indiana",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180017902601",
    },
    {
        "school": "Hoosier Hills Childcare Center",
        "district": "Monroe County Community Sch Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063002613",
    },
    {
        "school": "Wes-Del Preschool",
        "district": "Wes-Del Community Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180450002607",
    },
    {
        "school": "Center for Inquiry School 70",
        "district": "Indianapolis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002605",
    },
    {
        "school": "Gambold Pre-School",
        "district": "Indianapolis Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002611",
    },
    {
        "school": "John R. Wooden Middle School",
        "district": "M S D Martinsville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180651002600",
    },
    {
        "school": "Bell Intermediate Academy",
        "district": "M S D Martinsville Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180651002612",
    },
    {
        "school": "Tecumseh Middle School",
        "district": "Warrick County School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181239002609",
    },
    {
        "school": "Adair-Casey Jr. High School",
        "district": "Adair-Casey Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190309002236",
    },
    {
        "school": "Hamburg Middle School",
        "district": "Hamburg Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191344002235",
    },
    {
        "school": "Aurora Heights Elementary School",
        "district": "Newton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192061002233",
    },
    {
        "school": "Emerson Hough Elementary School",
        "district": "Newton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192061002238",
    },
    {
        "school": "Woodrow Wilson Elementary School",
        "district": "Newton Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192061002239",
    },
    {
        "school": "Berg Middle School",
        "district": "Newton Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192061002240",
    },
    {
        "school": "Perry Creek Elementary School",
        "district": "Sioux City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192640002237",
    },
    {
        "school": "Grant Ragan Elementary School",
        "district": "Waukee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051002234",
    },
    {
        "school": "Haven Virtual Academy",
        "district": "Haven Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200696002081",
    },
    {
        "school": "Hutchinson Middle School 7",
        "district": "Hutchinson Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200762002084",
    },
    {
        "school": "USD 331 Virtual School",
        "district": "Kingman - Norwich",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200807002082",
    },
    {
        "school": "Eisenhower Middle School",
        "district": "Liberal",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200873002080",
    },
    {
        "school": "Prairie View Elementary School",
        "district": "Liberal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200873002086",
    },
    {
        "school": "Maize Virtual Preparatory School",
        "district": "Maize",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200914002083",
    },
    {
        "school": "Northern Hills Elementary",
        "district": "Seaman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201149002085",
    },
    {
        "school": "The Learning Center",
        "district": "Valley Center Pub Sch",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201251002087",
    },
    {
        "school": "Imagineering Academy",
        "district": "Boone County",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210051002429",
    },
    {
        "school": "Booker T Washington Elementary School",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002426",
    },
    {
        "school": "Coventry Oak Elementary",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002433",
    },
    {
        "school": "Garrett Morgan Elementary",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002435",
    },
    {
        "school": "SAP Program",
        "district": "Fayette County",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210186002438",
    },
    {
        "school": "College View Campus",
        "district": "Hardin County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210249002439",
    },
    {
        "school": "Norton Commons Elementary",
        "district": "Jefferson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299002430",
    },
    {
        "school": "Laurel County Virtual Academy",
        "district": "Laurel County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210321002436",
    },
    {
        "school": "Lee County Middle High School",
        "district": "Lee County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210327002434",
    },
    {
        "school": "South Marshall Middle",
        "district": "Marshall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210381002428",
    },
    {
        "school": "McCreary County Preschool North",
        "district": "McCreary County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210399002437",
    },
    {
        "school": "Phoenix Horizon Community",
        "district": "Scott County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210526002432",
    },
    {
        "school": "Taylor County Primary Center",
        "district": "Taylor County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210552002431",
    },
    {
        "school": "GEO International High School",
        "district": "Warren County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210573002427",
    },
    {
        "school": "Greater Grace Charter Academy Inc.",
        "district": "Greater Grace Charter Academy Inc",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027202428",
    },
    {
        "school": "Lincoln Preparatory School",
        "district": "Lincoln Preparatory School",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027502421",
    },
    {
        "school": "Livingston Collegiate Academy",
        "district": "Livingston Collegiate Academy",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027602433",
    },
    {
        "school": "KIPP Booker T Washington",
        "district": "KIPP Booker T Washington",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027702434",
    },
    {
        "school": "North Caddo Elementary-Middle School",
        "district": "Caddo Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030002424",
    },
    {
        "school": "Caddo Virtual Academy",
        "district": "Caddo Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030002426",
    },
    {
        "school": "AmiKiDs Caddo",
        "district": "Caddo Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030002431",
    },
    {
        "school": "EBR Virtual Academy",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002423",
    },
    {
        "school": "Cranberry Isles School",
        "district": "Cranberry Isles Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230462023153",
    },
    {
        "school": "Central Community Elementary School",
        "district": "RSU 64/MSAD 64",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231444023158",
    },
    {
        "school": "Hodgdon Middle/High School",
        "district": "RSU 70/MSAD 70",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476223151",
    },
    {
        "school": "Oceanside Middle School",
        "district": "RSU 13",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478723154",
    },
    {
        "school": "Oceanside High School",
        "district": "RSU 13",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478723156",
    },
    {
        "school": "Thomaston Grammar School",
        "district": "RSU 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478723157",
    },
    {
        "school": "Spruce Mountain Elementary School",
        "district": "RSU 73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480523150",
    },
    {
        "school": "Spruce Mountain Primary School",
        "district": "RSU 73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480523152",
    },
    {
        "school": "Acadia Academy School",
        "district": "Acadia Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231483123149",
    },
    {
        "school": "Maine Arts Academy School",
        "district": "Maine Arts Academy",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231483223155",
    },
    {
        "school": "Hallie Wells Middle School",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001739",
    },
    {
        "school": "Jonathan Hager Elementary",
        "district": "Washingtion County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240066001740",
    },
    {
        "school": "New Heights Charter School of Brockton",
        "district": "New Heights Charter School of Brockton (District)",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250055902869",
    },
    {
        "school": "Carol Huebner Early Childhood Program",
        "district": "Acton-Boxborough",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250171002867",
    },
    {
        "school": "Therapeutic Day School",
        "district": "Bridgewater-Raynham",
        "level": "High",
        "type": "Special education school",
        "state": "MA",
        "nces_id": "250303002866",
    },
    {
        "school": "The Career Academy",
        "district": "Lowell",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702002860",
    },
    {
        "school": "Lunenburg Middle School",
        "district": "Lunenburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250708002870",
    },
    {
        "school": "Turkey Hill Elementary School",
        "district": "Lunenburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250708002871",
    },
    {
        "school": "New Liberty Innovation School",
        "district": "Salem",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251038002864",
    },
    {
        "school": "Southbridge Middle School",
        "district": "Southbridge",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251101002865",
    },
    {
        "school": "Southbridge High School",
        "district": "Southbridge",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251101002868",
    },
    {
        "school": "Gateway to College",
        "district": "Uxbridge",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "251185002862",
    },
    {
        "school": "Waltham Public Schools Dual Language Program",
        "district": "Waltham",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251200002863",
    },
    {
        "school": "Westport Junior/Senior High School",
        "district": "Westport",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251278002861",
    },
    {
        "school": "Marvin L Winans Academy Middle School",
        "district": "Marvin L. Winans Academy of Performing Arts",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260016908798",
    },
    {
        "school": "Huron Academy Grades 38",
        "district": "Huron Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260021108769",
    },
    {
        "school": "Hope of Detroit Academy  MiddleHigh",
        "district": "Hope of Detroit Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260024308799",
    },
    {
        "school": "Crescent Academy PK1",
        "district": "Crescent Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260029508588",
    },
    {
        "school": "ACE Academy  Jefferson site",
        "district": "ACE Academy (SDA)",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260094308800",
    },
    {
        "school": "Lighthouse Academy  Eagle Village",
        "district": "Lighthouse Academy",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260094908763",
    },
    {
        "school": "Lighthouse Academy  The Pier",
        "district": "Lighthouse Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260094908764",
    },
    {
        "school": "American International Academy High SchoolMiddle Schooll",
        "district": "American International Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260098608795",
    },
    {
        "school": "New Paradigm Glazer Academy",
        "district": "New Paradigm Glazer-Loving Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260099804881",
    },
    {
        "school": "Communication and Media Arts High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110300079",
    },
    {
        "school": "Paul Robeson Malcolm X Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110300081",
    },
    {
        "school": "Golightly Education Center",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110300085",
    },
    {
        "school": "Detroit School of Arts",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110300093",
    },
    {
        "school": "Davis Aerospace Technical High School at Golightly",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110300279",
    },
    {
        "school": "Palmer Park Preparatory Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110301293",
    },
    {
        "school": "Blackwell Institute",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110301298",
    },
    {
        "school": "Moses Field Center",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260110301299",
    },
    {
        "school": "Detroit Lions Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110301419",
    },
    {
        "school": "West Side Academy of Information Technology and Cyber Securi",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110301423",
    },
    {
        "school": "Charles Wright Academy of Arts and Science",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110301609",
    },
    {
        "school": "Fisher Magnet Lower Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110301611",
    },
    {
        "school": "Fisher Magnet Upper Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110301679",
    },
    {
        "school": "Diann BanksWilliamson Educational Center",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260110301703",
    },
    {
        "school": "Jerry L White Center",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260110301920",
    },
    {
        "school": "Keidan Special Education Center",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110301922",
    },
    {
        "school": "AL Holmes Academy of Blended Learning",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304637",
    },
    {
        "school": "Ann Arbor Trail Magnet School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304641",
    },
    {
        "school": "Bagley Elementary School of Journalism and Technology",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304643",
    },
    {
        "school": "Roberto Clemente Learning Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304646",
    },
    {
        "school": "Bennett Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304650",
    },
    {
        "school": "Bunche Preparatory Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304658",
    },
    {
        "school": "Burton International Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304663",
    },
    {
        "school": "Carstens ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304667",
    },
    {
        "school": "Carver STEM Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304668",
    },
    {
        "school": "Cass Technical High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304669",
    },
    {
        "school": "Chrysler Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304675",
    },
    {
        "school": "Cooke STEM Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304683",
    },
    {
        "school": "Thurgood Marshall Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304691",
    },
    {
        "school": "Davison ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304692",
    },
    {
        "school": "Dixon Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304695",
    },
    {
        "school": "Dossin ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304696",
    },
    {
        "school": "Durfee ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304701",
    },
    {
        "school": "Martin Luther King Jr Senior High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304703",
    },
    {
        "school": "Edison Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304704",
    },
    {
        "school": "Emerson ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304707",
    },
    {
        "school": "Gardner Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304717",
    },
    {
        "school": "Gompers ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304719",
    },
    {
        "school": "Greenfield Union ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304722",
    },
    {
        "school": "Harms Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304732",
    },
    {
        "school": "Hutchinson ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304744",
    },
    {
        "school": "John R King Academic and Performing Arts Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304756",
    },
    {
        "school": "Mann Learning Community",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304772",
    },
    {
        "school": "Mark Twain ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304774",
    },
    {
        "school": "Marquette ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304775",
    },
    {
        "school": "Mason Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304778",
    },
    {
        "school": "Maybury Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304779",
    },
    {
        "school": "Neinas Dual Language Learning Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304796",
    },
    {
        "school": "Nichols ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304799",
    },
    {
        "school": "Detroit Collegiate Preparatory High School at Northwestern",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304802",
    },
    {
        "school": "Pasteur Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304809",
    },
    {
        "school": "Priest ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304816",
    },
    {
        "school": "Pulaski ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304817",
    },
    {
        "school": "Schulze Academy for Technology and Arts",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304826",
    },
    {
        "school": "Spain ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304832",
    },
    {
        "school": "Ludington Magnet Middle School",
        "district": "Detroit Public Schools Community District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304834",
    },
    {
        "school": "Coleman A Young Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304835",
    },
    {
        "school": "Edward  Duke  Ellington at Beckham",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304838",
    },
    {
        "school": "Ronald Brown Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304841",
    },
    {
        "school": "Thirkell ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304845",
    },
    {
        "school": "Vernor Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304848",
    },
    {
        "school": "Bow ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304851",
    },
    {
        "school": "Wayne Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304853",
    },
    {
        "school": "SampsonWebber Leadership Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304855",
    },
    {
        "school": "Western International High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304857",
    },
    {
        "school": "Carleton Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304880",
    },
    {
        "school": "Noble ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304892",
    },
    {
        "school": "Renaissance High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304906",
    },
    {
        "school": "Frederick Douglass Academy for Young Men",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110307415",
    },
    {
        "school": "Bates Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110307481",
    },
    {
        "school": "Clippert Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110307754",
    },
    {
        "school": "Foreign Language Immersion and Cultural Studies",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110307755",
    },
    {
        "school": "Garvey Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110307756",
    },
    {
        "school": "Detroit International Academy for Young Women",
        "district": "Detroit Public Schools Community District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110307972",
    },
    {
        "school": "Cody High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110307984",
    },
    {
        "school": "Henderson Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308041",
    },
    {
        "school": "J E Clark Preparatory Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308052",
    },
    {
        "school": "Brewer Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308081",
    },
    {
        "school": "Osborn High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308084",
    },
    {
        "school": "Mackenzie ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308222",
    },
    {
        "school": "Earhart ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308245",
    },
    {
        "school": "Munger ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308262",
    },
    {
        "school": "Benjamin Carson High School of Science and Medicine",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308271",
    },
    {
        "school": "Charles R Drew Transition Center",
        "district": "Detroit Public Schools Community District",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260110308275",
    },
    {
        "school": "East English Village Preparatory Academy",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308306",
    },
    {
        "school": "Success Virtual Learning Centers of Michigan",
        "district": "Success Virtual Learning Centers of Michigan",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260110408772",
    },
    {
        "school": "Saginaw Covenant Academy",
        "district": "Saginaw Covenant Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260110608786",
    },
    {
        "school": "Highpoint Virtual Academy of MIchigan",
        "district": "Highpoint Virtual Academy of Michigan",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110708801",
    },
    {
        "school": "Livingston Classical Academy",
        "district": "Livingston Classical Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110808791",
    },
    {
        "school": "Inkster Preparatory Academy",
        "district": "Inkster Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260111008797",
    },
    {
        "school": "Dream Innovative Academy",
        "district": "Benton Harbor Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260483007861",
    },
    {
        "school": "Success  Kenowa Hills",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008753",
    },
    {
        "school": "Flat Rock Academic Virtual Academy K5",
        "district": "Flat Rock Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260708008792",
    },
    {
        "school": "Burr Oak Virtual Academy",
        "district": "Burr Oak Community School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260741008787",
    },
    {
        "school": "Chesaning Union Schools Alternative Education",
        "district": "Chesaning Union Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260915008784",
    },
    {
        "school": "Renaissance Virtual School",
        "district": "Clarkston Community School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260990008777",
    },
    {
        "school": "Dexter Alternative School",
        "district": "Dexter Community School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261203008790",
    },
    {
        "school": "Eastpointe Virtual Academy",
        "district": "Eastpointe Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261245008766",
    },
    {
        "school": "FAPSGEAR UP ACADEMY",
        "district": "Fenton Area Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261425008756",
    },
    {
        "school": "Lakeshore Virtual School",
        "district": "Gibraltar School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261587008793",
    },
    {
        "school": "Viking Virtual Academy",
        "district": "Hazel Park School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261803008776",
    },
    {
        "school": "Holland Language Academy at Van Raalte",
        "district": "Holland City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261842008781",
    },
    {
        "school": "Jamestown Lower Elementary School",
        "district": "Hudsonville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884008782",
    },
    {
        "school": "Kalamazoo Innovative Learning Program",
        "district": "Kalamazoo Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261995008761",
    },
    {
        "school": "Learning Options High School",
        "district": "Lake Orion Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262073008778",
    },
    {
        "school": "Harrington Elementary School",
        "district": "Marshall Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262297003950",
    },
    {
        "school": "Mason Virtual Academy",
        "district": "Mason Consolidated Schools (Monroe)",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262310008771",
    },
    {
        "school": "Endeavour Elementary and Middle School",
        "district": "New Haven Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262523008768",
    },
    {
        "school": "Tier III Intervention Academy",
        "district": "Pontiac City School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262874008773",
    },
    {
        "school": "Southfield High School for the Arts and Technology",
        "district": "Southfield Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263231008774",
    },
    {
        "school": "Union City High School Early College",
        "district": "Union City Community Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263441008755",
    },
    {
        "school": "Vandercook Lake Virtual Academy",
        "district": "Vandercook Lake Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263465008759",
    },
    {
        "school": "Ypsilanti International Elementary School",
        "district": "Ypsilanti Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263663008788",
    },
    {
        "school": "ACCE",
        "district": "Ypsilanti Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263663008789",
    },
    {
        "school": "Kalamazoo RESA West CampusECSE",
        "district": "Kalamazoo RESA",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268060008760",
    },
    {
        "school": "Eveleth Gilbert HOPE Program",
        "district": "EVELETH-GILBERT SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002105010",
    },
    {
        "school": "Parkers Lake High School",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002505014",
    },
    {
        "school": "Allina PHP CT",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002505056",
    },
    {
        "school": "Glacial Ridge Transitional Skills P",
        "district": "Lake Agassiz Education Cooperative",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270004005080",
    },
    {
        "school": "Sholund School for Girls",
        "district": "MEEKER AND WRIGHT SPECIAL EDUCATION",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270004505005",
    },
    {
        "school": "HVED Spectrum Program",
        "district": "HIAWATHA VALLEY ED. DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270005504960",
    },
    {
        "school": "Benton Stearns Education District 1",
        "district": "Benton-Stearns Education District",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007104986",
    },
    {
        "school": "RTR ALC",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270008605037",
    },
    {
        "school": "STARRS ONLINE ACADEMY",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270008605093",
    },
    {
        "school": "Fillmore Central ALP",
        "district": "FILLMORE CENTRAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270010005076",
    },
    {
        "school": "Banaadir South",
        "district": "MINNESOTA TRANSITIONS CHARTER SCH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011704989",
    },
    {
        "school": "ALP Credit Recovery",
        "district": "HOWARD LAKE-WAVERLY-WINSTED",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270012305059",
    },
    {
        "school": "Blue Earth Area Early Childhood Spe",
        "district": "BLUE EARTH AREA PUBLIC SCHOOL",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270013004998",
    },
    {
        "school": "Early Wonders Preschool Partnership",
        "district": "PARTNERSHIP ACADEMY INC.",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270023704966",
    },
    {
        "school": "Seven Hills Prep Academy Lower El",
        "district": "SEVEN HILLS PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028405030",
    },
    {
        "school": "SMEC ALC",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270032704978",
    },
    {
        "school": "Enrich Program",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032704983",
    },
    {
        "school": "CARDS Program",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032705011",
    },
    {
        "school": "Success Program",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032705013",
    },
    {
        "school": "Wolverine Program",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032705020",
    },
    {
        "school": "Flight Program",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032705061",
    },
    {
        "school": "LILA Annex",
        "district": "LAKES INTERNATIONAL LANGUAGE ACADEM",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270035805055",
    },
    {
        "school": "Kaleidoscope Middle School",
        "district": "KALEIDOSCOPE CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036005071",
    },
    {
        "school": "Little Mountain Elementary - SNW",
        "district": "SHERBURNE AND NORTHERN WRIGHT SPECI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270041305084",
    },
    {
        "school": "Primary DCD - SNW",
        "district": "SHERBURNE AND NORTHERN WRIGHT SPECI",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041305086",
    },
    {
        "school": "Intensive DCD  - SNW",
        "district": "SHERBURNE AND NORTHERN WRIGHT SPECI",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041305087",
    },
    {
        "school": "SW Metro ALC",
        "district": "Southwest Metro Intermediate 288",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270042004979",
    },
    {
        "school": "SW Metro Online Learning",
        "district": "Southwest Metro Intermediate 288",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270042004995",
    },
    {
        "school": "SW Metro Day Treatment",
        "district": "Southwest Metro Intermediate 288",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270042004999",
    },
    {
        "school": "SW Metro CCJ",
        "district": "Southwest Metro Intermediate 288",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270042005015",
    },
    {
        "school": "SW Metro Level 4 Programs",
        "district": "Southwest Metro Intermediate 288",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270042005038",
    },
    {
        "school": "SW Metro Independent Study",
        "district": "Southwest Metro Intermediate 288",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270042005044",
    },
    {
        "school": "SW Metro JAF",
        "district": "Southwest Metro Intermediate 288",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270042005050",
    },
    {
        "school": "SW Metro Seat Based",
        "district": "Southwest Metro Intermediate 288",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270042005052",
    },
    {
        "school": "SW Shakopee Special Ed",
        "district": "Southwest Metro Intermediate 288",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270042005063",
    },
    {
        "school": "Lakeside Academy",
        "district": "Southwest Metro Intermediate 288",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270042005091",
    },
    {
        "school": "Laura Baker SUN Program",
        "district": "Cannon Valley Special Education Coo",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270042405068",
    },
    {
        "school": "CVSEC STEP",
        "district": "Cannon Valley Special Education Coo",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270042405069",
    },
    {
        "school": "Oakland Education Center",
        "district": "Austin Albert Lea Area Special Educ",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270042605016",
    },
    {
        "school": "Austin Albert Lea Area Sp Ed Coop",
        "district": "Austin Albert Lea Area Special Educ",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270042605045",
    },
    {
        "school": "Phoenix Academy Charter School",
        "district": "Phoenix Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270042904969",
    },
    {
        "school": "Athlos Academy of Saint Cloud",
        "district": "Athlos Academy of Saint Cloud",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270043004959",
    },
    {
        "school": "Skyline Math and Science Academy",
        "district": "Skyline Math and Science Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270043305067",
    },
    {
        "school": "Marine Area Community School",
        "district": "Marine Area Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270043705088",
    },
    {
        "school": "SciTech Academy Charter School",
        "district": "SciTech Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270043905072",
    },
    {
        "school": "Northern Lights Academy",
        "district": "Northern Lights Academy Cooperative",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270044205073",
    },
    {
        "school": "NE Metro North",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270226404984",
    },
    {
        "school": "NE Metro Tartan",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270226405031",
    },
    {
        "school": "CLC - Pre-Kindergarten",
        "district": "AUSTIN PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270345005043",
    },
    {
        "school": "Breckenridge Area Learning Program",
        "district": "BRECKENRIDGE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270615004963",
    },
    {
        "school": "Brooklyn Center Middle School ALC",
        "district": "BROOKLYN CENTER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270624004780",
    },
    {
        "school": "Brooklyn Center ECSE Age 3 - 5",
        "district": "BROOKLYN CENTER SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270624004970",
    },
    {
        "school": "Diamondhead Ready to Learn",
        "district": "BURNSVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270729004990",
    },
    {
        "school": "Riverside Academy IS",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270741004972",
    },
    {
        "school": "Riverside Academy",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270741005006",
    },
    {
        "school": "Riverside Academy MLP",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270741005021",
    },
    {
        "school": "Carver Elementary School",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270819005049",
    },
    {
        "school": "FOCUS ALP",
        "district": "CHATFIELD PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270822005070",
    },
    {
        "school": "Anchor",
        "district": "COLUMBIA HEIGHTS PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270951004971",
    },
    {
        "school": "Tonka Online",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271167005003",
    },
    {
        "school": "Transition Plus",
        "district": "MINNETONKA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271167005057",
    },
    {
        "school": "McKinley PreK",
        "district": "FARIBAULT PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271176004988",
    },
    {
        "school": "Early Childhood Special Education S",
        "district": "FRIDLEY PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271242005079",
    },
    {
        "school": "Voluntary Prekindergarten School",
        "district": "FRIDLEY PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271242005082",
    },
    {
        "school": "Hendricks Preschool",
        "district": "HENDRICKS PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271368004987",
    },
    {
        "school": "Hendricks Middle School ALC",
        "district": "HENDRICKS PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271368005007",
    },
    {
        "school": "Pine County Transition Program",
        "district": "HINCKLEY-FINLAYSON SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271407005064",
    },
    {
        "school": "SENOPS",
        "district": "HOPKINS PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271426005032",
    },
    {
        "school": "Passages Transition Program",
        "district": "MAHTOMEDI PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "271875005041",
    },
    {
        "school": "Menahga Middle School",
        "district": "MENAHGA PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272058005019",
    },
    {
        "school": "Southwest High School - SWS",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124004975",
    },
    {
        "school": "Prekindergarten South",
        "district": "Minneapolis Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124004991",
    },
    {
        "school": "800 W Broadway Extended",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124005000",
    },
    {
        "school": "800 W Broadway",
        "district": "Minneapolis Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272124005036",
    },
    {
        "school": "Prekindergarten North",
        "district": "Minneapolis Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272124005048",
    },
    {
        "school": "Eastview Education Center",
        "district": "MONTICELLO PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272139005092",
    },
    {
        "school": "Dorothy Dodds Elementary School",
        "district": "MOORHEAD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272142005026",
    },
    {
        "school": "Career and Life Transition Program",
        "district": "MOUNDS VIEW PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272295005060",
    },
    {
        "school": "NEW ULM MIDDLE SCHOOL",
        "district": "NEW ULM PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272349005035",
    },
    {
        "school": "Frank White Education Center",
        "district": "PARK RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272808004965",
    },
    {
        "school": "Princeton Area Learning Center",
        "district": "PRINCETON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273003005001",
    },
    {
        "school": "Early Childhood Center",
        "district": "PROCTOR PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273009005081",
    },
    {
        "school": "FAIR School Pilgrim Lane",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178005078",
    },
    {
        "school": "Mighty Oaks Early Learning School",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273180005022",
    },
    {
        "school": "Rochester ALC Recovery Program",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273180005034",
    },
    {
        "school": "East Lake Elementary School",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273239004981",
    },
    {
        "school": "Centerview Elementary",
        "district": "SPRING LAKE PARK PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273333005028",
    },
    {
        "school": "Saints Academy",
        "district": "St. Francis Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273354004980",
    },
    {
        "school": "Saints Guided Studies",
        "district": "St. Francis Area Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273354005051",
    },
    {
        "school": "Valley Crossing Elementary",
        "district": "SOUTH WASHINGTON COUNTY SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273381004967",
    },
    {
        "school": "Early Ed Eastern Heights",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384004992",
    },
    {
        "school": "WM - Connections",
        "district": "Watertown-Mayer Public School Dist",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274191005062",
    },
    {
        "school": "Special Education",
        "district": "WEST ST. PAUL-MENDOTA HTS.-EAGAN",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274227005008",
    },
    {
        "school": "Lakeland Elementary School",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274272005083",
    },
    {
        "school": "W.O.R.K. Program",
        "district": "RIVER BEND EDUCATION DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279135305009",
    },
    {
        "school": "R.I.S.E. Program",
        "district": "RIVER BEND EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279135305074",
    },
    {
        "school": "Lake City Credit Recovery",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279144305058",
    },
    {
        "school": "OVERSTREET ELEMENTARY",
        "district": "STARKVILLE- OKTIBBEHA CONS DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018901468",
    },
    {
        "school": "JOEL E. SMILOW PREP",
        "district": "JOEL E. SMILLOW PREP",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019201471",
    },
    {
        "school": "BELLE SHIVERS MIDDLE SCHOOL",
        "district": "ABERDEEN SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280036001467",
    },
    {
        "school": "NORTH GULFPORT MIDDLE SCHOOL",
        "district": "HARRISON CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280177001469",
    },
    {
        "school": "LELAND SCHOOL PARK",
        "district": "LELAND SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280261001472",
    },
    {
        "school": "SOUTH HARRISON MIDDLE",
        "district": "SOUTH HARRISON CO. R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290000203297",
    },
    {
        "school": "CROSSROADS - QUALITY HILL",
        "district": "CROSSROADS CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060303295",
    },
    {
        "school": "EAGLE TOWER GROVE EAST",
        "district": "EAGLE COLLEGE PREP ENDEAVOR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060503299",
    },
    {
        "school": "CENTER FOR EARLY LRNING-NORTH",
        "district": "COLUMBIA 93",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100003287",
    },
    {
        "school": "BEULAH RALPH ELEMENTARY",
        "district": "COLUMBIA 93",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290100003292",
    },
    {
        "school": "FLINT HILL ELEMENTARY",
        "district": "FT. ZUMWALT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837003289",
    },
    {
        "school": "CLINTON EARLY CHILDHOOD CENTER",
        "district": "CLINTON",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290986003291",
    },
    {
        "school": "GALLATIN MIDDLE SCHOOL",
        "district": "GALLATIN R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291266003296",
    },
    {
        "school": "HUMANSVILLE MIDDLE SCHOOL",
        "district": "HUMANSVILLE R-IV",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291530003298",
    },
    {
        "school": "Early Learning Center",
        "district": "ORCHARD FARM R-V",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292316003290",
    },
    {
        "school": "COMPASS ELEMENTARY",
        "district": "PLATTE CO. R-III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292523003288",
    },
    {
        "school": "RITENOUR EARLY CHILDHOOD CTR",
        "district": "RITENOUR",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292664003300",
    },
    {
        "school": "TROY SOUTH MIDDLE SCHOOL",
        "district": "TROY R-III",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293045003293",
    },
    {
        "school": "Hillside Colony School",
        "district": "Liberty Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009300081",
    },
    {
        "school": "Rimrock Colony School",
        "district": "Liberty Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300009300089",
    },
    {
        "school": "Pondera Colony School",
        "district": "Dutton/Brady K-12 Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300010201116",
    },
    {
        "school": "F E Miley School",
        "district": "Big Sandy K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300375000055",
    },
    {
        "school": "Big Sandy 7-8",
        "district": "Big Sandy K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300375000868",
    },
    {
        "school": "Medicine Crow Middle School",
        "district": "Billings Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387001115",
    },
    {
        "school": "Hill Top Colony School",
        "district": "Centerville Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302513001117",
    },
    {
        "school": "CRETE INTERMEDIATE SCHOOL",
        "district": "CRETE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009502345",
    },
    {
        "school": "ARBOR VIEW ELEMENTARY SCHOOL",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011002337",
    },
    {
        "school": "SWEDE PRESCHOOL ACADEMY",
        "district": "GOTHENBURG PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317110002340",
    },
    {
        "school": "WYSONG ELEMENTARY",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002329",
    },
    {
        "school": "EASTWARD ELEMENTARY SCHOOL",
        "district": "NELIGH-OAKDALE SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317422002327",
    },
    {
        "school": "WESTWARD ELEMENTARY SCHOOL",
        "district": "NELIGH-OAKDALE SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317422002332",
    },
    {
        "school": "EARLY LEARNING CENTER (0-3) AT GATEWAY",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482002326",
    },
    {
        "school": "OPS VIRTUAL ELEMENTARY SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482002336",
    },
    {
        "school": "OPS VIRTUAL MIDDLE SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482002339",
    },
    {
        "school": "EARLY LEARNING CENTER (0-3) AT SKINNER",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482002344",
    },
    {
        "school": "LIBERTY MIDDLE SCHOOL",
        "district": "PAPILLION LA VISTA COMMUNITY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317527002341",
    },
    {
        "school": "18+ PROGRAM",
        "district": "EDUCATIONAL SERVICE UNIT 09",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "318009002335",
    },
    {
        "school": "CENTRAL HEAD START",
        "district": "EDUCATIONAL SERVICE UNIT 13",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318013002328",
    },
    {
        "school": "HOME BASED",
        "district": "EDUCATIONAL SERVICE UNIT 13",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318013002330",
    },
    {
        "school": "GERING HEAD START",
        "district": "EDUCATIONAL SERVICE UNIT 13",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318013002331",
    },
    {
        "school": "WESTERN NEBRASK CHILD DEV CENTER (WNCDC)",
        "district": "EDUCATIONAL SERVICE UNIT 13",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318013002342",
    },
    {
        "school": "BRIDGEPORT HEAD START",
        "district": "EDUCATIONAL SERVICE UNIT 13",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318013002347",
    },
    {
        "school": "Sports Leadership and Management Academy",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100870",
    },
    {
        "school": "Warm Springs Elementary/Middle School",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320036000871",
    },
    {
        "school": "Claremont Preschool Center",
        "district": "Claremont School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330234000724",
    },
    {
        "school": "Jonathan Daniels School",
        "district": "Keene School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330405000723",
    },
    {
        "school": "Middleton Elementary School",
        "district": "Middleton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330477000725",
    },
    {
        "school": "Marie H Katzenbach Elementary/ Middle School for the Deaf",
        "district": "Marie H. Katzenbach School for the Deaf",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "340077803377",
    },
    {
        "school": "Philip's Academy Charter School of Paterson",
        "district": "Philip's Academy Charter School of Paterson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340078403383",
    },
    {
        "school": "Camden's Promise Charter School",
        "district": "Camden's Promise Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340078503390",
    },
    {
        "school": "Cresthaven Academy Charter School",
        "district": "Cresthaven Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340078603385",
    },
    {
        "school": "Hudson Arts and Science Charter School",
        "district": "Hudson Arts and Science Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340078703387",
    },
    {
        "school": "J. Christian Bollwage Finance Academy",
        "district": "Elizabeth Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340459003389",
    },
    {
        "school": "Hoboken Middle School",
        "district": "Hoboken Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340735003381",
    },
    {
        "school": "Innovation High School",
        "district": "Jersey City Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783003378",
    },
    {
        "school": "Academy for Environmental Science",
        "district": "Morris County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341072003375",
    },
    {
        "school": "Lincoln Annex School",
        "district": "New Brunswick School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341122003379",
    },
    {
        "school": "Salome Ure?a Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134003374",
    },
    {
        "school": "Young Men's Academy",
        "district": "Paterson Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003369",
    },
    {
        "school": "Dr. Hani Awadallah School",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003382",
    },
    {
        "school": "School 16",
        "district": "Paterson Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003384",
    },
    {
        "school": "Union County Career & Technical Institute",
        "district": "Union County Vocational-Technical School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341804003391",
    },
    {
        "school": "NEW MEXICO INTERNATIONAL SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001072",
    },
    {
        "school": "SIEMBRA LEADERSHIP HIGH SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001117",
    },
    {
        "school": "ROOTS & WINGS COMMUNITY",
        "district": "ROOTS AND WINGS COMMUNITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350017600846",
    },
    {
        "school": "SIX DIRECTIONS INDIGENOUS SCHOOL",
        "district": "SIX DIRECTIONS INDIGENOUS SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350017701126",
    },
    {
        "school": "DESERT WILLOW ELEMENTARY",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030001118",
    },
    {
        "school": "OCOTILLO ELEMENTARY",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030001123",
    },
    {
        "school": "PECOS CONNECTIONS ACADEMY",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030001127",
    },
    {
        "school": "SAN JUAN COLLEGE HIGH SCHOOL",
        "district": "FARMINGTON MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350099001119",
    },
    {
        "school": "YUCCA HEIGHTS ELEMENTARY",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108001125",
    },
    {
        "school": "GADSDEN ADMIN COMPLEX PREK CENTER",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108001129",
    },
    {
        "school": "LA MESA ON TRACK PREK CENTER",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108001130",
    },
    {
        "school": "CHAPARRAL ON-TRACK PREK CENTER",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108001131",
    },
    {
        "school": "ANTHONY ON-TRACK PREK CENTER",
        "district": "GADSDEN INDEPENDENT SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350108001132",
    },
    {
        "school": "TOPPER FRESHMAN ACADEMY",
        "district": "LOS ALAMOS PUBLIC SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350165001122",
    },
    {
        "school": "EARLY COLLEGE HIGH SCHOOL",
        "district": "ROSWELL INDEPENDENT SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350225001128",
    },
    {
        "school": "EARLY COLLEGE OPPORTUNITIES",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237001120",
    },
    {
        "school": "SHIWI TS'ANA ELEMENTARY",
        "district": "ZUNI PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350280001124",
    },
    {
        "school": "PORT RICHMOND SCHOOL FOR VISIONARY LEARNING",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #31",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010306590",
    },
    {
        "school": "SCHOOL IN THE SQUARE PUBLIC CHARTER SCHOOL",
        "district": "SCHOOL IN THE SQUARE PUBLIC CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360113906571",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-BED STUY 3",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-BED STUY 3",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360114006583",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-SOUTH JAMAICA",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-SOUTH JAMAICA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360114106598",
    },
    {
        "school": "BRONX CHARTER SCHOOL FOR EXCELLENCE 2",
        "district": "BRONX CHARTER SCHOOL FOR EXCELLENCE 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360114206578",
    },
    {
        "school": "ACHIEVEMENT FIRST VOYAGER CHARTER SCHOOL",
        "district": "ACHIEVEMENT FIRST VOYAGER CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360114306591",
    },
    {
        "school": "CAPITAL PREPARATORY (CP) HARLEM CHARTER SCHOOL",
        "district": "CAPITAL PREPARATORY (CP) HARLEM CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360114406597",
    },
    {
        "school": "COLLEGIATE ACADEMY-MATH-PERSONAL AWA",
        "district": "COLLEGIATE ACADEMY-MATH-PERSONAL AWA",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360114506574",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-BUSHWICK",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-BUSHWICK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360114606580",
    },
    {
        "school": "SOUTH BRONX COMMUNITY CHARTER HIGH SCHOOL",
        "district": "SOUTH BRONX COMMUNITY CHARTER HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360114706595",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-FLATBUSH",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-FLATBUSH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360114806585",
    },
    {
        "school": "AMBER CHARTER SCHOOL KINGSBRIDGE",
        "district": "AMBER CHARTER SCHOOL KINGSBRIDGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360114906588",
    },
    {
        "school": "BROOKLYN PROSPECT CHARTER SCHOOL-CSD 13",
        "district": "BROOKLYN PROSPECT CHARTER SCHOOL-CSD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360115006582",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-FAR ROCKAWAY",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-FAR ROCKAWAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360115106581",
    },
    {
        "school": "GROWING UP GREEN CHARTER SCHOOL II",
        "district": "GROWING UP GREEN CHARTER SCHOOL II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360115206577",
    },
    {
        "school": "ROCHESTER PREP CHARTER SCHOOL 3",
        "district": "ROCHESTER PREP CHARTER SCHOOL 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360115306592",
    },
    {
        "school": "NEW YORK CITY CHARTER SCHOOL OF THE ARTS",
        "district": "NEW YORK CITY CHARTER SCHOOL OF THE ARTS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360115406586",
    },
    {
        "school": "ALDEN INTERMEDIATE SCHOOL",
        "district": "ALDEN CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360255006572",
    },
    {
        "school": "LAFAYETTE INTERNATIONAL SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585006593",
    },
    {
        "school": "EAST COMMUNITY SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585006594",
    },
    {
        "school": "NEWCOMER ACADEMY AT LAFAYETTE",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585006596",
    },
    {
        "school": "LINNAEUS W WEST SCHOOL",
        "district": "UNION-ENDICOTT CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361071006576",
    },
    {
        "school": "HUDSON JUNIOR HIGH SCHOOL",
        "district": "HUDSON CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361494006579",
    },
    {
        "school": "NIAGARA COUNTY JAIL",
        "district": "LOCKPORT CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "361767006587",
    },
    {
        "school": "MAHOPAC FALLS SCHOOL",
        "district": "MAHOPAC CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "361812006584",
    },
    {
        "school": "ONEIDA MIDDLE SCHOOL",
        "district": "SCHENECTADY CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362601006573",
    },
    {
        "school": "UNION SPRINGS MIDDLE SCHOOL",
        "district": "UNION SPRINGS CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362925006575",
    },
    {
        "school": "Montford North Star Academy",
        "district": "Asheville City Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370027003435",
    },
    {
        "school": "Asheville Primary",
        "district": "Asheville City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370027003436",
    },
    {
        "school": "Movement Charter School",
        "district": "Movement Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370041103431",
    },
    {
        "school": "Coastal Preparatory Academy",
        "district": "Coastal Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370041203415",
    },
    {
        "school": "Emereau: Bladen",
        "district": "Emereau: Bladen",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370041303430",
    },
    {
        "school": "UpROAR Leadership Academy",
        "district": "UpROAR Leadership Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370041603423",
    },
    {
        "school": "Pine Springs Prep Academy",
        "district": "Pine Springs Preparatory Academy: CFA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370041703413",
    },
    {
        "school": "Discovery Charter",
        "district": "Discovery Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370041803428",
    },
    {
        "school": "ECU Community School",
        "district": "East Carolina Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370041903434",
    },
    {
        "school": "Catamount School",
        "district": "Catamount School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042103437",
    },
    {
        "school": "Hawks Nest STEAM Academy",
        "district": "Gaston County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162003409",
    },
    {
        "school": "Gaston Virtual Academy",
        "district": "Gaston County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370162003433",
    },
    {
        "school": "Harnett Early College (HCEC)",
        "district": "Harnett County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201003443",
    },
    {
        "school": "Agriculture and Science Early College",
        "district": "Iredell-Statesville Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370231003432",
    },
    {
        "school": "Swift Creek Middle",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237003424",
    },
    {
        "school": "The Innovation Academy at South Campus",
        "district": "Johnston County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370237003441",
    },
    {
        "school": "GW Carver Elementary",
        "district": "Kannapolis City Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370243003429",
    },
    {
        "school": "J T Williams Secondary Montessori",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003416",
    },
    {
        "school": "Renaissance West STEAM Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003417",
    },
    {
        "school": "Charlotte Teacher Early College",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003418",
    },
    {
        "school": "Vaughan Academy of Technology",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003419",
    },
    {
        "school": "Marie G Davis",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003420",
    },
    {
        "school": "Merancas Middle College High",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003421",
    },
    {
        "school": "Montgomery County Early College",
        "district": "Montgomery County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306003438",
    },
    {
        "school": "SEA-Tech",
        "district": "New Hanover County Schools",
        "level": "Secondary",
        "type": "Career and Technical School",
        "state": "NC",
        "nces_id": "370333003439",
    },
    {
        "school": "Onslow Early College",
        "district": "Onslow County Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345003425",
    },
    {
        "school": "Elizabeth City Pasquotank Early College",
        "district": "Elizabeth City-Pasquotank Public Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370354003426",
    },
    {
        "school": "Oakboro Choice STEM",
        "district": "Stanly County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432003440",
    },
    {
        "school": "North Wake College and Career Academy",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003410",
    },
    {
        "school": "Rogers Lane Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003411",
    },
    {
        "school": "River Bend Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003412",
    },
    {
        "school": "Hortons Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003414",
    },
    {
        "school": "Washington Early College High",
        "district": "Washington County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370480003442",
    },
    {
        "school": "DICKINSON MIDDLE SCHOOL",
        "district": "DICKINSON 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003800887",
    },
    {
        "school": "WATFORD CITY MIDDLE SCHOOL",
        "district": "MCKENZIE CO 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381254000886",
    },
    {
        "school": "WILLOW PARK ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000888",
    },
    {
        "school": "Village Preparatory School Willard",
        "district": "Village Preparatory School Willard",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390158105885",
    },
    {
        "school": "Bridge Gate Community School",
        "district": "Bridge Gate Community School",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390158205874",
    },
    {
        "school": "Westwood Preparatory Academy",
        "district": "Westwood Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390158305886",
    },
    {
        "school": "East Branch Preparatory AcademydbaWright Preparatory Academy",
        "district": "East Branch Preparatory AcademydbaWright Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390158405877",
    },
    {
        "school": "iLEAD Spring Meadows",
        "district": "iLEAD Spring Meadows",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390158505881",
    },
    {
        "school": "Beacon Academy",
        "district": "Beacon Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390158605871",
    },
    {
        "school": "Urban Early College Network",
        "district": "Urban Early College Network",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390158705880",
    },
    {
        "school": "Global Ambassadors Language Academy",
        "district": "Global Ambassadors Language Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390158805878",
    },
    {
        "school": "Lincoln West School Of Global Studies",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805873",
    },
    {
        "school": "Lincoln West School of Science & Health",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805888",
    },
    {
        "school": "Northgate Intermediate",
        "district": "Columbus City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438005884",
    },
    {
        "school": "Linden Park Neighborhood Early Childhood Education Center",
        "district": "Columbus City School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438005887",
    },
    {
        "school": "Southview Middle School",
        "district": "Lorain City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442605875",
    },
    {
        "school": "Springmill STEM Elementary",
        "district": "Mansfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442905872",
    },
    {
        "school": "Bolton Crossing Elementary",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448005876",
    },
    {
        "school": "Allen East Middle School",
        "district": "Allen East Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390457505882",
    },
    {
        "school": "Buckeye Career Center Annex-Hiland Satellite",
        "district": "Buckeye",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390516505883",
    },
    {
        "school": "Little Whippets Preschool",
        "district": "Shelby City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391000905879",
    },
    {
        "school": "CARLTON LANDING ACADEMY ES",
        "district": "CARLTON LANDING ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079502830",
    },
    {
        "school": "SANTA FE SOUTH MS",
        "district": "SANTA FE SOUTH (CHARTER)",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079602829",
    },
    {
        "school": "SANTA FE S PATHWAYS MID COLLEG",
        "district": "SANTA FE SOUTH (CHARTER)",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079602831",
    },
    {
        "school": "SANTA FE SOUTH HILLS ES",
        "district": "SANTA FE SOUTH (CHARTER)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079602832",
    },
    {
        "school": "SANTA FE SOUTH PENN ES",
        "district": "SANTA FE SOUTH (CHARTER)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079602837",
    },
    {
        "school": "SANTA FE SOUTH HS",
        "district": "SANTA FE SOUTH (CHARTER)",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079602838",
    },
    {
        "school": "HEARTLAND MS",
        "district": "EDMOND",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401059002835",
    },
    {
        "school": "ELK CITY ES",
        "district": "ELK CITY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401074002836",
    },
    {
        "school": "WASHINGTON PRE KG CENTER",
        "district": "PONCA CITY",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402469002834",
    },
    {
        "school": "THACKERVILLE MS",
        "district": "THACKERVILLE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402985002833",
    },
    {
        "school": "Mountainside High School",
        "district": "Beaverton SD 48J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001855",
    },
    {
        "school": "Sato Elementary School",
        "district": "Beaverton SD 48J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410192001856",
    },
    {
        "school": "Cascade Opportunity Center",
        "district": "Cascade SD 5",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410278001854",
    },
    {
        "school": "Lighthouse Charter School",
        "district": "Coos Bay SD 9",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410366004188",
    },
    {
        "school": "Twin Rivers Charter School",
        "district": "Eugene SD 4J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001848",
    },
    {
        "school": "Bridges High School",
        "district": "Jefferson County SD 509J",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410674001852",
    },
    {
        "school": "Klamath Learning Center",
        "district": "Klamath Falls City Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410708001847",
    },
    {
        "school": "Bridge Charter Academy",
        "district": "Lowell SD 71",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410759001846",
    },
    {
        "school": "Redmond Early Learning Center at Hugh Hartman",
        "district": "Redmond SD 2J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411035001850",
    },
    {
        "school": "Rose School",
        "district": "Douglas County SD 4",
        "level": "High",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "411071001853",
    },
    {
        "school": "Oregon Virtual Education",
        "district": "Scio SD 95",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411104001818",
    },
    {
        "school": "The Cannon Beach Academy",
        "district": "Seaside SD 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411110001857",
    },
    {
        "school": "Sutherlin Valley Online Academy",
        "district": "Sutherlin SD 130",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411194001849",
    },
    {
        "school": "Meridian Creek Middle School",
        "district": "West Linn-Wilsonville SD 3J",
        "level": "Middle",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411317001851",
    },
    {
        "school": "Reach Cyber CS",
        "district": "Reach Cyber CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420088707580",
    },
    {
        "school": "KIPP West Philadelphia CS",
        "district": "KIPP West Philadelphia CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420088807590",
    },
    {
        "school": "Mastery CS John Wister Elementary",
        "district": "Mastery CS John Wister Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420088907599",
    },
    {
        "school": "Provident CS",
        "district": "Provident CS",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420089007574",
    },
    {
        "school": "MaST Community CS II",
        "district": "MaST Community CS II",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420089107602",
    },
    {
        "school": "Global Leadership Academy CS Southwest a",
        "district": "Global Leadership Academy CS Southwest at Huey",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420089207595",
    },
    {
        "school": "Independence CS West",
        "district": "Independence CS West",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420089307600",
    },
    {
        "school": "Innovative Arts Academy CS",
        "district": "Innovative Arts Academy CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420089407594",
    },
    {
        "school": "TECH Freire CS",
        "district": "TECH Freire CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420089507589",
    },
    {
        "school": "A L Wilson El Sch",
        "district": "Albert Gallatin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420210007575",
    },
    {
        "school": "West Berwick El Sch",
        "district": "Berwick Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420348007582",
    },
    {
        "school": "Brandywine Heights Intrmd/MS",
        "district": "Brandywine Heights Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420405007585",
    },
    {
        "school": "Brownsville Area El Sch",
        "district": "Brownsville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420408007573",
    },
    {
        "school": "Brookwood El Sch",
        "district": "Bristol Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420423007591",
    },
    {
        "school": "Mill Creek El Sch",
        "district": "Bristol Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420423007596",
    },
    {
        "school": "Keystone El Sch",
        "district": "Bristol Township SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420423007597",
    },
    {
        "school": "Marion El Sch",
        "district": "Chambersburg Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420555007579",
    },
    {
        "school": "Forest Hills JSHS",
        "district": "Forest Hills SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420994007586",
    },
    {
        "school": "Cougar Academy",
        "district": "Harrisburg City SD",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421158007583",
    },
    {
        "school": "Richard J. Hyde El Sch",
        "district": "Moon Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421583007577",
    },
    {
        "school": "Morrisville HS",
        "district": "Morrisville Borough SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421590007587",
    },
    {
        "school": "Morrisville Intermediate Sch",
        "district": "Morrisville Borough SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421590007601",
    },
    {
        "school": "Tawanka El Sch",
        "district": "Neshaminy SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421641007604",
    },
    {
        "school": "Philadelphia Learning Academy - South",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007588",
    },
    {
        "school": "Science Leadership Academy MS",
        "district": "Philadelphia City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007592",
    },
    {
        "school": "Kenderton El Sch",
        "district": "Philadelphia City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007593",
    },
    {
        "school": "Kensington HS",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007598",
    },
    {
        "school": "Philadelphia Learning Academy - North",
        "district": "Philadelphia City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007603",
    },
    {
        "school": "Shikellamy MS",
        "district": "Shikellamy SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422154007584",
    },
    {
        "school": "Sto-Rox Upper El Sch",
        "district": "Sto-Rox SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422283007576",
    },
    {
        "school": "Turbotville El Sch",
        "district": "Warrior Run SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422487007581",
    },
    {
        "school": "Westmont Hilltop JSHS",
        "district": "Westmont Hilltop SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422613007578",
    },
    {
        "school": "Blackstone Valley Prep Mid2",
        "district": "Blackstone Valley Prep  A RI Mayoral Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440001500513",
    },
    {
        "school": "Hope Highlands Middle School",
        "district": "Cranston",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440024000504",
    },
    {
        "school": "Cranston Early Learning Center",
        "district": "Cranston",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "RI",
        "nces_id": "440024000509",
    },
    {
        "school": "Warwick Veterans Middle School",
        "district": "Warwick",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440111000512",
    },
    {
        "school": "Maisie E. Quinn School",
        "district": "West Warwick",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440114000514",
    },
    {
        "school": "Philip Simmons High",
        "district": "Berkeley 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001681",
    },
    {
        "school": "Bowen's Corner Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001682",
    },
    {
        "school": "Carolina Park Elementary",
        "district": "Charleston 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001690",
    },
    {
        "school": "Camp Road Middle",
        "district": "Charleston 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450144001691",
    },
    {
        "school": "Socastee Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001677",
    },
    {
        "school": "St. James Intermediate",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001679",
    },
    {
        "school": "Ten Oaks Middle",
        "district": "Horry 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001680",
    },
    {
        "school": "Cayce Elementary",
        "district": "Lexington 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273001678",
    },
    {
        "school": "Jackson Creek Elementary",
        "district": "Richland 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450339001676",
    },
    {
        "school": "Pleasant Knoll Middle",
        "district": "York 04",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001683",
    },
    {
        "school": "Greenville Technical Charter High School",
        "district": "SC Public Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390100460",
    },
    {
        "school": "Felton Laboratory Charter School",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101401",
    },
    {
        "school": "GREEN Charter School of the Midlands",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101684",
    },
    {
        "school": "Legacy Early College",
        "district": "SC Public Charter School District",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101685",
    },
    {
        "school": "Brashier Middle College",
        "district": "SC Public Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101687",
    },
    {
        "school": "Greer Middle College Charter High",
        "district": "SC Public Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101688",
    },
    {
        "school": "Meyer Center for Special Children",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "SC",
        "nces_id": "450390101689",
    },
    {
        "school": "Patriot Elementary -06",
        "district": "Douglas School District 51-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "461941001384",
    },
    {
        "school": "Boulder Colony School - 06",
        "district": "Edmunds Central School District 22-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "463444001385",
    },
    {
        "school": "Sturgis Intermediate School - 06",
        "district": "Meade School District 46-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993001383",
    },
    {
        "school": "Todd County Achievement Middle School - 18",
        "district": "Todd County School District 66-1",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "467209001386",
    },
    {
        "school": "Kadoka Middle School - 03",
        "district": "Kadoka Area School District 35-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043701382",
    },
    {
        "school": "Memphis Scholars Raleigh-Egypt",
        "district": "Achievement School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702458",
    },
    {
        "school": "Kirby Middle School",
        "district": "Achievement School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702461",
    },
    {
        "school": "Memphis Scholars Caldwell-Guthrie",
        "district": "Achievement School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702462",
    },
    {
        "school": "Hillcrest High School",
        "district": "Achievement School District",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014702466",
    },
    {
        "school": "Memphis STEM Academy",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802459",
    },
    {
        "school": "Aspire East Academy",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802465",
    },
    {
        "school": "Memphis Delta Preparatory",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802467",
    },
    {
        "school": "Westhaven Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802470",
    },
    {
        "school": "Freedom Preparatory Academy Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802471",
    },
    {
        "school": "Power Center Academy Middle - Southeast",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802474",
    },
    {
        "school": "Jackson Central-Merry Early College High",
        "district": "Madison County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258002463",
    },
    {
        "school": "Rose Hill School",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470258002464",
    },
    {
        "school": "KA @ The Crossings",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002460",
    },
    {
        "school": "East Nashville Middle",
        "district": "Davidson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002468",
    },
    {
        "school": "Baxter Primary",
        "district": "Putnam County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470348002475",
    },
    {
        "school": "Mill Creek Elementary School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002469",
    },
    {
        "school": "Mill Creek Middle School",
        "district": "Williamson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002472",
    },
    {
        "school": "TEXANS CAN ACADEMY - GARLAND",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001613458",
    },
    {
        "school": "TEXANS CAN ACADEMY - HOUSTON SOUTHWEST",
        "district": "TEXANS CAN ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480001613459",
    },
    {
        "school": "UPLIFT WISDOM SECONDARY",
        "district": "UPLIFT EDUCATION",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013474",
    },
    {
        "school": "UPLIFT GRAND SECONDARY",
        "district": "UPLIFT EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013476",
    },
    {
        "school": "UPLIFT MIGHTY MIDDLE",
        "district": "UPLIFT EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013478",
    },
    {
        "school": "UPLIFT INFINITY H S",
        "district": "UPLIFT EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013481",
    },
    {
        "school": "UPLIFT MIGHTY H S",
        "district": "UPLIFT EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013482",
    },
    {
        "school": "UPLIFT WHITE ROCK HILLS PREP",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013483",
    },
    {
        "school": "UPLIFT LUNA SECONDARY SCHOOL",
        "district": "UPLIFT EDUCATION",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013484",
    },
    {
        "school": "SEGUIN EL",
        "district": "SOUTHWEST PREPARATORY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006313468",
    },
    {
        "school": "SETON HOME",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007113487",
    },
    {
        "school": "CEDAR CREST",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007113489",
    },
    {
        "school": "DR TERRY ROBBINS MIDDLE",
        "district": "PINEYWOODS COMMUNITY ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007413549",
    },
    {
        "school": "RICHARD MILBURN ACADEMY MIDLAND SOUTH",
        "district": "RICHARD MILBURN ALTER HIGH SCHOOL (KILLEEN)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007513433",
    },
    {
        "school": "RICHARD MILBURN ACADEMY PASADENA",
        "district": "RICHARD MILBURN ALTER HIGH SCHOOL (KILLEEN)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007513435",
    },
    {
        "school": "TEXAS SERENITY ACADEMY - GANO",
        "district": "TEXAS SERENITY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480015113543",
    },
    {
        "school": "FOUNDERS CLASSICAL ACADEMY OF SCHERTZ",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313495",
    },
    {
        "school": "FALLBROOK ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313497",
    },
    {
        "school": "JUBILEE BROWNSVILLE",
        "district": "JUBILEE ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017913451",
    },
    {
        "school": "EDUCATION CENTER INTERNATIONAL ACADEMY 3",
        "district": "EDUCATION CENTER INTERNATIONAL ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480018613557",
    },
    {
        "school": "VANGUARD BEETHOVEN",
        "district": "VANGUARD ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480019513536",
    },
    {
        "school": "PREMIER H S OF NORTH HOUSTON",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020713396",
    },
    {
        "school": "PREMIER H S OF TEXARKANA",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020713402",
    },
    {
        "school": "IDEA MAYS COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113504",
    },
    {
        "school": "IDEA JUDSON COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113508",
    },
    {
        "school": "IDEA BLUFF SPRINGS ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113510",
    },
    {
        "school": "IDEA TOROS COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113514",
    },
    {
        "school": "IDEA JUDSON ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113519",
    },
    {
        "school": "IDEA MAYS ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113520",
    },
    {
        "school": "IDEA BLUFF SPRINGS COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113523",
    },
    {
        "school": "NOLAN CREEK SCHOOL",
        "district": "ORENDA CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023513521",
    },
    {
        "school": "KINGSLAND SCHOOL",
        "district": "ORENDA CHARTER SCHOOL",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023513524",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - CEDAR PARK",
        "district": "HARMONY SCIENCE ACADEMY (AUSTIN)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480024113430",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY HOUSTON",
        "district": "SCHOOL OF SCIENCE AND TECHNOLOGY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480025813512",
    },
    {
        "school": "KIPP AUSTIN BRAVE",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413461",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - BROWNSVILLE",
        "district": "HARMONY SCIENCE ACAD (SAN ANTONIO)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026613421",
    },
    {
        "school": "HARMONY SCHOOL OF EXCELLENCE - LAREDO",
        "district": "HARMONY SCIENCE ACAD (SAN ANTONIO)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026613428",
    },
    {
        "school": "BROOKS ACADEMY OAKS",
        "district": "BROOKS ACADEMIES OF TEXAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026813397",
    },
    {
        "school": "HARMONY SCHOOL OF EXCELLENCE - EL PASO",
        "district": "HARMONY SCIENCE ACAD (EL PASO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027213391",
    },
    {
        "school": "HARMONY SCHOOL OF ENRICHMENT - HOUSTON",
        "district": "HARMONY SCHOOL OF EXCELLENCE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027413460",
    },
    {
        "school": "STEP CHARTER II",
        "district": "STEP CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027513436",
    },
    {
        "school": "THE RHODES SCHOOL - HUMBLE",
        "district": "THE RHODES SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480028313395",
    },
    {
        "school": "THE RHODES SCHOOL - NW",
        "district": "THE RHODES SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480028313400",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - PLANO",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029213498",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - WACO",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029213499",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY ADVANCEMENT",
        "district": "SCHOOL OF SCIENCE AND TECHNOLOGY DISCOVERY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140013427",
    },
    {
        "school": "HARMONY SCHOOL OF EXCELLENCE - SUGAR LAND",
        "district": "HARMONY SCHOOL OF SCIENCE - HOUSTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140513420",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - KATY",
        "district": "HARMONY SCHOOL OF SCIENCE - HOUSTON",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140513426",
    },
    {
        "school": "BOB HOPE SCHOOL - EL CAMPUS",
        "district": "BOB HOPE SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141013465",
    },
    {
        "school": "MANARA LEADERSHIP ACADEMY",
        "district": "MANARA ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141513534",
    },
    {
        "school": "LEADERSHIP PREP SCHOOL SECONDARY",
        "district": "LEADERSHIP PREP SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142013518",
    },
    {
        "school": "NEWMAN INTERNATIONAL ACADEMY AT FORT WORTH",
        "district": "NEWMAN INTERNATIONAL ACADEMY OF ARLINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142113502",
    },
    {
        "school": "NEWMAN INTERNATIONAL ACADEMY AT PIONEER",
        "district": "NEWMAN INTERNATIONAL ACADEMY OF ARLINGTON",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142113511",
    },
    {
        "school": "NEWMAN INTERNATIONAL ACADEMY OF MANSFIELD",
        "district": "NEWMAN INTERNATIONAL ACADEMY OF ARLINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142113515",
    },
    {
        "school": "NEWMAN INTERNATIONAL ACADEMY AT GRACE",
        "district": "NEWMAN INTERNATIONAL ACADEMY OF ARLINGTON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142113516",
    },
    {
        "school": "UME PREPARATORY ACADEMY - DUNCANVILLE",
        "district": "UME PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480142513490",
    },
    {
        "school": "ILTEXAS LANCASTER MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013404",
    },
    {
        "school": "ILTEXAS SAGINAW MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013406",
    },
    {
        "school": "ILTEXAS EAST FORT WORTH EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013408",
    },
    {
        "school": "ILTEXAS HOUSTON WINDMILL LAKES MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013410",
    },
    {
        "school": "ILTEXAS HOUSTON OREM EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013411",
    },
    {
        "school": "ILTEXAS HOUSTON WINDMILL LAKES EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013412",
    },
    {
        "school": "ILTEXAS KATY WESTPARK H S",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013413",
    },
    {
        "school": "ILTEXAS EAST FORT WORTH MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013415",
    },
    {
        "school": "ILTEXAS LANCASTER EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013416",
    },
    {
        "school": "ILTEXAS HOUSTON OREM MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013418",
    },
    {
        "school": "ILTEXAS SAGINAW EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013419",
    },
    {
        "school": "PIONEER TECHNOLOGY (PTAA) GREENVILLE",
        "district": "PIONEER TECHNOLOGY & ARTS ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145113443",
    },
    {
        "school": "TRIVIUM ACADEMY",
        "district": "TRIVIUM ACADEMY",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145613454",
    },
    {
        "school": "COMPASS ROSE ACADEMY",
        "district": "COMPASS ROSE ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145713398",
    },
    {
        "school": "GOODWATER MONTESSORI SCHOOL",
        "district": "GOODWATER MONTESSORI SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145813449",
    },
    {
        "school": "PECAN TRAIL INT",
        "district": "COLLEGE STATION ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735013424",
    },
    {
        "school": "COLLEGE VIEW H S",
        "district": "COLLEGE STATION ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735013429",
    },
    {
        "school": "LONG EARLY LEARNING CENTER",
        "district": "ABILENE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480744013477",
    },
    {
        "school": "MERIDIANA EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809013503",
    },
    {
        "school": "SHIRLEY DILL BROTHERS EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809013506",
    },
    {
        "school": "POMONA EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809013513",
    },
    {
        "school": "JUDITH L HARLOW EL",
        "district": "ANNA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480834013494",
    },
    {
        "school": "BEAUMONT ISD EARLY COLLEGE H S",
        "district": "BEAUMONT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967013457",
    },
    {
        "school": "ANDERSON ACCELERATED H S",
        "district": "BIG SPRING ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481020013473",
    },
    {
        "school": "NEW H S",
        "district": "BRAZOSPORT ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481119013455",
    },
    {
        "school": "BULLARD PRI",
        "district": "BULLARD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481206013437",
    },
    {
        "school": "BURLESON COLLEGIATE H S",
        "district": "BURLESON ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218013530",
    },
    {
        "school": "CELINA PRI",
        "district": "CELINA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481329013509",
    },
    {
        "school": "O'DELL EL",
        "district": "CELINA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481329013517",
    },
    {
        "school": "COLORADO EL AND MIDDLE",
        "district": "COLORADO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481464013409",
    },
    {
        "school": "LUBBOCK-COOPER EAST EL",
        "district": "LUBBOCK-COOPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481518013525",
    },
    {
        "school": "LUBBOCK-COOPER NEW HOPE ACADEMY",
        "district": "LUBBOCK-COOPER ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481518013526",
    },
    {
        "school": "HOLLIS T DIETZ EL",
        "district": "CRANDALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481551013390",
    },
    {
        "school": "HOOVER EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611013432",
    },
    {
        "school": "BRIDGELAND H S",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611013434",
    },
    {
        "school": "WELLS EL",
        "district": "CYPRESS-FAIRBANKS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481611013441",
    },
    {
        "school": "STONE HOTCHKISS AREA",
        "district": "DALLAS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013541",
    },
    {
        "school": "TITCHE BLANTON AREA",
        "district": "DALLAS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013546",
    },
    {
        "school": "FAR NORTH DALLAS AREA",
        "district": "DALLAS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013547",
    },
    {
        "school": "THOMPSON MONTESSORI",
        "district": "DALLAS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013548",
    },
    {
        "school": "WEST DALLAS STEM SCHOOL",
        "district": "DALLAS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013551",
    },
    {
        "school": "CITYLAB H S",
        "district": "DALLAS ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013553",
    },
    {
        "school": "WILMER TBD",
        "district": "DALLAS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013554",
    },
    {
        "school": "BARACK OBAMA EL MALE LEADERSHIP ACADEMY",
        "district": "DALLAS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013555",
    },
    {
        "school": "RODRIGUEZ MIDDLE",
        "district": "DENTON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674013393",
    },
    {
        "school": "EL DAEP",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481815013488",
    },
    {
        "school": "EARLY CHILDHOOD",
        "district": "EDINBURG CISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481818013556",
    },
    {
        "school": "PREK PARTNERSHIP SCHOOL",
        "district": "EL PASO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830013445",
    },
    {
        "school": "EVADALE DAEP",
        "district": "EVADALE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481875013431",
    },
    {
        "school": "MALALA YOUSAFZAI",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965013453",
    },
    {
        "school": "EL DAEP",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481965013456",
    },
    {
        "school": "LISCANO EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013462",
    },
    {
        "school": "TALLEY EL",
        "district": "FRISCO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013467",
    },
    {
        "school": "MEMORIAL H S",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013470",
    },
    {
        "school": "LAWLER MIDDLE",
        "district": "FRISCO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013472",
    },
    {
        "school": "MOODY EARLY CHILDHOOD CENTER",
        "district": "GALVESTON ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482028013439",
    },
    {
        "school": "GILBREATH-REED CAREER AND TECHNICAL CENTER",
        "district": "GARLAND ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482034013440",
    },
    {
        "school": "GEORGE WAGNER MIDDLE",
        "district": "GEORGETOWN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060013486",
    },
    {
        "school": "STUART CAREER TECH H S",
        "district": "GOOSE CREEK CISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482115013539",
    },
    {
        "school": "EL #31",
        "district": "HUMBLE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482391013452",
    },
    {
        "school": "KLEIN CAIN H S",
        "district": "KLEIN ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574013407",
    },
    {
        "school": "LA JOYA ISD HEAD START PROGRAM",
        "district": "LA JOYA ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482613013405",
    },
    {
        "school": "LAGO VISTA INT",
        "district": "LAGO VISTA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482640013522",
    },
    {
        "school": "BENTLEY EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658013542",
    },
    {
        "school": "KATHLEEN JOERGER LINDSEY EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658013544",
    },
    {
        "school": "DON CARTER EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658013552",
    },
    {
        "school": "GLENN H S",
        "district": "LEANDER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703013500",
    },
    {
        "school": "LONDON MIDDLE",
        "district": "LONDON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482799013493",
    },
    {
        "school": "EAST TEXAS MONTESSORI PREP ACADEMY",
        "district": "LONGVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811013422",
    },
    {
        "school": "MANOR NEW TECHNOLOGY MIDDLE",
        "district": "MANOR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482889013527",
    },
    {
        "school": "TCCSE EARLY COLLEGE H S AT TIMBERVIEW",
        "district": "MANSFIELD ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892013423",
    },
    {
        "school": "MARION ALTERNATIVE CENTER",
        "district": "MARION ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482910013401",
    },
    {
        "school": "LANNY FRASIER MIDDLE",
        "district": "MESQUITE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039013528",
    },
    {
        "school": "VOSS FARMS EL",
        "district": "NEW BRAUNFELS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237013532",
    },
    {
        "school": "VERAMENDI EL",
        "district": "NEW BRAUNFELS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483237013537",
    },
    {
        "school": "DOGWOOD EL",
        "district": "NEW CANEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240013442",
    },
    {
        "school": "NEISD - PK4SA",
        "district": "NORTH EAST ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294013540",
    },
    {
        "school": "NISD PKSA",
        "district": "NORTHSIDE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312013438",
    },
    {
        "school": "WEISS H S",
        "district": "PFLUGERVILLE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483013491",
    },
    {
        "school": "MOTT EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483013492",
    },
    {
        "school": "PARKWAY EL",
        "district": "PINE TREE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483498013446",
    },
    {
        "school": "BIRCH EL",
        "district": "PINE TREE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483498013448",
    },
    {
        "school": "NEW EL",
        "district": "RICHARDSON ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483702013414",
    },
    {
        "school": "PREPARATORY FOR EARLY COLLEGE H S",
        "district": "RIO GRANDE CITY CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483714013496",
    },
    {
        "school": "RRISD EARLY COLLEGE H S",
        "district": "ROUND ROCK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483808013545",
    },
    {
        "school": "ADVANCED LEARNING ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013447",
    },
    {
        "school": "DEL RIO EARLY COLLEGE H S",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890013444",
    },
    {
        "school": "SANTA MARIA ACADEMIC ACADEMY-OPTIONS CAMPUS (6-12)",
        "district": "SANTA MARIA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483933013394",
    },
    {
        "school": "SANTA MARIA MIDDLE",
        "district": "SANTA MARIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483933013399",
    },
    {
        "school": "LAURA REEVES PRI",
        "district": "SILSBEE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484023013550",
    },
    {
        "school": "SILSBEE EL",
        "district": "SILSBEE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484023013558",
    },
    {
        "school": "SGT JOSE F CARRASCO EL",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071013501",
    },
    {
        "school": "LA MARQUE H S",
        "district": "TEXAS CITY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251002941",
    },
    {
        "school": "LA MARQUE PRI",
        "district": "TEXAS CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251008215",
    },
    {
        "school": "LA MARQUE MIDDLE",
        "district": "TEXAS CITY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251012812",
    },
    {
        "school": "LA MARQUE EL",
        "district": "TEXAS CITY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484251012843",
    },
    {
        "school": "YOUTH VILLAGE DETENTION CENTER",
        "district": "UNITED ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484365013463",
    },
    {
        "school": "CASA ESPERANZA RECOVERY HOME",
        "district": "UNITED ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484365013464",
    },
    {
        "school": "YOUTH RECOVERY HOME",
        "district": "UNITED ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484365013466",
    },
    {
        "school": "BOB AND LOLA SANFORD EL",
        "district": "VAN ALSTYNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484389013507",
    },
    {
        "school": "NEW EL",
        "district": "WILLIS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484590013425",
    },
    {
        "school": "American Preparatory Academy - Salem",
        "district": "American Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490000501520",
    },
    {
        "school": "No. UT. Acad. of Math Engineering & Science Ogden",
        "district": "No. UT. Acad. for Math Engineering & Science",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490006301528",
    },
    {
        "school": "Blind South",
        "district": "Utah Schools for Deaf & Blind",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490006901531",
    },
    {
        "school": "Cedar Ridge School",
        "district": "Cache District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490012001536",
    },
    {
        "school": "Canyons Virtual High School",
        "district": "Canyons District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490014201529",
    },
    {
        "school": "Leadership Learning Academy - Ogden",
        "district": "Leadership Learning Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490016201522",
    },
    {
        "school": "Ascent Academies of Utah - West Valley",
        "district": "Ascent Academies of Utah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490017401523",
    },
    {
        "school": "Real Salt Lake Academy High School",
        "district": "Real Salt Lake Academy High School",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490019701517",
    },
    {
        "school": "Advantage Arts Academy",
        "district": "Advantage Arts Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490019801524",
    },
    {
        "school": "Capstone Classical Academy",
        "district": "Capstone Classical Academy",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490019901527",
    },
    {
        "school": "Mountain Ridge High",
        "district": "Jordan District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001525",
    },
    {
        "school": "Logan Early Childhood Center",
        "district": "Logan City District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490051001530",
    },
    {
        "school": "Apple Valley School",
        "district": "Nebo District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001518",
    },
    {
        "school": "Silver Summit Academy",
        "district": "South Summit District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490099001534",
    },
    {
        "school": "Silver Summit School",
        "district": "South Summit District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490099001535",
    },
    {
        "school": "Old Mill School",
        "district": "Tooele District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490105001519",
    },
    {
        "school": "Daniels Canyon School",
        "district": "Wasatch District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490111001532",
    },
    {
        "school": "Timpanogos Middle School",
        "district": "Wasatch District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490111001533",
    },
    {
        "school": "Water Canyon High",
        "district": "Washington District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001521",
    },
    {
        "school": "Majestic Fields School",
        "district": "Washington District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001526",
    },
    {
        "school": "Barstow Memorial School",
        "district": "Barstow Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039009274",
    },
    {
        "school": "Otter Valley Union High School",
        "district": "Otter Valley Unified Union School District #53",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039200234",
    },
    {
        "school": "Lothrop School",
        "district": "Otter Valley Unified Union School District #53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039200239",
    },
    {
        "school": "Neshobe School",
        "district": "Otter Valley Unified Union School District #53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039200411",
    },
    {
        "school": "Clarendon Elementary School",
        "district": "Mill River Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039300086",
    },
    {
        "school": "Tinmouth Elementary School",
        "district": "Mill River Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039300326",
    },
    {
        "school": "Mill River Union High School",
        "district": "Mill River Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039300344",
    },
    {
        "school": "Wallingford Village School",
        "district": "Mill River Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039300358",
    },
    {
        "school": "Shrewsbury Mountain School",
        "district": "Mill River Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039300446",
    },
    {
        "school": "CCPSONLINE",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084003040",
    },
    {
        "school": "PHOENIX CENTER",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510084003041",
    },
    {
        "school": "FORT BELVOIR UPPER",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126003032",
    },
    {
        "school": "BAILEY'S UPPER ELEMENTARY SCHOOL FOR THE ARTS A",
        "district": "FAIRFAX CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510126003033",
    },
    {
        "school": "BLUESTONE ELEMENTARY",
        "district": "HARRISONBURG CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510186003043",
    },
    {
        "school": "BRAMBLETON MIDDLE SCHOOL",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225003036",
    },
    {
        "school": "BALDWIN INTERMEDIATE SCHOOL",
        "district": "MANASSAS CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510236003034",
    },
    {
        "school": "KYLE R. WILSON ELEMENTARY SCHOOL",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313003037",
    },
    {
        "school": "COVINGTON-HARPER ELEMENTARY SCHOOL",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313003044",
    },
    {
        "school": "SUMMER HILL PRESCHOOL CENTER",
        "district": "RICHMOND CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510324003035",
    },
    {
        "school": "WARREN COUNTY MIDDLE SCHOOL",
        "district": "WARREN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510387003038",
    },
    {
        "school": "SKYLINE MIDDLE SCHOOL",
        "district": "WARREN CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510387003039",
    },
    {
        "school": "DANIEL MORGAN INTERMEDIATE SCHOOL",
        "district": "WINCHESTER CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510405003042",
    },
    {
        "school": "ESA 112 Special Ed Co-Op",
        "district": "Educational Service Agency 112",
        "level": "Other",
        "type": "Special education school",
        "state": "WA",
        "nces_id": "530034003593",
    },
    {
        "school": "IMPACT Reengagement Program",
        "district": "Lynden School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530462003592",
    },
    {
        "school": "UNITED HIGH SCHOOL",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540051001544",
    },
    {
        "school": "Pathways High",
        "district": "Pathways High Agency",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550007903064",
    },
    {
        "school": "Tomorrow River Virtual Charter School (TRVCS)",
        "district": "Tomorrow River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550033003063",
    },
    {
        "school": "Benton Middle",
        "district": "Benton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550111003061",
    },
    {
        "school": "Hudson 4K",
        "district": "Hudson School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550669003069",
    },
    {
        "school": "Kenosha Pike School",
        "district": "Kenosha School District",
        "level": "Other",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "550732003051",
    },
    {
        "school": "Insight School of Wisconsin High",
        "district": "McFarland School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550891003067",
    },
    {
        "school": "Milwaukee College Preparatory School -- 36th Street Campus",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960002537",
    },
    {
        "school": "Milwaukee College Preparatory School: Lola Rowe North Campus",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960003006",
    },
    {
        "school": "Carmen Hi Southeast Campus",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960003054",
    },
    {
        "school": "Vincent Accelerated Academy",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960003055",
    },
    {
        "school": "South Accelerated Academy",
        "district": "Milwaukee School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550960003057",
    },
    {
        "school": "Grant Gordon Learning Center",
        "district": "Milwaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960003058",
    },
    {
        "school": "Northeast Wisconsin Learning Academy",
        "district": "Oconto Unified School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551092003060",
    },
    {
        "school": "Port Washington-Saukville School District Preschool",
        "district": "Port Washington-Saukville School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551200003049",
    },
    {
        "school": "Odyssey Elementary",
        "district": "D C Everest Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551317003065",
    },
    {
        "school": "River Valley Early Learning Center",
        "district": "River Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551425003062",
    },
    {
        "school": "Turtle Lake Middle",
        "district": "Turtle Lake School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551506003068",
    },
    {
        "school": "Wonewoc-Center Virtual Academy",
        "district": "Wonewoc-Union Center School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551713003059",
    },
    {
        "school": "Stocktrail Elementary",
        "district": "Campbell County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000568",
    },
    {
        "school": "Meadowlark Elementary",
        "district": "Laramie County School District #1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000567",
    },
    {
        "school": "PODER Academy Secondary School",
        "district": "Laramie County School District #1",
        "level": "Secondary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560198000574",
    },
    {
        "school": "Peak High School",
        "district": "Platte County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560509000573",
    },
    {
        "school": "Willow Creek Elementary",
        "district": "Fremont County School District #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560522000570",
    },
    {
        "school": "Ashgrove Elementary",
        "district": "Fremont County School District #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560522000571",
    },
    {
        "school": "Aspen Early Learning Center",
        "district": "Fremont County School District #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560522000572",
    },
    {
        "school": "Jackson Elementary",
        "district": "Fremont County School District #25",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560522000575",
    },
    {
        "school": "Clearmont K-12 School",
        "district": "Sheridan County School District #3",
        "level": "Other",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560568000569",
    },
    {
        "school": "Montgomery Childrens Specialty Center",
        "district": "Montgomery Childrens Specialty Center",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10018702371",
    },
    {
        "school": "University Charter School",
        "district": "University Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10019902452",
    },
    {
        "school": "Baldwin County Virtual School",
        "district": "Baldwin County",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027002443",
    },
    {
        "school": "Genesis Innovative School",
        "district": "Conecuh County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10087002442",
    },
    {
        "school": "Alabama Virtual Academy at Eufaula City Schools",
        "district": "Eufaula City",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10141002439",
    },
    {
        "school": "Limestone County Virtual School Center",
        "district": "Limestone County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10210002436",
    },
    {
        "school": "Delta Junction Junior High School",
        "district": "Delta-Greely School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20010000764",
    },
    {
        "school": "Alaska Middle College School",
        "district": "Anchorage School District",
        "level": "High",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20018000763",
    },
    {
        "school": "Boreal Sun Charter School",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20060000761",
    },
    {
        "school": "PSD Correspondence Program",
        "district": "Pribilof School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20067000762",
    },
    {
        "school": "American Leadership Academy Signal Butte K-6",
        "district": "American Leadership Academy Inc. (4348)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011203570",
    },
    {
        "school": "American Leadership Academy Gilbert North K-12",
        "district": "American Leadership Academy Inc. (4348)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011203573",
    },
    {
        "school": "American Leadership Academy Gilbert South K-6",
        "district": "American Leadership Academy Inc. (4348)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40011203576",
    },
    {
        "school": "Champion San Tan",
        "district": "Fit Kids Inc. dba Champion Schools (78783)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40019103557",
    },
    {
        "school": "CVIT - Ray High School",
        "district": "Cobre Valley Institute of Technology District (79391)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40031603563",
    },
    {
        "school": "Pinnacle Online - WMCB",
        "district": "Pinnacle Education-WMCB Inc. (79439)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40032103565",
    },
    {
        "school": "CAVIAT - Flagstaff Arts and Leadership Academy",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034703568",
    },
    {
        "school": "Canyon View High School",
        "district": "Agua Fria Union High School District (4289)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40045003559",
    },
    {
        "school": "Northwest Campus",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503545",
    },
    {
        "school": "Canyon Rose Academy-East",
        "district": "Canyon Rose Academy Inc. (81029)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40063303536",
    },
    {
        "school": "KELLY",
        "district": "Edkey Inc. - Sequoia School for the Deaf and Hard (81050)",
        "level": "Other",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40064003569",
    },
    {
        "school": "PCJTED- Pierson High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203537",
    },
    {
        "school": "Pima County JTED",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203538",
    },
    {
        "school": "Pima County at Walden Grove",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203539",
    },
    {
        "school": "PCJTED- Nogales High School",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203540",
    },
    {
        "school": "Pima County JTED at Amphi Land Lab",
        "district": "Pima County JTED (89380)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40075203541",
    },
    {
        "school": "Vista College Prep - Maryvale",
        "district": "Vista College Preparatory Inc. (91948)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40088703561",
    },
    {
        "school": "STEDY- Arizona Western College",
        "district": "Southwest Technical Education District of Yuma (ST (92705)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40092003571",
    },
    {
        "school": "STEDY- Desert View Academy",
        "district": "Southwest Technical Education District of Yuma (ST (92705)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40092003574",
    },
    {
        "school": "STEDY- Central Campus",
        "district": "Southwest Technical Education District of Yuma (ST (92705)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40092003577",
    },
    {
        "school": "Leman Academy of Excellence-Sierra Vista",
        "district": "Leman Academy of Excellence Inc. (92730)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094403542",
    },
    {
        "school": "Leman Virtual Academy",
        "district": "Leman Academy of Excellence Inc. (92730)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094403547",
    },
    {
        "school": "BASIS Phoenix South Primary",
        "district": "BASIS Charter Schools Inc. (549803)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096103550",
    },
    {
        "school": "Legacy Traditional School - East Mesa",
        "district": "Legacy Traditional School - East Mesa (834265)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096203551",
    },
    {
        "school": "BASIS Peoria Primary",
        "district": "BASIS Charter Schools Inc. (273398)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096303558",
    },
    {
        "school": "Synergy Public School",
        "district": "Synergy Public School Inc. (92981)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096403553",
    },
    {
        "school": "ASU Preparatory Academy Digital",
        "district": "ASU Preparatory Academy Digital (522074)",
        "level": "Other",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096503556",
    },
    {
        "school": "Highland Prep",
        "district": "Highland Prep (92982)",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096603572",
    },
    {
        "school": "BASIS Phoenix Primary",
        "district": "BASIS Charter Schools Inc. (934316)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096703560",
    },
    {
        "school": "Victory Collegiate Academy",
        "district": "Victory Collegiate Academy Corporation (92985)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096803562",
    },
    {
        "school": "Arizona Agribusiness & Equine Center Inc. - Mesa",
        "district": "Arizona Agribusiness & Equine Center INC. (134379)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40096903543",
    },
    {
        "school": "RCB College Preparatory Academy",
        "district": "AIBT Non-Profit Charter High School Inc. (449790)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40097003546",
    },
    {
        "school": "ASU Preparatory Academy - Tempe",
        "district": "ASU Preparatory Academy (631426)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40097103567",
    },
    {
        "school": "Marionneaux Elementary School",
        "district": "Buckeye Elementary District (4269)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40138003575",
    },
    {
        "school": "Hope College and Career Readiness Academy",
        "district": "Maricopa County Regional School District (4234)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40386003535",
    },
    {
        "school": "Esperanza Prep",
        "district": "Maricopa County Regional School District (4234)",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "AZ",
        "nces_id": "40386003552",
    },
    {
        "school": "Indian Oasis Intermediate Elementary School",
        "district": "Baboquivari Unified School District #40 (4412)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40395003566",
    },
    {
        "school": "Faith North Early Childhood Learning Center",
        "district": "Phoenix Elementary District (4256)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40630003554",
    },
    {
        "school": "Phoenix Union-Wilson College Preparatory",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633003555",
    },
    {
        "school": "Blue Ridge High School Online",
        "district": "Blue Ridge Unified School District No. 32 (4397)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40658003564",
    },
    {
        "school": "EVIT North Fountain Hills",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973103544",
    },
    {
        "school": "EVIT - East Valley Academy",
        "district": "East Valley Institute of Technology (4516)",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973103548",
    },
    {
        "school": "EVIT East Apache Junction",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973103549",
    },
    {
        "school": "ODEN SCHOOLS",
        "district": "OUACHITA RIVER SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007301642",
    },
    {
        "school": "ST. JOE K-12 SCHOOL",
        "district": "OZARK MOUNTAIN SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007601643",
    },
    {
        "school": "BRUNO-PYATT K-12 SCHOOL",
        "district": "OZARK MOUNTAIN SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007601645",
    },
    {
        "school": "WESTERN GROVE K-12 SCHOOL",
        "district": "OZARK MOUNTAIN SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007601646",
    },
    {
        "school": "HAAS HALL ACADEMY AT THE LANE",
        "district": "HAAS HALL ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007801639",
    },
    {
        "school": "HAAS HALL ACADEMY JONES CENTER",
        "district": "HAAS HALL ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007801640",
    },
    {
        "school": "ADKINS PRE-K CENTER",
        "district": "JACKSONVILLE NORTH PULASKI SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041900901",
    },
    {
        "school": "THE EXCEL CENTER",
        "district": "THE EXCEL CENTER",
        "level": "Ungraded",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50042001638",
    },
    {
        "school": "CREEKSIDE MIDDLE SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001648",
    },
    {
        "school": "OSAGE CREEK ELEMENTARY SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001649",
    },
    {
        "school": "AGEE LIERLY LIFE PREPARATION SERVICES SCHOOL",
        "district": "FAYETTEVILLE SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50612001644",
    },
    {
        "school": "CENTERPOINT ELEMENTARY SCHOOL",
        "district": "CENTERPOINT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50669001652",
    },
    {
        "school": "J.F. WAHL ELEMENTARY SCHOOL",
        "district": "HELENA/ W.HELENA SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50768001637",
    },
    {
        "school": "NORTH LITTLE ROCK CENTER OF EXCELLENCE",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068001641",
    },
    {
        "school": "RIVER VALLEY VIRTUAL ACADEMY",
        "district": "VAN BUREN SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51341001650",
    },
    {
        "school": "Paso Verde",
        "district": "Natomas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60003614188",
    },
    {
        "school": "Santa Barbara Unified Early Childhood",
        "district": "Santa Barbara Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141414138",
    },
    {
        "school": "Adelante Dual Language Academy II",
        "district": "Alum Rock Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60231014147",
    },
    {
        "school": "Gateway",
        "district": "Alvord Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60243014097",
    },
    {
        "school": "Empower",
        "district": "Cajon Valley Union",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60681014179",
    },
    {
        "school": "Apple Pie Preschool",
        "district": "Carmel Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60753014185",
    },
    {
        "school": "Muraoka (Saburo) Elementary",
        "district": "Chula Vista Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861014127",
    },
    {
        "school": "Special Education Preschool",
        "district": "Chula Vista Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60861014135",
    },
    {
        "school": "San Salvador Preschool",
        "district": "Colton Joint Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60939014182",
    },
    {
        "school": "CNUSD Hybrid School of Innovation",
        "district": "Corona-Norco Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60985014184",
    },
    {
        "school": "Coronado Unified Special Education Pre-K",
        "district": "Coronado Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60987014121",
    },
    {
        "school": "Cotati-Rohnert Park Preschool",
        "district": "Cotati-Rohnert Park Unified",
        "level": "Not reported",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60994014180",
    },
    {
        "school": "Richard Crane Elementary",
        "district": "Cotati-Rohnert Park Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60994014195",
    },
    {
        "school": "Cottonwood Preschool",
        "district": "Cottonwood Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60999014148",
    },
    {
        "school": "John Adams Early Childhood Learning Center",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111014129",
    },
    {
        "school": "Woodruff Academy",
        "district": "Downey Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61146014075",
    },
    {
        "school": "El Nido Preschool",
        "district": "El Nido Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61215014152",
    },
    {
        "school": "Zehnder Ranch Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233014065",
    },
    {
        "school": "Robert J. McGarvey Elementary",
        "district": "Elk Grove Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61233014066",
    },
    {
        "school": "Redding Collegiate Academy",
        "district": "Enterprise Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61281014193",
    },
    {
        "school": "PACE Academy Charter",
        "district": "Enterprise Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61281014194",
    },
    {
        "school": "Falcon Ridge Elementary",
        "district": "Etiwanda Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61296014111",
    },
    {
        "school": "Mary Bird Early Childhood Education Center",
        "district": "Fairfield-Suisun Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61336014130",
    },
    {
        "school": "Mike Choate Early Childhood Education Center",
        "district": "Fallbrook Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61350014137",
    },
    {
        "school": "Sespe",
        "district": "Fillmore Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61380014162",
    },
    {
        "school": "Wawona K-8",
        "district": "Fresno Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61455014077",
    },
    {
        "school": "Early Childhood Education Center - Carver Campus",
        "district": "Garden Grove Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488014187",
    },
    {
        "school": "Gilroy Special Ed Preschool",
        "district": "Gilroy Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61518014178",
    },
    {
        "school": "Guadalupe Preschool",
        "district": "Guadalupe Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61626014201",
    },
    {
        "school": "Dogwood Elementary",
        "district": "Heber Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61683012918",
    },
    {
        "school": "Hemet Elementary",
        "district": "Hemet Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61692014164",
    },
    {
        "school": "Linda Mar Educational Center",
        "district": "Pacifica",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62046014110",
    },
    {
        "school": "Lakeside Early Advantage Preschool",
        "district": "Lakeside Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62079014081",
    },
    {
        "school": "Carson School",
        "district": "Lawndale Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62121014174",
    },
    {
        "school": "Lincoln Unified Preschool",
        "district": "Lincoln Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62169014125",
    },
    {
        "school": "Lawrence Elementary",
        "district": "Livermore Valley Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62211014134",
    },
    {
        "school": "Richard D. Browning High",
        "district": "Long Beach Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62250014120",
    },
    {
        "school": "Maywood Center for Enriched Studies",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271014102",
    },
    {
        "school": "Boys Academic Leadership Academy",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271014106",
    },
    {
        "school": "Horace Mann UCLA Community",
        "district": "Los Angeles Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271014112",
    },
    {
        "school": "Katherine Johnson STEM Academy",
        "district": "Los Angeles Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271014113",
    },
    {
        "school": "MPUSD Preschool",
        "district": "Monterey Peninsula Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62553014161",
    },
    {
        "school": "National School District Preschool",
        "district": "National Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62667014173",
    },
    {
        "school": "Delta Keys Charter",
        "district": "New Jerusalem Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62703014175",
    },
    {
        "school": "Delta Charter Online",
        "district": "New Jerusalem Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62703014183",
    },
    {
        "school": "Harper",
        "district": "Newport-Mesa Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62724014084",
    },
    {
        "school": "Oakland SOL (School of Language) Dual Language Middle",
        "district": "Oakland Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62805014086",
    },
    {
        "school": "Space Aeronautics Gateway to Exploration Magnet Academy",
        "district": "Palmdale Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62958014085",
    },
    {
        "school": "Paradise Unified Special Education",
        "district": "Paradise Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62982014190",
    },
    {
        "school": "Arete Charter Academy",
        "district": "Pleasant Ridge Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63093014123",
    },
    {
        "school": "Ravenswood Middle",
        "district": "Ravenswood City Elementary",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63186014095",
    },
    {
        "school": "Stellar Charter",
        "district": "Redding Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63204014118",
    },
    {
        "school": "West County Mandarin",
        "district": "West Contra Costa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63255014119",
    },
    {
        "school": "Educational Options Center State Preschool",
        "district": "Riverside Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63315014166",
    },
    {
        "school": "Orchard Ranch Elementary",
        "district": "Roseville City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360014181",
    },
    {
        "school": "Meraki High",
        "district": "San Juan Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63462014105",
    },
    {
        "school": "San Lorenzo Unified Preschool",
        "district": "San Lorenzo Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63471014128",
    },
    {
        "school": "Bayside Academy",
        "district": "San Mateo-Foster City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63492014143",
    },
    {
        "school": "Old Gallinas",
        "district": "San Rafael City Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63509014208",
    },
    {
        "school": "Mitchell Child Development",
        "district": "Santa Ana Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531014142",
    },
    {
        "school": "Advanced Learning Academy",
        "district": "Santa Ana Unified",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63531014192",
    },
    {
        "school": "Mission Early College High",
        "district": "Santa Clara Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63543014067",
    },
    {
        "school": "Santa Monica-Malibu Preschool",
        "district": "Santa Monica-Malibu Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570014126",
    },
    {
        "school": "Santa Rita Pre-K",
        "district": "Santa Rita Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63579014170",
    },
    {
        "school": "Shoreline Special Education Pre-School",
        "district": "Shoreline Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63667014088",
    },
    {
        "school": "Sulphur Springs Special Education Consortia",
        "district": "Sulphur Springs Union",
        "level": "Elementary",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63822014133",
    },
    {
        "school": "Global Learning Charter",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116014140",
    },
    {
        "school": "Yuba City Special Education Preschool",
        "district": "Yuba City Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64347014094",
    },
    {
        "school": "Eastwood Elementary",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450014114",
    },
    {
        "school": "Early Childhood Education",
        "district": "Nevada County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102314210",
    },
    {
        "school": "San Benito County Regional Special Education Center",
        "district": "San Benito County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102814074",
    },
    {
        "school": "HOPE Infant-Toddler Special Education",
        "district": "San Diego County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69103014068",
    },
    {
        "school": "Santa Cruz County Career Advancement Charter",
        "district": "Santa Cruz County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69103614200",
    },
    {
        "school": "Gold Ridge Educational Center",
        "district": "Tuolumne County Superintendent of Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104614139",
    },
    {
        "school": "Phoenix",
        "district": "Ventura County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104714073",
    },
    {
        "school": "Triton Academy",
        "district": "Ventura County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69104714080",
    },
    {
        "school": "Opportunity Academy",
        "district": "Alameda County Office of Education",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69105114090",
    },
    {
        "school": "Mono County Office of Education Inclusive Preschool",
        "district": "Mono County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69105214150",
    },
    {
        "school": "MONUMENT VIEW MONTESSORI CHARTER SCHOOL",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006706",
    },
    {
        "school": "COLORADO MILITARY ACADEMY",
        "district": "State Charter School Institute",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006708",
    },
    {
        "school": "COLORADO EARLY COLLEGES AURORA",
        "district": "State Charter School Institute",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006710",
    },
    {
        "school": "YAMPAH MOUNTAIN SCHOOL",
        "district": "COLORADO RIVER BOCES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80029201503",
    },
    {
        "school": "PAGOSA PEAK OPEN SCHOOL",
        "district": "Archuleta County School District No. 50 Jt",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80219006717",
    },
    {
        "school": "VEGA COLLEGIATE ACADEMY",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006732",
    },
    {
        "school": "ACADEMY OF ADVANCED LEARNING",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006736",
    },
    {
        "school": "MEADOWLARK SCHOOL",
        "district": "Boulder Valley School District No. Re2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80249006716",
    },
    {
        "school": "REUNION ELEMENTARY SCHOOL",
        "district": "School District 27J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006718",
    },
    {
        "school": "INFINITY MIDDLE SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006728",
    },
    {
        "school": "DSST: CONSERVATORY GREEN HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006730",
    },
    {
        "school": "DELTA HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006731",
    },
    {
        "school": "INSPIRE ELEMENTARY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006733",
    },
    {
        "school": "THE BOYS SCHOOL OF DENVER",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006734",
    },
    {
        "school": "COLORADO HIGH SCHOOL CHARTER - GES",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80336006735",
    },
    {
        "school": "RENAISSANCE SECONDARY SCHOOL",
        "district": "Douglas County School District No. Re 1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006714",
    },
    {
        "school": "THE JUNIPER SCHOOL",
        "district": "Durango School District No. 9-R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80348006712",
    },
    {
        "school": "BATTLE MOUNTAIN EARLY COLLEGE HIGH SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354006707",
    },
    {
        "school": "EAGLE VALLEY EARLY COLLEGE HIGH SCHOOL",
        "district": "Eagle County School District No. Re 50",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80354006709",
    },
    {
        "school": "ALLIES",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80387006725",
    },
    {
        "school": "RIVERVIEW SCHOOL",
        "district": "Roaring Fork School District No. Re-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80426006715",
    },
    {
        "school": "FRED TJARDES SCHOOL OF INNOVATION",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441006719",
    },
    {
        "school": "HANOVER ONLINE ACADEMY",
        "district": "Hanover School District No. 28 in the county of El Paso an",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80450006720",
    },
    {
        "school": "THREE CREEKS K-8",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006722",
    },
    {
        "school": "GREAT WORK MONTESSORI",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006723",
    },
    {
        "school": "ROSE STEIN INTERNATIONAL ELEMENTARY",
        "district": "Jefferson County School District No. R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006724",
    },
    {
        "school": "IRWIN PRESCHOOL",
        "district": "Jefferson County School District No. R-1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80480006726",
    },
    {
        "school": "LAKE COUNTY EARLY COLLEGE",
        "district": "Lake County School District No. R-1",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80519006729",
    },
    {
        "school": "NUCLA MIDDLE SCHOOL",
        "district": "West End School District No. Re-2",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80585006727",
    },
    {
        "school": "Pueblo School for Arts & Sciences at Fulton Height",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80612006711",
    },
    {
        "school": "PARAGON LEARNING CENTER",
        "district": "Pueblo School District No. 60 in the county of Pueblo and",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80612006713",
    },
    {
        "school": "WESTMINSTER PUBLIC SCHOOLS EARLY LEARNING CENTER",
        "district": "Westminster Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80723006721",
    },
    {
        "school": "Geraldine Claytor Magnet Academy",
        "district": "BRIDGEPORT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90045001918",
    },
    {
        "school": "Delmar Middle Level ILC",
        "district": "Delmar School District",
        "level": "Middle",
        "type": "Special education school",
        "state": "DE",
        "nces_id": "100027000386",
    },
    {
        "school": "Brandywine SITE",
        "district": "Brandywine School District",
        "level": "High",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100124000385",
    },
    {
        "school": "PALM BAY ELEMENTARY SCHOOL",
        "district": "BAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009008597",
    },
    {
        "school": "PINEAPPLE COVE CLASSICAL ACADEMY AT WEST MELBOURNE",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015008612",
    },
    {
        "school": "SOUTH LAKE ELEMENTARY",
        "district": "BREVARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015008651",
    },
    {
        "school": "CHAMPIONSHIP ACADEMY OF DISTINCTION OF WEST BROWARD",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008628",
    },
    {
        "school": "BRIDGEPREP ACADEMY BROWARD COUNTY",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008629",
    },
    {
        "school": "GULFSTREAM EARLY CHILDHOOD CENTER OF EXCELLENCE",
        "district": "BROWARD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008639",
    },
    {
        "school": "BABCOCK NEIGHBORHOOD SCHOOL",
        "district": "CHARLOTTE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024008634",
    },
    {
        "school": "DISCOVERY OAKS ELEMENTARY",
        "district": "CLAY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030008631",
    },
    {
        "school": "ST JOHNS CLASSICAL ACADEMY",
        "district": "CLAY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120030008632",
    },
    {
        "school": "MATER ACADEMY BAY MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008615",
    },
    {
        "school": "ARTS ACADEMY OF EXCELLENCE",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008616",
    },
    {
        "school": "DR. TONI BILBAO PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008620",
    },
    {
        "school": "SPORTS LEADERSHIP AND MANAGEMENT (SLAM) MIDDLE SCHOOL - NORT",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008621",
    },
    {
        "school": "ACCELERATION ACADEMIES LLC",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039008647",
    },
    {
        "school": "DOWNTOWN DORAL CHARTER UPPER SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008658",
    },
    {
        "school": "KIPP SUNRISE ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008661",
    },
    {
        "school": "TRUE NORTH CLASSICAL ACADEMY SOUTH",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008663",
    },
    {
        "school": "DIXIE VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "DIXIE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120045008585",
    },
    {
        "school": "DIXIE TEEN PARENT PRESCHOOL",
        "district": "DIXIE",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120045008653",
    },
    {
        "school": "SEASIDE CHARTER K-8 SCHOOL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008591",
    },
    {
        "school": "DUVAL CHARTER SCHOOL AT COASTAL",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008593",
    },
    {
        "school": "WEST GADSDEN MIDDLE SCHOOL",
        "district": "GADSDEN",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120060008590",
    },
    {
        "school": "GILCHRIST VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "GILCHRIST",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120063008602",
    },
    {
        "school": "GLADES VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "GLADES",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120066008587",
    },
    {
        "school": "MONTURA EARLY LEARNING CENTER",
        "district": "HENDRY",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078008636",
    },
    {
        "school": "HENDRY VIRTUAL INSTRUCTION PROGRAM DISTRICT PROVIDED",
        "district": "HENDRY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120078008637",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "HERNANDO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120081008654",
    },
    {
        "school": "HIGHLANDS VIRTUAL SCHOOL",
        "district": "HIGHLANDS",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120084008630",
    },
    {
        "school": "EAST TAMPA ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008580",
    },
    {
        "school": "WARREN HOPE DAWSON ELEMENTARY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008581",
    },
    {
        "school": "KIDS COMMUNITY COLLEGE SOUTHEAST MIDDLE CHARTER SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008582",
    },
    {
        "school": "THE COLLABORATORY PREPARATORY ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008584",
    },
    {
        "school": "DR KIRAN C PATEL HIGH SCHOOL",
        "district": "HILLSBOROUGH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008643",
    },
    {
        "school": "NAVIGATOR ACADEMY OF LEADERSHIP VALRICO",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008657",
    },
    {
        "school": "ENCORE",
        "district": "HILLSBOROUGH",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008664",
    },
    {
        "school": "FLORIDA CONNECTIONS ACADEMY",
        "district": "HILLSBOROUGH",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008666",
    },
    {
        "school": "SLAM ACADEMY AT APOLLO BEACH",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008667",
    },
    {
        "school": "BONIFAY K-8 SCHOOL",
        "district": "HOLMES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120090008604",
    },
    {
        "school": "JEFFERSON COUNTY HIGH A SOMERSET CHARTER SCHOOL",
        "district": "JEFFERSON",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120099008592",
    },
    {
        "school": "PINECREST LAKES ACADEMY",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105008588",
    },
    {
        "school": "BONITA SPRINGS HIGH SCHOOL",
        "district": "LEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108008599",
    },
    {
        "school": "ATHENIAN ACADEMY CHARTER SCHOOL",
        "district": "LEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108008656",
    },
    {
        "school": "LEVY VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "LEVY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120114008623",
    },
    {
        "school": "ROWLETT MIDDLE ACADEMY",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123008608",
    },
    {
        "school": "LINCOLN MEMORIAL ACADEMY",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123008662",
    },
    {
        "school": "OKEECHOBEE VIRTUAL INSTRUCTION PROGRAM",
        "district": "OKEECHOBEE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120141008586",
    },
    {
        "school": "TIMBER SPRINGS MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008605",
    },
    {
        "school": "OCPS ACADEMIC CENTER FOR EXCELLENCE",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008606",
    },
    {
        "school": "HORIZON WEST MIDDLE",
        "district": "ORANGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008607",
    },
    {
        "school": "CASTLEVIEW ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008610",
    },
    {
        "school": "WATER SPRING ELEMENTARY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008611",
    },
    {
        "school": "WINDERMERE HIGH",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008613",
    },
    {
        "school": "ORLANDO GIFTED ACADEMY",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008645",
    },
    {
        "school": "PINECREST ACADEMY AVALON",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008652",
    },
    {
        "school": "MATER PALMS ACADEMY",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008617",
    },
    {
        "school": "RENAISSANCE CHARTER SCHOOL AT BOGGY CREEK",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008618",
    },
    {
        "school": "TOHOPEKALIGA",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008622",
    },
    {
        "school": "BRIDGEPREP ACADEMY OSCEOLA COUNTY",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008626",
    },
    {
        "school": "SPORTS LEADERSHIP ARTS MANAGEMENT (SLAM)",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008627",
    },
    {
        "school": "NEOCITY ACADEMY",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008640",
    },
    {
        "school": "HARMONY MIDDLE SCHOOL",
        "district": "OSCEOLA",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008646",
    },
    {
        "school": "MATER ACADEMY AT ST CLOUD",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008659",
    },
    {
        "school": "CREATIVE INSPIRATION JOURNEY SCHOOL OF ST CLOUD",
        "district": "OSCEOLA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008660",
    },
    {
        "school": "ESE HOSPITAL HOMEBOUND INSTRUCTIONAL SERVICES",
        "district": "PALM BEACH",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120150008589",
    },
    {
        "school": "BRIDGEPREP ACADEMY OF PALM BEACH",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008594",
    },
    {
        "school": "SLAM BOCA",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008650",
    },
    {
        "school": "UNION PARK CHARTER ACADEMY",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008598",
    },
    {
        "school": "BEXLEY ELEMENTARY SCHOOL",
        "district": "PASCO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008601",
    },
    {
        "school": "WENDELL KRINN TECHNICAL HIGH SCHOOL",
        "district": "PASCO",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008638",
    },
    {
        "school": "PINECREST ACADEMY WESLEY CHAPEL",
        "district": "PASCO",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008665",
    },
    {
        "school": "PINELLAS VIRTUAL FRANCHISE",
        "district": "PINELLAS",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008596",
    },
    {
        "school": "TAPP CHILD CARE",
        "district": "SANTA ROSA",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165008644",
    },
    {
        "school": "TAYLOR COUNTY ACCELERATED SCHOOL",
        "district": "TAYLOR",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120186008603",
    },
    {
        "school": "UNION VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "UNION",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120189008619",
    },
    {
        "school": "OKEECHOBEE YOUTH TREATMENT CENTER (OYTC)",
        "district": "WASHINGTON",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120201008595",
    },
    {
        "school": "WASHINGTON ACADEMY OF VARYING EXCEPTIONALITIES (WAVE)",
        "district": "WASHINGTON",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120201008668",
    },
    {
        "school": "Terrell Regional Youth Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130002604269",
    },
    {
        "school": "John Lewis Invictus Academy",
        "district": "Atlanta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004276",
    },
    {
        "school": "Kindezi Old 4th Ward",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004277",
    },
    {
        "school": "Midway Hills Primary",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130021004289",
    },
    {
        "school": "Midway Hills Academy",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130021004290",
    },
    {
        "school": "Lakeview Primary",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130021004292",
    },
    {
        "school": "Lakeview Academy",
        "district": "Baldwin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130021004295",
    },
    {
        "school": "Genesis Innovation Academy for Girls",
        "district": "State Charter Schools II- Genesis Innovation Academy for Gir",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024404272",
    },
    {
        "school": "SAIL Charter Academy - School for Arts-Infused Learning",
        "district": "State Charter Schools II- SAIL Charter Academy - School for",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024504293",
    },
    {
        "school": "Coastal Plains Charter High School - Candler Campus",
        "district": "State Charter Schools- Coastal Plains Charter High School -",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024604299",
    },
    {
        "school": "Resurgence Hall Charter School",
        "district": "State Charter Schools II- Resurgence Hall Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024704283",
    },
    {
        "school": "Genesis Innovation Academy for Boys",
        "district": "State Charter Schools II- Genesis Innovation Academy for Boy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024804288",
    },
    {
        "school": "International Academy of Smyrna",
        "district": "State Charter Schools II- International Academy of Smyrna",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130024904273",
    },
    {
        "school": "Winder Elementary School",
        "district": "Barrow County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130029004275",
    },
    {
        "school": "Delta Innovative School",
        "district": "Brooks County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130054004264",
    },
    {
        "school": "Brooks County Early Learning Center",
        "district": "Brooks County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130054004267",
    },
    {
        "school": "Savannah Classical Academy Charter High School",
        "district": "Savannah-Chatham County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102004291",
    },
    {
        "school": "School of Humanities at Juliette Gordon Low",
        "district": "Savannah-Chatham County",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102004294",
    },
    {
        "school": "Susie King Taylor Community School",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102004298",
    },
    {
        "school": "Perry Career Academy - Eula Wilburn Ponds Perry Center for",
        "district": "Clayton County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123004279",
    },
    {
        "school": "Dooly County Prep Academy",
        "district": "Dooly County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130180004286",
    },
    {
        "school": "Second Chance",
        "district": "Evans County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130207004287",
    },
    {
        "school": "Mundy Mill Academy",
        "district": "Gainesville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130231004284",
    },
    {
        "school": "Rainey McCullers School of the Arts",
        "district": "Muscogee County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130387004270",
    },
    {
        "school": "Telfair Alternative Preparation School",
        "district": "Telfair County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "GA",
        "nces_id": "130483004302",
    },
    {
        "school": "Alaka'i O Kaua'i Charter School",
        "district": "Hawaii Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000304",
    },
    {
        "school": "LPOSD HOME SCHOOL ACADEMY",
        "district": "LAKE PEND OREILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000201086",
    },
    {
        "school": "RICHARD MCKENNA CHARTER SCHOOL - ONSITE",
        "district": "IDAHO VIRTUAL HIGH SCHOOL INC.",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160000501108",
    },
    {
        "school": "GEM PREP: POCATELLO SCHOOL",
        "district": "GEM PREP: POCATELLO LLC",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160017701073",
    },
    {
        "school": "PEACE VALLEY CHARTER SCHOOL",
        "district": "PEACE VALLEY CHARTER SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160017801101",
    },
    {
        "school": "GEM PREP: MERIDIAN",
        "district": "GEM PREP: MERIDIAN LLC",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160017901107",
    },
    {
        "school": "FUTURE PUBLIC SCHOOL",
        "district": "FUTURE PUBLIC SCHOOL INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160018101100",
    },
    {
        "school": "PROJECT IMPACT STEM ACADEMY",
        "district": "PROJECT IMPACT STEM ACADEMY INC.",
        "level": "Other",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160018201102",
    },
    {
        "school": "PATHWAYS IN EDUCATION: NAMPA",
        "district": "PATHWAYS IN EDUCATION - NAMPA INC.",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160018301098",
    },
    {
        "school": "HAYDEN CANYON CHARTER SCHOOL",
        "district": "HAYDEN CANYON CHARTER SCHOOL INC.",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160018401096",
    },
    {
        "school": "WAKAPA ACADEMY",
        "district": "BUHL JOINT DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160048001106",
    },
    {
        "school": "THUNDER RIDGE HIGH SCHOOL",
        "district": "BONNEVILLE JOINT DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160093001097",
    },
    {
        "school": "STRICKER ELEMENTARY SCHOOL",
        "district": "KIMBERLY DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160171001103",
    },
    {
        "school": "STAR MIDDLE SCHOOL",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210001104",
    },
    {
        "school": "NORTH GEM MIDDLE SCHOOL",
        "district": "NORTH GEM DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160243001099",
    },
    {
        "school": "TWIN FALLS VIRTUAL SCHOOLHOUSE",
        "district": "TWIN FALLS DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160324001105",
    },
    {
        "school": "Winnetka Covenant Preschool",
        "district": "Northern Suburban Spec Ed Dist",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170003106525",
    },
    {
        "school": "Arcola Bridges/Beacons RSSP",
        "district": "Clk/Cls/Cmbn/Dglas/Edgr/Mltr/Shlb",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017506552",
    },
    {
        "school": "Success Academy 4-5",
        "district": "Kane ROE",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106530",
    },
    {
        "school": "Northeast Academy North",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106535",
    },
    {
        "school": "New Directions - Geneva",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106545",
    },
    {
        "school": "Northeast Academy East",
        "district": "Kane ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106546",
    },
    {
        "school": "PAWS Academy",
        "district": "Kane ROE",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170019106547",
    },
    {
        "school": "SEAPCO RISE",
        "district": "Spec Educ Assoc of Peoria County",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022506529",
    },
    {
        "school": "Schuyler Industry Middle School",
        "district": "Schuyler-Industry CUSD 5",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170033206548",
    },
    {
        "school": "North Mac Middle School",
        "district": "North Mac CUSD 34",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170140306527",
    },
    {
        "school": "B H R A Cooperative HS",
        "district": "B H R A Cooperative HS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170143306554",
    },
    {
        "school": "Dimmick Comm Cons SD 175",
        "district": "Dimmick Comm Cons SD #175",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170143406538",
    },
    {
        "school": "DREAM Academy",
        "district": "CUSD 300",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170855006528",
    },
    {
        "school": "Acero Chtr - Sandra Cisneros Cmps",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006436",
    },
    {
        "school": "Perspectives Chtr - Leadership Ac",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006437",
    },
    {
        "school": "CICS - Longwood Campus",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006438",
    },
    {
        "school": "Noble St Chtr-Golder College Prep",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006439",
    },
    {
        "school": "Noble St Chtr-Chicago Bulls Prep",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006440",
    },
    {
        "school": "Perspectives Chtr - HS of Tech",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006441",
    },
    {
        "school": "YCCS-West Town Academy Alt HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006442",
    },
    {
        "school": "LEARN Chtr - Middle School",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006443",
    },
    {
        "school": "Acero Chtr - SPC Zizumbo Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006444",
    },
    {
        "school": "YCCS-Westside Holistic Ldr Acad",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006445",
    },
    {
        "school": "CICS - Bucktown Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006446",
    },
    {
        "school": "Noble St Chtr-Rowe-Clark MS Acad",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006447",
    },
    {
        "school": "Acero Chtr - Bartolome de las",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006448",
    },
    {
        "school": "YCCS-Latino Youth Alternative HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006449",
    },
    {
        "school": "Noble St Chtr-Butler - Crimson",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006450",
    },
    {
        "school": "LEARN Chtr - South Chicago Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006451",
    },
    {
        "school": "Noble St Chtr-Pritzker Col Prep",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006452",
    },
    {
        "school": "Aspira Charter - Bus and Fin",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006453",
    },
    {
        "school": "Noble St Chtr-Hansberry Prep Slvr",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006454",
    },
    {
        "school": "Acero Chtr - Rufino Tamayo Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006455",
    },
    {
        "school": "YCCS-Innovations of Arts Integr",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006456",
    },
    {
        "school": "LEARN Charter Excel Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006457",
    },
    {
        "school": "YCCS Chtr - Chatham",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006458",
    },
    {
        "school": "Noble St Chtr-Muchin College Prep",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006459",
    },
    {
        "school": "YCCS-Sullivan House Alt HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006460",
    },
    {
        "school": "CICS - Ralph Ellison Campus",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006461",
    },
    {
        "school": "CICS - Irving Park Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006462",
    },
    {
        "school": "YCCS-CCA Academy HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006463",
    },
    {
        "school": "Noble St Chtr-The Noble Academy",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006464",
    },
    {
        "school": "CICS - Wrightwood",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006465",
    },
    {
        "school": "Univ of Chicago Chtr-Nth Kenwood",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006466",
    },
    {
        "school": "Acero Chtr Netrk -  Major Garcia",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006467",
    },
    {
        "school": "YCCS-Community Youth Dev Inst HS",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006468",
    },
    {
        "school": "LEARN Chtr - 7th Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006469",
    },
    {
        "school": "Noble St Chtr-Noble Campus",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006470",
    },
    {
        "school": "LEARN Chtr - Butler",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006471",
    },
    {
        "school": "CICS - Quest North Campus",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006472",
    },
    {
        "school": "ASPIRA Charter - Early College Pr",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006473",
    },
    {
        "school": "Acero Chtr-Brighton Park Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006474",
    },
    {
        "school": "CICS - West Belden Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006475",
    },
    {
        "school": "North Lawndale Prep Chtr-Collins",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006476",
    },
    {
        "school": "KIPP Academy Chicago Campus",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006477",
    },
    {
        "school": "YCCS-Olive Harvey Mid College HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006478",
    },
    {
        "school": "YCCS-McKinley-Lakeside Leadership",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006479",
    },
    {
        "school": "Noble St Chtr-DRW Trading Col",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006480",
    },
    {
        "school": "Acero Chtr - Carlos Fuentes Cmpus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006481",
    },
    {
        "school": "Acero Chtr - Octavio Paz Campus",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006482",
    },
    {
        "school": "Acero Chtr Sch Netwrk- Victoria",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006483",
    },
    {
        "school": "CICS - Bond Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006484",
    },
    {
        "school": "Noble St Chtr-ITW Speer Acad",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006485",
    },
    {
        "school": "YCCS-Albizu Campos Puerto Rican",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006486",
    },
    {
        "school": "CICS - Loomis Primary Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006487",
    },
    {
        "school": "CICS - Basil Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006488",
    },
    {
        "school": "North Lawndale Prep Chtr - Christ",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006489",
    },
    {
        "school": "YCCS-Progressive Leadership Acad",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006490",
    },
    {
        "school": "Noble St Chtr-Baker Campus",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006491",
    },
    {
        "school": "LEARN Chtr -  Hunter Perkins Camp",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006492",
    },
    {
        "school": "Univ of Chicago Chtr-Woodlawn",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006493",
    },
    {
        "school": "Noble St Chtr-Johnson Colg Prep",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006494",
    },
    {
        "school": "Univ of Chicago Chtr-Donoghue",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006495",
    },
    {
        "school": "YCCS-Association House",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006496",
    },
    {
        "school": "Acero Chtr - Officer Marquez Cmps",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006497",
    },
    {
        "school": "CICS - Prairie Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006498",
    },
    {
        "school": "Noble St Chtr Rauner College Prep",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006499",
    },
    {
        "school": "CICS - Northtown  Campus",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006500",
    },
    {
        "school": "YCCS-Jane Addams Alternative HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006501",
    },
    {
        "school": "LEARN Chtr-Campbell Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006502",
    },
    {
        "school": "Perspectives Chtr - Joslin Campus",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006503",
    },
    {
        "school": "YCCS-ASPIRA Pantoja Alt HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006504",
    },
    {
        "school": "Acero Chtr Network - Jovita Idar",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006505",
    },
    {
        "school": "CICS - Avalon/South Shore",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006507",
    },
    {
        "school": "Acero Chtr  Sor Juana Ines de la",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006508",
    },
    {
        "school": "KIPP Chicago Chrtrs - Ascend Acad",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006509",
    },
    {
        "school": "KIPP Chicago Chrtrs  Bloom Campus",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006510",
    },
    {
        "school": "YCCS-Austin Career Ed Cntr HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006511",
    },
    {
        "school": "CICS - Washington Pk Campus",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006512",
    },
    {
        "school": "Noble St Chtr - Mansueto",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006513",
    },
    {
        "school": "Perspectives Chtr -  IIT Campus",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006514",
    },
    {
        "school": "Noble St Chtr-UIC College Prep",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006515",
    },
    {
        "school": "ASPIRA Charter - Haugan Campus",
        "district": "City of Chicago SD 299",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006516",
    },
    {
        "school": "YCCS-Truman Middle College HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006517",
    },
    {
        "school": "YCCS-Youth Connection Leadership",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006518",
    },
    {
        "school": "YCCS-Scholastic Achievement HS",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006519",
    },
    {
        "school": "KIPP One Academy",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006520",
    },
    {
        "school": "Acero Chtr - Esmera Santiago Cmps",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006521",
    },
    {
        "school": "Acero Chtr Network - PFC Torress",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006522",
    },
    {
        "school": "Noble St Chtr-Comer College Prep",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006523",
    },
    {
        "school": "Acero Chtr  Roberto Clemente Cmps",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006524",
    },
    {
        "school": "YCCS-Virtual HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006539",
    },
    {
        "school": "Foundations College Prep Charter",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006556",
    },
    {
        "school": "East Moline Education Center",
        "district": "East Moline SD 37",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171317006544",
    },
    {
        "school": "Illinois Park Elem School",
        "district": "SD U-46",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371006537",
    },
    {
        "school": "Fieldcrest Middle School",
        "district": "Fieldcrest CUSD 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171510006543",
    },
    {
        "school": "Serena Middle School",
        "district": "Serena CUSD 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171588006553",
    },
    {
        "school": "IVC Learning Center",
        "district": "Il Valley Central USD 321",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171997006541",
    },
    {
        "school": "John Schroder Early Childhood Ctr",
        "district": "Lombard SD 44",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172346006526",
    },
    {
        "school": "J Giles Elem School",
        "district": "Norridge SD 80",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172865006555",
    },
    {
        "school": "Pleasant Valley Middle School",
        "district": "Pleasant Valley SD 62",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173195006536",
    },
    {
        "school": "River Trails Lrning Ctr Parkview",
        "district": "River Trails SD 26",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173387006549",
    },
    {
        "school": "Rochelle Focus House",
        "district": "Rochelle Twp HSD 212",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173429006540",
    },
    {
        "school": "Wm Nashold Early Childhood Center",
        "district": "Rockford SD 205",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451006551",
    },
    {
        "school": "COOP HS 7",
        "district": "Rossville-Alvin CUSD 7",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173487006534",
    },
    {
        "school": "Northfield Community Nursery Sch",
        "district": "Sunset Ridge SD 29",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173840006542",
    },
    {
        "school": "Urbana Gerber School",
        "district": "Urbana SD 116",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173996006532",
    },
    {
        "school": "COMPASS Alternative School",
        "district": "Anderson Community School Corp",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "IN",
        "nces_id": "180015002623",
    },
    {
        "school": "Circle City Prep Charter School",
        "district": "Circle City Prep Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180018102617",
    },
    {
        "school": "Excel Center - Clarksville",
        "district": "Excel Center - Clarksville",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180018202619",
    },
    {
        "school": "Purdue Polytechnic High School Ind",
        "district": "Purdue Polytechnic High School Ind",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180018302632",
    },
    {
        "school": "Avondale Meadows Middle School",
        "district": "Avondale Meadows Middle School",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180018402620",
    },
    {
        "school": "Excel Center - Hammond",
        "district": "Excel Center - Hammond",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180018502624",
    },
    {
        "school": "Riverside High School",
        "district": "Riverside High School",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180018702633",
    },
    {
        "school": "J & R Phalen Leadership Academy",
        "district": "J & R Phalen Leadership Academy",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180018802618",
    },
    {
        "school": "Otwell Miller Academy",
        "district": "Otwell Miller Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180018902616",
    },
    {
        "school": "Ignite Achievement Academy",
        "district": "Ignite Achievement Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180019002635",
    },
    {
        "school": "Indiana Connections Career Academy",
        "district": "Indiana Connections Career Academy",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180019102631",
    },
    {
        "school": "Lincoln Elementary School",
        "district": "Brownsburg Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180102002626",
    },
    {
        "school": "McCutchanville Elementary School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345002627",
    },
    {
        "school": "Horace Mann Elementary",
        "district": "Huntington Co Com Sch Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180471002638",
    },
    {
        "school": "HW Longfellow Med/STEM Magnet Midl",
        "district": "Indianapolis Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002630",
    },
    {
        "school": "Milan Intermediate School",
        "district": "Milan Community Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180663002636",
    },
    {
        "school": "Mt Vernon Early Learning Academy",
        "district": "Mt Vernon Community School Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180726002634",
    },
    {
        "school": "Juvenile Services Center",
        "district": "Noblesville Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IN",
        "nces_id": "180765002621",
    },
    {
        "school": "Shoals Middle School",
        "district": "Shoals Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181017002615",
    },
    {
        "school": "Lewis Cass Polytechnic Academy",
        "district": "Lewis Cass Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "181068002622",
    },
    {
        "school": "Lewis Cass Junior High School",
        "district": "Lewis Cass Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181068002625",
    },
    {
        "school": "Heavilin Elementary School",
        "district": "Valparaiso Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181197002637",
    },
    {
        "school": "Valley Elementary School",
        "district": "North Fayette Valley Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190000602253",
    },
    {
        "school": "North Fayette Valley Middle School",
        "district": "North Fayette Valley Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190000602255",
    },
    {
        "school": "Aurelia Elementary School",
        "district": "Alta-Aurelia Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190348002251",
    },
    {
        "school": "Alta-Aurelia Middle Sch",
        "district": "Alta-Aurelia Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190348002252",
    },
    {
        "school": "Cardinal Junior High",
        "district": "Cardinal Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190624002246",
    },
    {
        "school": "Bess Streeter Aldrich Elementary",
        "district": "Cedar Falls Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190651002256",
    },
    {
        "school": "Heritage Elementary",
        "district": "Dallas Center-Grimes Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190852002242",
    },
    {
        "school": "Liberty High School",
        "district": "Iowa City Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470002241",
    },
    {
        "school": "Christine Grant Elementary",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470002250",
    },
    {
        "school": "Longfellow Elementary",
        "district": "Marion Independent School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191869002245",
    },
    {
        "school": "Odebolt Arthur Battle Creek Ida Grove Elementary - Ida Grove",
        "district": "Odebolt Arthur Battle Creek Ida Grove Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192160002247",
    },
    {
        "school": "Odebolt Arthur Battle Creek Ida Grove High School",
        "district": "Odebolt Arthur Battle Creek Ida Grove Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192160002248",
    },
    {
        "school": "Solon Intermediate",
        "district": "Solon Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192658002254",
    },
    {
        "school": "Van Meter Middle School",
        "district": "Van Meter Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192901002244",
    },
    {
        "school": "Radiant Elementary School",
        "district": "Waukee Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193051002249",
    },
    {
        "school": "Sunflower Elementary School",
        "district": "Ottawa",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200001502101",
    },
    {
        "school": "Fredonia Early Learning Center",
        "district": "Fredonia",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200627002089",
    },
    {
        "school": "Bridges/Wyandot Academy",
        "district": "Kansas City",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795002091",
    },
    {
        "school": "Fairfax Learning Center",
        "district": "Kansas City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795002094",
    },
    {
        "school": "500 Reach",
        "district": "Kansas City",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795002097",
    },
    {
        "school": "Fort Larned Elementary School",
        "district": "Ft Larned",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200837002100",
    },
    {
        "school": "Seymour Rogers Middle School",
        "district": "Liberal",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200873002095",
    },
    {
        "school": "Meadowlark Elementary School",
        "district": "Liberal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200873002096",
    },
    {
        "school": "Central State Academy",
        "district": "Nickerson",
        "level": "Other",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200999002092",
    },
    {
        "school": "Olathe West High School",
        "district": "Olathe",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014002088",
    },
    {
        "school": "Wolf Springs Elementary School",
        "district": "Blue Valley",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201200002098",
    },
    {
        "school": "Jardine Elementary",
        "district": "Topeka Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201226002090",
    },
    {
        "school": "Bluegrass Challenge Academy",
        "district": "Eminence Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210171002455",
    },
    {
        "school": "Frederick Douglass High School",
        "district": "Fayette County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002459",
    },
    {
        "school": "South Floyd Elementary School",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195002446",
    },
    {
        "school": "Floyd Central High School",
        "district": "Floyd County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195002450",
    },
    {
        "school": "Duff-Allen Central Elementary",
        "district": "Floyd County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210195002452",
    },
    {
        "school": "The Central Academy",
        "district": "Henderson County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210271002457",
    },
    {
        "school": "W.E.B. DuBois Academy",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210299002458",
    },
    {
        "school": "Ashgrove Academy",
        "district": "Jessamine County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210303002442",
    },
    {
        "school": "Knox Inspire Academy",
        "district": "Knox County",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210315002449",
    },
    {
        "school": "Marion County Knight Academy",
        "district": "Marion County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210378002443",
    },
    {
        "school": "Marion County Middle School",
        "district": "Marion County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210378002454",
    },
    {
        "school": "Purchase Youth Village",
        "district": "Marshall County",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210381002445",
    },
    {
        "school": "Pine Knot Elementary School",
        "district": "McCreary County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210399002451",
    },
    {
        "school": "West Perry Elementary School",
        "district": "Perry County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210477002453",
    },
    {
        "school": "Pike County Day Treatment",
        "district": "Pike County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210480002444",
    },
    {
        "school": "Union County Preschool and Headstart",
        "district": "Union County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210564002447",
    },
    {
        "school": "WC Tel Center",
        "district": "Washington County",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210576002448",
    },
    {
        "school": "Linwood Public Charter School",
        "district": "Recovery School District-LDE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220005400175",
    },
    {
        "school": "Northshore Charter School",
        "district": "City of Bogalusa School District",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220024002371",
    },
    {
        "school": "Noble Minds",
        "district": "Noble Minds",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027802436",
    },
    {
        "school": "Alice M Harte Elementary Charter School",
        "district": "Alice M. Harte Elementary Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027900903",
    },
    {
        "school": "Einstein Charter Middle Sch at Sarah Towles Reed",
        "district": "Einstein Charter Middle Sch at Sarah Towles Reed",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220028002430",
    },
    {
        "school": "New Orleans Charter Science and Mathematics HS",
        "district": "New Orleans Charter Science and Mathematics HS",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220028100234",
    },
    {
        "school": "Lake Forest Elementary Charter School",
        "district": "Lake Forest Elementary Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220028201937",
    },
    {
        "school": "Einstein Charter School at Village De L'Est",
        "district": "Einstein Charter School at Village De L'Est",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220028300858",
    },
    {
        "school": "McDonogh 42 Charter School",
        "district": "McDonogh 42 Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220028400944",
    },
    {
        "school": "Audubon Charter School",
        "district": "Audubon Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220028501620",
    },
    {
        "school": "Robert Russa Moton Charter School",
        "district": "Robert Russa Moton Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220028601830",
    },
    {
        "school": "ENCORE Academy",
        "district": "ENCORE Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220028702350",
    },
    {
        "school": "Collegiate Baton Rouge",
        "district": "Collegiate Baton Rouge",
        "level": "Secondary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220028802448",
    },
    {
        "school": "Bricolage Academy",
        "district": "Bricolage Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220028902364",
    },
    {
        "school": "Thrive Academy",
        "district": "Thrive Academy",
        "level": "High",
        "type": "Special education school",
        "state": "LA",
        "nces_id": "220029002335",
    },
    {
        "school": "Eleanor McMain Secondary School",
        "district": "Eleanor McMain Secondary School",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220029100945",
    },
    {
        "school": "Einstein Charter at Sherwood Forest",
        "district": "Einstein Charter at Sherwood Forest",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220029202422",
    },
    {
        "school": "The NET 2 Charter High School",
        "district": "The NET 2 Charter High School",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220029302439",
    },
    {
        "school": "Edna Karr High School",
        "district": "Edna Karr High School",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220029400911",
    },
    {
        "school": "Einstein Charter High School at Sarah Towles Reed",
        "district": "Einstein Charter High School at Sarah Towles Reed",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220029502427",
    },
    {
        "school": "Wilson Charter School",
        "district": "Wilson Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220029602414",
    },
    {
        "school": "Lusher Charter School",
        "district": "Lusher Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220029700926",
    },
    {
        "school": "GEO Prep Mid-City of Greater Baton Rouge",
        "district": "GEO Prep Mid-City of Greater Baton Rouge",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220029802361",
    },
    {
        "school": "Benjamin Franklin High School",
        "district": "Benjamin Franklin High School",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220029900888",
    },
    {
        "school": "Fair Park Middle School",
        "district": "Caddo Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030002444",
    },
    {
        "school": "JCFA Lafayette",
        "district": "JCFA Lafayette",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030102445",
    },
    {
        "school": "Istrouma High School",
        "district": "East Baton Rouge Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002440",
    },
    {
        "school": "Ralph J Bunche Elementary",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002447",
    },
    {
        "school": "Edward J Sam Accelerated School of Lafayette",
        "district": "Lafayette Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087002441",
    },
    {
        "school": "Southside High School",
        "district": "Lafayette Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087002442",
    },
    {
        "school": "Live Oak Junior High",
        "district": "Livingston Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220102002435",
    },
    {
        "school": "Rooted School",
        "district": "Orleans Parish",
        "level": "Secondary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220117002437",
    },
    {
        "school": "Elan Academy Charter School",
        "district": "Orleans Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220117002438",
    },
    {
        "school": "East Ouachita Middle School",
        "district": "Ouachita Parish",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220120002446",
    },
    {
        "school": "Arlene Meraux Elementary School",
        "district": "St. Bernard Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220141002449",
    },
    {
        "school": "St. Helena Early Learning Center",
        "district": "St. Helena Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220147002443",
    },
    {
        "school": "Moscow Elementary",
        "district": "RSU 83/MSAD 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231065023165",
    },
    {
        "school": "Upper Kennebec Valley Middle/Senior High School",
        "district": "RSU 83/MSAD 13",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231065023166",
    },
    {
        "school": "Milo Elementary School",
        "district": "RSU 41/MSAD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231158023161",
    },
    {
        "school": "Brownville Elementary School",
        "district": "RSU 41/MSAD 41",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231158023163",
    },
    {
        "school": "Piscataquis Community Elementary",
        "district": "RSU 80/MSAD 04",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231173023159",
    },
    {
        "school": "Piscataquis Community Secondary School",
        "district": "RSU 80/MSAD 04",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231173023160",
    },
    {
        "school": "Molly Ockett School",
        "district": "RSU 72/MSAD 72",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231476523172",
    },
    {
        "school": "Hall-Dale Middle and High School",
        "district": "RSU 02",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231477623162",
    },
    {
        "school": "Caribou Middle School",
        "district": "RSU 39",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479423168",
    },
    {
        "school": "Caribou High School",
        "district": "RSU 39",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479423170",
    },
    {
        "school": "Teague Park School",
        "district": "RSU 39",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231479423171",
    },
    {
        "school": "Cornville Downtown Campus",
        "district": "Cornville Regional Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480723164",
    },
    {
        "school": "Cornville Early Childhood Campus",
        "district": "Cornville Regional Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231480723167",
    },
    {
        "school": "Dirigo High School",
        "district": "RSU 56",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231483300382",
    },
    {
        "school": "T W Kelly Dirigo Middle School",
        "district": "RSU 56",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231483300927",
    },
    {
        "school": "Dirigo Elementary School",
        "district": "RSU 56",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231483323114",
    },
    {
        "school": "Monarch Academy Annapolis ES",
        "district": "Anne Arundel County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001744",
    },
    {
        "school": "Silver Creek Middle",
        "district": "Montgomery County Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001741",
    },
    {
        "school": "Princess Anne Elementary School",
        "district": "Somerset County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240057001742",
    },
    {
        "school": "Greenwood Elementary School",
        "district": "Somerset County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240057001743",
    },
    {
        "school": "St. Mary's County Evening High",
        "district": "St. Mary's County Public Schools",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240060001745",
    },
    {
        "school": "Libertas Academy Charter School",
        "district": "Libertas Academy Charter School (District)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250058602878",
    },
    {
        "school": "Old Sturbridge Academy Charter Public School",
        "district": "Old Sturbridge Academy Charter Public School (District)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250058702877",
    },
    {
        "school": "Hoosac Valley Middle School",
        "district": "Hoosac Valley Regional",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250178002879",
    },
    {
        "school": "Mattahunt Elementary School",
        "district": "Boston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250279002874",
    },
    {
        "school": "Resiliency Preparatory Academy",
        "district": "Fall River",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250483002873",
    },
    {
        "school": "Caleb Dustin Hunking School",
        "district": "Haverhill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597002881",
    },
    {
        "school": "Dr. Janice Adie Day School",
        "district": "Lowell",
        "level": "Other",
        "type": "Special education school",
        "state": "MA",
        "nces_id": "250702002876",
    },
    {
        "school": "Advanced Community Experience Program",
        "district": "Lunenburg",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MA",
        "nces_id": "250708002882",
    },
    {
        "school": "Nantucket Intermediate School",
        "district": "Nantucket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250825002880",
    },
    {
        "school": "Sharon Early Childhood Center",
        "district": "Sharon",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251062002872",
    },
    {
        "school": "Springfield Vocational Academy",
        "district": "Springfield",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MA",
        "nces_id": "251113002875",
    },
    {
        "school": "David Ellis Academy  PK",
        "district": "David Ellis Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260023408725",
    },
    {
        "school": "Frontier International Academy  Elementary",
        "district": "Frontier International Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260030108809",
    },
    {
        "school": "Walter P Reuther Psychiatric Hospital",
        "district": "Michigan Department of Community Health",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260096008001",
    },
    {
        "school": "Michigan Mathematics and Science Academy Dequindre",
        "district": "Michigan Mathematics and Science Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260096708813",
    },
    {
        "school": "Capstone Academy Charter SchoolMayfield",
        "district": "Capstone Academy Charter School (SDA)",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101308820",
    },
    {
        "school": "CapstoneWayne Co Juvenile Detention Fac",
        "district": "Capstone Academy Charter School (SDA)",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260101308822",
    },
    {
        "school": "Detroit Prep",
        "district": "Detroit Achievement Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260104808796",
    },
    {
        "school": "Breithaupt Career and Technical Center",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "260110300086",
    },
    {
        "school": "Randolph Career and Technical Center",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "260110300748",
    },
    {
        "school": "Golightly Career and Technical  Center",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "260110300749",
    },
    {
        "school": "Brenda Scott Academy for Theatre Arts",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110301676",
    },
    {
        "school": "Burns ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304660",
    },
    {
        "school": "Central High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304670",
    },
    {
        "school": "Denby High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304693",
    },
    {
        "school": "Mary McLeod Bethune ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304724",
    },
    {
        "school": "Henry Ford High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304734",
    },
    {
        "school": "Marion Law Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304773",
    },
    {
        "school": "Mumford High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304793",
    },
    {
        "school": "Nolan ElementaryMiddle School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304800",
    },
    {
        "school": "Pershing High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304813",
    },
    {
        "school": "Southeastern High School",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110304830",
    },
    {
        "school": "Academy of The Americas High School",
        "district": "Detroit Public Schools Community District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308803",
    },
    {
        "school": "Turning Point Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260110308805",
    },
    {
        "school": "Francis Street Primary School",
        "district": "Francis Street Primary School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260111108826",
    },
    {
        "school": "Michigan Online School",
        "district": "Michigan Online School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260111208844",
    },
    {
        "school": "Detroit Collegiate High School",
        "district": "Detroit Collegiate High School",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260111308825",
    },
    {
        "school": "Michigan International Prep School",
        "district": "Michigan International Prep School",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260111408807",
    },
    {
        "school": "Distinctive College Prep",
        "district": "Distinctive College Prep.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260111508828",
    },
    {
        "school": "Correctional Services",
        "district": "Ann Arbor Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260282008815",
    },
    {
        "school": "Berrien Springs Adult Education",
        "district": "Berrien Springs Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260543008346",
    },
    {
        "school": "Brandon Adult Transition Program",
        "district": "Brandon School District in the Counties of Oakland and Lapee",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260657008741",
    },
    {
        "school": "JB GRIFFIN",
        "district": "Carrollton Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260807008783",
    },
    {
        "school": "Clio Learning Center",
        "district": "Clio Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261011008804",
    },
    {
        "school": "Eastpointe Alternative Center",
        "district": "Eastpointe Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261245008832",
    },
    {
        "school": "East Jordan Alternative High School",
        "district": "East Jordan Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261256008823",
    },
    {
        "school": "WAY Eau Claire",
        "district": "Eau Claire Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261281008569",
    },
    {
        "school": "Hope Academic Academy",
        "district": "Ecorse Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261293008849",
    },
    {
        "school": "Farmington STEAM Academy",
        "district": "Farmington Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261407008836",
    },
    {
        "school": "Schofield Elementary School",
        "district": "Fitzgerald Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261446008818",
    },
    {
        "school": "Consolidated Community School Services",
        "district": "Engadine Consolidated Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261560001772",
    },
    {
        "school": "Ridgemoor Park Montessori",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008812",
    },
    {
        "school": "Tau Beta School",
        "district": "Hamtramck School District of the City of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261752008847",
    },
    {
        "school": "Redwood Elementary",
        "district": "Hartford Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261788008824",
    },
    {
        "school": "Southern Michigan Center for Science  Industry SMCSI",
        "district": "Hudson Area Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "261881008638",
    },
    {
        "school": "Tecumseh SMCSI",
        "district": "Hudson Area Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "261881008734",
    },
    {
        "school": "Early Childhood Building",
        "district": "Hudsonville Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261884008592",
    },
    {
        "school": "Huron AI Center FRCS FRHS Program",
        "district": "Huron School District",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261893008552",
    },
    {
        "school": "Huron AI Center FRCS Bobcean Program",
        "district": "Huron School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261893008794",
    },
    {
        "school": "IshpemingNegauneeNICE Comm Ed Division",
        "district": "Ishpeming Public School District No. 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261953002051",
    },
    {
        "school": "Jackson County Jail",
        "district": "Jackson Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261962008299",
    },
    {
        "school": "Jackson Pathways",
        "district": "Jackson Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261962008833",
    },
    {
        "school": "Kelloggsville Early Childhood Learning Center",
        "district": "Kelloggsville Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262016008610",
    },
    {
        "school": "Kenowa Hills Pathways High School",
        "district": "Kenowa Hills Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262028008817",
    },
    {
        "school": "Hill Center",
        "district": "Lansing Public School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "262115008436",
    },
    {
        "school": "Mixter School",
        "district": "Lincoln Park School District of the City of",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262160008337",
    },
    {
        "school": "Garfield Community School",
        "district": "Livonia Public Schools School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262184008810",
    },
    {
        "school": "Michigan Youth Challenge Academy",
        "district": "Marshall Public Schools",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262297008477",
    },
    {
        "school": "Central Park Elementary",
        "district": "Midland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262382008837",
    },
    {
        "school": "ESCE Program",
        "district": "Millington Community Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262391008732",
    },
    {
        "school": "Genesee Valley Regional Center",
        "district": "Mt. Morris Consolidated Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262472008659",
    },
    {
        "school": "Genesee County Jail",
        "district": "Mt. Morris Consolidated Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262472008665",
    },
    {
        "school": "Novi Adult Transition Center",
        "district": "Novi Community School District",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262613008676",
    },
    {
        "school": "Riverview Early Childhood Center",
        "district": "Riverview Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262991008827",
    },
    {
        "school": "Riverview Virtual Academy",
        "district": "Riverview Community School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262991008829",
    },
    {
        "school": "SPECIAL EDUCATION",
        "district": "South Lyon Community Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263225008493",
    },
    {
        "school": "William A Pearson Elementary",
        "district": "South Lyon Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263225008838",
    },
    {
        "school": "Jerolene",
        "district": "Sturgis Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263309008472",
    },
    {
        "school": "Tecumseh East STEAM Center",
        "district": "Tecumseh Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263372008840",
    },
    {
        "school": "Tecumseh West STEAM Center",
        "district": "Tecumseh Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263372008842",
    },
    {
        "school": "Compass Learning Center",
        "district": "Tecumseh Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "263372008843",
    },
    {
        "school": "Waterford Lifetracks Program  Crary Campus",
        "district": "Waterford School District",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263531008254",
    },
    {
        "school": "Project Search",
        "district": "West Bloomfield School District",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "263582008291",
    },
    {
        "school": "Genesee Career Institute",
        "district": "Genesee ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268040008535",
    },
    {
        "school": "SAIL Skills for Adult Independent Living",
        "district": "Ingham ISD",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268052008748",
    },
    {
        "school": "Heartlands Institute of Technology",
        "district": "Ionia ISD",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "268054008253",
    },
    {
        "school": "Local Based Special Education Early Childhood Programs",
        "district": "Jackson ISD",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268058008758",
    },
    {
        "school": "Kent Innovation High School",
        "district": "Kent ISD",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268062008464",
    },
    {
        "school": "MySchoolKent",
        "district": "Kent ISD",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "268062008762",
    },
    {
        "school": "STRIVE Transition Program",
        "district": "Lapeer ISD",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268066008636",
    },
    {
        "school": "Adult Transition Services",
        "district": "Livingston ESA",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268070008765",
    },
    {
        "school": "RoerinkKnoll Education Center",
        "district": "Ottawa Area ISD",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268090008831",
    },
    {
        "school": "Chisago County Schools' Life Work C",
        "district": "ST. CROIX RIVER EDUCATION DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270001505143",
    },
    {
        "school": "Skillbuilding Opportunities for Aca",
        "district": "ST. CROIX RIVER EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270001505144",
    },
    {
        "school": "Vision",
        "district": "ST. CROIX RIVER EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270001505145",
    },
    {
        "school": "Pine County Transition Program",
        "district": "ST. CROIX RIVER EDUCATION DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270001505146",
    },
    {
        "school": "Pathway to Change",
        "district": "ST. CROIX RIVER EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270001505147",
    },
    {
        "school": "Gateway to College - IS",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002505128",
    },
    {
        "school": "West Transition",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002505131",
    },
    {
        "school": "Customized Alternative Solutions fo",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270002605108",
    },
    {
        "school": "MSED Birth to 3",
        "district": "MID STATE EDUCATION DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007305111",
    },
    {
        "school": "Lakes Country Academy",
        "district": "REGION 4-LAKES COUNTRY SERVICE COOP",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270008305103",
    },
    {
        "school": "Lakes Country Academy - ALEX",
        "district": "REGION 4-LAKES COUNTRY SERVICE COOP",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270008305104",
    },
    {
        "school": "Community of Peace Academy Middle",
        "district": "COMMUNITY OF PEACE ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011505136",
    },
    {
        "school": "Twin Cities International Schools",
        "district": "Twin Cities International Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270018905160",
    },
    {
        "school": "Spectrum Middle School - Grades 7-8",
        "district": "SPECTRUM HIGH SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270027605140",
    },
    {
        "school": "Hiawatha College Prep - Northrop",
        "district": "HIAWATHA ACADEMIES",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270028805141",
    },
    {
        "school": "Nompeng Academy",
        "district": "NOBLE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270029505126",
    },
    {
        "school": "Lionsgate Academy - Shoreview",
        "district": "LIONSGATE ACADEMY",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270031505148",
    },
    {
        "school": "First Step Alden",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032705123",
    },
    {
        "school": "Enrich Kingsland",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032705124",
    },
    {
        "school": "First Step Adams",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032705125",
    },
    {
        "school": "Enrich Alden",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032705152",
    },
    {
        "school": "Hmong College Prep Academy ES",
        "district": "HMONG COLLEGE PREP ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270034205102",
    },
    {
        "school": "STEP Academy Elementary",
        "district": "STEP ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270036705139",
    },
    {
        "school": "Prodeo Academy St. Paul",
        "district": "PRODEO ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038005150",
    },
    {
        "school": "Art & Science Academy Middle School",
        "district": "ART AND SCIENCE ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039705095",
    },
    {
        "school": "FIT Academy High School",
        "district": "FIT Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270042505142",
    },
    {
        "school": "Northern Lights Academy Cooperative",
        "district": "Northern Lights Academy Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270044205117",
    },
    {
        "school": "The Studio School",
        "district": "The Studio School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270044305155",
    },
    {
        "school": "Progeny Academy Charter School",
        "district": "Progeny Academy Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270044405133",
    },
    {
        "school": "Gateway STEM Academy Charter School",
        "district": "Gateway STEM Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270044505138",
    },
    {
        "school": "Lirio Montessori",
        "district": "Minnesota Wildflower Montessori Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270044605098",
    },
    {
        "school": "Acorn Montessori",
        "district": "Minnesota Wildflower Montessori Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270044605157",
    },
    {
        "school": "Three Rivers Montessori School",
        "district": "Three Rivers Montessori School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270044905163",
    },
    {
        "school": "Horizon Science Academy Twin Cities",
        "district": "Horizon Science Academy Twin Cities",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270045005159",
    },
    {
        "school": "Gene Dillon Elementary School",
        "district": "BEMIDJI PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270444005094",
    },
    {
        "school": "Brooklyn Center Middle School",
        "district": "BROOKLYN CENTER SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270624005130",
    },
    {
        "school": "112 ALC Seat-Based",
        "district": "EASTERN CARVER COUNTY PUBLIC SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270819005118",
    },
    {
        "school": "Columbia Academy Anchor Program",
        "district": "COLUMBIA HEIGHTS PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270951005164",
    },
    {
        "school": "Columbia Heights Transition Program",
        "district": "COLUMBIA HEIGHTS PUBLIC SCHOOL DIST",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270951005165",
    },
    {
        "school": "Deer River High School ALP",
        "district": "DEER RIVER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271014005105",
    },
    {
        "school": "Ivan Sand Middle School ALC",
        "district": "Elk River School District",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271137005158",
    },
    {
        "school": "FEC Pre K",
        "district": "FARIBAULT PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271176005109",
    },
    {
        "school": "Granada Huntley East Chain Middle S",
        "district": "Granada Huntley East Chain",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271304005153",
    },
    {
        "school": "Prairie Care Mankato",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271878005116",
    },
    {
        "school": "Marshall EC Voluntary PreK",
        "district": "MARSHALL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271894005106",
    },
    {
        "school": "Transition Plus",
        "district": "WESTONKA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272292005161",
    },
    {
        "school": "Nicollet Early Childhood Special Ed",
        "district": "NICOLLET PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272358005112",
    },
    {
        "school": "Gladstone Voluntary Pre-K",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385005100",
    },
    {
        "school": "Beaver Lake Voluntary Pre-K",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272385005156",
    },
    {
        "school": "Onamia Intermediate School",
        "district": "ONAMIA PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272505005107",
    },
    {
        "school": "Sandburg Middle School",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178005115",
    },
    {
        "school": "Fairview School Readiness Plus",
        "district": "ROSEVILLE PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273243005099",
    },
    {
        "school": "Royalton Public Schools Early Child",
        "district": "ROYALTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273252005122",
    },
    {
        "school": "Early Childhood Family Center",
        "district": "SPRING LAKE PARK PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273333005135",
    },
    {
        "school": "Rondo Center Pre-K",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384005134",
    },
    {
        "school": "Early Ed Highland",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273384005166",
    },
    {
        "school": "Brookview Elementary",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273819005114",
    },
    {
        "school": "GATE 4/5",
        "district": "STILLWATER AREA PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273819005119",
    },
    {
        "school": "Warroad Alternative Learning Progra",
        "district": "WARROAD PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274185005149",
    },
    {
        "school": "Waseca Early Childhood",
        "district": "WASECA PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274188005096",
    },
    {
        "school": "North Woods Elementary School",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274216005151",
    },
    {
        "school": "Kenyon-Wanamingo High School Credit",
        "district": "GOODHUE COUNTY EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279144305110",
    },
    {
        "school": "Star Program",
        "district": "WEST CENTRAL EDUCATION DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279145505137",
    },
    {
        "school": "BALDWYN CAREER ADVANCEMENT CENTER",
        "district": "BALDWYN SCHOOL DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280054001481",
    },
    {
        "school": "BILOXI UPPER ELEMENTARY",
        "district": "BILOXI PUBLIC SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280063001478",
    },
    {
        "school": "CLEVELAND CENTRAL MIDDLE SCHOOL",
        "district": "CLEVELAND SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280075001475",
    },
    {
        "school": "D.M. SMITH ELEMENTARY",
        "district": "CLEVELAND SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280075001476",
    },
    {
        "school": "CLEVELAND CENTRAL HIGH SCHOOL",
        "district": "CLEVELAND SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280075001477",
    },
    {
        "school": "GEORGE COUNTY ALTERNATIVE",
        "district": "GEORGE CO SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280156001474",
    },
    {
        "school": "HOUSTON ALTERNATIVE SCHOOL",
        "district": "HOUSTON  SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280201001479",
    },
    {
        "school": "LOWNDES CO VOC COMPLEX",
        "district": "LOWNDES CO SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280273001480",
    },
    {
        "school": "KIPP ST. LOUIS HIGH",
        "district": "KIPP ST LOUIS PUBLIC SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059103314",
    },
    {
        "school": "CROSSROADS HIGH SCHOOL",
        "district": "CROSSROADS CHARTER SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060303311",
    },
    {
        "school": "EAGLE GRAVOIS PARK",
        "district": "EAGLE COLLEGE PREP ENDEAVOR",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060503304",
    },
    {
        "school": "Hawthorn High School",
        "district": "HAWTHORN LEADERSHIP SCHL GIRLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290060803317",
    },
    {
        "school": "THE ARCH COMMUNITY SCHOOL",
        "district": "THE ARCH COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290061403302",
    },
    {
        "school": "BUTLER EARLY CHILDHOOD",
        "district": "BUTLER R-V",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290636003308",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "FT. ZUMWALT R-II",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290837003315",
    },
    {
        "school": "DONIPHAN INTERMEDIATE",
        "district": "DONIPHAN R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291092003301",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "HANNIBAL 60",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291365003307",
    },
    {
        "school": "JEFFERSON R-VII PRESCHOOL",
        "district": "JEFFERSON CO. R-VII",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291623003305",
    },
    {
        "school": "DRESSEL ELEMENTARY SCHOOL",
        "district": "LINDBERGH SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291869003306",
    },
    {
        "school": "Spainhower School",
        "district": "MARSHALL",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292041003319",
    },
    {
        "school": "MOSAIC ELEMENTARY",
        "district": "MEHLVILLE R-IX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292067003320",
    },
    {
        "school": "LEAD INNOVATION STUDIO",
        "district": "PARK HILL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MO",
        "nces_id": "292355003313",
    },
    {
        "school": "RAYMORE-PECULIAR SOUTH MIDDLE",
        "district": "RAYMORE-PECULIAR R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292373003312",
    },
    {
        "school": "SHULL EARLY LEARNING CENTER",
        "district": "RAYMORE-PECULIAR R-II",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292373003316",
    },
    {
        "school": "THREE TRAILS PRESCHOOL",
        "district": "RAYTOWN C-2",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292607003318",
    },
    {
        "school": "SENECA EARLY CHILDHOOD SCHOOL",
        "district": "SENECA R-VII",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292790003303",
    },
    {
        "school": "STONE CREEK ELEMENTARY",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165003309",
    },
    {
        "school": "WABASH ELEMENTARY",
        "district": "WENTZVILLE R-IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293165003310",
    },
    {
        "school": "Ben Steele Middle School",
        "district": "Billings Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300387001118",
    },
    {
        "school": "Plains Elementary School",
        "district": "Plains K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302085000622",
    },
    {
        "school": "Plains 7-8",
        "district": "Plains K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302085000896",
    },
    {
        "school": "Surprise Creek School",
        "district": "Stanford K-12 Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302499000878",
    },
    {
        "school": "DOUGLAS CO WEST ALTERNATIVE HIGH SCHOOL",
        "district": "DOUGLAS CO WEST COMMUNITY SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310016502358",
    },
    {
        "school": "BOYD COUNTY ELEMENTARY (BUTTE)",
        "district": "BOYD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018702350",
    },
    {
        "school": "BOYD COUNTY ELEMENTARY (LYNCH)",
        "district": "BOYD COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018702352",
    },
    {
        "school": "BOYD COUNTY HIGH SCHOOL (SPENCER)",
        "district": "BOYD COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018702354",
    },
    {
        "school": "BOYD COUNTY MIDDLE SCHOOL (SPENCER)",
        "district": "BOYD COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310018702355",
    },
    {
        "school": "BEATRICE COMMUNITY PRESCHOOL",
        "district": "BEATRICE PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310360002361",
    },
    {
        "school": "BENNINGTON MIDDLE SCHOOL",
        "district": "BENNINGTON PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310399002357",
    },
    {
        "school": "RAYMOND CENTRAL PRESCHOOL",
        "district": "RAYMOND CENTRAL PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310495002365",
    },
    {
        "school": "ASPEN CREEK MIDDLE SCHOOL",
        "district": "GRETNA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317122002362",
    },
    {
        "school": "ASPEN CREEK ELEMENTARY SCHOOL",
        "district": "GRETNA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317122002364",
    },
    {
        "school": "HARVARD MIDDLE SCHOOL",
        "district": "HARVARD PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317155002353",
    },
    {
        "school": "MOORE MIDDLE SCHOOL",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317284002363",
    },
    {
        "school": "OPS VIRTUAL HIGH SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317482002360",
    },
    {
        "school": "Discovery Charter School Mesa Vista",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100885",
    },
    {
        "school": "Leadership Academy of Nevada",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100886",
    },
    {
        "school": "Quest Academy West Alexander",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100887",
    },
    {
        "school": "Doral Academy Cactus",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100888",
    },
    {
        "school": "Coral Academy of Science Las Vegas Tamarus",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100890",
    },
    {
        "school": "Doral Academy Northern Nevada",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100891",
    },
    {
        "school": "Doral Academy West Pebble",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100892",
    },
    {
        "school": "Doral Academy Fire Mesa",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100893",
    },
    {
        "school": "Coral Academy of Science Las Vegas Windmill",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100894",
    },
    {
        "school": "Legacy Traditional North Valley",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100895",
    },
    {
        "school": "Mater Academy Northern Nevada",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100896",
    },
    {
        "school": "Pinecrest Academy of Nevada Horizon",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100897",
    },
    {
        "school": "Somerset Academy Losee",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100898",
    },
    {
        "school": "Pinecrest Academy St Rose",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100899",
    },
    {
        "school": "Nevada State High School Downtown",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100900",
    },
    {
        "school": "Somerset Academy Lone Mountain",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100901",
    },
    {
        "school": "Mater Academy Bonanza",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100902",
    },
    {
        "school": "Nevada State High School Summerlin",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100903",
    },
    {
        "school": "Somerset Academy North Las Vegas",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100904",
    },
    {
        "school": "Doral Academy Saddle",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100906",
    },
    {
        "school": "Coral Academy of Science Las Vegas Nellis AFB",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100907",
    },
    {
        "school": "Coral Academy of Science Las Vegas Centennial Hills",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100908",
    },
    {
        "school": "Pinecrest Academy Inspirada",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100909",
    },
    {
        "school": "Somerset Academy Stephanie",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100910",
    },
    {
        "school": "Futuro Academy Elementary",
        "district": "ACHIEVEMENT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320002200881",
    },
    {
        "school": "Democracy Prep at Agassi High",
        "district": "ACHIEVEMENT SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320002200882",
    },
    {
        "school": "Democracy Prep at Agassi Elementary",
        "district": "ACHIEVEMENT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320002200883",
    },
    {
        "school": "Democracy Prep at Agassi Middle",
        "district": "ACHIEVEMENT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320002200884",
    },
    {
        "school": "Independence High School",
        "district": "CORRECTIONAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320002300808",
    },
    {
        "school": "Churchill County Adult",
        "district": "CHURCHILL COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320003000868",
    },
    {
        "school": "Don and Dee Snyder Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000872",
    },
    {
        "school": "Shelley Berkley Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000873",
    },
    {
        "school": "Jan Jones Blackhurst Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000874",
    },
    {
        "school": "Josh Stevens Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000875",
    },
    {
        "school": "Dr. Beverly S. Mathis Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000876",
    },
    {
        "school": "Billy and Rosemary Vassiliadis Elementary School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000877",
    },
    {
        "school": "Mission High School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320006000878",
    },
    {
        "school": "Lomie G. Heard Elementary School  A Marzano Academy",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000879",
    },
    {
        "school": "Douglas County Adult School",
        "district": "DOUGLAS COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320009000861",
    },
    {
        "school": "Adult Education",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320012000854",
    },
    {
        "school": "Humboldt Adult Program",
        "district": "HUMBOLDT COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320021000858",
    },
    {
        "school": "Lander Adult",
        "district": "LANDER COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320024000864",
    },
    {
        "school": "Lincoln Adult",
        "district": "LINCOLN COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320027000865",
    },
    {
        "school": "Lyon County Adult Education",
        "district": "LYON COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320030000860",
    },
    {
        "school": "Mineral County Adult Education School",
        "district": "MINERAL COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320033000859",
    },
    {
        "school": "Nye County Adult Education",
        "district": "NYE COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320036000862",
    },
    {
        "school": "Pershing Co Adult",
        "district": "PERSHING COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320042000867",
    },
    {
        "school": "Rise Academy for Achievement",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320048000863",
    },
    {
        "school": "Coral Academy Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000880",
    },
    {
        "school": "Steptoe Valley Adult Education",
        "district": "WHITE PINE COUNTY SCHOOL DISTRICT",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320051000857",
    },
    {
        "school": "LEAF Charter School",
        "district": "LEAF Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330330500722",
    },
    {
        "school": "Kreiva Academy Public Charter School (M)",
        "district": "Kreiva Academy Public Charter School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330330800726",
    },
    {
        "school": "Kreiva Academy Public Charter School (H)",
        "district": "Kreiva Academy Public Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330330800727",
    },
    {
        "school": "Capital City Public Charter School (H)",
        "district": "Capital City Public Charter School",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330331300728",
    },
    {
        "school": "Capital City Public Charter School (E)",
        "district": "Capital City Public Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330331300729",
    },
    {
        "school": "Windham Academy Public Charter School",
        "district": "Windham Academy Public Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330331400730",
    },
    {
        "school": "Hunterdon County Academies",
        "district": "Hunterdon County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340005003405",
    },
    {
        "school": "LEAD Charter School",
        "district": "LEAD Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340078803423",
    },
    {
        "school": "Ocean Academy Charter School",
        "district": "Ocean Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340078903411",
    },
    {
        "school": "College Achieve Greater Asbury Park Charter School",
        "district": "College Achieve Greater Asbury Park Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340079103403",
    },
    {
        "school": "Achieve Community Charter School",
        "district": "Achieve Community Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340079203419",
    },
    {
        "school": "College Achieve Paterson Charter School",
        "district": "College Achieve Paterson Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340079303413",
    },
    {
        "school": "Harrison School",
        "district": "CALDWELL-WEST CALDWELL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340258003425",
    },
    {
        "school": "Gloucester City Middle School",
        "district": "GLOUCESTER CITY PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340600003401",
    },
    {
        "school": "Patricia M. Noonan School PS #26",
        "district": "Jersey City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340783003395",
    },
    {
        "school": "Mercer County Technical School Health Sciences Academy",
        "district": "Area Vocational Technical Schools of Mercer County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340995003409",
    },
    {
        "school": "Mercer County Technical School Culinary Arts Academy",
        "district": "Area Vocational Technical Schools of Mercer County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340995003410",
    },
    {
        "school": "Mercer County Technical School STEM Academy",
        "district": "Area Vocational Technical Schools of Mercer County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340995003415",
    },
    {
        "school": "Washington School",
        "district": "Millburn Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341020003402",
    },
    {
        "school": "Academy for Biotechnology",
        "district": "Morris County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341072003418",
    },
    {
        "school": "Marcus Newcomb Middle School",
        "district": "Pemberton Township School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341281003398",
    },
    {
        "school": "Isaiah Haines",
        "district": "Pemberton Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341281003399",
    },
    {
        "school": "Dual Language School",
        "district": "Perth Amboy Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293003417",
    },
    {
        "school": "Betty Maddalena Early Learning Center",
        "district": "West Orange Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341761003416",
    },
    {
        "school": "Alternative School at Levitt",
        "district": "Willingboro Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "341800003421",
    },
    {
        "school": "Simon Youth Academy",
        "district": "Union County Vocational-Technical School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "341804003397",
    },
    {
        "school": "CIEN AGUAS INTERNATIONAL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001050",
    },
    {
        "school": "INTERNATIONAL SCHOOL AT MESA DEL SOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001056",
    },
    {
        "school": "WILLIAM W &  JOSEPHINE DORN CHARTER  COMMUNITY SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001087",
    },
    {
        "school": "COYOTE WILLOW FAMILY SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350006001133",
    },
    {
        "school": "ALTURA PREPARATORY SCHOOL",
        "district": "ALTURA PREPARATORY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350017801138",
    },
    {
        "school": "HOZHO ACADEMY",
        "district": "HOZHO ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350017901136",
    },
    {
        "school": "ALBUQUERQUE COLLEGIATE CHARTER SCHOOL",
        "district": "ALBUQUERQUE COLLEGIATE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018101134",
    },
    {
        "school": "MIMBRES VALLEY HIGH SCHOOL",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069001140",
    },
    {
        "school": "DEL NORTE ELEMENTARY",
        "district": "GALLUP-MCKINLEY CTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350111001137",
    },
    {
        "school": "MILAGRO MIDDLE",
        "district": "SANTA FE PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350237001139",
    },
    {
        "school": "MS 297",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007706602",
    },
    {
        "school": "IS 584",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 7",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008406613",
    },
    {
        "school": "PS 583",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 8",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008506614",
    },
    {
        "school": "PS 376",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009906626",
    },
    {
        "school": "PS 377",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #27",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012306606",
    },
    {
        "school": "PS 469-BRONX SCHOOL FOR CONTINUOUS LEARNING (THE)",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013506605",
    },
    {
        "school": "PS 889",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015306618",
    },
    {
        "school": "MS 890",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #22",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360015306619",
    },
    {
        "school": "WHIN MUSIC COMMUNITY CHARTER SCHOOL",
        "district": "WHIN MUSIC COMMUNITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360115506608",
    },
    {
        "school": "SOUTH BRONX CLASSICAL CHARTER SCHOOL IV",
        "district": "SOUTH BRONX CLASSICAL CHARTER SCHOOL IV",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360115606620",
    },
    {
        "school": "BRONX CHARTER SCHOOL FOR EXCELLENCE 3",
        "district": "BRONX CHARTER SCHOOL FOR EXCELLENCE 3",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360115706601",
    },
    {
        "school": "LEGACY COLLEGE PREPARATORY CHARTER SCHOOL",
        "district": "LEGACY COLLEGE PREPARATORY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360115806600",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 6",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-HARLEM 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360115906610",
    },
    {
        "school": "BROOKLYN EMERGING LEADERS ACADEMY CHARTER SCHOOL",
        "district": "BROOKLYN EMERGING LEADERS ACADEMY CHARTER SCHOOL",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360116006622",
    },
    {
        "school": "NYC AUTISM CHARTER SCHOOL BRONX",
        "district": "NYC AUTISM CHARTER SCHOOL BRONX",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360116106615",
    },
    {
        "school": "NEW VISIONS CHARTER HIGH SCHOOL FOR THE HUMANITIES IV",
        "district": "NEW VISIONS CHARTER HIGH SCHOOL FOR THE HUMANITIES IV",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360116206621",
    },
    {
        "school": "ELMWOOD VILLAGE CHARTER SCHOOL HERTEL",
        "district": "ELMWOOD VILLAGE CHARTER SCHOOL HERTEL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360116306604",
    },
    {
        "school": "FORTE PREPARATORY ACADEMY CHARTER SCHOOL",
        "district": "FORTE PREPARATORY ACADEMY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360116406623",
    },
    {
        "school": "BRILLA VERITAS CHARTER SCHOOL",
        "district": "BRILLA VERITAS CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360116506617",
    },
    {
        "school": "HEBREW LANGUAGE ACADEMY CHARTER SCHOOL 2",
        "district": "HEBREW LANGUAGE ACADEMY CHARTER SCHOOL 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360116606625",
    },
    {
        "school": "SUCCESS ACADEMY CHARTER SCHOOL-HUDSON YARDS",
        "district": "SUCCESS ACADEMY CHARTER SCHOOL-HUDSON YARDS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360116706607",
    },
    {
        "school": "EXPLORATION ELE CS - SCIENCE-TECHNOL",
        "district": "EXPLORATION ELE CS - SCIENCE-TECHNOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360116806616",
    },
    {
        "school": "EDMUND J O'NEAL MIDDLE SCHOOL OF EXCELLENCE",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246006624",
    },
    {
        "school": "RIVERSIDE ACADEMY HIGH SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585006609",
    },
    {
        "school": "LEWIS J BENNETT HIGH SCHOOL OF INNOVATIVE TECHNOLGY",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585006611",
    },
    {
        "school": "CORTLAND JUNIOR HIGH SCHOOL",
        "district": "CORTLAND CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360846006612",
    },
    {
        "school": "WASHINGTON CO CORRECTIONAL FACILITY",
        "district": "HUDSON FALLS CENTRAL SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "361497006589",
    },
    {
        "school": "WILLIAM FLOYD LEARNING CENTER",
        "district": "WILLIAM FLOYD UNION FREE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "361869006627",
    },
    {
        "school": "MARY K VOLLMER ELEMENTARY SCHOOL",
        "district": "RUSH-HENRIETTA CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362517006599",
    },
    {
        "school": "Innovation Early College High",
        "district": "Pitt County Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001203476",
    },
    {
        "school": "Ashe County Early College High",
        "district": "Ashe County Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370021003474",
    },
    {
        "school": "Bladen Early College",
        "district": "Bladen County Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370039003477",
    },
    {
        "school": "Davidson Charter Academy: CFA",
        "district": "Davidson Charter Academy: CFA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042203448",
    },
    {
        "school": "Carolina Charter Academy",
        "district": "Carolina Charter Academy: CFA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042303461",
    },
    {
        "school": "East Voyager Academy of Charlotte",
        "district": "East Voyager Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042403453",
    },
    {
        "school": "The Experiential School of Greensboro",
        "district": "The Experiential School of Greensboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042503458",
    },
    {
        "school": "Monroe Charter Academy",
        "district": "Monroe Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042603456",
    },
    {
        "school": "Appalachian Academy at Middle Fork",
        "district": "Appalachian State U Academy Middle Fork",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042703457",
    },
    {
        "school": "Raleigh Oak Charter",
        "district": "Raleigh Oak Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042803452",
    },
    {
        "school": "D.C. Virgo Preparatory Academy",
        "district": "D.C. Virgo Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042903455",
    },
    {
        "school": "Johnston Charter Academy",
        "district": "Johnston Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370043003449",
    },
    {
        "school": "Moss Street Partnership School",
        "district": "Moss Street Partnership School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370043103447",
    },
    {
        "school": "Moore Montessori Community School",
        "district": "Moore Montessori Community School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370043203460",
    },
    {
        "school": "Rolesville Charter Academy",
        "district": "Rolesville Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370043303454",
    },
    {
        "school": "Essie Mae Kiser Foxx Charter",
        "district": "Essie Mae Kiser Foxx Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370043403446",
    },
    {
        "school": "Next Generation Academy",
        "district": "Next Generation Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370043503450",
    },
    {
        "school": "Ascend Leadership Academy: Lee County",
        "district": "Ascend Leadership Academy: Lee County",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370043803459",
    },
    {
        "school": "Apprentice Academy High School",
        "district": "Apprentice Academy HS of NC",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370043903463",
    },
    {
        "school": "Mountain Island Day Community Charter",
        "district": "Mountain Island Day Community Charter Sc",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370044103465",
    },
    {
        "school": "Southside Ashpole Elementary",
        "district": "Innovative School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370044203484",
    },
    {
        "school": "Mountain View Elementary",
        "district": "Burke County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370048003480",
    },
    {
        "school": "West Cabarrus High",
        "district": "Cabarrus County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053003482",
    },
    {
        "school": "Marine Sci. & Tech. Early College HS",
        "district": "Carteret County Public Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370063003486",
    },
    {
        "school": "Granville Academy",
        "district": "Granville County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370180003483",
    },
    {
        "school": "McDowell Academy for Innovation",
        "district": "McDowell County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370294003487",
    },
    {
        "school": "Villa Heights Elementary",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003466",
    },
    {
        "school": "Charlotte East Language Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003467",
    },
    {
        "school": "Wilson STEM Academy",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003468",
    },
    {
        "school": "CITI High School",
        "district": "Nash-Rocky Mount Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370327003475",
    },
    {
        "school": "Surf City Elementary",
        "district": "Pender County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357003478",
    },
    {
        "school": "Surf City Middle",
        "district": "Pender County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370357003479",
    },
    {
        "school": "Roanoke Rapids Early College High",
        "district": "Roanoke Rapids City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370390003481",
    },
    {
        "school": "West Rowan Elementary",
        "district": "Rowan-Salisbury Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405003464",
    },
    {
        "school": "Stanly County Virtual Education",
        "district": "Stanly County Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432003485",
    },
    {
        "school": "SCORE Academy",
        "district": "Wake County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370472003444",
    },
    {
        "school": "Connections Academy",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370472003445",
    },
    {
        "school": "Apex Friendship Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003470",
    },
    {
        "school": "Bryan Road Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003471",
    },
    {
        "school": "South Garner High",
        "district": "Wake County Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003472",
    },
    {
        "school": "Buckhorn Creek Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003473",
    },
    {
        "school": "P S BERG ELEMENTARY SCHOOL",
        "district": "DICKINSON 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380003800895",
    },
    {
        "school": "RICHARDTON-TAYLOR ELEMENTARY SCHOOL",
        "district": "RICHARDTON-TAYLOR 34",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380004800893",
    },
    {
        "school": "MAPLE VALLEY ELEMENTARY SCHOOL",
        "district": "MAPLE VALLEY 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381202000889",
    },
    {
        "school": "SUNDALE COLONY HIGH SCHOOL",
        "district": "MILNOR 2",
        "level": "High",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381293000896",
    },
    {
        "school": "MISSOURI RIDGE MIDDLE SCHOOL",
        "district": "WILLIAMS COUNTY 8",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381376000892",
    },
    {
        "school": "WARWICK MIDDLE SCHOOL",
        "district": "WARWICK 29",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381926000890",
    },
    {
        "school": "Monroe Junior High School",
        "district": "Monroe Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390009405926",
    },
    {
        "school": "Southwest Ohio Preparatory School",
        "district": "Southwest Ohio Preparatory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390159005956",
    },
    {
        "school": "Kids Care Elementary",
        "district": "Kids Care Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390159105906",
    },
    {
        "school": "Euclid Preparatory School",
        "district": "Euclid Preparatory School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390159205911",
    },
    {
        "school": "United Preparatory Academy East",
        "district": "United Preparatory Academy East",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390159305929",
    },
    {
        "school": "Citizens Leadership Academy East",
        "district": "Citizens Leadership Academy East",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390159405904",
    },
    {
        "school": "Liberty High School",
        "district": "Liberty High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390159505936",
    },
    {
        "school": "South Columbus Preparatory Academy",
        "district": "South Columbus Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390159605913",
    },
    {
        "school": "Orchard Park Academy",
        "district": "Orchard Park Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390159705961",
    },
    {
        "school": "Reach Center Summit Lake",
        "district": "Akron City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434805924",
    },
    {
        "school": "APS Preschool",
        "district": "Akron City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434805957",
    },
    {
        "school": "Barberton Preschool",
        "district": "Barberton City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435305935",
    },
    {
        "school": "Glenview Center for Childcare and Learning",
        "district": "Bay Village City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390435405919",
    },
    {
        "school": "Leap Academy at North Fairmount",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505907",
    },
    {
        "school": "Spencer Center for Gifted and Exceptional Students",
        "district": "Cincinnati Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505925",
    },
    {
        "school": "Rising Stars at Vine",
        "district": "Cincinnati Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505932",
    },
    {
        "school": "Rising Stars at Ezzard Charles",
        "district": "Cincinnati Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505939",
    },
    {
        "school": "Rising Stars at Carthage",
        "district": "Cincinnati Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505955",
    },
    {
        "school": "Bard High Early College Cleveland East Campus",
        "district": "Cleveland Municipal",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805917",
    },
    {
        "school": "John Adams College & Career Academy",
        "district": "Cleveland Municipal",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805920",
    },
    {
        "school": "Campus International High School",
        "district": "Cleveland Municipal",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805946",
    },
    {
        "school": "Rhodes College and Career Academy",
        "district": "Cleveland Municipal",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805947",
    },
    {
        "school": "Davis Aerospace & Maritime High School",
        "district": "Cleveland Municipal",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805950",
    },
    {
        "school": "Rhodes School of Environmental Studies",
        "district": "Cleveland Municipal",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805951",
    },
    {
        "school": "Early Childhood Education and Family Center",
        "district": "Columbus City School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438005934",
    },
    {
        "school": "G. Tyree Learning School",
        "district": "Columbus City School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438005942",
    },
    {
        "school": "Miami School",
        "district": "Hamilton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390441005959",
    },
    {
        "school": "Early Childhood Center 2",
        "district": "Lancaster City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442005905",
    },
    {
        "school": "Lima HS - Preschool",
        "district": "Lima City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442205952",
    },
    {
        "school": "Massillon Preschool",
        "district": "Massillon City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443505893",
    },
    {
        "school": "Headstart Eastland",
        "district": "Newark City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444505912",
    },
    {
        "school": "South Preschool Center located at Starlight School",
        "district": "New Philadelphia City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444805903",
    },
    {
        "school": "Ranger High Tech Academy",
        "district": "North Ridgeville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390445305909",
    },
    {
        "school": "Rocky River Early Childhood Center at Beach School",
        "district": "Rocky River City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390447005901",
    },
    {
        "school": "Stiles Family Center",
        "district": "South-Western City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448005923",
    },
    {
        "school": "TPS Mosaic Ministries Preschool",
        "district": "Toledo City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449005910",
    },
    {
        "school": "Mayfair",
        "district": "Toledo City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449005915",
    },
    {
        "school": "Summit",
        "district": "Toledo City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449005941",
    },
    {
        "school": "Westwood Elementary School",
        "district": "Warrensville Heights City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390450005892",
    },
    {
        "school": "Wilson School",
        "district": "Youngstown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451605918",
    },
    {
        "school": "Volney Rogers School",
        "district": "Youngstown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451605944",
    },
    {
        "school": "Kirkmere School",
        "district": "Youngstown City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451605948",
    },
    {
        "school": "Harold Lewis Center School",
        "district": "Marysville Exempted Village",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390454705890",
    },
    {
        "school": "Perrysburg Preschool",
        "district": "Perrysburg Exempted Village",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455805896",
    },
    {
        "school": "Hull Prairie Intermediate School",
        "district": "Perrysburg Exempted Village",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390455805937",
    },
    {
        "school": "Fairfield Compass Elementary",
        "district": "Fairfield City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390461005930",
    },
    {
        "school": "CNE Early Childhood Academy",
        "district": "Clermont Northeastern Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390463205916",
    },
    {
        "school": "Richmond Heights Middle School",
        "district": "Richmond Heights Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390465905921",
    },
    {
        "school": "Ansonia Pre-School at Ansonia Methodist",
        "district": "Ansonia Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466205953",
    },
    {
        "school": "Arcanum Early Learning Center",
        "district": "Arcanum-Butler Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466305949",
    },
    {
        "school": "Mississinawa Valley Preschool",
        "district": "Mississinawa Valley Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390466705897",
    },
    {
        "school": "Olentangy Shanahan Preschool",
        "district": "Olentangy Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605933",
    },
    {
        "school": "Pickerington Alternative School",
        "district": "Pickerington Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390468905931",
    },
    {
        "school": "Hamilton Local Preschool",
        "district": "Hamilton Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469505898",
    },
    {
        "school": "Gahanna- Jefferson  Clark Hall",
        "district": "Gahanna-Jefferson City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390469605958",
    },
    {
        "school": "Ferguson Hall Freshman School",
        "district": "Beavercreek City",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390472405960",
    },
    {
        "school": "Summit Station Preschool",
        "district": "Licking Heights Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480005891",
    },
    {
        "school": "Southwest Licking Early Learning Center",
        "district": "Southwest Licking Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390480405895",
    },
    {
        "school": "East Elementary Annex",
        "district": "Morgan Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390487705954",
    },
    {
        "school": "Maysville O TAGS",
        "district": "Maysville Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488505943",
    },
    {
        "school": "Clear Fork Valley Preschool",
        "district": "Clear Fork Valley Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390494105894",
    },
    {
        "school": "Mason Central",
        "district": "Mason City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390504505899",
    },
    {
        "school": "Mercer County Head Start",
        "district": "Celina City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003005908",
    },
    {
        "school": "DOVE SCIENCE ACADEMY TULSA HS",
        "district": "DOVE SCHOOLS OF TULSA",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400075302851",
    },
    {
        "school": "TULSA SCHL ARTS SCIENCES MS",
        "district": "SCHL ARTS/SCI (CHARTER)",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400077402860",
    },
    {
        "school": "TULSA SCHL ARTS SCIENCES HS",
        "district": "SCHL ARTS/SCI (CHARTER)",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400077402862",
    },
    {
        "school": "SANTA FE SOUTH SPERO ES",
        "district": "SANTA FE SOUTH (CHARTER)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079602842",
    },
    {
        "school": "SANTA FE SOUTH EARLY CHILDHOOD",
        "district": "SANTA FE SOUTH (CHARTER)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079602848",
    },
    {
        "school": "OLUSTEE-ELDORADO HS",
        "district": "OLUSTEE-ELDORADO",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079702843",
    },
    {
        "school": "OLUSTEE-ELDORADO ES",
        "district": "OLUSTEE-ELDORADO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079702845",
    },
    {
        "school": "DAVIDSON ES",
        "district": "DAVIDSON",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079802840",
    },
    {
        "school": "DOVE SCIENCE ACADEMY MS",
        "district": "DOVE SCIENCE ACADEMY (CHARTER)",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079902856",
    },
    {
        "school": "DOVE SCIENCE ACADEMY ES",
        "district": "DOVE SCIENCE ACADEMY (CHARTER)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079902857",
    },
    {
        "school": "DOVE SCIENCE ACADEMY HS",
        "district": "DOVE SCIENCE ACADEMY (CHARTER)",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079902858",
    },
    {
        "school": "EPIC BLENDED CHARTER OKC ES",
        "district": "EPIC BLENDED LEARNING CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080002863",
    },
    {
        "school": "EPIC BLENDED CHARTER TULSA ES",
        "district": "EPIC BLENDED LEARNING CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080002864",
    },
    {
        "school": "EPIC BLENDED CHARTER TULSA MS",
        "district": "EPIC BLENDED LEARNING CHARTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080002865",
    },
    {
        "school": "EPIC BLENDED CHARTER OKC HS",
        "district": "EPIC BLENDED LEARNING CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080002866",
    },
    {
        "school": "EPIC BLENDED CHARTER OKC MS",
        "district": "EPIC BLENDED LEARNING CHARTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080002867",
    },
    {
        "school": "EPIC BLENDED CHARTER TULSA HS",
        "district": "EPIC BLENDED LEARNING CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080002869",
    },
    {
        "school": "AGRA JHS",
        "district": "AGRA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400255002852",
    },
    {
        "school": "BRIDGE CREEK EARLY CHILDHOOD",
        "district": "BRIDGE CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400540002844",
    },
    {
        "school": "BRIDGE CREEK IES",
        "district": "BRIDGE CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400540002846",
    },
    {
        "school": "TIMBER RIDGE ES",
        "district": "BROKEN ARROW",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400549002849",
    },
    {
        "school": "NORTHWEST ES",
        "district": "JENKS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401572002859",
    },
    {
        "school": "CLINTON WEST ES",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002854",
    },
    {
        "school": "TUTTLE EARLY CHILDHOOD CENTER",
        "district": "TUTTLE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403042002839",
    },
    {
        "school": "ELLEN OCHOA ES",
        "district": "UNION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403060002850",
    },
    {
        "school": "WOODWARD MS NORTH CAMPUS",
        "district": "WOODWARD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403318002841",
    },
    {
        "school": "Frontier Charter Academy",
        "district": "Gervais SD 1",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410001501859",
    },
    {
        "school": "Desert Sky Montessori",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001860",
    },
    {
        "school": "Chinese Language Immersion School",
        "district": "Eugene SD 4J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410474001858",
    },
    {
        "school": "Roberto Clemente CS",
        "district": "Roberto Clemente CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420006807636",
    },
    {
        "school": "Westinghouse Arts Academy CS",
        "district": "Westinghouse Arts Academy CS",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420089607608",
    },
    {
        "school": "Easton Arts Academy Elementary CS",
        "district": "Easton Arts Academy Elementary CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420089707625",
    },
    {
        "school": "Insight PA Cyber CS",
        "district": "Insight PA Cyber CS",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420089807635",
    },
    {
        "school": "Building 21 Allentown",
        "district": "Allentown City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228007623",
    },
    {
        "school": "Jackson Early Childhood Center",
        "district": "Allentown City SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420228007624",
    },
    {
        "school": "Neil A Armstrong MS",
        "district": "Bristol Township SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420423007633",
    },
    {
        "school": "Muse El Sch",
        "district": "Canon-McMillan SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420489007614",
    },
    {
        "school": "Gordon Early Literacy Center",
        "district": "Coatesville Area SD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420624007627",
    },
    {
        "school": "Coatesville Intermediate HS",
        "district": "Coatesville Area SD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420624007628",
    },
    {
        "school": "Coatesville Area SD Cyber Academy",
        "district": "Coatesville Area SD",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420624007630",
    },
    {
        "school": "Strong Vincent MS",
        "district": "Erie City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930007609",
    },
    {
        "school": "East MS",
        "district": "Erie City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930007610",
    },
    {
        "school": "Erie HS",
        "district": "Erie City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420930007612",
    },
    {
        "school": "Greater Johnstown El Sch",
        "district": "Greater Johnstown SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421095007613",
    },
    {
        "school": "George Jr Republic El Sch",
        "district": "Grove City Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421122007606",
    },
    {
        "school": "Jeannette HS",
        "district": "Jeannette City SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421233007617",
    },
    {
        "school": "Leechburg Area MS",
        "district": "Leechburg Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421347007618",
    },
    {
        "school": "Alloway Creek El Sch",
        "district": "Littlestown Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421398007637",
    },
    {
        "school": "Mahanoy Area JSHS",
        "district": "Mahanoy Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421443007626",
    },
    {
        "school": "Doe Run El Sch",
        "district": "Manheim Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421455007632",
    },
    {
        "school": "Twin Rivers El Sch",
        "district": "McKeesport Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421494007615",
    },
    {
        "school": "Francis McClure El Sch",
        "district": "McKeesport Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421494007616",
    },
    {
        "school": "Mohawk JHS",
        "district": "Mohawk Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421554007605",
    },
    {
        "school": "Montour El Sch",
        "district": "Montour SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421572007607",
    },
    {
        "school": "Manavon El Sch",
        "district": "Phoenixville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421905007620",
    },
    {
        "school": "Phoenixville Early Learning Ctr",
        "district": "Phoenixville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421905007622",
    },
    {
        "school": "6th Grade Center",
        "district": "Quakertown Community SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421989007631",
    },
    {
        "school": "Iron Forge El Sch",
        "district": "South Middleton SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422205007629",
    },
    {
        "school": "Tussey Mountain MS",
        "district": "Tussey Mountain SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422397007611",
    },
    {
        "school": "Waynesboro Area MS",
        "district": "Waynesboro Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422511007619",
    },
    {
        "school": "Edgar Fahs Smith STEAM Academy",
        "district": "York City SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422682007621",
    },
    {
        "school": "AF Providence Mayoral Middle",
        "district": "Achievement First Rhode Island",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440002100515",
    },
    {
        "school": "Woonsocket Middle at Hamlet",
        "district": "Woonsocket",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440120000516",
    },
    {
        "school": "Woonsocket Middle @ Villa Nova",
        "district": "Woonsocket",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440120000517",
    },
    {
        "school": "Lakes and Bridges Charter School",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101692",
    },
    {
        "school": "Bettis Preparatory Leadership Academy",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101695",
    },
    {
        "school": "East Link Academy",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101696",
    },
    {
        "school": "Polaris Tech",
        "district": "SC Public Charter School District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101698",
    },
    {
        "school": "Virtus Academy of South Carolina",
        "district": "Charter Institute at Erskine",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901699",
    },
    {
        "school": "Belton Preparatory Academy",
        "district": "Charter Institute at Erskine",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901700",
    },
    {
        "school": "The Montessori School of Camden",
        "district": "Charter Institute at Erskine",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901701",
    },
    {
        "school": "Blue Sky Colony - 04",
        "district": "Milbank School District 25-4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460000201390",
    },
    {
        "school": "Dawson Colony School - 20",
        "district": "Bon Homme School District 04-2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460740001393",
    },
    {
        "school": "Whole Grade Sharing with Burke - 04",
        "district": "South Central 26-5",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460767001394",
    },
    {
        "school": "Falls Academy - 08",
        "district": "West Central School District 49-7",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "463171001389",
    },
    {
        "school": "iSucceed - 92",
        "district": "Northwestern Area School District 56-7",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465175001391",
    },
    {
        "school": "Parkston Virtual School - 92",
        "district": "Parkston School District 33-3",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "465430001395",
    },
    {
        "school": "Stagebarn Middle School - 10",
        "district": "Meade School District 46-1",
        "level": "Middle",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "466993001392",
    },
    {
        "school": "Power Center Academy Elementary - Southeast",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802481",
    },
    {
        "school": "Southwest Early College High School",
        "district": "Shelby County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802483",
    },
    {
        "school": "Memphis School of Excellence Elementary",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802485",
    },
    {
        "school": "Kaleidoscope School of Memphis",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802486",
    },
    {
        "school": "Lakeland Middle Preparatory School",
        "district": "Lakeland",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015402476",
    },
    {
        "school": "Bluff City High School",
        "district": "Tennessee State Board of Education",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015502478",
    },
    {
        "school": "Marion Virtual High School",
        "district": "Marion County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470264002477",
    },
    {
        "school": "KIPP Nashville College Prep Elementary",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002488",
    },
    {
        "school": "Rocky Fork Middle School",
        "district": "Rutherford County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002480",
    },
    {
        "school": "Springdale Elementary School",
        "district": "Wilson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455002479",
    },
    {
        "school": "MOE AND GENE JOHNSON H S",
        "district": "HAYS CISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001013567",
    },
    {
        "school": "UHLAND EL",
        "district": "HAYS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480001013599",
    },
    {
        "school": "UPLIFT GRAND H S",
        "district": "UPLIFT EDUCATION",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013588",
    },
    {
        "school": "THE LEADERSHIP ACADEMY",
        "district": "CUMBERLAND ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003413578",
    },
    {
        "school": "JHW INSPIRE ACADEMY - BELL COUNTY",
        "district": "INSPIRE ACADEMIES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480005313600",
    },
    {
        "school": "MUNDAY",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007113669",
    },
    {
        "school": "THE VARNETT SCHOOL SOUTHEAST",
        "district": "THE VARNETT PUBLIC SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007313635",
    },
    {
        "school": "JUBILEE LEADERSHIP ACADEMY",
        "district": "JUBILEE ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017913607",
    },
    {
        "school": "A+ SECONDARY SCHOOL",
        "district": "A+ ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020313579",
    },
    {
        "school": "PREMIER H S SAN ANTONIO - WEST",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020713657",
    },
    {
        "school": "YES PREP - NORTHLINE",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020913603",
    },
    {
        "school": "IDEA BRACKENRIDGE ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113569",
    },
    {
        "school": "IDEA RIO GRANDE CITY COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113598",
    },
    {
        "school": "IDEA TRES LAGOS ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113601",
    },
    {
        "school": "IDEA RIO GRANDE CITY ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113608",
    },
    {
        "school": "IDEA EWING HALSELL COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113611",
    },
    {
        "school": "IDEA BRACKENRIDGE COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113630",
    },
    {
        "school": "IDEA EWING HALSELL ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113646",
    },
    {
        "school": "IDEA NAJIM ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113653",
    },
    {
        "school": "IDEA NAJIM COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113660",
    },
    {
        "school": "IDEA TRES LAGOS COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113673",
    },
    {
        "school": "GOLDEN RULE SCHOOLS INC - WILMER",
        "district": "GOLDEN RULE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480023713576",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY EXCELLENCE",
        "district": "SCHOOL OF SCIENCE AND TECHNOLOGY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480025813571",
    },
    {
        "school": "BASIS SAN ANTONIO PRI- MEDICAL CENTER CAMPUS",
        "district": "BASIS TEXAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143813659",
    },
    {
        "school": "LEGACY SCHOOL OF SPORT SCIENCES",
        "district": "LEGACY SCHOOL OF SPORT SCIENCES",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145913637",
    },
    {
        "school": "ETOILE ACADEMY CHARTER SCHOOL",
        "district": "ETOILE ACADEMY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480146013614",
    },
    {
        "school": "VALOR SOUTH AUSTIN",
        "district": "VALOR PUBLIC SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480146113593",
    },
    {
        "school": "BRIDGEWAY PREPARATORY ACADEMY",
        "district": "BRIDGEWAY PREPARATORY ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480146213560",
    },
    {
        "school": "YELLOWSTONE COLLEGE PREPARATORY",
        "district": "YELLOWSTONE COLLEGE PREPARATORY",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480146313629",
    },
    {
        "school": "WELLBORN MIDDLE",
        "district": "COLLEGE STATION ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735013650",
    },
    {
        "school": "WALSH EL",
        "district": "ALEDO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480778013642",
    },
    {
        "school": "JENNY PRESTON EL",
        "district": "ALLEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480789013566",
    },
    {
        "school": "DR RONALD E MCNAIR JH",
        "district": "ALVIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809013577",
    },
    {
        "school": "BOB AND BETTY NELSON EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809013606",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "BARBERS HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480945013631",
    },
    {
        "school": "THE JOE BARNHART ACADEMY",
        "district": "BEEVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480972013625",
    },
    {
        "school": "BRENHAM EARLY CHILDHOOD LEARNING CENTER",
        "district": "BRENHAM ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481128013649",
    },
    {
        "school": "PINNACLE INT",
        "district": "CANYON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481281013597",
    },
    {
        "school": "ROUGHRIDER ACADEMY",
        "district": "CENTER ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481332013661",
    },
    {
        "school": "COTTONWOOD EL",
        "district": "CLEVELAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481437013664",
    },
    {
        "school": "CANYON RANCH EL",
        "district": "COPPELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481521013648",
    },
    {
        "school": "DRANE EARLY LEARNING CENTER",
        "district": "CORSICANA ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481533013632",
    },
    {
        "school": "NOBLE REED",
        "district": "CRANDALL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481551013634",
    },
    {
        "school": "TBD EARLY CHILDHOOD CENTER",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013617",
    },
    {
        "school": "NEWTON COLLINS EL",
        "district": "DEL VALLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481662013609",
    },
    {
        "school": "LITTLE EAGLES EARLY LEARNING CENTER",
        "district": "DESOTO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686013612",
    },
    {
        "school": "KATHERINE JOHNSON TECHNOLOGY MAGNET ACADEMY",
        "district": "DESOTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481686013644",
    },
    {
        "school": "EUGENE 'GENE' KRANZ J H",
        "district": "DICKINSON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481707013595",
    },
    {
        "school": "TRADITION EL",
        "district": "EAST CENTRAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785013627",
    },
    {
        "school": "PRE/K FOR SA - EAST CENTRAL ISD",
        "district": "EAST CENTRAL ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785013636",
    },
    {
        "school": "YOUNG WOMEN'S STEAM RESEARCH & PREPARATORY ACADEMY",
        "district": "EL PASO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830013596",
    },
    {
        "school": "KATHERINE G JOHNSON STEM ACADEMY",
        "district": "GREENVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482172013582",
    },
    {
        "school": "HEMPSTEAD ALTERNATIVE LEARNING CENTER",
        "district": "HEMPSTEAD ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482292013618",
    },
    {
        "school": "HIDALGO EARLY START ACADEMY",
        "district": "HIDALGO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482310013583",
    },
    {
        "school": "FALCON RIDGE EL",
        "district": "HUFFMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482382013573",
    },
    {
        "school": "WORTHAM OAKS EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499013564",
    },
    {
        "school": "ESCONDIDO EL",
        "district": "JUDSON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482499013662",
    },
    {
        "school": "CAMPBELL EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517013559",
    },
    {
        "school": "ADAMS J H",
        "district": "KATY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517013655",
    },
    {
        "school": "NEW H S #14",
        "district": "KATY ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517013663",
    },
    {
        "school": "MS055",
        "district": "KILLEEN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566013626",
    },
    {
        "school": "MAUDE MOORE WOOD EL",
        "district": "KILLEEN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566013633",
    },
    {
        "school": "HOFIUS INT",
        "district": "KLEIN ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574013590",
    },
    {
        "school": "MONTA JANE AKIN EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703013585",
    },
    {
        "school": "RANCHO SIENNA EL",
        "district": "LIBERTY HILL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482742013570",
    },
    {
        "school": "JUDSON STEAM ACADEMY",
        "district": "LONGVIEW ISD",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482811013580",
    },
    {
        "school": "BRAMLETTE STEAM ACADEMY",
        "district": "LONGVIEW ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482811013615",
    },
    {
        "school": "MAGNOLIA INT",
        "district": "MAGNOLIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874013568",
    },
    {
        "school": "BEAR BRANCH INT",
        "district": "MAGNOLIA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482874013624",
    },
    {
        "school": "DR SARAH JANDRUCKO ACADEMY FOR EARLY LEARNERS",
        "district": "MANSFIELD ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892013584",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "MCALLEN ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482967013592",
    },
    {
        "school": "MEDINA VALLEY LOMA ALTA MIDDLE",
        "district": "MEDINA VALLEY ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483006013652",
    },
    {
        "school": "LUCKEY RANCH EL",
        "district": "MEDINA VALLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483006013658",
    },
    {
        "school": "GENERAL TOMMY FRANKS EL",
        "district": "MIDLAND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057013622",
    },
    {
        "school": "MISSION EARLY LEARNING",
        "district": "MISSION CISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483104013565",
    },
    {
        "school": "BROOKWOOD FOREST EL",
        "district": "NEW CANEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240013619",
    },
    {
        "school": "LEO ADAMS MIDDLE",
        "district": "NORTHWEST ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318013574",
    },
    {
        "school": "LIZZIE CURTIS EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318013668",
    },
    {
        "school": "ODEM EL",
        "district": "ODEM-EDROY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483336013581",
    },
    {
        "school": "NEW IS",
        "district": "PASADENA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483432013562",
    },
    {
        "school": "NEW EL",
        "district": "PLANO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483510013589",
    },
    {
        "school": "RALPH AND MARY LYNN BOYER EL",
        "district": "PROSPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013604",
    },
    {
        "school": "JIM SPRADLEY EL",
        "district": "PROSPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013647",
    },
    {
        "school": "MARK TWAIN DUAL LANGUAGE ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013563",
    },
    {
        "school": "GONZALES EARLY CHILDHOOD CAMPUS",
        "district": "SAN ANTONIO ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013605",
    },
    {
        "school": "STEELE MONTESSORI ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013656",
    },
    {
        "school": "CAST TECH H S",
        "district": "SAN ANTONIO ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013665",
    },
    {
        "school": "WILLIAM F BARNETT EL",
        "district": "SANTA FE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483927013640",
    },
    {
        "school": "SLATON ISD DAEP",
        "district": "SLATON ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484044013610",
    },
    {
        "school": "COLONEL MENCHACA EARLY CHILDHOOD CENTER",
        "district": "SOUTHSIDE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484092013586",
    },
    {
        "school": "CAST STEM H S",
        "district": "SOUTHWEST ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484095013671",
    },
    {
        "school": "GILBERT WILLIE SR EL",
        "district": "TERRELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484245013575",
    },
    {
        "school": "DR BRUCE WOOD EL",
        "district": "TERRELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484245013591",
    },
    {
        "school": "J W LONG EL",
        "district": "TERRELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484245013672",
    },
    {
        "school": "TOMBALL STAR ACADEMY",
        "district": "TOMBALL ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296013654",
    },
    {
        "school": "TYLER ISD EARLY COLLEGE H S",
        "district": "TYLER ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484347013613",
    },
    {
        "school": "ALVIN V ANDERSON RISE ACADEMY",
        "district": "TYLER ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484347013616",
    },
    {
        "school": "SAN ISIDRO EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365013561",
    },
    {
        "school": "ELIAS HERRERA MIDDLE",
        "district": "UNITED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365013621",
    },
    {
        "school": "RAUL PERALES MIDDLE",
        "district": "UNITED ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365013639",
    },
    {
        "school": "FREEDOM EL",
        "district": "UNITED ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365013670",
    },
    {
        "school": "FLORES EL",
        "district": "UVALDE CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484372013638",
    },
    {
        "school": "VEGA J H",
        "district": "VEGA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484398013641",
    },
    {
        "school": "TURNER PREKINDERGARTEN ACADEMY",
        "district": "WAXAHACHIE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473013666",
    },
    {
        "school": "WYLIE EAST EL",
        "district": "WYLIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484650013623",
    },
    {
        "school": "PARKLAND PRE K CENTER",
        "district": "YSLETA ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668013620",
    },
    {
        "school": "Cedar Valley High",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001538",
    },
    {
        "school": "Lakeview Academy Campus 2",
        "district": "Lakeview Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004301544",
    },
    {
        "school": "Farmington High",
        "district": "Davis District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001537",
    },
    {
        "school": "Mountain Creek Middle School",
        "district": "Jordan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001540",
    },
    {
        "school": "Bluffdale Middle School #1",
        "district": "Jordan District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001541",
    },
    {
        "school": "Ridge View Elementary",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001542",
    },
    {
        "school": "Mountain Point Elementary",
        "district": "Jordan District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001543",
    },
    {
        "school": "Albert D. Lawton School",
        "district": "Essex-Westford Educational Community Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039500115",
    },
    {
        "school": "Hiawatha School",
        "district": "Essex-Westford Educational Community Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039500117",
    },
    {
        "school": "Essex High School",
        "district": "Essex-Westford Educational Community Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039500120",
    },
    {
        "school": "Essex Middle School",
        "district": "Essex-Westford Educational Community Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039500121",
    },
    {
        "school": "The Center for Technology - Essex",
        "district": "Essex-Westford Educational Community Unified School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500039500122",
    },
    {
        "school": "Essex Elementary School",
        "district": "Essex-Westford Educational Community Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039500123",
    },
    {
        "school": "Westford Elementary School",
        "district": "Essex-Westford Educational Community Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039500373",
    },
    {
        "school": "Founders Memorial School",
        "district": "Essex-Westford Educational Community Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039500403",
    },
    {
        "school": "Summit Street School",
        "district": "Essex-Westford Educational Community Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039500452",
    },
    {
        "school": "Thomas Fleming School",
        "district": "Essex-Westford Educational Community Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039500453",
    },
    {
        "school": "Champlain Valley Union High School",
        "district": "Champlain Valley Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039600082",
    },
    {
        "school": "Charlotte Central School",
        "district": "Champlain Valley Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039600084",
    },
    {
        "school": "Hinesburg Elementary School",
        "district": "Champlain Valley Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039600158",
    },
    {
        "school": "Williston Schools",
        "district": "Champlain Valley Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039600243",
    },
    {
        "school": "Shelburne Community School",
        "district": "Champlain Valley Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039600284",
    },
    {
        "school": "Green Mountain Technology and Career Center",
        "district": "Lamoille North Modified USD #058B",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500039700106",
    },
    {
        "school": "Lamoille Union High School",
        "district": "Lamoille North Modified USD #058B",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039700171",
    },
    {
        "school": "Lamoille Union Middle School",
        "district": "Lamoille North Modified USD #058B",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039700198",
    },
    {
        "school": "Addison Central School",
        "district": "Addison Northwest Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039800001",
    },
    {
        "school": "Ferrisburgh Central School",
        "district": "Addison Northwest Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039800133",
    },
    {
        "school": "Vergennes Union Elementary School",
        "district": "Addison Northwest Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039800349",
    },
    {
        "school": "Vergennes Union High School",
        "district": "Addison Northwest Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039800350",
    },
    {
        "school": "Bellows Free Academy UHSD #48",
        "district": "Maple Run Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039900205",
    },
    {
        "school": "Northwest Technical Center",
        "district": "Maple Run Unified School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500039900215",
    },
    {
        "school": "St. Albans City Elementary School",
        "district": "Maple Run Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039900304",
    },
    {
        "school": "St. Albans Town Educational Center",
        "district": "Maple Run Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039900306",
    },
    {
        "school": "Fairfield Center School",
        "district": "Maple Run Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039900432",
    },
    {
        "school": "Randolph Union High School",
        "district": "Orange Southwest Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040000042",
    },
    {
        "school": "Brookfield School",
        "district": "Orange Southwest Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040000057",
    },
    {
        "school": "Randolph Technical Career Center",
        "district": "Orange Southwest Unified School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500040000098",
    },
    {
        "school": "Braintree School",
        "district": "Orange Southwest Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040000422",
    },
    {
        "school": "Randolph Elementary School",
        "district": "Orange Southwest Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040000443",
    },
    {
        "school": "Eden Central School",
        "district": "Lamoille North Modified USD #058A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040100111",
    },
    {
        "school": "Hyde Park Elementary School",
        "district": "Lamoille North Modified USD #058A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040100161",
    },
    {
        "school": "Johnson Elementary School",
        "district": "Lamoille North Modified USD #058A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040100168",
    },
    {
        "school": "Waterville Elementary School",
        "district": "Lamoille North Modified USD #058A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040100364",
    },
    {
        "school": "Bridport Central School",
        "district": "Addison Central Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040200052",
    },
    {
        "school": "Bingham Memorial School",
        "district": "Addison Central Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040200095",
    },
    {
        "school": "Middlebury ID #4 School",
        "district": "Addison Central Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040200187",
    },
    {
        "school": "Middlebury Union High School",
        "district": "Addison Central Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040200189",
    },
    {
        "school": "Ripton Elementary School",
        "district": "Addison Central Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040200259",
    },
    {
        "school": "Shoreham Elementary School",
        "district": "Addison Central Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040200288",
    },
    {
        "school": "Weybridge Elementary School",
        "district": "Addison Central Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040200376",
    },
    {
        "school": "Salisbury Community School",
        "district": "Addison Central Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040200445",
    },
    {
        "school": "Middlebury Union Middle School",
        "district": "Addison Central Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040200469",
    },
    {
        "school": "Thatcher Brook Primary School",
        "district": "Harwood Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040300130",
    },
    {
        "school": "Fayston Elementary School",
        "district": "Harwood Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040300132",
    },
    {
        "school": "Crossett Brook Middle School",
        "district": "Harwood Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040300146",
    },
    {
        "school": "Harwood Union Middle/High School",
        "district": "Harwood Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040300148",
    },
    {
        "school": "Moretown Elementary School",
        "district": "Harwood Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040300202",
    },
    {
        "school": "Waitsfield Elementary School",
        "district": "Harwood Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040300353",
    },
    {
        "school": "Warren Elementary School",
        "district": "Harwood Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040300360",
    },
    {
        "school": "VSDB HIGH",
        "district": "VSDB-STAUNTON",
        "level": "High",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510005803050",
    },
    {
        "school": "VSDB MIDDLE",
        "district": "VSDB-STAUNTON",
        "level": "Middle",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510005803051",
    },
    {
        "school": "VSDB ELEMENTARY",
        "district": "VSDB-STAUNTON",
        "level": "Elementary",
        "type": "Special education school",
        "state": "VA",
        "nces_id": "510005803052",
    },
    {
        "school": "FERDINAND T. DAY ELEMENTARY",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012003053",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510012003057",
    },
    {
        "school": "WOODROW WILSON INTERMEDIATE",
        "district": "DANVILLE CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510111003055",
    },
    {
        "school": "CAMPUS AT LEE",
        "district": "HAMPTON CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510180003048",
    },
    {
        "school": "GOSHEN POST ELEMENTARY",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225003046",
    },
    {
        "school": "WILLARD INTERMEDIATE SCHOOL",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225003059",
    },
    {
        "school": "GOVERNOR'S STEM ACADEMY AT OSBURN HIGH SCHOOL",
        "district": "MANASSAS CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510236003047",
    },
    {
        "school": "VICTORY ACADEMY",
        "district": "PITTSYLVANIA CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510294003056",
    },
    {
        "school": "PHOENIX CENTER FOR INNOVATIVE LEARNING",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510366003049",
    },
    {
        "school": "THE COLLEGE AND CAREER ACADEMY AT PRUDEN",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510371003045",
    },
    {
        "school": "COLONEL FRED CHERRY MIDDLE SCHOOL",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510371003058",
    },
    {
        "school": "JAMES BLAIR MIDDLE",
        "district": "WILLIAMSBURG-JAMES CITY PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510402003054",
    },
    {
        "school": "JJ Smith Elementary",
        "district": "Enumclaw School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530000103598",
    },
    {
        "school": "Open Doors - Youth Reengagement Program",
        "district": "Northwest Educational Service District 189",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530000803609",
    },
    {
        "school": "Arlington Open Doors",
        "district": "Arlington School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530024003594",
    },
    {
        "school": "Rainier Valley Leadership Academy",
        "district": "Rainier Valley Leadership Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530034203602",
    },
    {
        "school": "Summit Public School: Atlas",
        "district": "Summit Public School: Atlas",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530034303611",
    },
    {
        "school": "Daybreak Youth Services",
        "district": "Battle Ground School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038003601",
    },
    {
        "school": "Bethel Elementary Learning Academy",
        "district": "Bethel School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530048003624",
    },
    {
        "school": "Barker Creek Community School",
        "district": "Central Kitsap School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530108003622",
    },
    {
        "school": "Liberty Creek Elementary School",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111003596",
    },
    {
        "school": "Sage Hills Open Doors",
        "district": "Ephrata School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530261003600",
    },
    {
        "school": "TAFA at Saghalie",
        "district": "Federal Way School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530282003610",
    },
    {
        "school": "Ferndale Family Connections",
        "district": "Ferndale School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530285003625",
    },
    {
        "school": "Marysville Getchell High School",
        "district": "Marysville School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530486003607",
    },
    {
        "school": "Pacific Crest Innovation Academy",
        "district": "Mill A School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530504003616",
    },
    {
        "school": "Pathfinder Kindergarten Center",
        "district": "Mukilteo School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530543003595",
    },
    {
        "school": "Mukilteo Reengagement Academy Open Doors",
        "district": "Mukilteo School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530543003597",
    },
    {
        "school": "CRCC-Open Doors",
        "district": "North Franklin School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530573003621",
    },
    {
        "school": "North Creek High School",
        "district": "Northshore School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591003617",
    },
    {
        "school": "Pasco Early Learning Center",
        "district": "Pasco School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657003626",
    },
    {
        "school": "Risdon Middle School",
        "district": "Renton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723003603",
    },
    {
        "school": "Leona Libby Middle School",
        "district": "Richland School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732003606",
    },
    {
        "school": "Meany Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003612",
    },
    {
        "school": "Cedar Park Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003613",
    },
    {
        "school": "Decatur Elementary School",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003618",
    },
    {
        "school": "Robert Eagle Staff Middle School",
        "district": "Seattle School District No. 1",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003620",
    },
    {
        "school": "Tahoma Elementary",
        "district": "Tahoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530876003604",
    },
    {
        "school": "Cedar River Elementary",
        "district": "Tahoma School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530876003605",
    },
    {
        "school": "Columbia River Gorge Elementary School",
        "district": "Washougal School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530954003608",
    },
    {
        "school": "WEST VALLEY VIRTUAL ACADEMY 9-12",
        "district": "West Valley School District (Yakima)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972003614",
    },
    {
        "school": "WEST VALLEY VIRTUAL ACADEMY 7-8",
        "district": "West Valley School District (Yakima)",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972003619",
    },
    {
        "school": "WEST VALLEY VIRTUAL ACADEMY K-6",
        "district": "West Valley School District (Yakima)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530972003623",
    },
    {
        "school": "BROOKE INTERMEDIATE SCHOOL SOUTH",
        "district": "BROOKE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540015001581",
    },
    {
        "school": "BROOKE MIDDLE SCHOOL",
        "district": "BROOKE COUNTY SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540015001582",
    },
    {
        "school": "BROOKE PRIMARY SCHOOL SOUTH",
        "district": "BROOKE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540015001583",
    },
    {
        "school": "BROOKE PRIMARY SCHOOL NORTH",
        "district": "BROOKE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540015001584",
    },
    {
        "school": "BROOKE INTERMEDIATE SCHOOL NORTH",
        "district": "BROOKE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540015001585",
    },
    {
        "school": "CRUM PRE K-8 SCHOOL",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001579",
    },
    {
        "school": "CEREDO-KENOVA ELEMENTARY",
        "district": "WAYNE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540150001580",
    },
    {
        "school": "Friess Lake Elementary",
        "district": "Holy Hill Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550008003077",
    },
    {
        "school": "Richfield Middle",
        "district": "Holy Hill Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550008003078",
    },
    {
        "school": "Rocketship Transformation Prep",
        "district": "Rocketship Education Wisconsin Inc",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550008103086",
    },
    {
        "school": "Isthmus Montessori Academy Public",
        "district": "Isthmus Montessori Academy Public Agency",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550008203085",
    },
    {
        "school": "One City Expeditionary Elementary School",
        "district": "One City Expeditionary Elementary School Agency",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550008303087",
    },
    {
        "school": "Almond-Bancroft Middle",
        "district": "Almond-Bancroft School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550024003076",
    },
    {
        "school": "Argyle Middle",
        "district": "Argyle School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550045003073",
    },
    {
        "school": "BDUSD4Kids",
        "district": "Beaver Dam Unified School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550096003082",
    },
    {
        "school": "Koshkonong Trails School",
        "district": "Cambridge School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550210003093",
    },
    {
        "school": "Eleva-Strum Middle",
        "district": "Eleva-Strum School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550420003081",
    },
    {
        "school": "Southwestern Wisconsin Community Middle",
        "district": "Southwestern Wisconsin School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550630003097",
    },
    {
        "school": "JEDI Virtual K-12",
        "district": "Lake Mills Area School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550771002901",
    },
    {
        "school": "Capital High",
        "district": "Madison Metropolitan School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550852003095",
    },
    {
        "school": "Carmen Middle School of Science and Technology South Campus",
        "district": "Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960003071",
    },
    {
        "school": "New School for Youth Empowerment",
        "district": "Milwaukee School District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960003080",
    },
    {
        "school": "Lakeland STAR Acad (LSA)",
        "district": "Lakeland UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550963003090",
    },
    {
        "school": "Lakeland STAR School--Strong Talented Adventurous Remarkable",
        "district": "Minocqua J1 School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550969003083",
    },
    {
        "school": "Riverdale Academy",
        "district": "Riverdale School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551014003084",
    },
    {
        "school": "WISE Academy",
        "district": "Nekoosa School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551038003089",
    },
    {
        "school": "New Richmond Early Childhood Special Education",
        "district": "New Richmond School District",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "WI",
        "nces_id": "551062003079",
    },
    {
        "school": "Norris Academy Virtual School",
        "district": "Norris School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551071003072",
    },
    {
        "school": "Eagles' Wings Virtual Charter School",
        "district": "Solon Springs School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551398003092",
    },
    {
        "school": "SASD 4K",
        "district": "Stoughton Area School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551455003094",
    },
    {
        "school": "Token Springs Elementary",
        "district": "Sun Prairie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464003074",
    },
    {
        "school": "Meadow View Elementary",
        "district": "Sun Prairie Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551464003075",
    },
    {
        "school": "Riverview School",
        "district": "Waukesha School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "551578003070",
    },
    {
        "school": "Chain Exploration Center",
        "district": "Waupaca School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551584003091",
    },
    {
        "school": "Central Oaks Academy",
        "district": "Wisconsin Rapids School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551707003088",
    },
    {
        "school": "Thunder Basin High School",
        "district": "Campbell County School District #1",
        "level": "High",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560147000580",
    },
    {
        "school": "West Side Elementary",
        "district": "Washakie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560624000577",
    },
    {
        "school": "South Side Elementary",
        "district": "Washakie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560624000578",
    },
    {
        "school": "East Side Elementary",
        "district": "Washakie County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560624000579",
    },
    {
        "school": "Meadowlark Academy",
        "district": "Right of Passage",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WY",
        "nces_id": "568025500576",
    },
    {
        "school": "Child Count Only",
        "district": "Al Inst Deaf And Blind",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10000902231",
    },
    {
        "school": "Morgan County System of Services Inc",
        "district": "SafetyNet Academy Minter",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10001502458",
    },
    {
        "school": "Sequel TSI Tuskegee LLC",
        "district": "Sequel TSI Tuskegee LLC",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10002602352",
    },
    {
        "school": "Spec Ed Private Services Child Count Only",
        "district": "The Little Tree Preschool  Auburn",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003502370",
    },
    {
        "school": "Lee Co Youth Detention Ctr",
        "district": "Lee County Youth Development Center",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003602451",
    },
    {
        "school": "Pathway at Baldwin",
        "district": "Pathway Inc",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10003802468",
    },
    {
        "school": "JF Ingram State Technical College Special Services",
        "district": "JF Ingram State Technical College",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017602460",
    },
    {
        "school": "Kilby Correctional Facility",
        "district": "JF Ingram State Technical College",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017602465",
    },
    {
        "school": "Staton Correctional Facility",
        "district": "JF Ingram State Technical College",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017602466",
    },
    {
        "school": "Frank Lee Youth Center",
        "district": "JF Ingram State Technical College",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017602467",
    },
    {
        "school": "Higdon Hill School",
        "district": "Higdon Hill School",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017802374",
    },
    {
        "school": "The Bridge Inc Gadsden",
        "district": "The Bridge",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10017902459",
    },
    {
        "school": "Father Purcell Memorial Exceptional Childrens Center",
        "district": "Father Purcell Center",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10018602335",
    },
    {
        "school": "Evergreen School",
        "district": "Evergreen School",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10019102305",
    },
    {
        "school": "Montgomery Public Schools MPS Classroom McInnis",
        "district": "Montgomery Public Schools MPS Classroom McInnis",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10019201694",
    },
    {
        "school": "St Marys Home",
        "district": "St Marys Home",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10019302341",
    },
    {
        "school": "Sequel TSI Montgomery LLC",
        "district": "Sequel TSI Montgomery LLC",
        "level": "High",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10019802450",
    },
    {
        "school": "East Alabama Medical Center",
        "district": "East Alabama Academy",
        "level": "Not reported",
        "type": "Special education school",
        "state": "AL",
        "nces_id": "10020002463",
    },
    {
        "school": "Creekside Elementary School",
        "district": "Auburn City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10021002454",
    },
    {
        "school": "Austin Junior High School",
        "district": "Decatur City",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10117002456",
    },
    {
        "school": "Career Technical Center",
        "district": "Decatur City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10117002457",
    },
    {
        "school": "Enterprise Career and Technology Center",
        "district": "Enterprise City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10132002455",
    },
    {
        "school": "Gaston Elementary School",
        "district": "Etowah County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10138002453",
    },
    {
        "school": "Heritage Academy Maricopa",
        "district": "Heritage Academy Inc. (4336)",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40005303602",
    },
    {
        "school": "NAVIT - Northland Pioneer College WMC",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703625",
    },
    {
        "school": "NAVIT - Northland Pioneer College PDC",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703626",
    },
    {
        "school": "NAVIT - Northland Pioneer College SPE",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703627",
    },
    {
        "school": "NAVIT - Northland Pioneer College SCC",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703629",
    },
    {
        "school": "NAVIT - Gila Community College",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703631",
    },
    {
        "school": "NAVIT - Northland Pioneer College LCC",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703632",
    },
    {
        "school": "NAVIT - Northland Pioneer College STJ",
        "district": "Northern Arizona Vocational Institute of Technolog (78786)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40019703633",
    },
    {
        "school": "VACTE - Yavapai College Sedona Center",
        "district": "Valley Academy for Career and Technology Education (79397)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034103622",
    },
    {
        "school": "CTD - Cochise College",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034503589",
    },
    {
        "school": "CAVIAT - Fredonia Central Campus",
        "district": "Coconino Association for Vocation Industry and Tec (79381)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034703592",
    },
    {
        "school": "Valencia Newcomer School",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060003599",
    },
    {
        "school": "Madrid Neighborhood School",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060003614",
    },
    {
        "school": "West-MEC Canyon View High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503587",
    },
    {
        "school": "West-MEC Gateway Community College",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503595",
    },
    {
        "school": "West-MEC Glendale Community College",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503603",
    },
    {
        "school": "West-MEC Glendale Community College - North",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503608",
    },
    {
        "school": "West-MEC Western School Science Technology",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503616",
    },
    {
        "school": "West-MEC Estrella Mountain Community College",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503620",
    },
    {
        "school": "MIJTED - Yavapai College Prescott Valley",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077203601",
    },
    {
        "school": "MIJTED - Yavapai College Agribusiness & Technology Center",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077203610",
    },
    {
        "school": "MICTED - Culinary",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077203628",
    },
    {
        "school": "MICTED - Medical",
        "district": "Mountain Institute JTED (90090)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40077203630",
    },
    {
        "school": "Vista College Prep - Middle School",
        "district": "Vista College Preparatory Inc. (91948)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40088703611",
    },
    {
        "school": "Academy of Math and Science Desert Sky",
        "district": "Academy of Mathematics and Science South Inc. (90878)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089103581",
    },
    {
        "school": "Leman Academy of Excellence East Mesa",
        "district": "Leman Academy of Excellence Inc. (92730)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094403584",
    },
    {
        "school": "Leman Academy of Excellence East Tucson",
        "district": "Leman Academy of Excellence Inc. (92730)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40094403586",
    },
    {
        "school": "Legacy Traditional School - Phoenix",
        "district": "Legacy Traditional School - Phoenix (873957)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40095903579",
    },
    {
        "school": "Phoenix International Academy",
        "district": "Phoenix International Academy (903484)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40097503596",
    },
    {
        "school": "Think Through Academy",
        "district": "Think Through Academy (92976)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40097603624",
    },
    {
        "school": "The French American Academy of Arizona",
        "district": "The French American School of Arizona (395879)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40097703580",
    },
    {
        "school": "Edison School of Innovation",
        "district": "Edison Project (743644)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40097803585",
    },
    {
        "school": "BASIS Scottsdale Primary - West Campus",
        "district": "BASIS Charter Schools Inc. (783027)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40098003607",
    },
    {
        "school": "Da Vinci Tree Academy",
        "district": "Science Technology Engineering and Math Arizona (1000050)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40098103605",
    },
    {
        "school": "The Buckeye Academy",
        "district": "Buckeye Union High School District (4284)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40141003591",
    },
    {
        "school": "Dr Daniel Bright Elementary School",
        "district": "Cottonwood-Oak Creek Elementary District (4487)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40237003612",
    },
    {
        "school": "Cottonwood Community School",
        "district": "Cottonwood-Oak Creek Elementary District (4487)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40237003619",
    },
    {
        "school": "Continental Project",
        "district": "Flagstaff Unified District (4192)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40286003597",
    },
    {
        "school": "David Kazan Family Educational Center",
        "district": "Isaac Elementary District (4259)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40396003590",
    },
    {
        "school": "Dove Mountain K-8",
        "district": "Marana Unified District (4404)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40463003588",
    },
    {
        "school": "Nadaburg Online Virtual Academy",
        "district": "Nadaburg Unified School District (4252)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40546003623",
    },
    {
        "school": "Montecito Community School",
        "district": "Osborn Elementary District (4262)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40567003613",
    },
    {
        "school": "PXU Digital Academy",
        "district": "Phoenix Union High School District (4286)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40633003578",
    },
    {
        "school": "Faith Mather Sossaman Elementary School",
        "district": "Queen Creek Unified District (4245)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681003583",
    },
    {
        "school": "Eastmark High School",
        "district": "Queen Creek Unified District (4245)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681003606",
    },
    {
        "school": "Wrightson Ridge K-8 School",
        "district": "Sahuarita Unified District (4411)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40730003582",
    },
    {
        "school": "Show Low Preschool",
        "district": "Show Low Unified District (4393)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40770003615",
    },
    {
        "school": "Meyer Montessori",
        "district": "Tempe School District (4258)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40831003600",
    },
    {
        "school": "Wings on Words Preschool",
        "district": "Tucson Unified District (4403)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880003617",
    },
    {
        "school": "Booth Magnet Elementary School",
        "district": "Tucson Unified District (4403)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40880003621",
    },
    {
        "school": "SCHOOL FOR THE DEAF SCHOOLS",
        "district": "ARK. SCHOOL FOR THE DEAF",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50003601653",
    },
    {
        "school": "ESTEM EAST VILLAGE JUNIOR HIGH PUBLIC CHARTER SCHOOL",
        "district": "ESTEM HIGH CHARTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039801658",
    },
    {
        "school": "ESTEM EAST VILLAGE ELEMENTARY PUBLIC CHARTER SCHOOL",
        "district": "ESTEM HIGH CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039801666",
    },
    {
        "school": "BOBBY G LESTER ELEMENTARY SCHOOL",
        "district": "JACKSONVILLE NORTH PULASKI SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50041901655",
    },
    {
        "school": "IVY PRIMARY ACADEMY",
        "district": "SCHOLARMADE ACHIEVEMENT PLACE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50042101656",
    },
    {
        "school": "NICHOLS INTERMEDIATE ACADEMY",
        "district": "SCHOLARMADE ACHIEVEMENT PLACE",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50042101669",
    },
    {
        "school": "SOUTHEAST ARKANSAS PREPARATORY HIGH SCHOOL",
        "district": "SOUTHEAST ARKANSAS PREPARATORY HIGH SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50042201654",
    },
    {
        "school": "FRIENDSHIP ASPIRE ACADEMY",
        "district": "FRIENDSHIP ASPIRE ACADEMY PINE BLUFF",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50042301657",
    },
    {
        "school": "PARKWAY ELEMENTARY SCHOOL",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369001661",
    },
    {
        "school": "CREATIVE ACTION TEAM SCHOOL",
        "district": "HOPE SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50784001662",
    },
    {
        "school": "JACKSON/WONDER ELEMENTARY SCHOOL",
        "district": "WEST MEMPHIS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50804001659",
    },
    {
        "school": "MARION MATH SCIENCE & TECHNOLOGY MAGNET SCHOOL",
        "district": "MARION SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50939001667",
    },
    {
        "school": "MARION VISUAL & PERFORMING ARTS MAGNET SCHOOL",
        "district": "MARION SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50939001668",
    },
    {
        "school": "POLK COUNTY VIRTUAL ACADEMY",
        "district": "MENA SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50975001665",
    },
    {
        "school": "PRESCOTT JUNIOR HIGH SCHOOL",
        "district": "PRESCOTT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51182001660",
    },
    {
        "school": "QUITMAN MIDDLE SCHOOL",
        "district": "QUITMAN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51188001664",
    },
    {
        "school": "STRONG-HUTTIG SCHOOLS",
        "district": "STRONG-HUTTIG SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51293001663",
    },
    {
        "school": "Dublin Unified Preschool",
        "district": "Dublin Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001914329",
    },
    {
        "school": "Dublin Unified Transition Program",
        "district": "Dublin Unified",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60001914338",
    },
    {
        "school": "Cottonwood Creek",
        "district": "Dublin Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60001914370",
    },
    {
        "school": "Murrieta Preschool Outreach",
        "district": "Murrieta Valley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002914389",
    },
    {
        "school": "North Bay Met Academy",
        "district": "Windsor Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60003414243",
    },
    {
        "school": "Humboldt Virtual Academy",
        "district": "Eureka City Schools",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60005214311",
    },
    {
        "school": "Porterville Military Academy",
        "district": "Porterville Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60006414357",
    },
    {
        "school": "Hillside Elementary",
        "district": "Chawanakee Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60011614261",
    },
    {
        "school": "Hansen Elementary",
        "district": "Lammersville Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60141014330",
    },
    {
        "school": "Success Learning Center",
        "district": "Wiseburn Unified",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "60142814278",
    },
    {
        "school": "Magnolia Science Academy Santa Ana",
        "district": "Magnolia Science Academy Santa Ana District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60146112419",
    },
    {
        "school": "River Valley Charter",
        "district": "River Valley Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60146207308",
    },
    {
        "school": "Vista Springs Charter",
        "district": "Vista Springs Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60146314373",
    },
    {
        "school": "Community Montessori",
        "district": "Community Montessori District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60146413054",
    },
    {
        "school": "Oakland Charter High",
        "district": "Oakland Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60146512041",
    },
    {
        "school": "Girls Athletic Leadership School Los Angeles",
        "district": "Girls Athletic Leadership School Los Angeles District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60146613973",
    },
    {
        "school": "Pacific Community Charter",
        "district": "Pacific Community Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60146708155",
    },
    {
        "school": "America's Finest Charter",
        "district": "America's Finest Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60146814198",
    },
    {
        "school": "Sycamore Valley Academy",
        "district": "Sycamore Valley Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60146913015",
    },
    {
        "school": "Crete Academy",
        "district": "Crete Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60147014100",
    },
    {
        "school": "Accelerated Charter Elementary",
        "district": "Accelerated Charter Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60147110830",
    },
    {
        "school": "Ocean Grove Charter",
        "district": "Ocean Grove Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60147211464",
    },
    {
        "school": "Classical Academy Vista",
        "district": "Classical Academy Vista District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60147314298",
    },
    {
        "school": "B. Roberto Cruz Leadership Academy",
        "district": "B. Roberto Cruz Leadership Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60147413927",
    },
    {
        "school": "Pathways to College K8",
        "district": "Pathways to College K8 District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60147511746",
    },
    {
        "school": "Camino Nuevo Charter High",
        "district": "Camino Nuevo Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60147610847",
    },
    {
        "school": "New Heights Charter",
        "district": "New Heights Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60147711630",
    },
    {
        "school": "Meadows Arts and Technology Elementary",
        "district": "Meadows Arts and Technology Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60147812541",
    },
    {
        "school": "American Indian Public Charter",
        "district": "American Indian Public Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60147905673",
    },
    {
        "school": "Sol Aureus College Preparatory",
        "district": "Sol Aureus College Preparatory District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60148011198",
    },
    {
        "school": "SOAR Charter Academy",
        "district": "SOAR Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60148112377",
    },
    {
        "school": "SD Global Vision Academy",
        "district": "SD Global Vision Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60148312630",
    },
    {
        "school": "PUC Triumph Charter Academy and PUC Triumph Charter High",
        "district": "PUC Triumph CHRTR Academy & PUC Triumph CHRTR High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60148412812",
    },
    {
        "school": "Crescent Valley Public Charter II",
        "district": "Crescent Valley Public Charter II District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60148514209",
    },
    {
        "school": "Palm Lane Elementary Charter",
        "district": "Palm Lane Elementary Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60148600162",
    },
    {
        "school": "Mojave River Academy - Route 66",
        "district": "Mojave River Academy - Route 66 District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60148714233",
    },
    {
        "school": "Palisades Charter High",
        "district": "Palisades Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60148804593",
    },
    {
        "school": "The Heights Charter",
        "district": "The Heights Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60148913185",
    },
    {
        "school": "CHIME Institute's Schwarzenegger Community",
        "district": "CHIME Institute's Schwarzenegger Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60149008724",
    },
    {
        "school": "Leadership High",
        "district": "Leadership High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60149107354",
    },
    {
        "school": "Downtown Charter Academy",
        "district": "Downtown Charter Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60149313752",
    },
    {
        "school": "Los Angeles Leadership Academy",
        "district": "Los Angeles Leadership Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60149410517",
    },
    {
        "school": "Wilder's Preparatory Academy Charter Middle",
        "district": "Wilder's Preparatory Academy Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60149512247",
    },
    {
        "school": "Aspire Triumph Technology Academy",
        "district": "Aspire Triumph Technology Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60149610724",
    },
    {
        "school": "Willits Elementary Charter",
        "district": "Willits Elementary Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60149713021",
    },
    {
        "school": "KIPP Bayview Elementary",
        "district": "KIPP Bayview Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60149814322",
    },
    {
        "school": "Sierra Expeditionary Learning",
        "district": "Sierra Expeditionary Learning District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60149912628",
    },
    {
        "school": "Options for Youth-Acton",
        "district": "Options for Youth-Acton District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60150014202",
    },
    {
        "school": "Olive Grove Charter - Buellton",
        "district": "Olive Grove Charter - Buellton District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60150114258",
    },
    {
        "school": "Making Waves Academy",
        "district": "Making Waves Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60150212043",
    },
    {
        "school": "Elevate",
        "district": "Elevate District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60150313795",
    },
    {
        "school": "Da Vinci Communications",
        "district": "Da Vinci Communications District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60150513832",
    },
    {
        "school": "ISANA Himalia Academy",
        "district": "ISANA Himalia Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60150712162",
    },
    {
        "school": "Valley Life Charter",
        "district": "Valley Life Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60150812862",
    },
    {
        "school": "Sweetwater Secondary",
        "district": "Sweetwater Secondary District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60150914089",
    },
    {
        "school": "Health Sciences Middle",
        "district": "Health Sciences Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60151013655",
    },
    {
        "school": "Creekside Charter",
        "district": "Creekside Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60151112515",
    },
    {
        "school": "Sutter Peak Charter Academy",
        "district": "Sutter Peak Charter Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60151213958",
    },
    {
        "school": "Peabody Charter",
        "district": "Peabody Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60151306027",
    },
    {
        "school": "Latitude 37.8 High",
        "district": "Latitude 37.8 High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60151414257",
    },
    {
        "school": "High Tech High Media Arts",
        "district": "High Tech High Media Arts District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60151511386",
    },
    {
        "school": "Harbor Springs Charter",
        "district": "Harbor Springs Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60151613715",
    },
    {
        "school": "Compass Charter Schools of San Diego",
        "district": "Compass Charter Schools of San Diego District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60151713179",
    },
    {
        "school": "OnePurpose",
        "district": "OnePurpose District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60151813938",
    },
    {
        "school": "EPIC Charter (Excellence Performance Innovation Citizenship)",
        "district": "EPIC CHRTR(Excellence Perf Innovation Citzenship) DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60151914018",
    },
    {
        "school": "Howard Gardner Community Charter",
        "district": "Howard Gardner Community Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60152012866",
    },
    {
        "school": "All Tribes Elementary Charter",
        "district": "All Tribes Elementary Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60152112735",
    },
    {
        "school": "Audeo Charter",
        "district": "Audeo Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60152210634",
    },
    {
        "school": "Encore Jr./Sr. High Sch for the Perf and Visual Arts",
        "district": "Encore Jr./Sr. High Sch for the Perf & Visual Arts District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60152312375",
    },
    {
        "school": "Aspire Titan Academy",
        "district": "Aspire Titan Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60152412447",
    },
    {
        "school": "Monsenor Oscar Romero Charter Middle",
        "district": "Monsenor Oscar Romero Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60152611928",
    },
    {
        "school": "Iftin Charter",
        "district": "Iftin Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60152711385",
    },
    {
        "school": "Insight @ San Diego",
        "district": "Insight @ San Diego District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60152813030",
    },
    {
        "school": "Valor Academy Elementary",
        "district": "Valor Academy Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60152913966",
    },
    {
        "school": "PUC Community Charter Elementary",
        "district": "PUC Community Charter Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60153013768",
    },
    {
        "school": "California Heritage Youthbuild Academy II",
        "district": "California Heritage Youthbuild Academy II District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60153112995",
    },
    {
        "school": "Bright Star Secondary Charter Academy",
        "district": "Bright Star Secondary Charter Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60153211665",
    },
    {
        "school": "Ingenuity Charter",
        "district": "Ingenuity Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60153313917",
    },
    {
        "school": "Los Angeles Academy of Arts and Enterprise",
        "district": "Los Angeles Academy of Arts and Enterprise District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60153411628",
    },
    {
        "school": "Intellectual Virtues Academy",
        "district": "Intellectual Virtues Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60153514009",
    },
    {
        "school": "Rocketship Si Se Puede Academy",
        "district": "Rocketship Si Se Puede Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60153612225",
    },
    {
        "school": "Pacific View Charter",
        "district": "Pacific View Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60153708313",
    },
    {
        "school": "Multicultural Learning Center",
        "district": "Multicultural Learning Center District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60153808721",
    },
    {
        "school": "Environmental Charter Middle - Inglewood",
        "district": "Environmental Charter Middle - Inglewood District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60154013591",
    },
    {
        "school": "ISANA Palmati Academy",
        "district": "ISANA Palmati Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60154112614",
    },
    {
        "school": "Alliance Kory Hunter Middle",
        "district": "Alliance Kory Hunter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60154213487",
    },
    {
        "school": "New Designs Charter School-Watts",
        "district": "New Designs Charter School-Watts District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60154312456",
    },
    {
        "school": "KIPP Comienza Community Prep",
        "district": "KIPP Comienza Community Prep District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60154412705",
    },
    {
        "school": "Keiller Leadership Academy",
        "district": "Keiller Leadership Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60154505492",
    },
    {
        "school": "Ivy Bound Acad Math Sci and Tech Charter Mid 2",
        "district": "Ivy Bound Acad Math Sci and Tech Charter Mid 2 District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60154613685",
    },
    {
        "school": "Aspire Richmond Technology Academy",
        "district": "Aspire Richmond Technology Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60154713891",
    },
    {
        "school": "New Designs Charter",
        "district": "New Designs Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60154810840",
    },
    {
        "school": "Pivot Charter School North Valley II",
        "district": "Pivot Charter School North Valley II District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60154914363",
    },
    {
        "school": "Los Feliz Charter School for the Arts",
        "district": "Los Feliz Charter School for the Arts District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60155011660",
    },
    {
        "school": "Urban Discovery Academy Charter",
        "district": "Urban Discovery Academy Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60155112318",
    },
    {
        "school": "Aspire Golden State College Preparatory Academy",
        "district": "Aspire Golden State College Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60155212331",
    },
    {
        "school": "Aspire Centennial College Preparatory Academy",
        "district": "Aspire Centennial College Preparatory Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60155313135",
    },
    {
        "school": "Inspire School of Arts and Sciences",
        "district": "Inspire School of Arts and Sciences District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60155412539",
    },
    {
        "school": "Glacier High School Charter",
        "district": "Glacier High School Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60155510541",
    },
    {
        "school": "Uncharted Shores Academy",
        "district": "Uncharted Shores Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60155611883",
    },
    {
        "school": "Aspire Junior Collegiate Academy",
        "district": "Aspire Junior Collegiate Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60155712077",
    },
    {
        "school": "Norton Science and Language Academy",
        "district": "Norton Science and Language Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60155812150",
    },
    {
        "school": "Lake County International Charter",
        "district": "Lake County International Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60155910819",
    },
    {
        "school": "Classical Academy",
        "district": "Classical Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60156008300",
    },
    {
        "school": "ACE Charter High",
        "district": "ACE Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60156113023",
    },
    {
        "school": "Mission View Public",
        "district": "Mission View Public District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60156211906",
    },
    {
        "school": "Sherman Thomas Charter High",
        "district": "Sherman Thomas Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60156312209",
    },
    {
        "school": "North Valley Military Institute College Preparatory Academy",
        "district": "North Valley Military INST College ACAD District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60156411339",
    },
    {
        "school": "Nova Academy Early College High",
        "district": "Nova Academy Early College High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60156510989",
    },
    {
        "school": "International School of Monterey",
        "district": "International School of Monterey District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60156708744",
    },
    {
        "school": "Alliance Ted K. Tajima High",
        "district": "Alliance Ted K. Tajima High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60156812766",
    },
    {
        "school": "WISH Academy High",
        "district": "WISH Academy High District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60156914098",
    },
    {
        "school": "Monterey Bay Charter",
        "district": "Monterey Bay Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60157011695",
    },
    {
        "school": "New Village Girls Academy",
        "district": "New Village Girls Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60157111631",
    },
    {
        "school": "Alliance Alice M. Baxter College-Ready High",
        "district": "Alliance Alice M. Baxter College-Ready High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60157213099",
    },
    {
        "school": "Watts Learning Center",
        "district": "Watts Learning Center District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60157307522",
    },
    {
        "school": "Yuba Environmental Science Charter Academy",
        "district": "Yuba Environmental Science Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60157412258",
    },
    {
        "school": "TEACH Prep Mildred S. Cunningham & Edith H. Morris Elem",
        "district": "TEACH Prep Mildred S. Cunningham & Edith H. Morris Elem DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60157514313",
    },
    {
        "school": "KIPP Adelante Preparatory Academy",
        "district": "KIPP Adelante Preparatory Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60157611263",
    },
    {
        "school": "Mojave River Academy - Silver Mountain",
        "district": "Mojave River Academy - Silver Mountain District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60157714245",
    },
    {
        "school": "Mueller Charter (Robert L.)",
        "district": "Mueller Charter (Robert L.) District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60157800869",
    },
    {
        "school": "Opportunities for Learning - Santa Clarita",
        "district": "Opportunities for Learning - Santa Clarita District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60157908070",
    },
    {
        "school": "CHAMPS - Charter HS of Arts-Multimedia & Performing",
        "district": "CHAMPS - Charter HS of Arts-Multimedia & Performing District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60158010865",
    },
    {
        "school": "Laurel Tree Charter",
        "district": "Laurel Tree Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60158112960",
    },
    {
        "school": "Caliber: ChangeMakers Academy",
        "district": "Caliber: ChangeMakers Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60158214030",
    },
    {
        "school": "Five Keys Adult School (SF Sheriff's)",
        "district": "Five Keys Adult School (SF Sheriff's) District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60158312373",
    },
    {
        "school": "PUC Lakeview Charter Academy",
        "district": "PUC Lakeview Charter Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60158410837",
    },
    {
        "school": "King-Chavez Academy of Excellence",
        "district": "King-Chavez Academy of Excellence District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60158510381",
    },
    {
        "school": "Valley Charter Elementary",
        "district": "Valley Charter Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60158612641",
    },
    {
        "school": "Golden Valley Orchard",
        "district": "Golden Valley Orchard District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60158713910",
    },
    {
        "school": "Edison-Bethune Charter Academy",
        "district": "Edison-Bethune Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60158807958",
    },
    {
        "school": "Alliance College-Ready Middle Academy 8",
        "district": "Alliance College-Ready Middle Academy 8 District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60158913273",
    },
    {
        "school": "Heartland Charter",
        "district": "Heartland Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60159014226",
    },
    {
        "school": "Discovery Charter",
        "district": "Discovery Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60159111792",
    },
    {
        "school": "JCS - Pine Hills",
        "district": "JCS - Pine Hills District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60159214346",
    },
    {
        "school": "Clear Passage Educational Center",
        "district": "Clear Passage Educational Center District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60159313860",
    },
    {
        "school": "Santa Monica Boulevard Community Charter",
        "district": "Santa Monica Boulevard Community Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60159403333",
    },
    {
        "school": "Redding STEM Academy",
        "district": "Redding STEM Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60159513960",
    },
    {
        "school": "Birmingham Community Charter High",
        "district": "Birmingham Community Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60159602857",
    },
    {
        "school": "Downtown College Preparatory",
        "district": "Downtown College Preparatory District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60159708632",
    },
    {
        "school": "Aspire Capitol Heights Academy",
        "district": "Aspire Capitol Heights Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60159811189",
    },
    {
        "school": "ISANA Nascent Academy",
        "district": "ISANA Nascent Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60159910869",
    },
    {
        "school": "Scholarship Prep - Oceanside",
        "district": "Scholarship Prep - Oceanside District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60160014079",
    },
    {
        "school": "Mojave River Academy - Gold Canyon",
        "district": "Mojave River Academy - Gold Canyon District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60160114270",
    },
    {
        "school": "Piner-Olivet Charter",
        "district": "Piner-Olivet Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60160206676",
    },
    {
        "school": "Oasis Charter Public",
        "district": "Oasis Charter Public District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60160310558",
    },
    {
        "school": "Aspire East Palo Alto Charter",
        "district": "Aspire East Palo Alto Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60160414051",
    },
    {
        "school": "Family First Charter",
        "district": "Family First Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60160513705",
    },
    {
        "school": "Northern United - Siskiyou Charter",
        "district": "Northern United - Siskiyou Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60160614256",
    },
    {
        "school": "Summit Leadership Academy-High Desert",
        "district": "Summit Leadership Academy-High Desert District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60160711118",
    },
    {
        "school": "Willow Creek Academy Charter",
        "district": "Willow Creek Academy Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60160808732",
    },
    {
        "school": "Sierra Charter",
        "district": "Sierra Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60160911846",
    },
    {
        "school": "Redwood Academy of Ukiah",
        "district": "Redwood Academy of Ukiah District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60161008520",
    },
    {
        "school": "Orange County Workforce Innovation High",
        "district": "Orange County Workforce Innovation High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60161114040",
    },
    {
        "school": "LA's Promise Charter High #1",
        "district": "LA's Promise Charter High #1 District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60161214144",
    },
    {
        "school": "Fenton STEM Acad: Elem Center for Sci Tech Engr and Math",
        "district": "Fenton STEM Acad: Elem CTR for Sci Tech Engr & Math District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60161313872",
    },
    {
        "school": "Envision Academy for Arts & Technology",
        "district": "Envision Academy for Arts & Technology District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60161410947",
    },
    {
        "school": "Achieve Charter High",
        "district": "Achieve Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60161514213",
    },
    {
        "school": "California Virtual Academy at Fresno",
        "district": "California Virtual Academy at Fresno District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60161614251",
    },
    {
        "school": "Lennox Mathematics Science and Technology Academy",
        "district": "Lennox Mathematics Science and Technology Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60161711328",
    },
    {
        "school": "KIPP Heartwood Academy",
        "district": "KIPP Heartwood Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60161911444",
    },
    {
        "school": "Rocketship Discovery Prep",
        "district": "Rocketship Discovery Prep District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162112668",
    },
    {
        "school": "High Tech Middle North County",
        "district": "High Tech Middle North County District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162212388",
    },
    {
        "school": "Roses in Concrete",
        "district": "Roses in Concrete District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162313856",
    },
    {
        "school": "Animo Legacy Charter Middle",
        "district": "Animo Legacy Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162412935",
    },
    {
        "school": "Alta Vista Innovation High",
        "district": "Alta Vista Innovation High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162514154",
    },
    {
        "school": "KIPP San Francisco Bay Academy",
        "district": "KIPP San Francisco Bay Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162611255",
    },
    {
        "school": "Innovations Academy",
        "district": "Innovations Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162712261",
    },
    {
        "school": "Humphreys College Academy of Business Law and Education",
        "district": "Humphreys College Academy of Business Law and ED District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162813064",
    },
    {
        "school": "Community Collaborative Virtual - Sage Oak Charter",
        "district": "Community Collaborative Virtual - Sage Oak Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60162914107",
    },
    {
        "school": "Magnolia Science Academy Bell",
        "district": "Magnolia Science Academy Bell District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60163012695",
    },
    {
        "school": "Trivium Charter School Adventure",
        "district": "Trivium Charter School Adventure District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60163114339",
    },
    {
        "school": "Pacific View Charter 2.0",
        "district": "Pacific View Charter 2.0 District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60163208486",
    },
    {
        "school": "College Bridge Academy",
        "district": "College Bridge Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60163313704",
    },
    {
        "school": "New Day Academy",
        "district": "New Day Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60163414345",
    },
    {
        "school": "Alternatives in Action",
        "district": "Alternatives in Action District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60163508674",
    },
    {
        "school": "Alpha Cindy Avitia High",
        "district": "Alpha Cindy Avitia High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60163613926",
    },
    {
        "school": "Rocketship Alma Academy",
        "district": "Rocketship Alma Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60163713048",
    },
    {
        "school": "College Preparatory Middle",
        "district": "College Preparatory Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60163814334",
    },
    {
        "school": "County Collaborative Charter",
        "district": "County Collaborative Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60163913837",
    },
    {
        "school": "Leadership Military Academy",
        "district": "Leadership Military Academy District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60164012986",
    },
    {
        "school": "Provisional Accelerated Learning Academy",
        "district": "Provisional Accelerated Learning Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60164110364",
    },
    {
        "school": "The Academy of Alameda",
        "district": "The Academy of Alameda District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60164200042",
    },
    {
        "school": "Pathways Academy Charter Adult Education",
        "district": "Pathways Academy Charter Adult Education District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60164314062",
    },
    {
        "school": "Eel River Charter",
        "district": "Eel River Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60164403304",
    },
    {
        "school": "Arroyo Vista Charter",
        "district": "Arroyo Vista Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60164508299",
    },
    {
        "school": "Olive Grove Charter",
        "district": "Olive Grove Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60164613948",
    },
    {
        "school": "Impact Academy of Arts & Technology",
        "district": "Impact Academy of Arts & Technology District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60164711849",
    },
    {
        "school": "Summit Public School: Shasta",
        "district": "Summit Public School: Shasta District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60164813354",
    },
    {
        "school": "Animo Mae Jemison Charter Middle",
        "district": "Animo Mae Jemison Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60164913787",
    },
    {
        "school": "California Collegiate Charter",
        "district": "California Collegiate Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165113967",
    },
    {
        "school": "Gabriella Charter 2",
        "district": "Gabriella Charter 2 District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165214109",
    },
    {
        "school": "California Montessori Project-San Juan Campuses",
        "district": "California Montessori Project-San Juan Campuses District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165311733",
    },
    {
        "school": "Alliance Virgil Roberts Leadership Academy",
        "district": "Alliance Virgil Roberts Leadership Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165413597",
    },
    {
        "school": "Golden Oak Montessori of Hayward",
        "district": "Golden Oak Montessori of Hayward District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165512426",
    },
    {
        "school": "Downtown College Prep - Alum Rock",
        "district": "Downtown College Prep - Alum Rock District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165612827",
    },
    {
        "school": "Animo Jackie Robinson High",
        "district": "Animo Jackie Robinson High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165711636",
    },
    {
        "school": "Animo Ellen Ochoa Charter Middle",
        "district": "Animo Ellen Ochoa Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165812905",
    },
    {
        "school": "Optimist Charter",
        "district": "Optimist Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60165913536",
    },
    {
        "school": "Heritage K-8 Charter",
        "district": "Heritage K-8 Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60166011228",
    },
    {
        "school": "eCademy Charter at Crane",
        "district": "eCademy Charter at Crane District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60166112929",
    },
    {
        "school": "Kavod Charter",
        "district": "Kavod Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60166213201",
    },
    {
        "school": "Alameda Community Learning Center",
        "district": "Alameda Community Learning Center District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60166408673",
    },
    {
        "school": "Chico Country Day",
        "district": "Chico Country Day District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60166505708",
    },
    {
        "school": "Alliance Collins Family College-Ready High",
        "district": "Alliance Collins Family College-Ready High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60166610871",
    },
    {
        "school": "Aspire Pacific Academy",
        "district": "Aspire Pacific Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60166712634",
    },
    {
        "school": "The City",
        "district": "The City District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60166813899",
    },
    {
        "school": "Golden Valley River",
        "district": "Golden Valley River District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60166911902",
    },
    {
        "school": "Richmond Charter Elementary-Benito Juarez",
        "district": "Richmond Charter Elementary-Benito Juarez District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60167013753",
    },
    {
        "school": "Alpha: Cornerstone Academy Preparatory",
        "district": "Alpha: Cornerstone Academy Preparatory District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60167112639",
    },
    {
        "school": "Oxford Preparatory Academy - Saddleback Valley",
        "district": "Oxford Preparatory Academy - Saddleback Valley District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60167214001",
    },
    {
        "school": "Rocklin Academy at Meyers Street",
        "district": "Rocklin Academy at Meyers Street District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60167412012",
    },
    {
        "school": "Crescent View West Public Charter",
        "district": "Crescent View West Public Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60167710789",
    },
    {
        "school": "Magnolia Science Academy 4",
        "district": "Magnolia Science Academy 4 District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60167812360",
    },
    {
        "school": "Valor Academy Middle",
        "district": "Valor Academy Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60167912510",
    },
    {
        "school": "SIATech Academy South",
        "district": "SIATech Academy South District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60168113829",
    },
    {
        "school": "MethodSchools",
        "district": "MethodSchools District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60168213762",
    },
    {
        "school": "Lifeline Education Charter",
        "district": "Lifeline Education Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60168312119",
    },
    {
        "school": "High Tech LA",
        "district": "High Tech LA District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60168410829",
    },
    {
        "school": "Morrice Schaefer Charter",
        "district": "Morrice Schaefer Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60168509993",
    },
    {
        "school": "LaVerne Elementary Preparatory Academy",
        "district": "LaVerne Elementary Preparatory Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60168612333",
    },
    {
        "school": "King-Chavez Preparatory Academy",
        "district": "King-Chavez Preparatory Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60168711767",
    },
    {
        "school": "JCS - Cedar Cove",
        "district": "JCS - Cedar Cove District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60168814254",
    },
    {
        "school": "Pivot Charter School - San Diego II",
        "district": "Pivot Charter School - San Diego II District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60168914347",
    },
    {
        "school": "Alliance Leichtman-Levine Family Foundation Env Sci High",
        "district": "Alliance Leichtman-Levine FAM Foundation Env Sci High DIST",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60169012342",
    },
    {
        "school": "Community School for Creative Education",
        "district": "Community School for Creative Education District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60169112844",
    },
    {
        "school": "KIPP Academy of Opportunity",
        "district": "KIPP Academy of Opportunity District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60169311308",
    },
    {
        "school": "Alliance Jack H. Skirball Middle",
        "district": "Alliance Jack H. Skirball Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60169411634",
    },
    {
        "school": "San Jose Charter Academy",
        "district": "San Jose Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60169507533",
    },
    {
        "school": "KIPP Compton Community",
        "district": "KIPP Compton Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60169614242",
    },
    {
        "school": "San Jose Conservation Corps Charter",
        "district": "San Jose Conservation Corps Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60169710664",
    },
    {
        "school": "Millennium Charter",
        "district": "Millennium Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60169811426",
    },
    {
        "school": "Watts Learning Center Charter Middle",
        "district": "Watts Learning Center Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60169912491",
    },
    {
        "school": "City Heights Preparatory Charter",
        "district": "City Heights Preparatory Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60170012961",
    },
    {
        "school": "Empire Springs Charter",
        "district": "Empire Springs Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60170113671",
    },
    {
        "school": "Global Education Academy",
        "district": "Global Education Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60170211931",
    },
    {
        "school": "Aspire Alexander Twilight Secondary Academy",
        "district": "Aspire Alexander Twilight Secondary Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60170312785",
    },
    {
        "school": "ASCEND",
        "district": "ASCEND District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60170408677",
    },
    {
        "school": "Guajome Park Academy Charter",
        "district": "Guajome Park Academy Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60170503964",
    },
    {
        "school": "Magnolia Science Academy",
        "district": "Magnolia Science Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60170610524",
    },
    {
        "school": "Alliance Margaret M. Bloomfield Technology Academy High",
        "district": "Alliance Margaret M.Bloomfield Technology ACAD High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60170712924",
    },
    {
        "school": "Environmental Charter Middle",
        "district": "Environmental Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60170812673",
    },
    {
        "school": "New Vision Middle",
        "district": "New Vision Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60170912466",
    },
    {
        "school": "Adelanto Virtual Academy",
        "district": "Adelanto Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60171014369",
    },
    {
        "school": "ASA Charter",
        "district": "ASA Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171111105",
    },
    {
        "school": "Kid Street Learning Center Charter",
        "district": "Kid Street Learning Center Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171208401",
    },
    {
        "school": "Los Angeles College Prep Academy",
        "district": "Los Angeles College Prep Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171310897",
    },
    {
        "school": "Aspen Valley Prep Academy",
        "district": "Aspen Valley Prep Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171410775",
    },
    {
        "school": "Vista Norte Public Charter",
        "district": "Vista Norte Public Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171514217",
    },
    {
        "school": "California Virtual Academy @ Los Angeles",
        "district": "California Virtual Academy @ Los Angeles District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171612034",
    },
    {
        "school": "Civicorps Corpsmember Academy",
        "district": "Civicorps Corpsmember Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171712056",
    },
    {
        "school": "Cox Academy",
        "district": "Cox Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171804257",
    },
    {
        "school": "Manzanita Public Charter",
        "district": "Manzanita Public Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60171912214",
    },
    {
        "school": "Animo College Preparatory Academy",
        "district": "Animo College Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60172012903",
    },
    {
        "school": "Rise Kohyang Elementary",
        "district": "Rise Kohyang Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60172114422",
    },
    {
        "school": "Richmond College Preparatory",
        "district": "Richmond College Preparatory District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60172211576",
    },
    {
        "school": "Rise Kohyang Middle",
        "district": "Rise Kohyang Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60172312852",
    },
    {
        "school": "AeroSTEM Academy",
        "district": "AeroSTEM Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60172414234",
    },
    {
        "school": "ICEF Inglewood Elementary Charter Academy",
        "district": "ICEF Inglewood Elementary Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60172512467",
    },
    {
        "school": "Caliber: Beta Academy",
        "district": "Caliber: Beta Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60172613746",
    },
    {
        "school": "Kings Valley Academy II",
        "district": "Kings Valley Academy II District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60172814205",
    },
    {
        "school": "Rocketship Rising Stars",
        "district": "Rocketship Rising Stars District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60172913979",
    },
    {
        "school": "Horizon Charter",
        "district": "Horizon Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60173003557",
    },
    {
        "school": "ICEF View Park Preparatory High",
        "district": "ICEF View Park Preparatory High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60173111358",
    },
    {
        "school": "Accelerated",
        "district": "Accelerated District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60173203245",
    },
    {
        "school": "Opportunities for Learning - Baldwin Park",
        "district": "Opportunities for Learning - Baldwin Park District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60173308715",
    },
    {
        "school": "CORE Charter",
        "district": "CORE Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60173408436",
    },
    {
        "school": "Los Feliz Charter Middle School for the Arts",
        "district": "Los Feliz Charter Middle School for the Arts District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60173514296",
    },
    {
        "school": "Village Charter Academy",
        "district": "Village Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60173613765",
    },
    {
        "school": "Bella Mente Montessori Academy",
        "district": "Bella Mente Montessori Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60173713667",
    },
    {
        "school": "REACH Leadership STEAM Academy",
        "district": "REACH Leadership STEAM Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60173813116",
    },
    {
        "school": "Epiphany Prep Charter",
        "district": "Epiphany Prep Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60173914029",
    },
    {
        "school": "South Sutter Charter",
        "district": "South Sutter Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60174011518",
    },
    {
        "school": "Camino Nuevo Charter Academy #2",
        "district": "Camino Nuevo Charter Academy #2 District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60174112738",
    },
    {
        "school": "Ararat Charter",
        "district": "Ararat Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60174212437",
    },
    {
        "school": "Sky Mountain Charter",
        "district": "Sky Mountain Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60174311860",
    },
    {
        "school": "Ballington Academy for the Arts and Sciences",
        "district": "Ballington Academy for the Arts and Sciences District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60174412184",
    },
    {
        "school": "Insight School of California",
        "district": "Insight School of California District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60174513167",
    },
    {
        "school": "Mission Academy",
        "district": "Mission Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60174614230",
    },
    {
        "school": "North Oakland Community Charter",
        "district": "North Oakland Community Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60174708442",
    },
    {
        "school": "Dr. Lewis Dolphin Stallworth Sr. Charter",
        "district": "Dr. Lewis Dolphin Stallworth Sr. Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60174812374",
    },
    {
        "school": "Summit Public School: Rainier",
        "district": "Summit Public School: Rainier District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60174912769",
    },
    {
        "school": "Mojave River Academy - Marble City",
        "district": "Mojave River Academy - Marble City District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60175114291",
    },
    {
        "school": "Hume Lake Charter",
        "district": "Hume Lake Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60175211584",
    },
    {
        "school": "High Tech High",
        "district": "High Tech High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60175308599",
    },
    {
        "school": "Scholarship Prep",
        "district": "Scholarship Prep District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60175414060",
    },
    {
        "school": "Lodestar: A Lighthouse Community Charter Public",
        "district": "Lodestar: A Lighthouse Community Charter Public District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60175514027",
    },
    {
        "school": "River Islands Technology Academy II",
        "district": "River Islands Technology Academy II District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60175613146",
    },
    {
        "school": "National Univ Acad HomeSch/Independent Study Orange Co",
        "district": "National Univ Acad HomeSch/Independent Study Orange Co DIST",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60175714337",
    },
    {
        "school": "El Sol Santa Ana Science and Arts Academy",
        "district": "El Sol Santa Ana Science and Arts Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60175808755",
    },
    {
        "school": "University Preparatory",
        "district": "University Preparatory District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60175911467",
    },
    {
        "school": "Vista Condor Global Academy",
        "district": "Vista Condor Global Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60176014372",
    },
    {
        "school": "APEX Academy",
        "district": "APEX Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60176112312",
    },
    {
        "school": "EPIC de Cesar Chavez",
        "district": "EPIC de Cesar Chavez District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60176213819",
    },
    {
        "school": "Classical Academy High",
        "district": "Classical Academy High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60176311756",
    },
    {
        "school": "KIPP Raices Academy",
        "district": "KIPP Raices Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60176412292",
    },
    {
        "school": "Rio Valley Charter",
        "district": "Rio Valley Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60176512723",
    },
    {
        "school": "Renaissance Arts Academy",
        "district": "Renaissance Arts Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60176611314",
    },
    {
        "school": "Yav Pem Suab Academy - Preparing for the Future Charter",
        "district": "Yav Pem Suab Academy - Preparing for Future Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60176712652",
    },
    {
        "school": "High Tech Elementary Explorer",
        "district": "High Tech Elementary Explorer District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60176808602",
    },
    {
        "school": "City Language Immersion Charter",
        "district": "City Language Immersion Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60176913642",
    },
    {
        "school": "Alameda Unified Special Education",
        "district": "Alameda Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177014340",
    },
    {
        "school": "Voices College-Bound Language Academy at Morgan Hill",
        "district": "Voices College-Bound Language ACAD at Morgan Hill District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177113875",
    },
    {
        "school": "Plumas Charter",
        "district": "Plumas Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177307601",
    },
    {
        "school": "Futures High",
        "district": "Futures High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177511070",
    },
    {
        "school": "California Montessori Project - Elk Grove Campus",
        "district": "California Montessori Project - Elk Grove Campus District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177611727",
    },
    {
        "school": "ISANA Achernar Academy",
        "district": "ISANA Achernar Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177712925",
    },
    {
        "school": "Aspire University Charter",
        "district": "Aspire University Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177814342",
    },
    {
        "school": "Vista Oaks Charter",
        "district": "Vista Oaks Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60177913821",
    },
    {
        "school": "Gold Rush Charter",
        "district": "Gold Rush Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60178011827",
    },
    {
        "school": "SIATech",
        "district": "SIATech District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60178111401",
    },
    {
        "school": "Rocketship Mateo Sheedy Elementary",
        "district": "Rocketship Mateo Sheedy Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60178211864",
    },
    {
        "school": "Mare Island Technology Academy",
        "district": "Mare Island Technology Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60178308398",
    },
    {
        "school": "Desert Sands Charter",
        "district": "Desert Sands Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60178408714",
    },
    {
        "school": "PUC Lakeview Charter High",
        "district": "PUC Lakeview Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60178512816",
    },
    {
        "school": "The Language Academy of Sacramento",
        "district": "The Language Academy of Sacramento District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60178611076",
    },
    {
        "school": "High Tech LA Middle",
        "district": "High Tech LA Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60178714225",
    },
    {
        "school": "Gompers Preparatory Academy",
        "district": "Gompers Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60178812386",
    },
    {
        "school": "Valor Academy High",
        "district": "Valor Academy High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60178913564",
    },
    {
        "school": "Compass Charter Schools of Los Angeles",
        "district": "Compass Charter Schools of Los Angeles District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60179014045",
    },
    {
        "school": "KIPP Ignite Academy",
        "district": "KIPP Ignite Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60179113883",
    },
    {
        "school": "Stockton Collegiate International Secondary",
        "district": "Stockton Collegiate International Secondary District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60179212547",
    },
    {
        "school": "Rocketship Redwood City",
        "district": "Rocketship Redwood City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60179313923",
    },
    {
        "school": "Options for Youth-San Juan",
        "district": "Options for Youth-San Juan District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60179408578",
    },
    {
        "school": "Extera Public School No. 2",
        "district": "Extera Public School No. 2 District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60179513316",
    },
    {
        "school": "SAVA - Sacramento Academic and Vocational Academy - EGUSD",
        "district": "SAVA- Sacramento ACAD and Vocational Academy- EGUSD District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60179614368",
    },
    {
        "school": "Los Angeles Leadership Primary Academy",
        "district": "Los Angeles Leadership Primary Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60179712963",
    },
    {
        "school": "Math and Science College Preparatory",
        "district": "Math and Science College Preparatory District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60179813084",
    },
    {
        "school": "Ednovate - Brio College Prep",
        "district": "Ednovate - Brio College Prep District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60179914104",
    },
    {
        "school": "High Tech Middle Chula Vista",
        "district": "High Tech Middle Chula Vista District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60180012642",
    },
    {
        "school": "Aspire Langston Hughes Academy",
        "district": "Aspire Langston Hughes Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60180112244",
    },
    {
        "school": "California Virtual Academy San Mateo",
        "district": "California Virtual Academy San Mateo District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60180211787",
    },
    {
        "school": "Valley Oak Charter",
        "district": "Valley Oak Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60180310709",
    },
    {
        "school": "Extera Public",
        "district": "Extera Public District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60180412982",
    },
    {
        "school": "California Virtual Academy @ San Diego",
        "district": "California Virtual Academy @ San Diego District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60180510641",
    },
    {
        "school": "iLEAD Online",
        "district": "iLEAD Online District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60180614203",
    },
    {
        "school": "High Tech Middle",
        "district": "High Tech Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60180811262",
    },
    {
        "school": "San Diego Cooperative Charter",
        "district": "San Diego Cooperative Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60180910636",
    },
    {
        "school": "California Virtual Academy at Sutter",
        "district": "California Virtual Academy at Sutter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60181013698",
    },
    {
        "school": "Cottonwood Creek Charter",
        "district": "Cottonwood Creek Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60181112647",
    },
    {
        "school": "REACH",
        "district": "REACH District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60181212469",
    },
    {
        "school": "Bellevue-Santa Fe Charter",
        "district": "Bellevue-Santa Fe Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60181305868",
    },
    {
        "school": "Barona Indian Charter",
        "district": "Barona Indian Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60181410631",
    },
    {
        "school": "Leadership Public Schools - Hayward",
        "district": "Leadership Public Schools - Hayward District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60181510737",
    },
    {
        "school": "Urban Montessori Charter",
        "district": "Urban Montessori Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60181613008",
    },
    {
        "school": "Harriet Tubman Village Charter",
        "district": "Harriet Tubman Village Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60181703943",
    },
    {
        "school": "High Tech High North County",
        "district": "High Tech High North County District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60181812064",
    },
    {
        "school": "Conservatory of Vocal/Instrumental Arts High",
        "district": "Conservatory of Vocal/Instrumental Arts High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60181913888",
    },
    {
        "school": "Lemoore Online College Preparatory High",
        "district": "Lemoore Online College Preparatory High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60182014163",
    },
    {
        "school": "Aspire Antonio Maria Lugo Academy",
        "district": "Aspire Antonio Maria Lugo Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60182110891",
    },
    {
        "school": "Antioch Charter Academy II",
        "district": "Antioch Charter Academy II District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60182211984",
    },
    {
        "school": "Gorman Learning Center San Bernardino/Santa Clarita",
        "district": "Gorman Learning Center San Bernardino/Santa Clarita District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60182314328",
    },
    {
        "school": "Higher Learning Academy",
        "district": "Higher Learning Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60182411916",
    },
    {
        "school": "Opportunities for Learning - Duarte",
        "district": "Opportunities for Learning - Duarte District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60182513697",
    },
    {
        "school": "Aspire Vanguard College Preparatory Academy",
        "district": "Aspire Vanguard College Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60182612511",
    },
    {
        "school": "Bay Area Technology",
        "district": "Bay Area Technology District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60182710720",
    },
    {
        "school": "Journey",
        "district": "Journey District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60182814358",
    },
    {
        "school": "Big Picture Educational Academy",
        "district": "Big Picture Educational Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60182912427",
    },
    {
        "school": "EJE Elementary Academy Charter",
        "district": "EJE Elementary Academy Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60183011124",
    },
    {
        "school": "Gilroy Prep (a Navigator School)",
        "district": "Gilroy Prep (a Navigator School) District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60183112751",
    },
    {
        "school": "Kairos Public School Vacaville Academy",
        "district": "Kairos Public School Vacaville Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60183213743",
    },
    {
        "school": "PUC CALS Middle School and Early College High",
        "district": "PUC CALS Middle School and Early College High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60183310890",
    },
    {
        "school": "University High",
        "district": "University High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60183411911",
    },
    {
        "school": "Alliance Marine - Innovation and Technology 6-12 Complex",
        "district": "Alliance Marine - Innovation and Techn 6-12 Complex District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60183513857",
    },
    {
        "school": "School of Universal Learning (SOUL)",
        "district": "School of Universal Learning (SOUL) District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60183614069",
    },
    {
        "school": "Camino Nuevo Charter Academy #4",
        "district": "Camino Nuevo Charter Academy #4 District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60183712915",
    },
    {
        "school": "Steele Canyon High",
        "district": "Steele Canyon High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60183808594",
    },
    {
        "school": "Francophone Charter School of Oakland",
        "district": "Francophone Charter School of Oakland District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60183913942",
    },
    {
        "school": "Thompson Peak Charter",
        "district": "Thompson Peak Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60184014096",
    },
    {
        "school": "JCS - Manzanita",
        "district": "JCS - Manzanita District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60184114353",
    },
    {
        "school": "San Carlos Charter Learning Center",
        "district": "San Carlos Charter Learning Center District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60184204029",
    },
    {
        "school": "CORE Butte Charter",
        "district": "CORE Butte Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60184311953",
    },
    {
        "school": "New West Charter",
        "district": "New West Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60184411208",
    },
    {
        "school": "Sherwood Montessori",
        "district": "Sherwood Montessori District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60184512750",
    },
    {
        "school": "TEAM Charter",
        "district": "TEAM Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60184612900",
    },
    {
        "school": "Mirus Secondary",
        "district": "Mirus Secondary District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60184711899",
    },
    {
        "school": "Rocketship Academy Brilliant Minds",
        "district": "Rocketship Academy Brilliant Minds District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60184813073",
    },
    {
        "school": "Crown Preparatory Academy",
        "district": "Crown Preparatory Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60184912811",
    },
    {
        "school": "Port of Los Angeles High",
        "district": "Port of Los Angeles High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60185010864",
    },
    {
        "school": "California Connections Academy Southern California",
        "district": "California Connections Academy Southern California District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60185110983",
    },
    {
        "school": "ACE Esperanza Middle",
        "district": "ACE Esperanza Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60185213740",
    },
    {
        "school": "Wonderful College Prep Academy - Lost Hills",
        "district": "Wonderful College Prep Academy - Lost Hills District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60185314168",
    },
    {
        "school": "Antelope Valley Learning Academy",
        "district": "Antelope Valley Learning Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60185412022",
    },
    {
        "school": "Audeo Charter II",
        "district": "Audeo Charter II District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60185514028",
    },
    {
        "school": "Fusion Charter",
        "district": "Fusion Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60185613826",
    },
    {
        "school": "Aspire Ollin University Preparatory Academy",
        "district": "Aspire Ollin University Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60185711655",
    },
    {
        "school": "Ingenium Charter Middle",
        "district": "Ingenium Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60185813466",
    },
    {
        "school": "EJE Middle Academy",
        "district": "EJE Middle Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60185912409",
    },
    {
        "school": "Gateway Middle",
        "district": "Gateway Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186112800",
    },
    {
        "school": "Kepler Neighborhood",
        "district": "Kepler Neighborhood District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186213508",
    },
    {
        "school": "ISANA Cardinal Academy",
        "district": "ISANA Cardinal Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186312942",
    },
    {
        "school": "Resolute Academy Charter",
        "district": "Resolute Academy Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186413901",
    },
    {
        "school": "Alliance College-Ready Middle Academy 4",
        "district": "Alliance College-Ready Middle Academy 4 District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186512528",
    },
    {
        "school": "New Los Angeles Charter",
        "district": "New Los Angeles Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186612324",
    },
    {
        "school": "Synergy Quantum Academy",
        "district": "Synergy Quantum Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186712883",
    },
    {
        "school": "Rising Sun Montessori",
        "district": "Rising Sun Montessori District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186813748",
    },
    {
        "school": "Learning Works",
        "district": "Learning Works District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60186912366",
    },
    {
        "school": "Options for Youth-San Bernardino",
        "district": "Options for Youth-San Bernardino District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60187012457",
    },
    {
        "school": "Vista Charter Middle",
        "district": "Vista Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60187112776",
    },
    {
        "school": "John Henry High",
        "district": "John Henry High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60187213892",
    },
    {
        "school": "The Education Corps",
        "district": "The Education Corps District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60187313673",
    },
    {
        "school": "MIT Griffin Academy Middle",
        "district": "MIT Griffin Academy Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60187514264",
    },
    {
        "school": "Charter School of San Diego",
        "district": "Charter School of San Diego District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60187603939",
    },
    {
        "school": "Accelerated Achievement Academy",
        "district": "Accelerated Achievement Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60187710552",
    },
    {
        "school": "High Tech Middle Media Arts",
        "district": "High Tech Middle Media Arts District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60187811155",
    },
    {
        "school": "BRIDGES Charter",
        "district": "BRIDGES Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60187912617",
    },
    {
        "school": "American Indian Public Charter II",
        "district": "American Indian Public Charter II District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60188012013",
    },
    {
        "school": "ICEF View Park Preparatory Elementary",
        "district": "ICEF View Park Preparatory Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60188108030",
    },
    {
        "school": "Fuente Nueva Charter",
        "district": "Fuente Nueva Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60188210799",
    },
    {
        "school": "Endeavor College Preparatory Charter",
        "district": "Endeavor College Preparatory Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60188312536",
    },
    {
        "school": "California Virtual Academy at Kings",
        "district": "California Virtual Academy at Kings District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60188411996",
    },
    {
        "school": "Magnolia Science Academy 5",
        "district": "Magnolia Science Academy 5 District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60188512347",
    },
    {
        "school": "Learning Without Limits",
        "district": "Learning Without Limits District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60188612054",
    },
    {
        "school": "Nea Community Learning Center",
        "district": "Nea Community Learning Center District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60188712399",
    },
    {
        "school": "Discovery Charter",
        "district": "Discovery Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60188810393",
    },
    {
        "school": "Stella Middle Charter Academy",
        "district": "Stella Middle Charter Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60188911361",
    },
    {
        "school": "High Tech High International",
        "district": "High Tech High International District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60189111138",
    },
    {
        "school": "Leadership Public Schools: Richmond",
        "district": "Leadership Public Schools: Richmond District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60189211225",
    },
    {
        "school": "San Diego Virtual",
        "district": "San Diego Virtual District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60189312767",
    },
    {
        "school": "Santiago Middle",
        "district": "Santiago Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60189404450",
    },
    {
        "school": "Forest Ranch Charter",
        "district": "Forest Ranch Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60189512233",
    },
    {
        "school": "Albert Einstein Academy Charter Middle",
        "district": "Albert Einstein Academy Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60189611766",
    },
    {
        "school": "Scale Leadership Academy - East",
        "district": "Scale Leadership Academy - East District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60189714356",
    },
    {
        "school": "Vaughn Next Century Learning Center",
        "district": "Vaughn Next Century Learning Center District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60189803426",
    },
    {
        "school": "Animo Ralph Bunche Charter High",
        "district": "Animo Ralph Bunche Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60189911635",
    },
    {
        "school": "Alliance Piera Barbaglia Shaheen Health Services Academy",
        "district": "Alliance Piera Barbaglia Shaheen HLT SRVs Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60190012378",
    },
    {
        "school": "East Palo Alto Academy",
        "district": "East Palo Alto Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60190111431",
    },
    {
        "school": "El Camino Real Charter High",
        "district": "El Camino Real Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60190202977",
    },
    {
        "school": "Children's Community Charter",
        "district": "Children's Community Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60190305717",
    },
    {
        "school": "Larchmont Charter",
        "district": "Larchmont Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60190410870",
    },
    {
        "school": "PUC Milagro Charter",
        "district": "PUC Milagro Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60190510835",
    },
    {
        "school": "Escuela Popular Accelerated Family Learning",
        "district": "Escuela Popular Accelerated Family Learning District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60190610666",
    },
    {
        "school": "Downtown Value",
        "district": "Downtown Value District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60190710522",
    },
    {
        "school": "River Oaks Academy",
        "district": "River Oaks Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60190812801",
    },
    {
        "school": "Northern United - Humboldt Charter",
        "district": "Northern United - Humboldt Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60190914323",
    },
    {
        "school": "Academy for Academic Excellence",
        "district": "Academy for Academic Excellence District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60191107296",
    },
    {
        "school": "Summit Public School K2",
        "district": "Summit Public School K2 District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60191213776",
    },
    {
        "school": "Charter School of Morgan Hill",
        "district": "Charter School of Morgan Hill District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60191310405",
    },
    {
        "school": "California School of the Arts - San Gabriel Valley",
        "district": "California School of the Arts - San Gabriel Valley District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60191414083",
    },
    {
        "school": "Odyssey Charter",
        "district": "Odyssey Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60191508012",
    },
    {
        "school": "Willits Charter",
        "district": "Willits Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60191608213",
    },
    {
        "school": "Our Community Charter",
        "district": "Our Community Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60191710896",
    },
    {
        "school": "ICEF Vista Middle Academy",
        "district": "ICEF Vista Middle Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60191811954",
    },
    {
        "school": "Ballington Acad for the Arts and Scis - San Bernardino",
        "district": "Ballington Acad for Arts & Scis - San Bernardino District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60191913983",
    },
    {
        "school": "KIPP Corazon Academy",
        "district": "KIPP Corazon Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60192014108",
    },
    {
        "school": "Voices College-Bound Language Acad at W. Contra Costa Co",
        "district": "Voices College-Bound Lang Acad @ W. Contra Costa Co District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60192114227",
    },
    {
        "school": "Redwood Coast Montessori",
        "district": "Redwood Coast Montessori District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60192214287",
    },
    {
        "school": "N.E.W. Academy of Science and Arts",
        "district": "N.E.W. Academy of Science and Arts District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60192311333",
    },
    {
        "school": "Olivet Elementary Charter",
        "district": "Olivet Elementary Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60192404738",
    },
    {
        "school": "Anahuacalmecac International Univ Prep of N. America",
        "district": "Anahuacalmecac International Univ Prep N. America District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60192512271",
    },
    {
        "school": "Alliance Dr. Olga Mohan High",
        "district": "Alliance Dr. Olga Mohan High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60192611633",
    },
    {
        "school": "Phoenix Charter Academy",
        "district": "Phoenix Charter Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60192714159",
    },
    {
        "school": "Integrity Charter",
        "district": "Integrity Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60192811237",
    },
    {
        "school": "JCS - Mountain Oaks",
        "district": "JCS - Mountain Oaks District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60192914231",
    },
    {
        "school": "Ridgecrest Elem Acad for Language Music and Sci",
        "district": "Ridgecrest Elem Acad for Language Music and Sci District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60193108706",
    },
    {
        "school": "Latino College Preparatory Academy",
        "district": "Latino College Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60193210402",
    },
    {
        "school": "Primary Charter",
        "district": "Primary Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60193311425",
    },
    {
        "school": "Alliance Judy Ivie Burton Technology Academy High",
        "district": "Alliance Judy Ivie Burton Technology Academy High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60193410867",
    },
    {
        "school": "Mojave River Academy - National Trails",
        "district": "Mojave River Academy - National Trails District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60193514219",
    },
    {
        "school": "Novato Charter",
        "district": "Novato Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60193606035",
    },
    {
        "school": "Lighthouse Community Charter",
        "district": "Lighthouse Community Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60193710408",
    },
    {
        "school": "Trivium Charter School Voyage",
        "district": "Trivium Charter School Voyage District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60193814237",
    },
    {
        "school": "Arts in Action Community Middle",
        "district": "Arts in Action Community Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60193914061",
    },
    {
        "school": "Grossmont Secondary",
        "district": "Grossmont Secondary District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60194014169",
    },
    {
        "school": "Ipakanni Early College Charter",
        "district": "Ipakanni Early College Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60194112613",
    },
    {
        "school": "Northcoast Preparatory and Performing Arts Academy",
        "district": "Northcoast Preparatory and Performing Arts Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60194211934",
    },
    {
        "school": "Almond Acres Charter Academy",
        "district": "Almond Acres Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60194313176",
    },
    {
        "school": "Equitas Academy #3 Charter",
        "district": "Equitas Academy #3 Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60194413802",
    },
    {
        "school": "Palmdale Aerospace Academy",
        "district": "Palmdale Aerospace Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60194513029",
    },
    {
        "school": "Rise Kohyang High",
        "district": "Rise Kohyang High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60194613974",
    },
    {
        "school": "Empower Generations",
        "district": "Empower Generations District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60194714042",
    },
    {
        "school": "GOALS Academy",
        "district": "GOALS Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60194813858",
    },
    {
        "school": "Today's Fresh Start-Compton",
        "district": "Today's Fresh Start-Compton District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195211336",
    },
    {
        "school": "Valley International Preparatory High",
        "district": "Valley International Preparatory High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195314248",
    },
    {
        "school": "National University Academy Dual Language Institute",
        "district": "National University Academy Dual Language Institute District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195414341",
    },
    {
        "school": "Lashon Academy",
        "district": "Lashon Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195513261",
    },
    {
        "school": "Elite Academic Academy - Adult Work Force Investment",
        "district": "Elite ACAD Academy - Adult Work Force Investment District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195614359",
    },
    {
        "school": "KIPP San Francisco College Preparatory",
        "district": "KIPP San Francisco College Preparatory District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195713410",
    },
    {
        "school": "Libertas College Preparatory Charter",
        "district": "Libertas College Preparatory Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195813902",
    },
    {
        "school": "Pacoima Charter Elementary",
        "district": "Pacoima Charter Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60195903261",
    },
    {
        "school": "Animo James B. Taylor Charter Middle",
        "district": "Animo James B. Taylor Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60196012908",
    },
    {
        "school": "Pacific Coast Academy",
        "district": "Pacific Coast Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60196114103",
    },
    {
        "school": "Oxford Preparatory Academy - South Orange County",
        "district": "Oxford Preparatory Academy - South Orange County District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60196212855",
    },
    {
        "school": "Venture Academy",
        "district": "Venture Academy District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60196310651",
    },
    {
        "school": "iQ Academy California-Los Angeles",
        "district": "iQ Academy California-Los Angeles District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60196412477",
    },
    {
        "school": "Soleil Academy Charter",
        "district": "Soleil Academy Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60196514349",
    },
    {
        "school": "Excelsior Charter School Corona-Norco",
        "district": "Excelsior Charter School Corona-Norco District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60196614354",
    },
    {
        "school": "LPS Oakland R & D Campus",
        "district": "LPS Oakland R & D Campus District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60196713155",
    },
    {
        "school": "Ednovate - East College Prep",
        "district": "Ednovate - East College Prep District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60196813898",
    },
    {
        "school": "John Adams Academy - El Dorado Hills",
        "district": "John Adams Academy - El Dorado Hills District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60196914072",
    },
    {
        "school": "Taylion High Desert Academy/Adelanto",
        "district": "Taylion High Desert Academy/Adelanto District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60197013723",
    },
    {
        "school": "Oakland Military Institute College Preparatory Academy",
        "district": "Oakland Military InstituteCollege Preparatory ACAD District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60197110729",
    },
    {
        "school": "Woodland Star Charter",
        "district": "Woodland Star Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60197211484",
    },
    {
        "school": "Da Vinci Design",
        "district": "Da Vinci Design District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60197312410",
    },
    {
        "school": "Vox Collegiate of Los Angeles",
        "district": "Vox Collegiate of Los Angeles District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60197414221",
    },
    {
        "school": "Clarksville Charter",
        "district": "Clarksville Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60197514165",
    },
    {
        "school": "California Montessori Project-Shingle Springs Campus",
        "district": "CA Montessori Project-Shingle Springs Campus District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60197611580",
    },
    {
        "school": "Knowledge Enlightens You (KEY) Academy",
        "district": "Knowledge Enlightens You (KEY) Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60197713351",
    },
    {
        "school": "Stone Bridge",
        "district": "Stone Bridge District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60197810975",
    },
    {
        "school": "Delta Elementary Charter",
        "district": "Delta Elementary Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60197912128",
    },
    {
        "school": "Leadership Military Academy - Indio",
        "district": "Leadership Military Academy - Indio District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60198114007",
    },
    {
        "school": "Golden Valley Tahoe",
        "district": "Golden Valley Tahoe District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60198214371",
    },
    {
        "school": "Camino Polytechnic",
        "district": "Camino Polytechnic District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60198312702",
    },
    {
        "school": "Baypoint Preparatory Academy",
        "district": "Baypoint Preparatory Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60198413941",
    },
    {
        "school": "John Adams Academy - Lincoln",
        "district": "John Adams Academy - Lincoln District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60198614071",
    },
    {
        "school": "National University Academy 1001 STEAM",
        "district": "National University Academy 1001 STEAM District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60198714294",
    },
    {
        "school": "MAAC Community Charter",
        "district": "MAAC Community Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60198810384",
    },
    {
        "school": "All Tribes Charter",
        "district": "All Tribes Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60198910387",
    },
    {
        "school": "California Virtual Academy @ San Joaquin",
        "district": "California Virtual Academy @ San Joaquin District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60199013191",
    },
    {
        "school": "Dimensions Collaborative",
        "district": "Dimensions Collaborative District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60199114308",
    },
    {
        "school": "Leonardo da Vinci Health Sciences Charter",
        "district": "Leonardo da Vinci Health Sciences Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60199212425",
    },
    {
        "school": "Voices College-Bound Language Academy",
        "district": "Voices College-Bound Language Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60199312031",
    },
    {
        "school": "Aspire ERES Academy",
        "district": "Aspire ERES Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60199412542",
    },
    {
        "school": "Redwood Preparatory Charter",
        "district": "Redwood Preparatory Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60199512857",
    },
    {
        "school": "Yuba City Charter",
        "district": "Yuba City Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60199608658",
    },
    {
        "school": "Monarch Learning Center",
        "district": "Monarch Learning Center District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60199708636",
    },
    {
        "school": "Five Keys Charter (SF Sheriff's)",
        "district": "Five Keys Charter (SF Sheriff's) District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60199811407",
    },
    {
        "school": "Three Rivers Charter",
        "district": "Three Rivers Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60199912818",
    },
    {
        "school": "Camino Nuevo High #2",
        "district": "Camino Nuevo High #2 District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60200013537",
    },
    {
        "school": "NextGeneration STEAM Academy",
        "district": "NextGeneration STEAM Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60200113850",
    },
    {
        "school": "Old Town Academy K-8 Charter",
        "district": "Old Town Academy K-8 Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60200212786",
    },
    {
        "school": "Natomas Charter",
        "district": "Natomas Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60200307250",
    },
    {
        "school": "Ednovate - Esperanza College Prep",
        "district": "Ednovate - Esperanza College Prep District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60200414117",
    },
    {
        "school": "Julian Charter",
        "district": "Julian Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60200508596",
    },
    {
        "school": "Northwest Prep Charter",
        "district": "Northwest Prep Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60200611480",
    },
    {
        "school": "Pasadena Rosebud Academy",
        "district": "Pasadena Rosebud Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60200711918",
    },
    {
        "school": "Gateway College and Career Academy",
        "district": "Gateway College and Career Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60200813730",
    },
    {
        "school": "Sycamore Academy of Science and Cultural Arts",
        "district": "Sycamore Academy of Science and Cultural Arts District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60200912433",
    },
    {
        "school": "University Preparation Charter School at CSU Channel Islands",
        "district": "UNIV Preparation Charter SCH @ CSU Channel Islands District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60201110711",
    },
    {
        "school": "Golden Valley Charter",
        "district": "Golden Valley Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60201210451",
    },
    {
        "school": "Yu Ming Charter",
        "district": "Yu Ming Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60201312901",
    },
    {
        "school": "Nord Country",
        "district": "Nord Country District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60201411569",
    },
    {
        "school": "King-Chavez Primary Academy",
        "district": "King-Chavez Primary Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60201505556",
    },
    {
        "school": "Oxford Day Academy",
        "district": "Oxford Day Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60201614082",
    },
    {
        "school": "KIPP Promesa Prep",
        "district": "KIPP Promesa Prep District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60201713877",
    },
    {
        "school": "Barack Obama Charter",
        "district": "Barack Obama Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60201812404",
    },
    {
        "school": "Jardin de la Infancia",
        "district": "Jardin de la Infancia District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60201910853",
    },
    {
        "school": "KIPP Los Angeles College Preparatory",
        "district": "KIPP Los Angeles College Preparatory District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60202011324",
    },
    {
        "school": "Sierra Academy of Expeditionary Learning",
        "district": "Sierra Academy of Expeditionary Learning District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60202112922",
    },
    {
        "school": "Camarillo Academy of Progressive Education",
        "district": "Camarillo Academy of Progressive Education District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60202211873",
    },
    {
        "school": "Ingenium Charter",
        "district": "Ingenium Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60202312570",
    },
    {
        "school": "La Vida Charter",
        "district": "La Vida Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60202411686",
    },
    {
        "school": "Ivy Academia",
        "district": "Ivy Academia District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60202510845",
    },
    {
        "school": "Summit Public School: Tamalpais",
        "district": "Summit Public School: Tamalpais District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60202613986",
    },
    {
        "school": "Antioch Charter Academy",
        "district": "Antioch Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60202707493",
    },
    {
        "school": "KIPP Excelencia Community Preparatory",
        "district": "KIPP Excelencia Community Preparatory District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60203013874",
    },
    {
        "school": "Global Education Academy 2",
        "district": "Global Education Academy 2 District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60203213789",
    },
    {
        "school": "Gateway International",
        "district": "Gateway International District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60203413656",
    },
    {
        "school": "Pacific Springs Charter",
        "district": "Pacific Springs Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60203514290",
    },
    {
        "school": "Eleanor Roosevelt Community Learning Center",
        "district": "Eleanor Roosevelt Community Learning Center District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60203610445",
    },
    {
        "school": "Invictus Academy of Richmond",
        "district": "Invictus Academy of Richmond District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60203714304",
    },
    {
        "school": "Luis Valdez Leadership Academy",
        "district": "Luis Valdez Leadership Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60203813815",
    },
    {
        "school": "Golden Eagle Charter",
        "district": "Golden Eagle Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60203912203",
    },
    {
        "school": "NOVA Academy - Coachella",
        "district": "NOVA Academy - Coachella District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60204012684",
    },
    {
        "school": "KIPP Vida Preparatory Academy",
        "district": "KIPP Vida Preparatory Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60204113760",
    },
    {
        "school": "Olive Grove Charter - Orcutt/Santa Maria",
        "district": "Olive Grove Charter - Orcutt/Santa Maria District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60204214265",
    },
    {
        "school": "Ednovate - Legacy College Prep.",
        "district": "Ednovate - Legacy College Prep. District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60204314046",
    },
    {
        "school": "Desert Trails Preparatory Academy",
        "district": "Desert Trails Preparatory Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60204403819",
    },
    {
        "school": "STEM Preparatory Elementary",
        "district": "STEM Preparatory Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60204514315",
    },
    {
        "school": "Aspire Berkley Maynard Academy",
        "district": "Aspire Berkley Maynard Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60204610727",
    },
    {
        "school": "KIPP San Jose Collegiate",
        "district": "KIPP San Jose Collegiate District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60204712236",
    },
    {
        "school": "Grace Hopper STEM Academy",
        "district": "Grace Hopper STEM Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60204813719",
    },
    {
        "school": "High Tech Elementary Mesa",
        "district": "High Tech Elementary Mesa District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60204914415",
    },
    {
        "school": "Citizens of the World Charter School Hollywood",
        "district": "Citizens of the World Charter School Hollywood District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60205012708",
    },
    {
        "school": "Samueli Academy",
        "district": "Samueli Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60205113076",
    },
    {
        "school": "Animo Leadership High",
        "district": "Animo Leadership High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60205208504",
    },
    {
        "school": "Maria Montessori Charter Academy",
        "district": "Maria Montessori Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60205312302",
    },
    {
        "school": "Thomas Edison Charter Academy",
        "district": "Thomas Edison Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60205410388",
    },
    {
        "school": "Paragon Collegiate Academy",
        "district": "Paragon Collegiate Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60205512661",
    },
    {
        "school": "KIPP Philosophers Academy",
        "district": "KIPP Philosophers Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60205613002",
    },
    {
        "school": "STREAM Charter",
        "district": "STREAM Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60205713790",
    },
    {
        "school": "Union Street Charter",
        "district": "Union Street Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60205811590",
    },
    {
        "school": "Aspire Rosa Parks Academy",
        "district": "Aspire Rosa Parks Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60205911423",
    },
    {
        "school": "iLEAD Lancaster Charter",
        "district": "iLEAD Lancaster Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60206013037",
    },
    {
        "school": "High Tech High Chula Vista",
        "district": "High Tech High Chula Vista District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60206112083",
    },
    {
        "school": "Blue Ridge Academy",
        "district": "Blue Ridge Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60206214020",
    },
    {
        "school": "Ingenium Clarion Charter Middle",
        "district": "Ingenium Clarion Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60206314249",
    },
    {
        "school": "Voices College-Bound Language Academy at Mt. Pleasant",
        "district": "Voices College-Bound Language ACAD at Mt. Pleasant District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60206413925",
    },
    {
        "school": "Sacramento Valley Charter",
        "district": "Sacramento Valley Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60206512962",
    },
    {
        "school": "Children of Promise Preparatory Academy",
        "district": "Children of Promise Preparatory Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60206612576",
    },
    {
        "school": "Temecula Valley Charter",
        "district": "Temecula Valley Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60206803648",
    },
    {
        "school": "Aspire Benjamin Holt Middle",
        "district": "Aspire Benjamin Holt Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60206913963",
    },
    {
        "school": "Bear Valley Elementary",
        "district": "Alpine County Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60207014292",
    },
    {
        "school": "Chula Vista Learning Community Charter",
        "district": "Chula Vista Learning Community Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60207107649",
    },
    {
        "school": "Alder Grove Charter School 2",
        "district": "Alder Grove Charter School 2 District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60207211593",
    },
    {
        "school": "Highland Academy",
        "district": "Highland Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60207313150",
    },
    {
        "school": "Aveson School of Leaders",
        "district": "Aveson School of Leaders District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60207411929",
    },
    {
        "school": "Hawking S.T.E.A.M. Charter",
        "district": "Hawking S.T.E.A.M. Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60207513113",
    },
    {
        "school": "Environmental Charter High",
        "district": "Environmental Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60207608718",
    },
    {
        "school": "Camino Nuevo Elementary School #3",
        "district": "Camino Nuevo Elementary School #3 District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60207712805",
    },
    {
        "school": "Synergy Kinetic Academy",
        "district": "Synergy Kinetic Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60207812276",
    },
    {
        "school": "Diego Hills Central Public Charter",
        "district": "Diego Hills Central Public Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60207914199",
    },
    {
        "school": "Journey",
        "district": "Journey District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60208008542",
    },
    {
        "school": "Community Outreach Academy",
        "district": "Community Outreach Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60208111200",
    },
    {
        "school": "PUC Inspire Charter Academy",
        "district": "PUC Inspire Charter Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60208213750",
    },
    {
        "school": "University Preparatory Value High",
        "district": "University Preparatory Value High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60208312699",
    },
    {
        "school": "Temecula Preparatory",
        "district": "Temecula Preparatory District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60208408564",
    },
    {
        "school": "Everest Value",
        "district": "Everest Value District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60208513756",
    },
    {
        "school": "Rocketship Spark Academy",
        "district": "Rocketship Spark Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60208713582",
    },
    {
        "school": "Pathways Charter",
        "district": "Pathways Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60208810685",
    },
    {
        "school": "River Springs Charter",
        "district": "River Springs Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60208911707",
    },
    {
        "school": "Learning by Design Charter",
        "district": "Learning by Design Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60209014271",
    },
    {
        "school": "Grimmway Academy Shafter",
        "district": "Grimmway Academy Shafter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60209114186",
    },
    {
        "school": "Alain Leroy Locke College Preparatory Academy",
        "district": "Alain Leroy Locke College Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60209212248",
    },
    {
        "school": "Bert Corona Charter",
        "district": "Bert Corona Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60209310852",
    },
    {
        "school": "St. HOPE Public School 7",
        "district": "St. HOPE Public School 7 District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60209411199",
    },
    {
        "school": "Aspire Summit Charter Academy",
        "district": "Aspire Summit Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60209511809",
    },
    {
        "school": "Animo Florence-Firestone Charter Middle",
        "district": "Animo Florence-Firestone Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60209614036",
    },
    {
        "school": "High Tech Elementary Chula Vista",
        "district": "High Tech Elementary Chula Vista District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60209712726",
    },
    {
        "school": "Literacy First Charter",
        "district": "Literacy First Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60209810374",
    },
    {
        "school": "Ivy Bound Acad of Math Sci and Tech Charter Mid",
        "district": "Ivy Bound Acad of Math Sci and Tech Charter Mid District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60209911856",
    },
    {
        "school": "Santa Rosa Academy",
        "district": "Santa Rosa Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210111023",
    },
    {
        "school": "PUC Excel Charter Academy",
        "district": "PUC Excel Charter Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210211657",
    },
    {
        "school": "City Arts and Tech High",
        "district": "City Arts and Tech High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210311408",
    },
    {
        "school": "Escalon Charter Academy",
        "district": "Escalon Charter Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210413059",
    },
    {
        "school": "Animo Westside Charter Middle",
        "district": "Animo Westside Charter Middle District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210512631",
    },
    {
        "school": "Museum",
        "district": "Museum District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210607689",
    },
    {
        "school": "San Diego Workforce Innovation High",
        "district": "San Diego Workforce Innovation High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210814037",
    },
    {
        "school": "John Muir Charter",
        "district": "John Muir Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60210908230",
    },
    {
        "school": "School for Entrepreneurship and Technology",
        "district": "School for Entrepreneurship and Technology District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60211012640",
    },
    {
        "school": "Center for Advanced Learning",
        "district": "Center for Advanced Learning District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60211112044",
    },
    {
        "school": "Aspire College Academy",
        "district": "Aspire College Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60211213676",
    },
    {
        "school": "Unity Middle College High",
        "district": "Unity Middle College High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60211314191",
    },
    {
        "school": "Public Safety Academy",
        "district": "Public Safety Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60211511108",
    },
    {
        "school": "Bert Corona Charter High",
        "district": "Bert Corona Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60211613897",
    },
    {
        "school": "Gorman Learning Center",
        "district": "Gorman Learning Center District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60211708502",
    },
    {
        "school": "Five Keys Independence HS (SF Sheriff's)",
        "district": "Five Keys Independence HS (SF Sheriff's) District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60211812256",
    },
    {
        "school": "Alliance Cindy and Bill Simon Technology Academy High",
        "district": "Alliance Cindy and Bill Simon Technology ACAD High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60211912567",
    },
    {
        "school": "Bay View Academy",
        "district": "Bay View Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60212012864",
    },
    {
        "school": "Richmond Charter Academy",
        "district": "Richmond Charter Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60212113164",
    },
    {
        "school": "Learning Choice Academy - Chula Vista",
        "district": "Learning Choice Academy - Chula Vista District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60212214260",
    },
    {
        "school": "Aspire Alexander Twilight College Preparatory Academy",
        "district": "Aspire Alexander Twilight College Preparatory ACAD District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60212312449",
    },
    {
        "school": "Career Technical Education Charter",
        "district": "Career Technical Education Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60212414297",
    },
    {
        "school": "Fenton Avenue Charter",
        "district": "Fenton Avenue Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60212603000",
    },
    {
        "school": "California Connections Academy North Bay",
        "district": "California Connections Academy North Bay District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60212713769",
    },
    {
        "school": "Equitas Academy 4",
        "district": "Equitas Academy 4 District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60212813970",
    },
    {
        "school": "Greater San Diego Academy",
        "district": "Greater San Diego Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60212908302",
    },
    {
        "school": "Edward B. Cole Academy",
        "district": "Edward B. Cole Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60213011223",
    },
    {
        "school": "Central City Value",
        "district": "Central City Value District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60213111337",
    },
    {
        "school": "Olive Grove Charter - Lompoc",
        "district": "Olive Grove Charter - Lompoc District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60213214218",
    },
    {
        "school": "Achieve Charter School of Paradise Inc.",
        "district": "Achieve Charter School of Paradise Inc. District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60213311571",
    },
    {
        "school": "IvyTech Charter",
        "district": "IvyTech Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60213412564",
    },
    {
        "school": "PUC Early College Academy for Leaders and Scholars (ECALS)",
        "district": "PUC Early College ACAD for Leaders&Scholars(ECALS) District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60213512869",
    },
    {
        "school": "The O'Farrell Charter",
        "district": "The O'Farrell Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60213610056",
    },
    {
        "school": "Santa Clarita Valley International",
        "district": "Santa Clarita Valley International District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60213712191",
    },
    {
        "school": "ACE Inspire Academy",
        "district": "ACE Inspire Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60213813852",
    },
    {
        "school": "Alliance College-Ready Middle Academy 5",
        "district": "Alliance College-Ready Middle Academy 5 District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60213912474",
    },
    {
        "school": "KIPP Empower Academy",
        "district": "KIPP Empower Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60214012717",
    },
    {
        "school": "KIPP Iluminar Academy",
        "district": "KIPP Iluminar Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60214213657",
    },
    {
        "school": "Gabriella Charter",
        "district": "Gabriella Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60214310866",
    },
    {
        "school": "Alpha: Jose Hernandez",
        "district": "Alpha: Jose Hernandez District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60214413757",
    },
    {
        "school": "N.E.W. Academy Canoga Park",
        "district": "N.E.W. Academy Canoga Park District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60214510838",
    },
    {
        "school": "Today's Fresh Start Charter School Inglewood",
        "district": "Today's Fresh Start Charter School Inglewood District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60214612416",
    },
    {
        "school": "Empowering Possibilities International Charter",
        "district": "Empowering Possibilities International Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60214713935",
    },
    {
        "school": "Preuss School UCSD",
        "district": "Preuss School UCSD District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60214808303",
    },
    {
        "school": "Village Charter",
        "district": "Village Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60214911882",
    },
    {
        "school": "Method Schools LA",
        "district": "Method Schools LA District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60215014259",
    },
    {
        "school": "Vincent Academy",
        "district": "Vincent Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60215112648",
    },
    {
        "school": "KIPP King Collegiate High",
        "district": "KIPP King Collegiate High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60215211893",
    },
    {
        "school": "Ezequiel Tafoya Alvarado Academy",
        "district": "Ezequiel Tafoya Alvarado Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60215310951",
    },
    {
        "school": "KIPP Scholar Academy",
        "district": "KIPP Scholar Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60215413004",
    },
    {
        "school": "Creative Arts Charter",
        "district": "Creative Arts Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60215503982",
    },
    {
        "school": "Placer Academy Charter",
        "district": "Placer Academy Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60215614215",
    },
    {
        "school": "Tree of Life International Charter",
        "district": "Tree of Life International Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60215700736",
    },
    {
        "school": "Connecting Waters Charter - East Bay",
        "district": "Connecting Waters Charter - East Bay District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60215914091",
    },
    {
        "school": "Live Oak Charter",
        "district": "Live Oak Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216110431",
    },
    {
        "school": "Rocketship Futuro Academy",
        "district": "Rocketship Futuro Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216214044",
    },
    {
        "school": "Perseverance Preparatory",
        "district": "Perseverance Preparatory District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216314412",
    },
    {
        "school": "School of Unlimited Learning",
        "district": "School of Unlimited Learning District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216407497",
    },
    {
        "school": "Achieve Academy",
        "district": "Achieve Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216511561",
    },
    {
        "school": "Sunrise Middle",
        "district": "Sunrise Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216612865",
    },
    {
        "school": "Ambassador Phillip V. Sanchez II Public Charter",
        "district": "Ambassador Phillip V. Sanchez II Public Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216714206",
    },
    {
        "school": "Coastal Grove Charter",
        "district": "Coastal Grove Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216810500",
    },
    {
        "school": "Summit Public School: Denali",
        "district": "Summit Public School: Denali District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60216913485",
    },
    {
        "school": "Connecting Waters Charter",
        "district": "Connecting Waters Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60217010698",
    },
    {
        "school": "Insight @ San Joaquin",
        "district": "Insight @ San Joaquin District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60217113952",
    },
    {
        "school": "KIPP Bayview Academy",
        "district": "KIPP Bayview Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60217211256",
    },
    {
        "school": "Feaster (Mae L.) Charter",
        "district": "Feaster (Mae L.) Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60217300858",
    },
    {
        "school": "iLead Agua Dulce",
        "district": "iLead Agua Dulce District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60217414324",
    },
    {
        "school": "Allegiance STEAM Academy - Thrive",
        "district": "Allegiance STEAM Academy - Thrive District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60217514235",
    },
    {
        "school": "Alliance Gertz-Ressler Richard Merkin 6-12 Complex",
        "district": "Alliance Gertz-Ressler Richard Merkin 6-12 Complex District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60217610851",
    },
    {
        "school": "Blue Oak Charter",
        "district": "Blue Oak Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60217708682",
    },
    {
        "school": "Goethe International Charter",
        "district": "Goethe International Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60217812215",
    },
    {
        "school": "The Academy of Alameda Elementary",
        "district": "The Academy of Alameda Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60217913871",
    },
    {
        "school": "School of Arts and Enterprise",
        "district": "School of Arts and Enterprise District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60218011207",
    },
    {
        "school": "Aveson Global Leadership Academy",
        "district": "Aveson Global Leadership Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60218112028",
    },
    {
        "school": "PUC Comm Charter Mid and PUC Comm Charter Early College High",
        "district": "PUC Comm CHRTR Mid & PUC Comm CHRTR Early College High DIST",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60218208027",
    },
    {
        "school": "Growth Public",
        "district": "Growth Public District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60218314124",
    },
    {
        "school": "KIPP Navigate College Prep",
        "district": "KIPP Navigate College Prep District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60218414282",
    },
    {
        "school": "King-Chavez Community High",
        "district": "King-Chavez Community High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60218512195",
    },
    {
        "school": "Citizens of the World Charter School Mar Vista",
        "district": "Citizens of the World Charter School Mar Vista District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60218613088",
    },
    {
        "school": "Animo Compton Charter",
        "district": "Animo Compton Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60218714269",
    },
    {
        "school": "Paseo Grande Charter",
        "district": "Paseo Grande Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60218813882",
    },
    {
        "school": "Para Los Ni?os - Evelyn Thurman Gratts Primary",
        "district": "Para Los Ni?os - Evelyn Thurman Gratts Primary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60218912616",
    },
    {
        "school": "Alliance Susan and Eric Smidt Technology High",
        "district": "Alliance Susan and Eric Smidt Technology High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60219012817",
    },
    {
        "school": "Rocketship Los Suenos Academy",
        "district": "Rocketship Los Suenos Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60219112478",
    },
    {
        "school": "East Bay Innovation Academy",
        "district": "East Bay Innovation Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60219213735",
    },
    {
        "school": "Ventura Charter School of Arts and Global Education",
        "district": "Ventura Charter School of Arts and Global Education District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60219311829",
    },
    {
        "school": "Magnolia Science Academy 3",
        "district": "Magnolia Science Academy 3 District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60219412010",
    },
    {
        "school": "New Opportunities Charter",
        "district": "New Opportunities Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60219513732",
    },
    {
        "school": "Aspire Slauson Academy Charter",
        "district": "Aspire Slauson Academy Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60219612950",
    },
    {
        "school": "Santa Ynez Valley Charter",
        "district": "Santa Ynez Valley Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60219710398",
    },
    {
        "school": "King-Chavez Athletics Academy",
        "district": "King-Chavez Athletics Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60219811391",
    },
    {
        "school": "Life Source International Charter",
        "district": "Life Source International Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60219912650",
    },
    {
        "school": "Intellectual Virtues Academy of Long Beach",
        "district": "Intellectual Virtues Academy of Long Beach District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60220013471",
    },
    {
        "school": "Grove",
        "district": "Grove District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60220108292",
    },
    {
        "school": "TEACH Academy of Technologies",
        "district": "TEACH Academy of Technologies District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60220212622",
    },
    {
        "school": "North County Trade Tech High",
        "district": "North County Trade Tech High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60220311970",
    },
    {
        "school": "River Montessori Elementary Charter",
        "district": "River Montessori Elementary Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60220412549",
    },
    {
        "school": "Magnolia Science Academy 6",
        "district": "Magnolia Science Academy 6 District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60220512322",
    },
    {
        "school": "Granada Hills Charter",
        "district": "Granada Hills Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60220603050",
    },
    {
        "school": "Elite Academic Academy - Lucerne",
        "district": "Elite Academic Academy - Lucerne District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60220714250",
    },
    {
        "school": "Oakland Charter Academy",
        "district": "Oakland Charter Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60220802893",
    },
    {
        "school": "Mojave River Academy - Oro Grande",
        "district": "Mojave River Academy - Oro Grande District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60220914262",
    },
    {
        "school": "Kinetic Academy",
        "district": "Kinetic Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60221014050",
    },
    {
        "school": "Helix High",
        "district": "Helix High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60221102023",
    },
    {
        "school": "Aspire Lionel Wilson College Preparatory Academy",
        "district": "Aspire Lionel Wilson College Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60221210459",
    },
    {
        "school": "WISH Community",
        "district": "WISH Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60221314196",
    },
    {
        "school": "Pivot Charter School Riverside",
        "district": "Pivot Charter School Riverside District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60221414240",
    },
    {
        "school": "Da Vinci RISE High",
        "district": "Da Vinci RISE High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60221514355",
    },
    {
        "school": "Harvest Ridge Cooperative Charter",
        "district": "Harvest Ridge Cooperative Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60221612790",
    },
    {
        "school": "ACE Empower Academy",
        "district": "ACE Empower Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60221712198",
    },
    {
        "school": "PREPA TEC - Los Angeles",
        "district": "PREPA TEC - Los Angeles District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60221813348",
    },
    {
        "school": "Animo Watts College Preparatory Academy",
        "district": "Animo Watts College Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60221911640",
    },
    {
        "school": "Alpha: Blanca Alvarado",
        "district": "Alpha: Blanca Alvarado District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60222112989",
    },
    {
        "school": "Summit Public School: Tahoma",
        "district": "Summit Public School: Tahoma District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60222212625",
    },
    {
        "school": "Epic Charter",
        "district": "Epic Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60222313772",
    },
    {
        "school": "Sherman Thomas STEM Academy",
        "district": "Sherman Thomas STEM Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60222514101",
    },
    {
        "school": "Ocean Charter",
        "district": "Ocean Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60222610833",
    },
    {
        "school": "American Indian Public High",
        "district": "American Indian Public High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60222711563",
    },
    {
        "school": "Synergy Charter Academy",
        "district": "Synergy Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60222810846",
    },
    {
        "school": "Everest Public High",
        "district": "Everest Public High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60222912395",
    },
    {
        "school": "YouthBuild Charter School of California",
        "district": "YouthBuild Charter School of California District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60223012197",
    },
    {
        "school": "Collegiate Charter High School of Los Angeles",
        "district": "Collegiate Charter High School of Los Angeles District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60223113851",
    },
    {
        "school": "High Tech Middle Mesa",
        "district": "High Tech Middle Mesa District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60223214427",
    },
    {
        "school": "University Preparatory Academy Charter",
        "district": "University Preparatory Academy Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60223312016",
    },
    {
        "school": "Ross Valley Charter",
        "district": "Ross Valley Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60223414064",
    },
    {
        "school": "Oscar De La Hoya Animo Charter High",
        "district": "Oscar De La Hoya Animo Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60223511313",
    },
    {
        "school": "Mission Preparatory",
        "district": "Mission Preparatory District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60223612768",
    },
    {
        "school": "Camino Nuevo Charter Academy",
        "district": "Camino Nuevo Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60223708508",
    },
    {
        "school": "Silver Oak High Public Montessori Charter",
        "district": "Silver Oak High Public Montessori Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60223813531",
    },
    {
        "school": "Wildflower Open Classroom",
        "district": "Wildflower Open Classroom District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60223912755",
    },
    {
        "school": "Kipp Prize Preparatory Academy",
        "district": "Kipp Prize Preparatory Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60224013778",
    },
    {
        "school": "ISANA Octavia Academy",
        "district": "ISANA Octavia Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60224112782",
    },
    {
        "school": "Fenton Primary Center",
        "district": "Fenton Primary Center District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60224212019",
    },
    {
        "school": "Orange County Academy of Sciences and Arts",
        "district": "Orange County Academy of Sciences and Arts District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60224300688",
    },
    {
        "school": "Great Valley Academy - Salida",
        "district": "Great Valley Academy - Salida District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60224412945",
    },
    {
        "school": "Orange County Educational Arts Academy",
        "district": "Orange County Educational Arts Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60224510992",
    },
    {
        "school": "Sierra Foothill Charter",
        "district": "Sierra Foothill Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60224613041",
    },
    {
        "school": "Guajome Learning Center",
        "district": "Guajome Learning Center District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60224712930",
    },
    {
        "school": "Audeo Charter School III",
        "district": "Audeo Charter School III District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60224814228",
    },
    {
        "school": "Para Los Ni?os Charter",
        "district": "Para Los Ni?os Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60224910526",
    },
    {
        "school": "Downtown College Preparatory Middle",
        "district": "Downtown College Preparatory Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60225113738",
    },
    {
        "school": "Dixon Montessori Charter",
        "district": "Dixon Montessori Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60225211473",
    },
    {
        "school": "Chrysalis Charter",
        "district": "Chrysalis Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60225311800",
    },
    {
        "school": "Magnolia Science Academy 7",
        "district": "Magnolia Science Academy 7 District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60225412235",
    },
    {
        "school": "Discovery Charter Preparatory #2",
        "district": "Discovery Charter Preparatory #2 District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60225511889",
    },
    {
        "school": "Valiente College Preparatory Charter",
        "district": "Valiente College Preparatory Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60225613895",
    },
    {
        "school": "Animo Pat Brown",
        "district": "Animo Pat Brown District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60225710849",
    },
    {
        "school": "Coastal Academy Charter",
        "district": "Coastal Academy Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60225814145",
    },
    {
        "school": "KIPP Heritage Academy",
        "district": "KIPP Heritage Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60225913763",
    },
    {
        "school": "Sonoma Charter",
        "district": "Sonoma Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60226004112",
    },
    {
        "school": "John Adams Academy - Roseville",
        "district": "John Adams Academy - Roseville District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60226112569",
    },
    {
        "school": "Aspire Firestone Academy Charter",
        "district": "Aspire Firestone Academy Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60226212761",
    },
    {
        "school": "ICEF Innovation Los Angeles Charter",
        "district": "ICEF Innovation Los Angeles Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60226312194",
    },
    {
        "school": "Montague Charter Academy",
        "district": "Montague Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60226403194",
    },
    {
        "school": "CATCH Prep Charter High Inc.",
        "district": "CATCH Prep Charter High Inc. District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60226511312",
    },
    {
        "school": "Alliance Ouchi-O'Donovan 6-12 Complex",
        "district": "Alliance Ouchi-O'Donovan 6-12 Complex District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60226611641",
    },
    {
        "school": "Tree of Life Charter",
        "district": "Tree of Life Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60226708521",
    },
    {
        "school": "Rocklin Academy Gateway",
        "district": "Rocklin Academy Gateway District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60226813641",
    },
    {
        "school": "Credo High",
        "district": "Credo High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60226912635",
    },
    {
        "school": "Citizens of the World Charter School Silver Lake",
        "district": "Citizens of the World Charter School Silver Lake District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60227013114",
    },
    {
        "school": "Temecula International Academy",
        "district": "Temecula International Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60227114131",
    },
    {
        "school": "Tomorrow's Leadership Collaborative (TLC) Charter",
        "district": "Tomorrow's Leadership Collaborative (TLC) Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60227214331",
    },
    {
        "school": "Cabrillo Point Academy",
        "district": "Cabrillo Point Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60227413913",
    },
    {
        "school": "McGill School of Success",
        "district": "McGill School of Success District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60227505339",
    },
    {
        "school": "KIPP Bridge Academy",
        "district": "KIPP Bridge Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60227611935",
    },
    {
        "school": "Architecture Construction & Engineering Charter High (ACE)",
        "district": "ArchitectureConstruction & Engineer CHTR High(ACE) District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60227712465",
    },
    {
        "school": "Twin Rivers Charter",
        "district": "Twin Rivers Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60227811519",
    },
    {
        "school": "Alliance Renee and Meyer Luskin Academy High",
        "district": "Alliance Renee and Meyer Luskin Academy High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60227912848",
    },
    {
        "school": "King-Chavez Arts Academy",
        "district": "King-Chavez Arts Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60228011390",
    },
    {
        "school": "Yosemite-Wawona Elementary Charter",
        "district": "Yosemite-Wawona Elementary Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60228113800",
    },
    {
        "school": "Valley Charter High",
        "district": "Valley Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60228208409",
    },
    {
        "school": "OCSA",
        "district": "OCSA District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60228408546",
    },
    {
        "school": "SAVA - Sacramento Academic and Vocational Academy",
        "district": "SAVA - Sacramento Academic and Vocational Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60228511951",
    },
    {
        "school": "Rocketship Delta Prep",
        "district": "Rocketship Delta Prep District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60228614366",
    },
    {
        "school": "Summit Preparatory Charter High",
        "district": "Summit Preparatory Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60228711981",
    },
    {
        "school": "Elite Academic Academy - Mountain Empire",
        "district": "Elite Academic Academy - Mountain Empire District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60228814348",
    },
    {
        "school": "Alliance Tennenbaum Family Technology High",
        "district": "Alliance Tennenbaum Family Technology High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60228912572",
    },
    {
        "school": "Discovery Charter",
        "district": "Discovery Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60229002633",
    },
    {
        "school": "Academia Avance Charter",
        "district": "Academia Avance Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60229110895",
    },
    {
        "school": "Oakland Unity High",
        "district": "Oakland Unity High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60229211351",
    },
    {
        "school": "Da Vinci Connect",
        "district": "Da Vinci Connect District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60229313702",
    },
    {
        "school": "San Diego Mission Academy",
        "district": "San Diego Mission Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60229414433",
    },
    {
        "school": "Baypoint Preparatory Academy - San Diego",
        "district": "Baypoint Preparatory Academy - San Diego District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60229514247",
    },
    {
        "school": "Long Valley",
        "district": "Long Valley District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60229609067",
    },
    {
        "school": "New Millennium Secondary",
        "district": "New Millennium Secondary District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60229712253",
    },
    {
        "school": "Sparrow Academy",
        "district": "Sparrow Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60229814132",
    },
    {
        "school": "Blue Oak Academy",
        "district": "Blue Oak Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60229914157",
    },
    {
        "school": "ICEF View Park Preparatory Middle",
        "district": "ICEF View Park Preparatory Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60230010530",
    },
    {
        "school": "Savant Preparatory Academy of Business",
        "district": "Savant Preparatory Academy of Business District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60230114293",
    },
    {
        "school": "Holly Drive Leadership Academy",
        "district": "Holly Drive Leadership Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60230208306",
    },
    {
        "school": "Sacramento Charter High",
        "district": "Sacramento Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60230311190",
    },
    {
        "school": "Paradise Charter Middle",
        "district": "Paradise Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60230404403",
    },
    {
        "school": "California Montessori Project - Capitol Campus",
        "district": "California Montessori Project - Capitol Campus District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60230511732",
    },
    {
        "school": "Shasta Charter Academy",
        "district": "Shasta Charter Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60230608391",
    },
    {
        "school": "Animo City of Champions Charter High",
        "district": "Animo City of Champions Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60230714151",
    },
    {
        "school": "W.E.B. DuBois Public Charter",
        "district": "W.E.B. DuBois Public Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60230808472",
    },
    {
        "school": "Inland Leaders Charter",
        "district": "Inland Leaders Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60230911884",
    },
    {
        "school": "Opportunities for Learning - Capistrano",
        "district": "Opportunities for Learning - Capistrano District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231111221",
    },
    {
        "school": "Rocklin Academy",
        "district": "Rocklin Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231208762",
    },
    {
        "school": "Excelsior Charter",
        "district": "Excelsior Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231305058",
    },
    {
        "school": "River Charter Schools Lighthouse Charter",
        "district": "River Charter Schools Lighthouse Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231413849",
    },
    {
        "school": "Wonderful College Prep Academy",
        "district": "Wonderful College Prep Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231512450",
    },
    {
        "school": "California Virtual Academy @ Sonoma",
        "district": "California Virtual Academy @ Sonoma District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231611478",
    },
    {
        "school": "Citrus Springs Charter",
        "district": "Citrus Springs Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231714034",
    },
    {
        "school": "Learning for Life Charter",
        "district": "Learning for Life Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231810560",
    },
    {
        "school": "Magnolia Science Academy 2",
        "district": "Magnolia Science Academy 2 District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60231911842",
    },
    {
        "school": "Hollister Prep",
        "district": "Hollister Prep District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60232013525",
    },
    {
        "school": "Aspen Meadow Public",
        "district": "Aspen Meadow Public District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60232114004",
    },
    {
        "school": "Stella Elementary Charter Academy",
        "district": "Stella Elementary Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60232214281",
    },
    {
        "school": "Learning Choice Academy",
        "district": "Learning Choice Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60232311139",
    },
    {
        "school": "Design Tech High",
        "district": "Design Tech High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60232413774",
    },
    {
        "school": "James Jordan Middle",
        "district": "James Jordan Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60232510893",
    },
    {
        "school": "Entrepreneur High",
        "district": "Entrepreneur High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60232614321",
    },
    {
        "school": "California Pacific Charter - San Diego",
        "district": "California Pacific Charter - San Diego District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60232813918",
    },
    {
        "school": "Public Policy Charter",
        "district": "Public Policy Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60232913868",
    },
    {
        "school": "Pivot Charter School - North Bay",
        "district": "Pivot Charter School - North Bay District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60233014244",
    },
    {
        "school": "Community Roots Academy",
        "district": "Community Roots Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60233112651",
    },
    {
        "school": "Woodward Leadership Academy",
        "district": "Woodward Leadership Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60233313063",
    },
    {
        "school": "Roseland Charter",
        "district": "Roseland Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60233411178",
    },
    {
        "school": "Aspire Juanita Tate Academy Charter",
        "district": "Aspire Juanita Tate Academy Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60233512967",
    },
    {
        "school": "Contra Costa School of Performing Arts",
        "district": "Contra Costa School of Performing Arts District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60233614059",
    },
    {
        "school": "Peak to Peak Mountain Charter",
        "district": "Peak to Peak Mountain Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60233713690",
    },
    {
        "school": "Northern Summit Academy Shasta",
        "district": "Northern Summit Academy Shasta District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60233813799",
    },
    {
        "school": "HomeTech Charter",
        "district": "HomeTech Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60233904345",
    },
    {
        "school": "one.Charter",
        "district": "one.Charter District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60234012462",
    },
    {
        "school": "High Tech High Mesa",
        "district": "High Tech High Mesa District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60234114220",
    },
    {
        "school": "Clayton Valley Charter High",
        "district": "Clayton Valley Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60234203940",
    },
    {
        "school": "Adelante Charter",
        "district": "Adelante Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60234308628",
    },
    {
        "school": "Animo Jefferson Charter Middle",
        "district": "Animo Jefferson Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60234412690",
    },
    {
        "school": "Ednovate - USC Hybrid High College Prep",
        "district": "Ednovate - USC Hybrid High College Prep District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60234513094",
    },
    {
        "school": "Oakland Unity Middle",
        "district": "Oakland Unity Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60234613887",
    },
    {
        "school": "SAVA - Sacramento Academic and Vocational Academy - SCUSD",
        "district": "SAVA- Sacramento ACAD and Vocational Academy- SCUSD District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60234814224",
    },
    {
        "school": "Excelencia Charter Academy",
        "district": "Excelencia Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60234914214",
    },
    {
        "school": "e3 Civic High",
        "district": "e3 Civic High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60235013288",
    },
    {
        "school": "Para Los Ni?os Middle",
        "district": "Para Los Ni?os Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60235112361",
    },
    {
        "school": "Team Charter Academy",
        "district": "Team Charter Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60235214076",
    },
    {
        "school": "Visions In Education",
        "district": "Visions In Education District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60235308283",
    },
    {
        "school": "Community Collaborative Charter",
        "district": "Community Collaborative Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60235413904",
    },
    {
        "school": "Prepa Tec Los Angeles High",
        "district": "Prepa Tec Los Angeles High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60235513997",
    },
    {
        "school": "Lighthouse Community Charter High",
        "district": "Lighthouse Community Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60235610726",
    },
    {
        "school": "Connect Community Charter",
        "district": "Connect Community Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60235713060",
    },
    {
        "school": "Manzanita Middle",
        "district": "Manzanita Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60235808692",
    },
    {
        "school": "Options for Youth-Victorville Charter",
        "district": "Options for Youth-Victorville Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60235902619",
    },
    {
        "school": "Academia Moderna",
        "district": "Academia Moderna District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60236112455",
    },
    {
        "school": "Alliance Patti And Peter Neuwirth Leadership Academy",
        "district": "Alliance Patti & Peter Neuwirth Leadership Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60236211632",
    },
    {
        "school": "Great Valley Academy",
        "district": "Great Valley Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60236312249",
    },
    {
        "school": "Darnall Charter",
        "district": "Darnall Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60236401220",
    },
    {
        "school": "Mountain Home Charter (Alternative)",
        "district": "Mountain Home Charter (Alternative) District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60236510251",
    },
    {
        "school": "JCS - Pine Valley",
        "district": "JCS - Pine Valley District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60236614333",
    },
    {
        "school": "Aspire APEX Academy",
        "district": "Aspire APEX Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60236712659",
    },
    {
        "school": "ICEF Vista Elementary Academy",
        "district": "ICEF Vista Elementary Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60236812222",
    },
    {
        "school": "KIPP Sol Academy",
        "district": "KIPP Sol Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60236913005",
    },
    {
        "school": "Heritage Peak Charter",
        "district": "Heritage Peak Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60237111073",
    },
    {
        "school": "Imagine Schools Riverside County",
        "district": "Imagine Schools Riverside County District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60237212985",
    },
    {
        "school": "San Joaquin Building Futures Academy",
        "district": "San Joaquin Building Futures Academy District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60237312662",
    },
    {
        "school": "Health Sciences High",
        "district": "Health Sciences High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60237412179",
    },
    {
        "school": "Empower Charter",
        "district": "Empower Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60237513803",
    },
    {
        "school": "Aspire Benjamin Holt College Preparatory Academy",
        "district": "Aspire Benjamin Holt College Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60237611341",
    },
    {
        "school": "Marconi Learning Academy",
        "district": "Marconi Learning Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60237714360",
    },
    {
        "school": "Family Partnership Charter",
        "district": "Family Partnership Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60237811789",
    },
    {
        "school": "Rocketship Fuerza Community Prep",
        "district": "Rocketship Fuerza Community Prep District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60237913747",
    },
    {
        "school": "LA's Promise Charter Middle #1",
        "district": "LA's Promise Charter Middle #1 District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60238014033",
    },
    {
        "school": "Community Collaborative Virtual - Keppel Partnership Academy",
        "district": "COM Collaborative Virtual - Keppel Partnership ACAD District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60238114092",
    },
    {
        "school": "Encore High School for the Arts - Riverside",
        "district": "Encore High School for the Arts - Riverside District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60238213908",
    },
    {
        "school": "Carter G. Woodson Public Charter",
        "district": "Carter G. Woodson Public Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60238308697",
    },
    {
        "school": "KIPP Academy of Innovation",
        "district": "KIPP Academy of Innovation District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60238413691",
    },
    {
        "school": "Redding School of the Arts",
        "district": "Redding School of the Arts District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60238514024",
    },
    {
        "school": "Diego Valley East Public Charter",
        "district": "Diego Valley East Public Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60238614301",
    },
    {
        "school": "Magnolia Science Academy San Diego",
        "district": "Magnolia Science Academy San Diego District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60238711393",
    },
    {
        "school": "California Connections Academy @ Ripon",
        "district": "California Connections Academy @ Ripon District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60238813152",
    },
    {
        "school": "Arts In Action Community Charter",
        "district": "Arts In Action Community Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60238912683",
    },
    {
        "school": "San Jacinto Valley Academy",
        "district": "San Jacinto Valley Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60239007219",
    },
    {
        "school": "Escuela Popular/Center for Training and Careers Family Lrng",
        "district": "Escuela Popular/CTR for TRN and Careers FAM Lrng District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60239211449",
    },
    {
        "school": "PUC Nueva Esperanza Charter Academy",
        "district": "PUC Nueva Esperanza Charter Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60239313947",
    },
    {
        "school": "Crescent View South II",
        "district": "Crescent View South II District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60239514204",
    },
    {
        "school": "Matrix for Success Academy",
        "district": "Matrix for Success Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60239614253",
    },
    {
        "school": "New Horizons Charter Academy",
        "district": "New Horizons Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60239713684",
    },
    {
        "school": "Options for Youth San Gabriel",
        "district": "Options for Youth San Gabriel District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60239807165",
    },
    {
        "school": "OCS - South",
        "district": "OCS - South District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60239914352",
    },
    {
        "school": "Inspire Charter School - North",
        "district": "Inspire Charter School - North District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60240014025",
    },
    {
        "school": "Trivium Charter",
        "district": "Trivium Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60240112941",
    },
    {
        "school": "Aspire Richmond Ca. College Preparatory Academy",
        "district": "Aspire Richmond Ca. College Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60240313890",
    },
    {
        "school": "Lazear Charter Academy",
        "district": "Lazear Charter Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60240504288",
    },
    {
        "school": "Connecting Waters Charter School - Central Valley",
        "district": "Connecting Waters Charter School - Central Valley District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60240614327",
    },
    {
        "school": "Alliance Morgan McKinzie High",
        "district": "Alliance Morgan McKinzie High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60240712259",
    },
    {
        "school": "Alma Fuerte Public",
        "district": "Alma Fuerte Public District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60240814146",
    },
    {
        "school": "Albert Einstein Academy Charter Elementary",
        "district": "Albert Einstein Academy Charter Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60240910637",
    },
    {
        "school": "Discovery Charter II",
        "district": "Discovery Charter II District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60241013640",
    },
    {
        "school": "California Connections Academy@Central",
        "district": "California Connections Academy@Central District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60241111819",
    },
    {
        "school": "Lemoore Middle College High",
        "district": "Lemoore Middle College High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60241211607",
    },
    {
        "school": "Wallis Annenberg High",
        "district": "Wallis Annenberg High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60241311365",
    },
    {
        "school": "River Oak Charter",
        "district": "River Oak Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60241412026",
    },
    {
        "school": "Bullis Charter",
        "district": "Bullis Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60241511442",
    },
    {
        "school": "Da Vinci Science",
        "district": "Da Vinci Science District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60241612208",
    },
    {
        "school": "Aspire Inskeep Academy Charter",
        "district": "Aspire Inskeep Academy Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60241712856",
    },
    {
        "school": "Stockton Collegiate International Elementary",
        "district": "Stockton Collegiate International Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60241812451",
    },
    {
        "school": "Century Community Charter",
        "district": "Century Community Charter District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60241910827",
    },
    {
        "school": "Walden Academy",
        "district": "Walden Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60242012983",
    },
    {
        "school": "Stanislaus Alternative Charter",
        "district": "Stanislaus Alternative Charter District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60242113669",
    },
    {
        "school": "Winship Community",
        "district": "Winship Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60242206984",
    },
    {
        "school": "Hardy Brown College Prep",
        "district": "Hardy Brown College Prep District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60242312796",
    },
    {
        "school": "Nevada City School of the Arts",
        "district": "Nevada City School of the Arts District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60242411940",
    },
    {
        "school": "Equitas Academy Charter",
        "district": "Equitas Academy Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60242512479",
    },
    {
        "school": "Gateway High",
        "district": "Gateway High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60242607725",
    },
    {
        "school": "Mojave River Academy - Rockview Park",
        "district": "Mojave River Academy - Rockview Park District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60242714316",
    },
    {
        "school": "Ceiba College Preparatory Academy",
        "district": "Ceiba College Preparatory Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60242812189",
    },
    {
        "school": "High Tech Elementary",
        "district": "High Tech Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60242913878",
    },
    {
        "school": "High Tech Elementary North County",
        "district": "High Tech Elementary North County District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243113517",
    },
    {
        "school": "Fortune",
        "district": "Fortune District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243214070",
    },
    {
        "school": "Community Collaborative Charter",
        "district": "Community Collaborative Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243311072",
    },
    {
        "school": "Vista Heritage Global Academy",
        "district": "Vista Heritage Global Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243413905",
    },
    {
        "school": "Animo South Los Angeles Charter",
        "district": "Animo South Los Angeles Charter District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243510836",
    },
    {
        "school": "Julia Lee Performing Arts Academy",
        "district": "Julia Lee Performing Arts Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243614343",
    },
    {
        "school": "Assurance Learning Academy",
        "district": "Assurance Learning Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243713121",
    },
    {
        "school": "The New School of San Francisco",
        "district": "The New School of San Francisco District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60243913939",
    },
    {
        "school": "Highlands Community Charter",
        "district": "Highlands Community Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60244213830",
    },
    {
        "school": "Escondido Charter High",
        "district": "Escondido Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60244306493",
    },
    {
        "school": "Rocketship Mosaic Elementary",
        "district": "Rocketship Mosaic Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60244412645",
    },
    {
        "school": "Aspire Port City Academy",
        "district": "Aspire Port City Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60244512106",
    },
    {
        "school": "Alliance Marc & Eva Stern Math and Science",
        "district": "Alliance Marc & Eva Stern Math and Science District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60244611642",
    },
    {
        "school": "Capitol Collegiate Academy",
        "district": "Capitol Collegiate Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60244712810",
    },
    {
        "school": "Aspire Monarch Academy",
        "district": "Aspire Monarch Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60244808440",
    },
    {
        "school": "Wilder's Preparatory Academy Charter",
        "district": "Wilder's Preparatory Academy Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60244911296",
    },
    {
        "school": "California Virtual Academy at Maricopa",
        "district": "California Virtual Academy at Maricopa District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245114255",
    },
    {
        "school": "Aspire River Oaks Charter",
        "district": "Aspire River Oaks Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245210389",
    },
    {
        "school": "Alliance College-Ready Middle Academy 12",
        "district": "Alliance College-Ready Middle Academy 12 District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245313403",
    },
    {
        "school": "Grimmway Academy",
        "district": "Grimmway Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245412948",
    },
    {
        "school": "Puente Charter",
        "district": "Puente Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245510525",
    },
    {
        "school": "Fenton Charter Leadership Academy",
        "district": "Fenton Charter Leadership Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245613900",
    },
    {
        "school": "KIPP Summit Academy",
        "district": "KIPP Summit Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245711159",
    },
    {
        "school": "Oakland School for the Arts",
        "district": "Oakland School for the Arts District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245810461",
    },
    {
        "school": "Aurum Preparatory Academy",
        "district": "Aurum Preparatory Academy District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60245914335",
    },
    {
        "school": "Yosemite Valley Charter",
        "district": "Yosemite Valley Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60246014019",
    },
    {
        "school": "Animo Venice Charter High",
        "district": "Animo Venice Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60246110848",
    },
    {
        "school": "ARISE High",
        "district": "ARISE High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60246212040",
    },
    {
        "school": "Rocky Point Charter",
        "district": "Rocky Point Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60246311927",
    },
    {
        "school": "iEmpire Academy",
        "district": "iEmpire Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60246412557",
    },
    {
        "school": "Vista Real Charter High",
        "district": "Vista Real Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60246511537",
    },
    {
        "school": "Century Academy for Excellence",
        "district": "Century Academy for Excellence District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60246611614",
    },
    {
        "school": "Sherman Thomas Charter",
        "district": "Sherman Thomas Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60246711160",
    },
    {
        "school": "Valley Charter Middle",
        "district": "Valley Charter Middle District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60246812643",
    },
    {
        "school": "Big Sur Charter",
        "district": "Big Sur Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60246912240",
    },
    {
        "school": "TEACH Tech Charter High",
        "district": "TEACH Tech Charter High District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60247013741",
    },
    {
        "school": "Animo Inglewood Charter High",
        "district": "Animo Inglewood Charter High District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60247110538",
    },
    {
        "school": "Aspire Gateway Academy Charter",
        "district": "Aspire Gateway Academy Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60247212679",
    },
    {
        "school": "Western Sierra Collegiate Academy",
        "district": "Western Sierra Collegiate Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60247312390",
    },
    {
        "school": "New Los Angeles Charter Elementary",
        "district": "New Los Angeles Charter Elementary District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60247513972",
    },
    {
        "school": "Aspire Vincent Shalvey Academy",
        "district": "Aspire Vincent Shalvey Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60247608323",
    },
    {
        "school": "Sebastopol Independent Charter",
        "district": "Sebastopol Independent Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60247705457",
    },
    {
        "school": "Valley View Charter Prep",
        "district": "Valley View Charter Prep District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60247813797",
    },
    {
        "school": "Olive Grove Charter - Santa Barbara",
        "district": "Olive Grove Charter - Santa Barbara District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60248014229",
    },
    {
        "school": "KIPP Valiant Community Prep",
        "district": "KIPP Valiant Community Prep District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60248114087",
    },
    {
        "school": "iLEAD Hybrid",
        "district": "iLEAD Hybrid District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60248213859",
    },
    {
        "school": "MIT Academy",
        "district": "MIT Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60248310681",
    },
    {
        "school": "Equitas Academy #2",
        "district": "Equitas Academy #2 District",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60248413145",
    },
    {
        "school": "Elite Public",
        "district": "Elite Public District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60248514376",
    },
    {
        "school": "Sycamore Creek Community Charter",
        "district": "Sycamore Creek Community Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60248614377",
    },
    {
        "school": "Excel Academy Charter",
        "district": "Excel Academy Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60248714407",
    },
    {
        "school": "California Connections Academy Central Coast",
        "district": "California Connections Academy Central Coast District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60248814411",
    },
    {
        "school": "Lashon Academy City",
        "district": "Lashon Academy City District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60248914405",
    },
    {
        "school": "Pathways Academy Charter - Adult Education",
        "district": "Pathways Academy Charter - Adult Education District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60249114406",
    },
    {
        "school": "Scholarship Prep - South Bay",
        "district": "Scholarship Prep - South Bay District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60249314408",
    },
    {
        "school": "Peak Prep Pleasant Valley",
        "district": "Peak Prep Pleasant Valley District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60249414413",
    },
    {
        "school": "Kidinnu Academy",
        "district": "Kidinnu Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60249514409",
    },
    {
        "school": "KIPP Pueblo Unido",
        "district": "KIPP Pueblo Unido District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60249614410",
    },
    {
        "school": "Watsonville Prep",
        "district": "Watsonville Prep District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60249714404",
    },
    {
        "school": "The Learning Choice Academy - East County",
        "district": "The Learning Choice Academy - East County District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60249814437",
    },
    {
        "school": "GANAS Academy",
        "district": "GANAS Academy District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60249914439",
    },
    {
        "school": "Excel Academy Charter",
        "district": "Excel Academy Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60250014435",
    },
    {
        "school": "Brookfield Engineering Science Technology Academy",
        "district": "Brookfield Engineering Science Technology Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60250114440",
    },
    {
        "school": "Options For Youth - Duarte Inc",
        "district": "Options For Youth - Duarte Inc District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60250214438",
    },
    {
        "school": "Academy of Media Arts",
        "district": "Academy of Media Arts District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60250314434",
    },
    {
        "school": "Equitas Academy 6",
        "district": "Equitas Academy 6 District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60250414441",
    },
    {
        "school": "Sage Oak Charter - South",
        "district": "Sage Oak Charter - South District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60250514436",
    },
    {
        "school": "Shasta View Academy",
        "district": "Shasta View Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60250614418",
    },
    {
        "school": "International School for Science and Culture",
        "district": "International School for Science and Culture District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60250714420",
    },
    {
        "school": "Monarch River Academy",
        "district": "Monarch River Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60250814423",
    },
    {
        "school": "California Innovative Career Academy",
        "district": "California Innovative Career Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60250914417",
    },
    {
        "school": "California Pacific Charter - Sonoma",
        "district": "California Pacific Charter - Sonoma District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60251014414",
    },
    {
        "school": "Garvey/Allen Visual & Performing Arts Academy for STEM",
        "district": "Garvey/Allen Visual & Performing Arts Academy for STEM DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60251114421",
    },
    {
        "school": "Heartwood Charter",
        "district": "Heartwood Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60251214416",
    },
    {
        "school": "Mission Vista Academy",
        "district": "Mission Vista Academy District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60251314419",
    },
    {
        "school": "Vista Horizon Global Academy",
        "district": "Vista Horizon Global Academy District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60251514424",
    },
    {
        "school": "Granite Mountain Charter",
        "district": "Granite Mountain Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60251614425",
    },
    {
        "school": "California Connections Academy Monterey Bay",
        "district": "California Connections Academy Monterey Bay District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60251714429",
    },
    {
        "school": "Sycamore Academy of Science and Cultural Arts - Chino Valley",
        "district": "Sycamore Academy of Science and Cultural Arts Chino VLY DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60251814426",
    },
    {
        "school": "Mary L. Booker Leadership Academy",
        "district": "Mary L. Booker Leadership Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60251914431",
    },
    {
        "school": "Lake View Charter",
        "district": "Lake View Charter District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60252014428",
    },
    {
        "school": "Compass Charter School of Yolo",
        "district": "Compass Charter School of Yolo District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60252114432",
    },
    {
        "school": "Equitas Academy 5",
        "district": "Equitas Academy 5 District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60252214430",
    },
    {
        "school": "Hayward Collegiate Charter",
        "district": "Hayward Collegiate Charter District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60252314443",
    },
    {
        "school": "Cottonwood",
        "district": "Cottonwood District",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60252414444",
    },
    {
        "school": "Rafer Johnson",
        "district": "Bakersfield City",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60363014223",
    },
    {
        "school": "Barstow Fine Arts Academy",
        "district": "Barstow Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60402014398",
    },
    {
        "school": "Starlight Elementary",
        "district": "Beaumont Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60429014274",
    },
    {
        "school": "Belleview Special Education Preschool",
        "district": "Belleview Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60450014379",
    },
    {
        "school": "Buckeye Union Mandarin Immersion Charter",
        "district": "Buckeye Union Elementary",
        "level": "Other",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60627014309",
    },
    {
        "school": "Dolores S. Whitley Elementary",
        "district": "Panama-Buena Vista Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60639014239",
    },
    {
        "school": "Campbell School of Innovation",
        "district": "Campbell Union",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60720014280",
    },
    {
        "school": "Esencia",
        "district": "Capistrano Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744014361",
    },
    {
        "school": "Esencia Middle",
        "district": "Capistrano Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60744014392",
    },
    {
        "school": "Online Academy - Sonoma County",
        "district": "Cloverdale Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60897014399",
    },
    {
        "school": "Corning Independent Study",
        "district": "Corning Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60981014286",
    },
    {
        "school": "Richard R. Oliphant Elementary",
        "district": "Desert Sands Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61111014222",
    },
    {
        "school": "Skylark Preschool",
        "district": "Garden Grove Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61488014387",
    },
    {
        "school": "Duff Language Magnet Academy",
        "district": "Garvey Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61494014288",
    },
    {
        "school": "Arroyo Seco Academy",
        "district": "Greenfield Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61608014263",
    },
    {
        "school": "Guerneville Primary",
        "district": "Guerneville Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61632014302",
    },
    {
        "school": "Hanford Online Charter",
        "district": "Hanford Joint Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61650014320",
    },
    {
        "school": "Imperial Cross Elementary",
        "district": "Imperial Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61821014386",
    },
    {
        "school": "Del Sol Academy",
        "district": "Jurupa Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "61926014336",
    },
    {
        "school": "Kelseyville Learning Academy",
        "district": "Kelseyville Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61932014318",
    },
    {
        "school": "Lakeside Union Alternative Education",
        "district": "Lakeside Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62079014397",
    },
    {
        "school": "Lindsay Preschool",
        "district": "Lindsay Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62187014391",
    },
    {
        "school": "Valley Robotics Academy",
        "district": "Lodi Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62223014403",
    },
    {
        "school": "University Pathways Public Service Academy",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271014289",
    },
    {
        "school": "University Pathways Medical Magnet Academy",
        "district": "Los Angeles Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62271014307",
    },
    {
        "school": "Transitional Kindergarten Center",
        "district": "Los Banos Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274014283",
    },
    {
        "school": "Mabel Mattos Elementary",
        "district": "Milpitas Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62450014277",
    },
    {
        "school": "Taawila Elementary",
        "district": "Menifee Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62454014364",
    },
    {
        "school": "Moreno Valley Bridge Academy",
        "district": "Moreno Valley Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62580014241",
    },
    {
        "school": "MVWSD Preschool",
        "district": "Mountain View Whisman",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628014279",
    },
    {
        "school": "Jose Antonio Vargas Elementary",
        "district": "Mountain View Whisman",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62628014375",
    },
    {
        "school": "Willow Elementary",
        "district": "Napa Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62664014216",
    },
    {
        "school": "Summer Lake Elementary",
        "district": "Oakley Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62808014374",
    },
    {
        "school": "Oxnard Middle College High",
        "district": "Oxnard Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62927014319",
    },
    {
        "school": "Paradise Ridge Elementary",
        "district": "Paradise Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62982014442",
    },
    {
        "school": "Odyssey STEM Academy",
        "district": "Paramount Unified",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62985014236",
    },
    {
        "school": "Pathways for Adult Life Skills",
        "district": "Perris Union High",
        "level": "High",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "63021014362",
    },
    {
        "school": "Maidu Virtual Charter Academy",
        "district": "Placer Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63075014310",
    },
    {
        "school": "Rocking Horse Preschool",
        "district": "Rialto Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63237014275",
    },
    {
        "school": "Rio del Sol",
        "district": "Rio Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63276014252",
    },
    {
        "school": "Rancho San Juan High",
        "district": "Salinas Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63398014401",
    },
    {
        "school": "Mariposa",
        "district": "San Carlos Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63429014383",
    },
    {
        "school": "Edward Hyatt World Language Academy",
        "district": "San Jacinto Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63444014382",
    },
    {
        "school": "Malibu Middle",
        "district": "Santa Monica-Malibu Unified",
        "level": "Middle",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63570014384",
    },
    {
        "school": "Saratoga Special Services Preschool",
        "district": "Saratoga Union Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63591014314",
    },
    {
        "school": "Tide Academy",
        "district": "Sequoia Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63639014381",
    },
    {
        "school": "Goodwill Independent Study",
        "district": "Victor Valley Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63697214284",
    },
    {
        "school": "Marshall K-8 Community Day",
        "district": "Stockton Unified",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63801014326",
    },
    {
        "school": "Dr. Ralph H. Baker 21st Century Learning Center",
        "district": "Victor Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64104014388",
    },
    {
        "school": "Creekside Community Day",
        "district": "Visalia Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64116014400",
    },
    {
        "school": "Denton Elementary",
        "district": "Visalia Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64116014402",
    },
    {
        "school": "James A. Forrest Elementary",
        "district": "Wasco Union Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64140014394",
    },
    {
        "school": "Mt. SAC Early College Academy at West Covina",
        "district": "West Covina Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64200014238",
    },
    {
        "school": "ATLAS Learning Academy",
        "district": "Western Placer Unified",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64214014396",
    },
    {
        "school": "Edward P. Duplex",
        "district": "Wheatland Union High",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64235014385",
    },
    {
        "school": "Early Childhood Education Center",
        "district": "Whittier City Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64245014390",
    },
    {
        "school": "Castaic High",
        "district": "William S. Hart Union High",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64251014393",
    },
    {
        "school": "Sanhedrin Alternative",
        "district": "Willits Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64256014273",
    },
    {
        "school": "Waggoner Elementary",
        "district": "Winters Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64293014395",
    },
    {
        "school": "Woodland Middle Grade Community Day",
        "district": "Woodland Joint Unified",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "64308014351",
    },
    {
        "school": "Spring Lake Elementary",
        "district": "Woodland Joint Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64308014365",
    },
    {
        "school": "Cadence Park",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450014305",
    },
    {
        "school": "Loma Ridge",
        "district": "Irvine Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "68450014380",
    },
    {
        "school": "BASES Learning Center",
        "district": "Butte County Office of Education",
        "level": "Other",
        "type": "Special education school",
        "state": "CA",
        "nces_id": "69100214445",
    },
    {
        "school": "Westwood State Preschool",
        "district": "Lassen County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69101514232",
    },
    {
        "school": "Rainbow Learning Center",
        "district": "Lassen County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69101514303",
    },
    {
        "school": "Come Back Charter",
        "district": "Merced County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69102014312",
    },
    {
        "school": "Shasta County State Preschools",
        "district": "Shasta County Office of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69103714344",
    },
    {
        "school": "GOLDEN VIEW CLASSICAL ACADEMY",
        "district": "State Charter School Institute",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006639",
    },
    {
        "school": "Coperni 2",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006761",
    },
    {
        "school": "COLORADO PREPARATORY ACADEMY ELEMENTARY SCHOOL",
        "district": "EDUCATION REENVISIONED BOCES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80028206752",
    },
    {
        "school": "COLORADO PREPARATORY ACADEMY MIDDLE SCHOOL",
        "district": "EDUCATION REENVISIONED BOCES",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80028206764",
    },
    {
        "school": "BETTY K MARLER YOUTH SERVICES CENTER",
        "district": "DIVISION OF YOUTH SERVICES",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80028606742",
    },
    {
        "school": "NEW SUMMIT CHARTER ACADEMY",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006745",
    },
    {
        "school": "LEGACY PEAK ELEMENTARY SCHOOL",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006758",
    },
    {
        "school": "BAYFIELD PRIMARY SCHOOL",
        "district": "Bayfield School District No. 10Jt-R",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80240006747",
    },
    {
        "school": "RIVERDALE RIDGE HIGH SCHOOL",
        "district": "School District 27J",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006738",
    },
    {
        "school": "RODGER QUIST MIDDLE SCHOOL",
        "district": "School District 27J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80258006753",
    },
    {
        "school": "Astravo Online Academy Elementary School",
        "district": "Byers School District No. 32J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80270006749",
    },
    {
        "school": "ELEVATE ACADEMY ELEMENTARY SCHOOL",
        "district": "Byers School District No. 32J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80270006751",
    },
    {
        "school": "Astravo Online Academy Middle School",
        "district": "Byers School District No. 32J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80270006755",
    },
    {
        "school": "Astravo Academy Middle School",
        "district": "Byers School District No. 32J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80270006759",
    },
    {
        "school": "ALTITUDE ELEMENTARY SCHOOL",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006750",
    },
    {
        "school": "DSST MIDDLE SCHOOL @ NOEL CAMPUS",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006746",
    },
    {
        "school": "KIPP SUNSHINE PEAK ELEMENTARY",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006748",
    },
    {
        "school": "5280 HIGH SCHOOL",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006756",
    },
    {
        "school": "ASCENT CLASSICAL ACADEMY",
        "district": "Douglas County School District No. Re 1",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006760",
    },
    {
        "school": "LEMAN CLASSICAL ACADEMY",
        "district": "Douglas County School District No. Re 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80345006765",
    },
    {
        "school": "LIBERTY TREE ACADEMY",
        "district": "El Paso County Colorado School District 49",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387006744",
    },
    {
        "school": "BENNETT RANCH ELEMENTARY SCHOOL",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387006766",
    },
    {
        "school": "COMPASS COMMUNITY COLLABORATIVE SCHOOL",
        "district": "Poudre School District R-1",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399006762",
    },
    {
        "school": "LITTLE TRAPPERS PRESCHOOL",
        "district": "Weld re-8 schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80402006754",
    },
    {
        "school": "ECC AIMS DISTRICT 6 PRESCHOOL",
        "district": "GreeleySchool District No. 6 in the county of Weld and Sta",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80441006741",
    },
    {
        "school": "MEADOW RIDGE ELEMENTARY SCHOOL",
        "district": "Weld County School District RE-3J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80492006743",
    },
    {
        "school": "SOARING HEIGHTS PK-8",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006739",
    },
    {
        "school": "GRAND VIEW ELEMENTARY",
        "district": "St. Vrain Valley School District No. Re1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80537006757",
    },
    {
        "school": "PSAS HOMESCHOOL PROGRAM",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615006763",
    },
    {
        "school": "NEW AMERICA SCHOOL - THORNTON",
        "district": "Adams 12 Five Star Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CO",
        "nces_id": "80690006480",
    },
    {
        "school": "THUNDER VISTA P-8",
        "district": "Adams 12 Five Star Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80690006740",
    },
    {
        "school": "Sussex Montessori School",
        "district": "Sussex Montessori School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100006300387",
    },
    {
        "school": "Friendship PCS - Southeast MS",
        "district": "Friendship PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800515",
    },
    {
        "school": "Elsie Whitlow Stokes Community Freedom PCS - East End",
        "district": "Elsie Whitlow Stokes Community Freedom PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000900520",
    },
    {
        "school": "Excel Academy",
        "district": "District of Columbia Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000519",
    },
    {
        "school": "AppleTree Early Learning Center PCS - Parklands at THEARC",
        "district": "AppleTree Early Learning PCS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110005400517",
    },
    {
        "school": "Rocketship DC PCS - Legacy Prep",
        "district": "Rocketship DC PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110010600514",
    },
    {
        "school": "Digital Pioneers Academy PCS",
        "district": "Digital Pioneers Academy PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110010900521",
    },
    {
        "school": "Statesmen College Preparatory Academy for Boys PCS",
        "district": "Statesmen College Preparatory Academy for Boys PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110011000518",
    },
    {
        "school": "FLVS FULL TIME 6-8",
        "district": "FL VIRTUAL",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120000208677",
    },
    {
        "school": "BAY VIRTUAL INSTRUCTION PROGRAM (DISTRICT PROVIDED)",
        "district": "BAY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120009008742",
    },
    {
        "school": "SOMERSET ACADEMY ELEMENTARY SOUTH CAMPUS",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008705",
    },
    {
        "school": "PACE CENTER FOR GIRLS",
        "district": "CITRUS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120027008728",
    },
    {
        "school": "CONTRACTED RESIDENTIAL SERVICES",
        "district": "CLAY",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120030008696",
    },
    {
        "school": "SOMERSET PALMS ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008669",
    },
    {
        "school": "ACCELERATION ACADEMIES  LEJEUNE",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039008678",
    },
    {
        "school": "MATER HIGH SOUTH",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008683",
    },
    {
        "school": "ACADEMY FOR INTERNATIONAL EDUCATION UPPER CHARTER SCHOOL FOR",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008684",
    },
    {
        "school": "SOMERSET PREP ACADEMY MIDDLE HOMESTEAD",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008688",
    },
    {
        "school": "DORAL SCHOOL OF THE ARTS",
        "district": "MIAMI-DADE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008692",
    },
    {
        "school": "ACADEMIR CHARTER SCHOOL EAST",
        "district": "MIAMI-DADE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008693",
    },
    {
        "school": "BRIDGEPREP ACADEMY OF NORTH MIAMI BEACH",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008694",
    },
    {
        "school": "KENDALL SQUARE K-8 CENTER",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008697",
    },
    {
        "school": "PHOENIX ACADEMY OF EXCELLENCE NORTH",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039008700",
    },
    {
        "school": "MATER PREPARATORY ACADEMY",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008702",
    },
    {
        "school": "CHARTER HIGH SCHOOL OF THE AMERICAS (FLORIDA CITY CAMPUS)",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008703",
    },
    {
        "school": "TRUE NORTH CLASSICAL ACADEMY EAST",
        "district": "MIAMI-DADE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008710",
    },
    {
        "school": "MATER BRICKELL PREPARATORY HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008712",
    },
    {
        "school": "HIVE PREPARATORY SCHOOL-RIVERSIDE",
        "district": "MIAMI-DADE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008718",
    },
    {
        "school": "TRUE NORTH CLASSICAL ACADEMY KENDALL",
        "district": "MIAMI-DADE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008723",
    },
    {
        "school": "PHOENIX ACADEMY OF EXCELLENCE",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039008725",
    },
    {
        "school": "SLAM ACADEMY  HIGH SCHOOL NORTH CAMPUS",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008726",
    },
    {
        "school": "SOMERSET ACADEMY KENDALL",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008727",
    },
    {
        "school": "INTERNATIONAL STUDIES ACADEMY (ISA) HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008729",
    },
    {
        "school": "INTERNATIONAL STUDIES ACADEMY (ISA) MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008730",
    },
    {
        "school": "BEACON COLLEGE PREP  MIDDLE SCHOOL",
        "district": "MIAMI-DADE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008735",
    },
    {
        "school": "ACCELERATION ACADEMIES LLC  HOMESTEAD",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039008738",
    },
    {
        "school": "BRIDGEPREP ACADEMY OF MIAMI DADE",
        "district": "MIAMI-DADE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008741",
    },
    {
        "school": "PINECREST NORTH PREPARATORY (FONTAINEBLEAU CAMPUS)",
        "district": "MIAMI-DADE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008744",
    },
    {
        "school": "ACADEMIR CHARTER SCHOOL OF MATH AND SCIENCE",
        "district": "MIAMI-DADE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008748",
    },
    {
        "school": "SOMERSET PREPARATORY ACADEMY HIGH SCHOOL HOMESTEAD",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008749",
    },
    {
        "school": "FLAGLER VIRTUAL INSTRUCTION KG-6",
        "district": "FLAGLER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120054008695",
    },
    {
        "school": "CENTER FOR SUCCESS AND INDEPENDENCE BROOKSVILLE ACADEMY",
        "district": "HERNANDO",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120081008687",
    },
    {
        "school": "BRIDGEPREP ACADEMY OF ADVANCED STUDIES OF HILLSBOROUGH",
        "district": "HILLSBOROUGH",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008676",
    },
    {
        "school": "ELEMENTARY E",
        "district": "HILLSBOROUGH",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008714",
    },
    {
        "school": "RIVERVIEW ACADEMY OF MATH AND SCIENCE",
        "district": "HILLSBOROUGH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008715",
    },
    {
        "school": "BIG BEND ACADEMY OF MATH AND SCIENCE",
        "district": "HILLSBOROUGH",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008722",
    },
    {
        "school": "INDIAN RIVER VIRTUAL COURSE OFFERINGS",
        "district": "INDIAN RIVER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120093008734",
    },
    {
        "school": "JCSB TAPP CONTRACT SITE",
        "district": "JACKSON",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120096008675",
    },
    {
        "school": "HOPE FOREST ACADEMY",
        "district": "LAKE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120105008670",
    },
    {
        "school": "SEVEN LAKES PREPARATORY ACADEMY",
        "district": "LAKE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105008745",
    },
    {
        "school": "TALLAHASSEE CLASSICAL SCHOOL",
        "district": "LEON",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120111008746",
    },
    {
        "school": "PARRISH CHARTER ACADEMY",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123008704",
    },
    {
        "school": "PARRISH COMMUNITY HIGH SCHOOL",
        "district": "MANATEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123008711",
    },
    {
        "school": "DR MONA JAIN MIDDLE SCHOOL",
        "district": "MANATEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123008717",
    },
    {
        "school": "BARBARA A HARVEY ELEMENTARY SCHOOL",
        "district": "MANATEE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120123008719",
    },
    {
        "school": "MARTIN COUNTY ACCELERATION ACADEMIES",
        "district": "MARTIN",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120129008674",
    },
    {
        "school": "THE HOPE ACADEMY FOR AUTISM",
        "district": "MARTIN",
        "level": "Elementary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120129008679",
    },
    {
        "school": "TREASURE COAST CLASSICAL ACADEMY",
        "district": "MARTIN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120129008739",
    },
    {
        "school": "LOWER KEYS ACADEMIC CONNECTIONS FOR EXCELLENCE",
        "district": "MONROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120132008681",
    },
    {
        "school": "UPPER KEYS ACADEMIC CONNECTIONS FOR EXCELLENCE",
        "district": "MONROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120132008731",
    },
    {
        "school": "CONTRACTED RESIDENTIAL SERVICES",
        "district": "NASSAU",
        "level": "Secondary",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120135008720",
    },
    {
        "school": "CONTRACTED RESIDENTIAL SERVICES",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120138008737",
    },
    {
        "school": "85-E-W-4",
        "district": "ORANGE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008686",
    },
    {
        "school": "INNOVATION MONTESSORI HIGH CHARTER",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008691",
    },
    {
        "school": "AUDUBON PARK SCHOOL",
        "district": "ORANGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008698",
    },
    {
        "school": "83-E-SE-3",
        "district": "ORANGE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008699",
    },
    {
        "school": "CHAMPIONSHIP ACADEMY OF DISTINCTION AT ORLANDO",
        "district": "ORANGE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008732",
    },
    {
        "school": "AMERICAN CLASSICAL CHARTER ACADEMY",
        "district": "OSCEOLA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008750",
    },
    {
        "school": "OLYMPUS INTERNATIONAL ACADEMY",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008724",
    },
    {
        "school": "SOMERSET ACADEMY OF THE ARTS",
        "district": "PALM BEACH",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008747",
    },
    {
        "school": "MIDTOWN ACADEMY",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008706",
    },
    {
        "school": "POLK CHARTER ACADEMY",
        "district": "POLK",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159008671",
    },
    {
        "school": "NAVIGATOR ACADEMY OF LEADERSHIP DAVENPORT",
        "district": "POLK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159008680",
    },
    {
        "school": "NORTHEAST POLK 19-AAA",
        "district": "POLK",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159008685",
    },
    {
        "school": "EDWARD W BOK ACADEMY NORTH",
        "district": "POLK",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159008690",
    },
    {
        "school": "RIDGE TECHNICAL ACADEMY",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159008701",
    },
    {
        "school": "GIBBONS STREET PK CENTER",
        "district": "POLK",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159008708",
    },
    {
        "school": "MAYNARD A TRAVISS TECHNICAL ACADEMY",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159008733",
    },
    {
        "school": "LANGUAGE & LITERACY ACADEMY FOR LEARNING",
        "district": "POLK",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120159008736",
    },
    {
        "school": "TEEN PARENT PK CHILD CARE PROGRAM",
        "district": "PUTNAM",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120162008673",
    },
    {
        "school": "HOSPITAL HOMEBOUND",
        "district": "SANTA ROSA",
        "level": "Other",
        "type": "Special education school",
        "state": "FL",
        "nces_id": "120165008716",
    },
    {
        "school": "ELKHART SCHOOL",
        "district": "SANTA ROSA",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120165008721",
    },
    {
        "school": "SARASOTA COUNTY ACCELERATION ACADEMIES",
        "district": "SARASOTA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120168008743",
    },
    {
        "school": "SUMTER VIRTUAL INSTRUCTION (COURSE OFFERINGS)",
        "district": "SUMTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120180008682",
    },
    {
        "school": "VOLUSIA ONLINE LEARNING-FLVS (FRANCHISE)",
        "district": "VOLUSIA",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192008707",
    },
    {
        "school": "PK CHILD CARE PROGRAM",
        "district": "VOLUSIA",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120192008713",
    },
    {
        "school": "TEEN PARENT PK CHILD CARE PROGRAM",
        "district": "WAKULLA",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120195008689",
    },
    {
        "school": "Clearview Elementary School",
        "district": "Troup County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000104317",
    },
    {
        "school": "Horizon Academy",
        "district": "Coastal Plains RESA",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130002004326",
    },
    {
        "school": "Wilkes County Regional Detention Center",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130002604329",
    },
    {
        "school": "KIPP Soul Primary",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004315",
    },
    {
        "school": "International Charter Academy of Georgia",
        "district": "State Charter Schools II- International Charter Academy of G",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130025004325",
    },
    {
        "school": "SLAM Academy of Atlanta",
        "district": "State Charter Schools II- SLAM Academy of Atlanta",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130025104306",
    },
    {
        "school": "Eddie White Elementary School",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123004309",
    },
    {
        "school": "Kay R Pace Elementary School of the Arts",
        "district": "Clayton County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123004324",
    },
    {
        "school": "Cobb Horizon High School",
        "district": "Cobb County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130129004303",
    },
    {
        "school": "Denmark High School",
        "district": "Forsyth County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222004314",
    },
    {
        "school": "Alliance Academy for Innovation",
        "district": "Forsyth County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130222004320",
    },
    {
        "school": "Glascock County Elementary School",
        "district": "Glascock County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130237004318",
    },
    {
        "school": "Paul Duke STEM High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004313",
    },
    {
        "school": "The Foundry",
        "district": "Hall County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261004305",
    },
    {
        "school": "Cherokee Bluff Middle",
        "district": "Hall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261004308",
    },
    {
        "school": "Cherokee Bluff High School",
        "district": "Hall County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261004327",
    },
    {
        "school": "World Language Academy Middle School",
        "district": "Hall County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130261004328",
    },
    {
        "school": "Haralson County Rebel Academy",
        "district": "Haralson County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130267004310",
    },
    {
        "school": "McClelland Elementary School",
        "district": "Long County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130336004323",
    },
    {
        "school": "Emily Lembeck Early Learning Center",
        "district": "Marietta City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130351004304",
    },
    {
        "school": "Dove Creek Elementary School",
        "district": "Oconee County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130396004316",
    },
    {
        "school": "Belair K-8 School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438004312",
    },
    {
        "school": "DreamHouse Ewa Beach",
        "district": "Hawaii Department of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000305",
    },
    {
        "school": "iSucceed Academy",
        "district": "ISUCCEED VIRTUAL HIGH SCHOOL INC.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160014401111",
    },
    {
        "school": "FERN-WATERS PUBLIC CHARTER SCHOOL",
        "district": "FERN-WATERS PUBLIC CHARTER SCHOOL INC.",
        "level": "Middle",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160018601114",
    },
    {
        "school": "TREASURE VALLEY CLASSICAL ACADEMY",
        "district": "TREASURE VALLEY CLASSICAL ACADEMY INC.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160018801110",
    },
    {
        "school": "ELEVATE ACADEMY",
        "district": "ELEVATE ACADEMY INC.",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160018901113",
    },
    {
        "school": "FORGE INTERNATIONAL SCHOOL",
        "district": "Forge International LLC",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160019001109",
    },
    {
        "school": "JEFFERSON SCHOOL DISTRICT 251 EARLY CHILDHOOD CENTER",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160157001116",
    },
    {
        "school": "Adult LIFE Academy",
        "district": "Eastern IL Area of Spec Educ",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002306578",
    },
    {
        "school": "A.E.R.O-Connect Prog-Satellite",
        "district": "A E R O  Spec Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002406574",
    },
    {
        "school": "A.E.R.O-Functional Acad Learning-",
        "district": "A E R O  Spec Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002406575",
    },
    {
        "school": "A.E.R.O. EC Program-Satellite",
        "district": "A E R O  Spec Educ Coop",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002406580",
    },
    {
        "school": "A.E.R.O-STAR (Autism)-Satellite",
        "district": "A E R O  Spec Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002406581",
    },
    {
        "school": "A.E.R.O.-Comm. Develop.-Satellite",
        "district": "A E R O  Spec Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002406582",
    },
    {
        "school": "Franklin-Jefferson SPED-Int-K-12",
        "district": "Franklin-Jefferson Co Sp Ed Dist",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170004806577",
    },
    {
        "school": "Mid-Valley Satellite Classes",
        "district": "Mid-Valley Special Ed Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005406629",
    },
    {
        "school": "Mid-Valley Transition Program",
        "district": "Mid-Valley Special Ed Coop",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005406638",
    },
    {
        "school": "LIFE (Learning in Functional Envi",
        "district": "Four Rivers Spec Educ Dist",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170008006559",
    },
    {
        "school": "Early Childhood",
        "district": "Four Rivers Spec Educ Dist",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170008006562",
    },
    {
        "school": "OCEC Life Skills",
        "district": "Ogle Co Education Cooperative",
        "level": "Secondary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170008106670",
    },
    {
        "school": "Black Hawk Area DHH Program",
        "district": "Black Hawk Area Sp Ed District",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170008406662",
    },
    {
        "school": "LWASE-Self-K-8",
        "district": "Lincoln-Way Area Spec Ed JA Dist",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170009706669",
    },
    {
        "school": "ROE #40 Safe School Jersey",
        "district": "Calhoun/Greene/Jersy/Macoupin ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016906623",
    },
    {
        "school": "Bi-County Sp Ed-K-2 LIfe Skills-S",
        "district": "Bi-County Special Educ Coop",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706647",
    },
    {
        "school": "Bi-County Sp Ed-3-5 Life Skills-M",
        "district": "Bi-County Special Educ Coop",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706652",
    },
    {
        "school": "Bi-County Sp Ed-ECSE Montmorency",
        "district": "Bi-County Special Educ Coop",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706653",
    },
    {
        "school": "Bi-County Sp Ed-Jr HS LIfe Skills",
        "district": "Bi-County Special Educ Coop",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706655",
    },
    {
        "school": "Bi-County Sp Ed-HI MS",
        "district": "Bi-County Special Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706656",
    },
    {
        "school": "Bi-County Sp Ed-ECSE Tampico",
        "district": "Bi-County Special Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706661",
    },
    {
        "school": "Bi-County Sp Ed-Transition Life S",
        "district": "Bi-County Special Educ Coop",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706666",
    },
    {
        "school": "Bi-County Sp Ed-Life Skills HS-Mo",
        "district": "Bi-County Special Educ Coop",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706674",
    },
    {
        "school": "Bi-County Sp Ed-Life Skill Jr Hgh",
        "district": "Bi-County Special Educ Coop",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706675",
    },
    {
        "school": "Bi-County Sp Ed-K-2 Life Skills-M",
        "district": "Bi-County Special Educ Coop",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706680",
    },
    {
        "school": "Bi-County Sp Ed-ECSE Prophetstown",
        "district": "Bi-County Special Educ Coop",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706683",
    },
    {
        "school": "Bi-County Sp Ed-3-5 LIfe Skills-S",
        "district": "Bi-County Special Educ Coop",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706684",
    },
    {
        "school": "Bi-County Sp Ed-HI Elem",
        "district": "Bi-County Special Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706685",
    },
    {
        "school": "Bi-County Sp Ed-HS LIfe Skills-St",
        "district": "Bi-County Special Educ Coop",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706687",
    },
    {
        "school": "WCISEC HS ED",
        "district": "West Central IL Spec Educ Coop",
        "level": "Secondary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170027206630",
    },
    {
        "school": "WCISEC HS MD",
        "district": "West Central IL Spec Educ Coop",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170027206632",
    },
    {
        "school": "WCISEC MD",
        "district": "West Central IL Spec Educ Coop",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170027206636",
    },
    {
        "school": "WCISEC ED",
        "district": "West Central IL Spec Educ Coop",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170027206639",
    },
    {
        "school": "Eisenhower Coop-DHH Program",
        "district": "Eisenhower Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170031206558",
    },
    {
        "school": "Region III 5-8 CLIP Prgrm",
        "district": "Region III Spec Ed Coop",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170032506605",
    },
    {
        "school": "Region III K-8 CLIP PRG",
        "district": "Region III Spec Ed Coop",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170032506641",
    },
    {
        "school": "DESTINY Program",
        "district": "Southwest Cook Coop Spec Ed",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170139206563",
    },
    {
        "school": "Communication Dev Program",
        "district": "Southwest Cook Coop Spec Ed",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170139206568",
    },
    {
        "school": "Deaf/Hard of Hearing Program",
        "district": "Southwest Cook Coop Spec Ed",
        "level": "Secondary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170139206571",
    },
    {
        "school": "Grundy County Spec Educ Coop",
        "district": "Grundy County Spec Educ Coop",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170139306584",
    },
    {
        "school": "Knox-Warren SE-KW UJH LS",
        "district": "Knox Warren Spec Ed Districts",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143206611",
    },
    {
        "school": "Elgin Math and Science Acad Chtr",
        "district": "Elgin Math and Science Acad Chtr",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170143506608",
    },
    {
        "school": "Franklin Co Detention Center 6-8",
        "district": "Benton CCSD 47",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170595006598",
    },
    {
        "school": "Franklin Co Detention Center 9-12",
        "district": "Benton Cons HSD 103",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170597006588",
    },
    {
        "school": "Oak Knoll Early Childhood Center",
        "district": "Cary CCSD 26",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170873006622",
    },
    {
        "school": "Pathways in Education Brighton Pa",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006587",
    },
    {
        "school": "Ombudsman Chicago West",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006589",
    },
    {
        "school": "Bronzeville Classical Elem Sch",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006590",
    },
    {
        "school": "Ombudsman Chicago Northwest",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006591",
    },
    {
        "school": "Pathways in Education Avondale",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006599",
    },
    {
        "school": "Ombudsman Chicago South",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006602",
    },
    {
        "school": "Sor Juana Ines de la Cruz",
        "district": "City of Chicago SD 299",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006603",
    },
    {
        "school": "Pathways in Education Ashburn",
        "district": "City of Chicago SD 299",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006604",
    },
    {
        "school": "Vermilion Co Detention Center",
        "district": "Danville CCSD 118",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171179006672",
    },
    {
        "school": "Clinton Rosette Middle School",
        "district": "DeKalb CUSD 428",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171200006601",
    },
    {
        "school": "Madison Co Detention Center",
        "district": "Edwardsville CUSD 7",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171353006625",
    },
    {
        "school": "Knox Co Mary Davis Detention Home",
        "district": "Galesburg CUSD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171608006617",
    },
    {
        "school": "Will Co Detention Center 6-8",
        "district": "Joliet PSD 86",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172058006682",
    },
    {
        "school": "Will Co Detention Center 9-12",
        "district": "Joliet Twp HSD 204",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172061006651",
    },
    {
        "school": "LADSE-Phonological Program",
        "district": "Lagrange Area Dept Spec Ed-Ladse",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172159006560",
    },
    {
        "school": "LADSE-Comm Develop",
        "district": "Lagrange Area Dept Spec Ed-Ladse",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172159006561",
    },
    {
        "school": "LADSE-ECSE",
        "district": "Lagrange Area Dept Spec Ed-Ladse",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172159006564",
    },
    {
        "school": "LADSE-Multineeds",
        "district": "Lagrange Area Dept Spec Ed-Ladse",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172159006565",
    },
    {
        "school": "LADSE-Emotional Disabilities",
        "district": "Lagrange Area Dept Spec Ed-Ladse",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172159006566",
    },
    {
        "school": "LADSE-DHH Transition Cntr",
        "district": "Lagrange Area Dept Spec Ed-Ladse",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172159006567",
    },
    {
        "school": "LADSE-DHH-Hinsdale South HS",
        "district": "Lagrange Area Dept Spec Ed-Ladse",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172159006569",
    },
    {
        "school": "LADSE-Project Search",
        "district": "Lagrange Area Dept Spec Ed-Ladse",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172159006570",
    },
    {
        "school": "Lake Co Hulse Detention Center 6-",
        "district": "Lincolnshire-Prairieview SD 103",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172309006634",
    },
    {
        "school": "LASEC-EC",
        "district": "Lockport Area Spec Educ Coop",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172334006648",
    },
    {
        "school": "LASEC-Communication Dev Program",
        "district": "Lockport Area Spec Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172334006650",
    },
    {
        "school": "LASEC Academy",
        "district": "Lockport Area Spec Educ Coop",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172334006664",
    },
    {
        "school": "LASEC-CAD Program",
        "district": "Lockport Area Spec Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172334006686",
    },
    {
        "school": "Franklin Elementary School",
        "district": "Mattoon CUSD 2",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172505006573",
    },
    {
        "school": "McClean Co Detention Center",
        "district": "McLean County USD 5",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172862006600",
    },
    {
        "school": "NIA-D/HH PK-Elem Prgrm",
        "district": "Northwestern Illinois Assn",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172902006586",
    },
    {
        "school": "NIA D/HH HS Prgrm",
        "district": "Northwestern Illinois Assn",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172902006592",
    },
    {
        "school": "NIA-D/HH MS Prgrm",
        "district": "Northwestern Illinois Assn",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172902006596",
    },
    {
        "school": "LaSalle Co Detention Center 9-12",
        "district": "Ottawa Twp HSD 140",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173033006613",
    },
    {
        "school": "Lake Co Hulse Detention Center 9-",
        "district": "Adlai E Stevenson HSD 125",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173258006631",
    },
    {
        "school": "Queen Bee School",
        "district": "Queen Bee SD 16",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173297006594",
    },
    {
        "school": "Winnebago Co Detention Center",
        "district": "Rockford SD 205",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451006572",
    },
    {
        "school": "Sangamon Co Detention Center",
        "district": "Springfield SD 186",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708006668",
    },
    {
        "school": "Fox Ridge School",
        "district": "St Charles CUSD 303",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717006614",
    },
    {
        "school": "Kane Co Detention Center",
        "district": "St Charles CUSD 303",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173717006642",
    },
    {
        "school": "Taylorville Alternative School",
        "district": "Taylorville CUSD 3",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173870006557",
    },
    {
        "school": "Center for Academics and Technolo",
        "district": "Thornton Fractional Twp HSD 215",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173894006579",
    },
    {
        "school": "Center for Alternative Learning",
        "district": "Thornton Fractional Twp HSD 215",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173894006583",
    },
    {
        "school": "Champaign Co Detention Center",
        "district": "Urbana SD 116",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173996006576",
    },
    {
        "school": "LaSalle Co Detention Center 6-8",
        "district": "Wallace CCSD 195",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "174053006627",
    },
    {
        "school": "Parke Heritage High School",
        "district": "North Central Parke Comm Schl Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180011802644",
    },
    {
        "school": "Parke Heritage Middle School",
        "district": "North Central Parke Comm Schl Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180011802667",
    },
    {
        "school": "Urban ACT Academy",
        "district": "Urban ACT Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180019202640",
    },
    {
        "school": "Vanguard Collegiate of Indy",
        "district": "Vanguard Collegiate of Indy",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180019302639",
    },
    {
        "school": "Matchbook Learning",
        "district": "Matchbook Learning",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180019402642",
    },
    {
        "school": "Gary Middle College West",
        "district": "Gary Middle College West",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180019502641",
    },
    {
        "school": "Paramount Community Heights",
        "district": "Paramount Community Heights",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180019602643",
    },
    {
        "school": "Excel Center - Muncie",
        "district": "Excel Center - Muncie",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180019702662",
    },
    {
        "school": "Indiana Agriculture and Technology",
        "district": "Indiana Agriculture and Technology",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180019802665",
    },
    {
        "school": "Allegiant Preparatory Academy",
        "district": "Allegiant Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180019902648",
    },
    {
        "school": "Excel Center - Gary",
        "district": "Excel Center - Gary",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180020002652",
    },
    {
        "school": "pilotED Schools Bethel Park",
        "district": "pilotED Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180020202661",
    },
    {
        "school": "Timothy L. Johnson Academy Middle",
        "district": "Timothy L. Johnson Academy Middle",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180020302668",
    },
    {
        "school": "Early Learning Center",
        "district": "Monroe County Community Sch Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180063002663",
    },
    {
        "school": "Harwood Career Prep High School",
        "district": "Evansville Vanderburgh School Corp",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180345002649",
    },
    {
        "school": "Gary Middle School",
        "district": "Gary Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180387002664",
    },
    {
        "school": "Impact Academy",
        "district": "Indianapolis Public Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002651",
    },
    {
        "school": "Thrival Academy",
        "district": "Indianapolis Public Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180477002653",
    },
    {
        "school": "New Palestine Intermediate School",
        "district": "Southern Hancock Co Com Sch Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181071002659",
    },
    {
        "school": "Indiana Digital Elementary",
        "district": "Union School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181173002654",
    },
    {
        "school": "Indiana Digital Alternative School",
        "district": "Union School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181173002660",
    },
    {
        "school": "Indiana Digital JR and High School",
        "district": "Union School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181173002666",
    },
    {
        "school": "Willow Lake Elementary School",
        "district": "M S D Washington Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002647",
    },
    {
        "school": "Clearwater Elementary School",
        "district": "M S D Washington Township",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181272002657",
    },
    {
        "school": "AHSTW Intermediate School",
        "district": "AHSTW Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190408002261",
    },
    {
        "school": "Ruby Van Meter",
        "district": "Des Moines Independent Comm School District",
        "level": "Other",
        "type": "Special education school",
        "state": "IA",
        "nces_id": "190897002260",
    },
    {
        "school": "Rock Valley Middle School",
        "district": "Rock Valley Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192466002262",
    },
    {
        "school": "Logan Preschool",
        "district": "Shenandoah Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192607002259",
    },
    {
        "school": "Lawrence Gardner High School",
        "district": "Department of Corrections",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200002402104",
    },
    {
        "school": "Blackmore Elementary",
        "district": "El Dorado",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200573002105",
    },
    {
        "school": "Lansing Intermediate School",
        "district": "Lansing",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200834002107",
    },
    {
        "school": "Opportunity Academy",
        "district": "Newton",
        "level": "High",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200996002109",
    },
    {
        "school": "Summit Trail Middle School",
        "district": "Olathe",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014002102",
    },
    {
        "school": "Lenexa Hills Elementary",
        "district": "Shawnee Mission Pub Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201164002106",
    },
    {
        "school": "Timber Sage Elementary School",
        "district": "Spring Hill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201185002108",
    },
    {
        "school": "Bryant Opportunity Academy",
        "district": "Wichita",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201299002103",
    },
    {
        "school": "iLEAD Academy",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902468",
    },
    {
        "school": "Delta Academy",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902478",
    },
    {
        "school": "Southeast Kentucky Academy",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902479",
    },
    {
        "school": "Ballyshannon Middle School",
        "district": "Boone County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210051002460",
    },
    {
        "school": "Boyd County Central School",
        "district": "Boyd County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210062002466",
    },
    {
        "school": "Edna L. Toliver Intermediate School",
        "district": "Danville Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210144002476",
    },
    {
        "school": "Mary G. Hogsett Primary School",
        "district": "Danville Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210144002477",
    },
    {
        "school": "The Center for Academic Improvement",
        "district": "Daviess County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210147002470",
    },
    {
        "school": "Success Academy",
        "district": "Fayette County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210186002463",
    },
    {
        "school": "William Cofield High School",
        "district": "Franklin County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210201002471",
    },
    {
        "school": "Fulton County Middle School",
        "district": "Fulton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210210002480",
    },
    {
        "school": "Jackson Co Schools Learning Center",
        "district": "Jackson County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210294002461",
    },
    {
        "school": "Boonesborough Elementary",
        "district": "Madison County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210372002481",
    },
    {
        "school": "MC@HOME",
        "district": "Marshall County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210381002474",
    },
    {
        "school": "Northview Elementary",
        "district": "Montgomery County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210425002472",
    },
    {
        "school": "Great Crossing High School",
        "district": "Scott County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526002482",
    },
    {
        "school": "Creekside Elementary",
        "district": "Scott County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210526002483",
    },
    {
        "school": "Trimble County Alternative Program",
        "district": "Trimble County",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210561002464",
    },
    {
        "school": "Trimble County JR/SR High School",
        "district": "Trimble County",
        "level": "High",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210561002475",
    },
    {
        "school": "Jennings Creek Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210573002465",
    },
    {
        "school": "Jackson Academy Elementary",
        "district": "Warren County",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210573002469",
    },
    {
        "school": "Haughton Elementary School",
        "district": "Bossier Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220027002450",
    },
    {
        "school": "FirstLine Live Oak",
        "district": "FirstLine Live Oak",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030202460",
    },
    {
        "school": "Audubon Charter School - Gentilly",
        "district": "Audubon Charter School - Gentilly",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030302458",
    },
    {
        "school": "New Harmony High Institute",
        "district": "New Harmony High Institute",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030402457",
    },
    {
        "school": "Athlos Academy of Jefferson Parish",
        "district": "Athlos Academy of Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030502452",
    },
    {
        "school": "Dwight D. Eisenhower Charter School",
        "district": "Dwight D. Eisenhower Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030602455",
    },
    {
        "school": "Rosenwald Collegiate Academy",
        "district": "Rosenwald Collegiate Academy",
        "level": "Secondary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030702461",
    },
    {
        "school": "BASIS Baton Rouge",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002451",
    },
    {
        "school": "IDEA Bridge",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002453",
    },
    {
        "school": "The Emerge School for Autism",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002454",
    },
    {
        "school": "IDEA Innovation",
        "district": "East Baton Rouge Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220054002459",
    },
    {
        "school": "Belle Chasse Primary School",
        "district": "Plaquemines Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220123002456",
    },
    {
        "school": "Cony Middle School",
        "district": "Augusta Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230264023175",
    },
    {
        "school": "Ash Point Community School",
        "district": "RSU 13",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478723176",
    },
    {
        "school": "Harpswell Coastal Academy Divisions 2 and 3",
        "district": "Harpswell Coastal Academy",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231481623173",
    },
    {
        "school": "Sebago Elementary School",
        "district": "Sebago Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231483700675",
    },
    {
        "school": "Katahdin Middle/High School",
        "district": "RSU 89",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231483800397",
    },
    {
        "school": "Katahdin Elementary School",
        "district": "RSU 89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231483800398",
    },
    {
        "school": "Maine Ocean School",
        "district": "Maine Ocean School",
        "level": "High",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231484023174",
    },
    {
        "school": "Carrie Weedon Early Education Center",
        "district": "Anne Arundel County Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240006001746",
    },
    {
        "school": "Honeygo Elementary",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001750",
    },
    {
        "school": "Butterfly Ridge Elementary",
        "district": "Frederick County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240033001748",
    },
    {
        "school": "Hanover Hills",
        "district": "Howard County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240042001749",
    },
    {
        "school": "Bayard Rustin Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001747",
    },
    {
        "school": "Hampden Charter School of Science West",
        "district": "Hampden Charter School of Science West (District)",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250058802888",
    },
    {
        "school": "Map Academy Charter School",
        "district": "Map Academy Charter School (District)",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250058902885",
    },
    {
        "school": "Phoenix Academy Public Charter High School Lawrence",
        "district": "Phoenix Academy Public Charter High School Lawrence (Distric",
        "level": "High",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250059002886",
    },
    {
        "school": "Gibbs School",
        "district": "Arlington",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250198002889",
    },
    {
        "school": "Chelsea Opportunity Academy",
        "district": "Chelsea",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "250354002890",
    },
    {
        "school": "Veritas Prep Holyoke",
        "district": "Holyoke",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627002895",
    },
    {
        "school": "Holyoke STEM Academy",
        "district": "Holyoke",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250627002897",
    },
    {
        "school": "Cardinal O'Connell Early Learning Center",
        "district": "Lowell",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250702002891",
    },
    {
        "school": "Lanesborough Elementary",
        "district": "Mount Greylock",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250816002887",
    },
    {
        "school": "Williamstown Elementary",
        "district": "Mount Greylock",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250816002899",
    },
    {
        "school": "Anne Bradstreet Early Childhood Center",
        "district": "North Andover",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250870002883",
    },
    {
        "school": "Southbridge Academy",
        "district": "Southbridge",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MA",
        "nces_id": "251101002896",
    },
    {
        "school": "Springfield International Academy at Sci-Tech",
        "district": "Springfield",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002884",
    },
    {
        "school": "Springfield International Academy at Johnson",
        "district": "Springfield",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251113002898",
    },
    {
        "school": "Whitin Intermediate",
        "district": "Uxbridge",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251185002892",
    },
    {
        "school": "Preschool at Wellesley Schools",
        "district": "Wellesley",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251227002893",
    },
    {
        "school": "Westfield Intermediate School",
        "district": "Westfield",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251263002894",
    },
    {
        "school": "Battle Creek STEM Innovation Center",
        "district": "Battle Creek Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000508921",
    },
    {
        "school": "Fremont International Academy",
        "district": "Battle Creek Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260000508923",
    },
    {
        "school": "Cole Academy East",
        "district": "Cole Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260007908857",
    },
    {
        "school": "Old Redford Academy  Middle School",
        "district": "Old Redford Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260024208903",
    },
    {
        "school": "American International Academy Upper Elementary",
        "district": "American International Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260098608907",
    },
    {
        "school": "Great Lakes Cyber Academy HS",
        "district": "Great Lakes Cyber Academy",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260105008885",
    },
    {
        "school": "Waterford Montessori Academy",
        "district": "Waterford Montessori Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260105308898",
    },
    {
        "school": "Keys Grace Academy",
        "district": "Keys Grace Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110008905",
    },
    {
        "school": "Legacy Academy",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308902",
    },
    {
        "school": "Academy of the Americas at Logan",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308927",
    },
    {
        "school": "Barton Elementary School",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308930",
    },
    {
        "school": "The School at Marygrove",
        "district": "Detroit Public Schools Community District",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308932",
    },
    {
        "school": "Edmonson Montessori",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308933",
    },
    {
        "school": "Distinctive College Prep",
        "district": "Distinctive College Prep.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260111508897",
    },
    {
        "school": "Pembroke Academy",
        "district": "Pembroke Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260111608870",
    },
    {
        "school": "Flex High School of Michigan",
        "district": "Flex High School of Michigan",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260111708862",
    },
    {
        "school": "Lighthouse Connections Academy",
        "district": "Lighthouse Connections Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260111808853",
    },
    {
        "school": "Old Mission Peninsula School",
        "district": "Old Mission Peninsula School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260111908865",
    },
    {
        "school": "Uplift Michigan Academy",
        "district": "Uplift Michigan Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260112008890",
    },
    {
        "school": "The Woodley Leadership Academy",
        "district": "The Woodley Leadership Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260112108906",
    },
    {
        "school": "Flextech High School Shepherd",
        "district": "Flextech High School Shepherd",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260112208877",
    },
    {
        "school": "Ivywood Classical Academy",
        "district": "Ivywood Classical Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260112308912",
    },
    {
        "school": "Flint Cultural Center Academy",
        "district": "Flint Cultural Center Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260112408908",
    },
    {
        "school": "Westfield Preparatory High School",
        "district": "Westfield Charter Academy",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260112508928",
    },
    {
        "school": "Westfield Charter Academy",
        "district": "Westfield Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260112508931",
    },
    {
        "school": "Orchard Academy",
        "district": "Orchard Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260112708914",
    },
    {
        "school": "Henry Niedermeier Elementary School",
        "district": "Airport Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260198008925",
    },
    {
        "school": "Allendale Early Childhood Center",
        "district": "Allendale Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260255008909",
    },
    {
        "school": "Diploma and Careers Institute",
        "district": "Avondale School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260369008854",
    },
    {
        "school": "Avondale Gifted and Talented Education",
        "district": "Avondale School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260369008910",
    },
    {
        "school": "Bay City Virtual School",
        "district": "Bay City School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260426008922",
    },
    {
        "school": "Smith Road Elementary School",
        "district": "Bedford Public Schools",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "260447008461",
    },
    {
        "school": "Charlotte Public Schools Project Success",
        "district": "Charlotte Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260877008861",
    },
    {
        "school": "Cheboygan Middle School",
        "district": "Cheboygan Area Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260891008856",
    },
    {
        "school": "Comstock Park Flex Academy",
        "district": "Comstock Park Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261062008929",
    },
    {
        "school": "CAPS Academy",
        "district": "Coopersville Area Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261083008899",
    },
    {
        "school": "Bates",
        "district": "Dexter Community School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261203008866",
    },
    {
        "school": "Dexter Early Elementary Complex",
        "district": "Dexter Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261203008924",
    },
    {
        "school": "SER Metro YouthBuild Learning Academy",
        "district": "Ecorse Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261293008901",
    },
    {
        "school": "Flint Junior High School",
        "district": "Flint School District of the City of",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261452008858",
    },
    {
        "school": "Kearsley Street",
        "district": "Flint School District of the City of",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261452008864",
    },
    {
        "school": "Raider Virtual Academy",
        "district": "Flushing Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261455008919",
    },
    {
        "school": "CA Frost Environmental Science Academy Elementary",
        "district": "Grand Rapids Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008880",
    },
    {
        "school": "Grand Rapids Montessori MiddleHigh",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008881",
    },
    {
        "school": "Ottawa High Transition",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261644008882",
    },
    {
        "school": "Grand Rapids Public Museum Middle",
        "district": "Grand Rapids Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008886",
    },
    {
        "school": "Union High Transition",
        "district": "Grand Rapids Public Schools",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "261644008894",
    },
    {
        "school": "Hamilton Virtual School",
        "district": "Hamilton Community Schools",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261740008874",
    },
    {
        "school": "The Harper Woods College and Career Institute",
        "district": "Harper Woods The School District of the City of",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MI",
        "nces_id": "261776008935",
    },
    {
        "school": "Innovation Academy",
        "district": "Howell Public Schools",
        "level": "High",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261872008860",
    },
    {
        "school": "El Puente Spanish Immersion",
        "district": "Jenison Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261983008873",
    },
    {
        "school": "JIA Elementary",
        "district": "Jenison Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261983008917",
    },
    {
        "school": "Boys To Men Group Home",
        "district": "Kalamazoo Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261995008878",
    },
    {
        "school": "Kalamazoo County Juvenile Home Youth Center School",
        "district": "Kalamazoo Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261995008883",
    },
    {
        "school": "Lets Talk About It Girls Home",
        "district": "Kalamazoo Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261995008887",
    },
    {
        "school": "Lets Talk About It Home for Young Men",
        "district": "Kalamazoo Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261995008893",
    },
    {
        "school": "Kearsley Virtual Academy",
        "district": "Kearsley Community School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262007008934",
    },
    {
        "school": "Pine Tree Center",
        "district": "Lake Orion Community Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262073008850",
    },
    {
        "school": "Lakeview Alternative High School",
        "district": "Lakeview Sch. District (Calhoun)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262085008913",
    },
    {
        "school": "Lakeview Virtual School",
        "district": "Lakeview Public Schools (Macomb)",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262088008895",
    },
    {
        "school": "Gardner International School",
        "district": "Lansing Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115008871",
    },
    {
        "school": "Woodcreek Montessori",
        "district": "Lansing Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262115008918",
    },
    {
        "school": "Riverside Intermediate School",
        "district": "Manchester Community Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262238008851",
    },
    {
        "school": "McBain Middle School",
        "district": "McBain Rural Agricultural Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262331008926",
    },
    {
        "school": "PrePrimary Center at Carpenter Street School",
        "district": "Midland Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262382008868",
    },
    {
        "school": "North Central Middle School",
        "district": "North Central Area Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "262922008879",
    },
    {
        "school": "Redford Union Virtual Learning",
        "district": "Redford Union Schools District No. 1",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262946008900",
    },
    {
        "school": "Vestaburg Community Alternative Education School",
        "district": "Vestaburg Community Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "263492008891",
    },
    {
        "school": "EUPISD Project Search",
        "district": "Eastern Upper Peninsula ISD",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268028008892",
    },
    {
        "school": "WIN-Middle School",
        "district": "MID STATE EDUCATION DISTRICT",
        "level": "Middle",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007305181",
    },
    {
        "school": "SWWC ELC - Montevideo",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270008605170",
    },
    {
        "school": "Hennepin Middle School",
        "district": "HENNEPIN ELEMENTARY SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270033505203",
    },
    {
        "school": "MMSA Middle School",
        "district": "MINNESOTA MATH AND SCIENCE ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039905177",
    },
    {
        "school": "MMSA High School",
        "district": "MINNESOTA MATH AND SCIENCE ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270039905179",
    },
    {
        "school": "Level Up Middle Academy",
        "district": "LEVEL UP ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270040805167",
    },
    {
        "school": "SNW - Big Lake HS Transitions",
        "district": "SHERBURNE AND NORTHERN WRIGHT SPECI",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041305213",
    },
    {
        "school": "SNW - Liberty Elementary",
        "district": "SHERBURNE AND NORTHERN WRIGHT SPECI",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041305214",
    },
    {
        "school": "SNW - Becker Intermediate",
        "district": "SHERBURNE AND NORTHERN WRIGHT SPECI",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041305215",
    },
    {
        "school": "SNW - Big Lake Middle School",
        "district": "SHERBURNE AND NORTHERN WRIGHT SPECI",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041305216",
    },
    {
        "school": "The Annica Program",
        "district": "Southwest Metro Intermediate 288",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270042005190",
    },
    {
        "school": "Passageways",
        "district": "Southwest Metro Intermediate 288",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270042005193",
    },
    {
        "school": "Prairie Care",
        "district": "Southwest Metro Intermediate 288",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270042005204",
    },
    {
        "school": "Proctor LIFE",
        "district": "Northern Lights Academy Cooperative",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270044205186",
    },
    {
        "school": "Quantum STEAM Academy Charter",
        "district": "Quantum STEAM Academy Charter",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270045105182",
    },
    {
        "school": "STEAM Academy Charter School",
        "district": "STEAM Academy Charter School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270045305171",
    },
    {
        "school": "Great Oaks Academy Charter School",
        "district": "Great Oaks Academy Charter School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270045405175",
    },
    {
        "school": "Aurora Waasakone Community of Learn",
        "district": "Aurora Waasakone Community of Learn",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270045505196",
    },
    {
        "school": "Cambia Hills",
        "district": "NORTHEAST METRO 916",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270226405176",
    },
    {
        "school": "Karuna",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270226405211",
    },
    {
        "school": "Sunflower Learning Center - WBL",
        "district": "NORTHEAST METRO 916",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270226405212",
    },
    {
        "school": "Brookside Academy",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270741005198",
    },
    {
        "school": "Shared Time School",
        "district": "FERGUS FALLS PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "271188005201",
    },
    {
        "school": "Eden Prairie Online",
        "district": "EDEN PRAIRIE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271422005194",
    },
    {
        "school": "Nicollet Special Education",
        "district": "NICOLLET PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "272358005172",
    },
    {
        "school": "LION Program - Alternative Educatio",
        "district": "OGILVIE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272397005208",
    },
    {
        "school": "Owatonna School Readiness",
        "district": "OWATONNA PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272805005195",
    },
    {
        "school": "Credit Recovery",
        "district": "PRINCETON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273003005200",
    },
    {
        "school": "Central Education Center",
        "district": "RICHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273175005189",
    },
    {
        "school": "Robbinsdale Virtual Academy",
        "district": "ROBBINSDALE PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273178005191",
    },
    {
        "school": "Hoover Early Learning School",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273180005188",
    },
    {
        "school": "LEAP - Launching Emerging Adults Pr",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273180005197",
    },
    {
        "school": "Middle School Right Fit",
        "district": "ROCHESTER PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273180005219",
    },
    {
        "school": "Hillside Early Childhood Center",
        "district": "SAUK RAPIDS-RICE PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273288005206",
    },
    {
        "school": "Restore Program",
        "district": "St. Francis Area Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273354005173",
    },
    {
        "school": "Crossroads School",
        "district": "St. Francis Area Schools",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273354005205",
    },
    {
        "school": "Gordon Parks HS Summer",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384005168",
    },
    {
        "school": "LEAP HS Summer",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273384005209",
    },
    {
        "school": "E-STEM Middle School",
        "district": "ST. PAUL PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273384005210",
    },
    {
        "school": "Summer NW Area Learning Center",
        "district": "THIEF RIVER FALLS SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273885005178",
    },
    {
        "school": "Middle School ALC",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274272005220",
    },
    {
        "school": "South Fork Program",
        "district": "RIVER BEND EDUCATION DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279135305183",
    },
    {
        "school": "Raptor Program",
        "district": "RIVER BEND EDUCATION DISTRICT",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279135305192",
    },
    {
        "school": "Connect and Soar Program",
        "district": "RIVER BEND EDUCATION DISTRICT",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279135305199",
    },
    {
        "school": "LCWM ECSE",
        "district": "LAKE CRYSTAL-WELLCOME MEMORIAL",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "279144505169",
    },
    {
        "school": "MOORHEAD CENTRAL SCHOOL",
        "district": "SUNFLOWER CTY CONS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280018701498",
    },
    {
        "school": "Joel E Smilow Collegiate",
        "district": "JOEL E SMILOW COLLEGIATE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019301502",
    },
    {
        "school": "CLARKSDALE COLLEGIATE",
        "district": "CLARKSDALE COLLEGIATE DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019401492",
    },
    {
        "school": "S V MARSHALL ELEMENTARY SCHOOL",
        "district": "HOLMES CO CONSOLIDATED SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019501486",
    },
    {
        "school": "HOLMES COUNTY CENTRAL HIGH SCHOOL",
        "district": "HOLMES CO CONSOLIDATED SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019501488",
    },
    {
        "school": "HOLMES LEARNING CENTER",
        "district": "HOLMES CO CONSOLIDATED SCHOOL DIST",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280019501490",
    },
    {
        "school": "WILLIAMS-SULLIVAN ELEMENTARY",
        "district": "HOLMES CO CONSOLIDATED SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019501491",
    },
    {
        "school": "DURANT ELEMENTARY SCHOOL",
        "district": "HOLMES CO CONSOLIDATED SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019501495",
    },
    {
        "school": "WILLIAM DEAN JR. ELEMENTARY SCHOOL",
        "district": "HOLMES CO CONSOLIDATED SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019501496",
    },
    {
        "school": "GOODMAN PICKENS ELEMENTARY SCHOOL",
        "district": "HOLMES CO CONSOLIDATED SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019501503",
    },
    {
        "school": "HOLMES CO CAREER TECHNICAL CENTER",
        "district": "HOLMES CO CONSOLIDATED SCHOOL DIST",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280019501505",
    },
    {
        "school": "WINONA SECONDARY SCHOOL",
        "district": "WINONA-MONTGOMERY CONSOLIDATED",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019601485",
    },
    {
        "school": "WINONA ELEMENTARY SCHOOL",
        "district": "WINONA-MONTGOMERY CONSOLIDATED",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019601493",
    },
    {
        "school": "WINONA VOC COMPLEX",
        "district": "WINONA-MONTGOMERY CONSOLIDATED",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280019601500",
    },
    {
        "school": "MS SCHOOL FOR THE DEAF",
        "district": "MS SCHS FOR THE BLIND AND DEAF",
        "level": "Other",
        "type": "Special education school",
        "state": "MS",
        "nces_id": "280118901504",
    },
    {
        "school": "KEMPER COUNTY MIDDLE SCHOOL",
        "district": "KEMPER CO SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280231001489",
    },
    {
        "school": "LUMBERTON HIGH SCHOOL",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001484",
    },
    {
        "school": "LUMBERTON ELEMENTARY",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001487",
    },
    {
        "school": "LUMBERTON MIDDLE SCHOOL",
        "district": "LAMAR COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280240001507",
    },
    {
        "school": "MARION CO ALT SCHOOL",
        "district": "MARION CO SCHOOL DIST",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280282001494",
    },
    {
        "school": "NORTH PIKE UPPER ELEMENTARY SCHOOL",
        "district": "NORTH PIKE SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280324001509",
    },
    {
        "school": "OKOLONA MIDDLE SCHOOL",
        "district": "OKOLONA SEPARATE SCHOOL DIST",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280339001482",
    },
    {
        "school": "COLDWATER ELEMENTARY SCHOOL",
        "district": "TATE CO SCHOOL DIST",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280423001499",
    },
    {
        "school": "COLDWATER HIGH SCHOOL",
        "district": "TATE CO SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280423001508",
    },
    {
        "school": "ACADEMIE LAFAYETTE - ARMOUR",
        "district": "ACADEMIE LAFAYETTE",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290001703331",
    },
    {
        "school": "ALLEN VILLAGE JUNIOR",
        "district": "ALLEN VILLAGE",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002503325",
    },
    {
        "school": "ALLEN VILLAGE PRIMARY",
        "district": "ALLEN VILLAGE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290002503327",
    },
    {
        "school": "GRAND CENTER ARTS ACADEMY HIGH",
        "district": "CONFLUENCE ACADEMIES",
        "level": "High",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290057903342",
    },
    {
        "school": "GRAND CENTER ARTS ACAD MIDDLE",
        "district": "CONFLUENCE ACADEMIES",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290057903345",
    },
    {
        "school": "NORTH SIDE COMMUNITY-GRAND CTR",
        "district": "NORTH SIDE COMMUNITY SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290058903344",
    },
    {
        "school": "ADVANCE PRESCHOOL",
        "district": "ADVANCE R-IV",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290288003340",
    },
    {
        "school": "LITTLE STINGERS PRESCHOOL",
        "district": "FAIR PLAY R-II",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291173003338",
    },
    {
        "school": "TAYLOR EARLY CHILDHOOD",
        "district": "DUNKLIN R-V",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291425003326",
    },
    {
        "school": "CAPITAL CITY HIGH SCHOOL",
        "district": "JEFFERSON CITY",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291619003346",
    },
    {
        "school": "LINCOLN COLLEGE ACADEMY MIDDLE",
        "district": "KANSAS CITY 33",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291640003322",
    },
    {
        "school": "KEARNEY EARLY EDUCATION CENTER",
        "district": "KEARNEY R-I",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291645003329",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "MARYVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292049003336",
    },
    {
        "school": "NIANGUA MIDDLE SCHOOL",
        "district": "NIANGUA R-V",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292250003343",
    },
    {
        "school": "GATEWAY 6TH GRADE CENTER",
        "district": "NORTH KANSAS CITY 74",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280003321",
    },
    {
        "school": "RISING HILL ELEMENTARY",
        "district": "NORTH KANSAS CITY 74",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292280003335",
    },
    {
        "school": "OZARK TIGERPAW EARLY CHILD CTR",
        "district": "OZARK R-VI",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292343003333",
    },
    {
        "school": "EARLY CHILDHOOD",
        "district": "PARKWAY C-2",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292358003349",
    },
    {
        "school": "MEADOW HEIGHTS MIDDLE SCHOOL",
        "district": "MEADOW HEIGHTS R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292364003339",
    },
    {
        "school": "PATTONVILLE EARLY CHILDHOOD",
        "district": "PATTONVILLE R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292370003328",
    },
    {
        "school": "EAGLE HEIGHTS ELEMENTARY",
        "district": "SMITHVILLE R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292841003341",
    },
    {
        "school": "ST.CHARLES EARLY CHILDHOOD CTR",
        "district": "ST. CHARLES R-VI",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292892003334",
    },
    {
        "school": "LITTLE TIGER PRESCHOOL",
        "district": "STOCKTON R-I",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292952003323",
    },
    {
        "school": "COGDILL EARLY CHILDHOOD CENTER",
        "district": "STRAFFORD R-VI",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292964003330",
    },
    {
        "school": "LINCOLN CO EARLY CHILDHOOD CTR",
        "district": "TROY R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293045003347",
    },
    {
        "school": "QULIN MIDDLE",
        "district": "TWIN RIVERS R-X",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293052003337",
    },
    {
        "school": "VIENNA MIDDLE",
        "district": "MARIES CO. R-I",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293087003324",
    },
    {
        "school": "WILLIAMS EARLY CHILDHOOD CTR",
        "district": "WAYNESVILLE R-VI",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293144003332",
    },
    {
        "school": "OSAGE CO. R-III PRESCHOOL",
        "district": "OSAGE CO. R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293183003348",
    },
    {
        "school": "Radley Elementary School",
        "district": "East Helena K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065500268",
    },
    {
        "school": "Eastgate School",
        "district": "East Helena K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065500908",
    },
    {
        "school": "East Valley Middle School",
        "district": "East Helena K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065500995",
    },
    {
        "school": "Prickly Pear Elem",
        "district": "East Helena K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065501122",
    },
    {
        "school": "Lockwood Intermediate",
        "district": "Lockwood K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065600529",
    },
    {
        "school": "Lockwood Primary",
        "district": "Lockwood K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065600530",
    },
    {
        "school": "Lockwood Middle School",
        "district": "Lockwood K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065600912",
    },
    {
        "school": "Giant Springs Elementary",
        "district": "Great Falls Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301304001121",
    },
    {
        "school": "Hellgate El Intermediate",
        "district": "Hellgate Elem",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301386001119",
    },
    {
        "school": "Jeannette Rankin Elementary Sc",
        "district": "Kalispell Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301545001120",
    },
    {
        "school": "Grass Land Colony School",
        "district": "Centerville Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "302513001123",
    },
    {
        "school": "ST PAUL JR/SR HIGH SCHOOL",
        "district": "ST PAUL PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310008502369",
    },
    {
        "school": "ADAMS CENTRAL ELEMENTARY SCHOOL",
        "district": "ADAMS CENTRAL PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310277002370",
    },
    {
        "school": "ADAMS CENTRAL EARLY CHILDHOOD CENTER",
        "district": "ADAMS CENTRAL PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310277002372",
    },
    {
        "school": "ELKHORN BLUE SAGE ELEMENTARY",
        "district": "ELKHORN PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317011002373",
    },
    {
        "school": "YOUNG ADULT PROGRAM",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317071002367",
    },
    {
        "school": "PATHFINDER PROGRAM - 9-12",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317071002368",
    },
    {
        "school": "PATHFINDER PROGRAM - K-5",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317071002376",
    },
    {
        "school": "SIXPENCE PRESCHOOL",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317071002377",
    },
    {
        "school": "ESU #2 INDEPENDENT SCHOOL",
        "district": "FREMONT PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317071002380",
    },
    {
        "school": "MIDDLE SCHOOL STUDENT SUPPORT PROGRAM",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317284002374",
    },
    {
        "school": "LPS GRADUATION PATHWAYS PROGRAM",
        "district": "LINCOLN PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317284002382",
    },
    {
        "school": "KEITH LUTZ HORIZON HIGH SCHOOL",
        "district": "MILLARD PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "317374002375",
    },
    {
        "school": "3-YEAR-OLD PRESCHOOL",
        "district": "SOUTHERN SCHOOL DISTRICT 1",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317718002379",
    },
    {
        "school": "SIMEON SCHOOL",
        "district": "VALENTINE COMMUNITY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317802002371",
    },
    {
        "school": "ESU 7 CENTER",
        "district": "EDUCATIONAL SERVICE UNIT 07",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "318007002381",
    },
    {
        "school": "Somerset Skye Canyon",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100911",
    },
    {
        "school": "Legacy Traditional Cadence",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100912",
    },
    {
        "school": "Somerset Aliante",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100921",
    },
    {
        "school": "Coral Academy of Science Las Vegas Eastgate",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100922",
    },
    {
        "school": "NV State HS Meadowood",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100924",
    },
    {
        "school": "NV State HS Sunrise",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100928",
    },
    {
        "school": "Legacy Traditional School Southwest Las Vegas",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100934",
    },
    {
        "school": "NEVADA STATE HIGH SCHOOL SOUTHWEST",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100937",
    },
    {
        "school": "NV Rise ES",
        "district": "ACHIEVEMENT SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320002200917",
    },
    {
        "school": "NV Prep",
        "district": "ACHIEVEMENT SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320002200929",
    },
    {
        "school": "Dennis Ortwein Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000915",
    },
    {
        "school": "Shirley A Barber Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000916",
    },
    {
        "school": "Quest Program",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000923",
    },
    {
        "school": "Kenneth Divich Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000927",
    },
    {
        "school": "Robert and Sandy Ellis Elementary",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000930",
    },
    {
        "school": "Jenkins  Earl N ES",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000933",
    },
    {
        "school": "Abston  Sandra B ES",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000935",
    },
    {
        "school": "Liberty Peak Elementary School",
        "district": "ELKO COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320012000931",
    },
    {
        "school": "Sky Ranch Middle School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000913",
    },
    {
        "school": "VOICE Program",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NV",
        "nces_id": "320048000926",
    },
    {
        "school": "DESERT SKIES MIDDLE SCHOOL",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000932",
    },
    {
        "school": "Nick Poulakidas Elementary School",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000936",
    },
    {
        "school": "Inter-Lakes Middle School",
        "district": "Inter-lakes School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330396000731",
    },
    {
        "school": "Inter-Lakes Elementary School",
        "district": "Inter-lakes School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330396000734",
    },
    {
        "school": "Oyster River Preschool Education Program",
        "district": "Oyster River Coop School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330552000735",
    },
    {
        "school": "Idlehurst Elementary School",
        "district": "Somersworth School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330624000732",
    },
    {
        "school": "Maple Wood Elementary School",
        "district": "Somersworth School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330624000733",
    },
    {
        "school": "Achievers Early College Prep Charter School",
        "district": "Achievers Early College Prep Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340079403457",
    },
    {
        "school": "Middlesex County STEM Charter School",
        "district": "Middlesex County STEM Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340079503451",
    },
    {
        "school": "BERGEN CO JDC",
        "district": "BERGEN CO JDC",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340079600669",
    },
    {
        "school": "ESSEX CO JDC",
        "district": "ESSEX CO JDC",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340079700675",
    },
    {
        "school": "OCEAN CO JDC",
        "district": "OCEAN CO JDC",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340079800686",
    },
    {
        "school": "MIDDLESEX CO JDC",
        "district": "MIDDLESEX CO JDC",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340079900681",
    },
    {
        "school": "BURLINGTON CO JDC",
        "district": "BURLINGTON CO JDC",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340080000671",
    },
    {
        "school": "CAMDEN CO JDC",
        "district": "CAMDEN CO JDC",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340080200672",
    },
    {
        "school": "ATLANTIC CO JDC",
        "district": "ATLANTIC CO JDC",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340080300667",
    },
    {
        "school": "MORRIS CO JDC",
        "district": "MORRIS CO JDC",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340080400685",
    },
    {
        "school": "Bayonne Alternative High School",
        "district": "Bayonne School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340126003447",
    },
    {
        "school": "Pride Academy",
        "district": "CAMDEN CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "340264003441",
    },
    {
        "school": "Clifton Early Learner Academies",
        "district": "Clifton Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340330003436",
    },
    {
        "school": "Claremont Elementary School",
        "district": "Franklin Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340549003448",
    },
    {
        "school": "Garfield Public Preschool 3 at Headstart",
        "district": "Garfield Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576003431",
    },
    {
        "school": "Thomas Jefferson School #9",
        "district": "Garfield Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340576003443",
    },
    {
        "school": "Academy for Performing Arts",
        "district": "Morris County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341072003439",
    },
    {
        "school": "East Ward Elementary School",
        "district": "Newark Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341134003455",
    },
    {
        "school": "Passaic Academy for Science and Engineering",
        "district": "Passaic City School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254003433",
    },
    {
        "school": "Passaic Preparatory Academy",
        "district": "Passaic City School District",
        "level": "High",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254003453",
    },
    {
        "school": "South Mountain Annex",
        "district": "South Orange-Maplewood School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341533003437",
    },
    {
        "school": "Harrison Elementary School",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003435",
    },
    {
        "school": "Trenton Central High School-9th Grade Academy",
        "district": "TRENTON PUBLIC SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341629003449",
    },
    {
        "school": "Work Readiness Academy",
        "district": "Union County Educational Services Commission",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "341640003430",
    },
    {
        "school": "Sgt. Dominick Pilla Middle School",
        "district": "Vineland Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341680003445",
    },
    {
        "school": "J. C. Stuart Early Childhood Development Center",
        "district": "Willingboro Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341800003459",
    },
    {
        "school": "Levitt Intermediate School",
        "district": "Willingboro Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341800003463",
    },
    {
        "school": "Oak Tree Road Elementary School",
        "district": "Woodbridge Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341812003452",
    },
    {
        "school": "Future Foundations Academy (FFA)",
        "district": "Educational Services Commission of New Jersey",
        "level": "High",
        "type": "Special education school",
        "state": "NJ",
        "nces_id": "348018003450",
    },
    {
        "school": "COTTONWOOD CLASSICAL PREP",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001031",
    },
    {
        "school": "ACE LEADERSHIP HIGH SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001074",
    },
    {
        "school": "HEALTH LEADERSHIP HIGH SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001098",
    },
    {
        "school": "TECHNOLOGY LEADERSHIP HIGH SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001112",
    },
    {
        "school": "TRES VOLCANES COMMUNITY COLLABORATIVE SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001142",
    },
    {
        "school": "MISSION ACHIEVEMENT AND SUCCESS 2.0",
        "district": "MISSION ACHIEVEMENT AND SUCCESS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350014801146",
    },
    {
        "school": "SOLARE COLLEGIATE CHARTER SCHOOL",
        "district": "SOLARE COLLEGIATE CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018301143",
    },
    {
        "school": "HILLCREST PRESCHOOL",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030001148",
    },
    {
        "school": "EARLY COLLEGE HIGH SCHOOL",
        "district": "DEMING PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350069001144",
    },
    {
        "school": "UTE LAKE ONLINE LEARNING CENTER",
        "district": "LOGAN MUNICIPAL SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350159001147",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "MORIARTY-EDGEWOOD SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350189001145",
    },
    {
        "school": "SILVER SCHOLARS ACADEMY",
        "district": "SILVER CONSOLIDATED SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350243001141",
    },
    {
        "school": "SOUTH BRONX INTERNATIONAL MIDDLE SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606629",
    },
    {
        "school": "MS 594",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360008606642",
    },
    {
        "school": "PS 595",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009006630",
    },
    {
        "school": "SCHOOL OF CREATIVITY AND INNOVATION (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #15",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009206659",
    },
    {
        "school": "BROOKLYN GREEN SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #16",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009406662",
    },
    {
        "school": "PS 384",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010206660",
    },
    {
        "school": "LEGACY SCHOOL OF THE ARTS",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #19",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012006666",
    },
    {
        "school": "COLLEGE POINT COLLABORATIVE",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #25",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360012206665",
    },
    {
        "school": "MS 596",
        "district": "NYC SPECIAL SCHOOLS - DISTRICT 75",
        "level": "Elementary",
        "type": "Special education school",
        "state": "NY",
        "nces_id": "360013506649",
    },
    {
        "school": "ACADEMY CHARTER SCHOOL-UNIONDALE",
        "district": "ACADEMY CHARTER SCHOOL-UNIONDALE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360116906639",
    },
    {
        "school": "BUFFALO COLLEGIATE CHARTER SCHOOL",
        "district": "BUFFALO COLLEGIATE CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360117006640",
    },
    {
        "school": "ZETA CHARTER SCHOOL - INWOOD 1",
        "district": "ZETA CHARTER SCHOOL - INWOOD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360117106637",
    },
    {
        "school": "PERSISTENCE PREPARATORY ACADEMY CHARTER SCHOOL",
        "district": "PERSISTENCE PREPARATORY ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360117206648",
    },
    {
        "school": "REACH ACADEMY CHARTER SCHOOL",
        "district": "REACH ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360117306635",
    },
    {
        "school": "ONTECH CHARTER HIGH SCHOOL",
        "district": "ONTECH CHARTER HIGH SCHOOL",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360117406658",
    },
    {
        "school": "CYPRESS HILLS ASCEND CHARTER SCHOOL",
        "district": "CYPRESS HILLS ASCEND CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360117506654",
    },
    {
        "school": "KIPP FREEDOM CHARTER SCHOOL",
        "district": "KIPP FREEDOM CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360117606647",
    },
    {
        "school": "ZETA CHARTER SCHOOL - BRONX 1",
        "district": "ZETA CHARTER SCHOOL - BRONX 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360117706638",
    },
    {
        "school": "ELM COMMUNITY CHARTER SCHOOL",
        "district": "ELM COMMUNITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360117806656",
    },
    {
        "school": "LOIS AND RICHARD NICOTRA EARLY COLLEGE CHARTER SCHOOL",
        "district": "LOIS AND RICHARD NICOTRA EARLY COLLEGE CHARTER SCHOOL",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360117906664",
    },
    {
        "school": "BRONX CHARTER SCHOOL FOR EXCELLENCE 4",
        "district": "BRONX CHARTER SCHOOL FOR EXCELLENCE 4",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360118006636",
    },
    {
        "school": "SYRACUSE ACADEMY OF SCIENCE AND CITIZENSHIP CHARTER SCHOOL",
        "district": "SYRACUSE ACADEMY OF SCIENCE AND CITIZENSHIP CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360118106661",
    },
    {
        "school": "URBAN ASSEMBLY CHARTER SCHOOL FOR COMPUTER SCIENCE",
        "district": "URBAN ASSEMBLY CHARTER SCHOOL FOR COMPUTER SCIENCE",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360118206634",
    },
    {
        "school": "OUR WORLD NEIGHBORHOOD CHARTER SCHOOL 2",
        "district": "OUR WORLD NEIGHBORHOOD CHARTER SCHOOL 2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360118306663",
    },
    {
        "school": "EMBLAZE ACADEMY CHARTER SCHOOL",
        "district": "EMBLAZE ACADEMY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360118406641",
    },
    {
        "school": "KEY COLLEGIATE CHARTER SCHOOL",
        "district": "KEY COLLEGIATE CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360118506657",
    },
    {
        "school": "EDMUND W GORDON BROOKLYN LABORATORY CHARTER SCHOOL",
        "district": "EDMUND W GORDON BROOKLYN LABORATORY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360118606645",
    },
    {
        "school": "URBAN DOVE TEAM CHARTER SCHOOL II",
        "district": "URBAN DOVE TEAM CHARTER SCHOOL II",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360118706628",
    },
    {
        "school": "PATHWAYS ACADEMY",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360585006632",
    },
    {
        "school": "NORTH PARK COMMUNITY SCHOOL #50",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585006633",
    },
    {
        "school": "BUFFALO SCHOOL OF CULINARY ARTS AND HOSPITALITY MANAGEMENT",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585006643",
    },
    {
        "school": "MARTIN LUTHER KING JR #48",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585006646",
    },
    {
        "school": "BUILD COMMUNITY SCHOOL",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585006650",
    },
    {
        "school": "GOUVERNEUR MIDDLE SCHOOL",
        "district": "GOUVERNEUR CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361236006655",
    },
    {
        "school": "HALDANE MIDDLE SCHOOL",
        "district": "HALDANE CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361323006653",
    },
    {
        "school": "HOLLAND MIDDLE SCHOOL",
        "district": "HOLLAND CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361455006651",
    },
    {
        "school": "LIBERTY MIDDLE SCHOOL",
        "district": "LIBERTY CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361722006667",
    },
    {
        "school": "BAYVILLE INTERMEDIATE SCHOOL",
        "district": "LOCUST VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361770006644",
    },
    {
        "school": "LOCUST VALLEY INTERMEDIATE SCHOOL",
        "district": "LOCUST VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361770006652",
    },
    {
        "school": "MOUNT VERNON STEAM ACADEMY",
        "district": "MOUNT VERNON SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362010006668",
    },
    {
        "school": "RISE COMMUNITY SCHOOL",
        "district": "ROCHESTER CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362475006631",
    },
    {
        "school": "Niner University Elementary",
        "district": "Niner University Elementary School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370044303493",
    },
    {
        "school": "B.L.U.E.-G.R.E.E.N. Academy",
        "district": "B.L.U.E.-G.R.E.E.N. Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370044403502",
    },
    {
        "school": "Hobgood Charter School",
        "district": "Hobgood Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370044503506",
    },
    {
        "school": "Southwest Charlotte STEM Academy",
        "district": "Southwest Charlotte STEM Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370044603504",
    },
    {
        "school": "Tillery Charter Academy",
        "district": "Tillery Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370044703509",
    },
    {
        "school": "Pocosin Innovative Charter",
        "district": "Pocosin Innovative Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370044803510",
    },
    {
        "school": "Bonnie Cone Classical Academy",
        "district": "Bonnie Cone Classical Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370044903503",
    },
    {
        "school": "Ridgeview Charter School",
        "district": "Ridgeview Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045103507",
    },
    {
        "school": "TeamCFA - Community Public Charter",
        "district": "TeamCFA - Community Public Charter",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045203499",
    },
    {
        "school": "West Lake Preparatory Academy",
        "district": "West Lake Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045303508",
    },
    {
        "school": "Steele Creek Preparatory Academy",
        "district": "Steele Creek Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045403501",
    },
    {
        "school": "Discovery Program at The Springs",
        "district": "Iredell-Statesville Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "NC",
        "nces_id": "370231003498",
    },
    {
        "school": "Jones Senior High School",
        "district": "Jones County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370240003496",
    },
    {
        "school": "WB Wicker Elementary",
        "district": "Lee County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370256003492",
    },
    {
        "school": "Madison County Alternative High",
        "district": "Madison County Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370282003500",
    },
    {
        "school": "McDeeds Creek Elementary",
        "district": "Moore County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370309003505",
    },
    {
        "school": "Southeast Raleigh Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003490",
    },
    {
        "school": "Alston Ridge Middle",
        "district": "Wake County Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003491",
    },
    {
        "school": "Parkside Elementary",
        "district": "Wake County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003494",
    },
    {
        "school": "Green Level High",
        "district": "Wake County Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003495",
    },
    {
        "school": "Blue Ridge Elementary",
        "district": "Yancey County Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370507003497",
    },
    {
        "school": "FORT YATES PK SCHOOL",
        "district": "FT YATES 4",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380720000898",
    },
    {
        "school": "DEER CREEK ELEMENTARY SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000897",
    },
    {
        "school": "HERITAGE MIDDLE SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Middle",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000899",
    },
    {
        "school": "Inspire Charter School - Elementary",
        "district": "Inspire Charter School - Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390159805979",
    },
    {
        "school": "Great River Connections Academy",
        "district": "Great River Connections Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390159905986",
    },
    {
        "school": "SMART Academy",
        "district": "SMART Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390160005964",
    },
    {
        "school": "Academy of Junior Scholars",
        "district": "Academy of Junior Scholars",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390160105988",
    },
    {
        "school": "AchievePoint Career Academy - Cincinnati",
        "district": "AchievePoint Career Academy - Cincinnati",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390160205984",
    },
    {
        "school": "Lorain Bilingual Preparatory Academy",
        "district": "Lorain Bilingual Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390160305971",
    },
    {
        "school": "Montgomery Preparatory Academy",
        "district": "Montgomery Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390160405980",
    },
    {
        "school": "Mount Auburn Preparatory Academy",
        "district": "Mount Auburn Preparatory Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390160505969",
    },
    {
        "school": "Horizon Science Academy Primary",
        "district": "Horizon Science Academy Primary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390160605963",
    },
    {
        "school": "I Promise School",
        "district": "Akron City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390434805982",
    },
    {
        "school": "AIM Academy at Fairmount",
        "district": "Canton City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437105973",
    },
    {
        "school": "Mt. Logan Early Childhood Center",
        "district": "Chillicothe City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437405981",
    },
    {
        "school": "James N. Gamble Montessori Elementary School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505962",
    },
    {
        "school": "Rising Stars at Aiken New Tech/College Hill",
        "district": "Cincinnati Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437505976",
    },
    {
        "school": "William Rainey Harper",
        "district": "Cleveland Municipal",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437805972",
    },
    {
        "school": "Columbus Africentric Early College Middle School",
        "district": "Columbus City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390438005985",
    },
    {
        "school": "Little Learners Preschool",
        "district": "Newark City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444505987",
    },
    {
        "school": "Newark Digital Academy",
        "district": "Newark City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390444505989",
    },
    {
        "school": "Heartland Early Learning Program",
        "district": "Orrville City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446105975",
    },
    {
        "school": "Princeton Innovation Center",
        "district": "Princeton City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390446705967",
    },
    {
        "school": "East Franklin Elementary School",
        "district": "South-Western City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448005965",
    },
    {
        "school": "Burbank Early Childhood School",
        "district": "Upper Arlington City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449305970",
    },
    {
        "school": "Ayersville Middle School",
        "district": "Ayersville Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467005978",
    },
    {
        "school": "Olentangy Berlin High School",
        "district": "Olentangy Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605968",
    },
    {
        "school": "Chardon Preschool",
        "district": "Chardon Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390471805974",
    },
    {
        "school": "Butler Tech LeSourdsville Location",
        "district": "Butler Technology & Career Development Schools",
        "level": "High",
        "type": "Career and Technical School",
        "state": "OH",
        "nces_id": "390508805983",
    },
    {
        "school": "KIPP TULSA UNIVERSITY PREP",
        "district": "KIPP (CHARTER)",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400078002874",
    },
    {
        "school": "LE MONDE INTERNATIONAL SCHL",
        "district": "LE MONDE INTERNATIONAL SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080102877",
    },
    {
        "school": "NORTH ROCK CREEK HS",
        "district": "NORTH ROCK CREEK",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080202875",
    },
    {
        "school": "NORTH ROCK CREEK ES",
        "district": "NORTH ROCK CREEK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080202876",
    },
    {
        "school": "NORTH ROCK CREEK MS",
        "district": "NORTH ROCK CREEK",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080202878",
    },
    {
        "school": "ACADEMY OF SEMINOLE CHARTER HS",
        "district": "ACADEMY OF SEMINOLE CHARTER",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080302873",
    },
    {
        "school": "CHARTER OAK ES",
        "district": "GUTHRIE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401356002879",
    },
    {
        "school": "RIVERWOOD ES",
        "district": "MUSTANG",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100002871",
    },
    {
        "school": "MEADOW BROOK INTERMEDIATE ES",
        "district": "MUSTANG",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100002880",
    },
    {
        "school": "GREENWOOD LEADERSHIP ACADEMY",
        "district": "TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403024002870",
    },
    {
        "school": "Skyline High School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001866",
    },
    {
        "school": "Realms High School",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001871",
    },
    {
        "school": "Oregon Family School",
        "district": "Harney County SD 4",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410360001870",
    },
    {
        "school": "Harmony Academy",
        "district": "Lake Oswego SD 7J",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410723001873",
    },
    {
        "school": "TEACH-NW",
        "district": "Marcola SD 79J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410774001872",
    },
    {
        "school": "Gib Olinger Elementary School",
        "district": "Milton-Freewater Unified SD 7",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410816001861",
    },
    {
        "school": "Destinations Career Academy of Oregon",
        "district": "Mitchell SD 55",
        "level": "High",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410828001864",
    },
    {
        "school": "Cascade Virtual Academy",
        "district": "Mitchell SD 55",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410828001869",
    },
    {
        "school": "Morrow Education Center",
        "district": "Morrow SD 1",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "OR",
        "nces_id": "410852001865",
    },
    {
        "school": "Rose City Park",
        "district": "Portland SD 1J",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411004001868",
    },
    {
        "school": "South Valley Academy",
        "district": "Rogue River SD 35",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411068001863",
    },
    {
        "school": "Deep Roots Charter School",
        "district": "Deep Roots Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420089907663",
    },
    {
        "school": "Mastery Prep Elementary CS",
        "district": "Mastery Prep Elementary CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420090007662",
    },
    {
        "school": "KIPP North Philadelphia CS",
        "district": "KIPP North Philadelphia CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420090107660",
    },
    {
        "school": "Five Points El Sch",
        "district": "Bangor Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420300007654",
    },
    {
        "school": "DeFranco El Sch",
        "district": "Bangor Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420300007655",
    },
    {
        "school": "Benton Area MS",
        "district": "Benton Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420339007644",
    },
    {
        "school": "Benton Area HS",
        "district": "Benton Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420339007646",
    },
    {
        "school": "Crestwood Secondary Campus",
        "district": "Crestwood SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420546007651",
    },
    {
        "school": "Holland MS",
        "district": "Council Rock SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696007656",
    },
    {
        "school": "Winding Creek El Sch",
        "district": "Cumberland Valley SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420711007645",
    },
    {
        "school": "Greenville El Sch",
        "district": "Greenville Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421116007640",
    },
    {
        "school": "East Juniata El Sch",
        "district": "Juniata County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421260007664",
    },
    {
        "school": "Juniata El Sch",
        "district": "Juniata County SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421260007665",
    },
    {
        "school": "Laurel MS",
        "district": "Laurel SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421338007639",
    },
    {
        "school": "Lehighton Area El Sch",
        "district": "Lehighton Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421350007657",
    },
    {
        "school": "Kennedy Early Childhood Center",
        "district": "Greater Nanticoke Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421629007648",
    },
    {
        "school": "Greater Nanticoke Area Ed Ctr",
        "district": "Greater Nanticoke Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421629007649",
    },
    {
        "school": "Northern Bedford County MS",
        "district": "Northern Bedford County SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421758007642",
    },
    {
        "school": "Northern Bedford County HS",
        "district": "Northern Bedford County SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421758007643",
    },
    {
        "school": "Village Park Academy",
        "district": "Pennsbury SD",
        "level": "Other",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421884007658",
    },
    {
        "school": "Vaux HS: A Big Picture School",
        "district": "Philadelphia City SD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421899007661",
    },
    {
        "school": "Punxsutawney Area El Sch",
        "district": "Punxsutawney Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421980007641",
    },
    {
        "school": "Tunkhannock STEM Academy",
        "district": "Tunkhannock Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422385007647",
    },
    {
        "school": "Tunkhannock Area Intermediate Sch",
        "district": "Tunkhannock Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422385007652",
    },
    {
        "school": "Tunkhannock Area Primary Cntr",
        "district": "Tunkhannock Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422385007653",
    },
    {
        "school": "Gulph EL Sch",
        "district": "Upper Merion Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422448007659",
    },
    {
        "school": "West Greene JSHS",
        "district": "West Greene SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422544007638",
    },
    {
        "school": "Wilkes-Barre Area SD STEM Academy",
        "district": "Wilkes-Barre Area SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422630007650",
    },
    {
        "school": "Highlander Secondary Charter S",
        "district": "Highlander",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003100521",
    },
    {
        "school": "Highlander Elementary Charter",
        "district": "Highlander",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003100524",
    },
    {
        "school": "Paul Cuffee Lower School",
        "district": "Paul Cuffee Charter Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003200520",
    },
    {
        "school": "Paul Cuffee Middle School",
        "district": "Paul Cuffee Charter Sch",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003200525",
    },
    {
        "school": "Paul Cuffee Upper School",
        "district": "Paul Cuffee Charter Sch",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003200526",
    },
    {
        "school": "Charette Charter School",
        "district": "Charette Charter",
        "level": "Secondary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440003700519",
    },
    {
        "school": "Edward R. Martin Middle Annex",
        "district": "East Providence",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000506",
    },
    {
        "school": "A. L. Corbett Middle",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001702",
    },
    {
        "school": "Aiken Scholars Academy",
        "district": "Aiken 01",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001708",
    },
    {
        "school": "Ridge Spring Monetta Middle",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001713",
    },
    {
        "school": "Foxbank Elementary",
        "district": "Berkeley 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450117001707",
    },
    {
        "school": "J. Paul Truluck Creative Arts and Science Magnet",
        "district": "Florence 03",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450219001709",
    },
    {
        "school": "Lancaster County School District Career Center",
        "district": "Lancaster 01",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450258001704",
    },
    {
        "school": "Van Wyck Elementary",
        "district": "Lancaster 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450258001712",
    },
    {
        "school": "Lexington Two Innovation Center",
        "district": "Lexington 02",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450273001705",
    },
    {
        "school": "Riverbank Elementary",
        "district": "Lexington 02",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450273001711",
    },
    {
        "school": "Drayton Mills Elementary",
        "district": "Spartanburg 07",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450366001710",
    },
    {
        "school": "Cherry Park Elementary School of Language Immersion",
        "district": "York 03",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450387001714",
    },
    {
        "school": "Catawba Ridge High School",
        "district": "York 04",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001718",
    },
    {
        "school": "Midlands Arts Conservatory",
        "district": "SC Public Charter School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101703",
    },
    {
        "school": "Charleston Acceleration Academy",
        "district": "SC Public Charter School District",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101706",
    },
    {
        "school": "Calhoun Falls Charter School",
        "district": "Charter Institute at Erskine",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901510",
    },
    {
        "school": "South Carolina Virtual Charter School",
        "district": "Charter Institute at Erskine",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901513",
    },
    {
        "school": "Odyssey Online Learning",
        "district": "Charter Institute at Erskine",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901527",
    },
    {
        "school": "Royal Live Oaks Academy of the Arts and Sciences",
        "district": "Charter Institute at Erskine",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901590",
    },
    {
        "school": "Coastal Leadership Academy",
        "district": "Charter Institute at Erskine",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901615",
    },
    {
        "school": "Cyber Academy of South Carolina",
        "district": "Charter Institute at Erskine",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901616",
    },
    {
        "school": "Midlands STEM Institute",
        "district": "Charter Institute at Erskine",
        "level": "Other",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901642",
    },
    {
        "school": "Gray Collegiate Academy",
        "district": "Charter Institute at Erskine",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901650",
    },
    {
        "school": "Oceanside Collegiate Academy",
        "district": "Charter Institute at Erskine",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901663",
    },
    {
        "school": "Mevers School of Excellence",
        "district": "Charter Institute at Erskine",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901686",
    },
    {
        "school": "Legion Collegiate Academy",
        "district": "Charter Institute at Erskine",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901715",
    },
    {
        "school": "Thornwell Charter School",
        "district": "Charter Institute at Erskine",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901716",
    },
    {
        "school": "Clear Dot Charter School",
        "district": "Charter Institute at Erskine",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901717",
    },
    {
        "school": "Summit Classical School",
        "district": "Charter Institute at Erskine",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390901719",
    },
    {
        "school": "Teachwell Virtual Academy - 92",
        "district": "East Dakota Educational Cooperative",
        "level": "High",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460002701398",
    },
    {
        "school": "Project Search - Avera McKennan 07",
        "district": "East Dakota Educational Cooperative",
        "level": "High",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "460002701399",
    },
    {
        "school": "Tea Area Venture Elementary - 06",
        "district": "Tea Area School District 41-5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "460005201400",
    },
    {
        "school": "Leola Alternative School - 07",
        "district": "Leola School District 44-2",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "464164001397",
    },
    {
        "school": "Odyssey - 47",
        "district": "Sioux Falls School District 49-5",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "466627001396",
    },
    {
        "school": "Tennessee School for the Deaf Nashville",
        "district": "Tennessee School for the Deaf",
        "level": "Elementary",
        "type": "Special education school",
        "state": "TN",
        "nces_id": "470014602564",
    },
    {
        "school": "Believe Memphis Academy Charter School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802489",
    },
    {
        "school": "Geeter School",
        "district": "Shelby County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802499",
    },
    {
        "school": "Memphis Business Academy Hickory Hill Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802531",
    },
    {
        "school": "Memphis Business Academy Hickory Hill Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802539",
    },
    {
        "school": "Perea Elementary School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802544",
    },
    {
        "school": "Crosstown High School",
        "district": "Shelby County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802548",
    },
    {
        "school": "Freedom Preparatory Academy Charter Schools",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802565",
    },
    {
        "school": "Schilling Farms Elementary School",
        "district": "Collierville",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014902515",
    },
    {
        "school": "KIPP Antioch College Prep Elementary",
        "district": "Tennessee State Board of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015502501",
    },
    {
        "school": "Samuel Everett School of Innovation",
        "district": "Blount County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030002557",
    },
    {
        "school": "Eagleton 1 Head Start",
        "district": "Blount County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470030002560",
    },
    {
        "school": "Chattanooga Preparatory School",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159002510",
    },
    {
        "school": "Hardin Valley Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222002512",
    },
    {
        "school": "Montgomery Village Child Development Center Inc.",
        "district": "Knox County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222002516",
    },
    {
        "school": "Gibbs Middle School",
        "district": "Knox County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470222002568",
    },
    {
        "school": "McNairy County Adult Learning Center",
        "district": "McNairy County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470288002570",
    },
    {
        "school": "Eagle View Elementary School",
        "district": "Davidson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002494",
    },
    {
        "school": "Casa Azafran Early Learning Center",
        "district": "Davidson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002498",
    },
    {
        "school": "Martha O' Bryan Center",
        "district": "Davidson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002521",
    },
    {
        "school": "Cambridge Early Learning Center",
        "district": "Davidson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002558",
    },
    {
        "school": "Susan Gray School",
        "district": "Davidson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470318002575",
    },
    {
        "school": "Robertson County Alternative Learning Center",
        "district": "Robertson County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360002490",
    },
    {
        "school": "Robertson County Adult High School",
        "district": "Robertson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360002496",
    },
    {
        "school": "Tennessee Virtual High School",
        "district": "Union County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470429002537",
    },
    {
        "school": "Thompson's Station Middle School",
        "district": "Williamson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002525",
    },
    {
        "school": "Jordan Elementary School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002573",
    },
    {
        "school": "Thompson's Station Elementary School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002579",
    },
    {
        "school": "UPLIFT ASCEND",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013809",
    },
    {
        "school": "LIFE SCHOOL CARROLLTON",
        "district": "LIFE SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480005513849",
    },
    {
        "school": "SJRC TEXAS",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007113821",
    },
    {
        "school": "THE REFUGE",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480007113838",
    },
    {
        "school": "HERITAGE ACADEMY OF DEL RIO MIDDLE",
        "district": "HERITAGE ACADEMY",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480008013778",
    },
    {
        "school": "TRINITY BASIN PREPARATORY",
        "district": "TRINITY BASIN PREPARATORY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480009213836",
    },
    {
        "school": "TRIUMPH PUBLIC HIGH SCHOOLS-BROWNSVILLE",
        "district": "TRIUMPH PUBLIC HIGH SCHOOLS-RIO GRANDE VALLEY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480013313801",
    },
    {
        "school": "FOUNDERS CLASSICAL ACADEMY - FRISCO",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Other",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313683",
    },
    {
        "school": "CLASSICAL ACADEMY - PERMIAN BASIN",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313855",
    },
    {
        "school": "PREMIER H S - SAN ANGELO",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480020713758",
    },
    {
        "school": "YES PREP - NORTHWEST",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020913812",
    },
    {
        "school": "IDEA ELSA COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113686",
    },
    {
        "school": "IDEA KYLE ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113700",
    },
    {
        "school": "IDEA EDGEMERE COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113702",
    },
    {
        "school": "IDEA OWASSA ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113712",
    },
    {
        "school": "IDEA RIO VISTA ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113729",
    },
    {
        "school": "IDEA ELSA ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113731",
    },
    {
        "school": "IDEA PFLUGERVILLE ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113739",
    },
    {
        "school": "IDEA OWASSA COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113744",
    },
    {
        "school": "IDEA PFLUGERVILLE COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113782",
    },
    {
        "school": "IDEA INGRAM HILLS COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113795",
    },
    {
        "school": "IDEA KYLE COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113815",
    },
    {
        "school": "IDEA INGRAM HILLS ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113824",
    },
    {
        "school": "IDEA EDGEMERE ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113839",
    },
    {
        "school": "IDEA RIO VISTA COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113847",
    },
    {
        "school": "TRINITY CHARTER SCHOOL - SPRING CAMPUS",
        "district": "TRINITY CHARTER SCHOOL",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480025913746",
    },
    {
        "school": "TRINITY CHARTER SCHOOL - BRENHAM CAMPUS",
        "district": "TRINITY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480025913767",
    },
    {
        "school": "FORTIS ACADEMY",
        "district": "HARRIS COUNTY DEPT OF ED",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480026113770",
    },
    {
        "school": "KIPP ACADEMY MIDDLE",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026407911",
    },
    {
        "school": "KIPP ASPIRE ACADEMY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026410422",
    },
    {
        "school": "KIPP TRUTH ACADEMY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026410552",
    },
    {
        "school": "KIPP 3D ACADEMY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026411229",
    },
    {
        "school": "KIPP PEACE EL",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026411246",
    },
    {
        "school": "KIPP ZENITH ACADEMY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026411247",
    },
    {
        "school": "KIPP SHARP PREP",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026411387",
    },
    {
        "school": "KIPP DREAM PREP",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026411408",
    },
    {
        "school": "KIPP SHINE PREP",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026411451",
    },
    {
        "school": "KIPP SPIRIT COLLEGE PREP",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026411457",
    },
    {
        "school": "KIPP LIBERATION COLLEGE PREPARATORY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026411548",
    },
    {
        "school": "KIPP EXPLORE ACADEMY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412057",
    },
    {
        "school": "KIPP HOUSTON H S",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412145",
    },
    {
        "school": "KIPP SHARPSTOWN COLEGE PREP",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412152",
    },
    {
        "school": "KIPP POLARIS ACADEMY FOR BOYS",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412173",
    },
    {
        "school": "KIPP UNIVERSITY PREP H S",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412354",
    },
    {
        "school": "KIPP INTREPID PREPARATORY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412444",
    },
    {
        "school": "KIPP VOYAGE ACADEMY FOR GIRLS",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412486",
    },
    {
        "school": "KIPP SUNNYSIDE H S",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412504",
    },
    {
        "school": "KIPP LEGACY PREPARATORY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412516",
    },
    {
        "school": "KIPP CAMINO ACADEMY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412635",
    },
    {
        "school": "KIPP GENERATIONS COLLEGIATE",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412773",
    },
    {
        "school": "KIPP CONNECT HOUSTON PRI",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412789",
    },
    {
        "school": "KIPP CONNECT MIDDLE",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412813",
    },
    {
        "school": "KIPP UN MUNDO PRI",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412834",
    },
    {
        "school": "KIPP NORTHEAST COLLEGE PREPARATORY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412977",
    },
    {
        "school": "KIPP DESTINY EL",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026412999",
    },
    {
        "school": "KIPP ESPERANZA PRI",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413170",
    },
    {
        "school": "KIPP PODER ACADEMY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413246",
    },
    {
        "school": "KIPP ACADEMY WEST MIDDLE",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413276",
    },
    {
        "school": "KIPP CLIMB ACADEMY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413278",
    },
    {
        "school": "KIPP UNITY PRI",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413280",
    },
    {
        "school": "KIPP PRIME COLLEGE PREPARATORY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413291",
    },
    {
        "school": "KIPP TRUTH EL",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413357",
    },
    {
        "school": "KIPP DESTINY MIDDLE",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413531",
    },
    {
        "school": "KIPP PLEASANT GROVE PRI",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413535",
    },
    {
        "school": "KIPP NEXUS PRI",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413594",
    },
    {
        "school": "KIPP NEXUS MIDDLE",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413628",
    },
    {
        "school": "KIPP PLEASANT GROVE MIDDLE",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413674",
    },
    {
        "school": "KIPP OAK CLIFF ACADEMY",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413754",
    },
    {
        "school": "KIPP CONNECT H S",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413807",
    },
    {
        "school": "HARMONY SCIENCE ACADEMY - CYPRESS",
        "district": "HARMONY SCHOOL OF EXCELLENCE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027413842",
    },
    {
        "school": "HARMONY SCHOOL OF INNOVATION - GRAND PRAIRIE",
        "district": "HARMONY SCIENCE ACAD (WACO)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480029213701",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY SUGARLAND",
        "district": "SCHOOL OF SCIENCE AND TECHNOLOGY DISCOVERY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140013693",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY NORTHWEST",
        "district": "SCHOOL OF SCIENCE AND TECHNOLOGY DISCOVERY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140013844",
    },
    {
        "school": "STEPPING STONES ACADEMY",
        "district": "MEADOWLAND CHARTER DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480140413750",
    },
    {
        "school": "BOB HOPE SCHOOL BEAUMONT",
        "district": "BOB HOPE SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141013818",
    },
    {
        "school": "PROMESA COLLEGE PREP BROWNSVILLE",
        "district": "PROMESA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141413823",
    },
    {
        "school": "PROMESA COLLEGE PREP WEST CORPUS CHRISTI",
        "district": "PROMESA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480141413853",
    },
    {
        "school": "AUSTIN ACHIEVE EL",
        "district": "AUSTIN ACHIEVE PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143113800",
    },
    {
        "school": "ILTEXAS LANCASTER DESOTO H S",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013759",
    },
    {
        "school": "ILTEXAS COLLEGE STATION EL",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013784",
    },
    {
        "school": "ILTEXAS HOUSTON WINDMILL LAKES OREM H S",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013813",
    },
    {
        "school": "ILTEXAS COLLEGE STATION MIDDLE",
        "district": "INTERNATIONAL LEADERSHIP OF TEXAS (ILTEXAS)",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144013819",
    },
    {
        "school": "GREAT HEARTS WESTERN HILLS",
        "district": "GREAT HEARTS TEXAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144113833",
    },
    {
        "school": "THE EXCEL CENTER FOR ADULTS - LOCKHART",
        "district": "THE EXCEL CENTER (FOR ADULTS)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480144813780",
    },
    {
        "school": "THE EXCEL CENTER FOR ADULTS - SOUTH AUSTIN",
        "district": "THE EXCEL CENTER (FOR ADULTS)",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144813834",
    },
    {
        "school": "HIGH POINT ACADEMY FW EL",
        "district": "HIGH POINT ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145013768",
    },
    {
        "school": "HIGH POINT ACADEMY SFW",
        "district": "HIGH POINT ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145013781",
    },
    {
        "school": "PIONEER TECHNOLOGY (PTAA) FATE",
        "district": "PIONEER TECHNOLOGY & ARTS ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145113828",
    },
    {
        "school": "LAKE GRANBURY ACADEMY",
        "district": "LAKE GRANBURY ACADEMY CHARTER SCHOOL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480146413723",
    },
    {
        "school": "REVE PREPARATORY CHARTER SCHOOL",
        "district": "REVE PREPARATORY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480146513797",
    },
    {
        "school": "BLOOM ACADEMY CHARTER SCHOOL",
        "district": "BLOOM ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480146613748",
    },
    {
        "school": "PROMESA ACADEMY CHARTER SCHOOL",
        "district": "PROMESA ACADEMY CHARTER SCHOOL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480146713752",
    },
    {
        "school": "EL FOR EDUCATION INNOVATION",
        "district": "BETTY M CONDRA SCHOOL FOR EDUCATION INNOVATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480146813679",
    },
    {
        "school": "RIVER BEND EL",
        "district": "COLLEGE STATION ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480735013808",
    },
    {
        "school": "HILL EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013675",
    },
    {
        "school": "STEHLIK EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013680",
    },
    {
        "school": "ECKERT EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013688",
    },
    {
        "school": "OGDEN EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013692",
    },
    {
        "school": "AVALOS P-TECH SCHOOL",
        "district": "ALDINE ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013696",
    },
    {
        "school": "MEAD MIDDLE",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013705",
    },
    {
        "school": "JONES MIDDLE",
        "district": "ALDINE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013718",
    },
    {
        "school": "BLANSON CTE H S",
        "district": "ALDINE ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013733",
    },
    {
        "school": "STOVALL EC/PK/K",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013760",
    },
    {
        "school": "PARKER EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013761",
    },
    {
        "school": "REED ACADEMY",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013764",
    },
    {
        "school": "ESCAMILLA EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013771",
    },
    {
        "school": "VARDEMAN EC/PK/K",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013775",
    },
    {
        "school": "MARCELLA EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013776",
    },
    {
        "school": "MAGRILL EC/PK/K",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013786",
    },
    {
        "school": "CARAWAY EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013787",
    },
    {
        "school": "WILSON EL",
        "district": "ALDINE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480771013799",
    },
    {
        "school": "NEW H S",
        "district": "ALVIN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809013725",
    },
    {
        "school": "NEW J H",
        "district": "ALVIN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809013790",
    },
    {
        "school": "BEL NAFEGAR SANCHEZ EL",
        "district": "ALVIN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809013837",
    },
    {
        "school": "ANNA EDUCATION CENTER",
        "district": "ANNA ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480834013704",
    },
    {
        "school": "ARGYLE WEST",
        "district": "ARGYLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480867013742",
    },
    {
        "school": "ARLINGTON COLLEGE AND CAREER H S",
        "district": "ARLINGTON ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870013677",
    },
    {
        "school": "WIMBISH WORLD LANGUAGE ACADEMY",
        "district": "ARLINGTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480870013852",
    },
    {
        "school": "MAINSPRING SCHOOLS",
        "district": "AUSTIN ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480894013846",
    },
    {
        "school": "BEAUMONT NEW EL DAEP",
        "district": "BEAUMONT ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480967013717",
    },
    {
        "school": "BEAUMONT UNITED H S",
        "district": "BEAUMONT ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480967013745",
    },
    {
        "school": "A C JONES HEALTH PROFESSIONS MAGNET ACADEMY",
        "district": "BEEVILLE ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480972013804",
    },
    {
        "school": "CHARTER OAK EL",
        "district": "BELTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986013678",
    },
    {
        "school": "NEW EL",
        "district": "BIRDVILLE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481023013690",
    },
    {
        "school": "HERFF EL",
        "district": "BOERNE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071013685",
    },
    {
        "school": "VOSS MIDDLE",
        "district": "BOERNE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481071013741",
    },
    {
        "school": "BROCK EL",
        "district": "BROCK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481146013695",
    },
    {
        "school": "GENESIS CAMPUS",
        "district": "BROOKESMITH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481155013724",
    },
    {
        "school": "REALM",
        "district": "BURLESON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481218013766",
    },
    {
        "school": "CAMPBELL EL",
        "district": "CLEAR CREEK ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481428013728",
    },
    {
        "school": "JJAEP",
        "district": "COMAL ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481473013793",
    },
    {
        "school": "MONTESSORI ACADEMY AT ONESIMO HERNANDEZ EL",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013714",
    },
    {
        "school": "SUDIE L WILLIAMS TALENTED AND GIFTED ACADEMY",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013736",
    },
    {
        "school": "IGNITE MIDDLE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013825",
    },
    {
        "school": "SOLAR PREP FOR BOYS AT JOHN F KENNEDY",
        "district": "DALLAS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013841",
    },
    {
        "school": "SCHOOL FOR THE TALENTED & GIFTED IN PLEASANT GROVE",
        "district": "DALLAS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013856",
    },
    {
        "school": "DECATUR INT",
        "district": "DECATUR ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481650013765",
    },
    {
        "school": "UNION PARK EL",
        "district": "DENTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481674013730",
    },
    {
        "school": "MARINE CREEK MIDDLE",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770013789",
    },
    {
        "school": "OAK CREST EL",
        "district": "EAST CENTRAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785013840",
    },
    {
        "school": "EAST CHAMBERS PRI",
        "district": "EAST CHAMBERS ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481788013732",
    },
    {
        "school": "STEAM AT THE FINE ARTS ACADEMY",
        "district": "EDGEWOOD ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815013735",
    },
    {
        "school": "FORT BEND ISD EARLY LITERACY CENTER",
        "district": "FORT BEND ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965013681",
    },
    {
        "school": "OVERTON PARK EL",
        "district": "FORT WORTH ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481970013769",
    },
    {
        "school": "CAREER & TECHNOLOGY EDUCATION CENTER",
        "district": "FRISCO ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013749",
    },
    {
        "school": "GALENA PARK ISD CAREER & TECHNICAL ECHS",
        "district": "GALENA PARK ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482025013711",
    },
    {
        "school": "ATASCOSA COUNTY JJAEP",
        "district": "GEORGE WEST ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482055013747",
    },
    {
        "school": "GODLEY LINKS ACADEMY",
        "district": "GODLEY ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482096013734",
    },
    {
        "school": "NIXON-SMILEY PACE",
        "district": "GONZALES ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482106013830",
    },
    {
        "school": "NIXON-SMILEY DAEP",
        "district": "GONZALES ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482106013850",
    },
    {
        "school": "WALLACE ACCELERATED H S",
        "district": "HERMLEIGH ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482304013722",
    },
    {
        "school": "BENJAMIN DOC KERLEY EL",
        "district": "HUTTO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482410013699",
    },
    {
        "school": "NEW JR #17",
        "district": "KATY ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517013706",
    },
    {
        "school": "LEONARD EL",
        "district": "KATY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517013805",
    },
    {
        "school": "NEW EL #43",
        "district": "KATY ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482517013832",
    },
    {
        "school": "J R PHILLIPS EL",
        "district": "KAUFMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482520013698",
    },
    {
        "school": "LUCILLE NASH EL",
        "district": "KAUFMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482520013727",
    },
    {
        "school": "J W MONDAY EL",
        "district": "KAUFMAN ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482520013740",
    },
    {
        "school": "EL143",
        "district": "KILLEEN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566013676",
    },
    {
        "school": "HS015",
        "district": "KILLEEN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566013777",
    },
    {
        "school": "EL142",
        "district": "KILLEEN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566013783",
    },
    {
        "school": "EL144",
        "district": "KILLEEN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566013848",
    },
    {
        "school": "NEW EL",
        "district": "KLEIN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482574013709",
    },
    {
        "school": "JJAEP",
        "district": "LACKLAND ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482637013715",
    },
    {
        "school": "BEE CAVE MIDDLE",
        "district": "LAKE TRAVIS ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482647013703",
    },
    {
        "school": "NEW EL",
        "district": "LAKE TRAVIS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482647013803",
    },
    {
        "school": "THOMAS R CULVER EL",
        "district": "LAMAR CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658013802",
    },
    {
        "school": "TAMARRON EL",
        "district": "LAMAR CISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658013858",
    },
    {
        "school": "LEANDER EXTENDED OPPORTUNITY",
        "district": "LEANDER ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482703013720",
    },
    {
        "school": "NEW EL 131",
        "district": "LEANDER ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703013751",
    },
    {
        "school": "NEW EL 128",
        "district": "LEANDER ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703013785",
    },
    {
        "school": "STACY KAYE DANIELSON MIDDLE",
        "district": "LEANDER ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703013816",
    },
    {
        "school": "LARKSPUR EL",
        "district": "LEANDER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482703013829",
    },
    {
        "school": "MILL STREET EL",
        "district": "LEWISVILLE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482730013721",
    },
    {
        "school": "JERRY R WALKER MIDDLE",
        "district": "LITTLE ELM ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482772013831",
    },
    {
        "school": "LOWELL H STRIKE MIDDLE",
        "district": "LITTLE ELM ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482772013843",
    },
    {
        "school": "LEON VALLEY",
        "district": "LOMETA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482796013689",
    },
    {
        "school": "MERCEDES EARLY LITERACY PROGRAM",
        "district": "MERCEDES ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483025013762",
    },
    {
        "school": "NEW CHOICE H S",
        "district": "MESQUITE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039013814",
    },
    {
        "school": "DR DON WOOLLEY MIDDLE",
        "district": "MESQUITE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483039013835",
    },
    {
        "school": "EARL & MARTHALU DIETERICH MIDDLE",
        "district": "MIDLOTHIAN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483060013755",
    },
    {
        "school": "NEW H S",
        "district": "NEW CANEY ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483240013810",
    },
    {
        "school": "KALLISON RANCH AREA MIDDLE",
        "district": "NORTHSIDE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312013774",
    },
    {
        "school": "WERNLI EL",
        "district": "NORTHSIDE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312013791",
    },
    {
        "school": "LANCE THOMPSON EL",
        "district": "NORTHWEST ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483318013716",
    },
    {
        "school": "ADULT TRANSITION CENTER",
        "district": "PLANO ISD",
        "level": "Adult Education",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483510013726",
    },
    {
        "school": "SOUTHARD MIDDLE",
        "district": "PRINCETON ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483585013687",
    },
    {
        "school": "LOWE EL",
        "district": "PRINCETON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483585013708",
    },
    {
        "school": "CHUCK AND CINDY STUBER EL",
        "district": "PROSPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013682",
    },
    {
        "school": "BILL HAYS MIDDLE",
        "district": "PROSPER ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013756",
    },
    {
        "school": "ROCK HILL H S",
        "district": "PROSPER ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013796",
    },
    {
        "school": "JACK AND JUNE FURR EL",
        "district": "PROSPER ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013857",
    },
    {
        "school": "RIVER ROAD MIDDLE",
        "district": "RIVER ROAD ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483726013757",
    },
    {
        "school": "NEW EL #15",
        "district": "ROCKWALL ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483765013788",
    },
    {
        "school": "DELIA GONZALEZ GARCIA EL",
        "district": "ROMA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483774013779",
    },
    {
        "school": "ROSCOE COLLEGIATE MONTESSORI EARLY CHILDHOOD",
        "district": "ROSCOE COLLEGIATE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483786013697",
    },
    {
        "school": "ROSEBUD-LOTT EL",
        "district": "ROSEBUD-LOTT ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483790013694",
    },
    {
        "school": "ROYAL EARLY COLLEGE H S",
        "district": "ROYAL ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483819013773",
    },
    {
        "school": "THOMAS ARNOLD EL",
        "district": "SALADO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483858013806",
    },
    {
        "school": "IRVING DUAL LANGUAGE ACADEMY",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013851",
    },
    {
        "school": "TEXANS CAN ACADEMY AT HIGHLANDS H S",
        "district": "SAN ANTONIO ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483873013859",
    },
    {
        "school": "DEL RIO MIDDLE 7TH GRADE CAMPUS",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890013822",
    },
    {
        "school": "RODRIGUEZ EL",
        "district": "SAN MARCOS CISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483897013738",
    },
    {
        "school": "JJAEP",
        "district": "SCHERTZ-CIBOLO-U CITY ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483948013820",
    },
    {
        "school": "SEALY EL",
        "district": "SEALY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483963013753",
    },
    {
        "school": "SHELDON LAKE EL",
        "district": "SHELDON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483999013854",
    },
    {
        "school": "CACTUS TRAILS",
        "district": "SOCORRO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071013684",
    },
    {
        "school": "LOSOYA MIDDLESCHOOL",
        "district": "SOUTHSIDE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484092013713",
    },
    {
        "school": "SPRINGWOODS VILLAGE MIDDLE",
        "district": "SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122013707",
    },
    {
        "school": "SPRING LEADERSHIP ACADEMY",
        "district": "SPRING ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484122013719",
    },
    {
        "school": "LEGACY EARLY COLLEGE H S",
        "district": "TAYLOR ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484228013845",
    },
    {
        "school": "NEW J H",
        "district": "TOMBALL ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296013737",
    },
    {
        "school": "GRAND OAKS EL",
        "district": "TOMBALL ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484296013743",
    },
    {
        "school": "CUATRO VIENTOS SOUTH MIDDLE",
        "district": "UNITED ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365013763",
    },
    {
        "school": "AQUERO MIDDLE",
        "district": "UNITED ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365013792",
    },
    {
        "school": "THE COVES EL",
        "district": "UNITED ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484365013794",
    },
    {
        "school": "EVELYN LOVE COLEMAN J H",
        "district": "WAXAHACHIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473013710",
    },
    {
        "school": "WILEMON STEAM ACADEMY",
        "district": "WAXAHACHIE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473013811",
    },
    {
        "school": "ROARK EARLY EDUCATION CENTER",
        "district": "WILLIS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484590013691",
    },
    {
        "school": "Belmont School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001545",
    },
    {
        "school": "Brookhaven School",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001547",
    },
    {
        "school": "New West Jordan School",
        "district": "Jordan District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001551",
    },
    {
        "school": "Crimson Cliffs Middle",
        "district": "Washington District",
        "level": "Secondary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001549",
    },
    {
        "school": "Orchard Springs",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120001546",
    },
    {
        "school": "Horizon Academy",
        "district": "Weber District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "UT",
        "nces_id": "490120001548",
    },
    {
        "school": "Silver Ridge Elementary",
        "district": "Weber District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490120001552",
    },
    {
        "school": "Otter Creek Academy at Leicester Sudbury and Whiting",
        "district": "Otter Valley Unified Union School District #53",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500039200544",
    },
    {
        "school": "Northfield Middle/High School",
        "district": "Paine Mountain School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040800227",
    },
    {
        "school": "Williamstown Elementary School",
        "district": "Paine Mountain School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040800379",
    },
    {
        "school": "Williamstown Middle/High School",
        "district": "Paine Mountain School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040800380",
    },
    {
        "school": "Northfield Elementary School",
        "district": "Paine Mountain School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040800440",
    },
    {
        "school": "Middletown Springs Elementary School",
        "district": "Wells Spring Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040900191",
    },
    {
        "school": "Wells Village School",
        "district": "Wells Spring Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500040900367",
    },
    {
        "school": "Montpelier High School",
        "district": "Montpelier Roxbury Unified Union School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041000199",
    },
    {
        "school": "Main Street School",
        "district": "Montpelier Roxbury Unified Union School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041000200",
    },
    {
        "school": "Union Elementary School",
        "district": "Montpelier Roxbury Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041000201",
    },
    {
        "school": "Roxbury Village School",
        "district": "Montpelier Roxbury Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041000265",
    },
    {
        "school": "Poultney Elementary School",
        "district": "Quarry Valley Unified Union School District #70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041100244",
    },
    {
        "school": "Poultney High School",
        "district": "Quarry Valley Unified Union School District #70",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041100245",
    },
    {
        "school": "Proctor Elementary School",
        "district": "Quarry Valley Unified Union School District #70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041100247",
    },
    {
        "school": "Proctor Junior/Senior High School",
        "district": "Quarry Valley Unified Union School District #70",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041100248",
    },
    {
        "school": "West Rutland School",
        "district": "Quarry Valley Unified Union School District #70",
        "level": "Other",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041100370",
    },
    {
        "school": "Waterford Elementary School",
        "district": "Caledonia Cooperative Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041200363",
    },
    {
        "school": "Barnet Elementary School",
        "district": "Caledonia Cooperative Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041200421",
    },
    {
        "school": "Walden School",
        "district": "Caledonia Cooperative Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041200448",
    },
    {
        "school": "Woodstock Union Middle/High School",
        "district": "Windsor Central Modified Unified Union School District #76B",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041600395",
    },
    {
        "school": "Dorset Elementary School",
        "district": "Taconic and Green Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041700104",
    },
    {
        "school": "Manchester Elementary/Middle School",
        "district": "Taconic and Green Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041700185",
    },
    {
        "school": "Sunderland Elementary School",
        "district": "Taconic and Green Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041700321",
    },
    {
        "school": "Flood Brook School",
        "district": "Taconic and Green Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041700337",
    },
    {
        "school": "Currier Memorial Union School",
        "district": "Taconic and Green Regional School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041700341",
    },
    {
        "school": "Twin Valley Elementary School",
        "district": "Twin Valley Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041800382",
    },
    {
        "school": "Twin Valley Middle High School",
        "district": "Twin Valley Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041800540",
    },
    {
        "school": "Mettawee Community School",
        "district": "Mettawee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500041900177",
    },
    {
        "school": "Halifax West School",
        "district": "Southern Valley Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042000145",
    },
    {
        "school": "Readsboro Elementary School",
        "district": "Southern Valley Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042000254",
    },
    {
        "school": "Newark School",
        "district": "Kingdom East Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042100212",
    },
    {
        "school": "Sutton Village School",
        "district": "Kingdom East Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042100322",
    },
    {
        "school": "Millers Run Union High School",
        "district": "Kingdom East Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042100336",
    },
    {
        "school": "Burke Town School",
        "district": "Kingdom East Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042100424",
    },
    {
        "school": "Concord Graded/Middle School",
        "district": "Kingdom East Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042100427",
    },
    {
        "school": "Lunenburg & Gilman Schools",
        "district": "Kingdom East Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042100435",
    },
    {
        "school": "Lyndon Town School",
        "district": "Kingdom East Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042100436",
    },
    {
        "school": "Ludlow Elementary School",
        "district": "Ludlow Mt. Holly Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042200176",
    },
    {
        "school": "Mt. Holly School",
        "district": "Ludlow Mt. Holly Unified Union School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042200209",
    },
    {
        "school": "Black River High School",
        "district": "Ludlow Mt. Holly Unified Union School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042200342",
    },
    {
        "school": "Stockbridge Central School",
        "district": "Rochester Stockbridge Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042300408",
    },
    {
        "school": "Rochester School",
        "district": "Rochester Stockbridge Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042300549",
    },
    {
        "school": "Lincoln Community School",
        "district": "Mt. Abraham Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042500174",
    },
    {
        "school": "Monkton Central School",
        "district": "Mt. Abraham Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042500196",
    },
    {
        "school": "Beeman Elementary School",
        "district": "Mt. Abraham Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042500211",
    },
    {
        "school": "Robinson School",
        "district": "Mt. Abraham Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042500317",
    },
    {
        "school": "Mt. Abraham Union High School #61",
        "district": "Mt. Abraham Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042500338",
    },
    {
        "school": "Bristol Elementary School",
        "district": "Mt. Abraham Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042500423",
    },
    {
        "school": "Bethel Elementary School",
        "district": "White River Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042600036",
    },
    {
        "school": "White River Valley High School",
        "district": "White River Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042600543",
    },
    {
        "school": "White River Valley Middle School",
        "district": "White River Unified School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042600545",
    },
    {
        "school": "South Royalton Elementary School",
        "district": "White River Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042600547",
    },
    {
        "school": "Cavendish Town Elementary School",
        "district": "Green Mountain Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042700081",
    },
    {
        "school": "Chester Andover Elementary School",
        "district": "Green Mountain Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042700345",
    },
    {
        "school": "Green Mountain Union High School",
        "district": "Green Mountain Unified School District",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042700348",
    },
    {
        "school": "Reading Elementary School",
        "district": "Windsor Central Modified Unified Union School District #76A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042800253",
    },
    {
        "school": "Killington Elementary School",
        "district": "Windsor Central Modified Unified Union School District #76A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042800287",
    },
    {
        "school": "Woodstock Elementary School",
        "district": "Windsor Central Modified Unified Union School District #76A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042800394",
    },
    {
        "school": "Prosper Valley School",
        "district": "Windsor Central Modified Unified Union School District #76A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042800538",
    },
    {
        "school": "Tunbridge Central School",
        "district": "First Branch Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042900330",
    },
    {
        "school": "Chelsea Elementary Middle School",
        "district": "First Branch Unified School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500042900550",
    },
    {
        "school": "Washington Village School",
        "district": "Echo Valley Community School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043000548",
    },
    {
        "school": "Orange Center School",
        "district": "Echo Valley Community School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043000551",
    },
    {
        "school": "DOROTHY HAMM MIDDLE",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Middle",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027003062",
    },
    {
        "school": "MONTESSORI PUBLIC SCHOOL OF ARLINGTON",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027003063",
    },
    {
        "school": "OLD HUNDRED ELEMENTARY",
        "district": "CHESTERFIELD CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510084003066",
    },
    {
        "school": "WAXPOOL ELEMENTARY",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225003060",
    },
    {
        "school": "INDEPENDENCE HIGH",
        "district": "LOUDOUN CO PBLC SCHS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510225003061",
    },
    {
        "school": "JOHN D. JENKINS ELEMENTARY",
        "district": "PRINCE WILLIAM CO PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510313003065",
    },
    {
        "school": "NORTH STAR EARLY CHILDHOOD EDUCATION CENTER",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366003064",
    },
    {
        "school": "Kelso Goal Oriented Learning Design",
        "district": "Kelso School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530000303667",
    },
    {
        "school": "Grays Harbor Academy",
        "district": "Aberdeen School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530003003633",
    },
    {
        "school": "Auburn Opportunity Project",
        "district": "Auburn School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530030003668",
    },
    {
        "school": "Willow Public School",
        "district": "Innovation Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530034403636",
    },
    {
        "school": "Impact | Puget Sound Elementary",
        "district": "Impact Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530034503653",
    },
    {
        "school": "Wilburton Elementary School",
        "district": "Bellevue School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530039003638",
    },
    {
        "school": "Open Doors",
        "district": "Burlington-Edison School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530078003639",
    },
    {
        "school": "Camas School District Open Doors",
        "district": "Camas School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530081003646",
    },
    {
        "school": "Odyssey Middle School",
        "district": "Camas School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081003652",
    },
    {
        "school": "Discovery High School",
        "district": "Camas School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081003662",
    },
    {
        "school": "Riverbend Elementary School",
        "district": "Central Valley School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111003629",
    },
    {
        "school": "Stem Academy at SVT",
        "district": "Central Valley School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111003657",
    },
    {
        "school": "James W Lintott Elementary School",
        "district": "Chehalis School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530117003654",
    },
    {
        "school": "Orin C Smith Elementary School",
        "district": "Chehalis School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530117003655",
    },
    {
        "school": "Chewelah Open Doors Reengagement Program",
        "district": "Chewelah School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530126003649",
    },
    {
        "school": "Ferry County Open Doors",
        "district": "Curlew School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530189003648",
    },
    {
        "school": "Kalispel Language Immersion School",
        "district": "Cusick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530192003630",
    },
    {
        "school": "Home Pride",
        "district": "Cusick School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530192003642",
    },
    {
        "school": "Eatonville Online Academy",
        "district": "Eatonville School District",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530237003645",
    },
    {
        "school": "Cascadia Technical Academy ALE",
        "district": "Evergreen School District (Clark)",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530270003661",
    },
    {
        "school": "Hood Canal Middle School",
        "district": "Hood Canal School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530360003666",
    },
    {
        "school": "Kalama High School",
        "district": "Kalama School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530381003659",
    },
    {
        "school": "Fuerza Elementary",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393003647",
    },
    {
        "school": "Amon Creek Elementary",
        "district": "Kennewick School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530393003663",
    },
    {
        "school": "Kettle Falls Early Learning Center",
        "district": "Kettle Falls School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530399003631",
    },
    {
        "school": "Stevens Creek Elementary",
        "district": "Lake Stevens School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530420003634",
    },
    {
        "school": "Ella Baker Elementary School",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423003628",
    },
    {
        "school": "Clara Barton Elementary School",
        "district": "Lake Washington School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423003640",
    },
    {
        "school": "Choice Academy",
        "district": "North Kitsap School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530576003627",
    },
    {
        "school": "Mary E. Theler Early Learning Center",
        "district": "North Mason School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530579003644",
    },
    {
        "school": "Early Childhood Center",
        "district": "Othello School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530648003658",
    },
    {
        "school": "PSD U Grad Academy",
        "district": "Prosser School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530690003664",
    },
    {
        "school": "Insight School of WA Open Doors Program",
        "district": "Quillayute Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530702003665",
    },
    {
        "school": "Sartori Elementary School",
        "district": "Renton School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530723003651",
    },
    {
        "school": "Richland School District Early Learning Center",
        "district": "Richland School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530732003635",
    },
    {
        "school": "Sunset Ridge Intermediate School",
        "district": "Ridgefield School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530735003660",
    },
    {
        "school": "Shelton Open Doors",
        "district": "Shelton School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530790003632",
    },
    {
        "school": "Tukwila Online Learning",
        "district": "Tukwila School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530813003650",
    },
    {
        "school": "Steilacoom PRIDE Academy",
        "district": "Steilacoom Hist. School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530846003656",
    },
    {
        "school": "Tehaleh Heights Elementary",
        "district": "Sumner School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530861003643",
    },
    {
        "school": "Camas Elementary",
        "district": "Wapato School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530948003637",
    },
    {
        "school": "Simcoe Elementary School",
        "district": "Wapato School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530948003641",
    },
    {
        "school": "West Valley Open Doors",
        "district": "West Valley School District (Yakima)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530972003669",
    },
    {
        "school": "PIKESIDE LEARNING CENTER",
        "district": "BERKELEY COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540006001586",
    },
    {
        "school": "BROOKE HANCOCK ALTERNATIIVE LEARNING CTR",
        "district": "BROOKE COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540015001587",
    },
    {
        "school": "FAYETTEVILLE PK-8",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030001595",
    },
    {
        "school": "VALLEY PK-8",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030001596",
    },
    {
        "school": "NEW RIVER INTERMEDIATE",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030001597",
    },
    {
        "school": "NEW RIVER PRIMARY",
        "district": "FAYETTE COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540030001598",
    },
    {
        "school": "BROOKE HANCOCK ALTERNATIVE LEARNING CTR",
        "district": "HANCOCK COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540045001588",
    },
    {
        "school": "HARRISON COUNTY EVOLUTION  ELEMENTARY",
        "district": "HARRISON COUNTY SCHOOLS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051001594",
    },
    {
        "school": "CAMMACK CHILDREN?S CENTER",
        "district": "INSTITUTIONAL EDUCATIONAL PROGRAMS",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WV",
        "nces_id": "540051101593",
    },
    {
        "school": "CHAPMANVILLE PRIMARY SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069001589",
    },
    {
        "school": "CHAPMANVILLE INTERMEDIATE SCHOOL",
        "district": "LOGAN COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540069001590",
    },
    {
        "school": "RIDGEVIEW ELEMENTARY",
        "district": "RALEIGH COUNTY SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WV",
        "nces_id": "540123001591",
    },
    {
        "school": "WETZEL COUNTY TECHNICAL EDUCATION CENTER",
        "district": "WETZEL COUNTY SCHOOLS",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WV",
        "nces_id": "540156001592",
    },
    {
        "school": "Chippewa Valley Correctional Treatment Facililty",
        "district": "Wisconsin Department of Corrections",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550003503104",
    },
    {
        "school": "Rocketship Southside Community Prep",
        "district": "Rocketship Education Wisconsin Inc",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550008102969",
    },
    {
        "school": "Columbus Intermediate",
        "district": "Columbus School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550282003100",
    },
    {
        "school": "Cuba City Middle",
        "district": "Cuba City School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550303003103",
    },
    {
        "school": "Eau Claire Virtual School",
        "district": "Eau Claire Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550405003115",
    },
    {
        "school": "Riveredge Outdoor Learning Elementary",
        "district": "Northern Ozaukee School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550489003106",
    },
    {
        "school": "eSucceed Charter School",
        "district": "Gilman School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550528003114",
    },
    {
        "school": "Northeast Wisconsin School of Innovation",
        "district": "Green Bay Area Public School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550582003105",
    },
    {
        "school": "Silver Spring Intermediate",
        "district": "Hamilton School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550603003118",
    },
    {
        "school": "Maple Park Charter School",
        "district": "Lake Geneva J1 School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550762003107",
    },
    {
        "school": "New Visions Charter School",
        "district": "Lake Geneva-Genoa City UHS School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550765003109",
    },
    {
        "school": "Green Tree Preparatory Academy",
        "district": "Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960003111",
    },
    {
        "school": "Necedah Middle",
        "district": "Necedah Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551023003099",
    },
    {
        "school": "N-Vision Learning Center",
        "district": "Necedah Area School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551023003112",
    },
    {
        "school": "N-Gage Academy",
        "district": "Necedah Area School District",
        "level": "High",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551023003116",
    },
    {
        "school": "New Auburn Middle",
        "district": "New Auburn School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551044003117",
    },
    {
        "school": "Prairie Ridge Intermediate",
        "district": "Reedsburg School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551266003098",
    },
    {
        "school": "Odyssey Academy of Virtual Learning",
        "district": "Ripon Area School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551302003102",
    },
    {
        "school": "Eagles' Wings Public Montessori Charter",
        "district": "Solon Springs School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551398003113",
    },
    {
        "school": "Sparta Elementary",
        "district": "Sparta Area School District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551416003110",
    },
    {
        "school": "White Lake Middle",
        "district": "White Lake School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551659003108",
    },
    {
        "school": "Monroe Elementary School",
        "district": "Sweetwater County School District #2",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560576200582",
    },
    {
        "school": "Munger Mountain Elementary School",
        "district": "Teton County School District #1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WY",
        "nces_id": "560583000583",
    },
    {
        "school": "Fagali'i Elementary School",
        "district": "American Samoa Department of Education",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AS",
        "nces_id": "600003000049",
    },
    {
        "school": "Science is Fun and Awesome Learning Academy Charter School",
        "district": "Science is Fun and Awesome Learning Academy Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000300085",
    },
    {
        "school": "Guahan Academy Charter School",
        "district": "Guahan Academy Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000400083",
    },
    {
        "school": "iLearn Academy Charter School",
        "district": "iLearn Academy Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GU",
        "nces_id": "660000500084",
    },
    {
        "school": "ESCUELA PUBLICA ALIANZA VIMENTI SCHOOL",
        "district": "PUERTO RICO DEPARTMENT OF EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PR",
        "nces_id": "720003001945",
    },
    {
        "school": "Riverchase Career Connection Center",
        "district": "Hoover City",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10000702487",
    },
    {
        "school": "Legacy Prep",
        "district": "Legacy Prep",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10020102472",
    },
    {
        "school": "Gulf Shores Elementary School",
        "district": "Gulf Shores City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10020202469",
    },
    {
        "school": "Gulf Shores Middle School",
        "district": "Gulf Shores City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10020202471",
    },
    {
        "school": "Gulf Shores High School",
        "district": "Gulf Shores City",
        "level": "High",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10020202473",
    },
    {
        "school": "LEAD Academy",
        "district": "LEAD Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10020302470",
    },
    {
        "school": "i3 Academy",
        "district": "i3 Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10020402476",
    },
    {
        "school": "Capstone",
        "district": "Capstone",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10020502488",
    },
    {
        "school": "Woodland Preparatory",
        "district": "Woodland Preparatory",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10020602491",
    },
    {
        "school": "Orange Beach MiddleHigh School",
        "district": "Baldwin County",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027002483",
    },
    {
        "school": "Elberta Middle School",
        "district": "Baldwin County",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10027002490",
    },
    {
        "school": "Richard Arrington Elementary",
        "district": "Birmingham City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10039002489",
    },
    {
        "school": "Dothan Preparatory Academy",
        "district": "Dothan City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123002480",
    },
    {
        "school": "Dothan City Early Education Center",
        "district": "Dothan City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10123002482",
    },
    {
        "school": "Kilby Laboratory School",
        "district": "Florence City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10153002474",
    },
    {
        "school": "Red Bay Elementary",
        "district": "Franklin County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10159002475",
    },
    {
        "school": "Academy for Academics and Arts Middle School",
        "district": "Huntsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180002478",
    },
    {
        "school": "Morris Middle School",
        "district": "Huntsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180002484",
    },
    {
        "school": "Academy For Science  Foreign Language Middle School",
        "district": "Huntsville City",
        "level": "Middle",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10180002486",
    },
    {
        "school": "Madison County Virtual School",
        "district": "Madison County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10222002479",
    },
    {
        "school": "Citronelle Center for Advanced Technology",
        "district": "Mobile County",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AL",
        "nces_id": "10237002477",
    },
    {
        "school": "SCC Virtual Preparatory Academy",
        "district": "St Clair County",
        "level": "Other",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10306202485",
    },
    {
        "school": "Vestavia Hills Elementary Dolly Ridge",
        "district": "Vestavia Hills City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AL",
        "nces_id": "10343002481",
    },
    {
        "school": "Mertarvik School",
        "district": "Lower Kuskokwim School District",
        "level": "Other",
        "type": "Regular school",
        "state": "AK",
        "nces_id": "20000100765",
    },
    {
        "school": "Discovery Peak Charter School",
        "district": "Fairbanks North Star Borough School District",
        "level": "Elementary",
        "type": "Special education school",
        "state": "AK",
        "nces_id": "20060000766",
    },
    {
        "school": "CVIT - Central Campus CAC Aravaipa",
        "district": "Cobre Valley Institute of Technology District (79391)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40031603670",
    },
    {
        "school": "CTD - Patagonia High School",
        "district": "Cochise Technology District (79403)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40034503671",
    },
    {
        "school": "Global Academy of Phoenix",
        "district": "Alhambra Elementary District (4280)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060003659",
    },
    {
        "school": "Alhambra Preschool Academy",
        "district": "Alhambra Elementary District (4280)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40060003660",
    },
    {
        "school": "West-MEC West Point High School",
        "district": "West-MEC - Western Maricopa Education Center (80923)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40061503641",
    },
    {
        "school": "Candeo North Scottsdale",
        "district": "Candeo Schools Inc. (89758)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40075803672",
    },
    {
        "school": "Sun Valley Academy-Avondale",
        "district": "Morrison Education Group Inc. (90192)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40079303675",
    },
    {
        "school": "WAVE - Mohave Community College Bullhead City Campus",
        "district": "Western Arizona Vocational District #50 (90123)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40079403673",
    },
    {
        "school": "WAVE - Mohave Community College Lake Havasu City Campus",
        "district": "Western Arizona Vocational District #50 (90123)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40079403674",
    },
    {
        "school": "Vista College Prep - ES#4",
        "district": "Vista College Preparatory Inc. (91948)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40088703678",
    },
    {
        "school": "Vista College Prep ? MS#5",
        "district": "Vista College Preparatory Inc. (91948)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40088703679",
    },
    {
        "school": "Academy of Math and Science Peoria Advanced",
        "district": "Academy of Mathematics and Science South Inc. (90878)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089103604",
    },
    {
        "school": "Academy of Math and Science Glendale",
        "district": "Academy of Mathematics and Science South Inc. (90878)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089103618",
    },
    {
        "school": "Academy of Math and Science Avondale",
        "district": "Academy of Mathematics and Science South Inc. (90878)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089103676",
    },
    {
        "school": "Academy of Math and Science South Mountain",
        "district": "Academy of Mathematics and Science South Inc. (90878)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40089103677",
    },
    {
        "school": "Somerset Academy Skyway Campus",
        "district": "Somerset Academy Arizona Inc. (1000160)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40098703640",
    },
    {
        "school": "Valor Preparatory Academy",
        "district": "Valor Preparatory Academy LLC (1000291)",
        "level": "Middle",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40098803680",
    },
    {
        "school": "ARCHES Academy",
        "district": "ARCHES Academy (92980)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40098903642",
    },
    {
        "school": "Phoenix Modern",
        "district": "New Learning Ventures Inc. (320470)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40099003649",
    },
    {
        "school": "Legacy Traditional School - Goodyear",
        "district": "Legacy Traditional School - Goodyear (1000283)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40099103650",
    },
    {
        "school": "Kaleidoscope School",
        "district": "Integrated Education Foundation Inc. (1000164)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40099203644",
    },
    {
        "school": "Providence High School",
        "district": "New Horizon High School Inc. (1000165)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40099303647",
    },
    {
        "school": "Self Development Eastmark Academy",
        "district": "Self Development Eastmark Academy (520359)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40099403645",
    },
    {
        "school": "Self Development Scottsdale Academy",
        "district": "Self Development Scottsdale Academy (308420)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40099503648",
    },
    {
        "school": "Legacy Traditional School - West Surprise",
        "district": "Legacy Traditional School - West Surprise (1000560)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40099603653",
    },
    {
        "school": "Legacy Traditional School - North Phoenix",
        "district": "Legacy Traditional School - North Phoenix (1000568)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40099703654",
    },
    {
        "school": "A+ Charter Schools",
        "district": "A+ Charter Schools (1000166)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40099803681",
    },
    {
        "school": "Freedom Prep Academy - Mesa",
        "district": "Freedom Preparatory Academy (1000979)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40099903682",
    },
    {
        "school": "Copper Credits",
        "district": "Bisbee Unified District (4169)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40118003655",
    },
    {
        "school": "Camp Verde Online",
        "district": "Camp Verde Unified District (4470)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40160003666",
    },
    {
        "school": "Freedom Traditional Academy",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269003656",
    },
    {
        "school": "Asante Preparatory Academy",
        "district": "Dysart Unified District (4243)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40269003657",
    },
    {
        "school": "Belen Soto Elementary School",
        "district": "Litchfield Elementary District (4281)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40438003661",
    },
    {
        "school": "MUSD Early Learning and Resource Center",
        "district": "Marana Unified District (4404)",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "AZ",
        "nces_id": "40463003663",
    },
    {
        "school": "GCC Early Childhood Learning Lab",
        "district": "Peoria Unified School District (4237)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40625003643",
    },
    {
        "school": "Katherine Mecham Barney Elementary",
        "district": "Queen Creek Unified District (4245)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681003651",
    },
    {
        "school": "Silver Valley Elementary",
        "district": "Queen Creek Unified District (4245)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40681003658",
    },
    {
        "school": "San Carlos Middle School",
        "district": "San Carlos Unified District (4210)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40696003683",
    },
    {
        "school": "Tolleson Virtual High School",
        "district": "Tolleson Union High School District (4288)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40852003662",
    },
    {
        "school": "Mica Mountain High",
        "district": "Vail Unified District (4413)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885003652",
    },
    {
        "school": "Vail Blended Learning",
        "district": "Vail Unified District (4413)",
        "level": "High",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885003664",
    },
    {
        "school": "Vail Inclusive Preschool",
        "district": "Vail Unified District (4413)",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40885003665",
    },
    {
        "school": "Dorothy Hall Elementary",
        "district": "Yuma Elementary District (4499)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AZ",
        "nces_id": "40960003667",
    },
    {
        "school": "EVIT Cactus Shadows High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973103668",
    },
    {
        "school": "EVIT Eastmark High School",
        "district": "East Valley Institute of Technology (4516)",
        "level": "High",
        "type": "Career and Technical School",
        "state": "AZ",
        "nces_id": "40973103669",
    },
    {
        "school": "CORNING MIDDLE SCHOOL",
        "district": "CORNING SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50000901671",
    },
    {
        "school": "EAST END MIDDLE SCHOOL",
        "district": "SHERIDAN SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50001501677",
    },
    {
        "school": "SOUTHWOOD ELEMENTARY SCHOOL",
        "district": "PINE BLUFF SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50002601670",
    },
    {
        "school": "ALLBRITTON ELEMENTARY SCHOOL",
        "district": "HAMBURG SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50004201675",
    },
    {
        "school": "RISON MIDDLE SCHOOL",
        "district": "CLEVELAND COUNTY SCHOOL DIST.",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50006701673",
    },
    {
        "school": "LISA ACADEMY SPRINGDALE",
        "district": "LISA ACADEMY CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50007401672",
    },
    {
        "school": "CSTP-CIVILIAN STUDENT TRAINING PROGRAM",
        "district": "ARKANSAS YOUTH SERVICES SCHOOL SYSTEM",
        "level": "Not reported",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50039001674",
    },
    {
        "school": "WEST LITTLE ROCK CLASSICAL ACADEMY",
        "district": "RESPONSIVE ED SOLUTIONS NORTHWEST ARK CLASSICAL ACADEMY",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50040901685",
    },
    {
        "school": "FRIENDSHIP ASPIRE ELEMENTARY ACADEMY LITTLE ROCK",
        "district": "FRIENDSHIP ASPIRE ACADEMY LITTLE ROCK",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50042401681",
    },
    {
        "school": "FRIENDSHIP ASPIRE MIDDLE ACADEMY LITTLE ROCK",
        "district": "FRIENDSHIP ASPIRE ACADEMY LITTLE ROCK",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50042401683",
    },
    {
        "school": "PREMIER HIGH SCHOOL OF NORTH LITTLE ROCK",
        "district": "RESPONSIVE ED SOLUTIONS PREMIER HIGH SCH OF NORTHLITTLE ROCK",
        "level": "High",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50042501686",
    },
    {
        "school": "EVENING STAR ELEMENTARY SCHOOL",
        "district": "BENTONVILLE SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50306001684",
    },
    {
        "school": "BRYANT JUNIOR HIGH SCHOOL",
        "district": "BRYANT SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50369001676",
    },
    {
        "school": "CENTERPOINT MIDDLE SCHOOL",
        "district": "CENTERPOINT SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50669001680",
    },
    {
        "school": "PINNACLE VIEW HIGH SCHOOL",
        "district": "LITTLE ROCK SCHOOL DISTRICT",
        "level": "Secondary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "50900001679",
    },
    {
        "school": "NORTH LITTLE ROCK MIDDLE SCHOOL 6TH GRADE CAMPUS",
        "district": "N. LITTLE ROCK SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51068001678",
    },
    {
        "school": "FAIRVIEW ELEMENTARY SCHOOL",
        "district": "ROGERS SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "AR",
        "nces_id": "51197001682",
    },
    {
        "school": "Rocklin Alternative Education Center",
        "district": "Rocklin Unified",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60001314465",
    },
    {
        "school": "Alberhill Elementary",
        "district": "Lake Elsinore Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60002714467",
    },
    {
        "school": "Tracy Independent Study Charter",
        "district": "Tracy Joint Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60004714472",
    },
    {
        "school": "Triumph Academy",
        "district": "Triumph Academy District",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60252614451",
    },
    {
        "school": "Open Door Charter",
        "district": "Open Door Charter District",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60252814477",
    },
    {
        "school": "We the People High",
        "district": "We the People High District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60252914478",
    },
    {
        "school": "Griffin Academy High",
        "district": "Griffin Academy High District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60253014479",
    },
    {
        "school": "Citizens of the World Charter School 5",
        "district": "Citizens of the World Charter School 5 District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60253114480",
    },
    {
        "school": "Aspire Stockton 6-12 Secondary Academy",
        "district": "Aspire Stockton 6-12 Secondary Academy District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60253214481",
    },
    {
        "school": "KIPP Esperanza High",
        "district": "KIPP Esperanza High District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60253314482",
    },
    {
        "school": "Aspire Stockton TK-5 Elementary Academy",
        "district": "Aspire Stockton TK-5 Elementary Academy District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60253414483",
    },
    {
        "school": "Orange County Classical Academy",
        "district": "Orange County Classical Academy District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60253514484",
    },
    {
        "school": "Virtual Preparatory Academy at Monterey",
        "district": "Virtual Preparatory Academy at Monterey District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60253614485",
    },
    {
        "school": "Vision Quest & Career Pathway",
        "district": "Vision Quest & Career Pathway District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60253714486",
    },
    {
        "school": "Endeavor Charter",
        "district": "Endeavor Charter District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60253814487",
    },
    {
        "school": "OCASA College Prep",
        "district": "OCASA College Prep District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60253914488",
    },
    {
        "school": "Ednovate College Prep 7",
        "district": "Ednovate College Prep 7 District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60254014489",
    },
    {
        "school": "American River Collegiate Academy",
        "district": "American River Collegiate Academy District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60254114490",
    },
    {
        "school": "Pacific Collegiate Charter",
        "district": "Pacific Collegiate Charter District",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60254208363",
    },
    {
        "school": "Agnes J. Johnson Charter",
        "district": "Agnes J. Johnson Charter District",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60254306363",
    },
    {
        "school": "Tehama eLearning Academy",
        "district": "Tehama eLearning Academy District",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60254410699",
    },
    {
        "school": "Anaheim Elementary Online Academy",
        "district": "Anaheim Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60261014460",
    },
    {
        "school": "Buena Park Learning Center",
        "district": "Buena Park Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60636014461",
    },
    {
        "school": "Byron Institute for Independent Study",
        "district": "Byron Union Elementary",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60675014447",
    },
    {
        "school": "Central Online Home",
        "district": "Central Unified",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "60797014455",
    },
    {
        "school": "Philistine Rondo School of Discovery",
        "district": "Corona-Norco Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "60985014466",
    },
    {
        "school": "Virtual Academy of Fairfield-Suisun",
        "district": "Fairfield-Suisun Unified",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "61336014474",
    },
    {
        "school": "Valley Oaks Center for Enriched Studies",
        "district": "Los Angeles Unified",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62271014456",
    },
    {
        "school": "Grasslands Elementary",
        "district": "Los Banos Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62274014458",
    },
    {
        "school": "Pacific View Academy",
        "district": "Lucia Mar Unified",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62308014473",
    },
    {
        "school": "Matilda Torres High",
        "district": "Madera Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62334014457",
    },
    {
        "school": "MDUSD Preschools",
        "district": "Mt. Diablo Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62637014454",
    },
    {
        "school": "Ojai Independent",
        "district": "Ojai Unified",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "62827014449",
    },
    {
        "school": "Duncan Holbert",
        "district": "Pajaro Valley Unified",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "62949014448",
    },
    {
        "school": "Riego Creek Elementary",
        "district": "Roseville City Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63360014462",
    },
    {
        "school": "West Park High",
        "district": "Roseville Joint Union High",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63363014463",
    },
    {
        "school": "Victor Valley Virtual Academy",
        "district": "Victor Valley Union High",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "63697214469",
    },
    {
        "school": "Soulsbyville",
        "district": "Soulsbyville Elementary",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63732014450",
    },
    {
        "school": "Flora Arca Mata",
        "district": "Stockton Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "63801014471",
    },
    {
        "school": "Special Education Preschool",
        "district": "Twain Harte",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64020014476",
    },
    {
        "school": "Scott M. Leaman",
        "district": "Western Placer Unified",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "64214014464",
    },
    {
        "school": "Santa Cruz County Cypress Charter High",
        "district": "Santa Cruz County Office of Education",
        "level": "High",
        "type": "Regular school",
        "state": "CA",
        "nces_id": "69103611259",
    },
    {
        "school": "Pathways Charter Academy",
        "district": "Sutter County Office of Education",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "CA",
        "nces_id": "69104214475",
    },
    {
        "school": "Axis International Academy",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006768",
    },
    {
        "school": "Colorado Early Colleges Fort Collins West",
        "district": "State Charter School Institute",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006777",
    },
    {
        "school": "Colorado Early Colleges Windsor",
        "district": "State Charter School Institute",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006779",
    },
    {
        "school": "Coperni 3",
        "district": "State Charter School Institute",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80002006784",
    },
    {
        "school": "Home School Academy",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006775",
    },
    {
        "school": "Chinook Trail Middle School",
        "district": "Academy School District No. 20 in the county of El Paso an",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80192006788",
    },
    {
        "school": "Aurora Community School",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006771",
    },
    {
        "school": "Empower Community High School",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006781",
    },
    {
        "school": "Aurora Science & Tech Middle School",
        "district": "Aurora Joint District No. 28 of the counties of Adams and A",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80234006787",
    },
    {
        "school": "Bennett Intermediate School",
        "district": "Bennett School District No. 29J",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80243006789",
    },
    {
        "school": "The Grove BVSD's Early Learning Program",
        "district": "Buena Vista School District No. R-31",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80264006767",
    },
    {
        "school": "Preschool 24",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006769",
    },
    {
        "school": "Colorado Skies Academy",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006770",
    },
    {
        "school": "Cherry Creek Elevation",
        "district": "Cherry Creek School District No. 5 in the county of Arapah",
        "level": "High",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80291006791",
    },
    {
        "school": "The Cube",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006780",
    },
    {
        "school": "Denver Green School Northfield",
        "district": "School District No. 1 in the county of Denver and State of C",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80336006790",
    },
    {
        "school": "Inspiration View Elementary School",
        "district": "El Paso County Colorado School District 49",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387006774",
    },
    {
        "school": "Falcon Homeschool Program",
        "district": "El Paso County Colorado School District 49",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387006778",
    },
    {
        "school": "Rocky Mountain Classical Academy Homeschool",
        "district": "El Paso County Colorado School District 49",
        "level": "Other",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80387006785",
    },
    {
        "school": "PSD Mountain Schools",
        "district": "Poudre School District R-1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80399006776",
    },
    {
        "school": "Trailside Academy",
        "district": "Mapleton School District No. 1 in the county of Adams & St",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80555006786",
    },
    {
        "school": "Villa Bella Expeditionary School",
        "district": "Pueblo County School District 70",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80615006773",
    },
    {
        "school": "Grand Mountain School",
        "district": "School District No. 3 in the county of El Paso and State of",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80648006772",
    },
    {
        "school": "Windsor Charter Academy Middle School",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "Middle",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735006782",
    },
    {
        "school": "Severance High School",
        "district": "Weld County Reorganized School District No. Re-4",
        "level": "Secondary",
        "type": "Regular school",
        "state": "CO",
        "nces_id": "80735006783",
    },
    {
        "school": "LEAP Alternative High School",
        "district": "Eastern Connecticut Regional Educational Service Center",
        "level": "High",
        "type": "Alternative Education School",
        "state": "CT",
        "nces_id": "90136001937",
    },
    {
        "school": "Groton Middle School",
        "district": "Groton School District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90177001938",
    },
    {
        "school": "Hartford Public High School",
        "district": "Hartford School District",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90192001925",
    },
    {
        "school": "P-TECH Norwalk",
        "district": "Norwalk School District",
        "level": "High",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90309001923",
    },
    {
        "school": "Haddam-Killingworth Intermediate School",
        "district": "Regional School District 17",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90353901921",
    },
    {
        "school": "Moser School",
        "district": "Rocky Hill School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "CT",
        "nces_id": "90384001936",
    },
    {
        "school": "Odessa High School",
        "district": "Appoquinimink School District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000390",
    },
    {
        "school": "Cantwell Bridge Middle School",
        "district": "Appoquinimink School District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100008000391",
    },
    {
        "school": "Capital Early Childhood Center",
        "district": "Capital School District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "DE",
        "nces_id": "100019000392",
    },
    {
        "school": "Red Clay Early Years Program",
        "district": "Red Clay Consolidated School District",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "DE",
        "nces_id": "100130000389",
    },
    {
        "school": "Friendship PCS - Armstrong Middle",
        "district": "Friendship PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800526",
    },
    {
        "school": "Friendship PCS - Ideal MS",
        "district": "Friendship PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800528",
    },
    {
        "school": "Friendship PCS - Ideal Elementary",
        "district": "Friendship PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110000800530",
    },
    {
        "school": "Ida B. Wells MS",
        "district": "District of Columbia Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000524",
    },
    {
        "school": "Bard HS Early College DC",
        "district": "District of Columbia Public Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003000529",
    },
    {
        "school": "KIPP DC - Honor Academy PCS",
        "district": "KIPP DC PCS",
        "level": "Middle",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100522",
    },
    {
        "school": "KIPP DC - Somerset College Preparatory PCS",
        "district": "KIPP DC PCS",
        "level": "High",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110003100523",
    },
    {
        "school": "Mundo Verde Bilingual PCS - 4401 8th Street NE Campus",
        "district": "Mundo Verde Bilingual PCS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110008600527",
    },
    {
        "school": "Lee Montessori PCS - East End",
        "district": "Lee Montessori PCS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "DC",
        "nces_id": "110009300525",
    },
    {
        "school": "CENTRAL ACADEMY",
        "district": "BAY",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120009008882",
    },
    {
        "school": "PINECREST ACADEMY SPACE COAST",
        "district": "BREVARD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015008790",
    },
    {
        "school": "VIERA ELEMENTARY SCHOOL",
        "district": "BREVARD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120015008800",
    },
    {
        "school": "SUMMIT ACADEMY CHARTER SCHOOL",
        "district": "BROWARD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120018008753",
    },
    {
        "school": "SUNED HIGH OF SOUTH BROWARD",
        "district": "BROWARD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120018008861",
    },
    {
        "school": "BABCOCK HIGH SCHOOL",
        "district": "CHARLOTTE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120024008877",
    },
    {
        "school": "E-NINI-HASSEE",
        "district": "CITRUS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120027008796",
    },
    {
        "school": "GOLDEN GATE INTERMEDIATE CENTER SOUTH",
        "district": "COLLIER",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033008828",
    },
    {
        "school": "FLORIDA VIRTUAL COURSE OFFERINGS",
        "district": "COLLIER",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033008842",
    },
    {
        "school": "GOLDEN GATE INTERMEDIATE CENTER NORTH",
        "district": "COLLIER",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120033008878",
    },
    {
        "school": "DON SOFFER AVENTURA HIGH SCHOOL",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008751",
    },
    {
        "school": "IPREP NORTH",
        "district": "MIAMI-DADE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008792",
    },
    {
        "school": "ACCELERATION ACADEMIES-CENTRAL MIAMI",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039008814",
    },
    {
        "school": "KIPP MIAMI-LIBERTY CITY",
        "district": "MIAMI-DADE",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120039008838",
    },
    {
        "school": "MIAMI GIRLS ACADEMY",
        "district": "MIAMI-DADE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120039008869",
    },
    {
        "school": "TEEN PAREN PK CHILD CARE PROGRAM",
        "district": "DESOTO",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120042008765",
    },
    {
        "school": "SEASIDE CHARTER NORTH CAMPUS",
        "district": "DUVAL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008758",
    },
    {
        "school": "GLOBAL OUTREACH CHARTER ACADEMY HIGH SCHOOL",
        "district": "DUVAL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008773",
    },
    {
        "school": "SAN JOSE PRIMARY SCHOOL",
        "district": "DUVAL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008779",
    },
    {
        "school": "JACKSONVILLE CLASSICAL ACADEMY",
        "district": "DUVAL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008789",
    },
    {
        "school": "SEVENTH GENERATION CLASSICAL ACADEMY AT MANDARIN",
        "district": "DUVAL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008798",
    },
    {
        "school": "CORNERSTONE CLASSICAL ACADEMY",
        "district": "DUVAL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120048008874",
    },
    {
        "school": "FRANKLIN VIRTUAL FRANCHISE-PACE FLVS",
        "district": "FRANKLIN",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120057008815",
    },
    {
        "school": "PRIVATE SCHOOL STUDENTS TITLE I PART C (MIGRANT) PROGRAMS",
        "district": "HAMILTON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120072008876",
    },
    {
        "school": "HARDEE VIRTUAL COURSE OFFERINGS",
        "district": "HARDEE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120075008772",
    },
    {
        "school": "LITERACY LEADERSHIP TECHNOLOGY ACADEMY SOUTH BAY",
        "district": "HILLSBOROUGH",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008760",
    },
    {
        "school": "NORTHSTAR ACADEMY OF HILLSBOROUGH COUNTY WEST",
        "district": "HILLSBOROUGH",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008783",
    },
    {
        "school": "NORTHSTAR ACADEMY OF HILLSBOROUGH COUNTY EAST",
        "district": "HILLSBOROUGH",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120087008803",
    },
    {
        "school": "PINECREST ACADEMY FOUR CORNERS",
        "district": "LAKE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120105008819",
    },
    {
        "school": "LAKE SUCCESS ACADEMY",
        "district": "LAKE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120105008829",
    },
    {
        "school": "THE COLLEGIATE SCHOOL OF FORT MYERS",
        "district": "LEE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108008794",
    },
    {
        "school": "PALM RIVER CHARTER HIGH SCHOOL",
        "district": "LEE",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108008804",
    },
    {
        "school": "EAST ZONE HIGH SHCOOL MMM",
        "district": "LEE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120108008840",
    },
    {
        "school": "SUNFIRE HIGH SCHOOL OF LEE COUNTY",
        "district": "LEE",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120108008880",
    },
    {
        "school": "JAIL SERVICES",
        "district": "LEVY",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120114008806",
    },
    {
        "school": "LIBERTY K12 VIRTUAL",
        "district": "LIBERTY",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120117008854",
    },
    {
        "school": "WAYPOINT CHARTER ACADEMY",
        "district": "MADISON",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120120008885",
    },
    {
        "school": "CRESTVIEW YOUTH ACADEMY (NON SECURE)",
        "district": "OKALOOSA",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120138008864",
    },
    {
        "school": "OKEECHOBEE YOUTH TREATMENT CENTER (OYTC)",
        "district": "OKEECHOBEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120141008807",
    },
    {
        "school": "OKEECHOBEE YOUTH CORRECTION (OYCC)",
        "district": "OKEECHOBEE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120141008848",
    },
    {
        "school": "PINECREST COLLEGIATE ACADEMY",
        "district": "ORANGE",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008761",
    },
    {
        "school": "90-K8-N-7",
        "district": "ORANGE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008786",
    },
    {
        "school": "80-H-SW-4",
        "district": "ORANGE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008801",
    },
    {
        "school": "CENTRAL FLORIDA POLYTECHNIC ACADEMY",
        "district": "ORANGE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008808",
    },
    {
        "school": "113-H-W-4",
        "district": "ORANGE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008827",
    },
    {
        "school": "89-E-W-4",
        "district": "ORANGE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008845",
    },
    {
        "school": "132-M-W-4",
        "district": "ORANGE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120144008872",
    },
    {
        "school": "MATER ACADEMY PREPARATORY HIGH SCHOOL.",
        "district": "OSCEOLA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008767",
    },
    {
        "school": "VICTORY CHARTER SCHOOL K-5",
        "district": "OSCEOLA",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120147008886",
    },
    {
        "school": "SLAM ACADEMY HIGH SCHOOL PALM BEACH",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120150008752",
    },
    {
        "school": "SOUTHTECH SUCCESS CENTER INC",
        "district": "PALM BEACH",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120150008825",
    },
    {
        "school": "CYPRESS CREEK MIDDLE SCHOOL",
        "district": "PASCO",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120153008776",
    },
    {
        "school": "ELISA NELSON ELEMENTARY",
        "district": "PINELLAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008799",
    },
    {
        "school": "PINNACLE ACADEMY",
        "district": "PINELLAS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120156008811",
    },
    {
        "school": "ST. PETERSBURG COLLEGIATE HIGH SCHOOL  NORTH PINELLAS",
        "district": "PINELLAS",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120156008862",
    },
    {
        "school": "ECKERD CONNECTS",
        "district": "POLK",
        "level": "High",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120159008762",
    },
    {
        "school": "DAVENPORT A",
        "district": "POLK",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120159008768",
    },
    {
        "school": "STATE COLLEGE OF FLA COLLEGIATE SCHOOL-VENICE",
        "district": "SARASOTA",
        "level": "High",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168008787",
    },
    {
        "school": "DREAMERS ACADEMY",
        "district": "SARASOTA",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120168008870",
    },
    {
        "school": "INDEPENDENCE CLASSICAL ACADEMY",
        "district": "ST. LUCIE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120177008887",
    },
    {
        "school": "SUWANNEE OPPORTUNITY SCHOOL",
        "district": "SUWANNEE",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "FL",
        "nces_id": "120183008860",
    },
    {
        "school": "TAYLOR PAEC K-12",
        "district": "TAYLOR",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120186008763",
    },
    {
        "school": "WALTON VIRTUAL SCHOOL WCSD",
        "district": "WALTON",
        "level": "Other",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198008849",
    },
    {
        "school": "BAY SCHOOL",
        "district": "WALTON",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "FL",
        "nces_id": "120198008863",
    },
    {
        "school": "The Hope Academy School",
        "district": "Troup County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130000104369",
    },
    {
        "school": "Coastal Academy",
        "district": "First District RESA",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130001804333",
    },
    {
        "school": "Cadwell RYDC",
        "district": "Department of Juvenile Justice",
        "level": "Secondary",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130002604354",
    },
    {
        "school": "Harper-Archer Elementary School",
        "district": "Atlanta Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130012004346",
    },
    {
        "school": "Academy For Classical Education",
        "district": "State Charter Schools II- Academy For Classical Education",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130025204345",
    },
    {
        "school": "Spring Creek Charter Academy",
        "district": "State Charter Schools II- Spring Creek Charter Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130025304349",
    },
    {
        "school": "Georgia Academy for the Blind",
        "district": "State Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130025404331",
    },
    {
        "school": "Atlanta Area School for the Deaf",
        "district": "State Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130025404352",
    },
    {
        "school": "Georgia School for the Deaf",
        "district": "State Schools",
        "level": "Other",
        "type": "Special education school",
        "state": "GA",
        "nces_id": "130025404367",
    },
    {
        "school": "Ethos Classical Charter School",
        "district": "State Charter Schools II- Ethos Classical Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130025504332",
    },
    {
        "school": "Baconton Community Charter School",
        "district": "State Charter Schools II- Baconton Community Charter School",
        "level": "Other",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130025604363",
    },
    {
        "school": "Yi Hwang Academy of Language Excellence",
        "district": "Charter Commission School-Yi Hwang Academy of Language Exce",
        "level": "Not reported",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130025704372",
    },
    {
        "school": "Furlow Charter School",
        "district": "Charter Commission School-Furlow Charter School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130025804373",
    },
    {
        "school": "Atlanta SMART Academy",
        "district": "Charter Commission School-Atlanta SMART Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130025904374",
    },
    {
        "school": "Harriet Tubman School of Science & Technology",
        "district": "Charter Commission School-Harriet Tubman School of Science",
        "level": "Not reported",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130026004375",
    },
    {
        "school": "Atlanta Unbound Academy",
        "district": "Charter Commission School-Atlanta Unbound Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130026104376",
    },
    {
        "school": "D.E.L.T.A. Steam Academy",
        "district": "Charter Commission School-D.E.L.T.A. Steam Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130026204377",
    },
    {
        "school": "Georgia Fugees Academy Charter School",
        "district": "Charter Commission School-Georgia Fugees Academy Charter Sc",
        "level": "Not reported",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130026304378",
    },
    {
        "school": "Hurricane Transition Academy",
        "district": "Ben Hill County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130036004365",
    },
    {
        "school": "Buford Senior Academy",
        "district": "Buford City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130060004338",
    },
    {
        "school": "Metter Career Academy",
        "district": "Candler County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130081004361",
    },
    {
        "school": "Henderson E Formey Jr Early Learning Center",
        "district": "Savannah-Chatham County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130102004348",
    },
    {
        "school": "7 Pillars Career Academy",
        "district": "Clayton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130123004364",
    },
    {
        "school": "Talley Street Elementary School",
        "district": "City Schools of Decatur",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130168004351",
    },
    {
        "school": "John Robert Lewis Elementary School",
        "district": "DeKalb County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130174004362",
    },
    {
        "school": "Lake Oconee Charter High School",
        "district": "Greene County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130249004341",
    },
    {
        "school": "McClure Health Science High School",
        "district": "Gwinnett County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130255004344",
    },
    {
        "school": "Jefferson County Middle School",
        "district": "Jefferson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130306004340",
    },
    {
        "school": "Eagle's Landing Academy",
        "district": "Mitchell County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130369004330",
    },
    {
        "school": "Richmond Hill K-8",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438004334",
    },
    {
        "school": "Wheeless Road Elementary School",
        "district": "Richmond County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438004342",
    },
    {
        "school": "Innovation Academy for Girls",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438004358",
    },
    {
        "school": "Innovation Academy for Boys",
        "district": "Richmond County",
        "level": "High",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130438004368",
    },
    {
        "school": "Main Elementary School",
        "district": "Rome City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "GA",
        "nces_id": "130444004356",
    },
    {
        "school": "Honouliuli Middle School",
        "district": "Hawaii Department of Education",
        "level": "Not reported",
        "type": "Regular school",
        "state": "HI",
        "nces_id": "150003000306",
    },
    {
        "school": "EMPOWER CONNECTIONS ACADEMY",
        "district": "INSPIRE ACADEMICS INC.",
        "level": "High",
        "type": "Alternative Education School",
        "state": "ID",
        "nces_id": "160001101120",
    },
    {
        "school": "MOSAICS PUBLIC SCHOOL",
        "district": "MOSAICS PUBLIC SCHOOL INC.",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160019101124",
    },
    {
        "school": "ISLAND PARK CHARTER SCHOOL",
        "district": "ISLAND PARK CHATER SCHOOL INC",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160019201125",
    },
    {
        "school": "MCCALL COMMUNITY SCHOOL",
        "district": "MCCALL COMMUNITY SCHOOL INC",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160019301121",
    },
    {
        "school": "COEUR D'ALENE EARLY CHILDHOOD LERNING CENTER",
        "district": "COEUR D'ALENE DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160078001118",
    },
    {
        "school": "COTTONWOOD ELEMENTARY",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160157001128",
    },
    {
        "school": "FARNSWORTH MIDDLE SCHOOL",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160157001131",
    },
    {
        "school": "RIGBY VIRTUAL ACADEMY",
        "district": "JEFFERSON COUNTY JOINT DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160157001132",
    },
    {
        "school": "KAMIAH EARLY CHILDHOOD CENTER",
        "district": "KAMIAH JOINT DISTRICT",
        "level": "Not reported",
        "type": "Special education school",
        "state": "ID",
        "nces_id": "160162001126",
    },
    {
        "school": "SWAN FALLS HIGH SCHOOL",
        "district": "KUNA JOINT DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160177001127",
    },
    {
        "school": "A Neil DeAtley Career Technical Education Center",
        "district": "LEWISTON INDEPENDENT DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160186001119",
    },
    {
        "school": "PLEASANT VIEW ELEMENTARY",
        "district": "JOINT SCHOOL DISTRICT NO. 2",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160210001123",
    },
    {
        "school": "ARTE I RPTCS (Regional Professional Technical Charter School",
        "district": "MINIDOKA COUNTY JOINT DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "ID",
        "nces_id": "160219001117",
    },
    {
        "school": "NAMPA ONLINE VIRTUAL ACADEMY",
        "district": "NAMPA SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160234001130",
    },
    {
        "school": "TREATY ROCK ELEMENTARY",
        "district": "POST FALLS DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ID",
        "nces_id": "160267001129",
    },
    {
        "school": "HELP Neoga",
        "district": "Eastern IL Area of Spec Educ",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170002306758",
    },
    {
        "school": "South School",
        "district": "Spec Educ Dist Lake County/Sedol",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170005906748",
    },
    {
        "school": "Bureau Valley Elementary and Junior High",
        "district": "Bureau Valley CUSD 340",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170012506750",
    },
    {
        "school": "LASSO-Medinah Primary Sch-Medinah SD 11",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206688",
    },
    {
        "school": "SSP-Roselle MS-Roselle SD 12",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206689",
    },
    {
        "school": "SSP-Spring Hills Elem-Roselle SD 12",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206697",
    },
    {
        "school": "ALSP-Medinah Inter Sch-Medinah SD 11",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206704",
    },
    {
        "school": "LASSO-Spring Hills Sch-Roselle SD 12",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206705",
    },
    {
        "school": "ALSP-Lake Park East HS-Lake Park SD 108",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Secondary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206712",
    },
    {
        "school": "ECSE AM/PM-Wood Dale Dist 7",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206715",
    },
    {
        "school": "SSP-F.E. Peacock MS-Itasca SD 10",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206718",
    },
    {
        "school": "LASSO-Tioga Elem Sch-Bensenville SD 2",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206728",
    },
    {
        "school": "LASSO-Erickson Elem-Bloomingdale Dist 13",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206737",
    },
    {
        "school": "ALSP-Fenton CHS-Fenton HSD 100",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206739",
    },
    {
        "school": "SSP Tioga Elem Sch",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206743",
    },
    {
        "school": "ALSP-F.E. Peacock MS-Itasca SD 10",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206744",
    },
    {
        "school": "ALSP-DuJardin Elem Sch-Bloomingdale SD 13",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206752",
    },
    {
        "school": "ALSP-Westfield MS-Bloomingdale SD 13",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206761",
    },
    {
        "school": "ALSP-Blackhawk MS-Bensenville SD 2",
        "district": "North DuPage Sp Ed Cooperative",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170015206765",
    },
    {
        "school": "Revive Alternative High School",
        "district": "Bnd/Chrstn/Effngh/Fytt/Mntgmr ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016506719",
    },
    {
        "school": "Phoenix Safe Schools Program",
        "district": "Bnd/Chrstn/Effngh/Fytt/Mntgmr ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170016506768",
    },
    {
        "school": "RE-Start Program",
        "district": "Champaign/Ford ROE",
        "level": "High",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170017106721",
    },
    {
        "school": "PROJECT IMPACT",
        "district": "Menard/Sangamon ROE",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "IL",
        "nces_id": "170020606764",
    },
    {
        "school": "Bi-County Sp Ed HI HS",
        "district": "Bi-County Special Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170022706767",
    },
    {
        "school": "Region III 5-8 BD Clip Prgm",
        "district": "Region III Spec Ed Coop",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170032506769",
    },
    {
        "school": "Communication Development (CD)",
        "district": "Exc Children Have Opportunities",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170138306716",
    },
    {
        "school": "Family Enrichment Program (FEP)",
        "district": "Exc Children Have Opportunities",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170138306724",
    },
    {
        "school": "Deaf & Hard of Hearing (DHH)",
        "district": "Exc Children Have Opportunities",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170138306730",
    },
    {
        "school": "EASE Program",
        "district": "Exc Children Have Opportunities",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170138306766",
    },
    {
        "school": "Transitional Employment Program",
        "district": "Southwest Cook Coop Spec Ed",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170139206755",
    },
    {
        "school": "Urban Prep West Charter School",
        "district": "Urban Prep West Charter School",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170143606756",
    },
    {
        "school": "WCSEA-Lowpoint Washburn",
        "district": "Woodford Cty Special Ed Assoc",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143706691",
    },
    {
        "school": "WCSEA-MTHS-9-12",
        "district": "Woodford Cty Special Ed Assoc",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143706695",
    },
    {
        "school": "WCSEA-Wenona-6-8",
        "district": "Woodford Cty Special Ed Assoc",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143706700",
    },
    {
        "school": "WCSEA-Minonk-K-2",
        "district": "Woodford Cty Special Ed Assoc",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143706703",
    },
    {
        "school": "WCSEA-Sowers-K-4",
        "district": "Woodford Cty Special Ed Assoc",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143706708",
    },
    {
        "school": "WCSEA Black Partridge Pub Day Prog",
        "district": "Woodford Cty Special Ed Assoc",
        "level": "Other",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143706723",
    },
    {
        "school": "WCSEA-GH-4-8",
        "district": "Woodford Cty Special Ed Assoc",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143706729",
    },
    {
        "school": "WCSEA-MGS",
        "district": "Woodford Cty Special Ed Assoc",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143706732",
    },
    {
        "school": "WCSEA-Benson",
        "district": "Woodford Cty Special Ed Assoc",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143706736",
    },
    {
        "school": "WCSEA-Riverview",
        "district": "Woodford Cty Special Ed Assoc",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143706757",
    },
    {
        "school": "Intrinsic 2 Charter High School",
        "district": "Intrinsic 2 Charter High School",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170143806763",
    },
    {
        "school": "SOWIC-EC Reed Custer",
        "district": "S Will Co Coop for Spec Ed",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906692",
    },
    {
        "school": "SOWIC-Early Childhood Channahon",
        "district": "S Will Co Coop for Spec Ed",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906693",
    },
    {
        "school": "SOWIC-Educ & Life Skills-Wilmington HS",
        "district": "S Will Co Coop for Spec Ed",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906699",
    },
    {
        "school": "SOWIC-Educ & Life Skills-Reed Custer ELEM",
        "district": "S Will Co Coop for Spec Ed",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906707",
    },
    {
        "school": "SOWIC-Comm & Adaptive Bhvr Three Rivers",
        "district": "S Will Co Coop for Spec Ed",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906711",
    },
    {
        "school": "SOWIC-EC Wilmington",
        "district": "S Will Co Coop for Spec Ed",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906722",
    },
    {
        "school": "SOWIC-Comm & Adaptive Bhvr CJH",
        "district": "S Will Co Coop for Spec Ed",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906727",
    },
    {
        "school": "SOWIC-Educ & Life Skills-Reed Custer MS",
        "district": "S Will Co Coop for Spec Ed",
        "level": "Middle",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906738",
    },
    {
        "school": "SOWIC-Com & Adaptive Bhvr NB Galloway",
        "district": "S Will Co Coop for Spec Ed",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906745",
    },
    {
        "school": "SOWIC Education Center",
        "district": "S Will Co Coop for Spec Ed",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906751",
    },
    {
        "school": "SOWIC-Comm & Adaptive Bhvr Pioneer",
        "district": "S Will Co Coop for Spec Ed",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906759",
    },
    {
        "school": "Joseph E Fisher School",
        "district": "S Will Co Coop for Spec Ed",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "170143906762",
    },
    {
        "school": "District 126 Early Childhood Center",
        "district": "Alsip-Hazlgrn-Oaklwn SD 126",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170348006690",
    },
    {
        "school": "Mary Kay McNeill Early Learning Center",
        "district": "Antioch CCSD 34",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170384006741",
    },
    {
        "school": "ACDC Penniman",
        "district": "Cahokia CUSD 187",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170804006709",
    },
    {
        "school": "Englewood STEM High School",
        "district": "City of Chicago SD 299",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006725",
    },
    {
        "school": "Ombudsman Chicago - Roseland HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006726",
    },
    {
        "school": "Pathways in Education - Humboldt Park HS",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006734",
    },
    {
        "school": "Art in Motion Charter School",
        "district": "City of Chicago SD 299",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "170993006770",
    },
    {
        "school": "Haber Oaks Campus",
        "district": "CHSD 155",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171137006754",
    },
    {
        "school": "Phoenix",
        "district": "SD U-46",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171371006698",
    },
    {
        "school": "ETHS Day School",
        "district": "Evanston Twp HSD 202",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171449006735",
    },
    {
        "school": "Franklin Elem School",
        "district": "Franklin CUSD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171575006714",
    },
    {
        "school": "Grigsby Intermediate School",
        "district": "Granite City CUSD 9",
        "level": "Middle",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171728006706",
    },
    {
        "school": "Bond County CUSD 2 Early Childhood Center",
        "district": "Bond County CUSD 2",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "171773006753",
    },
    {
        "school": "Lee Cty SpEd-ECE",
        "district": "Lee County Spec Educ Assoc",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172236006696",
    },
    {
        "school": "Lee Cty SpEd-Life Skills (2-5 Grade)",
        "district": "Lee County Spec Educ Assoc",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172236006702",
    },
    {
        "school": "Lee Cty SpEd-Life Skills (9-12 Grades)",
        "district": "Lee County Spec Educ Assoc",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172236006710",
    },
    {
        "school": "Lee Cty SpEd-Transitions",
        "district": "Lee County Spec Educ Assoc",
        "level": "High",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "172236006740",
    },
    {
        "school": "Lisle Elementary School",
        "district": "Lisle CUSD 202",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172320006747",
    },
    {
        "school": "Primary Learning Center",
        "district": "Prairie-Hills ESD 144",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172472006760",
    },
    {
        "school": "ChrisMont School",
        "district": "Nokomis CUSD 22",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "172856006733",
    },
    {
        "school": "Online Learning Academy",
        "district": "Peoria SD 150",
        "level": "Other",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123006717",
    },
    {
        "school": "Diploma Degree North Campus",
        "district": "Peoria SD 150",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123006731",
    },
    {
        "school": "Knoxville Safe School Program",
        "district": "Peoria SD 150",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173123006746",
    },
    {
        "school": "Beyer Early Childhood Center",
        "district": "Rockford SD 205",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173451006694",
    },
    {
        "school": "Springfield Learning Academy",
        "district": "Springfield SD 186",
        "level": "High",
        "type": "Regular school",
        "state": "IL",
        "nces_id": "173708006742",
    },
    {
        "school": "WCSEC-Soc Emotnl Learn Found-Elementary",
        "district": "Winnebago County Spec Educ Coop",
        "level": "Elementary",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "174281006701",
    },
    {
        "school": "WCSEC-Soc Emtlnl Learn Found-MS Program",
        "district": "Winnebago County Spec Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "174281006713",
    },
    {
        "school": "WCSEC-Intermediate Instruc Prgrm",
        "district": "Winnebago County Spec Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "174281006720",
    },
    {
        "school": "WCSEC-Primary Instructional Prgrm",
        "district": "Winnebago County Spec Educ Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "IL",
        "nces_id": "174281006749",
    },
    {
        "school": "Anderson Intermediate School",
        "district": "Anderson Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180015002682",
    },
    {
        "school": "James & Rosemary Phalen Elementary",
        "district": "James & Rosemary Phalen Elementary",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180020400838",
    },
    {
        "school": "Dynamic Minds Academy",
        "district": "Dynamic Minds Academy",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180020502673",
    },
    {
        "school": "KIPP Indy Legacy High",
        "district": "KIPP Indy Legacy High",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180020602669",
    },
    {
        "school": "Invent Learning Hub",
        "district": "Invent Learning Hub",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180020702683",
    },
    {
        "school": "Paramount Englewood",
        "district": "Paramount Englewood",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180020802655",
    },
    {
        "school": "Excel Center - Bloomington",
        "district": "Excel Center - Bloomington",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180020902675",
    },
    {
        "school": "Purdue Polytechnic High Sch North",
        "district": "Purdue Polytechnic High Sch North",
        "level": "Secondary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180021102685",
    },
    {
        "school": "Henryville Elementary School",
        "district": "Borden-Henryville School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180021201530",
    },
    {
        "school": "Henryville Jr & Sr High School",
        "district": "Borden-Henryville School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180021201531",
    },
    {
        "school": "William W Borden Elementary School",
        "district": "Borden-Henryville School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180021201539",
    },
    {
        "school": "William W Borden High School",
        "district": "Borden-Henryville School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180021201540",
    },
    {
        "school": "Silver Creek High School",
        "district": "Silver Creek School Corporation",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180021301536",
    },
    {
        "school": "Silver Creek Middle School",
        "district": "Silver Creek School Corporation",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180021301537",
    },
    {
        "school": "Silver Creek Elementary School",
        "district": "Silver Creek School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180021301538",
    },
    {
        "school": "Silver Creek Primary School",
        "district": "Silver Creek School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180021302469",
    },
    {
        "school": "Walnut Grove Elementary School",
        "district": "Center Grove Community School Corp",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180144002677",
    },
    {
        "school": "Wanamaker Early Learning Center",
        "district": "Franklin Township Com Sch Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180375002678",
    },
    {
        "school": "Gary Virtual Academy",
        "district": "Gary Community School Corp",
        "level": "Other",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180387002684",
    },
    {
        "school": "Lakeland Primary School",
        "district": "Lakeland School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180552002670",
    },
    {
        "school": "Lima-Brighton Elementary",
        "district": "Lakeland School Corporation",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180552002671",
    },
    {
        "school": "Lakeland Intermediate School",
        "district": "Lakeland School Corporation",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180552002672",
    },
    {
        "school": "Wolcott Mills Elementary School",
        "district": "Lakeland School Corporation",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180552002674",
    },
    {
        "school": "LaPorte Middle School",
        "district": "LaPorte Community School Corp",
        "level": "Middle",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180558002680",
    },
    {
        "school": "Little Cadets Preschool",
        "district": "Mill Creek Community Sch Corp",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180666002681",
    },
    {
        "school": "Indian Creek Online Academy",
        "district": "Nineveh-Hensley-Jackson United",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "180762002686",
    },
    {
        "school": "Golden Bear Preschool",
        "district": "Shelbyville Central Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181014002687",
    },
    {
        "school": "Southeastern Elementary School",
        "district": "Hamilton Southeastern Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181065002679",
    },
    {
        "school": "Greater Lafayette Career Academy",
        "district": "Tippecanoe School Corp",
        "level": "Other",
        "type": "Career and Technical School",
        "state": "IN",
        "nces_id": "181134002688",
    },
    {
        "school": "Vigo Virtual School Academy",
        "district": "Vigo County School Corp",
        "level": "High",
        "type": "Regular school",
        "state": "IN",
        "nces_id": "181209002676",
    },
    {
        "school": "Oak Hill Elementary",
        "district": "Clear Creek Amana Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190759002265",
    },
    {
        "school": "Prairie Early Childhood Center",
        "district": "College Comm School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190786002263",
    },
    {
        "school": "Virtual Campus",
        "district": "Des Moines Independent Comm School District",
        "level": "High",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "190897002268",
    },
    {
        "school": "Griswold Elementary",
        "district": "Griswold Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191323002264",
    },
    {
        "school": "Interstate 35 Middle School",
        "district": "Interstate 35 Comm School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191467002267",
    },
    {
        "school": "Herbert Hoover Elementary School",
        "district": "Iowa City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "191470002266",
    },
    {
        "school": "Harmony Elementary School",
        "district": "Van Buren County Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "192898000827",
    },
    {
        "school": "Northeast Hamilton Elementary School",
        "district": "Webster City Comm School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "IA",
        "nces_id": "193063001888",
    },
    {
        "school": "Gloria Willis Middle School",
        "district": "Kansas City",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "200795002112",
    },
    {
        "school": "Canyon Creek Elementary",
        "district": "Olathe",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201014002110",
    },
    {
        "school": "Woodland Spring Middle School",
        "district": "Spring Hill",
        "level": "Middle",
        "type": "Regular school",
        "state": "KS",
        "nces_id": "201185002111",
    },
    {
        "school": "Ashland Alternative School",
        "district": "Ashland Independent",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210015002487",
    },
    {
        "school": "Ignite Institute",
        "district": "Kentucky Tech System",
        "level": "Ungraded",
        "type": "Career and Technical School",
        "state": "KY",
        "nces_id": "210028902485",
    },
    {
        "school": "LBJ Elementary Preschool",
        "district": "Breathitt County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210069002494",
    },
    {
        "school": "Corbin Elementary",
        "district": "Corbin Independent",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210132002489",
    },
    {
        "school": "Early Learning Center",
        "district": "Erlanger-Elsmere Independent",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210174002498",
    },
    {
        "school": "Brenda Cowan Elementary",
        "district": "Fayette County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210186002486",
    },
    {
        "school": "Westport Early Childhood Center",
        "district": "Jefferson County",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210299002499",
    },
    {
        "school": "Bellevue Transitional School",
        "district": "Madison County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210372002484",
    },
    {
        "school": "Frenchburg Group Home",
        "district": "Menifee County",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210408002496",
    },
    {
        "school": "Newport School of Innovation",
        "district": "Newport Independent",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210444002493",
    },
    {
        "school": "Russellville Middle School",
        "district": "Russellville Independent",
        "level": "Middle",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210519002490",
    },
    {
        "school": "Marnel C. Moorman School",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "KY",
        "nces_id": "210532002491",
    },
    {
        "school": "Lakeview Academy",
        "district": "Taylor County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210552002495",
    },
    {
        "school": "Walton-Verona Early Childhood Center",
        "district": "Walton-Verona Independent",
        "level": "Prekindergarten",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210570002488",
    },
    {
        "school": "Jackson Academy",
        "district": "Warren County",
        "level": "Ungraded",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210573002492",
    },
    {
        "school": "Colonel Academy",
        "district": "Whitley County",
        "level": "High",
        "type": "Alternative Education School",
        "state": "KY",
        "nces_id": "210588002497",
    },
    {
        "school": "Central Southwest Alternative High School",
        "district": "Office of Juvenile Justice",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "LA",
        "nces_id": "220004702462",
    },
    {
        "school": "Bullion Primary School",
        "district": "Ascension Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220009002472",
    },
    {
        "school": "Red River Charter Academy",
        "district": "Red River Charter Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030802465",
    },
    {
        "school": "Opportunities Academy",
        "district": "Opportunities Academy",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220030902475",
    },
    {
        "school": "IDEA Oscar Dunn",
        "district": "IDEA Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220031002476",
    },
    {
        "school": "Glen Oaks Middle School",
        "district": "Glen Oaks Middle School",
        "level": "Middle",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220031102463",
    },
    {
        "school": "McDonogh 35 Senior High School",
        "district": "McDonogh 35 Senior High School",
        "level": "Secondary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220031202477",
    },
    {
        "school": "GEO Next Generation High School",
        "district": "GEO Next Generation High School",
        "level": "Secondary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220031302470",
    },
    {
        "school": "Living School",
        "district": "Living School Inc.",
        "level": "Secondary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220031402466",
    },
    {
        "school": "Capitol High School",
        "district": "RSD-Capitol Education Foundation",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220031502469",
    },
    {
        "school": "Ruppel Academie Francaise",
        "district": "Jefferson Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002464",
    },
    {
        "school": "Young Audiences Charter High School",
        "district": "Jefferson Parish",
        "level": "High",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220084002478",
    },
    {
        "school": "Dr. Raphael A. Baranco Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087002467",
    },
    {
        "school": "Martial Billeaud Elementary School",
        "district": "Lafayette Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220087002473",
    },
    {
        "school": "Bayou Blue Upper Elementary School",
        "district": "Lafourche Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220090002474",
    },
    {
        "school": "Edward Hynes Charter School (UNO Campus)",
        "district": "Orleans Parish",
        "level": "Elementary",
        "type": "Regular school",
        "state": "LA",
        "nces_id": "220117002468",
    },
    {
        "school": "Red River Academic Academy",
        "district": "Red River Parish",
        "level": "Middle",
        "type": "Alternative Education School",
        "state": "LA",
        "nces_id": "220132002471",
    },
    {
        "school": "Robert V. Connors Elementary School",
        "district": "Lewiston Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "230732023179",
    },
    {
        "school": "Saco Pre-K",
        "district": "Saco Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231038023184",
    },
    {
        "school": "Sanford Middle School",
        "district": "Sanford Public Schools",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231050023177",
    },
    {
        "school": "Vivian E Hussey School",
        "district": "RSU 60/MSAD 60",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231470023180",
    },
    {
        "school": "Hanson School",
        "district": "RSU 60/MSAD 60",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231470023185",
    },
    {
        "school": "Sebasticook Valley Elementary School",
        "district": "RSU 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478523178",
    },
    {
        "school": "Nokomis Regional Middle School",
        "district": "RSU 19",
        "level": "Middle",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478523181",
    },
    {
        "school": "Etna-Dixmont School",
        "district": "RSU 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478523182",
    },
    {
        "school": "Somerset Elementary School",
        "district": "RSU 19",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231478523183",
    },
    {
        "school": "Ecology Learning Ctr",
        "district": "Ecology Learning Center",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231484123186",
    },
    {
        "school": "Limestone Community School",
        "district": "Limestone Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "ME",
        "nces_id": "231484223169",
    },
    {
        "school": "Baltimore International Academy West",
        "district": "Baltimore City Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240009001752",
    },
    {
        "school": "Southwest EDLP at Woodlawn High School",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012001751",
    },
    {
        "school": "Watershed Public Charter",
        "district": "Baltimore County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240012001753",
    },
    {
        "school": "Northeast EDLP at Parkville High School",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012001754",
    },
    {
        "school": "Northwest EDLP at Milford Mill Academy",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012001756",
    },
    {
        "school": "Southeast EDLP at Dundalk High School",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012001759",
    },
    {
        "school": "Central EDLP at Loch Raven High School",
        "district": "Baltimore County Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MD",
        "nces_id": "240012001760",
    },
    {
        "school": "Billingsley Elementary School",
        "district": "Charles County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240027001757",
    },
    {
        "school": "Snowden Farm Elementary",
        "district": "Montgomery County Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MD",
        "nces_id": "240048001758",
    },
    {
        "school": "Career and Technical Education Evening High",
        "district": "Prince George's County Public Schools",
        "level": "Secondary",
        "type": "Career and Technical School",
        "state": "MD",
        "nces_id": "240051001755",
    },
    {
        "school": "Barnstable Community Innovation School",
        "district": "Barnstable",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250231002908",
    },
    {
        "school": "Berlin Memorial School",
        "district": "Berlin-Boylston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250258002901",
    },
    {
        "school": "Boylston Elementary School",
        "district": "Berlin-Boylston",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250258002912",
    },
    {
        "school": "Bourne Intermediate School",
        "district": "Bourne",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250282002909",
    },
    {
        "school": "Brookline Early Education Program at Clark Road",
        "district": "Brookline",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250315002904",
    },
    {
        "school": "Cohasset Middle School",
        "district": "Cohasset",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250378002910",
    },
    {
        "school": "Webster Extension",
        "district": "Everett",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250477002900",
    },
    {
        "school": "Tilton Upper Middle School",
        "district": "Haverhill",
        "level": "Middle",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597002906",
    },
    {
        "school": "Crowell",
        "district": "Haverhill",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250597002907",
    },
    {
        "school": "Leicester Integrated Preschool",
        "district": "Leicester",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250672002911",
    },
    {
        "school": "Granite Valley School",
        "district": "Monson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250804002903",
    },
    {
        "school": "Quarry Hill Community School",
        "district": "Monson",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "250804002905",
    },
    {
        "school": "The Pre-School Academy at Whitman Hanson",
        "district": "Whitman-Hanson",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MA",
        "nces_id": "251293002902",
    },
    {
        "school": "Oak Park Service Learning Academy OPSLA",
        "district": "Detroit Service Learning Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260023908945",
    },
    {
        "school": "AdamYoungs Building",
        "district": "Washington-Parks Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260095808944",
    },
    {
        "school": "Hamilton Academy",
        "district": "Detroit Public Schools Community District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260110308093",
    },
    {
        "school": "Flex High Burton",
        "district": "Flex High School of Michigan",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "260111708953",
    },
    {
        "school": "Lakeside Charter School  Albion",
        "district": "Lakeside Charter School - Albion",
        "level": "Other",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260112608888",
    },
    {
        "school": "New Hope Public School Academy",
        "district": "New Hope Public School Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260112808943",
    },
    {
        "school": "Sigma Academy for Leadership and Early Middle College",
        "district": "Sigma Academy for Leadership and Early Middle College",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260112908940",
    },
    {
        "school": "Royal Academy of Michigan",
        "district": "Royal Academy of Michigan",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260113008942",
    },
    {
        "school": "Center Line Academy",
        "district": "Center Line Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260113108964",
    },
    {
        "school": "Cassopolis Middle School",
        "district": "Cassopolis Public Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "260843008955",
    },
    {
        "school": "Dearborn Newcomer College Prep Academy",
        "district": "Dearborn City School District",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261160008962",
    },
    {
        "school": "The SER Learning Academy  East",
        "district": "Ecorse Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261293008939",
    },
    {
        "school": "Edwardsburg Alternative Learning Center",
        "district": "Edwardsburg Public Schools",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261299008956",
    },
    {
        "school": "Southwest MiddleHigh School",
        "district": "Grand Rapids Public Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261644008957",
    },
    {
        "school": "Grandville Education Center",
        "district": "Grandville Public Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MI",
        "nces_id": "261647008958",
    },
    {
        "school": "Hastings Virtual Academy",
        "district": "Hastings Area School District",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "261797008954",
    },
    {
        "school": "Center for Success at Pleasant View",
        "district": "Lansing Public School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262115008947",
    },
    {
        "school": "Young Adult Program",
        "district": "Milan Area Schools",
        "level": "Ungraded",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "262385008950",
    },
    {
        "school": "Northview Next Learning Center",
        "district": "Northview Public Schools",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262595008938",
    },
    {
        "school": "River Rouge Alternative Virtual Academy",
        "district": "River Rouge School District of the City of",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MI",
        "nces_id": "262976008952",
    },
    {
        "school": "Kent Education CenterBeltline",
        "district": "Kent ISD",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268062000888",
    },
    {
        "school": "Lincoln School",
        "district": "Kent ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268062005328",
    },
    {
        "school": "Kent Education CenterOakleigh",
        "district": "Kent ISD",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268062005335",
    },
    {
        "school": "Community Transition Campus",
        "district": "Kent ISD",
        "level": "High",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268062008363",
    },
    {
        "school": "KenOSha Home Community",
        "district": "Kent ISD",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268062008514",
    },
    {
        "school": "Pine Grove Learning Center",
        "district": "Kent ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268062008875",
    },
    {
        "school": "Lincoln Developmental Center",
        "district": "Kent ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268062008884",
    },
    {
        "school": "Kent ISD Oral Deaf",
        "district": "Kent ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268062008896",
    },
    {
        "school": "Montcalm Area ISD Transition Center",
        "district": "Montcalm Area ISD",
        "level": "Not reported",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268083008960",
    },
    {
        "school": "LAKESHORE LEARNING CENTER",
        "district": "Muskegon Area ISD",
        "level": "Other",
        "type": "Special education school",
        "state": "MI",
        "nces_id": "268085007799",
    },
    {
        "school": "Fairview",
        "district": "INTERMEDIATE SCHOOL DISTRICT 287",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002505252",
    },
    {
        "school": "Dakota County Area Learning School",
        "district": "INTERMEDIATE SCHOOL DISTRICT 917",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270002605223",
    },
    {
        "school": "ACHIEVE",
        "district": "HIAWATHA VALLEY ED. DISTRICT",
        "level": "Not reported",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270005505293",
    },
    {
        "school": "Benton-Stearns Education Pioneers",
        "district": "Benton-Stearns Education District",
        "level": "Not reported",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270007105287",
    },
    {
        "school": "SWWC Center for Transition and Care",
        "district": "Region 6 and 8-SW/WC Service Coop",
        "level": "Not reported",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270008605288",
    },
    {
        "school": "Banaadir Secondary",
        "district": "Minnesota Transitions Charter Sch",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270011705279",
    },
    {
        "school": "River's Edge Academy",
        "district": "ST. PAUL CITY SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270014205264",
    },
    {
        "school": "BIG STONE COLONY ELEMENTARY",
        "district": "CLINTON-GRACEVILLE-BEARDSLEY",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270015005276",
    },
    {
        "school": "Lismore Colony Senior High School",
        "district": "CLINTON-GRACEVILLE-BEARDSLEY",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270015005277",
    },
    {
        "school": "North Lakes Academy Elementary",
        "district": "NORTH LAKES ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270017705239",
    },
    {
        "school": "Friendship Academy of Arts - Interm",
        "district": "FRIENDSHIP ACDMY OF FINE ARTS CHTR.",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270019005280",
    },
    {
        "school": "Hiawatha Leadership Academy - SIP",
        "district": "HIAWATHA ACADEMIES",
        "level": "Elementary",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270028805226",
    },
    {
        "school": "Community School of Excellence High",
        "district": "COMMUNITY SCHOOL OF EXCELLENCE",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270030405221",
    },
    {
        "school": "Legacy KIPP Academy",
        "district": "KIPP MINNESOTA CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270030805269",
    },
    {
        "school": "KIPP Legacy Primary",
        "district": "KIPP MINNESOTA CHARTER SCHOOL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270030805286",
    },
    {
        "school": "First Step - Kingsland",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032705227",
    },
    {
        "school": "RESET",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032705231",
    },
    {
        "school": "SMEC Education Center",
        "district": "SOUTHERN MN EDUCATION CONSORTIUM",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270032705240",
    },
    {
        "school": "Sejong Academy High School",
        "district": "Sejong Academy of Minnesota",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270038605247",
    },
    {
        "school": "Foundations II",
        "district": "Sherburne and Northern Wright Speci",
        "level": "Middle",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041305259",
    },
    {
        "school": "SNW Monti MS EBD Program",
        "district": "Sherburne and Northern Wright Speci",
        "level": "Middle",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041305265",
    },
    {
        "school": "SNW Monti HS EBD Program",
        "district": "Sherburne and Northern Wright Speci",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270041305271",
    },
    {
        "school": "Southwest Metro Waseca",
        "district": "Southwest Metro Intermediate 288",
        "level": "Other",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270042005237",
    },
    {
        "school": "Waseca S W Metro",
        "district": "Southwest Metro Intermediate 288",
        "level": "Not reported",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270042005278",
    },
    {
        "school": "Chapter Journey School",
        "district": "The Journey School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270043805258",
    },
    {
        "school": "The Journey School Middle",
        "district": "The Journey School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270043805290",
    },
    {
        "school": "SciTech Academy Middle",
        "district": "SciTech Academy Charter School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270043905291",
    },
    {
        "school": "Water Lily Montessori",
        "district": "Minnesota Wildflower Montessori Sch",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270044605234",
    },
    {
        "school": "Modern Montessori Charter School",
        "district": "Modern Montessori Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270045605224",
    },
    {
        "school": "East-West International Ed Academy",
        "district": "East-West International Education A",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270045705241",
    },
    {
        "school": "East West International Secondary",
        "district": "East-West International Education A",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270045705292",
    },
    {
        "school": "St. Paul School of Northern Lights",
        "district": "St. Paul School of Northern Lights",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270045805256",
    },
    {
        "school": "Notre Ecole Academy",
        "district": "Notre Ecole Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270045905245",
    },
    {
        "school": "Metro Tech Academy",
        "district": "Metro Tech Academy Charter School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270046005249",
    },
    {
        "school": "Minneapolis School of New Music Cha",
        "district": "Minneapolis School of New Music",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270046105257",
    },
    {
        "school": "Exploration High School",
        "district": "Exploration High School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270046205233",
    },
    {
        "school": "Aspire Academy Charter School",
        "district": "Aspire Academy Charter School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270046505274",
    },
    {
        "school": "Franklin Elementary",
        "district": "Rock Ridge Public District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270046605295",
    },
    {
        "school": "Nelle Shean Elementary",
        "district": "Rock Ridge Public District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270046605296",
    },
    {
        "school": "Roosevelt Elementary",
        "district": "Rock Ridge Public District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270046605297",
    },
    {
        "school": "Eveleth-Gilbert Junior High",
        "district": "Rock Ridge Public District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270046605298",
    },
    {
        "school": "Eveleth-Gilbert Senior High",
        "district": "Rock Ridge Public District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270046605299",
    },
    {
        "school": "Eveleth-Gilbert HOPE Program",
        "district": "Rock Ridge Public District",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270046605300",
    },
    {
        "school": "Virginia Secondary",
        "district": "Rock Ridge Public District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270046605301",
    },
    {
        "school": "Parkview Elementary",
        "district": "Rock Ridge Public District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270046605302",
    },
    {
        "school": "Aris Woodwinds",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270226405238",
    },
    {
        "school": "N E Metro Independent",
        "district": "NORTHEAST METRO 916",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270226405273",
    },
    {
        "school": "Brookside Elementary",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318005266",
    },
    {
        "school": "Sunrise Elementary",
        "district": "ANOKA-HENNEPIN PUBLIC SCHOOL DIST.",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270318005272",
    },
    {
        "school": "BOLD Middle School",
        "district": "BIRD ISLAND-OLIVIA-LAKE LILLIAN",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "270566005222",
    },
    {
        "school": "Brooklyn Center 9th Grade Summer AL",
        "district": "BROOKLYN CENTER SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "270624005285",
    },
    {
        "school": "Isanti Early Childhood Special Ed",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270741005243",
    },
    {
        "school": "Cambridge Early Childhood SpecialEd",
        "district": "CAMBRIDGE-ISANTI PUBLIC SCHOOL DIST",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "270741005246",
    },
    {
        "school": "Lowell Elementary Spanish Immersion",
        "district": "DULUTH PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271104005225",
    },
    {
        "school": "East Central Early Childhood",
        "district": "EAST CENTRAL SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271108505275",
    },
    {
        "school": "Prairie View Middle School",
        "district": "Elk River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271137005253",
    },
    {
        "school": "Ranger Online",
        "district": "FOREST LAKE PUBLIC SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271227005294",
    },
    {
        "school": "East Rapids Elementary",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271317005230",
    },
    {
        "school": "West Rapids Elementary",
        "district": "GRAND RAPIDS PUBLIC SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271317005236",
    },
    {
        "school": "Laporte Middle School",
        "district": "Laporte Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271794005248",
    },
    {
        "school": "CENTRAL MIDDLE SCHOOL ALP",
        "district": "MANKATO PUBLIC SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "271878005281",
    },
    {
        "school": "Rum River Online",
        "district": "MILACA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272067005260",
    },
    {
        "school": "North Branch Area Education Center",
        "district": "NORTH BRANCH PUBLIC SCHOOLS",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272382005228",
    },
    {
        "school": "Fairview Adolescent Program 2",
        "district": "North St. Paul-Maplewood Oakdale",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "272385005289",
    },
    {
        "school": "School Readiness Plus",
        "district": "NORTHFIELD PUBLIC SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "272388005270",
    },
    {
        "school": "Onward Transition Program",
        "district": "PRINCETON PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273003005229",
    },
    {
        "school": "Early Childhood Special Education",
        "district": "PRINCETON PUBLIC SCHOOL DISTRICT",
        "level": "Prekindergarten",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "273003005232",
    },
    {
        "school": "Hamilton Ridge Elementary School",
        "district": "PRIOR LAKE-SAVAGE AREA SCHOOLS",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273006005244",
    },
    {
        "school": "JEFFERSON EL.",
        "district": "RED WING PUBLIC SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273048005284",
    },
    {
        "school": "Middle School ALC",
        "district": "ROSEMOUNT-APPLE VALLEY-EAGAN",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "273239005283",
    },
    {
        "school": "Riverview Intermediate School",
        "district": "SARTELL-ST. STEPHEN SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273282005261",
    },
    {
        "school": "Sauk Centre Middle",
        "district": "SAUK CENTRE PUBLIC SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273285005251",
    },
    {
        "school": "STMA Online",
        "district": "ST. MICHAEL-ALBERTVILLE SCHOOL DIST",
        "level": "High",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "273379005254",
    },
    {
        "school": "Falcon View Connections Academy",
        "district": "WABASHA-KELLOGG PUBLIC SCHOOL DIST.",
        "level": "Other",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274106005263",
    },
    {
        "school": "Wayzata Transition School",
        "district": "WAYZATA PUBLIC SCHOOL DISTRICT",
        "level": "High",
        "type": "Special education school",
        "state": "MN",
        "nces_id": "274216005242",
    },
    {
        "school": "Greater Minnesota Education Center",
        "district": "WILLMAR PUBLIC SCHOOL DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "274272005267",
    },
    {
        "school": "Windom Area Elementary",
        "district": "WINDOM PUBLIC SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "MN",
        "nces_id": "274278005282",
    },
    {
        "school": "River Bend ALC Credit Recovery Prog",
        "district": "RIVER BEND EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279135305268",
    },
    {
        "school": "Phoenix Recovery Programs",
        "district": "LAKE CRYSTAL-WELLCOME MEMORIAL",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279144505235",
    },
    {
        "school": "WCED Credit Recovery",
        "district": "WEST CENTRAL EDUCATION DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "MN",
        "nces_id": "279145505250",
    },
    {
        "school": "Ambition Preparatory Charter School",
        "district": "Ambition Preparatory Charter School",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019701510",
    },
    {
        "school": "BANKSTON ELEMENTARY SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801511",
    },
    {
        "school": "AMANDA ELZY HIGH SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801512",
    },
    {
        "school": "AMANDA ELZY JUNIOR HIGH SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801513",
    },
    {
        "school": "DAVIS ELEMENTARY SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801514",
    },
    {
        "school": "EAST ELEMENTARY SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801515",
    },
    {
        "school": "GREENWOOD HIGH SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801516",
    },
    {
        "school": "THREADGILL PRIMARY SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801517",
    },
    {
        "school": "LEFLORE COUNTY HIGH SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801518",
    },
    {
        "school": "LEFLORE COUNTY ELEMENTARY SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801519",
    },
    {
        "school": "CLAUDINE F BROWN ELEMENTARY SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801520",
    },
    {
        "school": "THREADGILL ELEMENTARY SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801521",
    },
    {
        "school": "GREENWOOD MIDDLE SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "MS",
        "nces_id": "280019801522",
    },
    {
        "school": "CAREER AND TECHNICAL CENTER",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "High",
        "type": "Career and Technical School",
        "state": "MS",
        "nces_id": "280019801523",
    },
    {
        "school": "LEFLORE COUNTY ALTERNATIVE SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280019801524",
    },
    {
        "school": "GREENWOOD ALTERNATIVE SCHOOL",
        "district": "GREENWOOD-LEFLORE CONS SCH DISTRICT",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "MS",
        "nces_id": "280019801525",
    },
    {
        "school": "LIFT FOR LIFE ACADEMY ELEM.",
        "district": "LIFT FOR LIFE ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290057403356",
    },
    {
        "school": "KIPP WONDER ACADEMY",
        "district": "KIPP ST LOUIS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290059103363",
    },
    {
        "school": "MIDDLE SCHOOL CAMPUS",
        "district": "CITIZENS OF THE WORLD CHARTER",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290061203365",
    },
    {
        "school": "KANSAS CITY GIRLS PREP ACADEMY",
        "district": "KANSAS CITY GIRLS PREP ACADEMY",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290061503364",
    },
    {
        "school": "KAIROS ACADEMIES",
        "district": "KAIROS ACADEMIES",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290061603362",
    },
    {
        "school": "THE SOULARD SCHOOL",
        "district": "THE SOULARD SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "290061703360",
    },
    {
        "school": "EXCELSIOR SPRINGS EAR CHLD CTR",
        "district": "EXCELSIOR SPRINGS 40",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291165003352",
    },
    {
        "school": "BERKELEY ELEMENTARY SCHOOL",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201003367",
    },
    {
        "school": "THE INNOVATION SCHOOL AT CV",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Secondary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201003371",
    },
    {
        "school": "STEAM ACADEMY MIDDLE SCHOOL",
        "district": "FERGUSON-FLORISSANT R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291201003372",
    },
    {
        "school": "GAINESVILLE PRESCHOOL",
        "district": "GAINESVILLE R-V",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291260003373",
    },
    {
        "school": "BURKE ALTERNATIVE PROGRAM",
        "district": "HICKMAN MILLS C-1",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291434003370",
    },
    {
        "school": "HIGBEE MIDDLE SCHOOL",
        "district": "HIGBEE R-VIII",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291437003357",
    },
    {
        "school": "CASSELL PARK ELEMENTARY",
        "district": "INDEPENDENCE 30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291548003366",
    },
    {
        "school": "LENS",
        "district": "KEARNEY R-I",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "291645003353",
    },
    {
        "school": "BEL-NOR",
        "district": "NORMANDY SCHOOLS COLLABORATIVE",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292265003369",
    },
    {
        "school": "WALDEN MIDDLE",
        "district": "PARK HILL",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355003359",
    },
    {
        "school": "HOPEWELL ELEMENTARY",
        "district": "PARK HILL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292355003368",
    },
    {
        "school": "PERRYVILLE PRIMARY CENTER",
        "district": "PERRY CO. 32",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292453003361",
    },
    {
        "school": "EARLY CHILDHOOD CENTER",
        "district": "SCHOOL OF THE OSAGE",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292763003358",
    },
    {
        "school": "TRI-LAKES SPECL. EDUC. COOP.",
        "district": "SHELL KNOB 78",
        "level": "Other",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292820003350",
    },
    {
        "school": "EXCEPTIONAL PUPIL COOP. - ECSE",
        "district": "STOCKTON R-I",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "292952003351",
    },
    {
        "school": "EARLY LEARNING CENTER",
        "district": "WARREN CO. R-III",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293105003355",
    },
    {
        "school": "WILLARD INTERMEDIATE-SOUTH",
        "district": "WILLARD R-II",
        "level": "Middle",
        "type": "Regular school",
        "state": "MO",
        "nces_id": "293201003354",
    },
    {
        "school": "East Helena High School",
        "district": "East Helena K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065501126",
    },
    {
        "school": "Lockwood High School",
        "district": "Lockwood K-12",
        "level": "High",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "300065601125",
    },
    {
        "school": "Hillcrest School",
        "district": "Harlowton K-12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301347000401",
    },
    {
        "school": "Hillcrest 7-8",
        "district": "Harlowton K-12",
        "level": "Middle",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301347001076",
    },
    {
        "school": "Hellgate El Primary Grades",
        "district": "Hellgate Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301386001127",
    },
    {
        "school": "South School",
        "district": "Laurel Elem",
        "level": "Elementary",
        "type": "Regular school",
        "state": "MT",
        "nces_id": "301620001124",
    },
    {
        "school": "WYANDOTTE LEARNING CENTER",
        "district": "GRAND ISLAND PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310001602399",
    },
    {
        "school": "BANNER COUNTY MIDDLE SCHOOL",
        "district": "BANNER COUNTY PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310006702395",
    },
    {
        "school": "CRETE PRESCHOOL",
        "district": "CRETE PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310009502383",
    },
    {
        "school": "CRETE SUCCESS ACADEMY",
        "district": "CRETE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310009502384",
    },
    {
        "school": "EMERSON-HUBBARD MIDDLE SCHOOL",
        "district": "EMERSON-HUBBARD PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310014102390",
    },
    {
        "school": "YOUTH CARE AND BEYOND LEARNING CENTER",
        "district": "YOUTH CARE AND BEYOND LEARNING CENTER",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "NE",
        "nces_id": "310018802388",
    },
    {
        "school": "ANCHOR POINTE ELEMENTARY",
        "district": "BENNINGTON PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310399002403",
    },
    {
        "school": "KRAMER EDUCATION CENTER",
        "district": "COLUMBUS PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "310534002397",
    },
    {
        "school": "MULLEN MIDDLE SCHOOL",
        "district": "MULLEN PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317404002405",
    },
    {
        "school": "LITTLE PANTHERS PRESCHOOL",
        "district": "NORFOLK PUBLIC SCHOOLS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317443002385",
    },
    {
        "school": "INTEGRATED LEARNING PROGRAM AT SARATOGA",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317482002391",
    },
    {
        "school": "INTEGRATED LEARNING PROGRAM AT SKINNER",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317482002393",
    },
    {
        "school": "TRANSITION PROGRAM NORTH",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "317482002396",
    },
    {
        "school": "GIFFORD ELEMENTARY SCHOOL",
        "district": "OMAHA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "317482002406",
    },
    {
        "school": "ESU 3 HEAD START - PARKVIEW HEIGHTS",
        "district": "EDUCATIONAL SERVICE UNIT 03",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318003002386",
    },
    {
        "school": "ESU 3 HEAD START - FORT CROOK",
        "district": "EDUCATIONAL SERVICE UNIT 03",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318003002389",
    },
    {
        "school": "ESU 3 HEAD START - PETER SARPY",
        "district": "EDUCATIONAL SERVICE UNIT 03",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318003002392",
    },
    {
        "school": "ESU 3 HEAD START - EARLY HEAD START",
        "district": "EDUCATIONAL SERVICE UNIT 03",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318003002394",
    },
    {
        "school": "ESU 3 HEAD START - BELLEVUE WEST",
        "district": "EDUCATIONAL SERVICE UNIT 03",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318003002398",
    },
    {
        "school": "ESU 3 HEAD START - GOLDEN HILLS",
        "district": "EDUCATIONAL SERVICE UNIT 03",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318003002400",
    },
    {
        "school": "ESU 3 HEAD START - BELLEAIRE",
        "district": "EDUCATIONAL SERVICE UNIT 03",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318003002404",
    },
    {
        "school": "ESU 7 LEARNING ACADEMY",
        "district": "EDUCATIONAL SERVICE UNIT 07",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NE",
        "nces_id": "318007002401",
    },
    {
        "school": "WESTWAY HEAD START",
        "district": "EDUCATIONAL SERVICE UNIT 13",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318013002387",
    },
    {
        "school": "NORTHFIELD HEAD START",
        "district": "EDUCATIONAL SERVICE UNIT 13",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NE",
        "nces_id": "318013002402",
    },
    {
        "school": "Signature Preparatory",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100938",
    },
    {
        "school": "Pinecrest Academy of Nevada Sloan Canyon",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100941",
    },
    {
        "school": "Nevada State High School Downtown Henderson",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100944",
    },
    {
        "school": "Nevada State High School Northwest",
        "district": "STATE-SPONSORED CHARTER SCHOOLS",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320000100948",
    },
    {
        "school": "Toland  Helen Anderson ES",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000940",
    },
    {
        "school": "Mackey Jo MS",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000945",
    },
    {
        "school": "Thompson Tyrone ES",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000946",
    },
    {
        "school": "Mountains Edge Middle School",
        "district": "CLARK COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320006000947",
    },
    {
        "school": "Esmeralda Virtual High School",
        "district": "ESMERALDA COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320015000943",
    },
    {
        "school": "MARCE HERZ MIDDLE SCHOOL",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000939",
    },
    {
        "school": "JOHN BOHACH ELEMENTARY SCHOOL",
        "district": "WASHOE COUNTY SCHOOL DISTRICT",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NV",
        "nces_id": "320048000942",
    },
    {
        "school": "North Country Charter Academy Lancaster (M)",
        "district": "North Country Charter Academy",
        "level": "Middle",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330003000737",
    },
    {
        "school": "North Country Charter Academy Lancaster (H)",
        "district": "North Country Charter Academy",
        "level": "High",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330003000738",
    },
    {
        "school": "Compass Classical Academy Charter School (H)",
        "district": "Compass Classical Academy Charter School",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330330100739",
    },
    {
        "school": "Spark Academy of Advanced Technologies Charter School",
        "district": "Spark Academy of Advanced Technologies",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330331500736",
    },
    {
        "school": "Northeast Woodland Chartered Public School",
        "district": "Northeast Woodland Chartered Public School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330331600741",
    },
    {
        "school": "Salem Preschool",
        "district": "Salem School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NH",
        "nces_id": "330606000740",
    },
    {
        "school": "Creativity CoLaboratory Charter School",
        "district": "Creativity CoLaboratory Charter School",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340080503481",
    },
    {
        "school": "Brigantine Community School",
        "district": "Brigantine Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340234003479",
    },
    {
        "school": "Collingswood Pre School at Oaklyn",
        "district": "Collingswood Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340342003485",
    },
    {
        "school": "VoTech",
        "district": "Dover Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340393003478",
    },
    {
        "school": "Central School",
        "district": "Glen Ridge Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340594003475",
    },
    {
        "school": "Academy of Career and Technical Education",
        "district": "Hudson County Schools of Technology School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "340757003468",
    },
    {
        "school": "Community",
        "district": "Lyndhurst School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "340921003471",
    },
    {
        "school": "Athletic Training and Physical Therapy",
        "district": "Morris County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341072003474",
    },
    {
        "school": "Endeavour Elementary School",
        "district": "North Hanover Township School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341158003470",
    },
    {
        "school": "Palmyra Middle School",
        "district": "Palmyra Public School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341239003483",
    },
    {
        "school": "Sonia Sotomayor School #21",
        "district": "Passaic City School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341254003487",
    },
    {
        "school": "Diana C. Lobosco STEM Academy",
        "district": "Passaic County Vocational School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "NJ",
        "nces_id": "341263003477",
    },
    {
        "school": "14# Avenue Early Learning Center",
        "district": "Paterson Public School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341269003473",
    },
    {
        "school": "A.E. Burling High School",
        "district": "Pennsauken Township Board of Education School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NJ",
        "nces_id": "341287003465",
    },
    {
        "school": "Rose M. Lopez Elementary School",
        "district": "Perth Amboy Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341293003467",
    },
    {
        "school": "Project Before at Selover School",
        "district": "Sayreville School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341464003469",
    },
    {
        "school": "Early Childhood Development Center at Garfield East",
        "district": "Willingboro Public School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NJ",
        "nces_id": "341800003489",
    },
    {
        "school": "OTERO COUNTY PRISON",
        "district": "NM CORRECTIONS",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "NM",
        "nces_id": "350001201152",
    },
    {
        "school": "NMSBVI ALBUQUERQUE CAMPUS",
        "district": "NM SCHOOL FOR THE BLIND AND VISUALLY IMPAIRED",
        "level": "Not applicable",
        "type": "Special education school",
        "state": "NM",
        "nces_id": "350001301151",
    },
    {
        "school": "NEW AMERICA SCHOOL",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001045",
    },
    {
        "school": "CORAL COMMUNITY CHARTER",
        "district": "ALBUQUERQUE PUBLIC SCHOOLS",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350006001081",
    },
    {
        "school": "RAICES DEL SABER XINACHTLI COMMUNITY SCHOOL",
        "district": "RAICES DEL SABER XINACHTLI COMMUNITY SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018401149",
    },
    {
        "school": "ACES TECHNICAL CHARTER SCHOOL",
        "district": "ACES TECHNICAL CHARTER SCHOOL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018501150",
    },
    {
        "school": "MIDDLE COLLEGE HIGH SCHOOL CHARTER - GALLUP",
        "district": "MIDDLE COLLEGE HIGH SCHOOL CHARTER - GALLUP",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350018600860",
    },
    {
        "school": "EDISON ELEMENTARY",
        "district": "CARLSBAD MUNICIPAL SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350030001154",
    },
    {
        "school": "DREAM DINE",
        "district": "CENTRAL CONSOLIDATED SCHOOLS",
        "level": "Not applicable",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350039001102",
    },
    {
        "school": "CMS IACADEMY AT LINCOLN JACKSON",
        "district": "CLOVIS MUNICIPAL SCHOOLS",
        "level": "Other",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350057001155",
    },
    {
        "school": "GCCS EARLY COLLEGE HIGH SCHOOL",
        "district": "GRANTS-CIBOLA COUNTY SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "NM",
        "nces_id": "350117001153",
    },
    {
        "school": "CATTARAUGUS COUNTY JAIL",
        "district": "CATTARAUGUS-LITTLE VALLEY CENTRAL SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360002406680",
    },
    {
        "school": "JUDITH S KAYE HIGH SCHOOL (THE)",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT # 4",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360007906603",
    },
    {
        "school": "GOTHAM PROFESSIONAL ARTS ACADEMY",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009105927",
    },
    {
        "school": "PS 915",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #13",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009106704",
    },
    {
        "school": "ASPIRATIONS DIPLOMA PLUS HIGH SCHOOL",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #17",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360009505994",
    },
    {
        "school": "PS 398",
        "district": "NEW YORK CITY GEOGRAPHIC DISTRICT #30",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360010206706",
    },
    {
        "school": "HARRIET TUBMAN RESIDENTIAL CENTER",
        "district": "NEW YORK STATE OFFICE OF CHILDREN AND FAMILY SERVICES (OCFS)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360013106699",
    },
    {
        "school": "TRUXTON ACADEMY CHARTER SCHOOL",
        "district": "TRUXTON ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360118806703",
    },
    {
        "school": "MOUNTAIN VIEW CAMPUS",
        "district": "BOQUET VALLEY CSD",
        "level": "Other",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360118900804",
    },
    {
        "school": "LAKE VIEW CAMPUS",
        "district": "BOQUET VALLEY CSD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360118904170",
    },
    {
        "school": "ACADEMY OF HEALTH SCIENCES CHARTER SCHOOL",
        "district": "ACADEMY OF HEALTH SCIENCES CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360119006669",
    },
    {
        "school": "HARLEM VILLAGE ACADEMY WEST 2 CHARTER SCHOOL",
        "district": "HARLEM VILLAGE ACADEMY WEST 2 CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360119106671",
    },
    {
        "school": "STOREFRONT ACADEMY HARLEM CHARTER SCHOOL",
        "district": "STOREFRONT ACADEMY HARLEM CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360119206705",
    },
    {
        "school": "NEIGHBORHOOD CHARTER SCHOOL - BRONX",
        "district": "NEIGHBORHOOD CHARTER SCHOOL - BRONX",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360119306672",
    },
    {
        "school": "CREO COLLEGE PREPARATORY CHARTER SCHOOL",
        "district": "CREO COLLEGE PREPARATORY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360119406693",
    },
    {
        "school": "AECI II:  NYC CHARTER HS-COMP ENGIN",
        "district": "AECI II:  NYC CHARTER HS-COMP ENGIN",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360119506687",
    },
    {
        "school": "DREAM CHARTER SCHOOL MOTT HAVEN",
        "district": "DREAM CHARTER SCHOOL MOTT HAVEN",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360119606691",
    },
    {
        "school": "UNIVERSITY PREP CHARTER MIDDLE SCHOOL",
        "district": "UNIVERSITY PREP CHARTER MIDDLE SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360119706707",
    },
    {
        "school": "BOLD CHARTER SCHOOL",
        "district": "BOLD CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360119806695",
    },
    {
        "school": "BRONX ARTS AND SCIENCE CHARTER SCHOOL",
        "district": "BRONX ARTS AND SCIENCE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360119906688",
    },
    {
        "school": "BRONX CHARTER SCHOOL FOR EXCELLENCE 5",
        "district": "BRONX CHARTER SCHOOL FOR EXCELLENCE 5",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360120006675",
    },
    {
        "school": "CARDINAL MCCLOSKEY COMMUNITY CHARTER SCHOOL",
        "district": "CARDINAL MCCLOSKEY COMMUNITY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360120106679",
    },
    {
        "school": "KIPP BRONX CHARTER SCHOOL II",
        "district": "KIPP BRONX CHARTER SCHOOL II",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360120206676",
    },
    {
        "school": "KIPP BRONX CHARTER SCHOOL III",
        "district": "KIPP BRONX CHARTER SCHOOL III",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360120306678",
    },
    {
        "school": "BROOKLYN RISE CHARTER SCHOOL",
        "district": "BROOKLYN RISE CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360120406683",
    },
    {
        "school": "LEEP DUAL LANGUAGE ACADEMY CHARTER SCHOOL",
        "district": "LEEP DUAL LANGUAGE ACADEMY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360120506696",
    },
    {
        "school": "BROOKLYN PROSPECT CHARTER SCHOOL - CSD 15.2",
        "district": "BROOKLYN PROSPECT CHARTER SCHOOL - CSD 15.2",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360120606670",
    },
    {
        "school": "LEFFERTS GARDENS ASCEND CHARTER SCHOOL (LGACS)",
        "district": "LEFFERTS GARDENS ASCEND CHARTER SCHOOL (LGACS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360120706673",
    },
    {
        "school": "EAST FLATBUSH ASCEND CHARTER SCHOOL (EFACS)",
        "district": "EAST FLATBUSH ASCEND CHARTER SCHOOL (EFACS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360120806698",
    },
    {
        "school": "IVY HILL PREPARATORY CHARTER SCHOOL",
        "district": "IVY HILL PREPARATORY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360120906701",
    },
    {
        "school": "EAST BROOKLYN ASCEND CHARTER SCHOOL (EBACS)",
        "district": "EAST BROOKLYN ASCEND CHARTER SCHOOL (EBACS)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360121006682",
    },
    {
        "school": "NEW DAWN CHARTER HIGH SCHOOL II",
        "district": "NEW DAWN CHARTER HIGH SCHOOL II",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360121106692",
    },
    {
        "school": "VALENCE COLLEGE PREPARATORY CHARTER SCHOOL",
        "district": "VALENCE COLLEGE PREPARATORY CHARTER SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360121206684",
    },
    {
        "school": "BRIDGE PREPARATORY CHARTER SCHOOL",
        "district": "BRIDGE PREPARATORY CHARTER SCHOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360121306694",
    },
    {
        "school": "HELLENIC CLASSICAL CHARTER SCHOOL - STATEN ISLAND",
        "district": "HELLENIC CLASSICAL CHARTER SCHOOL - STATEN ISLAND",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360121406686",
    },
    {
        "school": "NORTH ALBANY ACADEMY MIDDLE SCHOOL",
        "district": "ALBANY CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360246006700",
    },
    {
        "school": "ERIE COUNTY DETENTION FACILITY",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "360585006685",
    },
    {
        "school": "RESEARCH LABORATORY HS-BIOINFORMATIC",
        "district": "BUFFALO CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "360585006689",
    },
    {
        "school": "WHEELOCK PRIMARY SCHOOL",
        "district": "FREDONIA CENTRAL SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "361152006697",
    },
    {
        "school": "PERU MIDDLE SCHOOL",
        "district": "PERU CENTRAL SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362283006690",
    },
    {
        "school": "WARRIOR ACADEMY",
        "district": "SALAMANCA CITY SCHOOL DISTRICT",
        "level": "High",
        "type": "Alternative Education School",
        "state": "NY",
        "nces_id": "362544006681",
    },
    {
        "school": "STEAM AT DR KING ELEMENTARY SCHOOL",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859006674",
    },
    {
        "school": "BRIGHTON ACADEMY",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859006677",
    },
    {
        "school": "SYRACUSE STEM AT BLODGETT",
        "district": "SYRACUSE CITY SCHOOL DISTRICT",
        "level": "Middle",
        "type": "Regular school",
        "state": "NY",
        "nces_id": "362859006702",
    },
    {
        "school": "Cumberland Academy",
        "district": "Cumberland County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370001103539",
    },
    {
        "school": "C.A. Dillon - NC Learning Academy",
        "district": "NCDPS Juvenile Education Services",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370015703551",
    },
    {
        "school": "Town Creek Middle",
        "district": "Brunswick County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370042003514",
    },
    {
        "school": "Movement School Eastland",
        "district": "Movement School East",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045503536",
    },
    {
        "school": "Kaleidoscope Charter High",
        "district": "Kaleidoscope Charter High School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045603521",
    },
    {
        "school": "Wilmington School of the Arts",
        "district": "Wilmington School of the Arts",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045703522",
    },
    {
        "school": "Elaine Riddick Charter",
        "district": "Elaine Riddick Charter School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045803524",
    },
    {
        "school": "Achievement Charter Academy",
        "district": "Achievement Charter Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370045903534",
    },
    {
        "school": "North Raleigh Charter Academy",
        "district": "North Raleigh Charter Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370046003531",
    },
    {
        "school": "Davis Academy Chadbourn",
        "district": "Davis Academy Chadbourn",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370046103527",
    },
    {
        "school": "CE Academy",
        "district": "CE Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370046203529",
    },
    {
        "school": "Revolution Academy",
        "district": "Revolution Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370046303532",
    },
    {
        "school": "Doral Academy North Carolina",
        "district": "Doral Academy North Carolina",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370046403535",
    },
    {
        "school": "Cardinal Charter Acad at Wendell Falls",
        "district": "Cardinal Charter Acad at Wendell Falls",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370046503523",
    },
    {
        "school": "MINA Charter School of Lee County",
        "district": "MINA Charter School of Lee County",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370046603530",
    },
    {
        "school": "Alamance Community School",
        "district": "Alamance Community School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370046703528",
    },
    {
        "school": "Wake Preparatory Academy",
        "district": "Wake Preparatory Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370046803533",
    },
    {
        "school": "Hickory Ridge Elementary",
        "district": "Cabarrus County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053003518",
    },
    {
        "school": "Cabarrus County Schools Virtual Academy",
        "district": "Cabarrus County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370053003538",
    },
    {
        "school": "Chatham Grove Elementary",
        "district": "Chatham County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370075003516",
    },
    {
        "school": "Hayesville Primary School",
        "district": "Clay County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370087003526",
    },
    {
        "school": "Cleveland Innovation",
        "district": "Cleveland County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370090003537",
    },
    {
        "school": "Guilford eLearning Virtual School",
        "district": "Guilford County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192003540",
    },
    {
        "school": "Guilford eLearning University Prep",
        "district": "Guilford County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370192003541",
    },
    {
        "school": "Halifax County Early College High",
        "district": "Halifax County Schools",
        "level": "High",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370195003512",
    },
    {
        "school": "Harnett Virtual Academy",
        "district": "Harnett County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370201003542",
    },
    {
        "school": "Jackson Blended Learning Academy",
        "district": "Jackson County Public Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370234003544",
    },
    {
        "school": "Choice Plus Academy",
        "district": "Johnston County Public Schools",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "NC",
        "nces_id": "370237003545",
    },
    {
        "school": "Macon K-12 Virtual Academy",
        "district": "Macon County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370276003546",
    },
    {
        "school": "New Rea Farms STEM K-8 School",
        "district": "Charlotte-Mecklenburg Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370297003517",
    },
    {
        "school": "Montgomery Central High",
        "district": "Montgomery County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370306003515",
    },
    {
        "school": "Mooresville Online Academy",
        "district": "Mooresville Graded School District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370312003543",
    },
    {
        "school": "Porters Neck Elementary",
        "district": "New Hanover County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370333003520",
    },
    {
        "school": "Onslow K-12 Virtual School",
        "district": "Onslow County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370345003547",
    },
    {
        "school": "South Robeson Intermediate",
        "district": "Public Schools of Robeson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370393003511",
    },
    {
        "school": "Summit K-8 Virtual Academy",
        "district": "Rowan-Salisbury Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370405003548",
    },
    {
        "school": "South Johnson Elementary",
        "district": "Scotland County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370420003525",
    },
    {
        "school": "Stanly STEM Early College",
        "district": "Stanly County Schools",
        "level": "Secondary",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370432003513",
    },
    {
        "school": "Surry Online Magnet School",
        "district": "Surry County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370441003549",
    },
    {
        "school": "Vance Virtual Village Academy",
        "district": "Vance County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370465003550",
    },
    {
        "school": "South Lakes Elementary",
        "district": "Wake County Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "NC",
        "nces_id": "370472003519",
    },
    {
        "school": "HOPE PAGE ELEMENTARY SCHOOL",
        "district": "HOPE PAGE 85",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380040400900",
    },
    {
        "school": "HOPE PAGE HIGH SCHOOL",
        "district": "HOPE PAGE 85",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "380040400901",
    },
    {
        "school": "FOX HILLS ELEMENTARY SCHOOL",
        "district": "MCKENZIE CO 1",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381254000903",
    },
    {
        "school": "WOLVES CENTER ACADEMY",
        "district": "MCKENZIE CO 1",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381254000905",
    },
    {
        "school": "HORACE HIGH SCHOOL",
        "district": "WEST FARGO 6",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381941000902",
    },
    {
        "school": "ASB INNOVATION ACADEMY",
        "district": "WILLISTON 1",
        "level": "Not reported",
        "type": "Regular school",
        "state": "ND",
        "nces_id": "381988000904",
    },
    {
        "school": "Kenmore Preparatory Academy dba Toledo Preparatory Academy",
        "district": "Kenmore Preparatory Academy dba Toledo Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390160806010",
    },
    {
        "school": "Marion Preparatory Academy",
        "district": "Marion Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390160905999",
    },
    {
        "school": "Capital Collegiate Preparatory Academy",
        "district": "Capital Collegiate Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390161005992",
    },
    {
        "school": "North Columbus Preparatory Academy",
        "district": "North Columbus Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390161106016",
    },
    {
        "school": "Huber Heights Preparatory Academy dba Parma Academy",
        "district": "Huber Heights Preparatory Academy dba Parma Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390161206007",
    },
    {
        "school": "Northwest Ohio Classical Academy",
        "district": "Northwest Ohio Classical Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390161306015",
    },
    {
        "school": "ReGeneration Bond Hill",
        "district": "ReGeneration Bond Hill",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390161405996",
    },
    {
        "school": "Ohio Digital Learning School",
        "district": "Ohio Digital Learning School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390161506004",
    },
    {
        "school": "Urban Male Tech Academy",
        "district": "Urban Male Tech Academy",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390161606017",
    },
    {
        "school": "Cypress High School",
        "district": "Cypress High School",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390161705991",
    },
    {
        "school": "Stepping Stone Preschool",
        "district": "Brecksville-Broadview Heights City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436405995",
    },
    {
        "school": "Cambridge City Preschool",
        "district": "Cambridge City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390436906003",
    },
    {
        "school": "Northeast Ohio Impact Academy",
        "district": "Campbell City",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437006008",
    },
    {
        "school": "Clifton Area Neighborhood School",
        "district": "Cincinnati Public Schools",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390437506009",
    },
    {
        "school": "Madeira Preschool",
        "district": "Madeira City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390442806000",
    },
    {
        "school": "Marion City Schools Preschool at YMCA",
        "district": "Marion City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443305994",
    },
    {
        "school": "Marion City Schools Preschool at Marie English",
        "district": "Marion City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390443306012",
    },
    {
        "school": "McKinley STEM Academy",
        "district": "Steubenville City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390448206011",
    },
    {
        "school": "Escuela SMART Academy",
        "district": "Toledo City",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449006005",
    },
    {
        "school": "Karaffa Elementary",
        "district": "Toronto City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449106001",
    },
    {
        "school": "Vandalia-Butler Preschool",
        "district": "Vandalia-Butler City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390449506013",
    },
    {
        "school": "Choffin Preschool",
        "district": "Youngstown City",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390451605997",
    },
    {
        "school": "Olentangy Preschool at DACC",
        "district": "Olentangy Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390467605990",
    },
    {
        "school": "Reynoldsburg High School 9X Impact",
        "district": "Reynoldsburg City",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390470006014",
    },
    {
        "school": "Taylor Middle School",
        "district": "Three Rivers Local",
        "level": "Middle",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390473905993",
    },
    {
        "school": "Franklin Local Community School",
        "district": "Franklin Local",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488406002",
    },
    {
        "school": "TVMS Pre-School",
        "district": "Tri-Valley Local",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "390488705998",
    },
    {
        "school": "Tri Star Career Compact",
        "district": "Celina City",
        "level": "High",
        "type": "Regular school",
        "state": "OH",
        "nces_id": "391003006006",
    },
    {
        "school": "DOVE SCIENCE ACADEMY TULSA",
        "district": "DOVE SCHOOLS OF TULSA",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400075302890",
    },
    {
        "school": "KIPP OKC COLLEGE PREP",
        "district": "KIPP REACH COLL (CHARTER)",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400076602900",
    },
    {
        "school": "TULSA HONOR ACADEMY HS",
        "district": "HONOR ACADEMY(CHARTER)",
        "level": "Secondary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079202887",
    },
    {
        "school": "DOVE SCIENCE ACAD SOUTH OKC",
        "district": "DOVE SCIENCE ACADEMY (CHARTER)",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400079902903",
    },
    {
        "school": "NORTH ROCK CREEK INTERMEDIATE",
        "district": "NORTH ROCK CREEK",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080202908",
    },
    {
        "school": "ACADEMY OF SEMINOLE CHARTER ES",
        "district": "ACADEMY OF SEMINOLE CHARTER",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080302907",
    },
    {
        "school": "eSCHOOL VIRTUAL CHARTER HS",
        "district": "eSCHOOL VIRTUAL CHARTER ACAD",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080402899",
    },
    {
        "school": "eSCHOOL VIRTUAL CHARTER ES",
        "district": "eSCHOOL VIRTUAL CHARTER ACAD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080402901",
    },
    {
        "school": "eSCHOOL VIRTUAL CHARTER MS",
        "district": "eSCHOOL VIRTUAL CHARTER ACAD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080402904",
    },
    {
        "school": "SOVEREIGN COMMUNITY SCHL MS",
        "district": "SOVEREIGN COMMUNITY SCHOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080502886",
    },
    {
        "school": "SOVEREIGN COMMUNITY SCHL HS",
        "district": "SOVEREIGN COMMUNITY SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "400080502898",
    },
    {
        "school": "GLENPOOL INTERMEDIATE SCHOOL",
        "district": "GLENPOOL",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401272002892",
    },
    {
        "school": "GLENPOOL LOWER ES",
        "district": "GLENPOOL",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401272002896",
    },
    {
        "school": "MCLOUD INTERMEDIATE SCHOOL",
        "district": "MCLOUD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401956002882",
    },
    {
        "school": "MCLOUD EARLY CHILDHOOD CENTER",
        "district": "MCLOUD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "401956002911",
    },
    {
        "school": "MILLWOOD ARTS ACADEMY MS",
        "district": "MILLWOOD",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402008002888",
    },
    {
        "school": "6TH GRADE ACADEMY",
        "district": "MUSKOGEE",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402097002905",
    },
    {
        "school": "MUSTANG CENTRAL MS",
        "district": "MUSTANG",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402100002881",
    },
    {
        "school": "CAPITOL HILL MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002885",
    },
    {
        "school": "PUTNAM HEIGHTS ACADEMY HS",
        "district": "OKLAHOMA CITY",
        "level": "High",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002889",
    },
    {
        "school": "MARY GOLDA ROSS MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002891",
    },
    {
        "school": "SOUTHEAST MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002893",
    },
    {
        "school": "STAR SPENCER MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002894",
    },
    {
        "school": "WHEELER MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002897",
    },
    {
        "school": "ROGERS ES",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002906",
    },
    {
        "school": "PUTNAM HEIGHTS ACADEMY MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002910",
    },
    {
        "school": "MOON MS",
        "district": "OKLAHOMA CITY",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402277002912",
    },
    {
        "school": "LUCILLE ELLINGWOOD MORROW ES",
        "district": "OWASSO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402328002895",
    },
    {
        "school": "PAWHUSKA MS",
        "district": "PAWHUSKA",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402358002883",
    },
    {
        "school": "PIEDMONT EARLY CHILDHOOD CTR",
        "district": "PIEDMONT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402397002909",
    },
    {
        "school": "SILO EARLY CHILDHOOD CENTER",
        "district": "SILO",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "402764002884",
    },
    {
        "school": "WAUKOMIS MS",
        "district": "WAUKOMIS",
        "level": "Middle",
        "type": "Regular school",
        "state": "OK",
        "nces_id": "403195002902",
    },
    {
        "school": "North Star Elementary",
        "district": "Bend-LaPine Administrative SD 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410198001875",
    },
    {
        "school": "Silvies River Charter School",
        "district": "Harney County Union High SD 1J",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410363001756",
    },
    {
        "school": "Beatrice Morrow Cannady Elementary",
        "district": "North Clackamas SD 12",
        "level": "Elementary",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "410883001874",
    },
    {
        "school": "Willamette Connections Academy",
        "district": "Scio SD 95",
        "level": "Other",
        "type": "Regular school",
        "state": "OR",
        "nces_id": "411104001876",
    },
    {
        "school": "Philadelphia Hebrew Public CS",
        "district": "Philadelphia Hebrew Public CS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420090207673",
    },
    {
        "school": "MaST Community CS III",
        "district": "MaST Community CS III",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420090307674",
    },
    {
        "school": "North Brandywine MS",
        "district": "Coatesville Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420624007676",
    },
    {
        "school": "Wrightstown El Sch",
        "district": "Council Rock SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420696007679",
    },
    {
        "school": "Ephrata Intermediate Sch",
        "district": "Ephrata Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "420927007680",
    },
    {
        "school": "Lyndwood El Sch",
        "district": "Hanover Area SD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421142007678",
    },
    {
        "school": "Baron EL Sch",
        "district": "Manheim Central SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421455007677",
    },
    {
        "school": "Turtle Creek EL STEAM Academy",
        "district": "Woodland Hills SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421650007667",
    },
    {
        "school": "Woodland Hills Intermediate Sch",
        "district": "Woodland Hills SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "421650007670",
    },
    {
        "school": "Southwest MS",
        "district": "Reading SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422004007675",
    },
    {
        "school": "South Allegheny MS",
        "district": "South Allegheny SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422191007668",
    },
    {
        "school": "South Allegheny HS",
        "district": "South Allegheny SD",
        "level": "High",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422191007669",
    },
    {
        "school": "Upper Perkiomen 4th and 5th Grade Center",
        "district": "Upper Perkiomen SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422454007671",
    },
    {
        "school": "West Branch MS",
        "district": "West Branch Area SD",
        "level": "Middle",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422523007672",
    },
    {
        "school": "Homeville El Sch",
        "district": "West Mifflin Area SD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "PA",
        "nces_id": "422568007666",
    },
    {
        "school": "AF Iluminar Mayoral Middle Sch",
        "district": "Achievement First Rhode Island",
        "level": "Middle",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440002100527",
    },
    {
        "school": "Raices Dual Language Academy",
        "district": "Central Falls",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440012000529",
    },
    {
        "school": "James R. D. Oldham School",
        "district": "East Providence",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440033000532",
    },
    {
        "school": "Times2 Elementary School",
        "district": "Providence",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000528",
    },
    {
        "school": "Times2 Middle/High School",
        "district": "Providence",
        "level": "High",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440090000530",
    },
    {
        "school": "Pothier-Citizens Elem Campus",
        "district": "Woonsocket",
        "level": "Elementary",
        "type": "Regular school",
        "state": "RI",
        "nces_id": "440120000531",
    },
    {
        "school": "Broad River High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000101721",
    },
    {
        "school": "Allendale High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000101730",
    },
    {
        "school": "Kirkland High",
        "district": "Dept Of Correction N04",
        "level": "High",
        "type": "Alternative Education School",
        "state": "SC",
        "nces_id": "450000101731",
    },
    {
        "school": "Aiken Intermediate",
        "district": "Aiken 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001727",
    },
    {
        "school": "Graniteville Elementary",
        "district": "Aiken 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450072001729",
    },
    {
        "school": "R.N. Beck Child Development Center",
        "district": "Florence 01",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450213001728",
    },
    {
        "school": "Myrtle Beach Elementary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001724",
    },
    {
        "school": "Myrtle Beach Child Development Center",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001726",
    },
    {
        "school": "Myrtle Beach Primary",
        "district": "Horry 01",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450249001732",
    },
    {
        "school": "Beechwood Middle",
        "district": "Lexington 01",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450270001723",
    },
    {
        "school": "River Trail Elementary School",
        "district": "York 04",
        "level": "Not reported",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001734",
    },
    {
        "school": "Kings Town Elementary School",
        "district": "York 04",
        "level": "Not reported",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001735",
    },
    {
        "school": "Forest Creek Middle School",
        "district": "York 04",
        "level": "Not reported",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390001736",
    },
    {
        "school": "GREEN Charter School of Spartanburg",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101722",
    },
    {
        "school": "Renaissance Collegiate Academy",
        "district": "SC Public Charter School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101733",
    },
    {
        "school": "Butler Academy",
        "district": "SC Public Charter School District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390101737",
    },
    {
        "school": "Creek Bridge STEM Academy",
        "district": "Marion 10",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450390801725",
    },
    {
        "school": "Edisto Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000116",
    },
    {
        "school": "Hunter-Kinard-Tyler High",
        "district": "Orangeburg",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000196",
    },
    {
        "school": "Hunter-Kinard-Tyler Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000635",
    },
    {
        "school": "Bethune-Bowman Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000849",
    },
    {
        "school": "Bethune-Bowman Middle/High",
        "district": "Orangeburg",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000850",
    },
    {
        "school": "Holly Hill Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000853",
    },
    {
        "school": "Vance-Providence Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000855",
    },
    {
        "school": "Edisto Primary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000860",
    },
    {
        "school": "Carver Edisto Middle",
        "district": "Orangeburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000861",
    },
    {
        "school": "Edisto High",
        "district": "Orangeburg",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000862",
    },
    {
        "school": "Marshall Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000864",
    },
    {
        "school": "Brookdale Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000866",
    },
    {
        "school": "Sheridan Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000868",
    },
    {
        "school": "Whittaker Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000869",
    },
    {
        "school": "Orangeburg Wilkinson High",
        "district": "Orangeburg",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000873",
    },
    {
        "school": "Dover Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000875",
    },
    {
        "school": "North Middle/High",
        "district": "Orangeburg",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000876",
    },
    {
        "school": "Elloree Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000877",
    },
    {
        "school": "Lockett Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000879",
    },
    {
        "school": "Branchville High",
        "district": "Orangeburg",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391000880",
    },
    {
        "school": "Orangeburg Consolidated School District Five Technology Cent",
        "district": "Orangeburg",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450391000912",
    },
    {
        "school": "Lake Marion High School and Technology Center",
        "district": "Orangeburg",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391001192",
    },
    {
        "school": "Holly Hill-Roberts Middle",
        "district": "Orangeburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391001289",
    },
    {
        "school": "St. James-Gaillard Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391001290",
    },
    {
        "school": "Robert E. Howard Middle",
        "district": "Orangeburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391001291",
    },
    {
        "school": "William J. Clark Middle",
        "district": "Orangeburg",
        "level": "Middle",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391001370",
    },
    {
        "school": "OCSD5 High School for Health Professions",
        "district": "Orangeburg",
        "level": "High",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391001604",
    },
    {
        "school": "Rivelon Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391001693",
    },
    {
        "school": "Mellichamp Elementary",
        "district": "Orangeburg",
        "level": "Elementary",
        "type": "Regular school",
        "state": "SC",
        "nces_id": "450391001694",
    },
    {
        "school": "Anderson Institute of Technology",
        "district": "Anderson 81",
        "level": "High",
        "type": "Career and Technical School",
        "state": "SC",
        "nces_id": "450391101720",
    },
    {
        "school": "Teachwell Prosper - 08",
        "district": "East Dakota Educational Cooperative",
        "level": "Not reported",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "460002701406",
    },
    {
        "school": "Teachwell Elementary and Intermediate - 09",
        "district": "East Dakota Educational Cooperative",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "SD",
        "nces_id": "460002701407",
    },
    {
        "school": "Brentwood Colony Virtual High School - 92",
        "district": "Faulkton Area Schools 24-4",
        "level": "Not reported",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "462403001405",
    },
    {
        "school": "Dakota Reach - 06",
        "district": "Plankinton School District 01-1",
        "level": "Not reported",
        "type": "Special education school",
        "state": "SD",
        "nces_id": "465571001401",
    },
    {
        "school": "Lakota Tech High School - 10",
        "district": "Oglala Lakota County 65-1",
        "level": "Not reported",
        "type": "Career and Technical School",
        "state": "SD",
        "nces_id": "466546001408",
    },
    {
        "school": "Garfield Education Center - 14",
        "district": "Watertown School District 14-4",
        "level": "Not reported",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "467662001404",
    },
    {
        "school": "Platte-Geddes Cyber Middle School - 93",
        "district": "Platte - Geddes School District 11-5",
        "level": "Not reported",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043801402",
    },
    {
        "school": "Platte-Geddes Cyber High School - 92",
        "district": "Platte - Geddes School District 11-5",
        "level": "Not reported",
        "type": "Regular school",
        "state": "SD",
        "nces_id": "468043801403",
    },
    {
        "school": "Aster College Preparatory",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802581",
    },
    {
        "school": "Compass Community School Orange Mound Campus",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802582",
    },
    {
        "school": "Compass Community School Berclair Campus",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802585",
    },
    {
        "school": "Memphis Merit Academy",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802588",
    },
    {
        "school": "Compass Community School Binghampton Campus",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802589",
    },
    {
        "school": "University Middle",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802590",
    },
    {
        "school": "Compass Community School Hickory Hill Campus",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802594",
    },
    {
        "school": "Raleigh Egypt Middle School",
        "district": "Shelby County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802601",
    },
    {
        "school": "Compass Community School Frayser Campus",
        "district": "Shelby County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802605",
    },
    {
        "school": "Hamilton School",
        "district": "Shelby County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802609",
    },
    {
        "school": "Compass Community School Midtown Campus",
        "district": "Shelby County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470014802611",
    },
    {
        "school": "Forest Hill Elementary School",
        "district": "Germantown",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015102602",
    },
    {
        "school": "KIPP Antioch College Prep Middle",
        "district": "Tennessee State Board of Education",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470015502607",
    },
    {
        "school": "Candy's Creek Cherokee Elementary School",
        "district": "Cleveland",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470069002608",
    },
    {
        "school": "Sullivan Central Elementary School",
        "district": "Dickson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102002592",
    },
    {
        "school": "Burns Middle School",
        "district": "Dickson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470102002610",
    },
    {
        "school": "Howard Connect Academy",
        "district": "Hamilton County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470159002595",
    },
    {
        "school": "Lincoln Central Academy",
        "district": "Lincoln County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470249002600",
    },
    {
        "school": "Battle Creek Elementary School",
        "district": "Maury County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276002596",
    },
    {
        "school": "Battle Creek Middle School",
        "district": "Maury County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470276002598",
    },
    {
        "school": "McNairy County Virtual School",
        "district": "McNairy County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470288002606",
    },
    {
        "school": "Salem Elementary School",
        "district": "Murfreesboro",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470315002591",
    },
    {
        "school": "Perry County Virtual School",
        "district": "Perry County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470339002586",
    },
    {
        "school": "Polk Innovative Learning Academy",
        "district": "Polk County",
        "level": "Other",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470345002599",
    },
    {
        "school": "Tennessee Connections Academy 9-12",
        "district": "Robertson County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360002583",
    },
    {
        "school": "Tennessee Connections Academy K-8",
        "district": "Robertson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470360002597",
    },
    {
        "school": "Rockvale High School",
        "district": "Rutherford County",
        "level": "High",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002580",
    },
    {
        "school": "Rocky Fork Elementary School",
        "district": "Rutherford County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470369002584",
    },
    {
        "school": "Sullivan East Middle School",
        "district": "Sullivan County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470399002604",
    },
    {
        "school": "Boones Creek Elementary School",
        "district": "Washington County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470438002603",
    },
    {
        "school": "Creekside Elementary School",
        "district": "Williamson County",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470453002587",
    },
    {
        "school": "Gladeville Middle School",
        "district": "Wilson County",
        "level": "Middle",
        "type": "Regular school",
        "state": "TN",
        "nces_id": "470455002593",
    },
    {
        "school": "EL #5",
        "district": "DRIPPING SPRINGS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480000813978",
    },
    {
        "school": "UPLIFT ELEVATE PREPARATORY SCHOOL",
        "district": "UPLIFT EDUCATION",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003013926",
    },
    {
        "school": "THE LINGUISTIC ACAD OF EL PASO-CULTURAL DEMO SITE",
        "district": "BURNHAM WOOD CHARTER SCHOOL DISTRICT",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480003713938",
    },
    {
        "school": "HORIZON MONTESSORI - PEARLAND",
        "district": "HORIZON MONTESSORI PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480006513976",
    },
    {
        "school": "CLEARFORK ACADEMY",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007113999",
    },
    {
        "school": "SAFE HAVEN",
        "district": "UNIVERSITY OF TEXAS UNIVERSITY CHARTER SCHOOL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480007114014",
    },
    {
        "school": "EL PASO CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313959",
    },
    {
        "school": "WESTCHASE CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313964",
    },
    {
        "school": "FOUNDERS CLASSICAL ACADEMY - ROCKWALL",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313985",
    },
    {
        "school": "EASTEX-JENSEN CLASSICAL ACADEMY",
        "district": "TEXAS COLLEGE PREPARATORY ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480016313987",
    },
    {
        "school": "JUBILEE ACADEMIES MIDDLE",
        "district": "JUBILEE ACADEMIES",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017913866",
    },
    {
        "school": "JUBILEE SENDERO",
        "district": "JUBILEE ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017913941",
    },
    {
        "school": "JUBILEE WESTWOOD",
        "district": "JUBILEE ACADEMIES",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480017913946",
    },
    {
        "school": "FOUNDATION SCHOOL OF AUTISM - SAN ANTONIO",
        "district": "PREMIER HIGH SCHOOLS",
        "level": "Elementary",
        "type": "Special education school",
        "state": "TX",
        "nces_id": "480020713927",
    },
    {
        "school": "YES PREP - HOBBY",
        "district": "YES PREP PUBLIC SCHOOLS INC",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480020913939",
    },
    {
        "school": "IDEA HARDY ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113950",
    },
    {
        "school": "IDEA RISE COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113953",
    },
    {
        "school": "IDEA HEALTH PROFESSIONS ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113954",
    },
    {
        "school": "IDEA PARMER PARK COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113960",
    },
    {
        "school": "IDEA ROBINDALE COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113965",
    },
    {
        "school": "IDEA BURKE COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113971",
    },
    {
        "school": "IDEA SPEARS ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113974",
    },
    {
        "school": "IDEA HARDY COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113979",
    },
    {
        "school": "IDEA HEALTH PROFESSIONS COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113982",
    },
    {
        "school": "IDEA SPEARS COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113984",
    },
    {
        "school": "IDEA LOS ENCINOS COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113988",
    },
    {
        "school": "IDEA ACHIEVE COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113994",
    },
    {
        "school": "IDEA BURKE ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113995",
    },
    {
        "school": "IDEA PARMER PARK ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021113998",
    },
    {
        "school": "IDEA MESA HILLS ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021114003",
    },
    {
        "school": "IDEA ROBINDALE ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021114008",
    },
    {
        "school": "IDEA RISE ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021114013",
    },
    {
        "school": "IDEA LOS ENCINOS ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021114016",
    },
    {
        "school": "IDEA MESA HILLS COLLEGE PREPARATORY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021114018",
    },
    {
        "school": "IDEA ACHIEVE ACADEMY",
        "district": "IDEA PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480021114020",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY SPRING",
        "district": "SCHOOL OF SCIENCE AND TECHNOLOGY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480025813925",
    },
    {
        "school": "TRINITY CHARTER SCHOOLS - FORT WORTH CAMPUS",
        "district": "TRINITY CHARTER SCHOOL",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480025913891",
    },
    {
        "school": "THE LANDING AT CORPUS CHRISTI",
        "district": "TRINITY CHARTER SCHOOL",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480025913899",
    },
    {
        "school": "KIPP JOURNEY PRI",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413967",
    },
    {
        "school": "KIPP SOMOS H S",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413986",
    },
    {
        "school": "KIPP JOURNEY COLLEGIATE SCHOOL",
        "district": "KIPP TEXAS PUBLIC SCHOOLS",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480026413990",
    },
    {
        "school": "HARMONY SCHOOL OF SCIENCE - EL PASO",
        "district": "HARMONY SCIENCE ACAD (EL PASO)",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480027213908",
    },
    {
        "school": "BUCKNER PREPARATORY",
        "district": "CITYSCAPE SCHOOLS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480028813864",
    },
    {
        "school": "SCHOOL OF SCIENCE AND TECHNOLOGY HILL COUNTRY",
        "district": "SCHOOL OF SCIENCE AND TECHNOLOGY DISCOVERY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480140013931",
    },
    {
        "school": "AUSTIN ACHIEVE H S",
        "district": "AUSTIN ACHIEVE PUBLIC SCHOOLS",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480143113981",
    },
    {
        "school": "GREAT HEARTS IRVING UPPER",
        "district": "GREAT HEARTS TEXAS",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144113888",
    },
    {
        "school": "GREAT HEARTS FOREST HEIGHTS",
        "district": "GREAT HEARTS TEXAS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144113902",
    },
    {
        "school": "THE EXCEL CENTER FOR ADULTS AYW",
        "district": "THE EXCEL CENTER (FOR ADULTS)",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480144813951",
    },
    {
        "school": "BILLY MOORE",
        "district": "THE EXCEL CENTER (FOR ADULTS)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480144813955",
    },
    {
        "school": "BRADSHAW",
        "district": "THE EXCEL CENTER (FOR ADULTS)",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480144813996",
    },
    {
        "school": "PIONEER TECHNOLOGY (PTAA) MESQUITE EL",
        "district": "PIONEER TECHNOLOGY & ARTS ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145113916",
    },
    {
        "school": "PIONEER TECHNOLOGY (PTAA) ROYSE CITY EL",
        "district": "PIONEER TECHNOLOGY & ARTS ACADEMY",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480145113923",
    },
    {
        "school": "HOUSTON CLASSICAL",
        "district": "HOUSTON CLASSICAL CHARTER SCHOOL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480146913863",
    },
    {
        "school": "ELEVATE COLLEGIATE",
        "district": "ELEVATE COLLEGIATE CHARTER SCHOOL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480147013942",
    },
    {
        "school": "TGP PUBLIC SCHOOL",
        "district": "THE GATHERING PLACE",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480147113945",
    },
    {
        "school": "SAN ANTONIO PREPARATORY",
        "district": "SAN ANTONIO PREPARATORY CHARTER SCHOOL",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480147213875",
    },
    {
        "school": "UNIVERSITY OF TEXAS AT AUSTIN H S",
        "district": "UNIVERSITY OF TEXAS AT AUSTIN H S",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480147313991",
    },
    {
        "school": "GARCIA EARLY CHILDHOOD CENTER",
        "district": "ALICE ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480780014012",
    },
    {
        "school": "NEW EL #122",
        "district": "ALVIN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809013879",
    },
    {
        "school": "NEW EL #121",
        "district": "ALVIN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480809013933",
    },
    {
        "school": "ANNA ISD DAEP",
        "district": "ANNA ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480834013928",
    },
    {
        "school": "FERGUSON EDUCATION CENTER",
        "district": "ARLINGTON ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "480870014006",
    },
    {
        "school": "JACKIE FULLER EL",
        "district": "AUBREY ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480891013884",
    },
    {
        "school": "BELTON MIDDLE",
        "district": "BELTON ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986013921",
    },
    {
        "school": "LAKE BELTON H S",
        "district": "BELTON ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "480986013935",
    },
    {
        "school": "DAVINCI",
        "district": "BROOKESMITH ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481155013892",
    },
    {
        "school": "QUEST",
        "district": "BROOKESMITH ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481155013898",
    },
    {
        "school": "FALFURRIAS INNOVATION ACADEMY",
        "district": "BROOKS COUNTY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481158013895",
    },
    {
        "school": "NORTH STAR H S",
        "district": "CENTER POINT ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "481335013963",
    },
    {
        "school": "NEW EL #19",
        "district": "COMAL ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473013887",
    },
    {
        "school": "NEW EL #20",
        "district": "COMAL ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481473013896",
    },
    {
        "school": "FLEX #21",
        "district": "CONROE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500013958",
    },
    {
        "school": "FLEX #20",
        "district": "CONROE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500013989",
    },
    {
        "school": "NEW J H",
        "district": "CONROE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481500014004",
    },
    {
        "school": "JUNE W DAVIS EL",
        "district": "CROWLEY ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481591013957",
    },
    {
        "school": "MI ESCUELITA-GOOD SHEPHERD",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013862",
    },
    {
        "school": "DOWNTOWN MONTESSORI",
        "district": "DALLAS ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013873",
    },
    {
        "school": "CHILDCAREGROUP-MARTIN LUTHER KING",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013880",
    },
    {
        "school": "BRYAN'S HOUSE",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013889",
    },
    {
        "school": "CHILDCAREGROUP-WEST DALLAS",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013890",
    },
    {
        "school": "GOOD STREET LEARNING CENTER",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013897",
    },
    {
        "school": "HEAVENLY LEARNING CENTER",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013904",
    },
    {
        "school": "MI ESCUELITA-CASA VIEW",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013906",
    },
    {
        "school": "MI ESCUELITA-COCKRELL HILL",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013914",
    },
    {
        "school": "NORTH LAKE EARLY COLLEGE H S",
        "district": "DALLAS ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013924",
    },
    {
        "school": "CHILDCAREGROUP-LANDAUER",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013934",
    },
    {
        "school": "MI ESCUELITA-CROSSOVER",
        "district": "DALLAS ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481623013944",
    },
    {
        "school": "DONNA EARLY COLLEGE H S",
        "district": "DONNA ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481739014005",
    },
    {
        "school": "COPPER CREEK EL",
        "district": "EAGLE MT-SAGINAW ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481770013980",
    },
    {
        "school": "EAST CENTRAL CAST LEAD H S",
        "district": "EAST CENTRAL ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785013877",
    },
    {
        "school": "SALADO EL",
        "district": "EAST CENTRAL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481785013919",
    },
    {
        "school": "GARDENDALE PRE-K 4 SA EARLY LEARNING",
        "district": "EDGEWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815013885",
    },
    {
        "school": "PRE-K 4 SAN ANTONIO",
        "district": "EDGEWOOD ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481815013893",
    },
    {
        "school": "DR JOSEPH TORRES EL",
        "district": "EL PASO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481830013868",
    },
    {
        "school": "ELGIN INT",
        "district": "ELGIN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481836013912",
    },
    {
        "school": "NEW MIDDLE #16",
        "district": "FORT BEND ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965013865",
    },
    {
        "school": "NEW EL #52",
        "district": "FORT BEND ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965013907",
    },
    {
        "school": "NEW EL #53",
        "district": "FORT BEND ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965013913",
    },
    {
        "school": "NEW EL ELC #2",
        "district": "FORT BEND ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965013920",
    },
    {
        "school": "NEW H S #12",
        "district": "FORT BEND ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "481965013932",
    },
    {
        "school": "H S #11",
        "district": "FRISCO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482001013915",
    },
    {
        "school": "WILLIAMS EL",
        "district": "GEORGETOWN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482060014001",
    },
    {
        "school": "UPLIFT LEE SECONDARY AT UPLIFT GRAND",
        "district": "GRAND PRAIRIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482142013867",
    },
    {
        "school": "GREENWOOD INT",
        "district": "GREENWOOD ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482175014010",
    },
    {
        "school": "HARTS BLUFF EARLY COLLEGE H S",
        "district": "HARTS BLUFF ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482271013961",
    },
    {
        "school": "TIERRA BLANCA EARLY CHILDHOOD CENTER",
        "district": "HEREFORD ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482301013910",
    },
    {
        "school": "MICHAEL M BOONE EL",
        "district": "HIGHLAND PARK ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482325013937",
    },
    {
        "school": "HOWE INT",
        "district": "HOWE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482367013900",
    },
    {
        "school": "IGO EL",
        "district": "JARRELL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482460013973",
    },
    {
        "school": "EARLY LEARNING CENTER - EAST",
        "district": "KELLER ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482526013969",
    },
    {
        "school": "EL145",
        "district": "KILLEEN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482566013869",
    },
    {
        "school": "DR THOMAS E RANDLE H S",
        "district": "LAMAR CISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658013860",
    },
    {
        "school": "HARRY WRIGHT J H",
        "district": "LAMAR CISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482658013886",
    },
    {
        "school": "SANTA RITA EL",
        "district": "LIBERTY HILL ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482742014017",
    },
    {
        "school": "CREEKSIDE EL",
        "district": "LIVINGSTON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482778013956",
    },
    {
        "school": "LONDON INT",
        "district": "LONDON ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482799013983",
    },
    {
        "school": "CHARLENE MCKINZEY MIDDLE",
        "district": "MANSFIELD ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892013975",
    },
    {
        "school": "ALMA MARTINEZ INT",
        "district": "MANSFIELD ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892013992",
    },
    {
        "school": "BRENDA NORWOOD EL",
        "district": "MANSFIELD ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482892014002",
    },
    {
        "school": "MARSHALL EARLY GRADUATION SCHOOL",
        "district": "MARSHALL ISD",
        "level": "High",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482916013949",
    },
    {
        "school": "MAYPEARL PRI",
        "district": "MAYPEARL ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "482958013874",
    },
    {
        "school": "MCDADE JJAEP",
        "district": "MCDADE ISD",
        "level": "Secondary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "482976013948",
    },
    {
        "school": "MELISSA RIDGE EDUCATION CENTER",
        "district": "MELISSA ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483012013917",
    },
    {
        "school": "IDEA TRAVIS ACADEMY",
        "district": "MIDLAND ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057013952",
    },
    {
        "school": "YOUNG WOMEN'S LEADERSHIP ACADEMY",
        "district": "MIDLAND ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057013970",
    },
    {
        "school": "PRE-K ACADEMY AT MIDLAND COLLEGE",
        "district": "MIDLAND ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483057013997",
    },
    {
        "school": "PRE-K ACADEMY AT WEST AVENUE",
        "district": "NORTH EAST ISD",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483294013947",
    },
    {
        "school": "ALTERNATIVE EL",
        "district": "NORTHSIDE ISD",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "483312013872",
    },
    {
        "school": "VILLAGE AT WESTPOINTE (NORTH) EL",
        "district": "NORTHSIDE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312013882",
    },
    {
        "school": "GALM ROAD AREA H S",
        "district": "NORTHSIDE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312013905",
    },
    {
        "school": "FM 471 N AREA #4 EL",
        "district": "NORTHSIDE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483312013918",
    },
    {
        "school": "NEW MIDDLE",
        "district": "PFLUGERVILLE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483013972",
    },
    {
        "school": "NEW EL",
        "district": "PFLUGERVILLE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483483014000",
    },
    {
        "school": "NELLIE CANUP",
        "district": "PRINCETON ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483585013936",
    },
    {
        "school": "SAM JOHNSON EL",
        "district": "PROSPER ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013861",
    },
    {
        "school": "NEW H S #3",
        "district": "PROSPER ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013870",
    },
    {
        "school": "WILLIAM RUSHING MIDDLE",
        "district": "PROSPER ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483600013903",
    },
    {
        "school": "BOBBY SUMMERS MIDDLE",
        "district": "ROYSE CITY ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483822013962",
    },
    {
        "school": "RUTH CHERRY EL",
        "district": "ROYSE CITY ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483822014011",
    },
    {
        "school": "HARRY HERNDON EL",
        "district": "ROYSE CITY ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483822014015",
    },
    {
        "school": "CAST MED H S",
        "district": "SAN ANTONIO ISD",
        "level": "Secondary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013894",
    },
    {
        "school": "YOUNG WOMEN'S LEADERSHIP ACADEMY PRI AT PAGE",
        "district": "SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483873013930",
    },
    {
        "school": "NEW EL",
        "district": "SAN FELIPE-DEL RIO CISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "483890013968",
    },
    {
        "school": "SHERMAN MIDDLE",
        "district": "SHERMAN ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484008013943",
    },
    {
        "school": "ABRAHAM KAZEN MIDDLE",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068013878",
    },
    {
        "school": "ATHENS EL",
        "district": "SOUTH SAN ANTONIO ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484068013929",
    },
    {
        "school": "NEW EL",
        "district": "SOCORRO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071013911",
    },
    {
        "school": "NEW MIDDLE",
        "district": "SOCORRO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484071013922",
    },
    {
        "school": "SOMERVILLE INT",
        "district": "SOMERVILLE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484077013871",
    },
    {
        "school": "TRINITY ALTERNATIVE EDUCATION",
        "district": "SOUTHSIDE ISD",
        "level": "Not reported",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484092013881",
    },
    {
        "school": "TIMBER LAKES EL",
        "district": "SPLENDORA ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484107013977",
    },
    {
        "school": "SUNNYVALE INT",
        "district": "SUNNYVALE ISD",
        "level": "Elementary",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484188013940",
    },
    {
        "school": "ESCHOOL PREP",
        "district": "TEXARKANA ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484248013901",
    },
    {
        "school": "CROSSROADS ACADEMY",
        "district": "UVALDE CISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484372014019",
    },
    {
        "school": "MAX H SIMPSON EL",
        "district": "WAXAHACHIE ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484473013909",
    },
    {
        "school": "WINNSBORO MEMORIAL INT",
        "district": "WINNSBORO ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484620014009",
    },
    {
        "school": "WINTERS/FAIRVIEW DAEP",
        "district": "WINTERS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484626013966",
    },
    {
        "school": "WINTERS/FAIRVIEW AEP",
        "district": "WINTERS ISD",
        "level": "High",
        "type": "Alternative Education School",
        "state": "TX",
        "nces_id": "484626013993",
    },
    {
        "school": "WYLIE EAST J H",
        "district": "WYLIE ISD",
        "level": "Middle",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484650014007",
    },
    {
        "school": "RIVERSIDE EL",
        "district": "YSLETA ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668013876",
    },
    {
        "school": "J M HANKS MIDDLE",
        "district": "YSLETA ISD",
        "level": "Not reported",
        "type": "Regular school",
        "state": "TX",
        "nces_id": "484668013883",
    },
    {
        "school": "Beehive Science & Technology Academy Elementary",
        "district": "Beehive Science & Technology Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490002301570",
    },
    {
        "school": "Polaris West High",
        "district": "Alpine District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001553",
    },
    {
        "school": "Centennial Elementary",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001573",
    },
    {
        "school": "Liberty Hills Elementary",
        "district": "Alpine District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001574",
    },
    {
        "school": "Lake Mountain Middle",
        "district": "Alpine District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490003001575",
    },
    {
        "school": "Monticello Academy West Point",
        "district": "Monticello Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490004901556",
    },
    {
        "school": "USD Online",
        "district": "Utah Schools for Deaf & Blind",
        "level": "High",
        "type": "Special education school",
        "state": "UT",
        "nces_id": "490006901572",
    },
    {
        "school": "Utah Mountain",
        "district": "Utah Mountain",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490020101557",
    },
    {
        "school": "Bridge Elementary School",
        "district": "Bridge Elementary School",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490020201566",
    },
    {
        "school": "Mountain Sunrise Academy",
        "district": "Mountain Sunrise Academy",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490020301565",
    },
    {
        "school": "Shoreline Junior High",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001569",
    },
    {
        "school": "Davis Connect 7-8",
        "district": "Davis District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490021001571",
    },
    {
        "school": "Launch High",
        "district": "Iron District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490039001562",
    },
    {
        "school": "Village 8 Daybreak",
        "district": "Jordan District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490042001568",
    },
    {
        "school": "Mountain Green Middle",
        "district": "Morgan District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490057001554",
    },
    {
        "school": "Mountain Green Preschool",
        "district": "Morgan District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490057001567",
    },
    {
        "school": "Spring Canyon Middle",
        "district": "Nebo District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001558",
    },
    {
        "school": "Maple Grove Middle",
        "district": "Nebo District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001560",
    },
    {
        "school": "Valley View Middle",
        "district": "Nebo District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001561",
    },
    {
        "school": "Mt. Nebo Middle",
        "district": "Nebo District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001563",
    },
    {
        "school": "Diamond Fork Middle",
        "district": "Nebo District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490063001564",
    },
    {
        "school": "Washington Fields Intermediate",
        "district": "Washington District",
        "level": "Middle",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001555",
    },
    {
        "school": "Crimson Cliffs High",
        "district": "Washington District",
        "level": "High",
        "type": "Regular school",
        "state": "UT",
        "nces_id": "490114001559",
    },
    {
        "school": "Brattleboro Union High School",
        "district": "Windham Southeast Unified Union School District #96",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043100051",
    },
    {
        "school": "Canal Street/Oak Grove Schools",
        "district": "Windham Southeast Unified Union School District #96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043100056",
    },
    {
        "school": "Green Street School",
        "district": "Windham Southeast Unified Union School District #96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043100061",
    },
    {
        "school": "Academy School",
        "district": "Windham Southeast Unified Union School District #96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043100079",
    },
    {
        "school": "Windham Regional Career Center",
        "district": "Windham Southeast Unified Union School District #96",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500043100102",
    },
    {
        "school": "Guilford Central School",
        "district": "Windham Southeast Unified Union School District #96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043100144",
    },
    {
        "school": "Putney Central School",
        "district": "Windham Southeast Unified Union School District #96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043100249",
    },
    {
        "school": "Dummerston Schools",
        "district": "Windham Southeast Unified Union School District #96",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043100430",
    },
    {
        "school": "Brattleboro Area Middle School",
        "district": "Windham Southeast Unified Union School District #96",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043100485",
    },
    {
        "school": "Leland & Gray Union Middle & High School",
        "district": "West River Valley Modified Union Education District #72B",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043200173",
    },
    {
        "school": "Swanton Schools",
        "district": "Missisquoi Valley School District #89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043300049",
    },
    {
        "school": "Franklin Central School",
        "district": "Missisquoi Valley School District #89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043300135",
    },
    {
        "school": "Missisquoi Valley Union High School",
        "district": "Missisquoi Valley School District #89",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043300195",
    },
    {
        "school": "Highgate School",
        "district": "Missisquoi Valley School District #89",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043300434",
    },
    {
        "school": "Bennington Elementary School",
        "district": "Southwest Vermont Union Elementary School District #87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043400028",
    },
    {
        "school": "Molly Stark School",
        "district": "Southwest Vermont Union Elementary School District #87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043400031",
    },
    {
        "school": "Monument School",
        "district": "Southwest Vermont Union Elementary School District #87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043400032",
    },
    {
        "school": "Pownal Elementary School",
        "district": "Southwest Vermont Union Elementary School District #87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043400246",
    },
    {
        "school": "Shaftsbury Elementary School",
        "district": "Southwest Vermont Union Elementary School District #87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043400282",
    },
    {
        "school": "Woodford Hollow School",
        "district": "Southwest Vermont Union Elementary School District #87",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043400393",
    },
    {
        "school": "Grand Isle Elementary School",
        "district": "Champlain Islands Unified Union School District #66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043500140",
    },
    {
        "school": "Isle La Motte Elementary School",
        "district": "Champlain Islands Unified Union School District #66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043500164",
    },
    {
        "school": "North Hero Elementary School",
        "district": "Champlain Islands Unified Union School District #66",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043500221",
    },
    {
        "school": "Barton Graded School",
        "district": "Lake Region Union Elementary Middle School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043600025",
    },
    {
        "school": "Brownington Central School",
        "district": "Lake Region Union Elementary Middle School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043600059",
    },
    {
        "school": "Glover Village School",
        "district": "Lake Region Union Elementary Middle School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043600137",
    },
    {
        "school": "Irasburg Village School",
        "district": "Lake Region Union Elementary Middle School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043600163",
    },
    {
        "school": "Orleans Elementary School",
        "district": "Lake Region Union Elementary Middle School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043600232",
    },
    {
        "school": "Albany Community School",
        "district": "Lake Region Union Elementary Middle School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043600420",
    },
    {
        "school": "Bradford Elementary School",
        "district": "Oxbow Unified Union School District #91",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043700039",
    },
    {
        "school": "River Bend Career & Technical Center",
        "district": "Oxbow Unified Union School District #91",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500043700118",
    },
    {
        "school": "Newbury Elementary School",
        "district": "Oxbow Unified Union School District #91",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043700213",
    },
    {
        "school": "Oxbow Union High School",
        "district": "Oxbow Unified Union School District #91",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043709272",
    },
    {
        "school": "Hardwick Elementary School",
        "district": "Orleans Southwest Union Elementary School District #94",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043800147",
    },
    {
        "school": "Woodbury Elementary School",
        "district": "Orleans Southwest Union Elementary School District #94",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043800392",
    },
    {
        "school": "Lakeview USD #43",
        "district": "Orleans Southwest Union Elementary School District #94",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043800461",
    },
    {
        "school": "Berlin Elementary School",
        "district": "Washington Central Unified Union School District #92",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043900035",
    },
    {
        "school": "Calais Elementary School",
        "district": "Washington Central Unified Union School District #92",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043900076",
    },
    {
        "school": "East Montpelier Elementary School",
        "district": "Washington Central Unified Union School District #92",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043900110",
    },
    {
        "school": "Rumney School (Middlesex)",
        "district": "Washington Central Unified Union School District #92",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043900190",
    },
    {
        "school": "U-32 Middle & High School",
        "district": "Washington Central Unified Union School District #92",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043900339",
    },
    {
        "school": "Doty Memorial School",
        "district": "Washington Central Unified Union School District #92",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500043900396",
    },
    {
        "school": "Benson Village School",
        "district": "Slate Valley Unified Union School District #62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044000033",
    },
    {
        "school": "Fair Haven Grade School",
        "district": "Slate Valley Unified Union School District #62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044000126",
    },
    {
        "school": "Fair Haven Union High School",
        "district": "Slate Valley Unified Union School District #62",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044000127",
    },
    {
        "school": "Orwell Village School",
        "district": "Slate Valley Unified Union School District #62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044000233",
    },
    {
        "school": "Castleton Elementary School",
        "district": "Slate Valley Unified Union School District #62",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044000542",
    },
    {
        "school": "Castleton Village School",
        "district": "Slate Valley Unified Union School District #62",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044000546",
    },
    {
        "school": "Bakersfield School",
        "district": "Northern Mountain Valley Unified Union School District #85",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044100009",
    },
    {
        "school": "Berkshire Elementary School",
        "district": "Northern Mountain Valley Unified Union School District #85",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044100034",
    },
    {
        "school": "Montgomery Center School",
        "district": "Northern Mountain Valley Unified Union School District #85",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044100197",
    },
    {
        "school": "Sheldon Elementary School",
        "district": "Northern Mountain Valley Unified Union School District #85",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044100286",
    },
    {
        "school": "Albert Bridge School (West Windsor)",
        "district": "Mount Ascutney School District #86",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044200371",
    },
    {
        "school": "Windsor School",
        "district": "Mount Ascutney School District #86",
        "level": "Other",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044200539",
    },
    {
        "school": "Smilie Memorial Elementary School",
        "district": "Mount Mansfield Unified Union School District #401",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044300038",
    },
    {
        "school": "Brewster Pierce School",
        "district": "Mount Mansfield Unified Union School District #401",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044300160",
    },
    {
        "school": "Jericho Elementary School",
        "district": "Mount Mansfield Unified Union School District #401",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044300167",
    },
    {
        "school": "Mt Mansfield Union High School",
        "district": "Mount Mansfield Unified Union School District #401",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044300210",
    },
    {
        "school": "Richmond Elementary School",
        "district": "Mount Mansfield Unified Union School District #401",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044300258",
    },
    {
        "school": "Underhill Central School",
        "district": "Mount Mansfield Unified Union School District #401",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044300333",
    },
    {
        "school": "Brown River Middle School",
        "district": "Mount Mansfield Unified Union School District #401",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044300398",
    },
    {
        "school": "Camels Hump Middle School",
        "district": "Mount Mansfield Unified Union School District #401",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044300399",
    },
    {
        "school": "Enosburg Falls Junior/Senior High School",
        "district": "Enosburgh-Richford Unified Union School District #88",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044400022",
    },
    {
        "school": "Cold Hollow Career Center",
        "district": "Enosburgh-Richford Unified Union School District #88",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500044400089",
    },
    {
        "school": "Enosburg Falls Elementary School",
        "district": "Enosburgh-Richford Unified Union School District #88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044400113",
    },
    {
        "school": "Richford Elementary School",
        "district": "Enosburgh-Richford Unified Union School District #88",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044400255",
    },
    {
        "school": "Richford Junior/Senior High School",
        "district": "Enosburgh-Richford Unified Union School District #88",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044400256",
    },
    {
        "school": "Barre Town Elementary School",
        "district": "Barre Unified Union School District #97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044500024",
    },
    {
        "school": "Barre City Elementary/Middle School",
        "district": "Barre Unified Union School District #97",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044500055",
    },
    {
        "school": "Central Vermont Career Center",
        "district": "Barre Unified Union School District #97",
        "level": "High",
        "type": "Career and Technical School",
        "state": "VT",
        "nces_id": "500044500119",
    },
    {
        "school": "Spaulding Union High School",
        "district": "Barre Unified Union School District #97",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044500419",
    },
    {
        "school": "Grafton Elementary School",
        "district": "Windham Northeast Union Elementary School District #95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044600138",
    },
    {
        "school": "Westminster Schools",
        "district": "Windham Northeast Union Elementary School District #95",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044600460",
    },
    {
        "school": "Dover Elementary School",
        "district": "River Valleys Unified School District #73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044700105",
    },
    {
        "school": "Wardsboro Central School",
        "district": "River Valleys Unified School District #73",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044700359",
    },
    {
        "school": "Lake Elmore School",
        "district": "Lamoille South Unified Union School District #90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044800112",
    },
    {
        "school": "Peoples Academy Middle School",
        "district": "Lamoille South Unified Union School District #90",
        "level": "Middle",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044800157",
    },
    {
        "school": "Peoples Academy",
        "district": "Lamoille South Unified Union School District #90",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044800207",
    },
    {
        "school": "Stowe Elementary School",
        "district": "Lamoille South Unified Union School District #90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044800318",
    },
    {
        "school": "Stowe Middle/High School",
        "district": "Lamoille South Unified Union School District #90",
        "level": "High",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044800319",
    },
    {
        "school": "Morristown Elementary School",
        "district": "Lamoille South Unified Union School District #90",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044800438",
    },
    {
        "school": "Jamaica Village School",
        "district": "West River Valley Modified Union Education District #72A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044900165",
    },
    {
        "school": "Townshend Village School",
        "district": "West River Valley Modified Union Education District #72A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044900327",
    },
    {
        "school": "Newbrook Elementary School",
        "district": "West River Valley Modified Union Education District #72A",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VT",
        "nces_id": "500044900537",
    },
    {
        "school": "GOVERNOR'S HEALTH SCIENCE ACADEMY",
        "district": "ALEXANDRIA CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510012003067",
    },
    {
        "school": "VALLEY ACADEMY",
        "district": "VALLEY ACADEMY",
        "level": "Not applicable",
        "type": "Alternative Education School",
        "state": "VA",
        "nces_id": "510025803074",
    },
    {
        "school": "INTEGRATION STATION",
        "district": "ARLINGTON CO PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510027003068",
    },
    {
        "school": "JORDAN SPRINGS ELEMENTARY",
        "district": "FREDERICK CO PBLC SCHS",
        "level": "Not reported",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510147003071",
    },
    {
        "school": "FAIRLAWN ELEM",
        "district": "NORFOLK CITY PBLC SCHS",
        "level": "Elementary",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510267003073",
    },
    {
        "school": "RISING STAR EARLY CHILDHOOD EDUCATION CENTER AT MELCHERS",
        "district": "STAFFORD CO PBLC SCHS",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "VA",
        "nces_id": "510366003069",
    },
    {
        "school": "FIRST ACADEMY",
        "district": "SUFFOLK CITY PBLC SCHS",
        "level": "Not applicable",
        "type": "Career and Technical School",
        "state": "VA",
        "nces_id": "510371003070",
    },
    {
        "school": "ESD 105 Open Doors",
        "district": "Educational Service District 105",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530001303670",
    },
    {
        "school": "Open Doors",
        "district": "Anacortes School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530015003704",
    },
    {
        "school": "Renton Technical College DFTC",
        "district": "Renton Technical College",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530032503687",
    },
    {
        "school": "Renton Technical College DFTC Direct Enrollment",
        "district": "Renton Technical College",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530032503695",
    },
    {
        "school": "Ashe Preparatory Academy",
        "district": "Ashe Preparatory Academy",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530034603713",
    },
    {
        "school": "Catalyst Public Schools",
        "district": "Catalyst Public Schools",
        "level": "Not reported",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530034703723",
    },
    {
        "school": "Maple Grove Primary",
        "district": "Battle Ground School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530038003681",
    },
    {
        "school": "The Heights Learning Center",
        "district": "Camas School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530081003689",
    },
    {
        "school": "Selkirk Middle School",
        "district": "Central Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530111003706",
    },
    {
        "school": "College Place Open Doors Program",
        "district": "College Place School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530147003684",
    },
    {
        "school": "Colville Fish Hatchery",
        "district": "Colville School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530163003680",
    },
    {
        "school": "Lincoln County Tech",
        "district": "Davenport School District",
        "level": "High",
        "type": "Career and Technical School",
        "state": "WA",
        "nces_id": "530201003705",
    },
    {
        "school": "Sage Hills ECEAP",
        "district": "Ephrata School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530261003671",
    },
    {
        "school": "Tambark Creek Elementary School",
        "district": "Everett School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530267003699",
    },
    {
        "school": "Ferndale Virtual Academy",
        "district": "Ferndale School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530285003703",
    },
    {
        "school": "Fife Open Doors",
        "district": "Fife School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530288003718",
    },
    {
        "school": "Highland ESD 105 Open Doors",
        "district": "Highland School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530351003692",
    },
    {
        "school": "Glacier Middle School",
        "district": "Highline School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530354003674",
    },
    {
        "school": "Issaquah Preschool",
        "district": "Issaquah School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530375003707",
    },
    {
        "school": "Timberline Middle School",
        "district": "Lake Washington School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530423003708",
    },
    {
        "school": "Moses Lake Big Picture",
        "district": "Moses Lake School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530522003721",
    },
    {
        "school": "Harriet Rowley Elementary",
        "district": "Mount Vernon School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530540003683",
    },
    {
        "school": "NACHES VALLEY ESD 105 OPEN DOORS",
        "district": "Naches Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530546003679",
    },
    {
        "school": "Nooksack Reengagement",
        "district": "Nooksack Valley School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530567003691",
    },
    {
        "school": "Northshore Family Partnership",
        "district": "Northshore School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530591003720",
    },
    {
        "school": "Oakville Preschool",
        "district": "Oakville School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530600003677",
    },
    {
        "school": "Oakville Homelink",
        "district": "Oakville School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530600003712",
    },
    {
        "school": "Orcas Island Montessori Public",
        "district": "Orcas Island School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530630003696",
    },
    {
        "school": "Soar to Success",
        "district": "Pasco School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530657003675",
    },
    {
        "school": "Three Rivers Elementary",
        "district": "Pasco School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530657003686",
    },
    {
        "school": "Kamiak Elementary",
        "district": "Pullman School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530693003694",
    },
    {
        "school": "Dessie F Evans Elementary",
        "district": "Puyallup School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530696003690",
    },
    {
        "school": "Ancient Lakes Elementary",
        "district": "Quincy School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530708003717",
    },
    {
        "school": "Ridgefield Early Learning Center",
        "district": "Ridgefield School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530735003697",
    },
    {
        "school": "Griffin Bay School Open Doors",
        "district": "San Juan Island School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530765003700",
    },
    {
        "school": "Magnolia Elementary",
        "district": "Seattle School District No. 1",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003714",
    },
    {
        "school": "Lincoln High School",
        "district": "Seattle School District No. 1",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530771003719",
    },
    {
        "school": "Selah Academy Auxiliary",
        "district": "Selah School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530777003676",
    },
    {
        "school": "Selah Academy BPL",
        "district": "Selah School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530777003710",
    },
    {
        "school": "North City",
        "district": "Shoreline School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792003685",
    },
    {
        "school": "Edwin Pratt Learning Center",
        "district": "Shoreline School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530792003688",
    },
    {
        "school": "Snoqualmie Middle School",
        "district": "Snoqualmie Valley School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530804003693",
    },
    {
        "school": "Pacific Northwest Connections Academy",
        "district": "South Kitsap School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530816003672",
    },
    {
        "school": "Open Doors for SHS",
        "district": "Stevenson-Carson School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530852003701",
    },
    {
        "school": "Willard Early Learning Center",
        "district": "Tacoma School District",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530870003702",
    },
    {
        "school": "Tahoma Open Doors",
        "district": "Tahoma School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530876003716",
    },
    {
        "school": "Tonasket Outreach School",
        "district": "Tonasket School District",
        "level": "Other",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530894003673",
    },
    {
        "school": "Tonasket Choice High School",
        "district": "Tonasket School District",
        "level": "High",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530894003709",
    },
    {
        "school": "ECEAP",
        "district": "Walla Walla Public Schools",
        "level": "Prekindergarten",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530945003682",
    },
    {
        "school": "Wapato ESD 105 Open Doors",
        "district": "Wapato School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530948003698",
    },
    {
        "school": "Valley Academy of Learning K-8",
        "district": "Wenatchee School District",
        "level": "Elementary",
        "type": "Alternative Education School",
        "state": "WA",
        "nces_id": "530966003678",
    },
    {
        "school": "White River Early Learning Center",
        "district": "White River School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "530978003722",
    },
    {
        "school": "Columbia Elementary School",
        "district": "Woodland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531005003711",
    },
    {
        "school": "North Fork Elementary School",
        "district": "Woodland School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WA",
        "nces_id": "531005003715",
    },
    {
        "school": "Tomorrow River Community Middle (TRCMS)",
        "district": "Tomorrow River School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550033003119",
    },
    {
        "school": "Southern Lakes Alternative High",
        "district": "Burlington Area School District",
        "level": "High",
        "type": "Alternative Education School",
        "state": "WI",
        "nces_id": "550189003120",
    },
    {
        "school": "Western Wisconsin Virtual Charter School (WWVC)",
        "district": "Elmwood School District",
        "level": "Other",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550435003121",
    },
    {
        "school": "Luck Middle",
        "district": "Luck School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550828003124",
    },
    {
        "school": "Andrew S Douglas Middle",
        "district": "Milwaukee School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "550960003123",
    },
    {
        "school": "Treffert Way for the Exceptional Mind",
        "district": "North Fond du Lac School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551074003125",
    },
    {
        "school": "Trillium Middle",
        "district": "Viroqua Area School District",
        "level": "Middle",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551536003122",
    },
    {
        "school": "eCampus Academy Charter School",
        "district": "Watertown Unified School District",
        "level": "Not reported",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551575003127",
    },
    {
        "school": "Hawthorne Elementary",
        "district": "Waukesha School District",
        "level": "Elementary",
        "type": "Regular school",
        "state": "WI",
        "nces_id": "551578003126",
    },
]
